(***********************************************************************



                    Mathematica-Compatible Notebook



This notebook can be used on any computer system with Mathematica 3.0,

MathReader 3.0, or any compatible application. The data for the notebook 

starts with the line of stars above.



To get the notebook into a Mathematica-compatible application, do one of 

the following:



* Save the data starting with the line of stars above into a file

  with a name ending in .nb, then open the file inside the application;



* Copy the data starting with the line of stars above to the

  clipboard, then use the Paste menu command inside the application.



Data for notebooks contains only printable 7-bit ASCII and can be

sent directly in email or through ftp in text mode.  Newlines can be

CR, LF or CRLF (Unix, Macintosh or MS-DOS style).



NOTE: If you modify the data for this notebook not in a Mathematica-

compatible application, you must delete the line below containing the 

word CacheID, otherwise Mathematica-compatible applications may try to 

use invalid cache data.



For more information on notebooks and Mathematica-compatible 

applications, contact Wolfram Research:

  web: http://www.wolfram.com

  email: info@wolfram.com

  phone: +1-217-398-0700 (U.S.)



Notebook reader applications are available free of charge from 

Wolfram Research.

***********************************************************************)



(*CacheID: 232*)





(*NotebookFileLineBreakTest

NotebookFileLineBreakTest*)

(*NotebookOptionsPosition[    976229,      40815]*)

(*NotebookOutlinePosition[    976971,      40841]*)

(*  CellTagsIndexPosition[    976927,      40837]*)

(*WindowFrame->Normal*)







Notebook[{



Cell[CellGroupData[{

Cell[TextData[{

  "   \"Shooting\" and \"Bifurcating\" with\n    ",

  StyleBox["Mathematica",

    FontFamily->"Times New Roman",

    FontSlant->"Italic"]

}], "Title",

  PageWidth->WindowWidth,

  TextAlignment->Center],



Cell["\<\

Jay H. Wolkowisky

Department of Mathematics 

University of Colorado

Boulder, Colorado 80309, USA

wolkowis@euclid.colorado.edu\

\>", "Subtitle",

  PageWidth->WindowWidth,

  TextAlignment->Center],



Cell[CellGroupData[{



Cell[TextData[{

  "1 ",

  StyleBox["The Shooting Method",

    FontFamily->"Times New Roman"]

}], "Section",

  FontSize->18],



Cell[CellGroupData[{



Cell[TextData[{

  StyleBox[

  "As a simple example, we will consider the boundary value \nproblem (BVP):",

    

    FontSize->14],

  "\n",

  StyleBox[

  "y'' =f(x,y,y',\[Lambda]),\ny(0)=0,                                         \

                                        (1.1)\ny(1)=0.\n\nAssociated with \

this boundary value problem is the initial\n value problem (IVP):\ny'' \

=f(x,y,y',\[Lambda]), \ny(0)=0,                                               \

                                  (1.2)\ny'(0)=\[Alpha].\n\nLet \n\

y(x,\[Alpha],\[Lambda]) \nbe a solution of (1.2) for a fixed value of \

\[Lambda]. Solutions of (1.1) (if any) \nwill be determined by the condition:\

\n\ny(1,\[Alpha],\[Lambda])=0.                                                \

                            (1.3)\n\nSo for each value of  \[Alpha] that \

satisfies (1.3) there will exist a \nsolution of (1.1). We use Newton's \

method to find the roots of (1.3).\nThis takes the form of:\n\n",

    FontSize->14],

  Cell[BoxData[

      FormBox[

        StyleBox[

          RowBox[{\(\[Alpha]\_\(n + 1\)\), "=", 

            RowBox[{

              FormBox[\(\[Alpha]\_n - \),

                "TraditionalForm"], 

              FormBox[

                RowBox[{

                  FormBox["",

                    "TraditionalForm"], 

                  SuperscriptBox[

                    RowBox[{\(y\_\[Alpha]\), "(", 

                      RowBox[{"1", ",", 

                        FormBox[\(\[Alpha]\_n\),

                          "TraditionalForm"], ",", "\[Lambda]"}], ")"}], 

                    \(-1\)]}],

                "TraditionalForm"], "y", 

              RowBox[{"(", 

                RowBox[{"1", ",", 

                  FormBox[\(\[Alpha]\_n\),

                    "TraditionalForm"], ",", "\[Lambda]"}], ")"}]}]}],

          FontSize->16], TraditionalForm]],

    FontSize->16],

  StyleBox[" ,     ",

    FontSize->16],

  StyleBox["n ",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[

  " =0,1,2,...  (1.4)\n\nIn order to calculate the partial derivative in \

(1.4) we differentiate\nthe IVP (1.2) with respect to \[Alpha] and obtain the \

fourth\norder IVP:\n\n",

    FontSize->16],

  StyleBox["y",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox["''=f(x,",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`y\)],

    FontSize->16],

  StyleBox[",",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`y\)],

    FontSize->16],

  StyleBox["',\[Lambda]),\n",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`\(y\_\[Alpha]'\)'\)],

    FontSize->16],

  StyleBox["=",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`f\_y\)],

    FontSize->16],

  StyleBox["(x,",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`y\)],

    FontSize->16],

  StyleBox[",",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`y\)],

    FontSize->16],

  StyleBox["',\[Lambda])",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`y\_\(\[Alpha]\n\t\)\)],

    FontSize->16],

  StyleBox[" + ",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`f\_\(y'\)\)],

    FontSize->16],

  StyleBox["(x,",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`y\)],

    FontSize->16],

  StyleBox[",",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`y\)],

    FontSize->16],

  StyleBox["',\[Lambda])",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`y\_\[Alpha]\)],

    FontSize->16],

  StyleBox["',\n",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`y\)],

    FontSize->16],

  StyleBox[

  "(0)=0,                                                                     \

              (1.5)\n",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`y\_\[Alpha]\)],

    FontSize->16],

  StyleBox["(0)=0,\n",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`y\)],

    FontSize->16],

  StyleBox["'(0)=\[Alpha],\n",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`y\_\[Alpha]\)],

    FontSize->16],

  StyleBox["'(0)=1.\n\nWe solve this IVP for ",

    FontSize->16],

  StyleBox["y",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox["(1,",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`\[Alpha]\_n\)],

    FontSize->16],

  StyleBox[",\[Lambda]) and ",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`y\_\[Alpha]\)],

    FontSize->16],

  StyleBox["(1,",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`\[Alpha]\_n\)],

    FontSize->16],

  StyleBox[",\[Lambda]),",

    FontSize->16],

  StyleBox[" n",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[

  "=1,2,... , at\neach stage of the iteration scheme (1.4).\n\nOnce we have a \

solution, \[Alpha](",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`\(\[Lambda]\_0)\)\)],

    FontSize->16],

  StyleBox[", of (1.3) at \[Lambda] = ",

    FontSize->16],

  Cell[BoxData[

      FormBox[

        StyleBox[\(\[Lambda]\_0\),

          FontSize->16], TraditionalForm]]],

  " ",

  StyleBox["we can get a solution\nfor \[Lambda] = ",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`\[Lambda]\_0\  + \ \ \[CapitalDelta]\[Lambda]\)],

    FontSize->16],

  " ",

  StyleBox["by using \[Alpha]=\[Alpha](",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`\[Lambda]\_0\)],

    FontSize->16],

  StyleBox[

  ") as our first iterate to start the \niteration scheme (1.4). After two \

points \[Alpha](",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`\(\[Lambda]\_o)\)\)],

    FontSize->16],

  StyleBox[" and \[Alpha](",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`\[Lambda]\_0\)],

    FontSize->16],

  StyleBox[" + \[CapitalDelta]\[Lambda])",

    FontSize->16],

  " ",

  StyleBox[

  " are \nfound on the graph of \[Alpha](\[Lambda]), instead of using \

\[Alpha](",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`\[Lambda]\_0\)],

    FontSize->16],

  StyleBox[

  " + \[CapitalDelta]\[Lambda]) as our initial\niterate to find the next \

point \[Alpha](",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`\[Lambda]\_0\)],

    FontSize->16],

  StyleBox[

  " + 2 \[CapitalDelta]\[Lambda]), it is easy to see \n(by the following \

figure)  that by using\n\n       \[Alpha](",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`\[Lambda]\_0\)],

    FontSize->16],

  StyleBox[" + \[CapitalDelta]\[Lambda]) + (\[Alpha](",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`\[Lambda]\_0\)],

    FontSize->16],

  StyleBox[" + \[CapitalDelta]\[Lambda]) - \[Alpha](",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`\[Lambda]\_0\)],

    FontSize->16],

  StyleBox[")) = 2 \[Alpha](",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`\[Lambda]\_0\)],

    FontSize->16],

  StyleBox[" + \[CapitalDelta]\[Lambda]) - \[Alpha](",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`\[Lambda]\_0\)],

    FontSize->16],

  StyleBox[

  ") \n       \nas the initial iterate, the convergence will be faster. \n",

    FontSize->16]

}], "Input",

  FormatType->TextForm],



Cell[GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000<P0002F1000`40O003

h00Oogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00

ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogoo

ogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogoo

ogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo

8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo

003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003o

OoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOooo

OoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOooo

OolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolS

Ool00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol0

0?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mo

oomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomo

oomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomo

ob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=o

o`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00

ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogoo

ogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogoo

ogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo

8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo

003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003o

OoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOooo

OoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOooo

OolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolS

Ool00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol0

0?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mo

oomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomo

oomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomo

ob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=o

o`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00

ogooVgoo0g`0CWoo0g`0ogoo<goo002]Ool3O00jOol00g`0Oomoo`1cOol0

0g`0Oomoo`0fOol017`0Oomoog`0CGoo00Al07ooOoml0?mooc=oo`00WWoo

0W`037oo00Al07ooOoml02Eoo`03O01oogoo019oo`03O01oogoo00Uoo`9l

00aoo`=l025oo`03O01oogoo01Uoo`9l00eoo`=l00Moo`03O01oogoo009l

02]oo`9l00Yoo`03O01oogoo009l02Aoo`03O01oogoo01Yoo`9l00Uoo`03

O01oogoo009l00Qoo`03O01oogoo0?moobMoo`00WWoo00=l07ooOol02goo

00=l07ooOol00W`097oo00=l07ooOol04Goo00=l07ooOol02Woo00=l07oo

Ool02Woo00Al07ooOoml025oo`03O01oogoo01Uoo`03O01oogoo00]oo`04

O01oogooO007Ool017`0Oomoogoo0W`0:Woo00=l07ooOol02Goo00=l07oo

Ool00W`097oo00=l07ooOol06Woo00=l07ooOol027oo00=l07ooOol00W`0

27oo00=l07ooOol0ogoo9goo001YOol3O002Ool017`0Oomoogoo0g`00goo

0W`00Woo0g`00Woo00=l07ooOol04Goo17`000=oog`0O0000Woo00Al07oo

Oomoo`9l00=oo`9l0005Ooml07ooO01oo`03O0000gooO01oo`04Ool00g`0

Oomoo`02Ool017`0Oomoogoo27`000=oog`0O0000goo0W`017oo00Al07oo

Ooml00Eoo`03O01oogoo009oo`03O01oogoo009oo`03O01oogoo009oo`Al

0003Ooml07`0009oo`04O01oogooOol2O003Ool2O0000gooO01l0002Ool2

O004Ool00g`0Oomoo`02Ool017`0Oomoogoo27`000=oog`0O0000goo0W`0

0goo00Al07ooOoml00Yoo`03O01oogoo009oo`Al0003Ooml07`0009oo`04

O01oogooOol2O003Ool2O0001GooO01oog`0Ool017`01Goo00=l07ooOol0

0Woo00Al07ooOoml009oo`03O01oogoo00Uoo`05O01oogooOoml0002Ool6

O003Ool4O0000gooO01l0002Ool017`0Oomoogoo0W`00goo0W`000Aoog`0

Oomoo`9l009oo`03O01oogoo00Aoo`03O01oogoo009oo`03O01oogoo00Ql

0003Ooml07`000=oo`9l00=oo`04O01oogooO00;Ool017`0Oomoogoo17`0

00=oog`0O0000goo00=l07ooOol00W`00goo0W`000Aoog`0Oomoo`9l00=o

o`03O01oogoo009oo`03O01oogoo0?moobMoo`00JWoo00El07ooOomoog`0

009oo`05O01oogooOoml0002Ool017`0Oomoog`067oo0W`00Woo0g`00goo

00=l07ooOol00Woo00=l07ooOol017`00Woo00=l07ooOol00W`01goo00=l

07ooOol01Woo00=l07ooOol00goo0W`00Woo00=l07ooOol017`00goo00=l

07ooOol01Woo00=l07ooOol01goo00Al07ooOomoo`9l009oo`=l00=oo`03

O01oogoo009oo`03O01oogoo00Al0004Ooml07ooOol2O004Ool00g`0Oomo

o`06Ool00g`0Oomoo`03Ool2O002Ool00g`0Oomoo`04O002Ool00g`0Oomo

o`0?Ool2O002Ool3O003Ool00g`0Oomoo`02Ool00g`0Oomoo`04O002Ool0

0g`0Oomoo`02O006Ool00g`0Oomoo`02Ool00g`0Oomoo`0GOol01G`0Oomo

ogooO0000Woo0W`00Woo0g`00goo00=l07ooOol00Woo00=l07ooOol01G`0

0Woo00=l07ooOol027oo00=l07ooOol01Goo00=l07ooOol00goo0W`00Woo

00=l07ooOol017`00Woo00=l07ooOol03goo0W`00Woo0g`017oo00El07oo

Oomoog`0009oo`El009oo`03O01oogoo00Moo`03O01oogoo0?moobMoo`00

JWoo00=l07ooOol00W`00Woo00El07ooOomoog`0009oo`03O01oogoo00Al

01Eoo`9l00=oo`9l00=oo`03O01oogoo009oo`04O01oogooO002Ool017`0

Oomoog`00Woo00=l07ooOol01Woo00=l07ooOol01goo00Al07ooOomoo`9l

00=oo`04O01oogooO002Ool01G`0OomoogooO00027oo00=l07ooOol01goo

00Al07ooOomoo`9l00=oo`9l00=oo`03O01oogoo009oo`04O01oogooO002

Ool00g`0Ooml0002Ool2O004Ool00g`0Oomoo`07Ool017`0Oomoogoo0W`0

0goo00Al07ooOoml009oo`04O01oogooO00AOol2O003Ool2O003Ool00g`0

Oomoo`02Ool017`0Oomoog`00Woo00Al07ooOoml009oo`9l00Ioo`03O01o

ogoo009oo`9l00Qoo`Ml00Yoo`03O01oogoo00=oo`9l00=oo`9l00=oo`03

O01oogoo009oo`04O01oogooO002Ool00g`0Ooml0002O00:Ool00g`0Oomo

o`06Ool017`0Oomoogoo0W`00goo00Al07ooOoml009oo`04O01oogooO00A

Ool2O003Ool2O004Ool01G`0OomoogooO0000Woo00El07ooOoml07oo00=l

00Uoo`03O01oogoo0?moobMoo`00JWoo00El07ooO01oog`0009oo`05O01o

ogooOoml0002Ool017`0Oomoog`00Woo00=l07ooOol04goo0W`00goo0W`0

0goo00=l07ooOol00Woo0W`000=oog`0Ool01Goo0g`01Goo1g`01Woo00Al

07ooOomoo`9l00=oo`9l0003Ooml07oo00Eoo`03O01oogoo00=oo`Ml00Io

o`04O01oogooOol2O003Ool2O003Ool00g`0Oomoo`02Ool2O0000gooO01o

o`03Ool017`0Oomoog`00Woo1g`01Woo00Al07ooOomoo`9l00=oo`9l0003

Ooml07oo00Aoo`03O01oogoo00=oo`Ml00Eoo`9l00=oo`9l00=oo`03O01o

ogoo009oo`9l0003Ooml07oo00Aoo`04O01oogooO007Ool00g`0Oomoo`02

Ool2O00JOol00g`0Oomoo`02Ool2O003Ool2O003Ool00g`0Oomoo`02Ool2

O0000gooO01oo`0=Ool7O005Ool017`0Oomoogoo0W`00goo0W`000=oog`0

Ool017oo00=l07ooOol017oo1g`017oo0W`00goo0W`017oo00Al07ooOomo

o`9l0003Ooml07oo00moo`03O01oogoo0?moobMoo`00JWoo00El07ooO01o

og`000=oo`=l009oo`=l009oo`9l00=oo`03O01oogoo011oo`9l00=oo`9l

00=oo`03O01oogoo00=oo`=l015oo`03O01oogoo00Moo`05O01oogooOoml

0005Ool3O006Ool00g`0Oomoo`06Ool00g`0Oomoo`07Ool017`0Oomoogoo

0W`00goo0W`00goo00=l07ooOol00goo0g`01Goo0g`01Goo00=l07ooOol0

1goo00El07ooOomoog`000Eoo`=l00Eoo`03O01oogoo00moo`9l00=oo`9l

00=oo`03O01oogoo00=oo`=l00Ioo`=l00Moo`03O01oogoo009oo`9l01]o

o`04O01oogooOol2O003Ool2O003Ool00g`0Oomoo`03Ool3O00AOol00g`0

Oomoo`06Ool01G`0OomoogooO0001Goo0g`01Goo00=l07ooOol03goo0W`0

0goo0W`017oo00=l07ooOol00Woo0g`047oo00=l07ooOol0ogoo9goo001Z

Ool2O002Ool00g`0Oomoo`07Ool00g`0Oomoo`0IOol2O003Ool3O002Ool0

0g`0Oomoo`03Ool3O00AOol00g`0Oomoo`08Ool017`0Ooml07`01Goo0g`0

1Woo00=l07ooOol01Woo00=l07ooOol01goo00Al07ooOomoo`9l00=oo`=l

009oo`03O01oogoo00=oo`=l00eoo`03O01oogoo00Qoo`04O01oog`0O005

Ool3O005Ool00g`0Oomoo`0?Ool2O003Ool3O002Ool00g`0Oomoo`03Ool3

O00@Ool00g`0Oomoo`02Ool00g`0Oomoo`07Ool7O00<Ool017`0Oomoogoo

0W`00goo0g`00Woo00=l07ooOol00goo0g`04Goo00=l07ooOol01goo00Al

07ooO01l00Eoo`=l00Eoo`03O01oogoo00moo`9l00=oo`=l00=oo`03O01o

ogoo009oo`=l011oo`03O01oogoo0?moobMoo`00JWoo00El07ooOomoog`0

00Uoo`03O01oogoo01Yoo`Al0003Ooml07`0009oo`03O01oogoo00Aoo`03

O01oogoo011oo`03O01oogoo00Qoo`04O01oog`0O006Ool00g`0Oomoo`05

Ool00g`0Oomoo`06Ool00g`0Oomoo`07Ool00g`0Oomoo`02Ool4O0000goo

O01l0002Ool00g`0Oomoo`04Ool00g`0Oomoo`0<Ool00g`0Oomoo`08Ool0

17`0Ooml07`01Woo00=l07ooOol017oo00=l07ooOol047oo17`000=oog`0

O0000Woo00=l07ooOol017oo00=l07ooOol03goo00=l07ooOol00Woo00=l

07ooOol06Woo00=l07ooOol00Woo17`000=oog`0O0000Woo00=l07ooOol0

17oo00=l07ooOol047oo00=l07ooOol01goo00Al07ooO01l00Ioo`03O01o

ogoo00Aoo`03O01oogoo011oo`Al0003Ooml07`000=oo`03O01oogoo00=o

o`03O01oogoo00moo`03O01oogoo0?moobMoo`00JGoo0W`00Woo0g`0;Woo

00=l07ooOol017oo00=l07ooOol047oo00=l07ooOol02Goo0W`01goo00=l

07ooOol01Goo00=l07ooOol01Woo00=l07ooOol01goo00=l07ooOol02goo

00=l07ooOol017oo00=l07ooOol037oo00=l07ooOol02Goo0W`01goo00=l

07ooOol017oo00=l07ooOol06Goo00=l07ooOol017oo00=l07ooOol03goo

00=l07ooOol00Woo00=l07ooOol05Woo00El07ooOomoog`000eoo`03O01o

ogoo00Aoo`03O01oogoo011oo`03O01oogoo00Qoo`9l00Moo`03O01oogoo

00Aoo`03O01oogoo01Yoo`03O01oogoo00=oo`03O01oogoo00moo`03O01o

ogoo0?moobMoo`00WWoo00El07ooOomoog`0009oo`03O01oogoo01aoo`9l

00Aoo`04O01oogooO007Ool00g`0Oomoo`0AOol00g`0Oomoo`0:Ool01G`0

OomoogooO0000Woo00=l07ooOol067oo0W`017oo00Al07ooOoml00Ioo`03

O01oogoo01Uoo`05O01oogooOoml0002Ool00g`0Oomoo`0?Ool01G`0Oomo

ogooO0006Woo17`03Goo00El07ooOomoog`0009oo`03O01oogoo01]oo`9l

00Aoo`04O01oogooO006Ool00g`0Oomoo`0JOol017`0Oomoog`00Woo00=l

07ooOol03goo00=l07ooOol0ogoo9goo002NOol3O00017ooO01l07`087oo

00=l07ooOol00Woo0g`01Woo0g`057oo00=l07ooOol02Goo0g`000Aoog`0

O01l01aoo`03O01oogoo009oo`=l00Eoo`=l01]oo`=l0004Ooml07`0O00@

Ool3O002Ool00g`0Oomoo`0JOol2O00>Ool3O00017ooO01l07`07goo00=l

07ooOol00Woo0g`01Goo0g`077oo1W`047oo0g`0ogoo:Goo002SOol2O00V

Ool2O00^Ool2O00ROol2O00XOol2O017Ool2O00UOol2O00XOol2O03oOoll

Ool00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol0

0?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mo

oomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomo

oomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomo

ob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=o

o`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00

ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogoo

ogooogoo8goo003oOoooOoooOolSOol00?mooleoo`<00?mooe9oo`00ogoo

O7oo0`00CGoo00@007ooOol00?mooe9oo`00ogooNgoo00@007ooOol004eo

o`03001oogoo0080055oo`<00?aoo`00ogooNgoo00<007ooOol00P00C7oo

00<007ooOol00P00D7oo00@007ooOol00?aoo`00ogoo<7oo0`00B7oo00<0

07ooOol00P00@Goo0P0017oo0P000goo00<007ooOol00P0000=oo`00Ool0

1Woo00<007ooOol00goo00@007ooOomoo`L00003Ool007oo00=oo`T00003

Ool0000000Aoo`8001ioo`03001oogoo00800?]oo`00ogoo97oo0P0017oo

0P0000Eoo`00Ool007oo008003ioo`8000Aoo`80009oo`03001oogoo0080

00Uoo`03001oogoo009oo`04001oogooOol90002Ool20004Ool2000LOol2

0003Ool40002Ool01000Oomoo`002Woo00<007ooOol027oo00<007ooOol0

0Woo00<007ooOol017oo00<007ooOol017oo0P0000=oo`0000000goo1000

4Woo0P0017oo0P000Woo0P000Woo0P001Woo00<007ooOol00goo00<007oo

Ool00Woo100017oo2@0000=oo`00000017oo0P00d7oo003oOolTOol20003

Ool40002Ool00`00Oomoo`02000mOol20003Ool400001Goo001oogoo0000

2Woo00<007ooOol01Woo00<007ooOol017oo0P000Woo0P000goo100077oo

0P000Woo00@007ooOol000=oo`<000Yoo`03001oogoo00Uoo`03001oogoo

00Uoo`03001oogoo00=oo`80009oo`80009oo`04001oogoo000BOol20003

Ool40002Ool00`00Oomoo`020006Ool00`00Oomoo`08Ool01@00Oomoogoo

00000goo00<007ooOol017oo0P0000=oo`0000000goo1000cgoo003oOolU

Ool20002Ool01000Oomoo`000Woo00<007ooOol00P00?Woo0P000Woo00@0

07ooOol0009oo`<000Yoo`03001oogoo00Moo`03001oogoo00=oo`8000=o

o`80009oo`04001oogoo000LOol20002Ool00`00Oomoo`0AOol00`00Oomo

o`0:Ool00`00Oomoo`08Ool00`00Oomoo`02Ool20003Ool20002Ool00`00

Oomoo`0DOol20002Ool01000Oomoo`000Woo00@007ooOol000Moo`03001o

ogoo00aoo`8000=oo`03001oogoo00=oo`80009oo`80009oo`04001oogoo

003?Ool00?moobEoo`80009oo`03001oogoo00=oo`03001oogoo008003io

o`80009oo`03001oogoo011oo`03001oogoo00Moo`03001oogoo009oo`80

00Aoo`80009oo`03001oogoo01ioo`800003Ool007oo00ioo`P000Uoo`80

00Yoo`04001oogooOol20004Ool200000goo001oo`0EOol20002Ool00`00

Oomoo`04Ool30007Ool00`00Oomoo`0<Ool20003Ool00`00Oomoo`02Ool2

0003Ool20002Ool00`00Oomoo`3@Ool00?moobIoo`800003Ool007oo00Ao

o`04001oogoo0010Ool200000goo001oo`0=Ool80007Ool01000Oomoogoo

0P001Goo0P0000=oo`00Ool07goo0`004goo0P003Goo00<007ooOol027oo

00<007ooOol00P001Goo0`0067oo0P0000=oo`00Ool02goo20002goo0P00

17oo00@007ooOomoo`8000Aoo`800003Ool007oo0=5oo`00ogoo9Woo0`00

1goo0`00@7oo0`004Woo0P002Woo00<007ooOol00P001Woo0`008Woo0P00

57oo00<007ooOol037oo00<007ooOol01goo00<007ooOol00P001Woo0P00

67oo0`0047oo0P002goo10001Goo00<007ooOol00P001Goo0`00dgoo003o

OolWOol2001;Ool2000COol00`00Oomoo`08Ool00`00Oomoo`020007Ool2

000ROol2000DOol00`00Oomoo`0<Ool00`00Oomoo`08Ool01000Ool00000

1Woo0P006Goo0P004Goo00<007ooOol02Woo0P001Woo00<007ooOol00P00

1Woo0P00dgoo003oOolWOol2001;Ool2000COol00`00Oomoo`09Ool01000

Ool000001goo0P008goo00<007ooOol04Woo00<007ooOol01goo00<007oo

Ool00Woo00<007ooOol027oo0`0027oo00<007ooOol05goo0P004Goo00<0

07ooOol02goo00<007ooOol01Goo00@007oo000000Ioo`800==oo`00ogoo

:7oo00<007ooOol0BWoo00<007ooOol04Goo00<007ooOol02Goo0`002Goo

00<007ooOol07Goo00@007ooOol001moo`80009oo`8000]oo`8000Aoo`04

001oogoo000KOol00`00Oomoo`0?Ool00`00Oomoo`07Ool00`00Oomoo`02

Ool00`00Oomoo`04Ool30008Ool00`00Oomoo`16Ool20005Ool30021Ool0

0?moobAoo`04001oogoo0019Ool01000Oomoo`008Goo0P001Goo00@007oo

Ool0021oo`04001oogoo000POol5000;Ool00`00Oomoo`03Ool01000Oomo

o`005goo00@007ooOol001aoo`04001oogooOol20007Ool20004Ool01000

Oomoo`00BGoo0P0017oo1@00P7oo003oOolTOol01000Oomoo`00BGoo00@0

07ooOol0025oo`03001oogoo00Aoo`04001oogoo000QOol3000QOol3000C

Ool3000GOol01000Oomoo`007Goo1@001goo00<007ooOol00goo00@007oo

Ool004Yoo`8000=oo`<00003Ool007oo07moo`00ogoo9Goo0`00BWoo0`00

:Goo0`008Goo0P00>7oo0P006Goo0`007Woo0`003goo0`00BWoo0`000Woo

00D007ooOomoo`00081oo`00ogoo9Goo0P00Bgoo0P00:Woo0P00Mgoo0P00

<Goo0P00<7oo00<007ooOol06Goo0P000Woo00<007ooOol0PWoo003oOooo

OomnOol5000FOol300000goo001oo`23Ool00?mooomooaEoo`03001oogoo

06]oo`@0019oo`D008Aoo`00l7oo00<007ooOol0=Goo00<007ooOol0DGoo

00<007ooOol0C7oo00<007ooOol0AGoo00<007ooOol0J7oo2P0047oo1000

Q7oo003oOolZOol00`00Oomoo`1@Ool00`00Oomoo`1<Ool00`00Oomoo`15

Ool00`00Oomoo`09OomO0006Ool4000@Ool30025Ool00?moobYoo`03001o

ogoo051oo`03001oogoo045ooel0065oo`@001Eoo`8008Eoo`00ogoo:Woo

00<007ooOol0=GooG`002goo00<007ooOol0AGoo00<007ooOol0Igoo0`00

6Woo00<007ooOol0Pgoo003oOol3OomO000KOol00`00Oomoo`1<Ool00`00

Oomoo`15Ool00`00Oomoo`1UOol2002SOol00?1ooa8002Moo`03001oogoo

051oo`03001oogoo04aoo`03001oogoo04Eoo`03001oogoo07moo`05001o

ogooOol00026Ool00?1oo`03001oogoo03Ioo`03001oogoo051oo`03001o

ogoo04aoo`03001oogoo04Eoo`03001oogoo07moo`800003Ool0000008Io

o`00l7oo00<007ooOol0=Woo00<007ooOol0D7oo00<007ooOol0C7oo00<0

07ooOol0AGoo00<007ooOol0P7oo1000QWoo003`Ool00`00Oomoo`0fOol0

0`00Oomoo`1@Ool00`00Oomoo`1<Ool00`00Oomoo`15Ool00`00Oomoo`20

Ool30027Ool00?1oo`03001oogoo03Ioo`03001oogoo051oo`03001oogoo

04aoo`03001oogoo04Eoo`03001oogoo0?moo`]oo`00l7oo00<007ooOol0

=Woo00<007ooOol0D7oo00<007ooOol0C7oo00<007ooOol0AGoo00<007oo

Ool0ogoo2goo003`Ool00`00Oomoo`0fOol00`00Oomoo`1@Ool00`00Oomo

o`1<Ool00`00Oomoo`15Ool00`00Oomoo`3oOol;Ool00?1oo`03001oogoo

03Ioo`03001oogoo051oo`03001oogoo04aoo`03001oogoo04Eoo`03001o

ogoo0?moo`]oo`00l7oo00<007ooOol0=Woo00<007ooOol0D7oo00<007oo

Ool0C7oo00<007ooOol0AGoo00<007ooOol0ogoo2goo003`Ool00`00Oomo

o`0fOol00`00Oomoo`1@Ool00`00Oomoo`1<Ool00`00Oomoo`15Ool00`00

Oomoo`3oOol;Ool00?1oo`03001oogoo03Ioo`03001oogoo051oo`03001o

ogoo04aoo`03001oogoo04Eoo`03001oogoo0?moo`]oo`00l7oo00<007oo

Ool0=Woo00<007ooOol0D7oo00<007ooOol0C7oo00<007ooOol0AGoo00<0

07ooOol0ogoo2goo003`Ool00`00Oomoo`0fOol00`00Oomoo`1@Ool00`00

Oomoo`1<Ool00`00Oomoo`15Ool00`00Oomoo`3oOol;Ool00?1oo`03001o

ogoo03Ioo`03001oogoo051oo`03001oogoo04aoo`03001oogoo04Eoo`03

001oogoo0?moo`]oo`00l7oo00<007ooOol0=Woo00<007ooOol0D7oo00<0

07ooOol0C7oo00<007ooOol0AGoo00<007ooOol0ogoo2goo003`Ool00`00

Oomoo`0fOol00`00Oomoo`1@Ool00`00Oomoo`1<Ool00`00Oomoo`15Ool0

0`00Oomoo`3oOol;Ool00?1oo`03001oogoo03Ioo`03001oogoo051oo`03

001oogoo04aoo`03001oogoo04Eoo`03001oogoo0?moo`]oo`00l7oo00<0

07ooOol0=Woo00<007ooOol0D7oo00<007ooOol0C7oo00<007ooOol0ogoo

Dgoo003`Ool00`00Oomoo`0fOol00`00Oomoo`1@Ool00`00Oomoo`1<Ool0

0`00Oomoo`3oOomCOol00?1oo`03001oogoo03Ioo`03001oogoo051oo`03

001oogoo04aoo`03001oogoo04Eoo`03001oogoo0?moo`]oo`00l7oo00<0

07ooOol0=Woo00<007ooOol0D7oo00<007ooOol0C7oo00<007ooOol0ogoo

Dgoo003`Ool00`00Oomoo`0fOol00`00Oomoo`1@Ool00`00Oomoo`1<Ool0

0`00Oomoo`3oOomCOol00?1oo`03001oogoo03Ioo`03001oogoo051oo`03

001oogoo04aoo`03001oogoo04Eoo`03001oogoo0?moo`]oo`00l7oo00<0

07ooOol0=Woo00<007ooOol0D7oo00<007ooOol0C7oo00<007ooOol0AGoo

00<007ooOol0ogoo2goo003`Ool00`00Oomoo`0fOol00`00Oomoo`1@Ool0

0`00Oomoo`1<Ool00`00Oomoo`3oOomCOol00?1oo`03001oogoo03Ioo`03

001oogoo051oo`03001oogoo04aoo`03001oogoo0?mooe=oo`00l7oo00<0

07ooOol0=Woo00<007ooOol0D7oo00<007ooOol0C7oo00<007ooOol0A7oo

00<007ooOol0ogoo37oo003`Ool00`00Oomoo`0fOol00`00Oomoo`1@Ool0

0`00Oomoo`1<Ool00`00Oomoo`3oOomCOol00?1oo`03001oogoo03Ioo`03

001oogoo051oo`03001oogoo04aoo`03001oogoo0?mooe=oo`00l7oo00<0

07ooOol0=Woo00<007ooOol0Wgoo00<007ooOol0A7oo00<007ooOol0ogoo

37oo003`Ool00`00Oomoo`0fOol00`00Oomoo`1@Ool00`00Oomoo`1<Ool0

0`00Oomoo`14Ool00`00Oomoo`3oOol<Ool00?1oo`03001oogoo03Ioo`03

001oogoo051oo`03001oogoo0?mooj9oo`00l7oo00<007ooOol0=Woo00<0

07ooOol0Wgoo00<007ooOol0A7oo00<007ooOol0ogoo37oo003`Ool00`00

Oomoo`0fOol00`00Oomoo`1@Ool00`00Oomoo`1<Ool00`00Oomoo`14Ool0

0`00Oomoo`3oOol<Ool00?1oo`03001oogoo03Ioo`03001oogoo051oo`03

001oogoo0?mooj9oo`00l7oo00<007ooOol0=Woo00<007ooOol0ogoomGoo

003`Ool00`00Oomoo`0fOol00`00Oomoo`2OOol00`00Oomoo`14Ool00`00

Oomoo`3oOol<Ool00?1oo`03001oogoo03Ioo`03001oogoo051oo`03001o

ogoo04aoo`03001oogoo04Aoo`03001oogoo0?moo`aoo`00l7oo00<007oo

Ool0=Woo00<007ooOol0iWoo00<007ooOol0ogoo37oo003`Ool00`00Oomo

o`0fOol00`00Oomoo`2OOol00`00Oomoo`14Ool00`00Oomoo`3oOol<Ool0

0?1oo`03001oogoo03Ioo`03001oogoo051oo`03001oogoo04aoo`03001o

ogoo04Aoo`03001oogoo0?moo`aoo`00l7oo00<007ooOol0=Woo00<007oo

Ool0D7oo00<007ooOol0Tgoo00<007ooOol0ogoo37oo003`Ool00`00Oomo

o`0fOol00`00Oomoo`3VOol00`00Oomoo`3oOol<Ool00?1oo`03001oogoo

03Ioo`03001oogoo051oo`03001oogoo04aoo`03001oogoo04Aoo`03001o

ogoo0?moo`aoo`00l7oo00<007ooOol0=Woo00<007ooOol0D7oo00<007oo

Ool0Tgoo00<007ooOol0ogoo37oo003`Ool00`00Oomoo`0fOol00`00Oomo

o`3VOol00`00Oomoo`3oOol<Ool00?1oo`03001oogoo03Ioo`03001oogoo

09moo`03001oogoo04Aoo`03001oogoo0?moo`aoo`00l7oo00<007ooOol0

=Woo00<007ooOol0Cgoo00<007ooOol0CGoo00<007ooOol0A7oo00<007oo

Ool0ogoo37oo003`Ool00`00Oomoo`0fOol00`00Oomoo`1?Ool00`00Oomo

o`2DOol00`00Oomoo`3oOol<Ool00=ioo`<000moo`03001oogoo03Ioo`03

001oogoo09ioo`03001oogoo04Eoo`03001oogoo0?moo`aoo`00cWoo1000

2goo00@007ooOol000=oo`@000Qoo`03001oogoo03Ioo`03001oogoo04mo

o`03001oogoo04aoo`03001oogoo04Eoo`03001oogoo0?moo`aoo`00cWoo

0P003Goo00<007ooOol00P0017oo0P0027oo00<007ooOol0=Woo00<007oo

Ool0Cgoo00<007ooOol0U7oo00<007ooOol0ogoo37oo003>Ool00`00Oomo

o`0<Ool00`00Oomoo`020005Ool00`00Oomoo`06Ool00`00Oomoo`0fOol0

0`00Oomoo`3VOol00`00Oomoo`3oOol<Ool00<=oo`D0009oo`05001oogoo

Ool00003Ool20004Ool20002Ool20002Ool20005Ool00`00Oomoo`06Ool0

0`00Oomoo`0fOol00`00Oomoo`1?Ool2O01=Ool00`00Oomoo`15Ool00`00

Oomoo`3oOol<Ool00<=oo`80009oo`D0009oo`04001oogooOol20003Ool4

0002Ool01000Oomoo`001Woo00<007ooOol01Woo00<007ooOol0=Goo0`00

CWoo1W`0Bgoo00<007ooOol0AGoo00<007ooOol0ogoo37oo0032Ool20004

Ool200001Goo001oogoo000017oo0P000Woo00@007ooOol000=oo`<000Io

o`03001oogoo00Ioo`03001oogoo00800003Ool00000009oo`800003Ool0

0000009oo`800003Ool00000009oo`03001oogoo00800003Ool00000009o

o`800003Ool00000009oo`800003Ool00000009oo`03001oogoo00800003

Ool0000000@004Ioo`03O01oogoo00Aoo`Il09=oo`03001oogoo0?moo`ao

o`00`Woo0P0017oo0P0017oo00<007ooOol00Woo0P000Woo00<007ooOol0

3Goo00<007ooOol01Woo00<007ooOol0<goo1`00AWoo17`000=oog`0O000

1G`0Bgoo00<007ooOol0AGoo00<007ooOol0ogoo37oo0032Ool20004Ool2

0004Ool00`00Oomoo`03Ool200000goo001oo`0>Ool00`00Oomoo`06Ool0

0`00Oomoo`0cOol700000gooO01l0002Ool00g`0Oomoo`02O0000gooO01l

0002Ool2O0000gooO01l0002Ool2O0000gooO01l0002Ool00g`0Oomoo`02

O0000gooO01l0002Ool2O0000gooO01l0002Ool2O0000gooO01l0002Ool2

O0000gooO01l0002Ool00g`0Oomoo`02O0000gooO01l0002Ool2O0000goo

O01l0007O01;Ool00`00Oomoo`15Ool00`00Oomoo`3oOol<Ool00<9oo`80

00Aoo`8000Aoo`03001oogoo00=oo`<0011oo`03001oogoo00Ioo`03001o

ogoo03=oo`L004Moo`Al0003Ooml07`000Al09=oo`03001oogoo0?moo`ao

o`00`goo00<007ooOol00goo0P000goo00<007ooOol017oo0P0047oo00<0

07ooOol01Woo00<007ooOol0<goo1P0000=l07ooOol0@goo0W`01Woo1G`0

Tgoo00<007ooOol0ogoo37oo0033Ool2000017oo000007oo0P000goo00<0

07ooOol017oo0P0047oo00<007ooOol01Woo00<007ooOol0=Goo100000=l

07ooOol0C7oo00=l07ooOol0C7oo00<007ooOol0AGoo00<007ooOol0ogoo

37oo0034Ool30003Ool01@00Oomoogoo00001goo00<007ooOol03Woo00<0

07ooOol01Woo00<007ooOol0?7oo00=l07ooOol0BWoo00=l07ooOol0Bgoo

00<007ooOol0AGoo00<007ooOol0ogoo37oo003>Ool01@00Oomoogoo0000

0Woo00<007ooOol03goo00<007ooOol01Woo00<007ooOol0?goo00=l07oo

Ool0Agoo00=l07ooOol0ogooXWoo003>Ool20002Ool01000Oomoo`0047oo

0P0027oo00<007ooOol0?goo00=l07ooO000UGoo00<007ooOol0AGoo00<0

07ooOol0ogoo37oo003>Ool4000017oo000000003Woo100027oo00<007oo

Ool0@Woo0W`0Tgoo00<007ooOol0AGoo00<007ooOol0ogoo37oo003COol2

000KOol00`00Oomoo`15Ool00g`0Oomoo`11Ool00g`0Oomoo`3oOonROol0

0?1oo`03001oogoo04Moo`03O01oogoo03moo`03O01oogoo0?mooj9oo`00

l7oo00<007ooOol0B7oo0W`0SGoo00<007ooOol0AGoo00<007ooOol0ogoo

37oo003`Ool00`00Oomoo`1;Ool2O00lOol00g`0Oomoo`2COol00`00Oomo

o`3oOol<Ool00?1oo`03001oogoo08Uoo`03O01oogoo0?mooj9oo`00l7oo

00<007ooOol0CWoo0W`0Qgoo00<007ooOol0ogooE7oo003`Ool00`00Oomo

o`1AOol2O024Ool00`00Oomoo`3oOomDOol00?1oo`03001oogoo08Uoo`03

O01oogoo04]oo`03001oogoo0?mooeAoo`00l7oo00<007ooOol0E7oo0g`0

<Woo00=l07ooOol0Bgoo00<007ooOol0ogooE7oo003`Ool00`00Oomoo`1H

Ool00g`0Oomoo`1lOol00`00Oomoo`14Ool00`00Oomoo`3oOol=Ool00?1o

o`03001oogoo05Yoo`9l02eoo`03O01oogoo04]oo`03001oogoo0?mooeAo

o`00l7oo00<007ooOol0Fgoo0W`0;7oo00=l07ooOol0Bgoo00<007ooOol0

ogooE7oo003`Ool00`00Oomoo`1NOol00g`0Oomoo`1fOol00`00Oomoo`14

Ool00`00Oomoo`3oOol=Ool00?1oo`03001oogoo061oo`9l07Eoo`03001o

ogoo04Aoo`03001oogoo0?moo`eoo`00l7oo00<007ooOol0RGoo00=l07oo

Ool0Bgoo00<007ooOol0ogooE7oo003`Ool00`00Oomoo`1TOol2O01aOol0

0`00Oomoo`14Ool00`00Oomoo`3oOol=Ool00?1oo`03001oogoo0=Moo`03

001oogoo04Aoo`03001oogoo0?moo`eoo`00l7oo00<007ooOol0RGoo00=l

07ooOol0Bgoo00<007ooOol0ogooE7oo003`Ool00`00Oomoo`1ZOol2O00M

Ool00g`0Oomoo`1;Ool00`00Oomoo`14Ool00`00Oomoo`3oOol=Ool00?1o

o`03001oogoo06eoo`03O01oogoo06Moo`03001oogoo04Aoo`03001oogoo

0?moo`eoo`00l7oo00<007ooOol0Kgoo00=l07ooOol05goo00=l07ooOol0

Bgoo00<007ooOol0A7oo00<007ooOol0ogoo3Goo003`Ool00`00Oomoo`1`

Ool2O00FOol2O0000gooO01oo`1:Ool00`00Oomoo`14Ool00`00Oomoo`3o

Ool=Ool00?1oo`03001oogoo07=oo`03O01oogoo019oo`03O01oog`004ao

o`03001oogoo04Aoo`03001oogoo0?moo`eoo`00l7oo00<007ooOol0M7oo

0W`04Woo00=l07ooO000C7oo00<007ooOol0A7oo00<007ooOol0ogoo3Goo

003`Ool00`00Oomoo`1gOol00g`0Oomoo`0>Ool3O01<Ool00`00Oomoo`14

Ool00`00Oomoo`3oOol=Ool00?1oo`03001oogoo07Yoo`03O01oogoo00ao

o`9l04aoo`03001oogoo04Aoo`03001oogoo0?moo`eoo`00l7oo00<007oo

Ool0NWoo00=l07ooOol037oo0W`0C7oo00<007ooOol0A7oo00<007ooOol0

ogoo3Goo002cOol4000=Ool3000POol40005Ool00`00Oomoo`1mOol00g`0

Oomoo`09Ool00g`0Oomoo`1;Ool00`00Oomoo`14Ool00`00Oomoo`3oOol=

Ool00;=oo`8000ioo`04001oogoo000ROol20005Ool00`00Oomoo`20Ool2

O007Ool00`00Oomoo`1;Ool00`00Oomoo`14Ool00`00Oomoo`3oOol=Ool0

0;=oo`03001oogoo00eoo`03001oogoo0080029oo`03001oogoo00=oo`03

001oogoo08Moo`D004]oo`03001oo`0O04Aoo`03001oogoo0?moo`eoo`00

Z7oo1@000Woo00D007ooOomoo`0000Aoo`8000Aoo`800005Ool007oo001o

o`030006Ool00`00Oomoo`02Ool90002Ool20004Ool20004Ool00`00Oomo

o`03Ool00`00Oomoo`23Ool2O002Ool2000017`000000000BWoo00<0000O

01l00P0O@Woo00<007ooOol0ogoo3Goo002XOol20002Ool50002Ool00`00

Oomoo`02Ool20003Ool40002Ool00`00Oomoo`020006Ool00`00Oomoo`02

Ool00`00Oomoo`04Ool20002Ool20003Ool40003Ool00`00Oomoo`03Ool0

0`00Oomoo`26Ool2O00200001G`000007`0OOol00P0O0Woo0P0O00=oo`0O

01l00Woo00<07gooOol00P0O00=oo`0O01l00Woo0P0O00=oo`0O01l00Woo

00<07gooOol097oo0`0O00=oo`0O00001@0O@Goo00<007ooOol0ogoo3Goo

002WOol20004Ool200001Goo001oogoo00001Goo0P000Woo00@007ooOol0

009oo`04001oogoo0007Ool00`00Oomoo`03Ool00`00Oomoo`03Ool20003

Ool20002Ool01000Oomoo`000goo00<007ooOol00goo00<007ooOol0QWoo

0P0000El0000001l0000025oo`807`9oo`0301moogoo00807`03Ool07`0O

009oo`D07`9oo`807`03Ool07`0O009oo`0301moogoo00807`03Ool07`0O

009oo`X07d1oo`03001oogoo0?moo`eoo`00Ygoo0P0017oo0P0017oo00<0

07ooOol00goo0P000Woo00<007ooOol017oo0`001goo00<007ooOol00goo

00<007ooOol00Woo0P0017oo0P000Woo00<007ooOol017oo00<007ooOol0

0Woo0P0000=oo`0000000Woo00<007ooOol00P0000=oo`0000000Woo0P00

00=oo`0000000Woo0P0000=oo`0000000Woo00<007ooOol00P0000=oo`00

00000Woo0P0000=oo`0000000Woo0P0000=oo`0000000Woo00<007ooOol0

0P0000=oo`0000000Woo0P0000=oo`0000000Woo0P0000=oo`0000000Woo

00<007ooOol00P0000=oo`0000000Woo0P0000=oo`0000000Woo0P0000=o

o`0000000Woo0P0000=oo`0000000Woo00<007ooOol00P0000=oo`000000

0Woo0P0000=oo`0000000Woo0P0000=oo`0000000Woo00<007ooOol01000

0W`000<007`0Ool0AWoo2P0O@7oo00<007ooOol0ogoo3Goo002WOol20004

Ool20004Ool00`00Oomoo`04Ool200000goo001oo`0;Ool80003Ool01000

Oomoogoo0P001Goo0P0000=oo`00Ool01Goo00<007ooOol00goo00<007oo

Ool0Qgoo1@000W`0A7oo0P0O00Aoo`0O01l000H07d1oo`03001oogoo0?mo

o`eoo`00Ygoo0P0017oo0P0017oo00<007ooOol017oo0`0047oo0P001Woo

00<007ooOol00P001Woo0`001goo00<007ooOol00goo00<007ooOol0R7oo

0`000goo00=l07ooOol0A7oo0P0O00<0000O01l0100O@7oo00<007ooOol0

ogoo3Goo002XOol00`00Oomoo`03Ool20003Ool00`00Oomoo`05Ool2000A

Ool00`00Oomoo`04Ool00`00Oomoo`020007Ool20007Ool00`00Oomoo`03

Ool00`00Oomoo`2@Ool00g`0Oomoo`13Ool00`0O00007`0401m1Ool00`00

Oomoo`3oOol=Ool00:Qoo`800004Ool00000Ool20003Ool00`00Oomoo`05

Ool2000AOol00`00Oomoo`05Ool01000Ool000001goo0P001goo00<007oo

Ool00goo00<007ooOol0TGoo0g`0@goo00<0000O01l00P0O@Woo00<007oo

Ool0ogoo3Goo002YOol30003Ool01@00Oomoogoo000027oo00<007ooOol0

3goo00<007ooOol01Goo0`002Goo00<007ooOol01Goo00<007ooOol00goo

00<007ooOol0TGoo00=l07ooOol00Woo00=l07ooOol0?Woo00<007ooOol0

A7oo00<007ooOol0ogoo3Goo002cOol00`00Oomoo`02Ool01000Oomoo`00

6goo0P001Goo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo09=o

o`04O01oogooO010Ool00`00Oomoo`14Ool00`00Oomoo`3oOol=Ool00;=o

o`8000=oo`04001oogoo000KOol00`00Oomoo`04Ool01000Oomoo`001goo

0P001Goo00<007ooOol0Tgoo0W`017oo00=l07ooOol0>goo00<007ooOol0

A7oo00<007ooOol0ogoo3Goo002cOol40002Ool3000SOol30005Ool40005

Ool00`00Oomoo`2EOol00g`0Oomoo`03Ool2O00jOol00`00Oomoo`3oOomD

Ool00;Uoo`8002Aoo`8000moo`03001oogoo09Ioo`03O01oogoo00=oo`9l

03Uoo`03001oogoo0?mooeAoo`00l7oo00<007ooOol0Wgoo0W`0=Woo00<0

07ooOol0A7oo00<007ooOol0ogoo3Goo003`Ool00`00Oomoo`2QOol2O00d

Ool00`00Oomoo`14Ool00`00Oomoo`3oOol=Ool00?1oo`03001oogoo09Uo

o`03O01oogoo00Moo`03O01oogoo0?moohQoo`00l7oo00<007ooOol0YGoo

0W`0<7oo00<007ooOol0A7oo00<007ooOol0ogoo3Goo003`Ool00`00Oomo

o`2KOol2O00jOol00`00Oomoo`14Ool00`00Oomoo`3oOol=Ool00?1oo`03

001oogoo09eoo`03O01oogoo0?moohioo`00l7oo00<007ooOol0WWoo00=l

07ooOol02Woo0W`0ogooPGoo003`Ool00`00Oomoo`2OOol00g`0Oomoo`0e

Ool00`00Oomoo`14Ool00`00Oomoo`3oOol=Ool00?1oo`03001oogoo0:1o

o`03O01oogoo00aoo`03O01oogoo02Eoo`03001oogoo04Aoo`03001oogoo

0?moo`eoo`00l7oo00<007ooOol0/Goo0W`0ogooNgoo003`Ool00`00Oomo

o`2SOol00g`0Oomoo`0>Ool2O00QOol00`00Oomoo`13Ool00`00Oomoo`3o

Ool>Ool00?1oo`03001oogoo0:=oo`03O01oogoo00moo`9l021oo`03001o

ogoo04=oo`03001oogoo0?moo`ioo`00l7oo00<007ooOol0^7oo00=l07oo

Ool0ogooLgoo003`Ool00`00Oomoo`2UOol2O00COol2O03oOombOol00?1o

o`03001oogoo0:Moo`03O01oogoo019oo`03O01oogoo01Qoo`03001oogoo

04=oo`03001oogoo0?moo`ioo`00l7oo00<007ooOol0Z7oo00=l07ooOol0

4goo0W`0ogooKWoo003`Ool00`00Oomoo`2YOol00g`0Oomoo`0EOol2O03o

Oom[Ool00>5oo`=l00aoo`03001oogoo0=Moo`03001oogoo04=oo`03001o

ogoo0?moo`ioo`00UGoo0g`0B7oo00Al07ooOoml00aoo`03001oogoo0<Ao

o`9l015oo`03001oogoo04=oo`03001oogoo0?moo`ioo`00U7oo00Al07oo

Ooml04Qoo`03O01oogoo009l00]oo`03001oogoo0<Moo`9l0?moofEoo`00

Qgoo0W`02goo00=l07ooOol00W`087oo00=l07ooOol06Goo0W`02Goo00=l

07ooOol00W`01Goo00=l07ooOol00goo00<007ooOol0[Goo00=l07ooOol0

9Woo00<007ooOol0A7oo00<007ooOol0ogoo3Woo0027Ool00g`0Oomoo`0:

Ool00g`0Oomoo`02O00POol00g`0Oomoo`0IOol00g`0Oomoo`08Ool00g`0

Oomoo`02O005Ool00g`0Oomoo`03Ool00`00Oomoo`3;Ool00g`0Oomoo`02

O006Ool00`00Oomoo`14Ool00`00Oomoo`3oOol>Ool007Eoo`Il00=oo`Al

0003Ooml07`0009oo`04O01oogooOol2O003Ool2O00017ooO01l07oo0g`0

17oo00=l07ooOol00Woo00Al07ooOomoo`Ql0003Ooml07`000=oo`9l00=o

o`03O01oog`000]oo`03O01oogoo009oo`Al0003Ooml07`0009oo`04O01o

ogooOol2O003Ool4O0000gooO01l0005Ool00g`0Oomoo`03Ool00`00Oomo

o`2_Ool2O00LOol2O0000gooO01oo`1;Ool00`00Oomoo`3oOol>Ool007Io

o`05O01oogooOoml0002Ool2O002Ool3O003Ool00g`0Oomoo`02Ool00g`0

Oomoo`04O0001GooO01oogooO0001Goo00=l07ooOol01Woo00=l07ooOol0

0goo0W`00Woo00=l07ooOol017`00Woo00=l07ooOol03goo0W`00Woo0g`0

0goo00=l07ooOol00Woo00=l07ooOol01g`01Woo00=l07ooOol00goo00<0

07ooOol0/Goo00=l07ooOol06Goo00El07ooO01oog`000Aoo`9l04Eoo`03

001oogoo0?moo`ioo`00Mgoo00=l07ooOol00goo0W`00goo0W`00goo00=l

07ooOol00Woo00Al07ooOoml009oo`03O01oogoo00=l00Eoo`03O01oogoo

00Moo`04O01oogooOol2O003Ool017`0Oomoog`00Woo00Al07ooOoml015o

o`9l00=oo`9l00=oo`03O01oogoo009oo`04O01oogooO002Ool00g`0Oomo

o`07Ool00g`0Oomoo`03Ool00`00Oomoo`2bOol00g`0Oomoo`0IOol5O000

0gooO01l0004O013Ool00`00Oomoo`3oOol>Ool007Qoo`03O01oogoo009o

o`9l00=oo`9l00=oo`03O01oogoo009oo`9l0003Ooml07oo00Uoo`Ml00Io

o`04O01oogooOol2O003Ool2O0000gooO01oo`04Ool00g`0Oomoo`03Ool7

O005Ool2O003Ool2O003Ool00g`0Oomoo`02Ool2O0000gooO01oo`0;Ool0

0g`0Oomoo`03Ool00`00Oomoo`2cOol00g`0Oomoo`0MOol7O013Ool00`00

Oomoo`3oOol>Ool007Uoo`04O01oogooOol2O003Ool2O003Ool00g`0Oomo

o`03Ool3O00=Ool00g`0Oomoo`07Ool01G`0OomoogooO0001Goo0g`01Goo

00=l07ooOol03goo0W`00goo0W`00goo00=l07ooOol00goo0g`037oo00=l

07ooOol00goo00<007ooOol00W`000=oog`0O0000Woo0W`000=oog`0O000

0Woo0W`000=oog`0O0000Woo00=l07ooOol00W`000=oog`0O0000Woo0W`0

00=oog`0O0000Woo0W`000=oog`0O0000Woo00=l07ooOol00W`000=oog`0

O0000Woo0W`000=oog`0O0000Woo0W`000=oog`0O0000Woo00=l07ooOol0

0W`000=oog`0O0000Woo0W`000=oog`0O0000Woo0W`000=oog`0O0000Woo

0W`000=oog`0O0000Woo00=l07ooOol00W`000=oog`0O0000Woo0W`000=o

og`0O0000Woo0W`000=oog`0O0000Woo00=l07ooOol00W`000=oog`0O000

0Woo0W`000=oog`0O0000Woo0W`000=oog`0O0000Woo00=l07ooOol00W`0

00=oog`0O0000Woo0W`000=oog`0O0000Woo0W`000=oog`0O0000Woo00=l

07ooOol00W`000Aoog`0O01oo`=l0003Ooml07`0009oo`9l0003Ooml07`0

009oo`03O01oogoo009l0003Ooml07`0009oo`9l0004Ooml07`0Ool6O013

Ool00`00Oomoo`3oOol>Ool007Uoo`04O01oogooOol2O003Ool3O002Ool0

0g`0Oomoo`03Ool3O00=Ool00g`0Oomoo`08Ool017`0Ooml07`01Goo0g`0

1Goo00=l07ooOol03goo0W`00goo0g`00Woo00=l07ooOol00goo0g`037oo

00=l07ooOol00goo00<007ooOol0]Goo00=l07ooOol06goo1g`0@goo00<0

07ooOol0ogoo3Woo001iOol00g`0Oomoo`02Ool4O0000gooO01l0002Ool0

0g`0Oomoo`04Ool00g`0Oomoo`0<Ool00g`0Oomoo`08Ool017`0Ooml07`0

1Woo00=l07ooOol017oo00=l07ooOol047oo17`000=oog`0O0000Woo00=l

07ooOol017oo00=l07ooOol02goo00=l07ooOol00goo00<007ooOol0e7oo

1W`0@goo00<007ooOol0ogoo3Woo001eOol01G`0OomoogooO0003Goo00=l

07ooOol017oo00=l07ooOol037oo00=l07ooOol02Goo0W`01goo00=l07oo

Ool017oo00=l07ooOol06Goo00=l07ooOol017oo00=l07ooOol02goo00=l

07ooOol00goo00<007ooOol0]goo0W`06goo1W`0@goo00<007ooOol0ogoo

3Woo001fOol4O00=Ool01G`0OomoogooO0000Woo00=l07ooOol067oo0W`0

17oo00Al07ooOoml00Ioo`03O01oogoo01Uoo`05O01oogooOoml0002Ool0

0g`0Oomoo`0;Ool00g`0Oomoo`03Ool00`00Oomoo`2iOol00g`0Oomoo`0J

Ool00g`0Oomoo`14Ool00`00Oomoo`3oOol>Ool007Moo`9l00ioo`=l0004

Ooml07`0O00LOol00g`0Oomoo`02Ool3O005Ool3O00KOol3O00017ooO01l

07`037oo0g`01Goo00<007ooOol0^Woo00=l07ooOol0H7oo00<007ooOol0

ogoo3Woo002<Ool2O00ROol2O00XOol2O00DOol00`00Oomoo`2kOol00g`0

Oomoo`0HOol00g`0Oomoo`14Ool00`00Oomoo`3oOol>Ool00?1oo`03001o

ogoo0;aoo`03O01oogoo05ioo`03001oogoo0?moo`ioo`00l7oo00<007oo

Ool0ogoo7Woo00<007ooOol0ogoo3Woo003`Ool00`00Oomoo`2oOol00g`0

Oomoo`0DOol00g`0Oomoo`14Ool00`00Oomoo`3oOol>Ool00?1oo`03001o

ogoo0;moo`03O01oogoo01Aoo`03O01oogoo04Aoo`03001oogoo0?moo`io

o`00l7oo00<007ooOol0ogoo7Woo00<007ooOol0ogoo3Woo003`Ool00`00

Oomoo`31Ool2O00COol00g`0Oomoo`14Ool00`00Oomoo`3oOol>Ool00?1o

o`03001oogoo0<=oo`03O01oogoo011oo`03O01oogoo04Aoo`03001oogoo

0?moo`ioo`00l7oo00<007ooOol0a7oo00=l07ooOol0EWoo00<007ooOol0

ogoo3Woo003`Ool00`00Oomoo`35Ool00g`0Oomoo`1EOol00`00Oomoo`3o

Ool>Ool00?1oo`03001oogoo0<Ioo`9l00ioo`03O01oogoo04Aoo`03001o

ogoo0?moo`ioo`00l7oo00<007ooOol0agoo00=l07ooOol037oo00=l07oo

Ool0ogooEGoo003`Ool00`00Oomoo`3oOolNOol00`00Oomoo`3oOol>Ool0

0?1oo`03001oogoo0<Uoo`9l00]oo`03O01oogoo04Aoo`03001oogoo0?mo

o`ioo`00l7oo00<007ooOol0eWoo00=l07ooOol0ogooEGoo003`Ool00`00

Oomoo`3<Ool00g`0Oomoo`05Ool017`0Oomoog`0ogooEWoo003`Ool00`00

Oomoo`3=Ool00g`0Oomoo`04Ool017`0Oomoog`0AGoo00<007ooOol0ogoo

3Woo003`Ool00`00Oomoo`3>Ool00g`0Oomoo`03Ool017`0Ooml07`0AGoo

00<007ooOol0ogoo3Woo003`Ool00`00Oomoo`3?Ool00g`0Oomoo`03Ool3

O03oOomFOol00;9oo`<003]oo`03001oogoo0=5oo`04O01oogooOol2O016

Ool00`00Oomoo`3oOol>Ool00:=oo`@000Yoo`04001oogoo000[Ool4000<

Ool00`00Oomoo`3AOol017`0Oomoogoo0W`0AWoo00<007ooOol0ogoo3Woo

002SOol2000<Ool00`00Oomoo`02000/Ool2000<Ool00`00Oomoo`3EOol2

O03oOomGOol00:=oo`03001oogoo00]oo`03001oogoo008002eoo`03001o

ogoo00Yoo`03001oogoo0==oo`9l00800?mooeMoo`00V7oo1@000Woo00D0

07ooOomoo`0000=oo`8000Aoo`80009oo`03001oogoo008000Moo`03001o

ogoo00=oo`04001oogooOol70002Ool900000goo00000004Ool200000goo

001oo`0;Ool00`00Oomoo`3BOol60014Ool00`00Oomoo`3oOol?Ool009Qo

o`80009oo`D0009oo`04001oogooOol20003Ool400001Goo001oogoo0000

27oo00<007ooOol027oo00<007ooOol00Woo00@007ooOol000Ioo`800003

Ool0000000=oo`D000aoo`03001oogoo0=9oo`@00003O000000004=oo`03

001oogoo0?moo`moo`00Ugoo0P0017oo0P0000Eoo`00Oomoo`0000Aoo`80

009oo`04001oogoo0002Ool30008Ool00`00Oomoo`09Ool00`00Oomoo`05

Ool00`00Oomoo`03Ool20002Ool20002Ool00`00Oomoo`02000<Ool00`00

Oomoo`3BOol500000g`0001oo`3oOomDOol009Moo`8000Aoo`8000Aoo`03

001oogoo009oo`80009oo`03001oogoo00ioo`03001oogoo00Yoo`03001o

ogoo00Aoo`03001oogoo009oo`8000=oo`80009oo`05001oogooOol0000<

Ool00`00Oomoo`3BOol600000g`0Oomoo`11Ool00`00Oomoo`3oOol?Ool0

09Moo`8000Aoo`8000Aoo`03001oogoo00=oo`800003Ool007oo00]oo`P0

00Uoo`8000Ioo`04001oogooOol20004Ool200000goo001oo`02Ool00`00

Oomoo`0:Ool20002Ool200000goo00000002Ool200000goo00000002Ool0

0`00Oomoo`0200000goo00000002Ool200000goo00000002Ool200000goo

00000002Ool00`00Oomoo`0200000goo00000002Ool200000goo00000002

Ool200000goo00000002Ool00`00Oomoo`0200000goo00000002Ool20000

0goo00000002Ool200000goo00000002Ool00`00Oomoo`020002Ool00`00

Oomoo`0200000goo00000002Ool200000goo00000002Ool200000goo0000

0002Ool00`00Oomoo`0200000goo00000002Ool200000goo00000002Ool2

00000goo00000002Ool00`00Oomoo`0200000goo00000002Ool200000goo

00000002Ool200000goo00000002Ool00`00Oomoo`0200000goo00000002

Ool200000goo00000002Ool200000goo00000002Ool00`00Oomoo`020000

0goo00000002Ool200000goo00000002Ool200000goo0000000400000goo

O01oo`11Ool00`00Oomoo`3oOol?Ool009Moo`8000Aoo`8000Aoo`03001o

ogoo00=oo`<0011oo`8000eoo`03001oogoo00Aoo`03001oogoo008000Eo

o`<000Aoo`03001oogoo00Yoo`03001oogoo0==oo`D00?mooeIoo`00V7oo

00<007ooOol00goo0P000goo00<007ooOol017oo0P004Goo00<007ooOol0

37oo00<007ooOol00goo00<007ooOol00P001Woo0P0017oo00<007ooOol0

2Woo00<007ooOol0e7oo00<007ooOol017oo0W`0ogooDGoo002HOol20000

17oo000007oo0P000goo00<007ooOol017oo0P004Goo00<007ooOol037oo

00<007ooOol017oo00@007oo000000Ioo`8000Aoo`03001oogoo00Yoo`03

001oogoo0?mooaeoo`03001oogoo0?moo`moo`00VGoo0`000goo00D007oo

Oomoo`0000Moo`03001oogoo00moo`03001oogoo00Moo`03001oogoo009o

o`03001oogoo00Aoo`<000Qoo`03001oogoo009oo`03001oogoo00Yoo`03

001oogoo0=ioo`03O01oogoo0?moodeoo`00Xgoo00D007ooOomoo`00009o

o`03001oogoo01Yoo`80009oo`8000Moo`8000Aoo`04001oogoo0005Ool0

0`00Oomoo`0:Ool00`00Oomoo`3OOol00g`0Oomoo`3oOom<Ool00:=oo`80

009oo`04001oogoo000MOol50007Ool00`00Oomoo`03Ool01000Oomoo`00

17oo0P0037oo00<007ooOol0h7oo00=l07ooOol0>Goo00<007ooOol0ogoo

3goo002SOol4000017oo000000007Woo0`003goo0`000Woo100037oo00<0

07ooOol0hGoo00=l07ooOol0>7oo00<007ooOol0ogoo3goo002XOol2000a

Ool2000COol00`00Oomoo`3ROol2O00hOol00`00Oomoo`3oOol?Ool00?1o

o`03001oogoo0>=oo`03O01oogoo03Ioo`03001oogoo0?moo`moo`00l7oo

00<007ooOol0ogoo7Goo00<007ooOol0ogoo3goo003`Ool00`00Oomoo`3U

Ool2O00eOol00`00Oomoo`3oOol?Ool00?1oo`03001oogoo0?mooaeoo`03

001oogoo0?moo`moo`00l7oo00<007ooOol0j7oo00=l07ooOol0<Goo00<0

07ooOol0ogoo3goo003`Ool00`00Oomoo`3XOol2O00bOol00`00Oomoo`3o

Ool?Ool00?1oo`03001oogoo0>Yoo`03O01oogoo02moo`03001oogoo0?mo

o`moo`00l7oo00<007ooOol0jgoo00=l07ooOol0;Woo00<007ooOol0ogoo

3goo003`Ool00`00Oomoo`3/Ool00g`0Oomoo`0]Ool00`00Oomoo`3oOol?

Ool00?1oo`03001oogoo0>eoo`9l02eoo`03001oogoo0?moo`moo`00l7oo

00<007ooOol0ogoo7Goo00<007ooOol0ogoo3goo003`Ool00`00Oomoo`3_

Ool2O00[Ool00`00Oomoo`3oOol?Ool00?1oo`03001oogoo0?mooaeoo`03

001oogoo0?moo`moo`00l7oo00<007ooOol0lWoo00=l07ooOol09goo00<0

07ooOol0ogoo3goo003`Ool00`00Oomoo`3cOol00g`0Oomoo`0VOol00`00

Oomoo`3oOol?Ool00?1oo`03001oogoo0?Aoo`9l02Ioo`03001oogoo0?mo

o`moo`00l7oo00<007ooOol0mGoo00=l07ooOol097oo00<007ooOol0ogoo

3goo003`Ool00`00Oomoo`3oOolMOol00`00Oomoo`3oOol?Ool00?1oo`03

001oogoo0?Moo`9l02=oo`03001oogoo0?moo`moo`00l7oo00<007ooOol0

ogooogoo;goo003`Ool00`00Oomoo`3jOol00g`0Oomoo`3oOolaOol00?1o

o`03001oogoo0?Yoo`03O01oogoo01moo`03001oogoo0?moo`moo`00l7oo

00<007ooOol0o7oo00=l07ooOol07Goo00<007ooOol0ogoo3goo003`Ool0

0`00Oomoo`3mOol00g`0Oomoo`3oOol^Ool00?1oo`03001oogoo0?ioo`03

O01oogoo01]oo`03001oogoo0?moo`moo`00l7oo00<007ooOol0ogoo0W`0

6goo00<007ooOol0ogoo3goo003`Ool00`00Oomoo`3oOoooOol_Ool00?1o

o`03001oogoo0?moo`9oo`9l0?moob]oo`00l7oo00<007ooOol0ogoo7Goo

00<007ooOol0ogoo3goo003`Ool00`00Oomoo`3oOol5Ool00g`0Oomoo`0E

Ool00`00Oomoo`3oOol?Ool00?1oo`03001oogoo0?moo`Ioo`03O01oogoo

0?moobIoo`00l7oo00<007ooOol0ogoo1goo0W`04goo00<007ooOol0ogoo

47oo003`Ool00`00Oomoo`3oOol8Ool00g`0Oomoo`0AOol00`00Oomoo`3o

Ool@Ool00?1oo`03001oogoo0?moo`Uoo`03O01oogoo0?moob=oo`00l7oo

00<007ooOol0ogoo2Woo0W`0ogoo8goo003`Ool00`00Oomoo`3oOolLOol0

0`00Oomoo`3oOol@Ool00?1oo`03001oogoo0?moo`eoo`03O01oogoo00ao

o`03001oogoo0?mooa1oo`00l7oo00<007ooOol0ogoo3Goo00=l07ooOol0

ogoo7goo003`Ool00`00Oomoo`3oOolLOol00`00Oomoo`3oOol@Ool00?1o

o`03001oogoo0?mooa1oo`03O01oogoo00Uoo`03001oogoo0?mooa1oo`00

l7oo00<007ooOol0ogoo4Goo00=l07ooOol0ogoo6goo003`Ool00`00Oomo

o`3oOolBOol00g`0Ooml003oOolJOol00?1oo`03001oogoo0?mooa=oo`03

O01oog`000Ioo`03001oogoo0?mooa1oo`00l7oo00<007ooOol0ogoo4Woo

1G`01Goo00<007ooOol0ogoo47oo001]Ool2O00gOol00g`0Oomoo`0@Ool2

O009Ool3O00TOol00g`0Oomoo`02Ool00`00Oomoo`3oOolDOol2O0000goo

O01oo`03Ool00`00Oomoo`3oOol@Ool006eoo`03O01oogoo00aoo`=l02Mo

o`03O01oogoo011oo`03O01oogoo00Moo`04O01oogooO00TOol00g`0Oomo

o`02Ool00`00Oomoo`3oOolFOol2O004Ool00`00Oomoo`3oOol@Ool005ao

o`Il009oo`Al0003Ooml07`0009oo`04O01oogooOol2O003Ool2O0001Goo

O01oog`0Ool00W`017oo00=l07ooOol00Woo00Al07ooOomoo`Il0003Ooml

07`000Il0003Ooml07`000=oo`9l00=oo`04O01oogooO00;Ool01G`0Oomo

ogooO0000goo0W`00goo0W`000Ioog`0O01l07ooO005Ool00g`0Oomoo`02

Ool017`0Oomoogoo27`000=oog`0O0000goo0W`00goo00=l07ooOol00Woo

00<007ooOol0ogoo6goo00=l0000O000ogoo4Goo001MOol01W`0Oomoogoo

O01oo`9l009oo`=l00=oo`03O01oogoo009oo`03O01oogoo00Al009oo`03

O01oogoo009l00=oo`03O01oogoo00Moo`07O01oogooOoml07ooO0001Goo

0W`00Woo00=l07ooOol017`00Woo00=l07ooOol047oo00=l07ooOol00Woo

00=l07ooOol017`000=oog`0O0001goo00=l07ooOol01Woo00=l07ooOol0

0goo0W`00Woo00=l07ooOol017`00Woo00=l07ooOol00Woo00<007ooOol0

ogoo6Woo0W`000@007`0O01l0?moo`moo`00GWoo00=l07ooOol00Woo0W`0

0goo0W`00goo00=l07ooOol00Woo00Al07ooOoml009oo`04O01oogooO002

Ool2O003Ool00g`0Oomoo`08Ool00g`0Oomoo`03Ool017`0Oomoogoo0W`0

0goo00Al07ooOoml009oo`04O01oogooO00BOol00g`0Oomoo`02Ool01G`0

Oomoog`0Ool00W`000=oog`0O0001goo00=l07ooOol01goo00Al07ooOomo

o`9l00=oo`04O01oogooO002Ool017`0Oomoog`017oo00<007ooOol0ogoo

6Goo1g`0ogoo3goo001OOol017`0Oomoogoo0W`00goo0W`00goo00=l07oo

Ool00Woo0W`000=oog`0Ool017oo00=l07ooOol02G`027oo00=l07ooOol0

0Woo00Al07ooOomoo`9l00=oo`9l0003Ooml07oo00Aoo`03O01oogoo00Ao

o`Ml00Eoo`03O01oogoo009oo`9l0004Ooml07ooO002Ool00g`0Oomoo`03

Ool7O006Ool017`0Oomoogoo0W`00goo0W`000=oog`0Ool017oo00=l07oo

Ool00Woo00<007ooOol0ogoo6Goo1g`0ogoo3goo001POol00g`0Oomoo`02

O003Ool2O003Ool00g`0Oomoo`03Ool3O005Ool017`0Oomoog`017oo00=l

07ooOol02Woo00El07ooOomoog`000=oo`03O01oogoo00=oo`=l00Eoo`03

O01oogoo011oo`03O01oogoo00=oo`=l009oo`=l00Qoo`03O01oogoo00Mo

o`05O01oogooOoml0005Ool3O005Ool00g`0Oomoo`02Ool00`00Oomoo`2b

Ool2O002Ool2O0000gooO01l0002Ool2O0000gooO01l0002Ool00g`0Oomo

o`02O0000gooO01l0002Ool2O0000gooO01l0002Ool2O0000gooO01l0002

Ool00g`0Oomoo`02O0000gooO01l0002Ool2O0000gooO01l0002Ool2O000

0gooO01l0002Ool2O0000gooO01l0002Ool00g`0Oomoo`02O0000gooO01l

0002Ool2O0000gooO01l0002Ool2O0000gooO01l0002Ool00g`0Oomoo`09

O03oOol?Ool0061oo`03O01oogoo009l00=oo`=l009oo`03O01oogoo00=o

o`=l00Ioo`=l00Aoo`03O01oogoo00Yoo`03O01oogoo009oo`04O01oog`0

O005Ool3O005Ool00g`0Oomoo`0@Ool00g`0Oomoo`03Ool3O00=Ool00g`0

Oomoo`08Ool017`0Ooml07`01Goo0g`01Goo00=l07ooOol00Woo00=l07oo

Ool00W`000=oog`0O0000Woo0W`000=oog`0O0000Woo0W`000=oog`0O000

0Woo00=l07ooOol00W`000=oog`0O0000Woo0W`000=oog`0O0000Woo0W`0

00=oog`0O0000Woo00=l07ooOol00W`000=oog`0O0000Woo0W`000=oog`0

O0000Woo0W`000=oog`0O0000Woo00=l07ooOol00W`000=oog`0O0000Woo

0W`000=oog`0O0000Woo0W`000=oog`0O0000Woo0W`000=oog`0O0000Woo

00=l07ooOol00W`000=oog`0O0000Woo0W`000=oog`0O0000Woo0W`000=o

og`0O0000Woo00=l07ooOol00W`000=oog`0O0000Woo0W`000=oog`0O000

0Woo0W`000=oog`0O0000Woo00=l07ooOol00W`000=oog`0O0000Woo0W`0

00=oog`0O0000Woo0W`000=oog`0O0000Woo00=l07ooOol0JGoo1g`0ogoo

3goo001POol017`0Oomoogoo17`000=oog`0O0000Woo00=l07ooOol017oo

00=l07ooOol037oo00=l07ooOol02Woo00=l07ooOol00Woo00Al07ooO01l

00Ioo`03O01oogoo00Aoo`03O01oogoo011oo`03O01oogoo00Aoo`03O01o

ogoo00aoo`03O01oogoo00Qoo`04O01oog`0O006Ool00g`0Oomoo`04Ool0

0g`0Oomoo`02Ool01000Ooml07`0ogoo6Goo1G`0ogoo47oo001LOol01G`0

OomoogooO00037oo00=l07ooOol017oo00=l07ooOol037oo00=l07ooOol0

1Woo00El07ooOomoog`000Eoo`9l00Moo`03O01oogoo00Aoo`03O01oogoo

011oo`03O01oogoo00Aoo`03O01oogoo00aoo`03O01oogoo00Uoo`9l00Mo

o`03O01oogoo00Aoo`03O01oogoo009oo`03001oogoo0?mooaaoo`03O01o

ogoo0?mooa1oo`00GGoo17`037oo00El07ooOomoog`0009oo`03O01oogoo

01Ioo`Al00Eoo`9l00Aoo`04O01oogooO006Ool00g`0Oomoo`0@Ool01G`0

OomoogooO0000Woo00=l07ooOol067oo0W`017oo00Al07ooOoml00Ioo`03

O01oogoo009oo`03001oogoo0?mooaaoo`03O01oogoo0?mooa1oo`00GWoo

0W`03Goo0g`000Aoog`0O01l01Yoo`9l00Moo`03O01oogoo009oo`=l00Eo

o`=l019oo`=l0004Ooml07`0O00LOol00g`0Oomoo`02Ool3O005Ool3O004

Ool00`00Oomoo`3oOolLOol00g`0Oomoo`3oOol@Ool0079oo`9l02Uoo`9l

01moo`9l029oo`9l00aoo`03001oogoo0?mooaaoo`03O01oogoo0?mooa1o

o`00l7oo00<007ooOol0ogoo77oo00=l07ooOol0ogoo47oo003`Ool00`00

Oomoo`3oOolLOol00g`0Oomoo`3oOol@Ool00?1oo`03001oogoo0?mooaao

o`03O01oogoo0?mooa1oo`00l7oo00<007ooOol0ogoo77oo00=l07ooOol0

ogoo47oo003`Ool00`00Oomoo`3oOolLOol00g`0Oomoo`3oOol@Ool00?1o

o`03001oogoo0?mooaaoo`03O01oogoo0?mooa1oo`00l7oo00<007ooOol0

ogoo77oo00=l07ooOol0ogoo47oo003`Ool00`00Oomoo`3oOolLOol00g`0

Oomoo`3oOol@Ool00?1oo`03001oogoo0?mooaaoo`03O01oogoo0?mooa1o

o`00l7oo00<007ooOol0ogoo77oo00=l07ooOol0ogoo47oo003`Ool00`00

Oomoo`3oOolLOol00g`0Oomoo`3oOol@Ool00?1oo`03001oogoo0?mooaao

o`03O01oogoo0?mooa1oo`00l7oo00<007ooOol0ogoo77oo00=l07ooOol0

ogoo47oo003`Ool00`00Oomoo`3oOolLOol00g`0Oomoo`3oOol@Ool00?1o

o`03001oogoo0?mooaaoo`03O01oogoo0?mooa1oo`00l7oo00<007ooOol0

ogoo77oo00=l07ooOol0ogoo47oo003`Ool00`00Oomoo`3oOolLOol00g`0

Oomoo`3oOol@Ool00?1oo`03001oogoo0?mooaaoo`03O01oogoo0?mooa1o

o`00l7oo00<007ooOol0ogoo77oo00=l07ooOol0ogoo47oo003`Ool00`00

Oomoo`3oOolLOol00g`0Oomoo`3oOol@Ool00?1oo`03001oogoo0?mooaao

o`03O01oogoo0?mooa1oo`00l7oo00<007ooOol0ogoo77oo00=l07ooOol0

ogoo47oo003`Ool00`00Oomoo`3oOolLOol00g`0Oomoo`3oOol@Ool00?1o

o`03001oogoo0?mooaaoo`03O01oogoo0?mooa1oo`00l7oo00<007ooOol0

ogoo77oo00=l07ooOol0ogoo47oo003`Ool00`00Oomoo`3oOolLOol00g`0

Oomoo`3oOol@Ool00?1oo`03001oogoo0?mooaaoo`03O01oogoo0?mooa1o

o`00l7oo00<007ooOol0ogoo77oo00=l07ooOol0ogoo47oo003`Ool00`00

Oomoo`3oOolLOol00g`0Oomoo`3oOol@Ool00?1oo`03001oogoo0?mooaao

o`03O01oogoo0?mooa1oo`00l7oo00<007ooOol0ogoo77oo00=l07ooOol0

ogoo47oo003`Ool00`00Oomoo`3oOolLOol00g`0Oomoo`3oOol@Ool00?1o

o`03001oogoo0?mooaYoo`05O01oog`0Ooml003oOol@Ool00?1oo`03001o

ogoo0?mooa]oo`9l0003Ooml07oo0?moo`moo`00Ygoo1000?Goo100017oo

00<007ooOol0ogoo6goo0g`0ogoo4Goo002WOol20011Ool20004Ool00`00

Oomoo`3oOolKOol3O03oOolAOol00:Moo`03001oogoo00aoo`<0039oo`03

001oogoo009oo`03001oogoo0?mooa]oo`=l0?mooa5oo`00W7oo1@000Woo

00D007ooOomoo`0000Aoo`8000Aoo`800004Ool007ooOol20008Ool00`00

Oomoo`02Ool00`00Oomoo`02Ool40004Ool900000goo00000004Ool20005

Ool00`00Oomoo`02Ool00`00Oomoo`3oOolLOol2O03oOolAOol009aoo`80

009oo`D0009oo`03001oogoo009oo`8000=oo`D0009oo`8000Qoo`03001o

ogoo00Moo`05001oogooOol00003Ool00`00Oomoo`04Ool200000goo0000

0003Ool40004Ool00`00Oomoo`02Ool00`00Oomoo`3oOolKOol00`00O000

003oOolAOol009]oo`8000Aoo`800005Ool007ooOol00005Ool20002Ool0

0`00Oomoo`020002Ool20008Ool00`00Oomoo`0;Ool20003Ool00`00Oomo

o`03Ool20002Ool20002Ool01000Oomoo`0017oo00<007ooOol00Woo00<0

07ooOol0ogoo6Goo0`0000Al000000000?moo`moo`00Vgoo0P0017oo0P00

17oo00<007ooOol00goo0P000Woo00D007ooOomoo`00009oo`8000Qoo`03

001oogoo00]oo`8000=oo`03001oogoo009oo`8000=oo`80009oo`03001o

ogoo00Eoo`03001oogoo009oo`03001oogoo0?mooaUoo`L00?moo`moo`00

Vgoo0P0017oo0P0017oo00<007ooOol017oo0P0000=oo`00Ool00Woo00@0

07ooOol000Eoo`P000Yoo`8000Aoo`04001oogooOol20004Ool200000goo

001oo`06Ool00`00Oomoo`02Ool20002Ool200000goo00000002Ool20000

0goo00000002Ool00`00Oomoo`0200000goo00000002Ool200000goo0000

0002Ool200000goo00000002Ool00`00Oomoo`0200000goo00000002Ool2

00000goo00000002Ool200000goo00000002Ool00`00Oomoo`0200000goo

00000002Ool200000goo00000002Ool200000goo00000002Ool00`00Oomo

o`020002Ool00`00Oomoo`0200000goo00000002Ool200000goo00000002

Ool200000goo00000002Ool00`00Oomoo`0200000goo00000002Ool20000

0goo00000002Ool200000goo00000002Ool00`00Oomoo`0200000goo0000

0002Ool200000goo00000002Ool200000goo00000002Ool00`00Oomoo`02

00000goo00000002Ool200000goo00000002Ool200000goo00000002Ool0

0`00Oomoo`0200000goo00000002Ool200000goo00000002Ool200000goo

00000002Ool00`00Oomoo`0200000goo00000002Ool200000goo00000002

Ool200000goo00000002Ool200000goo00000002Ool00`00Oomoo`020000

0goo00000002Ool200000goo00000002Ool200000goo00000002Ool00`00

Oomoo`0200000goo00000002Ool9003oOol>Ool009]oo`8000Aoo`8000Ao

o`03001oogoo00Aoo`<000Eoo`<000Qoo`8000Yoo`@000Eoo`03001oogoo

008000Eoo`<000Qoo`03001oogoo009oo`03001oogoo0?mooaQoo`T00?mo

o`ioo`00W7oo00<007ooOol00goo0P000goo00<007ooOol01Goo0P004Goo

00<007ooOol02Goo0P001Woo00<007ooOol00P001Woo0P0027oo00<007oo

Ool00Woo00<007ooOol0ogoo67oo2@00ogoo3Woo002LOol2000017oo0000

07oo0P000goo00<007ooOol01Goo0P004Goo00<007ooOol02Woo00<007oo

Ool01Goo00@007oo000000Ioo`8000Qoo`03001oogoo009oo`03001oogoo

0?mooaUoo`L00?moo`moo`00WGoo0`000goo00D007ooOomoo`0000Qoo`03

001oogoo00moo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo00Ao

o`<000Qoo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo0?mooaUo

o`L00?moo`moo`00Ygoo00<007ooOol00Woo00@007ooOol001]oo`04001o

ogooOol20007Ool20004Ool01000Oomoo`002Goo00<007ooOol00Woo00<0

07ooOol0ogoo6goo1000ogoo47oo002WOol20003Ool01000Oomoo`0077oo

1@001goo00<007ooOol00goo00@007ooOol000Qoo`8000Aoo`03001oogoo

0?mooomoobmoo`00Ygoo10000Woo0`007Goo0`003goo0`001Woo100017oo

00<007ooOol0ogooogoo;goo002]Ool2000`Ool2000?Ool00`00Oomoo`3o

OoooOol_Ool00?1oo`03001oogoo0?mooomoobmoo`00l7oo00<007ooOol0

ogooogoo;goo003`Ool00`00Oomoo`3oOoooOol_Ool00?1oo`03001oogoo

0?mooomoobmoo`00l7oo00<007ooOol0ogooogoo;goo003`Ool00`00Oomo

o`3oOoooOol_Ool00?1oo`03001oogoo0?mooomoobmoo`00l7oo00<007oo

Ool0ogooogoo;goo003`Ool00`00Oomoo`3oOoooOol_Ool00?1oo`03001o

ogoo0?mooomoobmoo`00l7oo00<007ooOol0ogooogoo;goo003`Ool00`00

Oomoo`3oOoooOol_Ool00?1oo`03001oogoo0?mooomoobmoo`00l7oo00<0

07ooOol0ogooogoo;goo003`Ool00`00Oomoo`3oOoooOol_Ool00?1oo`03

001oogoo0?mooomoobmoo`00l7oo00<007ooOol0ogooogoo;goo003`Ool0

0`00Oomoo`3oOoooOol_Ool00?1oo`03001oogoo0?mooomoobmoo`00l7oo

00<007ooOol0ogooogoo;goo003`Ool00`00Oomoo`3oOoooOol_Ool00?1o

o`03001oogoo0?mooomoobmoo`00l7oo00<007ooOol0ogooogoo;goo003`

Ool00`00Oomoo`3oOoooOol_Ool00?1oo`03001oogoo0?mooomoobmoo`00

l7oo00<007ooOol0ogooogoo;goo003`Ool00`00Oomoo`3oOoooOol_Ool0

0?1oo`03001oogoo0?mooomoobmoo`00l7oo00<007ooOol0ogooogoo;goo

003]Ool01000Oomoo`000goo00<007ooOol0ogooogoo:goo003]Ool01000

Oomoo`000goo00<007ooOol0ogooogoo:goo003]Ool01000Oomoo`000Woo

00<007ooOol0ogooogoo;7oo003^Ool00`00Ool00002Ool00`00Oomoo`3o

OoooOol/Ool00>ioo`03001oo`00009oo`03001oogoo0?mooomoobaoo`00

kWoo00<007oo00000Woo00<007ooOol0ogooogoo;7oo003^Ool01@00Ool0

07oo0000ogooogoo;goo003_Ool200000goo001oo`3oOoooOol^Ool00>mo

o`800003Ool007oo0?mooomoobioo`00kgoo0P0000=oo`00Ool0ogooogoo

;Woo003_Ool3003oOoooOol`Ool00?1oo`800?mooomooc1oo`00l7oo0P00

ogooogoo<7oo003`Ool2003oOoooOol`Ool00?1oo`03001oogoo0?mooomo

obmoo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=o

o`00ogooogooogoo8goo003_Ool50003Ool2003oOoooOolYOol00>ioo`<0

009oo`800004Ool00000003oOoooOolYOol00>eoo`<000Aoo`<00?mooomo

ob]oo`00kGoo0`0017oo0`00ogooogoo:goo003]Ool20005Ool3003oOooo

Ool[Ool00>eoo`8000Ioo`800?mooomoob]oo`00kGoo0P001Woo0`00ogoo

ogoo:Woo003]Ool30004Ool4003oOoooOolZOol00>ioo`8000Aoo`04001o

o`00003oOoooOolZOol00>moo`800005Ool00000001oo`02003oOoooOolZ

Ool00?1oo`@000=oo`03001oogoo0?mooomoobQoo`00ogooogooogoo8goo

003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003o

OoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOooo

OoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOooo

OolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolS

Ool00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol0

0?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mo

oomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomo

oomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomo

ob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=o

o`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00

ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogoo

ogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogoo

ogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo

8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo

003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003o

OoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOooo

OoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOooo

OolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolS

Ool00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol0

0?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mo

oomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomo

oomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomo

ob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=o

o`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00

ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogoo

ogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogoo

ogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo

8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo

003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003o

OoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOooo

OoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOooo

OolSOol00001\

\>"], "Graphics",

  ImageSize->{800, 600},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  ImageCacheContents->"Empty"]

}, Open  ]],



Cell[TextData[StyleBox[

"We \"march\" along in this way, obtaining a branch of solutions \[Alpha](\

\[Lambda]).\n\nNow we come back to the question of how  one calculates the \

initial iterate to \nget the first point on a branch of solutions? This is \

done by looking for a solution\nnear an eigenvalue of the \"linearized\" \

problem, since it is well known [1] that\nif a branch of solutions exist for \

the nonlinear problem, it must bifurcate from\nthe \"trival\" solution at a \

value of \[Lambda] near an eigenvalue of the \"linearized problem.\nThis idea \

will be illustrated in the next section.",

  FontSize->16]], "Input",

  PageWidth->WindowWidth,

  FormatType->TextForm]

}, Open  ]],



Cell[CellGroupData[{



Cell[TextData[StyleBox["2 The Buckled Plate on an Elastic Foundation",

  FontSize->18]], "Section",

  FontFamily->"Times New Roman"],



Cell[GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000<P0002F1000`40O003

h00Oogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00

ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogoo

ogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogoo

ogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo

8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo

003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003o

OoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOooo

OoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOooo

OolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolS

Ool00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol0

0?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mo

oomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomo

oomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomo

ob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=o

o`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00

ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogoo

ogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogoo

ogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo

8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo

003oOoooOoooOolSOol00?moofQoo`8001=oo`03001oogoo0?mooj9oo`00

ogoo8Woo00<007ooOol05Goo00<007ooOol04goo0P005Goo0P004goo0P00

4goo0P003goo0P004Woo0P00ogooJWoo003oOolQOol2000FOol2000DOol2

000EOol2000COol2000COol2000?Ool2000BOol2000AOol2000AOol00`00

Oomoo`0>Ool2000>Ool00`00Oomoo`0=Ool00`00Oomoo`3oOolCOol00?mo

ob1oo`8001Ioo`8001Aoo`8001Eoo`8001=oo`8001=oo`8000moo`80019o

o`80015oo`80015oo`8000moo`8000ioo`8000ioo`800?mooaEoo`00ogoo

7goo0P005Woo0P0057oo0P005Goo0P004goo0P004goo0P003goo0P004Woo

0P004Goo0P004Goo0P003goo0P003Woo0P003Woo0P00ogoo5Woo003oOolN

Ool2000FOol2000DOol2000EOol2000COol2000COol2000?Ool2000BOol2

000AOol2000AOol2000?Ool2000>Ool2000>Ool2003oOolGOol00?mooaeo

o`8001Ioo`8001Aoo`8001Eoo`8001=oo`8001=oo`8000moo`80019oo`80

015oo`80015oo`8000moo`8000ioo`8000ioo`800?mooaQoo`00ogoo77oo

0P005Woo0P0057oo0P005Goo0P004goo0P004goo0P003goo0P004Woo0P00

4Goo0P004Goo0P003goo0P003Woo0P003Woo0P00ogoo6Goo003oOolKOol2

000FOol2000DOol2000EOol2000COol2000COol2000?Ool2000BOol2000A

Ool2000AOol2000?Ool2000>Ool2000>Ool2003oOolJOol00?mooaYoo`80

01Ioo`8001Aoo`8001Eoo`8001=oo`8001=oo`8000moo`80019oo`80015o

o`80015oo`8000moo`8000ioo`8000ioo`800?mooa]oo`00ogoo6Goo0P00

5Woo0P0057oo0P005Goo0P004goo0P004goo0P003goo0P004Woo0P004Goo

0P004Goo0P003goo0P003Woo0P003Woo0P00ogoo77oo003oOolHOol2000F

Ool2000DOol2000EOol2000COol2000COol2000?Ool2000BOol2000AOol2

000AOol2000?Ool2000>Ool2000>Ool2003oOolMOol00?mooaMoo`8001Io

o`8001Aoo`8001Eoo`8001=oo`8001=oo`8000moo`80019oo`80015oo`80

015oo`8000moo`8000ioo`8000ioo`800?mooaioo`00ogoo5Woo0P005Woo

0P0057oo0P005Goo0P004goo0P004goo0P003goo0P004Woo0P004Goo0P00

4Goo0P003goo0P003Woo0P003Woo0P00ogoo7goo003oOolEOol2000FOol2

000DOol2000EOol2000COol2000COol2000?Ool2000BOol2000AOol2000A

Ool2000?Ool2000>Ool2000>Ool2003oOolPOol00?mooaAoo`8001Ioo`80

01Aoo`8001Eoo`8001=oo`8001=oo`8000moo`80019oo`80015oo`80015o

o`8000moo`8000ioo`8000ioo`800?moob5oo`00ogoo4goo0P005Woo0P00

57oo0P005Goo0P004goo0P004goo0P003goo0P004Woo0P004Goo0P004Goo

0P003goo0P003Woo0P003Woo0P00ogoo8Woo003oOolBOol2000FOol2000D

Ool2000EOol2000COol2000COol2000?Ool2000BOol2000AOol2000AOol2

000?Ool2000>Ool2000>Ool2003oOolSOol00?mooa5oo`8001Ioo`8001Ao

o`8001Eoo`8001=oo`8001=oo`8000moo`80019oo`80015oo`80015oo`80

00moo`8000ioo`8000ioo`800?moobAoo`00ogoo47oo0P005Woo0P0057oo

0P005Goo0P004goo0P004goo0P003goo0P004Woo0P004Goo0P004Goo0P00

3goo0P003Woo0P003Woo0P00ogoo9Goo003oOol?Ool2000FOol2000DOol2

000EOol2000COol2000COol2000?Ool2000BOol2000AOol2000AOol2000?

Ool2000>Ool2000>Ool2003oOolVOol00?moo`ioo`8001Ioo`8001Aoo`80

01Eoo`8001=oo`8001=oo`8000moo`80019oo`80015oo`80015oo`8000mo

o`8000ioo`8000ioo`800?moobMoo`00ogoo3Goo0P005Woo0P0057oo0P00

5Goo0P004goo0P004goo0P003goo0P004Woo0P004Goo0P004Goo0P003goo

0P003Woo0P003Woo0P00ogoo:7oo003oOol<Ool2000FOol2000DOol2000E

Ool2000COol2000COol2000?Ool2000BOol2000AOol2000AOol2000?Ool2

000>Ool2000>Ool2003oOolYOol00?moo`]oo`8001Ioo`8001Aoo`8001Eo

o`8001=oo`8001=oo`8000moo`80019oo`80015oo`80015oo`8000moo`80

00ioo`8000ioo`800?moobYoo`00ogoo2Woo0P005Woo0P0057oo0P005Goo

0P004goo0P004goo0P003goo0P004Woo0P004Goo0P004Goo0P003goo0P00

3Woo0P003Woo0P00ogoo:goo003nOol_000:Ool00`00Oomoo`0YOol00`00

Oomoo`0BOol00`00Oomoo`0>Ool00`00Oomoo`0AOol00`00Oomoo`0?Ool2

000AOol2000?Ool2000>Ool2000>Ool2003oOol/Ool00?moo`Uoo`03001o

ogoo01Eoo`03001oogoo00Yooa<0000301l0000002P0000301l0000002<0

000301l007oo01]oo`05001oogooOol07`0=Ool2000@Ool00`00Oomoo`0<

Ool2000>Ool2003oOol]Ool00?mood5oo`0301moogoo02Qoo`0301moogoo

02=oo`0301moo`0001l0000301l0000004@00?moobMoo`00ogoo@Goo00<0

7gooOol0:7oo00<07gooOol08goo00<07gooOol07goo00<07gooOol08Goo

00<07gooOol087oo3000ogoo6goo003oOom1Ool00`0OOomoo`0XOol00`0O

Oomoo`0SOol00`0OOomoo`0OOol00`0OOomoo`0QOol00`0OOomoo`3oOom7

Ool00?mood5oo`0301moogoo02Qoo`0301moogoo02=oo`0301moogoo01mo

o`0301moogoo025oo`0301moogoo0?moodMoo`00ogoo@Goo00<07gooOol0

:7oo00<07gooOol08goo00<07gooOol07goo00<07gooOol08Goo00<07goo

Ool0ogooAgoo003oOom1Ool00`0OOomoo`0XOol00`0OOomoo`0SOol00`0O

Oomoo`0OOol00`0OOomoo`0QOol00`0OOomoo`3oOom7Ool00?mood5oo`03

01moogoo02Qoo`0301moogoo02=oo`0301moogoo01moo`0301moogoo025o

o`0301moogoo0?moodMoo`00ogoo@Goo00<07gooOol0:7oo0`0O97oo00<0

7gooOol07Woo00<07gooOol08Goo00<07gooOol0ogooAgoo003oOom1Ool0

0`0OOomoo`0WOol00`0OOomoo`0201lSOol00`0OOomoo`0NOol00`0OOomo

o`0QOol00`0OOomoo`3oOom7Ool00?mood5oo`0301moogoo02Yoo`0401mo

o`0O01lQOol00`0OOomoo`0NOol00`0OOomoo`0QOol00`0OOomoo`3oOom7

Ool00?mood9oo`0301moogoo02eoo`807amoo`0301moogoo01ioo`0301mo

ogoo025oo`0301moogoo0?moodMoo`00ogoo@goo0P0O;goo0`0O77oo00<0

7gooOol07Woo00<07gooOol0ogooJgoo003oOom5Ool201l`Ool201lJOol0

0`0OOomoo`0NOol00`0OOomoo`0POol201ooOom9Ool00?moodMoo`0301mo

ogoo02moo`807aQoo`807amoo`0301moogoo01eoo`<07omood]oo`00ogoo

B7oo0P0O<Goo0`0O5goo100O6goo00<07goo01l01@0O5Goo0`0OogooCWoo

003oOom9Ool201l/Ool601lLOol301lPOol501l=Ool301ooOomAOol00?mo

od5oo`P07bQoo`H07bEoo`@07b1oo`807`Moo`807`03Ool07`0O0?mooeAo

o`00ogoo>Woo1`0O:Woo1P0O;goo0P0O77oo0P0O2Woo1P0OogooDWoo003o

OolhOol201l[Ool601l`Ool501lKOol301lBOol501ooOom=Ool00?moocYo

o`<07bMoo`@07bmoo`@07aeoo`<07aYoo`D07omoodQoo`00ogoo?Goo0P0O

:Goo100O9goo100O7Woo0`0O8Woo100OogooA7oo003oOoloOol301lZOol4

01lOOol401lOOol301lYOol201ooOom2Ool00?mood9oo`807baoo`@07aUo

o`807b1oo`<07bMoo`D07omoodAoo`00ogooA7oo0P0O;Woo100O5goo0`0O

77oo0`0O8goo1@0OogooBGoo003oOom6Ool301l_Ool401lFOol301lLOol6

01lHOol501ooOom>Ool00?moodUoo`807bioo`@07aQoo`<07amoo`D07`io

o`D07omooe=oo`00ogooAWoo1@0O:Woo100O7goo0`0O8Goo1@0O2Goo00<0

7gooOol0ogooEGoo003oOom0Ool601lZOol501lVOol301l2Ool00`0OOomo

o`0NOol201l8Ool401ooOomCOol00?mooc]oo`D07baoo`@07b]oo`D07aeo

o`@07`ioo`@07omoodmoo`00ogoo>7oo0`0O;7oo1@0O:Woo1@0O7Woo100O

5Woo1@0OogooBWoo003oOolhOol301l[Ool301lXOol501lOOol401lOOol4

01ooOom6Ool00?mooc]oo`<07b]oo`@07b1oo`@07b1oo`@07omoofeoo`00

ogoo?Woo100O:goo100O77oo100O7Goo0`0O:7oo1@0OogooA7oo003oOom2

Ool301l/Ool401lLOol501lHOol401lSOol401ooOom9Ool00?moodEoo`@0

7baoo`D07aaoo`D07aMoo`<07a]oo`D07omoodeoo`00ogooBGoo00<07goo

Ool0;Woo0P0O7goo1@0O5Goo0`0O57oo100OogooDWoo003oOom8Ool201l]

Ool301lVOol00`0OOomoo`0EOol301l?Ool201ooOomFOol00?mood=oo`D0

7baoo`<07bMoo`<07aYoo`<07`aoo`@07omooeAoo`00ogoo?goo100O;Woo

0`0O9Woo100O87oo0`0O3Goo0`0OogooDGoo003oOolhOol201l00goo01l0

7`0201l^Ool401lUOol401lROol401lAOol401ooOom=Ool00?moocQoo`<0

7bmoo`<07bEoo`@07b9oo`@07aUoo`@07omoodUoo`00ogoo>goo0P0O:Woo

0`0O97oo100O8Woo100O8Goo1`0Oogoo@Woo003oOolmOol201lWOol0100O

Ool07`0O8goo00<07gooOol087oo100O9Goo1@0OogooA7oo003oOoloOol0

100OOomoo`0O9goo0P0O8Woo0P0O7goo00<07gooOol08Woo1@0OogooBGoo

003oOom0Ool301lYOol201l3Ool00`0OOomoo`0LOol201lNOol201lKOol7

01ooOom>Ool00?mood9oo`0301moogoo02Uoo`@07b1oo`807aioo`807aQo

o`<07`03Ool07`0O0?mooe1oo`00ogoo@Woo00<07gooOol0;7oo00<07goo

Ool087oo0`0O7Goo00<07gooOol06goo0`0OogooCGoo003oOom2Ool00`0O

Oomoo`0/Ool00`0OOomoo`0ROol00`0OOomoo`0LOol201l00goo01moo`0K

Ool00`0OOol07`3oOom:Ool00?mood9oo`0301moogoo02aoo`0301moogoo

029oo`0301moogoo01moo`0301moogoo01aoo`0301moogoo0?moodQoo`00

ogoo@Woo00<07gooOol0;7oo00<07gooOol08Woo00<07gooOol07goo00<0

7gooOol077oo00<07gooOol0ogooB7oo003oOom2Ool00`0OOomoo`0/Ool0

0`0OOomoo`0ROol00`0OOomoo`0OOol00`0OOomoo`0LOol00`0OOomoo`3o

Oom8Ool00?mood9oo`0301moogoo02aoo`0301moogoo029oo`0301moogoo

01moo`0301moogoo01aoo`0301moogoo0?moodQoo`00ogoo@Woo00<07goo

Ool0;7oo00<07gooOol08Woo00<07gooOol07Woo00<07gooOol07Goo00<0

7gooOol0ogooB7oo003oOom2Ool00`0OOomoo`0/Ool00`0OOomoo`0ROol0

0`0OOomoo`0NOol00`0OOomoo`0MOol00`0OOomoo`3oOom8Ool00?mood9o

o`0301moogoo02aoo`0301moogoo029oo`0301moogoo01ioo`0301moogoo

01eoo`0301moogoo0?moodQoo`00ogoo@Woo00<07gooOol0;7oo00<07goo

Ool08Woo00<07gooOol07Woo00<07gooOol07Goo00<07gooOol0ogooB7oo

003oOom1Ool00`0OOomoo`0]Ool00`0OOomoo`0ROol00`0OOomoo`0NOol0

0`0OOomoo`0MOol00`0OOomoo`3oOom8Ool00?mood5oo`0301moogoo02eo

o`0301moogoo029oo`0301moogoo01ioo`0301moogoo01eoo`0301moogoo

0?moodQoo`00ogoo;7oo7000:Goo00<07gooOol08Woo00<07gooOol07Woo

00<07gooOol07Goo00<07gooOol0ogooB7oo003oOol]Ool00`00Oomoo`0H

OolY00000`0O0000000M0005Ool00`0OOomoo`0NOol00`0OOomoo`0MOol0

0`0OOomoo`0:Ool00`00Oomoo`3oOolkOol00?mooamoo`9l00]oo`03001o

ogoo069oobH0000301l0000001d0000301l0000000Yoo`03001oogoo0?mo

oc]oo`00ogoo8Goo17`01goo00<007ooOol0Zgoo3@00ogoo>goo003oOolU

Ool4O003Ool00`00Oomoo`2eOol00`00Oomoo`08Ool3O03oOol`Ool00=Ao

oeQl0;Moo`03001oogoo00Aoo`Al0?mooc=oo`00ogoo9goo17`000=oo`00

Ool0]Woo00<007ooO00017`0ogoo=goo003oOolSOol4O005Ool00`00Oomo

o`2eOolEO03oOolYOol00?mooamoo`Al00Uoo`03001oogoo0;Eoo`03001o

og`000=l00moobQl0?moo`5oo`00ogoo:goo00<007ooOol0]Woo00<007oo

Ool00goo0g`0=7oo27`0n7oo003oOol[Oom5001dOol00`00Oomoo`06Ool4

O03oOolaOol00?moob]oo`03001oogoo049oodP002aoo`03001oogoo00Yo

o`03O01oogoo0?moobioo`00ogoo^7oo;@00ogoo?Goo003oOoooOoooOolS

Ool00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol0

0?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mo

oomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomo

oomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomo

ob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=o

o`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00

ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogoo

ogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogoo

ogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo

8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo

003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003o

OoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOooo

OoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOooo

OolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolS

Ool00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol0

0?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mo

oomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomo

oomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomo

ob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=o

o`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00

ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogoo

ogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogoo

ogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo

8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo

003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003o

OoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOooo

OoooOolSOol00?moofeoo`03O01oogoo02moo`03O01oogoo0?mooh1oo`00

ogooKGoo00=l07ooOol0;goo00=l07ooOol0ogooP7oo003oOom^Ool00g`0

Oomoo`0]Ool00g`0Oomoo`3oOon1Ool00?moofioo`03O01oogoo02eoo`03

O01oogoo0?mooh5oo`00ogooKWoo00=l07ooOol0;Goo00=l07ooOol0ogoo

PGoo003oOom^Ool00g`0Oomoo`0]Ool00g`0Oomoo`3oOon1Ool00?moofio

o`03O01oogoo02eoo`03O01oogoo0?mooh5oo`00ogooKWoo00=l07ooOol0

;Goo00=l07ooOol0ogooPGoo003oOom_Ool00g`0Oomoo`0[Ool00g`0Oomo

o`3oOon2Ool00?moofmoo`03O01oogoo02]oo`03O01oogoo0?mooh9oo`00

ogooKgoo00=l07ooOol0:goo00=l07ooOol0ogooPWoo003oOom_Ool00g`0

Oomoo`0[Ool00g`0Oomoo`0]Ool00g`0Oomoo`3oOomBOol00?mood=oo`03

O01oogoo02Uoo`03O01oogoo02]oo`03O01oogoo02aoo`03O01oogoo0?mo

oe=oo`00ogooA7oo00=l07ooOol0:Goo00=l07ooOol0:Goo00=l07ooOol0

;Goo00=l07ooOol0ogooDgoo003oOom4Ool00g`0Oomoo`0YOol00g`0Oomo

o`0YOol00g`0Oomoo`0/Ool00g`0Oomoo`3oOomDOol00?moodEoo`03O01o

ogoo02Qoo`03O01oogoo02Uoo`03O01oogoo02]oo`03O01oogoo0?mooeEo

o`00ogooAGoo00=l07ooOol0:7oo00=l07ooOol0:Goo00=l07ooOol0:goo

00=l07ooOol0ogooEGoo003oOom6Ool00g`0Oomoo`0WOol00g`0Oomoo`0Y

Ool00g`0Oomoo`0ZOol00g`0Oomoo`3oOomFOol00?moodIoo`03O01oogoo

02Qoo`03O01oogoo02Qoo`03O01oogoo02Yoo`03O01oogoo0?mooeIoo`00

ogooAWoo00=l07ooOol0:7oo00=l07ooOol09goo00=l07ooOol0:Woo00=l

07ooOol0ogooEgoo003oOom7Ool00g`0Oomoo`0WOol00g`0Oomoo`0WOol0

0g`0Oomoo`0YOol00g`0Oomoo`3oOomHOol00?moodMoo`03O01oogoo02Mo

o`03O01oogoo02Moo`03O01oogoo02Uoo`03O01oogoo0?mooeQoo`00ogoo

B7oo00=l07ooOol09Woo00=l07ooOol09goo00=l07ooOol0:7oo00=l07oo

Ool0ogooFGoo003oOom8Ool00g`0Oomoo`0VOol00g`0Oomoo`0WOol00g`0

Oomoo`0XOol00g`0Oomoo`3oOomIOol00?moodUoo`03O01oogoo02Ioo`03

O01oogoo02Ioo`03O01oogoo02Moo`03O01oogoo01ioo`03O01oogoo0?mo

ocUoo`00ogooBGoo00=l07ooOol09Woo00=l07ooOol09Goo00=l07ooOol0

9goo00=l07ooOol07Woo00=l07ooOol0ogoo>Woo003oOom:Ool00g`0Oomo

o`0UOol00g`0Oomoo`0UOol00g`0Oomoo`0WOol00g`0Oomoo`0MOol00g`0

Oomoo`3oOolkOol00?moodYoo`03O01oogoo02Eoo`03O01oogoo02Eoo`03

O01oogoo02Ioo`03O01oogoo01ioo`03O01oogoo0?mooc]oo`00ogooBgoo

00=l07ooOol097oo00=l07ooOol09Goo00=l07ooOol09Woo00=l07ooOol0

7Goo00=l07ooOol0ogoo?7oo003oOom;Ool00g`0Oomoo`0UOol00g`0Oomo

o`0TOol00g`0Oomoo`0UOol00g`0Oomoo`0MOol00g`0Oomoo`3oOolmOol0

0?moob9oo`03O01oogoo02Moo`03O01oogoo02Aoo`03O01oogoo02Aoo`03

O01oogoo02Aoo`03O01oogoo01eoo`03O01oogoo0?moocioo`00ogoo8goo

00=l07ooOol09Woo00=l07ooOol097oo00=l07ooOol08goo00=l07ooOol0

9Goo00=l07ooOol077oo00=l07ooOol0ogoo?goo003oOolTOol00g`0Oomo

o`0VOol00g`0Oomoo`0SOol00g`0Oomoo`0SOol00g`0Oomoo`0TOol00g`0

Oomoo`0MOol00g`0Oomoo`3oOoloOol00?moobAoo`03O01oogoo02Ioo`03

O01oogoo02=oo`03O01oogoo02=oo`03O01oogoo02Aoo`03O01oogoo01ao

o`03O01oogoo0?mood1oo`00ogoo9Goo00=l07ooOol09Woo00=l07ooOol0

8goo00=l07ooOol08Woo00=l07ooOol08goo00=l07ooOol077oo00=l07oo

Ool0ogoo@Goo003oOolVOol00g`0Oomoo`0UOol00g`0Oomoo`0SOol00g`0

Oomoo`0ROol00g`0Oomoo`0SOol00g`0Oomoo`0KOol00g`0Oomoo`3oOom2

Ool00?moobMoo`03O01oogoo02Eoo`03O01oogoo029oo`03O01oogoo029o

o`03O01oogoo029oo`03O01oogoo01]oo`03O01oogoo0?mood=oo`00ogoo

9goo00=l07ooOol09Goo00=l07ooOol08Woo00=l07ooOol08Goo00=l07oo

Ool08Woo00=l07ooOol077oo00=l07ooOol0ogoo@goo003oOolXOol00g`0

Oomoo`0UOol00g`0Oomoo`0QOol00g`0Oomoo`0QOol00g`0Oomoo`0ROol0

0g`0Oomoo`0KOol00g`0Oomoo`3oOom4Ool00?moobUoo`03O01oogoo02Ao

o`03O01oogoo025oo`03O01oogoo025oo`03O01oogoo025oo`03O01oogoo

01]oo`03O01oogoo0?moodEoo`00ogoo:Woo00=l07ooOol097oo00=l07oo

Ool08Goo00=l07ooOol087oo00=l07ooOol08Goo00=l07ooOol06Woo00=l

07ooOol0ogooAWoo003oOolZOol00g`0Oomoo`0TOol00g`0Oomoo`0QOol0

0g`0Oomoo`0POol00g`0Oomoo`0POol00g`0Oomoo`0JOol00g`0Oomoo`3o

Oom7Ool00?moob]oo`03O01oogoo02=oo`03O01oogoo025oo`03O01oogoo

01moo`03O01oogoo021oo`03O01oogoo01Yoo`03O01oogoo0?moodQoo`00

ogoo;7oo00=l07ooOol08goo00=l07ooOol087oo00=l07ooOol07goo00=l

07ooOol087oo00=l07ooOol06Woo00=l07ooOol0ogooB7oo003oOol/Ool0

0g`0Oomoo`0SOol00g`0Oomoo`0POol00g`0Oomoo`0OOol00g`0Oomoo`0O

Ool00g`0Oomoo`0JOol00g`0Oomoo`3oOom9Ool00?moobeoo`03O01oogoo

02=oo`03O01oogoo021oo`03O01oogoo01ioo`03O01oogoo01moo`03O01o

ogoo01Uoo`03O01oogoo0?moodYoo`00ogoo;Woo00=l07ooOol08Woo00=l

07ooOol087oo00=l07ooOol07Woo00=l07ooOol07Woo00=l07ooOol06Goo

00=l07ooOol0ogooBgoo003oOol_Ool00g`0Oomoo`0ROol00g`0Oomoo`0O

Ool00g`0Oomoo`0NOol00g`0Oomoo`0MOol00g`0Oomoo`0IOol00g`0Oomo

o`3oOom<Ool00?moobmoo`03O01oogoo029oo`03O01oogoo01moo`03O01o

ogoo01eoo`03O01oogoo01ioo`03O01oogoo01Uoo`03O01oogoo0?moodao

o`00ogoo<7oo00=l07ooOol08Woo00=l07ooOol07Woo00=l07ooOol07Goo

00=l07ooOol07Goo00=l07ooOol06Goo00=l07ooOol0ogooCGoo003oOola

Ool00g`0Oomoo`0QOol00g`0Oomoo`0NOol00g`0Oomoo`0JOol017`0Oomo

og`07goo00=l07ooOol067oo00=l07ooOol0ogooCWoo003oOolaOol00g`0

Oomoo`0ROol00g`0Oomoo`0NOol017`0Oomoog`067oo00Al07ooOoml009o

o`03O01oogoo01Uoo`03O01oogoo01Qoo`03O01oogoo0?moodmoo`00ogoo

<Woo00=l07ooOol08Goo00=l07ooOol06goo00Al07ooOoml009oo`03O01o

ogoo01Ioo`04O01oogooO002Ool00g`0Oomoo`0HOol00g`0Oomoo`0HOol0

0g`0Oomoo`0_Ool2O03oOolOOol00?mooc=oo`03O01oogoo025oo`03O01o

ogoo01Yoo`04O01oogooO002Ool00g`0Oomoo`0FOol01W`0Oomoog`0Ooml

01]oo`03O01oogoo01Qoo`03O01oogoo02ioo`03O01oogoo0?mooamoo`00

ogoo=7oo00=l07ooOol087oo00=l07ooOol06Woo00Al07ooOoml009oo`03

O01oogoo01Ioo`03O01oog`0009oo`03O01oogoo01Qoo`03O01oogoo01Qo

o`03O01oogoo02eoo`9l0?moob9oo`00ogoo=7oo00=l07ooOol08Goo00=l

07ooOol06Woo00=l07ooO0000Woo00=l07ooOol05Woo00El07ooO01oog`0

01]oo`03O01oogoo01Moo`03O01oogoo02eoo`03O01oogoo0?moob9oo`00

ogoo=Goo00=l07ooOol087oo00=l07ooOol06Woo00Il07ooOoml07ooO00H

Ool01G`0Ooml07ooO0005Woo00El07ooOomoog`001Uoo`03O01oogoo02eo

o`03O01oogoo0?moob=oo`00ogoo=Woo00=l07ooOol087oo00=l07ooOol0

6Woo00El07ooO01oog`001Qoo`05O01oog`0Ooml000FOol017`0Oomoog`0

6Goo00=l07ooOol0;7oo0W`0ogoo9Woo003oOolgOol00g`0Oomoo`0OOol0

1G`0OomoogooO00067oo00El07ooO01oog`001Qoo`04O01oog`0O00FOol0

1G`0OomoogooO00067oo00=l07ooOol0;7oo00=l07ooOol0ogoo9Woo003o

OolgOol00g`0Oomoo`0POol017`0Oomoog`06Goo0g`06Goo00Al07ooO01l

01Ioo`04O01oogooO00IOol00g`0Oomoo`0ZOol2O03oOolYOol00?moo`]o

o`03O01oogoo02Yoo`03O01oogoo01moo`04O01oogooO00IOol3O00JOol2

O00GOol017`0Oomoog`00Woo00=l07ooOol04goo00=l07ooOol0:Woo00=l

07ooOol0ogoo:Goo003oOol<Ool00g`0Oomoo`0ZOol00g`0Oomoo`0KOol0

1g`0OomoogooO01oog`001Yoo`9l01Yoo`9l01Moo`03O01oog`0009oo`03

O01oogoo01=oo`03O01oogoo02Uoo`9l0?moobaoo`00ogoo3Goo00=l07oo

Ool0:Goo00=l07ooOol077oo00Al07ooOoml009oo`03O01oogoo01Moo`9l

01Yoo`03O01oogoo01Eoo`03O01oog`0009oo`03O01oogoo01=oo`03O01o

ogoo02Uoo`03O01oogoo0?moobaoo`00ogoo3Woo00=l07ooOol0:Goo00=l

07ooOol077oo00Il07ooOoml07ooO00JOol00g`0Oomoo`0C0005Ool00g`0

Oomoo`0EOol01G`0Ooml07ooO0005Goo00=l07ooOol0:7oo0W`0ogoo;goo

003oOol?Ool00g`0Oomoo`0YOol00g`0Oomoo`0LOol01G`0Ooml07ooO000

57oo2@004goo2@0057oo0W`000=oog`0Ool05Goo00=l07ooOol09goo00=l

07ooOol0ogoo;goo003oOol@Ool00g`0Oomoo`0YOol00g`0Oomoo`0KOol0

1G`0Ooml07ooO0004Goo0`009Goo0`0047oo00Al07ooO01l01Ioo`03O01o

ogoo02Moo`03O01oogoo0?mooc1oo`00ogoo4Goo00=l07ooOol0:7oo00=l

07ooOol077oo00Al07ooO01l00ioo`<002]oo`<000eoo`=l01Ioo`03O01o

ogoo02Ioo`9l0?mooc=oo`00ogoo4Woo0W`0:Goo00=l07ooOol077oo0W`0

00=oog`0Ool02Goo0`00<Goo10002Goo0W`04Woo00El07ooOomoog`002Qo

o`03O01oogoo0?mooc=oo`00ogoo57oo00=l07ooOol09goo00=l07ooOol0

77oo0g`01Woo1000>7oo0`001Goo0W`04goo00Al07ooOoml02Moo`9l0?mo

ocIoo`00ogoo5Goo00=l07ooOol09Woo00=l07ooOol07Goo0W`00goo0`00

?goo0`000Woo00=l07ooOol04Goo00El07ooOomoog`002Ioo`03O01oogoo

0?moocIoo`00ogoo5Woo00=l07ooOol09Woo00=l07ooOol077oo0W`000=o

o`000000AGoo0P0057oo00Al07ooOoml02Eoo`9l0?moocUoo`00ogoo5goo

00=l07ooOol09Woo00=l07ooOol077oo00=l0000Ool0B7oo0P004Goo00Al

07ooOoml00=oo`03O01oogoo01moo`03O01oogoo0?moocUoo`00ogoo67oo

00=l07ooOol09Woo00El07ooOomoog`001Qoo`8004aoo`8000moo`03O01o

og`0009oo`9l021oo`9l0?moocaoo`00ogoo6Goo00=l07ooOol09Goo00El

07ooOomoog`001Ioo`80051oo`03001oogoo00]oo`03O01oog`0009oo`03

O01oogoo01moo`03O01oogoo0?moocaoo`00ogoo6Woo00=l07ooOol09Goo

00El07ooOomoog`001=oo`8005=oo`8000]oo`9l009oo`03O01oogoo01mo

o`03O01oogoo0?mooceoo`00ogoo6goo00=l07ooOol09Goo00Al07ooOoml

015oo`8005Moo`8000Qoo`03O01oog`0009l021oo`9l0?mood1oo`00ogoo

77oo00=l07ooOol08Goo00Ml07ooOomoog`0Ooml000?Ool2001KOol20006

Ool3O00QOol00g`0Oomoo`3oOom0Ool00?mooaeoo`03O01oogoo025oo`04

O01oogooO002Ool00g`0Oomoo`0;Ool00`00Oomoo`1MOol20003Ool3O00P

Ool2O03oOom3Ool00?mooaioo`03O01oogoo025oo`06O01oogooO01oog`0

2goo0P00HWoo00<007ooOol00W`087oo00=l07ooOol0ogoo@goo003oOolO

Ool00g`0Oomoo`0QOol01W`0Oomoog`0Ooml00Uoo`03001oogoo06=oo`03

001oogoo01moo`9l0?moodIoo`00ogoo87oo00=l07ooOol08Goo00El07oo

O01oog`000Qoo`03001oogoo06Eoo`8001ioo`03O01oogoo031oo`03O01o

ogoo0?mooa=oo`00ogoo8Goo00=l07ooOol08Goo00Al07ooO01l00Moo`03

001oogoo06Qoo`03001oogoo01Uoo`9l035oo`9l0?mooaIoo`00ogoo8Woo

00=l07ooOol08Goo17`017oo0P00K7oo00<007ooOol04Woo00=l07ooOol0

0Woo00=l07ooOol0;goo0W`0ogoo67oo003oOolSOol00g`0Oomoo`0ROol2

O003Ool00`00Oomoo`1]Ool00`00Oomoo`0@Ool017`0Oomoogoo0W`0<7oo

0W`0ogoo6Woo003oOolTOol00g`0Oomoo`0ROol2O0000goo001oo`1`Ool0

0`00Oomoo`0>Ool01G`0OomoogooO000<7oo0W`0ogoo77oo003oOolUOol0

0g`0Oomoo`0SOol00`00Oomoo`1aOol2000=Ool01G`0OomoogooO000;Woo

0g`0ogoo7Woo003oOolVOol00g`0Oomoo`0QOol00`00Oomoo`1dOol00`00

Oomoo`09Ool00g`0Oomoo`02O00]Ool2O03oOolQOol00?moobMoo`03O01o

ogoo01ioo`8007Qoo`03001oogoo00Moo`04O01oogooO004Ool2O00WOol2

O03oOolSOol00?moobQoo`03O01oogoo01aoo`03001oogoo07Uoo`03001o

ogoo00Eoo`04O01oog`0O002Ool3O00WOol2O03oOolUOol00?moobUoo`03

O01oogoo01Yoo`03001oogoo07]oo`03001oogoo00=oo`03O01oog`0009o

o`9l02Qoo`9l0?moobMoo`00ogoo:Woo00=l07ooOol067oo00<007ooOol0

OGoo00<007ooOol00Woo1G`0:7oo0W`0ogoo:Goo003oOol[Ool00g`0Oomo

o`0GOol00`00Oomoo`1nOol00`00Oomoo`03O00YOol2O03oOol[Ool00?mo

obaoo`03O01oogoo01Eoo`03001oogoo081oo`03001oogoo02Uoo`9l0?mo

obeoo`00ogoo;Goo00=l07ooOol04goo00<007ooOol0PGoo00<007ooOol0

9goo0W`0ogoo;goo003oOol^Ool00g`0Oomoo`02Ool00g`0Oomoo`0<Ool0

0`00Oomoo`23Ool00`00Oomoo`0TOol2O03oOolaOol00?moobmoo`05O01o

ogooOoml000=Ool00`00Oomoo`25Ool00`00Oomoo`0QOol2O03oOolcOol0

0?mooc1oo`05O01oogooOoml000;Ool00`00Oomoo`27Ool00`00Oomoo`0N

Ool2O03oOoleOol00?mooc5oo`04O01oogooO00;Ool00`00Oomoo`28Ool0

0`00Oomoo`0KOol2O03oOolgOol00?mooc9oo`04O01oogooO009Ool00`00

Oomoo`2:Ool00`00Oomoo`0HOol2O03oOoliOol00?Eoo`9l03Ioo`9l00=o

o`04O01oogooO007Ool00`00Oomoo`2;Ool00`00Oomoo`0?Ool00g`0Oomo

o`04Ool2O03oOolkOol00?Moo`=l03Eoo`9l009oo`03O01oog`000Ioo`03

001oogoo08eoo`03001oogoo00eoo`03O01oogoo00=oo`9l0?mooceoo`00

nWoo0W`0=Goo00Il07ooOoml07ooO004Ool00`00Oomoo`2?Ool00`00Oomo

o`0:Ool2O004Ool2O03oOoloOol00?aoo`9l03Aoo`9l0004Ooml07ooO003

Ool00`00Oomoo`2@Ool00`00Oomoo`08Ool00g`0Oomoo`02Ool2O03oOom1

Ool00?ioo`9l03Aoo`Al009oo`03001oogoo095oo`03001oogoo00Moo`04

O01oogooOol2O03oOom3Ool00?moo`5oo`9l03Aoo`=l0003Ool007oo09=o

o`03001oogoo00Eoo`03O01oogoo009l0?moodEoo`00ogoo0goo0g`0<goo

00=l0000Ool0U7oo00<007ooOol017oo00Al07ooO01l00Aoo`=l0?mood1o

o`00ogoo1Woo0W`0<Goo00<007ooOol0UGoo00<007ooOol00Woo0g`00Woo

17`0ogoo@goo003oOol8Ool2O00_Ool00`00Oomoo`2EOol00`00Oomoo`07

O03oOom7Ool00?moo`Yoo`9l02aoo`03001oogoo09Moo`04001oog`0O03o

Oom<Ool00?moo`aoo`9l02Yoo`03001oogoo09Qoo`03001oogoo0?moodao

o`00ogoo3Woo0W`09goo00<007ooOol0VGoo00<007ooOol0ogooC7oo003o

Ool@Ool3O00TOol00`00Oomoo`2JOol00`00Oomoo`3oOom;Ool00?mooa=o

o`9l025oo`03001oogoo09]oo`03001oogoo0?mood]oo`00ogoo5Goo0W`0

7goo00<007ooOol0W7oo00<007ooOol0ogooBWoo003oOolGOol2O00LOol0

0`00Oomoo`2MOol00`00Oomoo`3oOom:Ool00?mooaUoo`9l01Yoo`03001o

ogoo09ioo`03001oogoo03ioo`=l0?moo`Qoo`00ogoo6goo0g`05Woo00<0

07ooOol0Wgoo00<007ooOol0>Woo17`0ogoo2goo003oOolNOol2O007Ool0

0g`0Oomoo`0:Ool00`00Oomoo`2POol00`00Oomoo`0dOol5O03oOol?Ool0

0?moob1oo`9l00Ioo`03O01oogoo00Qoo`03001oogoo0:5oo`03001oogoo

031oo`Al0?mooaAoo`00ogoo8Woo0W`01Goo00=l07ooOol01goo00<007oo

Ool0XGoo00<007ooOol0:goo1G`0ogoo67oo003oOolTOol2O004Ool00g`0

Oomoo`06Ool00`00Oomoo`2ROol00`00Oomoo`0VOol4O03oOolMOol00?mo

obIoo`=l009oo`9l00Eoo`03001oogoo0:=oo`03001oogoo025oo`El0?mo

ob5oo`00ogoo:Goo0W`00Woo00=l07ooOol00Woo00<007ooOol0Xgoo00<0

07ooOol077oo1G`0ogoo9Woo003oOol[Ool2O0000gooO01oo`02Ool00`00

Oomoo`2TOol00`00Oomoo`0:Ool2O00;Ool4O03oOol[Ool00?moobEoo`El

00=oo`Al0003001oogoo0:Eoo`03001oogoo00Qoo`9l00Qoo`El0?moobmo

o`00ogoo:Woo1g`000<007ooOol0YGoo00<007ooOol01Woo0W`01Woo17`0

ogoo=7oo003oOol`Ool00g`0001oo`2WOol00`00Oomoo`03Ool2O003Ool5

O03oOolhOol00?mooc1oo`03001oogoo0:Moo`04001oogooOol2O0000goo

O01l0002O03oOolmOol00?mooc1oo`03001oogoo0:Moo`03001oog`000Al

0?mood5oo`00ogoo<7oo00<007ooOol0Ygoo00<007`0O0003G`0ogoo>7oo

003oOol`Ool00`00Oomoo`2XOol00`00Oomoo`3oOom4Ool00?moobmoo`03

001oogoo0:Uoo`03001oogoo0?moodAoo`00ogoo;goo00<007ooOol0ZGoo

00<007ooOol0ogooA7oo003oOol_Ool00`00Oomoo`2ZOol00`00Oomoo`3o

Oom3Ool00?moobmoo`03001oogoo0:Yoo`03001oogoo0?mood=oo`00ogoo

;Woo00<007ooOol0Zgoo00<007ooOol0ogoo@goo003oOol^Ool00`00Oomo

o`2[Ool00`00Oomoo`3oOom3Ool00?moobioo`03001oogoo0:]oo`03001o

ogoo0?mood=oo`00ogoo;Woo00<007ooOol0Zgoo00<007ooOol0ogoo@goo

003oOol^Ool00`00Oomoo`2[Ool00`00Oomoo`3oOom3Ool00?moobioo`03

001oogoo0:]oo`03001oogoo0?mood=oo`00ogoo;Woo00<007ooOol0[7oo

00<007ooOol0ogoo@Woo003oOol^Ool00`00Oomoo`2/Ool00`00Oomoo`3o

Oom2Ool00?moobioo`03001oogoo0:aoo`03001oogoo00Uoo`=l0?moocIo

o`00ogoo;Goo00<007ooOol0[Goo00<007ooOol017oo1G`0ogoo>Goo003o

Ool]Ool00`00Oomoo`2]Ool00`00Ooml0004O03oOolnOol00?moobeoo`03

001oogoo0:eoo`03001l07`0011l0?mooc9oo`00ogoo;Goo00<007ooOol0

[Goo00@007ooOomoo`=l00aooaQl0?mooaYoo`00ogoo7Woo0W`03Goo00<0

07ooOol0[Goo00<007ooOol017oo0g`08Goo5G`0ogoo1Goo003[Ool7O00]

Ool4O009Ool00`00Oomoo`2]Ool00`00Oomoo`07Ool4O03oOolgOol00?9o

oaUl01Qoo`=l00Ioo`03001oogoo0:eoo`03001oogoo00]oo`03O01oogoo

0?moocAoo`00ogoo37oo6G`00Woo17`00Woo00<007ooOol0[Woo00<007oo

Ool0ogoo@Goo003oOolUOol7O0000goo001oo`2^Ool00`00Oomoo`3oOom2

Ool00?moob=oo`El00Eoo`03001oogoo0:eoo`03001oogoo0?mood9oo`00

ogoo7Woo1G`02Woo00<007ooOol0[Goo00<007ooOol0ogoo@Woo003oOol]

Ool00`00Oomoo`2]Ool00`00Oomoo`3oOom2Ool00?moobeoo`03001oogoo

0:eoo`03001oogoo0?mood9oo`00ogoo;Goo00<007ooOol0[Goo00<007oo

Ool0ogoo@Woo003oOol^Ool00`00Oomoo`2/Ool00`00Oomoo`3oOom2Ool0

0?moobioo`03001oogoo0:aoo`03001oogoo0?mood9oo`00ogoo;Woo00<0

07ooOol0[7oo00<007ooOol0ogoo@Woo003oOol^Ool00`00Oomoo`2/Ool0

0`00Oomoo`3oOom2Ool00?moobioo`03001oogoo0:]oo`03001oogoo0?mo

od=oo`00ogoo;Woo00<007ooOol0Zgoo00<007ooOol0ogoo@goo003oOol^

Ool00`00Oomoo`2[Ool00`00Oomoo`3oOom3Ool00?moobioo`03001oogoo

0:]oo`03001oogoo0?mood=oo`00ogoo;Woo00<007ooOol0Zgoo00<007oo

Ool0ogoo@goo003oOol^Ool00`00Oomoo`2[Ool00`00Oomoo`05Ool6O03o

OolhOol00?moobmoo`03001oogoo0:Yoo`03001l07`000El0?moocioo`00

ogoo;goo00<007ooOol0ZWoo00<007`0O0001G`0ogoo?Woo003oOol_Ool0

0`00Oomoo`2YOol00`00Oomoo`02Ool2O002Ool6O03oOolhOol00?moobmo

o`03001oogoo0:Uoo`03001oogoo00Aoo`9l00Ioo`Il0?mooc9oo`00ogoo

<7oo00<007ooOol0Z7oo00<007ooOol01Woo0W`02Woo1W`0ogoo;7oo003o

Ool`Ool00`00Oomoo`2WOol00`00Oomoo`09Ool3O00=Ool5O03oOolWOol0

0?mooc1oo`03001oogoo0:Moo`03001oogoo01ioo`Il0?moob5oo`00ogoo

<Goo00<007ooOol0YWoo00<007ooOol097oo1W`0ogoo6goo003oOolaOol0

0`00Oomoo`2UOol00`00Oomoo`0[Ool6O03oOolEOol00?mooc5oo`03001o

ogoo0:Eoo`03001oogoo035oo`El0?mooa1oo`00ogoo<Goo00<007ooOol0

YGoo00<007ooOol0=Woo1W`0ogoo2Woo003oOolbOol00`00Oomoo`2TOol0

0`00Oomoo`3oOom6Ool00?mooc9oo`03001oogoo0:=oo`03001oogoo0?mo

odMoo`00ogoo<Woo00<007ooOol0Xgoo00<007ooOol0ogooAgoo003oOol/

Ool6O0000goo001oo`2SOol00`00Oomoo`3oOom7Ool00?moobAoo`Ql009o

o`=l009oo`03001oogoo0:5oo`03001oogoo0?moodQoo`00ogoo:goo1G`0

0goo00<007ooOol0XGoo00<007ooOol0ogooB7oo003oOolXOol3O002Ool0

0g`0Oomoo`04Ool00`00Oomoo`2POol00`00Oomoo`3oOom8Ool00?moobEo

o`=l00=oo`9l00Moo`03001oogoo09moo`03001oogoo0?moodUoo`00ogoo

8goo0W`01Goo00=l07ooOol027oo00<007ooOol0WWoo00<007ooOol0ogoo

BGoo003oOolPOol3O005Ool2O00;Ool00`00Oomoo`2MOol00`00Oomoo`02

Ool3O03oOom5Ool00?mooaeoo`=l00Moo`03O01oogoo00aoo`03001oogoo

09aoo`03001oogoo00=oo`Il0?mood5oo`00ogoo6Woo0g`06Goo00<007oo

Ool0Vgoo00<007ooOol01Goo0g`00Woo17`0ogoo?Goo003oOolHOol2O00M

Ool00`00Oomoo`2JOol00`00Oomoo`06Ool017`0Ooml07`017oo0g`0ogoo

>Woo003oOolEOol3O00OOol00`00Oomoo`2IOol00`00Oomoo`08Ool00g`0

Oomoo`02O03oOoloOol00?mooa9oo`=l02=oo`03001oogoo09Moo`03001o

ogoo00Yoo`04O01oogooOol2O03oOolmOol00?moo`moo`=l02Ioo`03001o

ogoo09Moo`03001oogoo00]oo`03O01oogoo009oo`9l0?mooc]oo`00ogoo

3Goo0W`0:Woo00<007ooOol0UGoo00<007ooOol03Goo0W`017oo0W`0ogoo

>Goo003oOol:Ool3O00]Ool00`00Oomoo`2DOol00`00Oomoo`0?Ool00g`0

Oomoo`03Ool2O03oOolgOol00?moo`Moo`=l031oo`03001oogoo09=oo`03

001oogoo01Qoo`9l0?moocEoo`00ogoo17oo0g`0=7oo00<007ooOol0TWoo

00<007ooOol06Woo0W`0ogoo<goo003oOol1Ool3O00gOol00`00Oomoo`2A

Ool00`00Oomoo`0MOol2O03oOolaOol00?ioo`9l03]oo`03001oogoo091o

o`03001oogoo01moo`9l0?moobmoo`00ngoo0g`0?Goo00<007ooOol0Sgoo

00<007ooOol08Woo0W`0ogoo;Goo003hOol3O011Ool00`00Oomoo`2=Ool0

0`00Oomoo`0UOol2O03oOol[Ool00?Eoo`=l04Eoo`03001oogoo08]oo`03

001oogoo02Qoo`9l0?moobUoo`00m7oo00=l07ooOol0Agoo00<007ooOol0

RGoo00@007ooOomoo`=l02Moo`9l0?moobMoo`00ogoo?Goo0g`000<007oo

Ool0R7oo00<007ooOol00Woo1G`09Woo00=l07ooOol0ogoo97oo003oOolk

Ool4O002Ool00`00Oomoo`26Ool00`00Oomoo`04Ool3O00017ooO01l07`0

97oo0W`0ogoo97oo003oOoliOol2O00017ooO01oog`00Woo00<007ooOol0

QGoo00<007ooOol01Woo00=l07ooO0000goo0g`08goo0W`0ogoo8Woo003o

OolgOol2O002Ool00g`0Ooml0004Ool00`00Oomoo`23Ool00`00Oomoo`07

Ool00g`0Oomoo`02O004Ool00g`0Oomoo`0ROol2O03oOolPOol00?moocEo

o`9l00=oo`03O01oog`000Ioo`03001oogoo085oo`03001oogoo00Uoo`05

O01oogooOoml000ZOol2O03oOolNOol00?moocAoo`03O01oogoo009oo`03

O01oog`000Qoo`03001oogoo07moo`03001oogoo00]oo`04O01oogooOol2

O00ZOol2O03oOolLOol00?moocQoo`04O01oogooO009Ool00`00Oomoo`1n

Ool00`00Oomoo`0<Ool00g`0Oomoo`02Ool00g`0Oomoo`0YOol2O03oOolJ

Ool00?moocIoo`9l009oo`03O01oogoo00Uoo`03001oogoo07aoo`03001o

ogoo00ioo`03O01oogoo009oo`9l02]oo`03O01oogoo0?mooaMoo`00ogoo

=Goo00El07ooOomoog`000aoo`03001oogoo07]oo`03001oogoo011oo`03

O01oogoo00=oo`03O01oogoo0?mood9oo`00ogoo=7oo00=l07ooOol00Woo

00=l07ooOol02goo00<007ooOol0NGoo00<007ooOol067oo0W`0ogoo@Woo

003oOolcOol00g`0Oomoo`02Ool00g`0Oomoo`0=Ool2001hOol00`00Oomo

o`0KOol00g`0Oomoo`3oOoloOol00?mooc9oo`03O01oogoo01Eoo`03001o

ogoo07=oo`800003Ooml07oo01aoo`9l0?moocmoo`00ogoo<Goo00=l07oo

Ool05goo00<007ooOol0LGoo00<007ooOol00Woo0W`07Goo00=l07ooOol0

ogoo?7oo003oOol_Ool2O00KOol00`00Oomoo`1_Ool00`00Oomoo`03Ool4

O00LOol2O03oOollOol00?moobioo`03O01oogoo01aoo`8006ioo`03001o

ogoo00Eoo`9l0003Ooml07`001aoo`03O01oogoo0?moocUoo`00ogoo;Goo

00=l07ooOol07goo00<007ooOol0JWoo00<007ooOol01goo0g`000=oog`0

O0006goo0W`0ogoo>Goo003oOol/Ool00g`0Oomoo`0QOol00`00Oomoo`1W

Ool2000:Ool017`0Oomoog`00Woo0W`06goo00=l07ooOol0ogoo=Woo003o

Ool[Ool00g`0Oomoo`0SOol00`00Oomoo`1UOol00`00Oomoo`0;Ool017`0

Oomoog`00goo0W`06Woo0W`0ogoo=Woo003oOolYOol2O00WOol00`00Oomo

o`1SOol00`00Oomoo`0=Ool017`0Oomoog`087oo00=l07ooOol0ogoo<goo

003oOolXOol00g`0Oomoo`0XOol2001ROol00`00Oomoo`0?Ool017`0Oomo

og`087oo0W`0ogoo<goo003oOolWOol00g`0Oomoo`0[Ool2001NOol2000B

Ool017`0Oomoogoo0W`087oo00=l07ooOol0ogoo<7oo003oOolVOol00g`0

Oomoo`0ZOol3O0000goo001oo`1JOol2000EOol00g`0Oomoo`02Ool00g`0

Oomoo`0NOol2O03oOol`Ool00?moobEoo`03O01oogoo02Yoo`=l00=oo`80

05Moo`8001Qoo`03O01oogoo009oo`03O01oogoo01moo`03O01oogoo0?mo

obeoo`00ogoo97oo00=l07ooOol0:Woo00Al07ooO01l00Eoo`8005=oo`80

0003Ooml07`001eoo`03O01oogoo01moo`9l0?moobeoo`00ogoo8Woo0W`0

;7oo00Al07ooO01l00Qoo`8004moo`8000=oo`=l01eoo`03O01oogoo021o

o`03O01oogoo0?moobYoo`00ogoo8Goo00=l07ooOol0:Woo0W`000Aoog`0

Ooml00Yoo`8004]oo`8000Ioo`=l01eoo`9l025oo`9l0?moobYoo`00ogoo

87oo00=l07ooOol0:Woo00Il07ooOoml07ooO00=Ool20018Ool00`00Oomo

o`06Ool2O0000gooO01oo`0MOol00g`0Oomoo`0POol00g`0Oomoo`3oOolW

Ool00?mooamoo`03O01oogoo02Yoo`07O01oogooOoml07ooO0003goo0P00

A7oo0P002Woo0W`000=oog`0Ool07Goo00=l07ooOol087oo0W`0ogoo9goo

003oOolNOol00g`0Oomoo`0ZOol01G`0OomoogooO0000Woo00=l07ooOol0

3goo0`00?Goo100037oo00El07ooO01oog`001ioo`03O01oogoo025oo`03

O01oogoo0?moobAoo`00ogoo7Goo00=l07ooOol0;Woo00Al07ooOoml01Eo

o`<003Moo`<0011oo`03O01oog`0009oo`03O01oogoo01aoo`03O01oogoo

0?moodMoo`00ogoo6goo0W`0<7oo00El07ooOomoog`001Qoo`<0035oo`<0

01Aoo`03O01oog`0009oo`9l01eoo`9l0?moodMoo`00ogoo6Woo00=l07oo

Ool0<7oo00Al07ooOoml01aoo`@002Yoo`<001Moo`04O01oogooO003Ool0

0g`0Oomoo`0LOol00g`0Oomoo`3oOom4Ool00?mooaUoo`03O01oogoo031o

o`05O01oogooOoml000LOol017`0Oomoogoo0`008goo100027oo00=l07oo

Ool03goo00Al07ooOoml02=oo`03O01oogoo0?mood=oo`00ogoo67oo00=l

07ooOol0<7oo00=l07ooOol07Woo0W`01Woo2P0047oo2@0037oo0W`04Goo

00Al07ooOoml02=oo`03O01oogoo0?mood9oo`00ogoo5goo00=l07ooOol0

<7oo00=l07ooOol07Woo0g`047oo40001Goo00=l07ooOol03Goo0W`04Goo

00El07ooOomoog`002=oo`03O01oogoo0?mood5oo`00ogoo5Woo00=l07oo

Ool0<Goo00=l07ooOol07Woo0g`09Goo00=l07ooOol03Goo0g`04Goo00El

07ooOomoog`002=oo`03O01oogoo0?mood1oo`00ogoo57oo0W`0<goo00=l

07ooOol07Woo00Al07ooO01l01=oo`03O01oogoo00ioo`=l00ioo`=l01Eo

o`03O01oogoo029oo`9l0?mood1oo`00ogoo4goo00=l07ooOol0<Woo00=l

07ooOol07goo00Al07ooO01l01=oo`03O01oogoo00ioo`=l00ioo`9l0003

Ooml07oo01Aoo`03O01oogoo02=oo`03O01oogoo0?mooceoo`00ogoo4Woo

00=l07ooOol0<Woo00=l07ooOol07goo00El07ooO01oog`0019oo`9l011o

o`=l00ioo`04O01oog`0O00FOol00g`0Oomoo`0SOol00g`0Oomoo`3oOoll

Ool00?mooa5oo`03O01oogoo039oo`03O01oogoo021oo`05O01oog`0Ooml

000BOol3O00?Ool2O0000gooO01oo`0<Ool01G`0Ooml07ooO0005Goo00=l

07ooOol097oo00=l07ooOol0ogoo>goo003oOom6Ool00g`0Oomoo`0OOol0

1W`0Oomoog`0Ooml019oo`=l00moo`9l0003Ooml07oo00aoo`05O01oog`0

Ooml000FOol00g`0Oomoo`0TOol00g`0Oomoo`3oOoljOol00?moodEoo`03

O01oogoo021oo`06O01oogooO01oog`04Woo0g`03goo0W`000=oog`0Ool0

37oo00=l07ooO0000Woo00=l07ooOol057oo00=l07ooOol097oo0W`0ogoo

>Woo003oOom4Ool00g`0Oomoo`0POol017`0Oomoog`00Woo00=l07ooOol0

3goo00Al07ooO01l00ioo`06O01oogooO01oog`037oo00=l07ooO0000Woo

00=l07ooOol057oo00=l07ooOol09Woo00=l07ooOol0ogoo=goo003oOom3

Ool00g`0Oomoo`0QOol017`0Oomoog`00Woo00=l07ooOol03goo00El07oo

O01oog`000eoo`06O01oogooO01oog`037oo00Al07ooOoml009oo`03O01o

ogoo01Aoo`03O01oogoo02Ioo`03O01oogoo0?moocIoo`00ogoo@goo00=l

07ooOol097oo00Al07ooOoml015oo`05O01oog`0Ooml000=Ool01W`0Oomo

og`0Ooml00aoo`04O01oogooO002Ool00g`0Oomoo`0EOol00g`0Oomoo`0V

Ool00g`0Oomoo`3oOoleOol00?mood9oo`03O01oogoo02Eoo`04O01oogoo

O00AOol01G`0Ooml07ooO0003Goo00Al07ooOoml009oo`03O01oogoo00Uo

o`04O01oogooO00JOol00g`0Oomoo`0WOol00g`0Oomoo`3oOoldOol00?mo

od5oo`03O01oogoo02Eoo`03O01oogoo019oo`06O01oogooO01oog`03Goo

00Al07ooOoml009oo`03O01oogoo00Uoo`04O01oogooO00KOol00g`0Oomo

o`0WOol2O03oOoldOol00?mood1oo`03O01oogoo02Ioo`03O01oogoo019o

o`04O01oogooO002Ool00g`0Oomoo`0:Ool017`0Oomoog`04Goo00=l07oo

Ool06Woo00=l07ooOol0ogooG7oo003oOom0Ool00g`0Oomoo`0VOol00g`0

Oomoo`0BOol017`0Oomoog`00Woo00=l07ooOol03Goo00=l07ooOol047oo

00=l07ooOol06Goo00=l07ooOol0ogooG7oo003oOoloOol00g`0Oomoo`0W

Ool00g`0Oomoo`0BOol017`0Oomoog`00Woo00=l07ooOol03Goo00=l07oo

Ool047oo00=l07ooOol06Woo00=l07ooOol0ogooFgoo003oOolnOol00g`0

Oomoo`0WOol00g`0Oomoo`0FOol00g`0Oomoo`0@Ool00g`0Oomoo`0@Ool0

0g`0Oomoo`0KOol00g`0Oomoo`3oOomJOol00?mooceoo`03O01oogoo02Qo

o`03O01oogoo01Ioo`03O01oogoo011oo`03O01oogoo011oo`03O01oogoo

01]oo`03O01oogoo0?mooeYoo`00ogoo?Goo00=l07ooOol0:7oo00=l07oo

Ool05Woo00=l07ooOol047oo00=l07ooOol047oo00=l07ooOol077oo00=l

07ooOol0ogooFGoo003oOollOol00g`0Oomoo`0YOol00g`0Oomoo`0FOol0

0g`0Oomoo`0@Ool00g`0Oomoo`0AOol00g`0Oomoo`0LOol00g`0Oomoo`3o

OomHOol00?mooc]oo`03O01oogoo02Uoo`03O01oogoo01Moo`03O01oogoo

011oo`03O01oogoo015oo`03O01oogoo01eoo`03O01oogoo0?mooeMoo`00

ogoo>Woo00=l07ooOol0:Woo00=l07ooOol05goo00=l07ooOol047oo00=l

07ooOol04Goo00=l07ooOol07Goo00=l07ooOol0ogooEgoo003oOoljOol0

0g`0Oomoo`0ZOol00g`0Oomoo`0GOol00g`0Oomoo`0AOol00g`0Oomoo`0@

Ool00g`0Oomoo`0NOol00g`0Oomoo`3oOomFOol00?moocUoo`03O01oogoo

02]oo`03O01oogoo01Moo`03O01oogoo015oo`03O01oogoo011oo`03O01o

ogoo01moo`03O01oogoo0?mooeEoo`00ogoo>7oo00=l07ooOol0:goo00=l

07ooOol067oo00=l07ooOol04Goo00=l07ooOol04Goo00=l07ooOol07Woo

00=l07ooOol0ogooEGoo003oOolgOol00g`0Oomoo`0/Ool00g`0Oomoo`0H

Ool00g`0Oomoo`0AOol00g`0Oomoo`0AOol00g`0Oomoo`0OOol00g`0Oomo

o`3oOomDOol00?moocMoo`03O01oogoo02aoo`03O01oogoo01Qoo`03O01o

ogoo015oo`03O01oogoo015oo`03O01oogoo021oo`03O01oogoo0?mooe=o

o`00ogoo=Woo00=l07ooOol0;Goo00=l07ooOol067oo00=l07ooOol04Goo

00=l07ooOol04Goo00=l07ooOol087oo00=l07ooOol0ogooDgoo003oOole

Ool00g`0Oomoo`0]Ool00g`0Oomoo`0IOol00g`0Oomoo`0AOol00g`0Oomo

o`0AOol00g`0Oomoo`0QOol00g`0Oomoo`3oOomBOol00?moofEoo`03O01o

ogoo01Uoo`03O01oogoo015oo`03O01oogoo019oo`03O01oogoo025oo`03

O01oogoo0?mooe5oo`00ogooIGoo00=l07ooOol06Goo00=l07ooOol04Goo

00=l07ooOol04Woo00=l07ooOol08Goo00=l07ooOol0ogooDGoo003oOomU

Ool00g`0Oomoo`0IOol00g`0Oomoo`0AOol00g`0Oomoo`0BOol00g`0Oomo

o`0ROol00g`0Oomoo`3oOom@Ool00?moofAoo`03O01oogoo01Yoo`03O01o

ogoo015oo`03O01oogoo019oo`03O01oogoo02=oo`03O01oogoo0?moodmo

o`00ogooI7oo00=l07ooOol06Woo00=l07ooOol04Goo00=l07ooOol04goo

00=l07ooOol0ogooM7oo003oOomTOol00g`0Oomoo`0JOol00g`0Oomoo`0A

Ool00g`0Oomoo`0COol00g`0Oomoo`3oOomdOol00?moofAoo`03O01oogoo

01Yoo`03O01oogoo015oo`03O01oogoo01=oo`03O01oogoo0?moogAoo`00

ogooHgoo00=l07ooOol06goo00=l07ooOol04Woo00=l07ooOol04Woo00=l

07ooOol0ogooM7oo003oOomSOol00g`0Oomoo`0KOol00g`0Oomoo`0BOol0

0g`0Oomoo`0BOol00g`0Oomoo`3oOomdOol00?moof=oo`03O01oogoo01]o

o`03O01oogoo019oo`03O01oogoo01=oo`03O01oogoo0?moog=oo`00ogoo

Hgoo00=l07ooOol06goo00=l07ooOol04Woo00=l07ooOol04goo00=l07oo

Ool0ogooLgoo003oOomROol00g`0Oomoo`0LOol00g`0Oomoo`0BOol00g`0

Oomoo`0COol00g`0Oomoo`3oOomcOol00?moof9oo`03O01oogoo01aoo`03

O01oogoo019oo`03O01oogoo01=oo`03O01oogoo0?moog=oo`00ogooHWoo

00=l07ooOol077oo00=l07ooOol04Woo00=l07ooOol04goo00=l07ooOol0

ogooLgoo003oOomROol00g`0Oomoo`0LOol00g`0Oomoo`0BOol00g`0Oomo

o`0DOol00g`0Oomoo`3oOombOol00?moof5oo`03O01oogoo01eoo`03O01o

ogoo019oo`03O01oogoo0?moohUoo`00ogooHGoo00=l07ooOol07Goo00=l

07ooOol04Woo00=l07ooOol0ogooRGoo003oOomQOol00g`0Oomoo`0MOol0

0g`0Oomoo`0BOol00g`0Oomoo`3oOon9Ool00?moof5oo`03O01oogoo01eo

o`03O01oogoo0?mooiioo`00ogooH7oo00=l07ooOol07Woo00=l07ooOol0

ogooWWoo003oOon1Ool00g`0Oomoo`3oOonNOol00?mooh5oo`03O01oogoo

0?mooiioo`00ogooPGoo00=l07ooOol0ogooWWoo003oOon1Ool00g`0Oomo

o`3oOonNOol00?mooh5oo`03O01oogoo0?mooiioo`00ogooogooogoo8goo

003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003o

OoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOooo

OoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOooo

OolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolS

Ool00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol0

0?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mo

oomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomo

oomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomo

ob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=o

o`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00

ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogoo

ogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogoo

ogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo

8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo

003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003o

OoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOooo

OoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOooo

OolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolS

Ool00?mooomooomoob=oo`00ogooogooogoo8goo0000\

\>"], "Graphics",

  ImageSize->{602, 451.5},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}}],



Cell[CellGroupData[{



Cell[TextData[StyleBox["2.1 Mathematical Formulation",

  FontSize->18]], "Subsection"],



Cell[TextData[{

  StyleBox[

  "We investigate the radially symmetric deflections so that the variables \

are \nonly a function of the radius r. This problem is formulated in terms of \

the\nfollowing system of three second order nonlinear ordinary differential\n\

equations which we derived in an earlier paper [2].\n\nGq + ",

    FontSize->16],

  StyleBox[Cell[BoxData[

      \(TraditionalForm\`a\^2\)],

    FontSize->16]],

  StyleBox[" pq = ",

    FontSize->16],

  StyleBox[Cell[BoxData[

      \(TraditionalForm\`k\^2\)],

    FontSize->16]],

  StyleBox["W,\nGp = ",

    FontSize->16],

  StyleBox[Cell[BoxData[

      \(TraditionalForm\`1\/2\)],

    FontSize->16]],

  StyleBox[Cell[BoxData[

      FormBox[

        SuperscriptBox[

          StyleBox["q",

            FontSlant->"Plain"], "2"], TraditionalForm]],

    FontSize->16]],

  StyleBox[

  ",\nGW + q = 0,                                                             \

                                     (2.1)\nwhere  G\[FilledSmallCircle]=",

    FontSize->16],

  StyleBox[Cell[BoxData[

      FormBox[

        FractionBox["1", 

          StyleBox[\(r\^3\),

            FontSize->16]], TraditionalForm]],

    FontSize->16]],

  StyleBox[Cell[BoxData[

      FormBox[

        RowBox[{

          SubscriptBox["\[PartialD]", 

            StyleBox["r",

              FontSize->14]], " ", 

          RowBox[{"(", 

            RowBox[{\(r\^3\), 

              RowBox[{

                SubscriptBox["\[PartialD]", 

                  StyleBox["r",

                    FontSize->14]], " ", "\[FilledSmallCircle]"}]}]}]}], 

        TraditionalForm]],

    FontSize->16]],

  StyleBox[")  \nand 0 \[LessEqual] ",

    FontSize->16],

  StyleBox["r",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[

  " \[LessEqual] 1.\n\nThe boundary conditions are:\n\nq'(0) = 0,  p'(0) = 0, \

 W'(0) = 0,                                                                   \

  (2.2)\nq(1) = 0,   p(1) = 1,   W'(1) + 2 W(1) = 0.                          \

                            (2.3)\n\nThe variables q(",

    FontSize->16],

  StyleBox["r",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[") and W(",

    FontSize->16],

  StyleBox["r",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[") are defined in terms of the vertical deflection ",

    FontSize->16],

  StyleBox["w(r) ",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox["\nas follows:\n\nq(",

    FontSize->16],

  StyleBox["r",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[") = ",

    FontSize->16],

  StyleBox[Cell[BoxData[

      FormBox[

        StyleBox[

          FractionBox["1", 

            StyleBox["r",

              FontSize->16]],

          FontSize->16], TraditionalForm]],

    FontSize->16]],

  StyleBox[Cell[BoxData[

      FormBox[

        RowBox[{

          RowBox[{

            RowBox[{

              SubscriptBox["\[PartialD]", 

                StyleBox["r",

                  FontSize->14]], \(w(r)\)}], ","}], "\n"}], 

        TraditionalForm]],

    FontSize->16]],

  StyleBox[

  "                                                                           \

                                               "],

  StyleBox["(2.4)",

    FontSize->16],

  StyleBox["\n"],

  StyleBox["W(",

    FontSize->16],

  StyleBox["r",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[") = - ",

    FontSize->16],

  StyleBox[Cell[BoxData[

      FormBox[

        FractionBox["1", 

          StyleBox[\(r\ \),

            FontSize->16]], TraditionalForm]],

    FontSize->16]],

  StyleBox[Cell[BoxData[

      FormBox[

        RowBox[{

          SubsuperscriptBox[

            StyleBox["\[Integral]",

              FontSize->18], "0", 

            StyleBox["r",

              FontSize->16]], \(s\ \(w(s)\) \[DifferentialD]s\)}], 

        TraditionalForm]],

    FontSize->16]],

  StyleBox[

  ".                                                                          \

                                 "],

  StyleBox["(2.5)   ",

    FontSize->16],

  StyleBox["  \n\n"],

  StyleBox["The variable p(",

    FontSize->16],

  StyleBox["r",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[") represents the radial stress.\n",

    FontSize->16]

}], "Input",

  FormatType->TextForm]

}, Open  ]],



Cell[CellGroupData[{



Cell[TextData[StyleBox["2.2  The Linearized Problem",

  FontSize->18]], "Subsection"],



Cell[TextData[{

  StyleBox[

  "As was mentioned in Section 1,  we need to solve the linearized problem\n\

and find its eigenvalues in order to start the shooting method.\n \nThe \

boundary value problem defined by (2.1), (2.2), (2.3), has the obvious\n\

solution: \nq \[Congruent] 0, p \[Congruent] 1, W \[Congruent] 0 \nfor any ",

    FontSize->16],

  StyleBox["a",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[" and ",

    FontSize->16],

  StyleBox["k . ",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[

  "This solution represents the unbuckled state.\nThe BVP  problem linearized \

about this unbuckled solution is:\n\nGq + ",

    FontSize->16],

  Cell[BoxData[

      FormBox[

        SuperscriptBox[

          StyleBox["a",

            FontSlant->"Italic"], "2"], TraditionalForm]],

    FontSize->16],

  StyleBox["q = ",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`k\^2\)],

    FontSize->16],

  StyleBox[

  "W,\nGp = 0,                                                                \

                                            (2.6)\nGW + q = 0,\ntogether with \

the boundary conditions (2.2) and (2.3).\nThis BVP has been solved in [2]. \

The solution is:\n",

    FontSize->16]

}], "Input",

  FormatType->TextForm],



Cell[BoxData[

    FormBox[

      RowBox[{

        RowBox[{

          StyleBox[

            FormBox[

              SubscriptBox[

                StyleBox["q",

                  FontSlant->"Plain"], "n"],

              "TraditionalForm"],

            FontSize->16], 

          StyleBox["=",

            FontSize->16], 

          RowBox[{

            StyleBox[

              FormBox[

                FractionBox["1", 

                  StyleBox["r",

                    FontSize->16]],

                "TraditionalForm"],

              FontSize->16], 

            StyleBox[

              FormBox[

                RowBox[{"(", 

                  RowBox[{

                    RowBox[{

                      FormBox[\(\(\[Lambda]\_n\)(k)\),

                        "TraditionalForm"], 

                      FormBox[\(\ \(J\_0\)(k\/\(\(\[Lambda]\_n\)(k)\))\),

                        "TraditionalForm"], 

                      FormBox[\(\(J\_1\)(\(\(\[Lambda]\_n\)(k)\)\ r)\),

                        "TraditionalForm"]}], "-", 

                    RowBox[{

                      FormBox[\(k\/\(\(\[Lambda]\_n\)(k)\)\),

                        "TraditionalForm"], 

                      

                      FormBox[

                        \(\(\(J\_0\)(\(\[Lambda]\_n\)(k)\ )\) 

                          \(\(J\_1\)(\(\(k\ \)\/\(\(\[Lambda]\_n\)(k)\)\) r)

                            \)\),

                        "TraditionalForm"]}]}], ")"}],

                "TraditionalForm"],

              FontSize->16], 

            FormBox[

              RowBox[{

                FormBox["",

                  "TraditionalForm"], 

                FormBox["",

                  "TraditionalForm"]}],

              "TraditionalForm"]}]}], ","}], TraditionalForm]], "Input"],



Cell[BoxData[

    FormBox[

      RowBox[{

        RowBox[{

          StyleBox[

            RowBox[{

              RowBox[{

                SubscriptBox[

                  StyleBox["W",

                    FontSlant->"Plain"], "n"], 

                FormBox[

                  RowBox[{

                    FormBox["",

                      "TraditionalForm"], 

                    FormBox["",

                      "TraditionalForm"]}],

                  "TraditionalForm"]}], "=", 

              RowBox[{

                FormBox[

                  FractionBox["1", 

                    StyleBox["r",

                      FontSize->16]],

                  "TraditionalForm"], 

                FormBox[

                  RowBox[{"(", 

                    RowBox[{

                      RowBox[{

                        FormBox[\(k\/\(\(\[Lambda]\_n\)(k)\)\),

                          "TraditionalForm"], " ", 

                        FormBox[\(\ \(J\_0\)(k\/\(\(\[Lambda]\_n\)(k)\))\),

                          "TraditionalForm"], 

                        FormBox[\(\(J\_1\)(\(\(\[Lambda]\_n\)(k)\)\ r)\),

                          "TraditionalForm"]}], "-", 

                      RowBox[{

                        FormBox[\(\(\[Lambda]\_n\)(k)\),

                          "TraditionalForm"], 

                        

                        FormBox[

                          \(\(\(J\_0\)(\(\[Lambda]\_n\)(k))\)\ 

                            \(\(J\_1\)(\(\(k\ \)\/\(\(\[Lambda]\_n\)(k)\)\) r)

                              \)\),

                          "TraditionalForm"]}]}], ")"}],

                  "TraditionalForm"]}]}],

            FontSize->16], 

          StyleBox[" ",

            FontSize->16], 

          StyleBox[",",

            FontSize->16], "\n", 

          RowBox[{

            StyleBox["p",

              FontSize->16,

              FontSlant->"Plain"], 

            StyleBox[" ",

              FontSize->16], 

            StyleBox["\[Congruent]",

              FontSize->16], 

            StyleBox[" ",

              FontSize->16], 

            StyleBox["1.",

              FontSize->16]}]}], "\t"}], TraditionalForm]], "Input"],



Cell[TextData[{

  StyleBox["Where the ",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`\(\[Lambda]\_n\)(k)\)],

    FontSize->16],

  StyleBox[" are, for a fixed value of ",

    FontSize->16],

  StyleBox["k",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[", roots of",

    FontSize->16]

}], "Input",

  FormatType->TextForm],



Cell[BoxData[

    FormBox[

      RowBox[{

      \(\(\(\[Lambda]\_n\)(k)\) 

          \(\(J\_1\) \((\(\[Lambda]\_n\)(k)\ )\)\)\/\(\(J\_0\) 

              \((\(\[Lambda]\_n\)(k)\ )\)\)\), " ", "=", " ", 

        RowBox[{\(k\/\(\(\[Lambda]\_n\)(k)\)\), 

          RowBox[{

            FractionBox[

              RowBox[{\(J\_1\), 

                RowBox[{"(", 

                  FractionBox[

                    RowBox[{

                      StyleBox["k",

                        FontSize->16], " "}], 

                    StyleBox[\(\(\[Lambda]\_n\) \((k)\)\),

                      FontSize->16]], ")"}]}], 

              RowBox[{\(J\_0\), 

                RowBox[{"(", 

                  FractionBox[

                    StyleBox["k",

                      FontSize->16], 

                    StyleBox[\(\(\[Lambda]\_n\) \((k)\)\),

                      FontSize->16]], ")"}]}]], ".", 

            "                                                                 \

    ", \((2.7)\)}]}]}], TraditionalForm]], "Input",

  FormatType->StandardForm,

  FontSize->16],



Cell[TextData[{

  StyleBox["Here ",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`J\_0\)],

    FontSize->16],

  StyleBox[" and ",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`J\_1\)],

    FontSize->16],

  " ",

  StyleBox[

  "are the Bessel functions of the first kind. \nFinally, the eigenvalues ",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`a\_n\)],

    FontSize->16],

  StyleBox["(",

    FontSize->16],

  StyleBox["k",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[") are given by",

    FontSize->16]

}], "Input",

  FormatType->TextForm],



Cell[TextData[{

  StyleBox[" ",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`a\_n\)],

    FontSize->16],

  StyleBox["(",

    FontSize->16],

  StyleBox["k",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[") = ",

    FontSize->16],

  Cell[BoxData[

      FormBox[

        SuperscriptBox[

          RowBox[{"(", 

            StyleBox[

              RowBox[{\(\(\[Lambda]\_n\%2\)(k)\), " ", "+", " ", 

                FractionBox[

                  StyleBox[\(k\^2\),

                    FontSize->16], 

                  RowBox[{

                    StyleBox[\(\(\[Lambda]\_n\%2\)(k)\),

                      FontSize->16], " "}]]}],

              FontSize->16], " ", ")"}], \(1\/2\)], TraditionalForm]]],

  ".                                                                          \

                          ",

  StyleBox["  (2.8)",

    FontSize->16]

}], "Input",

  FormatType->TextForm],



Cell[TextData[{

  StyleBox[

  "We see from (2.7), which we call the eigenvalue equation, that for ",

    FontSize->16],

  StyleBox["k",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[" =0,\n",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`\(\(\[Lambda]\_n\)(0)\ \)\)],

    FontSize->16],

  StyleBox["=",

    FontSize->16],

  StyleBox[" ",

    FontSize->16,

    FontSlant->"Italic"],

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox[

            RowBox[{

              StyleBox["j",

                FontSlant->"Italic"], "1"}]], \(n\ \)], TraditionalForm]],

    FontSize->16,

    FontSlant->"Italic"],

  ", ",

  StyleBox[" where ",

    FontSize->16],

  Cell[BoxData[

      FormBox[

        StyleBox[

          SubscriptBox[

            StyleBox[

              RowBox[{

                StyleBox["j",

                  FontSlant->"Italic"], "1"}]], \(n\ \)],

          FontSize->16], TraditionalForm]]],

  " ",

  StyleBox["is the nth zero of  ",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`\(J\_1\)(\[Lambda])\)],

    FontSize->16],

  ". ",

  StyleBox["We find the  ",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`a\_n\)],

    FontSize->16],

  StyleBox["(",

    FontSize->16],

  StyleBox["k",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[") using\nthe following ",

    FontSize->16],

  StyleBox["Mathematica",

    FontFamily->"Times New Roman",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[" ",

    FontFamily->"System",

    FontSize->16],

  StyleBox["code. \n",

    FontSize->16]

}], "Input",

  FormatType->TextForm],



Cell[BoxData[{

    RowBox[{

      RowBox[{\(f1[lam_]\), " ", ":=", " ", 

        RowBox[{"lam", "*", 

          FormBox[\(\(\(J\_1\)(lam)\)\/\(\(J\_0\)(lam)\)\),

            "TraditionalForm"]}]}], "\n"}], 

    RowBox[{

      \(findroot[lam0_, k0_] := 

        lam /. FindRoot[f1[lam] == f1[k0/lam], {lam, lam0}]\), "\n"}], 

  \(eigenbranch[lam0_, \ k0_, \ dk_, \ jm_]\  := \ \n\ \ 

      Module[{Lam, a}, \ \n\ \ \ Lam[0] := findroot[lam0, k0 + 10^\(-100\)]; 

        \ \n\ \ \ Lam[1] := findroot[Lam[0], k0 + dk]; \ \n\ \ \ 

        Lam[i_] := 

          \((Lam[i] = findroot[2*Lam[i - 1] - Lam[i - 2], k0 + i*dk])\) /; 

            i >= 2; \n\ \ \ \ 

        a[i_] := \(a[i] = \@\(Lam[i]\^2 + \((k0 + i\ dk)\)\^2\/Lam[i]\^2\)\); 

        \ \n\ \ \ \ Table[{k0\  + \ j*dk, a[j]}, {j, 0, jm}]\n

        \t\ \ \ \ \ \ \ \ \ \ \ ]\)}], "Input",

  PageWidth->Infinity,

  ShowSpecialCharacters->False,

  FontSize->14],



Cell[TextData[{

  StyleBox["\nIn order to calculate the value of a particular  ",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`a\_n\)],

    FontSize->16],

  StyleBox["(",

    FontSize->16],

  StyleBox["k",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[") we use the following:\n",

    FontSize->16]

}], "Input",

  FormatType->TextForm],



Cell[BoxData[

    \(<< NumericalMath`BesselZeros`\)], "Input",

  FontSize->14],



Cell[BoxData[{\(j1[n_] := BesselJZeros[1, {n, n}]\), 

    RowBox[{

      RowBox[{

        SubscriptBox["a", 

          StyleBox[

            RowBox[{

              StyleBox["n",

                FontSize->11], "_"}]]], "[", "k_", "]"}], ":=", 

      \(\(eigenbranch[j1[n], 0, 1., k]\)[\([k + 1, 2]\)]\)}]}], "Input",

  FontSize->14],



Cell[TextData[{

  StyleBox["In this command we start at k = 0 with lam0 = j1[n]",

    FontSize->16],

  " . ",

  StyleBox[

  "We then march along \nincreasing k in steps of 1, until we reach the \

desired value of k. This is \nsimilar to the idea used in the shooting method \

to march along to ",

    FontSize->16],

  "get ",

  StyleBox["\na branch of solutions.\n\nFor example to calculate  ",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`a\_3\)],

    FontSize->16],

  StyleBox["(38) and ",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`a\_4\)],

    FontSize->16],

  StyleBox["(38) we would use\n",

    FontSize->16]

}], "Input",

  FormatType->TextForm,

  FontSize->16],



Cell[BoxData[

    RowBox[{"{", 

      RowBox[{\(a\_3[38]\), ",", 

        RowBox[{

          SubscriptBox["a", 

            StyleBox["4",

              FontWeight->"Plain"]], "[", "38", "]"}]}], "}"}]], "Input",

  FontSize->14],



Cell[CellGroupData[{



Cell[TextData[StyleBox["and get,",

  FontSize->16]], "Input",

  FormatType->TextForm],



Cell["{13.314,15.5456}", "Output",

  GeneratedCell->False,

  CellAutoOverwrite->False,

  FontSize->14]

}, Open  ]],



Cell[TextData[{

  StyleBox["\n\nWe could plot the graphs of the  ",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`a\_n\)],

    FontSize->16],

  StyleBox["(",

    FontSize->16],

  StyleBox["k",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[") with the following command.\n",

    FontSize->16]

}], "Input",

  FormatType->TextForm],



Cell[BoxData[

    \(eigenbranchgraph[k0_, dk_, jm_, mm_] := \n\t

      Show[Table[Graphics[{Line[eigenbranch[j1[m], k0, dk, jm]]}], {m, mm}], 

        \n\t\tAxes -> Automatic, AxesOrigin -> {0, 0}, \n\t\t

        AxesLabel -> {k, a}, PlotLabel -> \*"\"\<\!\(a\_n\)(k)\>\""]\)], 

  "Input",

  FontSize->14],



Cell[TextData[{

  StyleBox["\nFor example to plot the first five  ",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`a\_n\)],

    FontSize->16],

  StyleBox["(",

    FontSize->16],

  StyleBox["k",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox["), for  0 \[LessSlantEqual] ",

    FontSize->16],

  StyleBox["k",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[" \[LessSlantEqual] 100, we would use:\n",

    FontSize->16]

}], "Input",

  FormatType->TextForm],



Cell[CellGroupData[{



Cell[BoxData[

    \(eigenbranchgraph[0, 1., 100, 5]\)], "Input",

  FontSize->14],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.00952381 -0.119356 0.03499 [

[.21429 -0.13186 -6 -9 ]

[.21429 -0.13186 6 0 ]

[.40476 -0.13186 -6 -9 ]

[.40476 -0.13186 6 0 ]

[.59524 -0.13186 -6 -9 ]

[.59524 -0.13186 6 0 ]

[.78571 -0.13186 -6 -9 ]

[.78571 -0.13186 6 0 ]

[.97619 -0.13186 -9 -9 ]

[.97619 -0.13186 9 0 ]

[1.025 -0.11936 0 -8 ]

[1.025 -0.11936 9 8 ]

[.01131 .05559 -6 -4.5 ]

[.01131 .05559 0 4.5 ]

[.01131 .14307 -18 -4.5 ]

[.01131 .14307 0 4.5 ]

[.01131 .23054 -12 -4.5 ]

[.01131 .23054 0 4.5 ]

[.01131 .31802 -24 -4.5 ]

[.01131 .31802 0 4.5 ]

[.01131 .40549 -12 -4.5 ]

[.01131 .40549 0 4.5 ]

[.01131 .49297 -24 -4.5 ]

[.01131 .49297 0 4.5 ]

[.01131 .58044 -12 -4.5 ]

[.01131 .58044 0 4.5 ]

[.02381 .64303 -4.5 0 ]

[.02381 .64303 4.5 16 ]

[.5 .63053 -14 0 ]

[.5 .63053 14 16 ]

[ 0 -0.11936 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 -0.11936 m

.21429 -0.11311 L

s

[(20)] .21429 -0.13186 0 1 Mshowa

.40476 -0.11936 m

.40476 -0.11311 L

s

[(40)] .40476 -0.13186 0 1 Mshowa

.59524 -0.11936 m

.59524 -0.11311 L

s

[(60)] .59524 -0.13186 0 1 Mshowa

.78571 -0.11936 m

.78571 -0.11311 L

s

[(80)] .78571 -0.13186 0 1 Mshowa

.97619 -0.11936 m

.97619 -0.11311 L

s

[(100)] .97619 -0.13186 0 1 Mshowa

.125 Mabswid

.07143 -0.11936 m

.07143 -0.11561 L

s

.11905 -0.11936 m

.11905 -0.11561 L

s

.16667 -0.11936 m

.16667 -0.11561 L

s

.2619 -0.11936 m

.2619 -0.11561 L

s

.30952 -0.11936 m

.30952 -0.11561 L

s

.35714 -0.11936 m

.35714 -0.11561 L

s

.45238 -0.11936 m

.45238 -0.11561 L

s

.5 -0.11936 m

.5 -0.11561 L

s

.54762 -0.11936 m

.54762 -0.11561 L

s

.64286 -0.11936 m

.64286 -0.11561 L

s

.69048 -0.11936 m

.69048 -0.11561 L

s

.7381 -0.11936 m

.7381 -0.11561 L

s

.83333 -0.11936 m

.83333 -0.11561 L

s

.88095 -0.11936 m

.88095 -0.11561 L

s

.92857 -0.11936 m

.92857 -0.11561 L

s

.25 Mabswid

0 -0.11936 m

1 -0.11936 L

s

gsave

1.025 -0.11936 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(k) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 .05559 m

.03006 .05559 L

s

[(5)] .01131 .05559 1 0 Mshowa

.02381 .14307 m

.03006 .14307 L

s

[(7.5)] .01131 .14307 1 0 Mshowa

.02381 .23054 m

.03006 .23054 L

s

[(10)] .01131 .23054 1 0 Mshowa

.02381 .31802 m

.03006 .31802 L

s

[(12.5)] .01131 .31802 1 0 Mshowa

.02381 .40549 m

.03006 .40549 L

s

[(15)] .01131 .40549 1 0 Mshowa

.02381 .49297 m

.03006 .49297 L

s

[(17.5)] .01131 .49297 1 0 Mshowa

.02381 .58044 m

.03006 .58044 L

s

[(20)] .01131 .58044 1 0 Mshowa

.125 Mabswid

.02381 .07309 m

.02756 .07309 L

s

.02381 .09058 m

.02756 .09058 L

s

.02381 .10808 m

.02756 .10808 L

s

.02381 .12557 m

.02756 .12557 L

s

.02381 .16056 m

.02756 .16056 L

s

.02381 .17806 m

.02756 .17806 L

s

.02381 .19555 m

.02756 .19555 L

s

.02381 .21305 m

.02756 .21305 L

s

.02381 .24804 m

.02756 .24804 L

s

.02381 .26553 m

.02756 .26553 L

s

.02381 .28303 m

.02756 .28303 L

s

.02381 .30052 m

.02756 .30052 L

s

.02381 .33551 m

.02756 .33551 L

s

.02381 .35301 m

.02756 .35301 L

s

.02381 .3705 m

.02756 .3705 L

s

.02381 .388 m

.02756 .388 L

s

.02381 .42299 m

.02756 .42299 L

s

.02381 .44048 m

.02756 .44048 L

s

.02381 .45798 m

.02756 .45798 L

s

.02381 .47547 m

.02756 .47547 L

s

.02381 .51046 m

.02756 .51046 L

s

.02381 .52796 m

.02756 .52796 L

s

.02381 .54545 m

.02756 .54545 L

s

.02381 .56295 m

.02756 .56295 L

s

.02381 .0381 m

.02756 .0381 L

s

.02381 .0206 m

.02756 .0206 L

s

.02381 .00311 m

.02756 .00311 L

s

.02381 .59794 m

.02756 .59794 L

s

.02381 .61543 m

.02756 .61543 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -75 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 16.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(n) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

72.000000 15.000000 moveto

(H) show

77.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(k) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

82.000000 15.000000 moveto

(L) show

87.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

.5 Mabswid

.02381 .01472 m

.03333 .01534 L

.04286 .01718 L

.05238 .02018 L

.0619 .02426 L

.07143 .02931 L

.08095 .03521 L

.09048 .04182 L

.1 .04901 L

.10952 .05667 L

.11905 .06464 L

.12857 .07281 L

.1381 .08102 L

.14762 .08913 L

.15714 .09699 L

.16667 .10444 L

.17619 .11136 L

.18571 .11769 L

.19524 .12341 L

.20476 .12859 L

.21429 .13332 L

.22381 .1377 L

.23333 .14184 L

.24286 .14579 L

.25238 .14963 L

.2619 .15338 L

.27143 .15709 L

.28095 .16078 L

.29048 .16446 L

.3 .16815 L

.30952 .17184 L

.31905 .17556 L

.32857 .17929 L

.3381 .18305 L

.34762 .18683 L

.35714 .19063 L

.36667 .19445 L

.37619 .19829 L

.38571 .20214 L

.39524 .20601 L

.40476 .20989 L

.41429 .21377 L

.42381 .21766 L

.43333 .22154 L

.44286 .2254 L

.45238 .22926 L

.4619 .23309 L

.47143 .23689 L

.48095 .24066 L

.49048 .24439 L

Mistroke

.5 .24807 L

.50952 .2517 L

.51905 .25527 L

.52857 .25878 L

.5381 .26222 L

.54762 .26559 L

.55714 .26889 L

.56667 .27212 L

.57619 .27528 L

.58571 .27838 L

.59524 .28141 L

.60476 .28439 L

.61429 .28732 L

.62381 .29019 L

.63333 .29303 L

.64286 .29583 L

.65238 .29859 L

.6619 .30133 L

.67143 .30404 L

.68095 .30673 L

.69048 .3094 L

.7 .31206 L

.70952 .3147 L

.71905 .31734 L

.72857 .31997 L

.7381 .32259 L

.74762 .3252 L

.75714 .32781 L

.76667 .33042 L

.77619 .33302 L

.78571 .33563 L

.79524 .33823 L

.80476 .34083 L

.81429 .34343 L

.82381 .34603 L

.83333 .34863 L

.84286 .35122 L

.85238 .35382 L

.8619 .35642 L

.87143 .35901 L

.88095 .3616 L

.89048 .36419 L

.9 .36678 L

.90952 .36936 L

.91905 .37194 L

.92857 .37451 L

.9381 .37708 L

.94762 .37964 L

.95714 .38219 L

.96667 .38474 L

Mistroke

.97619 .38727 L

Mfstroke

.02381 .12612 m

.03333 .12622 L

.04286 .12653 L

.05238 .12704 L

.0619 .12776 L

.07143 .1287 L

.08095 .12986 L

.09048 .13127 L

.1 .13293 L

.10952 .13488 L

.11905 .13715 L

.12857 .13978 L

.1381 .14283 L

.14762 .14638 L

.15714 .15051 L

.16667 .15531 L

.17619 .16082 L

.18571 .16703 L

.19524 .17388 L

.20476 .18119 L

.21429 .18875 L

.22381 .19634 L

.23333 .2037 L

.24286 .2106 L

.25238 .21687 L

.2619 .22241 L

.27143 .22722 L

.28095 .23135 L

.29048 .23494 L

.3 .2381 L

.30952 .24093 L

.31905 .24352 L

.32857 .24594 L

.3381 .24824 L

.34762 .25045 L

.35714 .25261 L

.36667 .25473 L

.37619 .25684 L

.38571 .25895 L

.39524 .26106 L

.40476 .2632 L

.41429 .26536 L

.42381 .26756 L

.43333 .26979 L

.44286 .27208 L

.45238 .27442 L

.4619 .27681 L

.47143 .27927 L

.48095 .2818 L

.49048 .2844 L

Mistroke

.5 .28709 L

.50952 .28985 L

.51905 .29269 L

.52857 .29563 L

.5381 .29864 L

.54762 .30175 L

.55714 .30493 L

.56667 .30819 L

.57619 .31151 L

.58571 .3149 L

.59524 .31834 L

.60476 .32182 L

.61429 .32533 L

.62381 .32885 L

.63333 .33237 L

.64286 .33589 L

.65238 .33937 L

.6619 .34282 L

.67143 .34622 L

.68095 .34955 L

.69048 .3528 L

.7 .35597 L

.70952 .35905 L

.71905 .36203 L

.72857 .3649 L

.7381 .36768 L

.74762 .37036 L

.75714 .37294 L

.76667 .37543 L

.77619 .37784 L

.78571 .38017 L

.79524 .38244 L

.80476 .38464 L

.81429 .38679 L

.82381 .38889 L

.83333 .39095 L

.84286 .39297 L

.85238 .39497 L

.8619 .39695 L

.87143 .3989 L

.88095 .40084 L

.89048 .40277 L

.9 .40469 L

.90952 .40661 L

.91905 .40853 L

.92857 .41044 L

.9381 .41236 L

.94762 .41429 L

.95714 .41622 L

.96667 .41816 L

Mistroke

.97619 .42012 L

Mfstroke

.02381 .23661 m

.03333 .23665 L

.04286 .23675 L

.05238 .23691 L

.0619 .23715 L

.07143 .23745 L

.08095 .23783 L

.09048 .23828 L

.1 .23881 L

.10952 .23942 L

.11905 .24012 L

.12857 .24091 L

.1381 .2418 L

.14762 .24281 L

.15714 .24395 L

.16667 .24523 L

.17619 .2467 L

.18571 .24837 L

.19524 .25029 L

.20476 .25254 L

.21429 .25518 L

.22381 .25831 L

.23333 .26205 L

.24286 .26651 L

.25238 .27175 L

.2619 .27777 L

.27143 .28446 L

.28095 .29165 L

.29048 .29907 L

.3 .30646 L

.30952 .31355 L

.31905 .32009 L

.32857 .32592 L

.3381 .33094 L

.34762 .33518 L

.35714 .33873 L

.36667 .34172 L

.37619 .34428 L

.38571 .3465 L

.39524 .34847 L

.40476 .35026 L

.41429 .35191 L

.42381 .35345 L

.43333 .35492 L

.44286 .35633 L

.45238 .3577 L

.4619 .35904 L

.47143 .36037 L

.48095 .36169 L

.49048 .36301 L

Mistroke

.5 .36433 L

.50952 .36566 L

.51905 .36701 L

.52857 .36838 L

.5381 .36977 L

.54762 .37119 L

.55714 .37264 L

.56667 .37413 L

.57619 .37566 L

.58571 .37723 L

.59524 .37885 L

.60476 .38053 L

.61429 .38227 L

.62381 .38408 L

.63333 .38596 L

.64286 .38792 L

.65238 .38997 L

.6619 .39212 L

.67143 .39436 L

.68095 .39671 L

.69048 .39917 L

.7 .40175 L

.70952 .40444 L

.71905 .40725 L

.72857 .41016 L

.7381 .41318 L

.74762 .41629 L

.75714 .41949 L

.76667 .42276 L

.77619 .42608 L

.78571 .42944 L

.79524 .43283 L

.80476 .43622 L

.81429 .43959 L

.82381 .44294 L

.83333 .44624 L

.84286 .44947 L

.85238 .45262 L

.8619 .45568 L

.87143 .45864 L

.88095 .46148 L

.89048 .4642 L

.9 .4668 L

.90952 .46928 L

.91905 .47164 L

.92857 .47389 L

.9381 .47603 L

.94762 .47807 L

.95714 .48002 L

.96667 .48189 L

Mistroke

.97619 .48368 L

Mfstroke

.02381 .34684 m

.03333 .34685 L

.04286 .3469 L

.05238 .34697 L

.0619 .34708 L

.07143 .34721 L

.08095 .34738 L

.09048 .34758 L

.1 .34781 L

.10952 .34807 L

.11905 .34837 L

.12857 .3487 L

.1381 .34908 L

.14762 .34949 L

.15714 .34995 L

.16667 .35045 L

.17619 .35101 L

.18571 .35162 L

.19524 .35229 L

.20476 .35304 L

.21429 .35386 L

.22381 .35478 L

.23333 .35582 L

.24286 .35699 L

.25238 .35832 L

.2619 .35986 L

.27143 .36165 L

.28095 .36378 L

.29048 .36633 L

.3 .36941 L

.30952 .37315 L

.31905 .37766 L

.32857 .383 L

.3381 .38913 L

.34762 .39591 L

.35714 .40313 L

.36667 .4105 L

.37619 .41774 L

.38571 .42458 L

.39524 .43079 L

.40476 .4362 L

.41429 .44078 L

.42381 .44457 L

.43333 .44771 L

.44286 .4503 L

.45238 .45248 L

.4619 .45435 L

.47143 .45597 L

.48095 .45742 L

.49048 .45872 L

Mistroke

.5 .45992 L

.50952 .46104 L

.51905 .4621 L

.52857 .4631 L

.5381 .46407 L

.54762 .46502 L

.55714 .46594 L

.56667 .46685 L

.57619 .46775 L

.58571 .46864 L

.59524 .46954 L

.60476 .47043 L

.61429 .47133 L

.62381 .47224 L

.63333 .47316 L

.64286 .47409 L

.65238 .47503 L

.6619 .47599 L

.67143 .47697 L

.68095 .47798 L

.69048 .479 L

.7 .48006 L

.70952 .48114 L

.71905 .48226 L

.72857 .48342 L

.7381 .48462 L

.74762 .48586 L

.75714 .48715 L

.76667 .4885 L

.77619 .48991 L

.78571 .49139 L

.79524 .49295 L

.80476 .49459 L

.81429 .49632 L

.82381 .49815 L

.83333 .50008 L

.84286 .50213 L

.85238 .50431 L

.8619 .50661 L

.87143 .50904 L

.88095 .5116 L

.89048 .51429 L

.9 .51711 L

.90952 .52004 L

.91905 .52308 L

.92857 .52621 L

.9381 .52941 L

.94762 .53267 L

.95714 .53597 L

.96667 .53929 L

Mistroke

.97619 .54261 L

Mfstroke

.02381 .45695 m

.03333 .45696 L

.04286 .45698 L

.05238 .45702 L

.0619 .45708 L

.07143 .45715 L

.08095 .45723 L

.09048 .45734 L

.1 .45746 L

.10952 .4576 L

.11905 .45775 L

.12857 .45792 L

.1381 .45812 L

.14762 .45833 L

.15714 .45856 L

.16667 .45881 L

.17619 .45908 L

.18571 .45938 L

.19524 .4597 L

.20476 .46005 L

.21429 .46043 L

.22381 .46084 L

.23333 .46128 L

.24286 .46176 L

.25238 .46229 L

.2619 .46286 L

.27143 .46349 L

.28095 .46419 L

.29048 .46496 L

.3 .46582 L

.30952 .4668 L

.31905 .46791 L

.32857 .4692 L

.3381 .4707 L

.34762 .47248 L

.35714 .47463 L

.36667 .47723 L

.37619 .48043 L

.38571 .48433 L

.39524 .48905 L

.40476 .49462 L

.41429 .50096 L

.42381 .50789 L

.43333 .51516 L

.44286 .52248 L

.45238 .52956 L

.4619 .53613 L

.47143 .54198 L

.48095 .54699 L

.49048 .55116 L

Mistroke

.5 .55458 L

.50952 .55737 L

.51905 .55966 L

.52857 .56157 L

.5381 .56319 L

.54762 .56459 L

.55714 .56581 L

.56667 .56691 L

.57619 .5679 L

.58571 .56882 L

.59524 .56967 L

.60476 .57047 L

.61429 .57123 L

.62381 .57196 L

.63333 .57267 L

.64286 .57336 L

.65238 .57403 L

.6619 .57469 L

.67143 .57534 L

.68095 .57599 L

.69048 .57663 L

.7 .57728 L

.70952 .57792 L

.71905 .57856 L

.72857 .57921 L

.7381 .57987 L

.74762 .58053 L

.75714 .5812 L

.76667 .58188 L

.77619 .58257 L

.78571 .58327 L

.79524 .58398 L

.80476 .58471 L

.81429 .58546 L

.82381 .58622 L

.83333 .58701 L

.84286 .58782 L

.85238 .58865 L

.8619 .58951 L

.87143 .59039 L

.88095 .59131 L

.89048 .59227 L

.9 .59327 L

.90952 .59431 L

.91905 .5954 L

.92857 .59654 L

.9381 .59775 L

.94762 .59902 L

.95714 .60037 L

.96667 .6018 L

Mistroke

.97619 .60332 L

Mfstroke

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{602, 371.875},

  ImageMargins->{{44, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  FontSize->14,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009J0001L`P10`40000100000800002008200000

P800P020P<30`<3L`:K:l00003<006H009T00<`00?l0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV

09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<003o03?o06Ko09Wo0<co

0?oo0000<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I

<c>I<fJI<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0

IYT0I/`0I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bI

I_nIIP3<IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0c

VC<cVFHcVITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<

VIW<VLc<VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`c

c?lcc01Vc3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03o

c3?oc6Koc9Woc<coc?ooc000oc<0ofH0oiT0ol`0ool0o`0coc<cofHcoiTcol`coolco`1Voc=VofIV

oiUVolaVoomVo`2Ioc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<o`3ooc?oofKooiWoolco

ooooo`0000410@820P<30`@410D51@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C

4a@D5?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooooQon5Lh@00Z>4300?Q00<0hN40CN4300;Q

00<0hN40C>4200CQ00<0hN40CN400`3Qh@02h@030>7Q04SQ1@02h@030>7Q00;Q00<0hN40Dn400:SQ

00<0hN400^400`3Q001?h@060>7Q0>40CN400`3Q0002h@030>4004gQ00<0h@000^400`3Q001;h@07

0>7Qh@3Q0002h@030>4005CQ002Yh@070>7Qh@3Q001=h@@000CQ0>40CN400`3Q0002h@030>4004gQ

00<0h@000^400`3Q001;h@070>7Qh@3Q0002h@030>4005CQ002Yh@070>7Qh@3Q001=h@030>4000;Q

00<0h@00CN4200?Q00<0h@00C^401`3QhN40h@00Bn401`3QhN40h@000^400`3Q001Dh@00Z>400`3Q

0002h@030>4004kQ0P02h@030>4004gQ00<0hN400^400`3Q001=h@030>4000;Q00<0h@00Bn401`3Q

hN40h@000^400`3Q001Dh@00ZN400`3Qh@02h@030>7Q04kQ00D0hN7Q001?h@800n400`3Qh@1=h@03

0>7Q00;Q00<0hN40BN4200CQ00<0hN400^400`3Qh@1Ch@00on7ohEcQ003ohOoQG>400?oQon5Lh@00

on7ohEcQ003ohOoQG>400?oQon4Jh@8000?Q0000?N400?oQon4Kh@030>4003kQ001<hOl0`@0=h@<0

?^4006cQ00<0hN404^400`3Qh@0Ch@030>7Q01;Q00<0hN404^400`3Qh@0Bh@030>7Q01?Q00<0hN40

4^400`3Qh@0Bh@030>7Q01;Q00<0hN404n400`3Qh@0Bh@030>7Q01;Q00<0hN404^400`3Qh@0Ch@03

0>7Q01;Q00<0hN404^400`3Qh@0Bh@030>7Q01?Q00<0hN404^400`3Qh@0Fh@040>4003gQ001/h@03

0>7Q01;Q00<0hN404n400`3Qh@0Bh@030>7Q01;Q00<0hN404^400`3Qh@0Ch@030>7Q01;Q00<0hN40

4^400`3Qh@0Bh@030>7Q01?Q00<0hN404^400`3Qh@0Bh@030>7Q01;Q00<0hN404n400`3Qh@0Bh@03

0>7Q01;Q00<0hN404^400`3Qh@0Ch@030>7Q01;Q00<0hN405^400`3Qh@0nh@00[>400`3Qh@1Bh@03

0>7Q05;Q00<0hN40D^400`3Qh@1Bh@030>7Q01GQ0P10h@00on7ohEcQ003ohOoQG>400?oQon5Lh@00

on7ohEcQ003ohOoQG>400?oQon5Lh@00on7ohEcQ003ohOoQG>400?oQon5Lh@00on7ohEcQ003ohOoQ

G>400?oQon5Lh@00on7ohEcQ003ohOoQG>400?oQon5Lh@00on7ohEcQ003ohOoQG>400?oQon5Lh@00

on7ohEcQ003ohOoQG>400?oQon5Lh@00on7ohEcQ003ohOoQG>400?oQon5Lh@00on7ohEcQ003ohOoQ

G>400?oQon5Lh@00on7ohEcQ003ohOoQG>400?oQon5Lh@00on7ohEcQ003ohOoQG>400?oQon5Lh@00

on7ohEcQ003ohOoQG>400?oQon5Lh@00on7ohEcQ003ohOoQG>400?oQon5Lh@00on7ohEcQ003ohOoQ

G>400?oQon5Lh@00on7ohEcQ003ohOoQG>400?oQon5Lh@00on7ohEcQ003ohOoQG>400?oQon5Lh@00

on7ohEcQ001Gh@030>7Q0?oQon42h@00En400`3Qh@3ohOoQ0^4005OQ0`3ohOoQ0^4005OQ00<0hN40

on7oh@;Q001Gh@030>7Q0?oQon42h@00En400`3Qh@3ohOoQ0^4005OQ00<0hN40on7oh@;Q001Gh@H0

on7nh@00En400`3Qh@03h@D0on7ih@00En400`3Qh@08h@<0on7fh@00En4300_Q0P3ohOCQ001Gh@03

0>7Q00gQ0P3ohO;Q001Gh@030>7Q00oQ00<0hN40on7_h@00En400`3Qh@0@h@80on7_h@00En400`3Q

h@0Bh@030>7Q0?oQk>4005OQ00<0hN404n420?oQk>4005OQ00<0hN405N420?oQj^4005OQ0`0Gh@80

on7Xh@00En400`3Qh@0Ih@80on7Vh@00En400`3Qh@0Kh@030>7Q0?oQhn4005OQ00<0hN407>400`3Q

h@3ohN;Q001Gh@030>7Q01gQ0P3ohN;Q001Gh@030>7Q01oQ00<0hN40on7Oh@00C^400`3Qh@06h@03

0>7Q023Q00<0hN40on7Nh@00CN400`3Q0007h@030>7Q027Q00<0hN40on7Mh@00Cn400`3Qh@05h@@0

8N400`3Qh@3ohMcQ001=h@802>400`3Qh@0Sh@030>7Q0?oQfn4004gQ00<0hN401n400`3Qh@0Th@03

0>7Q0?oQf^4004gQ0`07h@030>7Q02GQ0P3ohM[Q001Gh@030>7Q02OQ00<0hN40on7Gh@00En400`3Q

h@0Xh@030>7Q0?oQe^4005OQ00<0hN40:N420?oQe^4005OQ00<0hN40:n400`3Qh@3ohM?Q001Gh@<0

;>400`3Qh@3ohM;Q001Gh@030>7Q02gQ00<0hN40on7Ah@00En400`3Qh@0^h@030>7Q0?oQd>4005OQ

00<0hN40;n400`3Qh@3ohLoQ001Gh@030>7Q033Q00<0hN40on7>h@00En400`3Qh@0ah@030>7Q0?oQ

cN4005OQ00<0hN40<^420?oQcN4005OQ00<0hN40=>400`3Qh@3ohL[Q001Gh@<0=N400`3Qh@3ohLWQ

001Gh@030>7Q03KQ00<0hN40on78h@00En400`3Qh@0gh@030>7Q0?oQan4005OQ00<0hN40>>400`3Q

h@3ohLKQ001Gh@030>7Q03WQ0P3ohLKQ001Gh@030>7Q03_Q0P3ohLCQ001Gh@030>7Q03gQ00<0hN40

on71h@00En400`3Qh@0nh@030>7Q0?oQ`>4005OQ0`0oh@80on70h@00En400`3Qh@11h@030>7Q0?oQ

_N4005OQ00<0hN40@^400`3Qh@3ohKcQ001Gh@030>7Q04?Q0P3ohKcQ001Gh@030>7Q04GQ00<0hN40

on6ih@00En400`3Qh@16h@030>7Q0?oQ^>4005OQ00<0hN40An420?oQ^>4005OQ00<0hN40BN420?oQ

]^4005OQ3`0oh@80on6dh@00En400`3Qh@0<h@d0=>420?oQ/^4005OQ00<0hN406N4403;Q0P3ohK3Q

001Gh@030>7Q01gQ100`h@80on6^h@00En400`3Qh@0Qh@@0;^420?oQ[>4004CQ00<0hN400^400`3Q

h@02h@030>7Q00KQ00<0hN409N4502_Q0P3ohJ[Q0014h@030>7Q00KQ00<0h@001n400`3Qh@0Zh@@0

:N420?oQZ>4004CQ00<0hN402>400`3Qh@05h@@0;N4302SQ0`3ohJGQ0015h@030>7Q00GQ0P08h@03

0>7Q037Q0P0Yh@80on6Sh@00@n400`3Q0007h@030>7Q00OQ00<0hN40<n4202WQ0`3ohJ3Q0013h@<0

1n4300OQ00<0hN40=N4202[Q0`3ohIgQ001Gh@030>7Q03OQ0`0Zh@80on6Kh@00En400`3Qh@0jh@80

:^420?oQVN4005OQ00<0hN40?>4202[Q0P3ohIOQ001Gh@030>7Q03kQ0P0Zh@@0on6Ch@00En43043Q

0P0/h@<0on6@h@00En400`3Qh@12h@030>7Q02cQ0P3ohHkQ001Gh@030>7Q04?Q0P0^h@80on6<h@00

En400`3Qh@15h@030>7Q02gQ0P3ohH[Q001Gh@030>7Q04KQ00<0hN40;^430?oQQn4005OQ00<0hN40

An42037Q103ohH?Q001Gh@030>7Q04WQ00<0hN40<^420?oQPN4005OQ00<0hN40B^4203CQ0P3ohGoQ

001Gh@<0C>4203CQ0P3ohGgQ001Gh@030>7Q04kQ00<0hN40<n430?oQN^4005OQ00<0hN40Cn400`3Q

h@0eh@<0on5gh@00En400`3Qh@1@h@030>7Q03OQ0P3ohGGQ001Gh@030>7Q057Q00<0hN40>>430?oQ

L^4005OQ00<0hN40D^400`3Qh@0jh@80on5`h@00En400`3Qh@1Ch@030>7Q03_Q0`3ohFgQ001Gh@03

0>7Q05CQ0P0nh@<0on5Zh@00En4305KQ00<0hN40?^420?oQJ>4005OQ00<0hN40En400`3Qh@0oh@80

on5Vh@00En400`3Qh@1Hh@80@N420?oQI>4005OQ00<0hN40F^400`3Qh@10h@@0on5Ph@00En400`3Q

h@1Kh@80A>430?oQGN4005OQ00<0hN40GN4204GQ0P3ohE_Q001Gh@030>7Q05oQ00<0hN40A>420?oQ

FN4005OQ00<0hN40H>400`3Qh@15h@80on5Gh@00En43067Q0P17h@80on5Eh@00En400`3Qh@1Sh@03

0>7Q04KQ0P3ohE?Q001Gh@030>7Q06CQ00<0hN40An440?oQCn4005OQ00<0hN40IN4204_Q0`3ohDcQ

001Gh@030>7Q06OQ00<0hN40Bn420?oQB^4004OQ1@02h@030>7Q00KQ00<0hN40J>4204gQ0P3ohDSQ

0019h@070>7Qh@3Q0007h@030>7Q06[Q0`1<h@80on56h@00BN401`3QhN40h@001n4406cQ0P1<h@80

on54h@00BN401`3QhN40h@001n400`3Qh@1_h@<0Bn420?oQ@^4004WQ00L0hN7Q0>4000OQ00<0hN40

L^4304[Q103ohCkQ0018h@801>400`3Qh@06hAL0HN4204cQ0`3ohC_Q001Gh@030>7Q01CQ4@1Bh@<0

C>420?oQ>N4005OQ00<0hN409N4=04SQ1@19h@80on4gh@00En400`3Qh@0bh@T0A>4404OQ0P3ohCGQ

001Gh@030>7Q03_Q1014h@@0AN430?oQ<^4005OQ0`0oh@P0@>4404CQ103ohBkQ001Gh@030>7Q04OQ

1@0oh@D0@n420?oQ;>4005OQ00<0hN40C>44043Q1011h@<0on4Yh@00En400`3Qh@1@h@<0@N44043Q

0`3ohBKQ001Gh@030>7Q05?Q0P13h@@0?n420?oQ9>4005OQ00<0hN40EN4304CQ1@0lh@80on4Rh@00

En400`3Qh@1Hh@@0AN4403[Q0P3ohB3Q001Gh@030>7Q05cQ0P17h@@0>>440?oQ7>4005OQ0`1Nh@80

BN4403SQ103ohASQ001Gh@030>7Q063Q00<0hN40B^4503OQ0`3ohAGQ001Gh@030>7Q067Q0P1?h@@0

=^420?oQ4n4005OQ00<0hN40Hn400`3Qh@1@h@@0=>430?oQ4>4005OQ00<0hN40I>4205CQ100ch@@0

on4<h@00En400`3Qh@1Vh@80E^4503;Q0P3oh@[Q001Gh@030>7Q06SQ00<0hN40F>44033Q0`3oh@OQ

001Gh@030>7Q06WQ0P1Lh@@0;n440?oQ0n4005OQ0`1[h@030>7Q05gQ0`0`h@<0on4005OQ00<0hN40

K>400`3Qh@1Oh@80<N420?gQ001Gh@030>7Q06gQ0P1Qh@@0;n440?WQ001Gh@030>7Q06oQ00<0hN40

H^4402oQ103eh@00En400`3Qh@1`h@030>7Q06GQ100_h@<0l^4005OQ00<0hN40LN400`3Qh@1Xh@<0

;n420?3Q001Gh@030>7Q07;Q0P1[h@80;n430>gQ001Gh@030>7Q07CQ00<0hN40J^4402kQ1@3Xh@00

En4307GQ00<0hN40KN43033Q103Th@00En400`3Qh@1fh@80L>4203;Q103Ph@00En400`3Qh@1hh@03

0>7Q06oQ0`0ch@<0gN4005OQ00<0hN40NN400`3Qh@1ah@<0<n420=_Q001Gh@030>7Q07[Q0P1dh@80

<n440=OQ000mh@D000CQ00000n400`3Qh@02h@030>7Q00KQ00<0hN40O>400`3Qh@1ch@@0<n440=?Q

000oh@050>7Qh@002N400`3Q0007h@030>7Q07gQ0P1gh@<0=>440<oQ000oh@030>7Q00;Q00<0hN40

2>400`3Qh@05h@@0O^4207SQ0P0fh@@0bn4003oQ00<0hN400^400`3Qh@06h@802>400`3Qh@21h@03

0>7Q07OQ0`0gh@D0a^4003oQ00L0hN7Q0>4000OQ00<0hN401n400`3Qh@22h@030>7Q07WQ0`0ih@<0

`n4003kQ0P04h@030>7Q00KQ0`07h@030>7Q08?Q0P1lh@80>^420<7Q001Gh@030>7Q08GQ00<0hN40

Nn4403SQ0`2nh@00En400`3Qh@26h@80On4303SQ102jh@00En400`3Qh@28h@80P>4203[Q1@2eh@00

En400`3Qh@2:h@80P>4303cQ102ah@00En4308cQ0`20h@<0?N440:gQ001Gh@030>7Q08oQ0P21h@80

?n430:[Q001Gh@030>7Q097Q0`20h@@0?^420:SQ001Gh@030>7Q09CQ1020h@<0?N440:CQ001Gh@03

0>7Q09SQ101oh@80?n440:3Q001GhAL0R>4507cQ0P11h@@0W>4005OQ00<0hN405>4R06_Q101jh@80

@n4409SQ001Gh@030>7Q03KQ4@1Nh@@0N>4304CQ1@2Ch@00En4304OQ3@1Eh@T0L^4504CQ0`2@h@00

En400`3Qh@1Dh@T0EN4407?Q0`14h@80S^4005OQ00<0hN40GN48057Q201^h@80A>4308_Q001Gh@03

0>7Q06GQ101Eh@T0In4304CQ1027h@00En400`3Qh@1Yh@D0FN4406KQ1014h@D0P^4005OQ00<0hN40

K^4405WQ2@1Qh@@0AN4407kQ001Gh@030>7Q07;Q101Nh@P0GN4204OQ101jh@00En400`3Qh@1fh@<0

Hn4405_Q0`18h@@0M^4005OQ0`1ih@80IN4905GQ1018h@@0L^4005OQ00<0hN40Nn4306_Q201Ah@@0

B>42073Q001Gh@030>7Q07kQ0P1ah@D0D>4504GQ0`1]h@00En400`3Qh@20h@80M>44057Q1014h@@0

JN4005OQ00<0hN40P^4207KQ201=h@@0A>4406GQ001Gh@030>7Q08CQ0P1lh@D0C>4404CQ1@1Ph@00

En400`3Qh@26h@030>7Q07kQ101<h@D0A>4405cQ001Gh@030>7Q08OQ0P22h@@0CN4404CQ0`1Ih@00

En4308WQ00<0hN40Pn4404gQ102Lh@00En400`3Qh@2:h@030>7Q08KQ1@1<h@@0V>4005OQ00<0hN40

Rn4208_Q101<h@D0Tn4005OQ00<0hN40SN400`3Qh@2<h@@0CN4408oQ001Gh@030>7Q08kQ0P2@h@@0

CN4408_Q0017h@D00^400`3Qh@06h@030>7Q093Q0P2Bh@D0C>4908;Q0019h@070>7Qh@3Q0007h@03

0>7Q09;Q00<0hN40U>44057Q101nh@00BN400`3Qh@03h@030>7Q00GQ102Bh@030>7Q09OQ101Ah@@0

N^4004WQ00@0hN7Q0P08h@030>7Q09CQ00<0hN40V^4305;Q101fh@00BN401@3QhN4000WQ00<0hN40

UN400`3Qh@2Lh@80E>45077Q0018h@800n4300OQ00<0hN40U^400`3Qh@2Mh@@0EN4406gQ001Gh@03

0>7Q09OQ00<0hN40X>4405GQ201Uh@00En400`3Qh@2Hh@80Y>4305[Q1@1Ph@00En400`3Qh@2Jh@03

0>7Q0:CQ0P1Mh@@0G>4005OQ00<0hN40Vn400`3Qh@2Uh@<0G^4305WQ001Gh@<0W>420:SQ102fh@00

En400`3Qh@2Nh@030>7Q0:WQ0P2dh@00En400`3Qh@2Oh@80Zn430;7Q001Gh@030>7Q0:7Q0P2/h@<0

[^4005OQ00<0hN40Xn400`3Qh@2/h@80[>4005OQ00<0hN40Y>420:kQ0`2Yh@00En400`3Qh@2Vh@80

[n440:GQ001Gh@030>7Q0:SQ0P2ah@80Xn4005OQ0`2Zh@80/N430:3Q001Gh@030>7Q0:cQ0P2bh@<0

WN4005OQ00<0hN40[^440;7Q0P2Kh@00En400`3Qh@2bh@@0[n4309SQ001Gh@030>7Q0;KQ102^h@@0

U>4005OQ00<0hN40^^440:kQ0P2Bh@00En400`3Qh@2nh@D0Zn4308oQ001GhA<0/n440:[Q102;h@00

En43013Q<`24h@P0Y^4408OQ001Gh@030>7Q04?Q6P1bh@T0XN4408?Q001Gh@030>7Q05gQ4@1Zh@P0

WN42087Q001Gh@030>7Q06kQ301Vh@d0T^4307kQ001Gh@030>7Q07[Q2@1Zh@T0S>4407[Q001Gh@03

0>7Q08?Q101_h@`0Q>4407KQ001Gh@030>7Q08OQ2@1bh@T0On45077Q001Gh@030>7Q093Q101gh@P0

O>4406gQ001Gh@<0U>4307cQ3@1ch@@0JN4005OQ00<0hN40Un4208OQ2@1^h@@0IN4005OQ00<0hN40

VN4208kQ201Zh@D0H>4005OQ00<0hN40Vn4209CQ2@1Vh@L0FN4005OQ00<0hN40WN4309[Q202nh@00

En400`3Qh@2Ph@80X>440;[Q000mh@D00^400`3Qh@02h@030>7Q00;Q00<0hN401^400`3Qh@2Rh@80

X^490;7Q000oh@030>7Q00;Q00<0hN401^400`3Q0007h@030>7Q0:CQ0P2Yh@@0[N4003oQ00<0hN40

0^400`3Qh@08h@030>7Q00GQ102Uh@80Zn490:CQ000oh@030>7Q00?Q00<0hN401N4200SQ00<0hN40

Z>400`3Qh@2ah@@0X>4003oQ00L0hN7Q0>4000OQ00<0hN401n400`3Qh@2Yh@80]N4409cQ000nh@80

0n4300OQ0`07h@030>7Q0:_Q00<0hN40]^4409SQ001Gh@030>7Q0:cQ00<0hN40^N4509?Q001Gh@03

0>7Q0:gQ0P2nh@@0Sn4005OQ00<0hN40[n400`3Qh@2oh@@0Rn4005OQ0`2`h@80`n4408OQ001Gh@03

0>7Q0;;Q0P35h@D0P^4005OQ00<0hN40]>400`3Qh@37h@@0O^4005OQ00<0hN40]N400`3Qh@3:h@<0

Nn4005OQ00<0hN40]^400`3Qh@3<h@80NN4005OQ00<0hN40]n400`3Qh@3=h@<0M^4005OQ00<0hN40

^>400`3Qh@3?h@D0LN4005OQ00<0hN40^N400`3Qh@3Ch@<0K^4005OQ0`2jh@80e^4206cQ001Gh@03

0>7Q0;cQ00<0hN40eN4306WQ001Gh@030>7Q0;gQ00<0hN40en4306KQ001Gh@030>7Q0;kQ0P3Jh@80

I>4005OQ00<0hN40`>420=[Q101Ph@00En400`3Qh@32h@80g>4305gQ001Gh@030>7Q0<CQ0P3Mh@80

Fn4005OQ00<0hN40a^400`3Qh@3Lh@80FN4005OQ0`37h@80on4hh@00En400`3Qh@39h@80on4fh@00

En400`3Qh@3;h@<0on4ch@00En400`3Qh@3>h@80on4ah@00En400`3Qh@3@h@@0on4]h@00En400`3Q

h@3Dh@@0on4Yh@00En400`3Qh@3Hh@@0on4Uh@00En400`3Qh@3Lh@@0on4Qh@00En430>3Q2@3ohASQ

001Gh@030>7Q0>WQ103ohACQ001Gh@030>7Q0>gQ3@3oh@OQ001Gh@030>7Q0?[Q3@3ih@00En400`3Q

h@3oh@SQ303]h@00En400`3Qh@3ohACQ3@3Ph@00B>4300?Q00<0hN401^400`3Qh@3ohB7Q4@3?h@00

B>400`3Qh@02h@030>4000OQ00<0hN40on4bh@d0`^4004WQ00L0hN7Q0>4000OQ103ohCkQ3@2eh@00

BN401`3QhN40h@001n400`3Qh@3ohDcQ4@2Th@00B>400`3Q0002h@030>4000OQ00<0hN40on5Mh@`0

V>4004WQ00<0hN400^400`3Qh@06h@030>7Q0?oQJN4908oQ001Gh@030>7Q0?oQL^4=08;Q001Gh@03

0>7Q0?oQOn4807[Q001Gh@030>7Q0?oQQn49077Q001Gh@<0on6@h@P0JN4005OQ00<0hN40on6Hh@T0

H>4005OQ00<0hN40on6Qh@@0G>4005OQ00<0hN40on6Uh@<0FN4005OQ00<0hN40on7oh@;Q001Gh@03

0>7Q0?oQon42h@00En400`3Qh@3ohOoQ0^4005OQ00<0hN40on7oh@;Q001Gh@<0on7oh@;Q001Gh@03

0>7Q0?oQon42h@00on7ohEcQ003ohOoQG>400?oQon5Lh@00on7ohEcQ003ohOoQG>400?oQon5Lh@00

on7ohEcQ003ohOoQG>400?oQon5Lh@00on4Uh@8000?Q0>400n400`3Qh@04h@030>7Q0?oQ9N400?oQ

9^400`3Q0003h@030>7Q00KQ00<0hN40on4Th@00on4Qh@@000CQ0>400^400`3Qh@020003h@0000?Q

00<0hN40on4Sh@00on4Qh@<00n401@3QhN4000?Q00<0h@001>400`3Qh@3ohB?Q003ohB?Q00<0hN40

1N40103QhN4300CQ00<0hN40on4Sh@00on4Rh@801n401P3QhN40h@800n400`3Qh@3ohB?Q003ohBcQ

00@0hN401N400`3Qh@3ohBCQ001Eh@@0dn4300CQ00<0hN40on4Uh@00EN430?oQon44h@00En400`3Q

h@3ohOoQ0^4005KQ0P3ohOoQ1>400?oQon5Lh@00on7ohEcQ003ohOoQG>400?oQon5Lh@00on7ohEcQ

003ohOoQG>400?oQon5Lh@00\

\>"],

  ImageRangeCache->{{{74.25, 554.813}, {381, 84.5}} -> {-42.4148, 5.83387, 

  0.235412, 0.064076}}]

}, Open  ]]

}, Open  ]],



Cell[CellGroupData[{



Cell[TextData[StyleBox["2.3 The Shooting Method for the Buckled Plate",

  FontSize->18]], "Subsection",

  FontSize->18],



Cell[TextData[{

  "Associated with the BVP (2.1)-(2.3) is the following IVP in the form of \

six first \norder differential equations and six initial conditions,\n\nq' = \

q1,\np' = p1,\nW' = W1,\nq1' + ",

  Cell[BoxData[

      FormBox[

        FractionBox["3", 

          StyleBox["r",

            FontSize->16]], TraditionalForm]]],

  "q1 + ",

  Cell[BoxData[

      \(TraditionalForm\`a\^2\)]],

  "pq = ",

  Cell[BoxData[

      \(TraditionalForm\`k\^2\)]],

  "W,\n\np1' +  ",

  Cell[BoxData[

      FormBox[

        FractionBox["3", 

          StyleBox["r",

            FontSize->16]], TraditionalForm]]],

  "p1 = ",

  Cell[BoxData[

      \(TraditionalForm\`1\/2\)]],

  Cell[BoxData[

      FormBox[

        SuperscriptBox[

          StyleBox["q",

            FontSlant->"Plain"], "2"], TraditionalForm]]],

  ",                                                                          \

        (2.9)\n\nW1' + ",

  Cell[BoxData[

      FormBox[

        FractionBox["3", 

          StyleBox["r",

            FontSize->16]], TraditionalForm]]],

  "W1 + q = 0,\nq1(0) = 0,  p1(0) = 0,  W1(0) = 0,\nq(0) = ",

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox["q",

            FontSlant->"Plain"], "0"], TraditionalForm]]],

  ",  p(0) = ",

  Cell[BoxData[

      FormBox[

        RowBox[{

          SubscriptBox[

            StyleBox["p",

              FontSlant->"Plain"], 

            StyleBox["0",

              FontSize->12]], ","}], TraditionalForm]]],

  "  W(0) = ",

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox["W",

            FontSlant->"Plain"], "0"], TraditionalForm]]],

  ".\n\nA solution {q(",

  StyleBox["r",

    FontSlant->"Italic"],

  ",",

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox["q",

            FontSlant->"Plain"], "0"], TraditionalForm]]],

  ",",

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox["p",

            FontSlant->"Plain"], 

          StyleBox["0",

            FontSize->12]], TraditionalForm]]],

  ",",

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox["W",

            FontSlant->"Plain"], "0"], TraditionalForm]]],

  "), p(",

  StyleBox["r",

    FontSlant->"Italic"],

  ",",

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox["q",

            FontSlant->"Plain"], "0"], TraditionalForm]]],

  ",",

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox["p",

            FontSlant->"Plain"], 

          StyleBox["0",

            FontSize->12]], TraditionalForm]]],

  ",",

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox["W",

            FontSlant->"Plain"], "0"], TraditionalForm]]],

  "), W(",

  StyleBox["r",

    FontSlant->"Italic"],

  ",",

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox["q",

            FontSlant->"Plain"], "0"], TraditionalForm]]],

  ",",

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox["p",

            FontSlant->"Plain"], 

          StyleBox["0",

            FontSize->12]], TraditionalForm]]],

  ",",

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox["W",

            FontSlant->"Plain"], "0"], TraditionalForm]]],

  ")} of this IVP will be a\nsolution of the BVP if ",

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox["q",

            FontSlant->"Plain"], "0"], TraditionalForm]]],

  ", ",

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox["p",

            FontSlant->"Plain"], 

          StyleBox["0",

            FontSize->12]], TraditionalForm]]],

  ", and ",

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox["W",

            FontSlant->"Plain"], "0"], TraditionalForm]]],

  " satisfy (2.3). That is, if\n\nF(",

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox["q",

            FontSlant->"Plain"], "0"], TraditionalForm]]],

  ",",

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox["p",

            FontSlant->"Plain"], 

          StyleBox["0",

            FontSize->12]], TraditionalForm]]],

  ",",

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox["W",

            FontSlant->"Plain"], "0"], TraditionalForm]]],

  ") = ",

  Cell[BoxData[

      FormBox[

        RowBox[{"(", GridBox[{

              {

                RowBox[{

                  StyleBox["q",

                    FontSlant->"Plain"], "(", 

                  RowBox[{"1", ",", 

                    FormBox[

                      SubscriptBox[

                        StyleBox["q",

                          FontSlant->"Plain"], "0"],

                      "TraditionalForm"], ",", 

                    FormBox[

                      SubscriptBox[

                        StyleBox["p",

                          FontSlant->"Plain"], 

                        StyleBox["0",

                          FontSize->12]],

                      "TraditionalForm"], ",", 

                    FormBox[

                      SubscriptBox[

                        StyleBox["W",

                          FontSlant->"Plain"], "0"],

                      "TraditionalForm"]}], ")"}]},

              {

                RowBox[{"                         ", 

                  RowBox[{

                    RowBox[{

                      RowBox[{

                        StyleBox["p",

                          FontSlant->"Plain"], "(", 

                        RowBox[{"1", ",", 

                          FormBox[

                            SubscriptBox[

                              StyleBox["q",

                                FontSlant->"Plain"], "0"],

                            "TraditionalForm"], ",", 

                          FormBox[

                            SubscriptBox[

                              StyleBox["p",

                                FontSlant->"Plain"], 

                              StyleBox["0",

                                FontSize->12]],

                            "TraditionalForm"], ",", 

                          FormBox[

                            SubscriptBox[

                              StyleBox["W",

                                FontSlant->"Plain"], "0"],

                            "TraditionalForm"]}], ")"}], "-", "1"}], "\n", 

                    RowBox[{

                      RowBox[{"W1", "(", 

                        RowBox[{"1", ",", 

                          FormBox[

                            SubscriptBox[

                              StyleBox["q",

                                FontSlant->"Plain"], "0"],

                            "TraditionalForm"], ",", 

                          FormBox[

                            SubscriptBox[

                              StyleBox["p",

                                FontSlant->"Plain"], 

                              StyleBox["0",

                                FontSize->12]],

                            "TraditionalForm"], ",", 

                          FormBox[

                            SubscriptBox[

                              StyleBox["W",

                                FontSlant->"Plain"], "0"],

                            "TraditionalForm"]}], ")"}], "+", 

                      RowBox[{"2", 

                        RowBox[{

                          StyleBox["W",

                            FontSlant->"Plain"], "(", 

                          RowBox[{"1", ",", 

                            FormBox[

                              SubscriptBox[

                                StyleBox["q",

                                  FontSlant->"Plain"], "0"],

                              "TraditionalForm"], ",", 

                            FormBox[

                              SubscriptBox[

                                StyleBox["p",

                                  FontSlant->"Plain"], 

                                StyleBox["0",

                                  FontSize->12]],

                              "TraditionalForm"], ",", 

                            FormBox[

                              SubscriptBox[

                                StyleBox["W",

                                  FontSlant->"Plain"], "0"],

                              "TraditionalForm"]}], ")"}]}]}]}], "\t"}]}

              }], "\[NegativeThinSpace]", ")"}], TraditionalForm]]],

  "  = 0.        (2.10)\n\nWe wish to solve F(",

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox["q",

            FontSlant->"Plain"], "0"], TraditionalForm]]],

  ",",

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox["p",

            FontSlant->"Plain"], 

          StyleBox["0",

            FontSize->12]], TraditionalForm]]],

  ",",

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox["W",

            FontSlant->"Plain"], "0"], TraditionalForm]]],

  ") = 0 for (",

  Cell[BoxData[

      FormBox[

        RowBox[{

          RowBox[{

            FormBox[

              SubscriptBox[

                StyleBox["q",

                  FontSlant->"Plain"], "0"],

              "TraditionalForm"], ",", 

            FormBox[

              SubscriptBox[

                StyleBox["p",

                  FontSlant->"Plain"], 

                StyleBox["0",

                  FontSize->12]],

              "TraditionalForm"], ",", 

            FormBox[

              SubscriptBox[

                StyleBox["W",

                  FontSlant->"Plain"], "0"],

              "TraditionalForm"]}], ")"}], TraditionalForm]]],

  " using Newton's method.\nThis iteration scheme takes the form\n\n",

  Cell[BoxData[

      FormBox[

        SubscriptBox["Q", 

          RowBox[{

            StyleBox["n",

              FontSlant->"Plain"], "+", "1"}]], TraditionalForm]]],

  " = ",

  Cell[BoxData[

      FormBox[

        SubscriptBox["Q", 

          StyleBox["n",

            FontSlant->"Plain"]], TraditionalForm]]],

  " - ",

  Cell[BoxData[

      FormBox[

        SuperscriptBox[

          RowBox[{"(", 

            RowBox[{

              SubscriptBox["\[PartialD]", 

                StyleBox["Q",

                  FontSize->14,

                  FontSlant->"Italic"]], 

              RowBox[{"F", "(", 

                SubscriptBox["Q", 

                  StyleBox["n",

                    FontSlant->"Plain"]], ")"}]}], ")"}], \(-1\)], 

        TraditionalForm]]],

  "F(",

  Cell[BoxData[

      FormBox[

        RowBox[{

          SubscriptBox["Q", 

            StyleBox["n",

              FontSlant->"Plain"]], ")"}], TraditionalForm]]],

  ",\n\nwhere ",

  StyleBox["Q = ",

    FontSlant->"Italic"],

  Cell[BoxData[

      FormBox[

        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{

              {

                RowBox[{

                  SubscriptBox[

                    StyleBox["q",

                      FontSlant->"Plain"], "0"], "\n", 

                  SubscriptBox[

                    StyleBox["p",

                      FontSlant->"Plain"], "0"]}]},

              {

                SubscriptBox[

                  StyleBox["W",

                    FontSlant->"Plain"], "0"]}

              }], "\[NegativeThinSpace]", ")"}], TraditionalForm]]],

  " and  ",

  Cell[BoxData[

      FormBox[

        RowBox[{

          SubscriptBox["\[PartialD]", 

            StyleBox["Q",

              FontSize->14,

              FontSlant->"Italic"]], \(F(Q)\)}], TraditionalForm]]],

  " = ",

  Cell[BoxData[

      FormBox[

        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{

              {GridBox[{

                    {

                      RowBox[{

                        RowBox[{

                          SubscriptBox["\[PartialD]", 

                            SubscriptBox[

                              StyleBox["q",

                                FontSlant->"Plain"], "0"]], 

                          StyleBox["q",

                            FontSlant->"Plain"]}], 

                        StyleBox[

                          RowBox[{

                            StyleBox[" ",

                              FontSlant->"Plain"], 

                            "                      "}]]}], 

                      RowBox[{

                        SubscriptBox["\[PartialD]", 

                          SubscriptBox[

                            StyleBox["p",

                              FontSlant->"Plain"], "0"]], 

                        StyleBox["q",

                          FontSlant->"Plain"]}]}

                    }], 

                RowBox[{

                  SubscriptBox["\[PartialD]", 

                    SubscriptBox[

                      StyleBox["W",

                        FontSlant->"Plain"], "0"]], 

                  StyleBox["q",

                    FontSlant->"Plain"]}]},

              {GridBox[{

                    {GridBox[{

                          {

                            RowBox[{

                              SubscriptBox["\[PartialD]", 

                                SubscriptBox[

                                  StyleBox["q",

                                    FontSlant->"Plain"], "0"]], 

                              StyleBox["p",

                                FontSlant->"Plain"]}]},

                          {

                            RowBox[{

                              SubscriptBox["\[PartialD]", 

                                SubscriptBox[

                                  StyleBox["q",

                                    FontSlant->"Plain"], "0"]], 

                              RowBox[{"(", 

                                RowBox[{"W1", "+", 

                                  RowBox[{"2", 

                                    StyleBox["W",

                                      FontSlant->"Plain"]}]}], ")"}]}]}

                          }], GridBox[{

                          {

                            RowBox[{

                              SubscriptBox["\[PartialD]", 

                                SubscriptBox[

                                  StyleBox["p",

                                    FontSlant->"Plain"], "0"]], 

                              StyleBox["p",

                                FontSlant->"Plain"]}]},

                          {

                            RowBox[{

                              SubscriptBox["\[PartialD]", 

                                SubscriptBox[

                                  StyleBox["p",

                                    FontSlant->"Plain"], "0"]], 

                              RowBox[{"(", 

                                RowBox[{"W1", "+", 

                                  RowBox[{"2", 

                                    StyleBox["W",

                                      FontSlant->"Plain"]}]}], ")"}]}]}

                          }]}

                    }], GridBox[{

                    {

                      RowBox[{

                        SubscriptBox["\[PartialD]", 

                          SubscriptBox[

                            StyleBox["W",

                              FontSlant->"Plain"], "0"]], 

                        StyleBox["p",

                          FontSlant->"Plain"]}]},

                    {

                      RowBox[{

                        SubscriptBox["\[PartialD]", 

                          SubscriptBox[

                            StyleBox["W",

                              FontSlant->"Plain"], "0"]], 

                        RowBox[{"(", 

                          RowBox[{"W1", "+", 

                            RowBox[{"2", 

                              StyleBox["W",

                                FontSlant->"Plain"]}]}], ")"}]}]}

                    }]}

              }], "\[NegativeThinSpace]", ")"}], TraditionalForm]]],

  " \n\nis the Jacobian matrix. In order to obtain the partial derivatives \

needed in\nthe above Jacobian matrix, we first differentiate each of the \

equations in  the\nfollowing IVP with respect to ",

  Cell[BoxData[

      FormBox[

        RowBox[{

          FormBox[

            SubscriptBox[

              StyleBox["q",

                FontSlant->"Plain"], "0"],

            "TraditionalForm"], ",", 

          FormBox[

            SubscriptBox[

              StyleBox["p",

                FontSlant->"Plain"], 

              StyleBox["0",

                FontSize->12]],

            "TraditionalForm"], ",", 

          FormBox[

            SubscriptBox[

              StyleBox["W",

                FontSlant->"Plain"], "0"],

            "TraditionalForm"]}], TraditionalForm]]],

  ", respectively.\n"

}], "Input",

  FormatType->TextForm,

  FontSize->16],



Cell[BoxData[

    RowBox[{

      RowBox[{"eqs", "=", 

        RowBox[{"{", 

          RowBox[{

            RowBox[{

              RowBox[{

                SuperscriptBox["q", "\[Prime]",

                  MultilineFunction->None], "[", \(r, q0, p0, w0\), "]"}], 

              "==", \(q1[r, q0, p0, w0]\)}], ",", "\n", "\t\t         ", 

            RowBox[{

              RowBox[{

                SuperscriptBox["p", "\[Prime]",

                  MultilineFunction->None], "[", \(r, q0, p0, w0\), "]"}], 

              "==", \(p1[r, q0, p0, w0]\)}], ",", "\n", "\t\t         ", 

            RowBox[{

              RowBox[{

                SuperscriptBox["w", "\[Prime]",

                  MultilineFunction->None], "[", \(r, q0, p0, w0\), "]"}], 

              "==", \(w1[r, q0, p0, w0]\)}], ",", "\n", "\t\t       ", 

            RowBox[{

              RowBox[{

                RowBox[{

                  SuperscriptBox["q1", "\[Prime]",

                    MultilineFunction->None], "[", \(r, q0, p0, w0\), "]"}], 

                "+", \(\((3*q1[r, \ q0, \ p0, \ w0])\)/r\), "+", "\n", 

                "\t\t\t                      ", 

                \(a\^2\ p[r, q0, p0, w0]\ q[r, q0, p0, w0]\)}], "==", 

              \(k\^2\ w[r, q0, p0, w0]\)}], ",", "       ", 

            RowBox[{

              RowBox[{

                RowBox[{

                  SuperscriptBox["p1", "\[Prime]",

                    MultilineFunction->None], "[", \(r, q0, p0, w0\), "]"}], 

                "+", \(\((3*p1[r, \ q0, \ p0, \ w0])\)/r\)}], "==", 

              \(0.5\ q[r, q0, p0, w0]^2\)}], ",", 

            RowBox[{

              RowBox[{

                RowBox[{

                  SuperscriptBox["w1", "\[Prime]",

                    MultilineFunction->None], "[", \(r, q0, p0, w0\), "]"}], 

                "+", \(\((3*w1[r, \ q0, \ p0, \ w0])\)/r\), "+", 

                \(q[r, q0, p0, w0]\)}], "==", "0"}], ",", 

            \(q1[10^\(-6\), q0, p0, w0] == 0\), ",", 

            \(p1[10^\(-6\), q0, p0, w0] == 0\), ",", 

            \(w1[10^\(-6\), q0, p0, w0] == 0\), ",", 

            \(q[10^\(-6\), q0, p0, w0] == q0\), ",", 

            \(p[10^\(-6\), q0, p0, w0] == p0\), ",", 

            \(w[10^\(-6\), q0, p0, w0] == w0\)}], "}"}]}], ";"}]], "Input",

  FontSize->14],



Cell[TextData[{

  "\nWe also simplify the notation. These steps are accomplished using the \n\

following ",

  StyleBox["Mathematica",

    FontSlant->"Italic"],

  " code.\n"

}], "Input",

  FormatType->TextForm,

  FontSize->16],



Cell[BoxData[

    \(cat[x_, y_] := ToExpression[StringJoin[ToString[x], ToString[y]]]\)], 

  "Input"],



Cell[BoxData[

    RowBox[{

      RowBox[{"newnames", "=", 

        RowBox[{"{", 

          RowBox[{

            RowBox[{

              RowBox[{

                SubscriptBox["\[PartialD]", 

                  StyleBox["q0",

                    FontSize->10]], 

                RowBox[{

                  SuperscriptBox["q_", "\[Prime]",

                    MultilineFunction->None], "[", \(r, q0, p0, w0\), "]"}]}],

               "\[RuleDelayed]", 

              RowBox[{

                SuperscriptBox[\(\(cat[q, d]\)[1]\), "\[Prime]",

                  MultilineFunction->None], "[", "r", "]"}]}], ",", "\n", 

            "\t\t                ", 

            RowBox[{

              RowBox[{\(\[PartialD]\_p0\), 

                RowBox[{

                  SuperscriptBox["q_", "\[Prime]",

                    MultilineFunction->None], "[", \(r, q0, p0, w0\), "]"}]}],

               "\[RuleDelayed]", 

              RowBox[{

                SuperscriptBox[\(\(cat[q, d]\)[2]\), "\[Prime]",

                  MultilineFunction->None], "[", "r", "]"}]}], ",", "\n", 

            "\t\t                ", 

            RowBox[{

              RowBox[{\(\[PartialD]\_w0\), 

                RowBox[{

                  SuperscriptBox["q_", "\[Prime]",

                    MultilineFunction->None], "[", \(r, q0, p0, w0\), "]"}]}],

               "\[RuleDelayed]", 

              RowBox[{

                SuperscriptBox[\(\(cat[q, d]\)[3]\), "\[Prime]",

                  MultilineFunction->None], "[", "r", "]"}]}], ",", "\n", 

            "\t\t                ", 

            \(\[PartialD]\_q0 q_[r_, q0, p0, w0] \[RuleDelayed] 

              \(\(cat[q, d]\)[1]\)[r]\), ",", "\n", "\t\t                ", 

            \(\[PartialD]\_p0 q_[r_, q0, p0, w0] \[RuleDelayed] 

              \(\(cat[q, d]\)[2]\)[r]\), ",", "\n", "\t\t                ", 

            \(\[PartialD]\_w0 q_[r_, q0, p0, w0] \[RuleDelayed] 

              \(\(cat[q, d]\)[3]\)[r]\), ",", "\n", 

            "\t\t                     ", 

            \(q_[r_, q0, p0, w0] \[RuleDelayed] q[r]\)}], "}"}]}], ";"}]], 

  "Input",

  FontSize->14],



Cell[BoxData[

    \(\(\n\ \ \ \ \ \ \ \ \ \ \ \ \ \ {eqs, \[PartialD]\_q0\ eqs, 

        \[PartialD]\_p0\ eqs, \[PartialD]\_w0\ eqs} /. newnames\n\)\)], 

  "Input",

  FontSize->14],



Cell["\<\

Then after some rearrangement we obtain the following IVP, consisting 

24 first order differential equations and 24 initial conditions.\

\>", "Input",

  FormatType->TextForm,

  FontSize->16],



Cell["\<\

eqns[q0_,p0_,w0_,a_,k_] :=

    Flatten[Join[{q'[r] == q1[r], p'[r] == p1[r], w'[r] == w1[r],

        q1'[r]+3/r q1[r]+a^2 p[r] q[r]==k^2 w[r],

        p1'[r]+3/r p1[r] == .5 q[r]^2,

        w1'[r]+3/r w1[r]+q[r] ==0,

      Table[{qd[i]'[r] == q1d[i][r],

         pd[i]'[r] == p1d[i][r],

         wd[i]'[r] == w1d[i][r],

        q1d[i]'[r]+3/r q1d[i][r]+a^2 pd[i][r] q[r]+a^2 p[r] qd[i][r]

                           ==k^2 wd[i][r],

        p1d[i]'[r]+3/r p1d[i][r] == q[r] qd[i][r],

        w1d[i]'[r]+3/r w1d[i][r]+qd[i][r] == 0,

        q1d[i][10^-6]==0,p1d[i][10^-6]==0,w1d[i][10^-6]==0},{i,3}

            ],

        q1[10^-6]==0, p1[10^-6]==0, w1[10^-6]==0,

         q[10^-6]==q0, p[10^-6]==p0, w[10^-6]==w0,

        qd[1][10^-6] ==1, qd[2][10^-6]==0, qd[3][10^-6]==0,

        pd[1][10^-6] ==0, pd[2][10^-6]==1, pd[3][10^-6]==0,

        wd[1][10^-6] ==0, wd[2][10^-6]==0, wd[3][10^-6]==1 }

                 ]

            ]

        \

\>", "Input",

  PageWidth->Infinity,

  InitializationCell->True,

  ShowSpecialCharacters->False,

  FormatType->InputForm,

  FontSize->14],



Cell[TextData[{

  "\nWe note that in this IVP, we have used r = ",

  Cell[BoxData[

      \(TraditionalForm\`10\^\(-6\)\)]],

  " because r = 0 is a \nsingular point of the differential equations. \n\n\

This IVP is solved using the following."

}], "Input",

  FormatType->TextForm,

  FontSize->16],



Cell["\<\

    

ivp[q0_,p0_,w0_,a_,k_] :=

     NDSolve[eqns[q0,p0,w0,a,k],Flatten[Join[{q,p,w,q1,p1,w1,

\t  Table[{qd[i],pd[i],wd[i], q1d[i],p1d[i],w1d[i]},{i,3}]}] ],

\t\t\t\t {r,1} ,MaxSteps->3000 ] \

\>", "Input",

  PageWidth->Infinity,

  InitializationCell->True,

  ShowSpecialCharacters->False,

  FormatType->InputForm],



Cell["\<\



Newton's method takes the form of the following commands.



\

\>", "Input",

  FormatType->TextForm,

  FontSize->16],



Cell[BoxData[

    FormBox[

      StyleBox[

        RowBox[{"jacobian", ":=", 

          RowBox[{"(", GridBox[{

                {\(\(qd[1]\)[1]\), \(\(qd[2]\)[1]\), \(\(qd[3]\)[1]\)},

                {\(\(pd[1]\)[1]\), \(\(pd[2]\)[1]\), \(\(pd[3]\)[1]\)},

               

                 {\(\(w1d[1]\)[1] + 2 \(wd[1]\)[1]\ \), \(\ 

                  \(w1d[2]\)[1] + 2\ \(wd[2]\)[1]\ \ \), 

                  \(\(w1d[3]\)[1] + 2\ \(wd[3]\)[1]\)}

                }], " ", ")"}]}],

        FontFamily->"Courier New"], TraditionalForm]], "Input"],



Cell[BoxData[

    RowBox[{"y1", ":=", 

      RowBox[{"(", "\[NegativeThinSpace]", GridBox[{

            {\(q[1]\)},

            {GridBox[{

                  {\(p[1]\  - \ 1\)},

                  {\(2\ w[1]\  + \ w1[1]\)}

                  }]}

            }], "\[NegativeThinSpace]", ")"}]}]], "Input"],



Cell[BoxData[

    \(\(\ndy0n := \(-Inverse[jacobian].y1\)\)\)], "Input"],



Cell[BoxData[

    \(\(\nf[{q0_, p0_, w0_}, a_, k_] := {q0, p0, w0} + dy0n /. 

        Flatten[ivp[q0, p0, w0, a, k]]\)\)], "Input"],



Cell[TextData[{

  "\nid[{q0_,p0_,w0_},a_,k_,e_] :=(",

  StyleBox["l=0",

    FontColor->RGBColor[1, 0, 0]],

  ";\n                                  FixedPoint[(",

  StyleBox["l++",

    FontColor->RGBColor[1, 0, 0]],

  ";f[#,a,k])&,{q0,p0,w0},\n                                    SameTest-> ( \

(Abs[ #1[[1]]-#2[[1]] ]+\n                                                  \

Abs[ #1[[2]]-#2[[2]] ]+\n                                                  \

Abs[ #1[[3]]-#2[[3]] ])<e &) \n                                            ]\n\

                              )"

}], "Input",

  PageWidth->Infinity,

  InitializationCell->True,

  ShowSpecialCharacters->False,

  FormatType->InputForm],



Cell[TextData[{

  StyleBox["jd",

    FontColor->RGBColor[1, 0, 0]],

  "[{q0_,p0_,w0_},a_,k_] := Det[jacobian/.Flatten[ivp[q0,p0,w0,a,k]] ]"

}], "Input",

  PageWidth->Infinity,

  InitializationCell->True,

  ShowSpecialCharacters->False,

  FormatType->InputForm],



Cell[TextData[{

  "Next, in order to follow a branch of solutions as",

  StyleBox[" \"",

    FontFamily->"Times New Roman"],

  StyleBox["a",

    FontFamily->"Courier New"],

  "\" and/or \"",

  StyleBox["k",

    FontFamily->"Courier New"],

  "\" is incremented\nby ",

  StyleBox["da",

    FontFamily->"Courier New"],

  " and ",

  StyleBox["dk",

    FontFamily->"Courier New"],

  " respectively, we use the following."

}], "Input",

  FormatType->TextForm,

  FontFamily->"Times New Roman",

  FontSize->16],



Cell[BoxData[

    RowBox[{"\n", 

      RowBox[{

      \(idbranch[q0_, p0_, w0_, a0_, k0_, da_, dk_, jm_, e_]\), " ", ":=", 

        "\n", "    ", 

        RowBox[{"Module", "[", 

          RowBox[{\({idb, jbd}\), ",", "\n", "          ", 

            RowBox[{

            \(idb[0]\  := \ {q0, p0, w0}\), ";", "\n", "          ", 

              \(idb[1]\  := \ id[idb[0], a0, k0, e]\), ";", "\n", 

              "          ", 

              RowBox[{\(idb[i_]\), " ", ":=", " ", 

                RowBox[{

                  RowBox[{"(", 

                    RowBox[{\(idb[i]\), " ", "=", " ", 

                      RowBox[{"id", "[", 

                        RowBox[{

                          RowBox[{"(", 

                            StyleBox[\(2\ idb[i - 1]\  - \ idb[i - 2]\),

                              CellFrame->True,

                              Background->RGBColor[0, 1, 0]], ")"}], ",", 

                          "\n", "                                  ", 

                          \(a0 + \((i - 1)\)\ da\), ",", 

                          \(k0 + \((i - 1)\)\ dk\), ",", "e"}], "]"}]}], 

                    ")"}], "/;", 

                  StyleBox[\(i >= 2\),

                    Background->RGBColor[0, 1, 0]]}]}], " ", ";", "\n", 

              "          ", 

              RowBox[{

                RowBox[{

                  StyleBox["jbd",

                    FontColor->RGBColor[1, 0, 0]], "[", "i_", "]"}], " ", 

                ":=", " ", 

                RowBox[{\(jbd[i]\), " ", "=", " ", 

                  RowBox[{

                    StyleBox["jd",

                      FontColor->RGBColor[1, 0, 0]], "[", \(idb[i], 

                    a0 + \((i - 1)\)\ da, k0 + \((i - 1)\)\ dk\), "]"}]}]}], 

              ";", "\n", "          ", 

              RowBox[{"Table", "[", 

                RowBox[{

                  RowBox[{"{", 

                    RowBox[{

                    \(k0 + \((j - 1)\)\ dk\), ",", " ", 

                      \(a0 + \((j - 1)\)\ da\), ",", \(idb[j]\), ",", 

                      RowBox[{

                        StyleBox["jbd",

                          FontColor->RGBColor[1, 0, 0]], "[", "j", "]"}], ",",

                       

                      StyleBox["l",

                        FontColor->RGBColor[1, 0, 0]]}], "}"}], ",", 

                  \({j, jm}\)}], "]"}]}]}], " ", "]"}]}], "\n"}]], "Input"]

}, Open  ]],



Cell[CellGroupData[{



Cell["2.4 Graphical Results", "Subsection",

  FontSize->18],



Cell[TextData[{

  "We illustrate the numerical results obtained using the previous commands\n\

by plotting either q0,p0, or w0 on the vertical axis versus \"",

  StyleBox["a",

    FontFamily->"Courier New"],

  "\" on the \nhorizontal axis. This is done using the following."

}], "Input",

  FormatType->TextForm,

  FontFamily->"Times New Roman",

  FontSize->16],



Cell[CellGroupData[{



Cell[BoxData[

    RowBox[{"\n", 

      RowBox[{

        RowBox[{"plota", "[", 

          RowBox[{

            StyleBox[

              RowBox[{

                StyleBox["c",

                  FontColor->RGBColor[1, 0, 0]], "_"}]], ",", "m_", ",", 

            "k_"}], "]"}], ":=", "   ", "\n", "        ", 

        RowBox[{"ListPlot", "[", 

          RowBox[{

            RowBox[{"Table", "[", 

              RowBox[{

                RowBox[{"{", 

                  RowBox[{\(idbranch[\([i, 2]\)]\), ",", 

                    RowBox[{"idbranch", "[", 

                      RowBox[{"[", 

                        RowBox[{"i", ",", "3", ",", 

                          StyleBox["c",

                            FontColor->RGBColor[1, 0, 0]]}], "]"}], "]"}]}], 

                  "}"}], ",", \({i, m}\)}], "\n", 

              "\t\t                                    ", "]"}], ",", "\n", 

            "              ", \(Axes -> Automatic\), ",", 

            \(AxesLabel -> {a, q0}\), ",", \(PlotJoined -> True\), ",", "\n", 

            "\t\t        ", \(PlotLabel -> StringForm["\<k=``\>", k]\), ",", 

            " ", \(PlotRange -> All\)}], " ", "]"}]}]}]], "Input"],



Cell[CellGroupData[{



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-0.962104 0.0969147 0.309017 0.0238716 [

[.20087 .29652 -6 -9 ]

[.20087 .29652 6 0 ]

[.3947 .29652 -6 -9 ]

[.3947 .29652 6 0 ]

[.58853 .29652 -6 -9 ]

[.58853 .29652 6 0 ]

[.78236 .29652 -6 -9 ]

[.78236 .29652 6 0 ]

[.97619 .29652 -6 -9 ]

[.97619 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[-0.00546 .0703 -18 -4.5 ]

[-0.00546 .0703 0 4.5 ]

[-0.00546 .18966 -12 -4.5 ]

[-0.00546 .18966 0 4.5 ]

[-0.00546 .42837 -6 -4.5 ]

[-0.00546 .42837 0 4.5 ]

[-0.00546 .54773 -12 -4.5 ]

[-0.00546 .54773 0 4.5 ]

[.00704 .64303 -7 0 ]

[.00704 .64303 7 16 ]

[.5 .63053 -9.5 0 ]

[.5 .63053 9.5 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.20087 .30902 m

.20087 .31527 L

s

[(12)] .20087 .29652 0 1 Mshowa

.3947 .30902 m

.3947 .31527 L

s

[(14)] .3947 .29652 0 1 Mshowa

.58853 .30902 m

.58853 .31527 L

s

[(16)] .58853 .29652 0 1 Mshowa

.78236 .30902 m

.78236 .31527 L

s

[(18)] .78236 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(20)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.0555 .30902 m

.0555 .31277 L

s

.10396 .30902 m

.10396 .31277 L

s

.15242 .30902 m

.15242 .31277 L

s

.24933 .30902 m

.24933 .31277 L

s

.29779 .30902 m

.29779 .31277 L

s

.34624 .30902 m

.34624 .31277 L

s

.44316 .30902 m

.44316 .31277 L

s

.49162 .30902 m

.49162 .31277 L

s

.54007 .30902 m

.54007 .31277 L

s

.63699 .30902 m

.63699 .31277 L

s

.68545 .30902 m

.68545 .31277 L

s

.7339 .30902 m

.7339 .31277 L

s

.83082 .30902 m

.83082 .31277 L

s

.87928 .30902 m

.87928 .31277 L

s

.92773 .30902 m

.92773 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.00704 .0703 m

.01329 .0703 L

s

[(-10)] -0.00546 .0703 1 0 Mshowa

.00704 .18966 m

.01329 .18966 L

s

[(-5)] -0.00546 .18966 1 0 Mshowa

.00704 .42837 m

.01329 .42837 L

s

[(5)] -0.00546 .42837 1 0 Mshowa

.00704 .54773 m

.01329 .54773 L

s

[(10)] -0.00546 .54773 1 0 Mshowa

.125 Mabswid

.00704 .09417 m

.01079 .09417 L

s

.00704 .11804 m

.01079 .11804 L

s

.00704 .14192 m

.01079 .14192 L

s

.00704 .16579 m

.01079 .16579 L

s

.00704 .21353 m

.01079 .21353 L

s

.00704 .2374 m

.01079 .2374 L

s

.00704 .26127 m

.01079 .26127 L

s

.00704 .28515 m

.01079 .28515 L

s

.00704 .33289 m

.01079 .33289 L

s

.00704 .35676 m

.01079 .35676 L

s

.00704 .38063 m

.01079 .38063 L

s

.00704 .4045 m

.01079 .4045 L

s

.00704 .45225 m

.01079 .45225 L

s

.00704 .47612 m

.01079 .47612 L

s

.00704 .49999 m

.01079 .49999 L

s

.00704 .52386 m

.01079 .52386 L

s

.00704 .04643 m

.01079 .04643 L

s

.00704 .02256 m

.01079 .02256 L

s

.00704 .5716 m

.01079 .5716 L

s

.00704 .59548 m

.01079 .59548 L

s

.25 Mabswid

.00704 0 m

.00704 .61803 L

s

gsave

.00704 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -70.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(k) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

78.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 .4 1 r

.5 Mabswid

.97619 .45178 m

.97425 .45227 L

.97231 .45276 L

.97038 .45325 L

.96844 .45374 L

.9665 .45424 L

.96456 .45473 L

.96262 .45523 L

.96068 .45573 L

.95875 .45624 L

.95681 .45674 L

.95487 .45724 L

.95293 .45775 L

.95099 .45826 L

.94905 .45877 L

.94712 .45928 L

.94518 .4598 L

.94324 .46031 L

.9413 .46083 L

.93936 .46135 L

.93742 .46187 L

.93549 .4624 L

.93355 .46292 L

.93161 .46345 L

.92967 .46398 L

.92773 .46451 L

.92579 .46504 L

.92386 .46558 L

.92192 .46611 L

.91998 .46665 L

.91804 .46719 L

.9161 .46773 L

.91417 .46828 L

.91223 .46882 L

.91029 .46937 L

.90835 .46992 L

.90641 .47047 L

.90447 .47102 L

.90254 .47158 L

.9006 .47214 L

.89866 .47269 L

.89672 .47326 L

.89478 .47382 L

.89284 .47438 L

.89091 .47495 L

.88897 .47552 L

.88703 .47609 L

.88509 .47666 L

.88315 .47723 L

.88121 .47781 L

Mistroke

.87928 .47839 L

.87734 .47896 L

.8754 .47955 L

.87346 .48013 L

.87152 .48071 L

.86958 .4813 L

.86765 .48189 L

.86571 .48248 L

.86377 .48307 L

.86183 .48367 L

.85989 .48426 L

.85795 .48486 L

.85602 .48546 L

.85408 .48607 L

.85214 .48667 L

.8502 .48728 L

.84826 .48788 L

.84632 .48849 L

.84439 .4891 L

.84245 .48972 L

.84051 .49033 L

.83857 .49095 L

.83663 .49157 L

.83469 .49219 L

.83276 .49281 L

.83082 .49344 L

.82888 .49406 L

.82694 .49469 L

.825 .49532 L

.82307 .49595 L

.82113 .49659 L

.81919 .49722 L

.81725 .49786 L

.81531 .4985 L

.81337 .49914 L

.81144 .49978 L

.8095 .50043 L

.80756 .50107 L

.80562 .50172 L

.80368 .50237 L

.80174 .50302 L

.79981 .50368 L

.79787 .50433 L

.79593 .50499 L

.79399 .50565 L

.79205 .50631 L

.79011 .50697 L

.78818 .50764 L

.78624 .5083 L

.7843 .50897 L

Mistroke

.78236 .50964 L

.78042 .51031 L

.77848 .51098 L

.77655 .51165 L

.77461 .51233 L

.77267 .51301 L

.77073 .51369 L

.76879 .51437 L

.76685 .51505 L

.76492 .51573 L

.76298 .51642 L

.76104 .5171 L

.7591 .51779 L

.75716 .51848 L

.75522 .51917 L

.75329 .51986 L

.75135 .52056 L

.74941 .52125 L

.74747 .52195 L

.74553 .52265 L

.7436 .52335 L

.74166 .52405 L

.73972 .52475 L

.73778 .52545 L

.73584 .52616 L

.7339 .52686 L

.73197 .52757 L

.73003 .52828 L

.72809 .52899 L

.72615 .5297 L

.72421 .53041 L

.72227 .53112 L

.72034 .53184 L

.7184 .53255 L

.71646 .53327 L

.71452 .53398 L

.71258 .5347 L

.71064 .53542 L

.70871 .53614 L

.70677 .53686 L

.70483 .53758 L

.70289 .5383 L

.70095 .53902 L

.69901 .53975 L

.69708 .54047 L

.69514 .54119 L

.6932 .54192 L

.69126 .54264 L

.68932 .54337 L

.68738 .5441 L

Mistroke

.68545 .54482 L

.68351 .54555 L

.68157 .54628 L

.67963 .547 L

.67769 .54773 L

.67575 .54846 L

.67382 .54919 L

.67188 .54992 L

.66994 .55064 L

.668 .55137 L

.66606 .5521 L

.66413 .55283 L

.66219 .55355 L

.66025 .55428 L

.65831 .55501 L

.65637 .55573 L

.65443 .55646 L

.6525 .55718 L

.65056 .5579 L

.64862 .55863 L

.64668 .55935 L

.64474 .56007 L

.6428 .56079 L

.64087 .56151 L

.63893 .56223 L

.63699 .56295 L

.63505 .56366 L

.63311 .56438 L

.63117 .56509 L

.62924 .5658 L

.6273 .56651 L

.62536 .56722 L

.62342 .56792 L

.62148 .56863 L

.61954 .56933 L

.61761 .57003 L

.61567 .57073 L

.61373 .57142 L

.61179 .57211 L

.60985 .5728 L

.60791 .57349 L

.60598 .57417 L

.60404 .57485 L

.6021 .57553 L

.60016 .57621 L

.59822 .57688 L

.59628 .57755 L

.59435 .57821 L

.59241 .57887 L

.59047 .57953 L

Mistroke

.58853 .58018 L

.58659 .58083 L

.58466 .58147 L

.58272 .58211 L

.58078 .58274 L

.57884 .58337 L

.5769 .584 L

.57496 .58462 L

.57303 .58523 L

.57109 .58584 L

.56915 .58644 L

.56721 .58703 L

.56527 .58762 L

.56333 .58821 L

.5614 .58878 L

.55946 .58935 L

.55752 .58992 L

.55558 .59047 L

.55364 .59102 L

.5517 .59156 L

.54977 .59209 L

.54783 .59262 L

.54589 .59313 L

.54395 .59364 L

.54201 .59414 L

.54007 .59463 L

.53814 .59511 L

.5362 .59558 L

.53426 .59604 L

.53232 .59648 L

.53038 .59692 L

.52844 .59735 L

.52651 .59776 L

.52457 .59817 L

.52263 .59856 L

.52069 .59894 L

.51875 .59931 L

.51681 .59966 L

.51488 .6 L

.51294 .60033 L

.511 .60064 L

.50906 .60094 L

.50712 .60122 L

.50518 .60148 L

.50325 .60174 L

.50131 .60197 L

.49937 .60219 L

.49743 .60239 L

.49549 .60257 L

.49356 .60273 L

Mistroke

.49162 .60288 L

.48968 .603 L

.48774 .60311 L

.4858 .60319 L

.48386 .60326 L

.48193 .6033 L

.47999 .60332 L

.47805 .60332 L

.47611 .60329 L

.47417 .60324 L

.47223 .60316 L

.4703 .60306 L

.46836 .60293 L

.46642 .60278 L

.46448 .60259 L

.46254 .60238 L

.4606 .60214 L

.45867 .60187 L

.45673 .60156 L

.45479 .60123 L

.45285 .60086 L

.45091 .60045 L

.44897 .60001 L

.44704 .59954 L

.4451 .59903 L

.44316 .59847 L

.44122 .59788 L

.43928 .59725 L

.43734 .59658 L

.43541 .59586 L

.43347 .5951 L

.43153 .59429 L

.42959 .59343 L

.42765 .59252 L

.42571 .59156 L

.42378 .59055 L

.42184 .58949 L

.4199 .58836 L

.41796 .58718 L

.41602 .58594 L

.41409 .58464 L

.41215 .58327 L

.41021 .58183 L

.40827 .58033 L

.40633 .57875 L

.40439 .5771 L

.40246 .57537 L

.40052 .57356 L

.39858 .57166 L

.39664 .56968 L

Mistroke

.3947 .5676 L

.39276 .56543 L

.39083 .56316 L

.38889 .56078 L

.38695 .5583 L

.38501 .5557 L

.38307 .55298 L

.38113 .55014 L

.3792 .54716 L

.37726 .54405 L

.37532 .54078 L

.37338 .53736 L

.37144 .53377 L

.3695 .53001 L

.36757 .52606 L

.36563 .52191 L

.36369 .51754 L

.36175 .51294 L

.35981 .50808 L

.35787 .50296 L

.35594 .49753 L

.354 .49178 L

.35206 .48566 L

.35012 .47913 L

.34818 .47214 L

.34624 .46462 L

.34431 .45649 L

.34237 .44764 L

.34043 .43791 L

.33849 .42707 L

.33655 .41479 L

.33462 .40047 L

.33268 .38292 L

.33074 .35885 L

.32916 .30902 L

Mfstroke

.97619 .16625 m

.97425 .16576 L

.97231 .16528 L

.97038 .16478 L

.96844 .16429 L

.9665 .1638 L

.96456 .1633 L

.96262 .1628 L

.96068 .1623 L

.95875 .1618 L

.95681 .1613 L

.95487 .16079 L

.95293 .16028 L

.95099 .15977 L

.94905 .15926 L

.94712 .15875 L

.94518 .15824 L

.94324 .15772 L

.9413 .1572 L

.93936 .15668 L

.93742 .15616 L

.93549 .15564 L

.93355 .15511 L

.93161 .15458 L

.92967 .15405 L

.92773 .15352 L

.92579 .15299 L

.92386 .15246 L

.92192 .15192 L

.91998 .15138 L

.91804 .15084 L

.9161 .1503 L

.91417 .14976 L

.91223 .14921 L

.91029 .14866 L

.90835 .14811 L

.90641 .14756 L

.90447 .14701 L

.90254 .14645 L

.9006 .1459 L

.89866 .14534 L

.89672 .14478 L

.89478 .14422 L

.89284 .14365 L

.89091 .14309 L

.88897 .14252 L

.88703 .14195 L

.88509 .14138 L

.88315 .1408 L

.88121 .14023 L

Mistroke

.87928 .13965 L

.87734 .13907 L

.8754 .13849 L

.87346 .1379 L

.87152 .13732 L

.86958 .13673 L

.86765 .13614 L

.86571 .13555 L

.86377 .13496 L

.86183 .13437 L

.85989 .13377 L

.85795 .13317 L

.85602 .13257 L

.85408 .13197 L

.85214 .13136 L

.8502 .13076 L

.84826 .13015 L

.84632 .12954 L

.84439 .12893 L

.84245 .12832 L

.84051 .1277 L

.83857 .12708 L

.83663 .12647 L

.83469 .12584 L

.83276 .12522 L

.83082 .1246 L

.82888 .12397 L

.82694 .12334 L

.825 .12271 L

.82307 .12208 L

.82113 .12145 L

.81919 .12081 L

.81725 .12017 L

.81531 .11953 L

.81337 .11889 L

.81144 .11825 L

.8095 .11761 L

.80756 .11696 L

.80562 .11631 L

.80368 .11566 L

.80174 .11501 L

.79981 .11436 L

.79787 .1137 L

.79593 .11304 L

.79399 .11239 L

.79205 .11172 L

.79011 .11106 L

.78818 .1104 L

.78624 .10973 L

.7843 .10907 L

Mistroke

.78236 .1084 L

.78042 .10773 L

.77848 .10705 L

.77655 .10638 L

.77461 .1057 L

.77267 .10503 L

.77073 .10435 L

.76879 .10367 L

.76685 .10299 L

.76492 .1023 L

.76298 .10162 L

.76104 .10093 L

.7591 .10024 L

.75716 .09955 L

.75522 .09886 L

.75329 .09817 L

.75135 .09748 L

.74941 .09678 L

.74747 .09608 L

.74553 .09539 L

.7436 .09469 L

.74166 .09399 L

.73972 .09328 L

.73778 .09258 L

.73584 .09188 L

.7339 .09117 L

.73197 .09046 L

.73003 .08976 L

.72809 .08905 L

.72615 .08834 L

.72421 .08762 L

.72227 .08691 L

.72034 .0862 L

.7184 .08548 L

.71646 .08477 L

.71452 .08405 L

.71258 .08333 L

.71064 .08261 L

.70871 .0819 L

.70677 .08118 L

.70483 .08045 L

.70289 .07973 L

.70095 .07901 L

.69901 .07829 L

.69708 .07756 L

.69514 .07684 L

.6932 .07611 L

.69126 .07539 L

.68932 .07466 L

.68738 .07394 L

Mistroke

.68545 .07321 L

.68351 .07248 L

.68157 .07176 L

.67963 .07103 L

.67769 .0703 L

.67575 .06957 L

.67382 .06885 L

.67188 .06812 L

.66994 .06739 L

.668 .06666 L

.66606 .06594 L

.66413 .06521 L

.66219 .06448 L

.66025 .06375 L

.65831 .06303 L

.65637 .0623 L

.65443 .06158 L

.6525 .06085 L

.65056 .06013 L

.64862 .05941 L

.64668 .05868 L

.64474 .05796 L

.6428 .05724 L

.64087 .05652 L

.63893 .0558 L

.63699 .05509 L

.63505 .05437 L

.63311 .05366 L

.63117 .05295 L

.62924 .05223 L

.6273 .05152 L

.62536 .05082 L

.62342 .05011 L

.62148 .04941 L

.61954 .04871 L

.61761 .04801 L

.61567 .04731 L

.61373 .04661 L

.61179 .04592 L

.60985 .04523 L

.60791 .04455 L

.60598 .04386 L

.60404 .04318 L

.6021 .0425 L

.60016 .04183 L

.59822 .04116 L

.59628 .04049 L

.59435 .03982 L

.59241 .03916 L

.59047 .03851 L

Mistroke

.58853 .03786 L

.58659 .03721 L

.58466 .03656 L

.58272 .03593 L

.58078 .03529 L

.57884 .03466 L

.5769 .03404 L

.57496 .03342 L

.57303 .03281 L

.57109 .0322 L

.56915 .0316 L

.56721 .031 L

.56527 .03041 L

.56333 .02983 L

.5614 .02925 L

.55946 .02868 L

.55752 .02812 L

.55558 .02756 L

.55364 .02701 L

.5517 .02647 L

.54977 .02594 L

.54783 .02542 L

.54589 .0249 L

.54395 .02439 L

.54201 .02389 L

.54007 .02341 L

.53814 .02293 L

.5362 .02246 L

.53426 .022 L

.53232 .02155 L

.53038 .02111 L

.52844 .02068 L

.52651 .02027 L

.52457 .01987 L

.52263 .01947 L

.52069 .01909 L

.51875 .01873 L

.51681 .01837 L

.51488 .01803 L

.51294 .01771 L

.511 .0174 L

.50906 .0171 L

.50712 .01682 L

.50518 .01655 L

.50325 .0163 L

.50131 .01606 L

.49937 .01585 L

.49743 .01565 L

.49549 .01547 L

.49356 .0153 L

Mistroke

.49162 .01516 L

.48968 .01503 L

.48774 .01493 L

.4858 .01484 L

.48386 .01478 L

.48193 .01473 L

.47999 .01472 L

.47805 .01472 L

.47611 .01475 L

.47417 .0148 L

.47223 .01487 L

.4703 .01497 L

.46836 .0151 L

.46642 .01526 L

.46448 .01544 L

.46254 .01565 L

.4606 .0159 L

.45867 .01617 L

.45673 .01647 L

.45479 .01681 L

.45285 .01718 L

.45091 .01758 L

.44897 .01802 L

.44704 .0185 L

.4451 .01901 L

.44316 .01956 L

.44122 .02015 L

.43928 .02078 L

.43734 .02146 L

.43541 .02218 L

.43347 .02294 L

.43153 .02375 L

.42959 .02461 L

.42765 .02551 L

.42571 .02647 L

.42378 .02748 L

.42184 .02855 L

.4199 .02967 L

.41796 .03085 L

.41602 .03209 L

.41409 .0334 L

.41215 .03476 L

.41021 .0362 L

.40827 .0377 L

.40633 .03928 L

.40439 .04093 L

.40246 .04267 L

.40052 .04448 L

.39858 .04637 L

.39664 .04836 L

Mistroke

.3947 .05043 L

.39276 .0526 L

.39083 .05487 L

.38889 .05725 L

.38695 .05973 L

.38501 .06233 L

.38307 .06505 L

.38113 .06789 L

.3792 .07087 L

.37726 .07399 L

.37532 .07725 L

.37338 .08067 L

.37144 .08426 L

.3695 .08802 L

.36757 .09198 L

.36563 .09613 L

.36369 .1005 L

.36175 .1051 L

.35981 .10995 L

.35787 .11508 L

.35594 .1205 L

.354 .12626 L

.35206 .13238 L

.35012 .13891 L

.34818 .1459 L

.34624 .15341 L

.34431 .16154 L

.34237 .1704 L

.34043 .18013 L

.33849 .19096 L

.33655 .20325 L

.33462 .21757 L

.33268 .23511 L

.33074 .25919 L

.32916 .30902 L

Mfstroke

1 0 0 r

.97619 .37344 m

.97367 .37372 L

.96979 .37416 L

.96592 .3746 L

.96204 .37504 L

.95816 .37549 L

.95429 .37594 L

.95041 .37639 L

.94653 .37684 L

.94266 .3773 L

.93878 .37776 L

.9349 .37823 L

.93103 .3787 L

.92715 .37917 L

.92328 .37965 L

.9194 .38013 L

.91552 .38061 L

.91165 .3811 L

.90777 .38159 L

.90389 .38208 L

.90002 .38258 L

.89614 .38308 L

.89226 .38359 L

.88839 .3841 L

.88451 .38461 L

.88063 .38512 L

.87676 .38564 L

.87288 .38617 L

.869 .3867 L

.86513 .38723 L

.86125 .38777 L

.85737 .3883 L

.8535 .38885 L

.84962 .3894 L

.84574 .38995 L

.84187 .39051 L

.83799 .39107 L

.83411 .39163 L

.83024 .3922 L

.82636 .39277 L

.82248 .39335 L

.81861 .39393 L

.81473 .39452 L

.81085 .39511 L

.80698 .3957 L

.8031 .3963 L

.79922 .39691 L

.79535 .39752 L

.79147 .39813 L

.78759 .39875 L

Mistroke

.78372 .39937 L

.77984 .4 L

.77596 .40063 L

.77209 .40126 L

.76821 .4019 L

.76433 .40255 L

.76046 .4032 L

.75658 .40386 L

.75271 .40452 L

.74883 .40518 L

.74495 .40585 L

.74108 .40653 L

.7372 .40721 L

.73332 .40789 L

.72945 .40858 L

.72557 .40928 L

.72169 .40998 L

.71782 .41069 L

.71394 .4114 L

.71006 .41212 L

.70619 .41284 L

.70231 .41356 L

.69843 .4143 L

.69456 .41504 L

.69068 .41578 L

.6868 .41653 L

.68293 .41728 L

.67905 .41804 L

.67517 .41881 L

.6713 .41958 L

.66742 .42036 L

.66354 .42114 L

.65967 .42193 L

.65579 .42272 L

.65191 .42352 L

.64804 .42433 L

.64416 .42514 L

.64028 .42596 L

.63641 .42678 L

.63253 .42761 L

.62865 .42844 L

.62478 .42928 L

.6209 .43013 L

.61702 .43098 L

.61315 .43184 L

.60927 .43271 L

.60539 .43358 L

.60152 .43446 L

.59764 .43534 L

.59376 .43623 L

Mistroke

.58989 .43712 L

.58601 .43803 L

.58214 .43893 L

.57826 .43985 L

.57438 .44077 L

.57051 .4417 L

.56663 .44263 L

.56275 .44357 L

.55888 .44451 L

.555 .44546 L

.55112 .44642 L

.54725 .44739 L

.54337 .44836 L

.53949 .44933 L

.53562 .45032 L

.53174 .4513 L

.52786 .4523 L

.52399 .4533 L

.52011 .45431 L

.51623 .45532 L

.51236 .45634 L

.50848 .45737 L

.5046 .4584 L

.50073 .45944 L

.49685 .46048 L

.49297 .46153 L

.4891 .46259 L

.48522 .46365 L

.48134 .46472 L

.47747 .46579 L

.47359 .46687 L

.46971 .46796 L

.46584 .46905 L

.46196 .47014 L

.45808 .47124 L

.45421 .47235 L

.45033 .47346 L

.44645 .47458 L

.44258 .4757 L

.4387 .47683 L

.43482 .47796 L

.43095 .4791 L

.42707 .48024 L

.4232 .48138 L

.41932 .48253 L

.41544 .48369 L

.41157 .48485 L

.40769 .48601 L

.40381 .48717 L

.39994 .48834 L

Mistroke

.39606 .48951 L

.39218 .49069 L

.38831 .49186 L

.38443 .49304 L

.38055 .49422 L

.37668 .49541 L

.3728 .49659 L

.36892 .49778 L

.36505 .49897 L

.36117 .50015 L

.35729 .50134 L

.35342 .50253 L

.34954 .50372 L

.34566 .5049 L

.34179 .50609 L

.33791 .50727 L

.33403 .50845 L

.33016 .50963 L

.32628 .51081 L

.3224 .51198 L

.31853 .51315 L

.31465 .51431 L

.31077 .51546 L

.3069 .51661 L

.30302 .51776 L

.29914 .51889 L

.29527 .52002 L

.29139 .52114 L

.28751 .52224 L

.28364 .52334 L

.27976 .52442 L

.27588 .52549 L

.27201 .52655 L

.26813 .52759 L

.26425 .52862 L

.26038 .52963 L

.2565 .53061 L

.25263 .53158 L

.24875 .53253 L

.24487 .53346 L

.241 .53436 L

.23712 .53523 L

.23324 .53608 L

.22937 .5369 L

.22549 .53769 L

.22161 .53844 L

.21774 .53916 L

.21386 .53984 L

.20998 .54048 L

.20611 .54108 L

Mistroke

.20223 .54164 L

.19835 .54214 L

.19448 .5426 L

.1906 .543 L

.18672 .54335 L

.18285 .54364 L

.17897 .54386 L

.17509 .54402 L

.17122 .54411 L

.16734 .54412 L

.16346 .54405 L

.15959 .54389 L

.15571 .54365 L

.15183 .54331 L

.14796 .54287 L

.14408 .54232 L

.1402 .54166 L

.13633 .54087 L

.13245 .53996 L

.12857 .5389 L

.1247 .5377 L

.12082 .53634 L

.11694 .53482 L

.11307 .53311 L

.10919 .53121 L

.10531 .5291 L

.10144 .52677 L

.09756 .5242 L

.09369 .52137 L

.08981 .51825 L

.08593 .51483 L

.08206 .51107 L

.07818 .50694 L

.0743 .5024 L

.07043 .49741 L

.06655 .49192 L

.06267 .48585 L

.0588 .47913 L

.05492 .47165 L

.05104 .46329 L

.04717 .45387 L

.04329 .44312 L

.03941 .43068 L

.03554 .41591 L

.03166 .39761 L

.02778 .37274 L

.02391 .3162 L

.02381 .30902 L

Mfstroke

.97619 .24459 m

.97367 .24431 L

.96979 .24387 L

.96592 .24343 L

.96204 .24299 L

.95816 .24255 L

.95429 .2421 L

.95041 .24165 L

.94653 .24119 L

.94266 .24073 L

.93878 .24027 L

.9349 .2398 L

.93103 .23933 L

.92715 .23886 L

.92328 .23839 L

.9194 .23791 L

.91552 .23742 L

.91165 .23694 L

.90777 .23645 L

.90389 .23595 L

.90002 .23545 L

.89614 .23495 L

.89226 .23445 L

.88839 .23394 L

.88451 .23343 L

.88063 .23291 L

.87676 .23239 L

.87288 .23187 L

.869 .23134 L

.86513 .2308 L

.86125 .23027 L

.85737 .22973 L

.8535 .22918 L

.84962 .22864 L

.84574 .22808 L

.84187 .22753 L

.83799 .22697 L

.83411 .2264 L

.83024 .22583 L

.82636 .22526 L

.82248 .22468 L

.81861 .2241 L

.81473 .22352 L

.81085 .22292 L

.80698 .22233 L

.8031 .22173 L

.79922 .22113 L

.79535 .22052 L

.79147 .21991 L

.78759 .21929 L

Mistroke

.78372 .21867 L

.77984 .21804 L

.77596 .21741 L

.77209 .21677 L

.76821 .21613 L

.76433 .21548 L

.76046 .21483 L

.75658 .21418 L

.75271 .21352 L

.74883 .21285 L

.74495 .21218 L

.74108 .21151 L

.7372 .21083 L

.73332 .21014 L

.72945 .20945 L

.72557 .20875 L

.72169 .20805 L

.71782 .20735 L

.71394 .20664 L

.71006 .20592 L

.70619 .2052 L

.70231 .20447 L

.69843 .20374 L

.69456 .203 L

.69068 .20225 L

.6868 .20151 L

.68293 .20075 L

.67905 .19999 L

.67517 .19923 L

.6713 .19845 L

.66742 .19768 L

.66354 .19689 L

.65967 .19611 L

.65579 .19531 L

.65191 .19451 L

.64804 .19371 L

.64416 .1929 L

.64028 .19208 L

.63641 .19126 L

.63253 .19043 L

.62865 .18959 L

.62478 .18875 L

.6209 .1879 L

.61702 .18705 L

.61315 .18619 L

.60927 .18533 L

.60539 .18446 L

.60152 .18358 L

.59764 .18269 L

.59376 .18181 L

Mistroke

.58989 .18091 L

.58601 .18001 L

.58214 .1791 L

.57826 .17819 L

.57438 .17727 L

.57051 .17634 L

.56663 .17541 L

.56275 .17447 L

.55888 .17352 L

.555 .17257 L

.55112 .17161 L

.54725 .17065 L

.54337 .16968 L

.53949 .1687 L

.53562 .16772 L

.53174 .16673 L

.52786 .16573 L

.52399 .16473 L

.52011 .16373 L

.51623 .16271 L

.51236 .16169 L

.50848 .16067 L

.5046 .15963 L

.50073 .1586 L

.49685 .15755 L

.49297 .1565 L

.4891 .15545 L

.48522 .15438 L

.48134 .15332 L

.47747 .15224 L

.47359 .15116 L

.46971 .15008 L

.46584 .14899 L

.46196 .14789 L

.45808 .14679 L

.45421 .14568 L

.45033 .14457 L

.44645 .14345 L

.44258 .14233 L

.4387 .1412 L

.43482 .14007 L

.43095 .13894 L

.42707 .1378 L

.4232 .13665 L

.41932 .1355 L

.41544 .13435 L

.41157 .13319 L

.40769 .13203 L

.40381 .13086 L

.39994 .12969 L

Mistroke

.39606 .12852 L

.39218 .12735 L

.38831 .12617 L

.38443 .12499 L

.38055 .12381 L

.37668 .12263 L

.3728 .12144 L

.36892 .12025 L

.36505 .11907 L

.36117 .11788 L

.35729 .11669 L

.35342 .1155 L

.34954 .11432 L

.34566 .11313 L

.34179 .11194 L

.33791 .11076 L

.33403 .10958 L

.33016 .1084 L

.32628 .10723 L

.3224 .10605 L

.31853 .10489 L

.31465 .10373 L

.31077 .10257 L

.3069 .10142 L

.30302 .10028 L

.29914 .09914 L

.29527 .09802 L

.29139 .0969 L

.28751 .09579 L

.28364 .0947 L

.27976 .09361 L

.27588 .09254 L

.27201 .09148 L

.26813 .09044 L

.26425 .08942 L

.26038 .08841 L

.2565 .08742 L

.25263 .08645 L

.24875 .0855 L

.24487 .08458 L

.241 .08368 L

.23712 .0828 L

.23324 .08195 L

.22937 .08113 L

.22549 .08035 L

.22161 .07959 L

.21774 .07887 L

.21386 .07819 L

.20998 .07755 L

.20611 .07695 L

Mistroke

.20223 .0764 L

.19835 .07589 L

.19448 .07543 L

.1906 .07503 L

.18672 .07468 L

.18285 .07439 L

.17897 .07417 L

.17509 .07401 L

.17122 .07393 L

.16734 .07392 L

.16346 .07399 L

.15959 .07414 L

.15571 .07438 L

.15183 .07472 L

.14796 .07517 L

.14408 .07571 L

.1402 .07638 L

.13633 .07716 L

.13245 .07808 L

.12857 .07913 L

.1247 .08033 L

.12082 .08169 L

.11694 .08322 L

.11307 .08492 L

.10919 .08682 L

.10531 .08893 L

.10144 .09126 L

.09756 .09383 L

.09369 .09666 L

.08981 .09978 L

.08593 .1032 L

.08206 .10696 L

.07818 .11109 L

.0743 .11563 L

.07043 .12062 L

.06655 .12612 L

.06267 .13218 L

.0588 .1389 L

.05492 .14638 L

.05104 .15474 L

.04717 .16417 L

.04329 .17491 L

.03941 .18735 L

.03554 .20212 L

.03166 .22042 L

.02778 .2453 L

.02391 .30183 L

.02381 .30902 L

Mfstroke

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{567, 350.313},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.776525,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008g0001GPP10`40000100000800002008200000

P800P020P<30`<3L`:K:l00003<006H009T00<`00?l0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV

09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<003o03?o06Ko09Wo0<co

0?oo0000<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I

<c>I<fJI<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0

IYT0I/`0I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bI

I_nIIP3<IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0c

VC<cVFHcVITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<

VIW<VLc<VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`c

c?lcc01Vc3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03o

c3?oc6Koc9Woc<coc?ooc000oc<0ofH0oiT0ol`0ool0o`0coc<cofHcoiTcol`coolco`1Voc=VofIV

oiUVolaVoomVo`2Ioc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<o`3ooc?oofKooiWoolco

ooooo`0000410@820P<30`@410D51@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C

4a@D5?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooa[Q00<0hN40on7ohAcQ000Jh@030>7Q0?oQ

on4Lh@006^400`3Qh@3ohOoQ7>4001[Q00<0hN40on7ohAcQ000Jh@030>7Q0?oQon4Lh@006^400`3Q

h@3ohOoQ7>4001[Q00<0hN40on7ohAcQ000Jh@030>7Q0?oQon4Lh@006^400`3Qh@3YhAFnon4Mh@00

6^400`3Qh@3Sh@Jn5N47__oQ5^4001[Q00<0hN40gn44_R;Q1[kohA3Q000Jh@030>7Q0=cQ0kh/h@Bn

on4<h@006^430=WQ0khch@Bnon48h@006^400`3Qh@3Gh@:n>^44__oQ1>4001[Q00<0hN40eN42_T3Q

1;koh@006^400`3Qh@3Dh@03_^7Q04CQ0kklh@006^400`3Qh@3Bh@:nB^43__WQ000Jh@030>7Q0=3Q

0[i?h@>nm^4001[Q00<0hN40cn400kkQh@1Bh@Bnl^4001[Q00<0hN40c^400kkQh@1Gh@>nkn4001[Q

00<0hN40cN400kkQh@1Kh@>nk>4001[Q00<0hN40bn42_V7Q0[kZh@006^400`3Qh@3:h@03_^7Q06?Q

0kkWh@006^400`3Qh@39h@03_^7Q06OQ0kkTh@006^430<SQ00>nhN40Jn43_^7Q000Jh@030>7Q0<OQ

00>nhN40Kn43_]kQ000Jh@030>7Q0<KQ00>nhN40Ln42_]cQ000Jh@030>7Q0<GQ00>nhN40M^43_]WQ

000Jh@030>7Q0<CQ00>nhN40N^43_]KQ000Jh@030>7Q0<CQ00>nhN40ON43_]?Q000Jh@030>7Q0<?Q

00>nhN40PN42_]7Q000Jh@030>7Q0<;Q00>nhN40Q>43_/kQ000Jh@030>7Q0<7Q00>nhN40R>43_/_Q

000Jh@030>7Q0<3Q00>nhN40S>42_/WQ000Jh@030>7Q0<3Q00>nhN40S^43_/KQ000:h@D00^400`3Q

h@06h@030>7Q0;oQ00>nhN40T^43_/?Q000<h@070>7Qh@3Q0007h@030>7Q0;kQ00>nhN40U^42_/7Q

0006h@<00n401`3QhN40h@001n450;cQ00>nhN40V>43_[kQ000<h@070>7Qh@3Q0007h@030>7Q0;gQ

00>nhN40W>42_[cQ000<h@070>7Qh@3Q0007h@030>7Q04CQ70mMh@03_^7Q09kQ0kjih@002n4200CQ

00<0hN401^400`3Qh@10h@@?7>483eCQ00>nhN40X^43_[KQ000Jh@030>7Q03cQ10lXh@H?CN400kkQ

h@2Vh@:n]>4001[Q00<0hN40>^423c;Q10m9h@03_^7Q0:SQ0kjah@006^400`3Qh@0fh@@?>>443dCQ

00>nhN40[>43_ZkQ000Jh@030>7Q03CQ0Pm0h@@?@>400kkQh@2_h@>nZn4001[Q00<0hN40<^423dKQ

10lkh@03_^7Q0;?Q0[jYh@006^400`3Qh@0`h@8?C>443cOQ00>nhN40]N43_ZKQ000Jh@030>7Q02kQ

0PmBh@@?<^400kkQh@2ih@>nXn4001[Q00<0hN40;N400`oQh@1Fh@@?;^400kkQh@2lh@:nXN4001[Q

0`0/h@033n7Q05_Q10lYh@03_^7Q0;oQ0kjNh@006^400`3Qh@0Zh@8?H^443bGQ00>nhN40`^43_Y_Q

000Jh@030>7Q02WQ00<?hN40I^423b;Q00>nhN40a^43_YSQ000Jh@030>7Q02SQ00<?hN40JN443akQ

00>nhN40bN42_YKQ000Jh@030>7Q02OQ00<?hN40K^443a[Q00>nhN40bn43_Y?Q000Jh@030>7Q02KQ

00<?hN40Ln423aOQ00>nhN40cn43_Y3Q000Jh@030>7Q02GQ00<?hN40M^443a?Q00>nhN40d^43_XgQ

000Jh@030>7Q02CQ00<?hN40Nn443`kQ00>nhN40e^43_X[Q000Jh@030>7Q02?Q00<?hN40P>423`cQ

00>nhN40fN43_XOQ000Jh@030>7Q02;Q00<?hN40Pn443`SQ00>nhN40g>43_XCQ000Jh@030>7Q027Q

00<?hN40R>443`?Q00>nhN40h>43_X7Q000Jh@030>7Q023Q00<?hN40SN423`03hKkQ0>CQ0kinh@00

6^4301oQ00<?hN40T>443nKQ0kikh@006^400`3Qh@0Oh@033n7Q093Q00BnhN7Q0PoWh@>nN>4001[Q

00<0hN407^400`oQh@2Ah@03_^7Q00?Q10oVh@>nMN4001[Q00<0hN407N400`oQh@2Bh@03_^7Q00OQ

10oUh@>nL^4001[Q00<0hN407N400`oQh@2Ah@03_^7Q00cQ0PoVh@>nKn4001[Q00<0hN407>400`oQ

h@2Bh@03_^7Q00kQ10oUh@>nK>4001[Q00<0hN406n400`oQh@2Ch@03_^7Q01;Q10oTh@>nJN4001[Q

00<0hN406n400`oQh@2Bh@03_^7Q01OQ0PoUh@>nI^4001[Q00<0hN406^400`oQh@2Ch@03_^7Q01WQ

10oTh@>nHn4001[Q00<0hN406N400`oQh@2Dh@03_^7Q01gQ10oSh@FnG^4001[Q00<0hN406N400`oQ

h@2Ch@03_^7Q02;Q0PoVh@>nFn4001[Q00<0hN406>400`oQh@2Dh@03_^7Q02CQ10oUh@>nF>4001[Q

00<0hN405n400`oQh@2Eh@03_^7Q02SQ10oTh@BnE>4001[Q0`0Gh@033n7Q09CQ00>nhN40;N423nKQ

0kiAh@006^400`3Qh@0Fh@033n7Q09GQ00>nhN40;n443nGQ0ki>h@006^400`3Qh@0Fh@033n7Q09GQ

00>nhN40<n443nCQ1;i:h@006^400`3Qh@0Eh@033n7Q09KQ00>nhN40=n443nCQ0ki7h@006^400`3Q

h@0Eh@033n7Q09GQ00>nhN40?>423nGQ1;i3h@006^400`3Qh@0Dh@033n7Q09KQ00>nhN40?^443nGQ

1;hoh@006^400`3Qh@0Dh@033n7Q09KQ00>nhN40@^443nGQ0khlh@006^400`3Qh@0Dh@033n7Q09KQ

00>nhN40A^443nCQ1;hhh@006^400`3Qh@0Ch@033n7Q09KQ00>nhN40Bn443nCQ1;hdh@006^400`3Q

h@0Ch@033n7Q09KQ00>nhN40Cn443nCQ0khah@006^400`3Qh@0Bh@033n7Q09OQ00>nhN40Dn423nGQ

1;h]h@006^400`3Qh@0Bh@033n7Q09OQ00>nhN40EN443nGQ1;hYh@006^4301;Q00<?hN40Un400kkQ

h@1Ih@@?iN44_RGQ000Jh@030>7Q017Q00<?hN40Un400kkQh@1Nh@@?on4;h@006^400`3Qh@0Ah@03

3n7Q09OQ00>nhN40H^443ooQ1n4001[Q00<0hN404N400`oQh@2Gh@03_^7Q06KQ10ooh@?Q000Jh@03

0>7Q013Q00<?hN40V>400kkQh@1Zh@@?o^4001[Q00<0hN404>400`oQh@2Hh@03_^7Q06kQ10ojh@00

6^400`3Qh@0@h@033n7Q09OQ00>nhN40Ln453oGQ000Jh@030>7Q00oQ00<?hN40V>400kkQh@1hh@H?

kn4001[Q00<0hN403n400`oQh@2Hh@03_^7Q07kQ10o[h@006^400`3Qh@0?h@033n7Q09SQ00>nhN40

P^443nOQ000Ah@030>7Q00KQ00<0hN403^400`oQh@2Ih@03_^7Q08KQ10oSh@004>400`3Q0007h@03

0>7Q00kQ00<?hN40V>400kkQh@2;h@@?gn4000_Q0`04h@030>7Q00GQ1@0<h@033n7Q09SQ00>nhN40

Sn463mWQ000@h@802>400`3Qh@0=h@033n7Q09WQ00>nhN40UN443mGQ000@h@030>7Q00OQ00<0hN40

3N400`oQh@2Ih@03_^7Q09WQ10oAh@004>4300OQ00<0hN403N400`oQh@2Ih@03_^7Q09gQ1Po;h@00

6^400`3Qh@0=h@033n7Q09WQ00>nhN40Xn443lOQ000Jh@030>7Q00cQ00<?hN40VN400kkQh@2Xh@H?

`N4001[Q00<0hN403>400`oQh@2Ih@03_^7Q0:kQ10nmh@006^400`3Qh@0<h@033n7Q09WQ00>nhN40

/^463kOQ000Jh@030>7Q00cQ00<?hN40VN400kkQh@2hh@@?/n4001[Q00<0hN403>400`oQh@2Ih@03

_^7Q0;cQ1Pn]h@006^400`3Qh@0;h@033n7Q09[Q00>nhN40`^463jOQ000Jh@030>7Q00_Q00<?hN40

V^400kkQh@38h@H?XN4001[Q00<0hN402n400`oQh@2Ih@03_^7Q0<oQ10nMh@006^4300_Q00<?hN40

VN400kkQh@3Ch@H?Un4001[Q00<0hN402^400`oQh@2Jh@03_^7Q0=WQ1PnAh@006^400`3Qh@0:h@03

3n7Q09[Q00>nhN40gn463h_Q000Jh@030>7Q00[Q00<?hN40V^400kkQh@3Uh@P?Pn4001[Q00<0hN40

2^400`oQh@2Jh@03_^7Q0>gQ1Pmmh@006^400`3Qh@0:h@033n7Q09[Q00>nhN40ln463gOQ000Jh@03

0>7Q00[Q00<?hN40V^400kkQh@3ih@H?LN4001[Q00<0hN402N400`oQh@2Jh@03_^7Q0?oQ0N483fWQ

000Jh@030>7Q00WQ00<?hN40V^400kkQh@3oh@WQ1PmSh@006^400`3Qh@09h@033n7Q09[Q00>nhN40

on4?h@P?Fn4001[Q00<0hN402N400`oQh@2Jh@03_^7Q0?oQ5n483e?Q000Jh@030>7Q00WQ00<?hN40

V^400kkQh@3ohAoQ20m;h@006^4300WQ00<?hN40V^400kkQh@3ohBOQ1Pm5h@006^400`3Qh@08h@03

3n7Q09_Q00>nhN40on4]h@X?>n4001[Q00<0hN402>400`oQh@2Kh@03_^7Q0?oQ=n483c?Q000Jh@03

0>7Q00SQ00<?hN40Vn400kkQh@3ohCoQ20l[h@006^400`3Qh@08h@033n7Q09_Q00>nhN40on57h@H?

9N4001[Q00<0hN402>400`oQh@2Kh@03_^7Q0?oQL^4001[Q00<0hN402>400`oQh@2Jh@03_^7Q0?oQ

Ln4001[Q00<0hN402>400`oQh@2Jh@03_^7Q0?oQLn4001[Q00<0hN402>400`oQh@2Jh@03_^7Q0?oQ

Ln4001[Q00<0hN402>400`oQh@2Jh@03_^7Q0?oQLn4001[Q00<0hN402>400`oQh@2Jh@03_^7Q0?oQ

Ln4001[Q00<0hN402>400`oQh@2Jh@03_^7Q0?oQLn4001[Q00<0hN401n400`oQh@2Kh@03_^7Q0?oQ

Ln4001[Q0`07h@033n7Q09_Q00>nhN40on5ch@006^400`3Qh@07h@033n7Q09_Q00>nhN40on5ch@00

6^400`3Qh@07h@033n7Q09_Q00>nhN40on5ch@006^400`3Qh@07h@033n7Q09_Q00>nhN40on5ch@00

6^400`3Qh@07h@033n7Q09_Q00>nhN40on5ch@006^400`3Qh@07h@033n7Q09_Q00>nhN40on5ch@00

6^400`3Qh@07h@033n7Q09_Q00>nhN40on5ch@006^400`3Qh@07h@033n7Q09_Q00>nhN40on5ch@00

6^400`3Qh@07h@033n7Q09_Q00>nhN40on5ch@006^400`3Qh@07h@033n7Q09_Q00>nhN40on5ch@00

6^400`3Qh@07h@033n7Q05?Q1@001>40000oh@03_^7Q01WQ1@02h@<0Fn450003h@0005cQ1@02h@03

0>7Q05cQ0`03h@030>7Q027Q000Jh@030>7Q00OQ00<?hN40EN401@3QhN40047Q00>nhN406n400`3Q

h@03h@030>7Q05cQ00L0hN7Q0>4005gQ00L0hN7Q0>4005gQ00<0hN400^400`3Q000Rh@006^4300OQ

00<?hN40EN400`3Qh@02h@030>7Q03gQ00>nhN407>40103QhN4405gQ00L0hN7Q0>4005gQ00L0hN7Q

0>4005kQ00L0hN7Q0>4002;Q000Jh@030>7Q00OQ00<?hN40EN400`3Qh@02h@030>7Q03gQ00>nhN40

7>401`3QhN40h@00G^40103QhN4205kQ00<0hN400^400`3Qh@1Mh@070>7Qh@3Q000Rh@006^400`3Q

h@06h@033n7Q05KQ00L0hN7Q0>4003kQ00>nhN407>400`3Qh@02h@80G^401@3QhN4005oQ00L0hN7Q

0>4005gQ00<0h@000^400`3Q000Rh@006^400`3Qh@06h@033n7Q05GQ0P04h@030>7Q03gQ00>nhN40

6n4200GQ00<0hN40Fn4200CQ0P1Lh@801>400`3Qh@1Mh@030>7Q00;Q00<0hN408N4001[Q00<0hN40

1^400`oQh@2Kh@03_^7Q0?oQM>4001[Q00<0hN401^400`oQh@2Kh@03_^7Q0?oQM>4001[Q00<0hN40

1^400`oQh@2Kh@03_^7Q0?oQM>4001[Q00<0hN401^400`oQh@2Kh@03_^7Q0?oQM>4001[Q00<0hN40

1^400`oQh@2Kh@03_^7Q0?oQM>4001[Q00<0hN401^400`oQh@2Kh@03_^7Q0?oQM>4001[Q00<0hN40

1^400`oQh@2Kh@03_^7Q0?oQJ^4400KQ000Jh@030>7Q00KQ00<?hN40Vn400kkQh@3ohF[Q0`07h@00

5n4<00033`0009/000>n0000o`1K017Q00<0hN401N4001[Q00<0hN401^400`oQh@0>h@030>7Q01KQ

00<0hN405^400`3Qh@0Fh@030>7Q01KQ00<0hN405^400`3Qh@0=h@03_^7Q00KQ00<0hN405^400`3Q

h@0Fh@030>7Q01OQ00<0hN405^400`3Qh@0Fh@030>7Q01KQ00<0hN405^400`3Qh@0Fh@030>7Q01KQ

00<0hN405^400`3Qh@0Gh@030>7Q01KQ00<0hN405^400`3Qh@0Jh@801n4001[Q00<0hN401^400`oQ

h@0>h@030>7Q01KQ00<0hN405^400`3Qh@0Fh@030>7Q01KQ00<0hN405^400`3Qh@0=h@03_^7Q00KQ

00<0hN405^400`3Qh@0Fh@030>7Q01OQ00<0hN405^400`3Qh@0Fh@030>7Q01KQ00<0hN405^400`3Q

h@0Fh@030>7Q01KQ00<0hN405^400`3Qh@0Gh@030>7Q01KQ00<0hN405^400`3Qh@0Sh@006^400`3Q

h@06h@033n7Q05WQ00<0hN40?n400kkQh@0Oh@030>7Q06;Q00<0hN40HN400`3Qh@1Rh@030>7Q02?Q

000Jh@030>7Q00KQ00<?hN40FN400`3Qh@0oh@03_^7Q01oQ00<0hN40H^400`3Qh@1Qh@030>7Q06;Q

00<0hN408n4001[Q00<0hN401^400`oQh@2Kh@03_^7Q0?oQM>4001[Q00<0hN401^400`oQh@2Kh@03

_^7Q0?oQM>4001[Q00<0hN401^400`oQh@2Kh@03_^7Q0?oQM>4001[Q00<0hN401^400`oQh@2Kh@03

_^7Q0?oQM>4001[Q00<0hN401^400`oQh@2Kh@03_^7Q0?oQM>4001[Q00<0hN401^400`oQh@2Kh@03

_^7Q0?oQM>4001[Q00<0hN401^400`oQh@2Kh@03_^7Q0?oQM>4001[Q00<0hN401n400`oQh@2Jh@03

_^7Q0?oQM>4001[Q0`07h@033n7Q09[Q00>nhN40on5dh@006^400`3Qh@07h@033n7Q09_Q00>nhN40

on5ch@006^400`3Qh@07h@033n7Q09_Q00>nhN40on5ch@006^400`3Qh@07h@033n7Q09_Q00>nhN40

on5ch@006^400`3Qh@07h@033n7Q09_Q00>nhN40on5ch@006^400`3Qh@07h@033n7Q09_Q00>nhN40

on5ch@006^400`3Qh@07h@033n7Q09_Q00>nhN40on5ch@006^400`3Qh@07h@033n7Q09_Q00>nhN40

on5ch@006^400`3Qh@07h@033n7Q09_Q00>nhN40on5ch@006^400`3Qh@07h@033n7Q09_Q00>nhN40

on5ch@006^400`3Qh@07h@033n7Q09_Q00>nhN40on5ch@006^400`3Qh@07h@033n7Q09_Q00>nhN40

on5ch@006^4300OQ00<?hN40Vn400kkQh@3ohG?Q000Jh@030>7Q00SQ00<?hN40V^400kkQh@3ohG?Q

000Jh@030>7Q00SQ00<?hN40V^400kkQh@3ohG?Q000Jh@030>7Q00SQ00<?hN40V^400kkQh@3ohG?Q

000Jh@030>7Q00SQ00<?hN40V^400kkQh@3ohG?Q000Jh@030>7Q00SQ00<?hN40V^400kkQh@3ohG?Q

000Jh@030>7Q00SQ00<?hN40V^400kkQh@3ohG?Q000Jh@030>7Q00SQ00<?hN40V^400kkQh@3ohG?Q

000Jh@030>7Q00SQ00<?hN40Vn400kkQh@3ohG;Q000Jh@030>7Q00SQ00<?hN40Vn400kkQh@3ohDKQ

1`lUh@006^400`3Qh@08h@033n7Q09_Q00>nhN40on4nh@P?;>4001[Q00<0hN402>400`oQh@2Kh@03

_^7Q0?oQ=>4:3cCQ000Jh@<02N400`oQh@2Jh@03_^7Q0?oQ;>483ckQ000Jh@030>7Q00WQ00<?hN40

V^400kkQh@3ohBCQ20m6h@006^400`3Qh@09h@033n7Q09[Q00>nhN40on4Nh@H?C^4001[Q00<0hN40

2N400`oQh@2Jh@03_^7Q0?oQ5^483eCQ000Jh@030>7Q00WQ00<?hN40V^400kkQh@3oh@kQ20mLh@00

6^400`3Qh@09h@033n7Q09[Q00>nhN40on48h@H?I>4001[Q00<0hN402^400`oQh@2Ih@03_^7Q0?oQ

20mZh@006^400`3Qh@0:h@033n7Q09[Q00>nhN40n>463g;Q000Jh@030>7Q00[Q00<?hN40V^400kkQ

h@3bh@H?N>4001[Q00<0hN402^400`oQh@2Jh@03_^7Q0>cQ1Pmnh@006^400`3Qh@0:h@033n7Q09[Q

00>nhN40i^463hCQ000Jh@030>7Q00[Q00<?hN40V^400kkQh@3Ph@H?R^4001[Q00<0hN402n400`oQ

h@2Ih@03_^7Q0=[Q1Pn@h@006^4300_Q00<?hN40VN400kkQh@3Dh@H?U^4001[Q00<0hN402n400`oQ

h@2Ih@03_^7Q0<kQ1PnLh@006^400`3Qh@0;h@033n7Q09[Q00>nhN40an463j;Q000Jh@030>7Q00_Q

00<?hN40V^400kkQh@31h@H?Z>4001[Q00<0hN403>400`oQh@2Ih@03_^7Q0;gQ10n^h@006^400`3Q

h@0<h@033n7Q09WQ00>nhN40]n463k;Q000Jh@030>7Q00cQ00<?hN40VN400kkQh@2ah@H?^>4001[Q

00<0hN403>400`oQh@2Ih@03_^7Q0:gQ10nnh@006^400`3Qh@0=h@033n7Q09SQ00>nhN40Yn463l;Q

000Jh@030>7Q00gQ00<?hN40VN400kkQh@2Rh@@?b>40017Q00<0hN401^400`3Qh@0=h@033n7Q09WQ

00>nhN40W^443lcQ000@h@030>4000OQ00<0hN403N400`oQh@2Ih@03_^7Q09SQ1Po@h@004^400`3Q

h@05h@D03>400`oQh@2Hh@03_^7Q09CQ10oFh@004>4200SQ00<0hN403^400`oQh@2Hh@03_^7Q093Q

10oJh@004>400`3Qh@07h@030>7Q00kQ00<?hN40V>400kkQh@2:h@H?g^40013Q0`07h@030>7Q00oQ

00<?hN40V>400kkQh@25h@@?i>4001[Q00<0hN403n400`oQh@2Hh@03_^7Q087Q10oXh@006^400`3Q

h@0?h@033n7Q09SQ00>nhN40ON443ncQ000Jh@030>7Q00oQ00<?hN40V>400kkQh@1hh@D?l>4001[Q

00<0hN404>400`oQh@2Gh@03_^7Q07CQ10oeh@006^400`3Qh@0@h@033n7Q09SQ00>nhN40Kn443oWQ

000Jh@030>7Q013Q00<?hN40V>400kkQh@1[h@@?oN4001[Q00<0hN404N400`oQh@2Gh@03_^7Q06OQ

10ooh@;Q000Jh@030>7Q017Q00<?hN40Un400kkQh@1Sh@@?on46h@006^400`3Qh@0Bh@033n7Q09KQ

00>nhN40Gn443n?Q00>nhN408n4001[Q0`0Bh@033n7Q09OQ00>nhN40F^443n?Q1;hVh@006^400`3Q

h@0Bh@033n7Q09OQ00>nhN40E^443n?Q1;hZh@006^400`3Qh@0Ch@033n7Q09KQ00>nhN40D^443n?Q

1;h^h@006^400`3Qh@0Ch@033n7Q09KQ00>nhN40C^443nCQ0khbh@006^400`3Qh@0Dh@033n7Q09GQ

00>nhN40B^443nCQ1;heh@006^400`3Qh@0Dh@033n7Q09KQ00>nhN40An423nCQ1;hih@006^400`3Q

h@0Dh@033n7Q09KQ00>nhN40@n443n?Q0khmh@006^400`3Qh@0Eh@033n7Q09GQ00>nhN40?n443n?Q

1;i0h@006^400`3Qh@0Eh@033n7Q09GQ00>nhN40>n443n?Q1;i4h@006^400`3Qh@0Fh@033n7Q09GQ

00>nhN40=^443nCQ0ki8h@006^400`3Qh@0Fh@033n7Q09GQ00>nhN40=>423nCQ1;i;h@006^400`3Q

h@0Fh@033n7Q09GQ00>nhN40<>443n?Q0ki?h@006^4301OQ00<?hN40U>400kkQh@0/h@@?i>43_U;Q

000Jh@030>7Q01OQ00<?hN40UN400kkQh@0Yh@8?i>44_UGQ000Jh@030>7Q01SQ00<?hN40U>400kkQ

h@0Uh@@?hn43_UWQ000Jh@030>7Q01WQ00<?hN40Tn400kkQh@0Qh@@?i>43_UcQ000Jh@030>7Q01WQ

00<?hN40U>400kkQh@0Nh@8?i>44_UoQ000Jh@030>7Q01[Q00<?hN40Tn400kkQh@0Jh@@?h^44_V?Q

000Jh@030>7Q01_Q00<?hN40T^400kkQh@0Fh@@?hn43_VOQ000Jh@030>7Q01_Q00<?hN40Tn400kkQ

h@0Ch@8?i>43_V[Q000Jh@030>7Q01cQ00<?hN40T^400kkQh@0?h@@?hn43_VgQ000Jh@030>7Q01gQ

00<?hN40TN400kkQh@0;h@@?i>43_W3Q000Jh@030>7Q01gQ00<?hN40T^400kkQh@08h@8?iN43_W?Q

000Jh@030>7Q01kQ00<?hN40TN400kkQh@04h@@?i>43_WKQ000Jh@<07n400`oQh@2@h@03_^7Q00@?

iN43_WWQ000Jh@030>7Q01oQ00<?hN40TN423nKQ0kilh@006^400`3Qh@0Ph@033n7Q08cQ10l00kkQ

h@3Rh@>nOn4001[Q00<0hN408N400`oQh@29h@8?1>400kkQh@3Oh@>nP^4001[Q00<0hN408^400`oQ

h@24h@@?1n400kkQh@3Kh@>nQN4001[Q00<0hN408n400`oQh@1oh@@?2n400kkQh@3Hh@>nR>4001[Q

00<0hN409>400`oQh@1lh@8?3n400kkQh@3Eh@>nRn4001[Q00<0hN409N400`oQh@1gh@@?4^400kkQ

h@3Ah@>nS^4001[Q00<0hN409^400`oQh@1bh@@?5^400kkQh@3?h@:nTN4001[Q00<0hN409n400`oQ

h@1_h@8?6n400kkQh@3;h@>nTn4001[Q00<0hN40:>400`oQh@1Zh@@?7N400kkQh@38h@>nU^4001[Q

00<0hN40:N423fKQ10lRh@03_^7Q0<CQ0kjIh@006^400`3Qh@0[h@033n7Q05oQ10lVh@03_^7Q0<7Q

0kjLh@006^4302cQ00<?hN40G>423b[Q00>nhN40_n42_YoQ000Jh@030>7Q02gQ0PmHh@@?;N400kkQ

h@2kh@>nXN4001[Q00<0hN40;n423e;Q10lah@03_^7Q0;SQ0kjTh@006^400`3Qh@0ah@033n7Q04_Q

10lfh@03_^7Q0;CQ0kjWh@006^400`3Qh@0bh@033n7Q04KQ10ljh@03_^7Q0;;Q0[jZh@006^400`3Q

h@0ch@@?@>443coQ00>nhN40[^43_ZcQ000Jh@030>7Q03OQ0Plhh@H?@n400kkQh@2[h@>n[n4001[Q

00<0hN40>N423c;Q10m:h@03_^7Q0:SQ0[jbh@006^400`3Qh@0kh@@?:>463doQ00>nhN40Y>43_[CQ

000Jh@030>7Q03oQ1PlJh@P?EN400kkQh@2Qh@>n]n4000[Q1@02h@030>7Q00KQ00<0hN40AN4J3ekQ

00>nhN40W^42_[[Q000<h@070>7Qh@3Q0007h@030>7Q0;gQ00>nhN40Vn43_[cQ000<h@070>7Qh@3Q

0007h@D0_>400kkQh@2Gh@>n_n4000cQ00L0hN7Q0>4000OQ00<0hN40_n400kkQh@2Dh@:n`^4000cQ

00L0hN7Q0>4000OQ00<0hN40_n400kkQh@2Ah@>na>4000_Q0P04h@030>7Q00KQ00<0hN40`>400kkQ

h@2=h@>nan4001[Q00<0hN40`N400kkQh@2:h@:nb^4001[Q00<0hN40`N400kkQh@27h@>nc>4001[Q

00<0hN40`^400kkQh@23h@>ncn4001[Q00<0hN40`n400kkQh@20h@:nd^4001[Q00<0hN40a>400kkQ

h@1lh@>ne>4001[Q00<0hN40aN400kkQh@1hh@>nen4001[Q00<0hN40a^400kkQh@1eh@:nf^4001[Q

00<0hN40an400kkQh@1ah@>ng>4001[Q0`37h@03_^7Q06kQ0kkOh@006^400`3Qh@38h@:nJn43_^;Q

000Jh@030>7Q0<[Q00>nhN40I^42_^GQ000Jh@030>7Q0<_Q00>nhN40H^43_^OQ000Jh@030>7Q0<cQ

00>nhN40G^43_^[Q000Jh@030>7Q0<gQ00>nhN40F^43_^gQ000Jh@030>7Q0<kQ00>nhN40E^43__3Q

000Jh@030>7Q0<oQ0[iCh@>nln4001[Q00<0hN40dN400kkQh@1<h@Bnm^4001[Q00<0hN40d^42_TWQ

0kkjh@006^400`3Qh@3Dh@:nA>43__gQ000Jh@030>7Q0=KQ0[hnh@Bnon41h@006^400`3Qh@3Hh@:n

>>44__oQ1N4001[Q0`3Jh@>n<N44__oQ2N4001[Q00<0hN40gN43_RWQ1Kkoh@gQ000Jh@030>7Q0>3Q

1;hPh@Fnon4Bh@006^400`3Qh@3Th@Nn4N48__oQ5n4001[Q00<0hN40jn4A__oQ7n4001[Q00<0hN40

on7ohAcQ000Jh@030>7Q0?oQon4Lh@006^400`3Qh@3ohOoQ7>4001[Q00<0hN40on7ohAcQ000Jh@03

0>7Q0?oQon4Lh@006^400`3Qh@3ohOoQ7>4001[Q00<0hN40on7ohAcQ000Jh@030>7Q0?oQon4Lh@00

on7ohCWQ003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ

>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQ4n420004h@00h@@00^400`3Qh@3ohAOQ003ohACQ

00<0h@001n400`3Q003ohASQ003ohACQ0`02h@@000CQ0>40on4Hh@00on4Dh@040>4000KQ00<0h@00

on4Hh@006>420?WQ00<0hN401n400`3Q003ohASQ000Ih@030>7Q0?KQ0P0:h@030>7Q0?oQ5n4001OQ

0`02h@030>7Q0?oQon4Jh@005^40203Qh@3Q0>40on7ohA_Q000Fh@080>7Q0>40h@3ohOoQ6n4001OQ

0`001>40h@3ohOoQ6n4001_Q00<0h@00on7ohA_Q000Lh@030>7Q0?oQon4Jh@00on7ohCWQ003ohOoQ

>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400001\

\>"],

  ImageRangeCache->{{{73.4375, 526}, {423.375, 144.125}} -> {7.63414, 

  1.62551, 0.0199214, 0.0808776}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-0.849469 0.0730264 0.309017 0.0238087 [

[.1729 .29652 -6 -9 ]

[.1729 .29652 6 0 ]

[.31895 .29652 -6 -9 ]

[.31895 .29652 6 0 ]

[.46501 .29652 -6 -9 ]

[.46501 .29652 6 0 ]

[.61106 .29652 -6 -9 ]

[.61106 .29652 6 0 ]

[.75711 .29652 -6 -9 ]

[.75711 .29652 6 0 ]

[.90316 .29652 -6 -9 ]

[.90316 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01435 .07093 -18 -4.5 ]

[.01435 .07093 0 4.5 ]

[.01435 .18997 -12 -4.5 ]

[.01435 .18997 0 4.5 ]

[.01435 .42806 -6 -4.5 ]

[.01435 .42806 0 4.5 ]

[.01435 .5471 -12 -4.5 ]

[.01435 .5471 0 4.5 ]

[.02685 .64303 -7 0 ]

[.02685 .64303 7 16 ]

[.5 .63053 -12 0 ]

[.5 .63053 12 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.1729 .30902 m

.1729 .31527 L

s

[(14)] .1729 .29652 0 1 Mshowa

.31895 .30902 m

.31895 .31527 L

s

[(16)] .31895 .29652 0 1 Mshowa

.46501 .30902 m

.46501 .31527 L

s

[(18)] .46501 .29652 0 1 Mshowa

.61106 .30902 m

.61106 .31527 L

s

[(20)] .61106 .29652 0 1 Mshowa

.75711 .30902 m

.75711 .31527 L

s

[(22)] .75711 .29652 0 1 Mshowa

.90316 .30902 m

.90316 .31527 L

s

[(24)] .90316 .29652 0 1 Mshowa

.125 Mabswid

.06336 .30902 m

.06336 .31277 L

s

.09987 .30902 m

.09987 .31277 L

s

.13639 .30902 m

.13639 .31277 L

s

.20941 .30902 m

.20941 .31277 L

s

.24593 .30902 m

.24593 .31277 L

s

.28244 .30902 m

.28244 .31277 L

s

.35547 .30902 m

.35547 .31277 L

s

.39198 .30902 m

.39198 .31277 L

s

.42849 .30902 m

.42849 .31277 L

s

.50152 .30902 m

.50152 .31277 L

s

.53803 .30902 m

.53803 .31277 L

s

.57455 .30902 m

.57455 .31277 L

s

.64757 .30902 m

.64757 .31277 L

s

.68408 .30902 m

.68408 .31277 L

s

.7206 .30902 m

.7206 .31277 L

s

.79362 .30902 m

.79362 .31277 L

s

.83014 .30902 m

.83014 .31277 L

s

.86665 .30902 m

.86665 .31277 L

s

.93968 .30902 m

.93968 .31277 L

s

.97619 .30902 m

.97619 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02685 .07093 m

.0331 .07093 L

s

[(-10)] .01435 .07093 1 0 Mshowa

.02685 .18997 m

.0331 .18997 L

s

[(-5)] .01435 .18997 1 0 Mshowa

.02685 .42806 m

.0331 .42806 L

s

[(5)] .01435 .42806 1 0 Mshowa

.02685 .5471 m

.0331 .5471 L

s

[(10)] .01435 .5471 1 0 Mshowa

.125 Mabswid

.02685 .09474 m

.0306 .09474 L

s

.02685 .11855 m

.0306 .11855 L

s

.02685 .14236 m

.0306 .14236 L

s

.02685 .16616 m

.0306 .16616 L

s

.02685 .21378 m

.0306 .21378 L

s

.02685 .23759 m

.0306 .23759 L

s

.02685 .2614 m

.0306 .2614 L

s

.02685 .28521 m

.0306 .28521 L

s

.02685 .33283 m

.0306 .33283 L

s

.02685 .35663 m

.0306 .35663 L

s

.02685 .38044 m

.0306 .38044 L

s

.02685 .40425 m

.0306 .40425 L

s

.02685 .45187 m

.0306 .45187 L

s

.02685 .47568 m

.0306 .47568 L

s

.02685 .49949 m

.0306 .49949 L

s

.02685 .5233 m

.0306 .5233 L

s

.02685 .04712 m

.0306 .04712 L

s

.02685 .02331 m

.0306 .02331 L

s

.02685 .57091 m

.0306 .57091 L

s

.02685 .59472 m

.0306 .59472 L

s

.25 Mabswid

.02685 0 m

.02685 .61803 L

s

gsave

.02685 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -73 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(k) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(28) show

83.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 .4 1 r

.5 Mabswid

.61106 .44096 m

.6082 .44204 L

.60528 .44315 L

.60236 .44427 L

.59944 .4454 L

.59652 .44654 L

.5936 .44768 L

.59068 .44883 L

.58776 .44999 L

.58483 .45116 L

.58191 .45233 L

.57899 .45351 L

.57607 .4547 L

.57315 .4559 L

.57023 .45711 L

.56731 .45833 L

.56439 .45955 L

.56147 .46078 L

.55855 .46202 L

.55562 .46327 L

.5527 .46452 L

.54978 .46579 L

.54686 .46706 L

.54394 .46835 L

.54102 .46964 L

.5381 .47094 L

.53518 .47224 L

.53226 .47356 L

.52933 .47489 L

.52641 .47622 L

.52349 .47756 L

.52057 .47892 L

.51765 .48028 L

.51473 .48165 L

.51181 .48303 L

.50889 .48441 L

.50597 .48581 L

.50305 .48721 L

.50012 .48863 L

.4972 .49005 L

.49428 .49148 L

.49136 .49292 L

.48844 .49437 L

.48552 .49583 L

.4826 .4973 L

.47968 .49877 L

.47676 .50025 L

.47383 .50175 L

.47091 .50325 L

.46799 .50476 L

Mistroke

.46507 .50628 L

.46215 .5078 L

.45923 .50934 L

.45631 .51088 L

.45339 .51243 L

.45047 .51399 L

.44755 .51555 L

.44462 .51713 L

.4417 .51871 L

.43878 .5203 L

.43586 .52189 L

.43294 .5235 L

.43002 .52511 L

.4271 .52672 L

.42418 .52834 L

.42126 .52997 L

.41833 .5316 L

.41541 .53324 L

.41249 .53488 L

.40957 .53653 L

.40665 .53818 L

.40373 .53984 L

.40081 .5415 L

.39789 .54316 L

.39497 .54483 L

.39205 .54649 L

.38912 .54816 L

.3862 .54983 L

.38328 .5515 L

.38036 .55317 L

.37744 .55483 L

.37452 .5565 L

.3716 .55816 L

.36868 .55982 L

.36576 .56147 L

.36283 .56312 L

.35991 .56476 L

.35699 .56639 L

.35407 .56802 L

.35115 .56963 L

.34823 .57124 L

.34531 .57283 L

.34239 .57441 L

.33947 .57597 L

.33655 .57752 L

.33362 .57904 L

.3307 .58055 L

.32778 .58203 L

.32486 .58349 L

.32194 .58492 L

Mistroke

.31902 .58633 L

.3161 .5877 L

.31318 .58904 L

.31026 .59034 L

.30733 .5916 L

.30441 .59282 L

.30149 .594 L

.29857 .59512 L

.29565 .5962 L

.29273 .59721 L

.28981 .59817 L

.28689 .59906 L

.28397 .59989 L

.28104 .60064 L

.27812 .6013 L

.2752 .60189 L

.27228 .60238 L

.26936 .60278 L

.26644 .60307 L

.26352 .60325 L

.2606 .60332 L

.25768 .60326 L

.25476 .60306 L

.25183 .60272 L

.24891 .60222 L

.24599 .60155 L

.24307 .60071 L

.24015 .59968 L

.23723 .59845 L

.23431 .59699 L

.23139 .5953 L

.22847 .59335 L

.22554 .59113 L

.22262 .58862 L

.2197 .58578 L

.21678 .5826 L

.21386 .57904 L

.21094 .57507 L

.20802 .57064 L

.2051 .56572 L

.20218 .56026 L

.19926 .55418 L

.19633 .54741 L

.19341 .53988 L

.19049 .53146 L

.18757 .52203 L

.18465 .5114 L

.18173 .49932 L

.17881 .48547 L

.17589 .46933 L

Mistroke

.17297 .45006 L

.17004 .42603 L

.16712 .39318 L

.1642 .31567 L

.16418 .30902 L

Mfstroke

.61106 .17707 m

.6082 .17599 L

.60528 .17488 L

.60236 .17376 L

.59944 .17263 L

.59652 .1715 L

.5936 .17035 L

.59068 .1692 L

.58776 .16804 L

.58483 .16688 L

.58191 .1657 L

.57899 .16452 L

.57607 .16333 L

.57315 .16213 L

.57023 .16092 L

.56731 .15971 L

.56439 .15849 L

.56147 .15725 L

.55855 .15601 L

.55562 .15477 L

.5527 .15351 L

.54978 .15224 L

.54686 .15097 L

.54394 .14969 L

.54102 .1484 L

.5381 .1471 L

.53518 .14579 L

.53226 .14447 L

.52933 .14315 L

.52641 .14181 L

.52349 .14047 L

.52057 .13912 L

.51765 .13776 L

.51473 .13639 L

.51181 .13501 L

.50889 .13362 L

.50597 .13223 L

.50305 .13082 L

.50012 .12941 L

.4972 .12798 L

.49428 .12655 L

.49136 .12511 L

.48844 .12366 L

.48552 .12221 L

.4826 .12074 L

.47968 .11926 L

.47676 .11778 L

.47383 .11629 L

.47091 .11479 L

.46799 .11328 L

Mistroke

.46507 .11176 L

.46215 .11023 L

.45923 .1087 L

.45631 .10715 L

.45339 .1056 L

.45047 .10405 L

.44755 .10248 L

.44462 .10091 L

.4417 .09932 L

.43878 .09774 L

.43586 .09614 L

.43294 .09454 L

.43002 .09293 L

.4271 .09131 L

.42418 .08969 L

.42126 .08806 L

.41833 .08643 L

.41541 .08479 L

.41249 .08315 L

.40957 .0815 L

.40665 .07985 L

.40373 .07819 L

.40081 .07653 L

.39789 .07487 L

.39497 .07321 L

.39205 .07154 L

.38912 .06988 L

.3862 .06821 L

.38328 .06654 L

.38036 .06487 L

.37744 .0632 L

.37452 .06154 L

.3716 .05988 L

.36868 .05822 L

.36576 .05656 L

.36283 .05492 L

.35991 .05327 L

.35699 .05164 L

.35407 .05001 L

.35115 .0484 L

.34823 .04679 L

.34531 .0452 L

.34239 .04362 L

.33947 .04206 L

.33655 .04052 L

.33362 .03899 L

.3307 .03749 L

.32778 .036 L

.32486 .03454 L

.32194 .03311 L

Mistroke

.31902 .0317 L

.3161 .03033 L

.31318 .029 L

.31026 .02769 L

.30733 .02643 L

.30441 .02521 L

.30149 .02404 L

.29857 .02291 L

.29565 .02184 L

.29273 .02082 L

.28981 .01986 L

.28689 .01897 L

.28397 .01815 L

.28104 .0174 L

.27812 .01673 L

.2752 .01615 L

.27228 .01565 L

.26936 .01525 L

.26644 .01496 L

.26352 .01478 L

.2606 .01472 L

.25768 .01478 L

.25476 .01497 L

.25183 .01532 L

.24891 .01582 L

.24599 .01648 L

.24307 .01732 L

.24015 .01835 L

.23723 .01959 L

.23431 .02104 L

.23139 .02274 L

.22847 .02468 L

.22554 .0269 L

.22262 .02941 L

.2197 .03225 L

.21678 .03543 L

.21386 .03899 L

.21094 .04296 L

.20802 .04739 L

.2051 .05231 L

.20218 .05778 L

.19926 .06386 L

.19633 .07062 L

.19341 .07816 L

.19049 .08657 L

.18757 .09601 L

.18465 .10664 L

.18173 .11871 L

.17881 .13256 L

.17589 .1487 L

Mistroke

.17297 .16797 L

.17004 .192 L

.16712 .22485 L

.1642 .30236 L

.16418 .30902 L

Mfstroke

.61106 .44096 m

.61836 .43823 L

.62566 .43554 L

.63297 .4329 L

.64027 .43031 L

.64757 .42775 L

.65487 .42524 L

.66218 .42277 L

.66948 .42034 L

.67678 .41794 L

.68408 .41559 L

.69139 .41328 L

.69869 .411 L

.70599 .40875 L

.7133 .40654 L

.7206 .40437 L

.7279 .40223 L

.7352 .40012 L

.74251 .39804 L

.74981 .39599 L

.75711 .39398 L

.76441 .39199 L

.77172 .39003 L

.77902 .3881 L

.78632 .3862 L

.79362 .38432 L

.80093 .38247 L

.80823 .38065 L

.81553 .37885 L

.82284 .37707 L

.83014 .37532 L

.83744 .37359 L

.84474 .37189 L

.85205 .3702 L

.85935 .36854 L

.86665 .36689 L

.87395 .36527 L

.88126 .36367 L

.88856 .36208 L

.89586 .36052 L

.90316 .35897 L

.91047 .35744 L

.91777 .35592 L

.92507 .35443 L

.93237 .35295 L

.93968 .35148 L

.94698 .35003 L

.95428 .3486 L

.96159 .34718 L

.96889 .34578 L

Mistroke

.97619 .34438 L

Mfstroke

.61106 .17707 m

.61836 .1798 L

.62566 .18249 L

.63297 .18513 L

.64027 .18773 L

.64757 .19028 L

.65487 .19279 L

.66218 .19527 L

.66948 .1977 L

.67678 .20009 L

.68408 .20244 L

.69139 .20476 L

.69869 .20704 L

.70599 .20928 L

.7133 .21149 L

.7206 .21367 L

.7279 .21581 L

.7352 .21792 L

.74251 .21999 L

.74981 .22204 L

.75711 .22406 L

.76441 .22604 L

.77172 .228 L

.77902 .22993 L

.78632 .23183 L

.79362 .23371 L

.80093 .23556 L

.80823 .23738 L

.81553 .23918 L

.82284 .24096 L

.83014 .24271 L

.83744 .24444 L

.84474 .24615 L

.85205 .24783 L

.85935 .2495 L

.86665 .25114 L

.87395 .25276 L

.88126 .25437 L

.88856 .25595 L

.89586 .25752 L

.90316 .25907 L

.91047 .2606 L

.91777 .26211 L

.92507 .26361 L

.93237 .26509 L

.93968 .26655 L

.94698 .268 L

.95428 .26943 L

.96159 .27085 L

.96889 .27226 L

Mistroke

.97619 .27365 L

Mfstroke

1 0 0 r

.61106 .31335 m

.61471 .31195 L

.61836 .31053 L

.62201 .30912 L

.62566 .30769 L

.62932 .30627 L

.63297 .30484 L

.63662 .3034 L

.64027 .30196 L

.64392 .30051 L

.64757 .29906 L

.65122 .2976 L

.65487 .29614 L

.65853 .29467 L

.66218 .2932 L

.66583 .29172 L

.66948 .29024 L

.67313 .28875 L

.67678 .28725 L

.68043 .28575 L

.68408 .28424 L

.68774 .28273 L

.69139 .28122 L

.69504 .2797 L

.69869 .27817 L

.70234 .27664 L

.70599 .27511 L

.70964 .27358 L

.7133 .27204 L

.71695 .2705 L

.7206 .26896 L

.72425 .26742 L

.7279 .26587 L

.73155 .26433 L

.7352 .26279 L

.73885 .26125 L

.74251 .25971 L

.74616 .25817 L

.74981 .25664 L

.75346 .25512 L

.75711 .2536 L

.76076 .25209 L

.76441 .25058 L

.76807 .24909 L

.77172 .24761 L

.77537 .24614 L

.77902 .24468 L

.78267 .24323 L

.78632 .24181 L

.78997 .24039 L

Mistroke

.79362 .239 L

.79728 .23762 L

.80093 .23627 L

.80458 .23493 L

.80823 .23362 L

.81188 .23233 L

.81553 .23106 L

.81918 .22982 L

.82284 .22861 L

.82649 .22742 L

.83014 .22625 L

.83379 .22512 L

.83744 .22401 L

.84109 .22294 L

.84474 .22189 L

.84839 .22087 L

.85205 .21988 L

.8557 .21892 L

.85935 .21799 L

.863 .21709 L

.86665 .21622 L

.8703 .21538 L

.87395 .21457 L

.8776 .21379 L

.88126 .21304 L

.88491 .21232 L

.88856 .21162 L

.89221 .21096 L

.89586 .21032 L

.89951 .20971 L

.90316 .20913 L

.90682 .20858 L

.91047 .20805 L

.91412 .20754 L

.91777 .20706 L

.92142 .20661 L

.92507 .20618 L

.92872 .20577 L

.93237 .20539 L

.93603 .20503 L

.93968 .20469 L

.94333 .20437 L

.94698 .20407 L

.95063 .20379 L

.95428 .20353 L

.95793 .20329 L

.96159 .20307 L

.96524 .20287 L

.96889 .20268 L

.97254 .20251 L

Mistroke

.97619 .20236 L

Mfstroke

.61106 .30468 m

.61471 .30609 L

.61836 .3075 L

.62201 .30892 L

.62566 .31034 L

.62932 .31177 L

.63297 .3132 L

.63662 .31463 L

.64027 .31607 L

.64392 .31752 L

.64757 .31897 L

.65122 .32043 L

.65487 .32189 L

.65853 .32336 L

.66218 .32483 L

.66583 .32631 L

.66948 .3278 L

.67313 .32929 L

.67678 .33078 L

.68043 .33228 L

.68408 .33379 L

.68774 .3353 L

.69139 .33682 L

.69504 .33834 L

.69869 .33986 L

.70234 .34139 L

.70599 .34292 L

.70964 .34446 L

.7133 .34599 L

.71695 .34753 L

.7206 .34907 L

.72425 .35062 L

.7279 .35216 L

.73155 .3537 L

.7352 .35525 L

.73885 .35679 L

.74251 .35833 L

.74616 .35986 L

.74981 .36139 L

.75346 .36292 L

.75711 .36443 L

.76076 .36595 L

.76441 .36745 L

.76807 .36894 L

.77172 .37043 L

.77537 .3719 L

.77902 .37336 L

.78267 .3748 L

.78632 .37623 L

.78997 .37764 L

Mistroke

.79362 .37904 L

.79728 .38041 L

.80093 .38177 L

.80458 .3831 L

.80823 .38442 L

.81188 .38571 L

.81553 .38697 L

.81918 .38821 L

.82284 .38943 L

.82649 .39062 L

.83014 .39178 L

.83379 .39291 L

.83744 .39402 L

.84109 .3951 L

.84474 .39615 L

.84839 .39717 L

.85205 .39816 L

.8557 .39911 L

.85935 .40004 L

.863 .40094 L

.86665 .40181 L

.8703 .40265 L

.87395 .40346 L

.8776 .40424 L

.88126 .40499 L

.88491 .40572 L

.88856 .40641 L

.89221 .40707 L

.89586 .40771 L

.89951 .40832 L

.90316 .4089 L

.90682 .40946 L

.91047 .40999 L

.91412 .41049 L

.91777 .41097 L

.92142 .41142 L

.92507 .41185 L

.92872 .41226 L

.93237 .41265 L

.93603 .41301 L

.93968 .41335 L

.94333 .41367 L

.94698 .41396 L

.95063 .41424 L

.95428 .4145 L

.95793 .41474 L

.96159 .41496 L

.96524 .41516 L

.96889 .41535 L

.97254 .41552 L

Mistroke

.97619 .41567 L

Mfstroke

.61106 .31335 m

.60814 .31448 L

.60449 .31588 L

.60083 .31727 L

.59718 .31867 L

.59353 .32006 L

.58988 .32144 L

.58623 .32282 L

.58258 .3242 L

.57893 .32558 L

.57528 .32696 L

.57162 .32833 L

.56797 .3297 L

.56432 .33107 L

.56067 .33243 L

.55702 .3338 L

.55337 .33516 L

.54972 .33652 L

.54607 .33788 L

.54241 .33925 L

.53876 .3406 L

.53511 .34196 L

.53146 .34332 L

.52781 .34468 L

.52416 .34604 L

.52051 .3474 L

.51685 .34876 L

.5132 .35012 L

.50955 .35149 L

.5059 .35285 L

.50225 .35421 L

.4986 .35558 L

.49495 .35695 L

.4913 .35832 L

.48764 .35969 L

.48399 .36107 L

.48034 .36244 L

.47669 .36382 L

.47304 .36521 L

.46939 .36659 L

.46574 .36798 L

.46208 .36937 L

.45843 .37077 L

.45478 .37217 L

.45113 .37357 L

.44748 .37498 L

.44383 .3764 L

.44018 .37781 L

.43653 .37923 L

.43287 .38066 L

Mistroke

.42922 .38209 L

.42557 .38353 L

.42192 .38497 L

.41827 .38642 L

.41462 .38787 L

.41097 .38933 L

.40731 .39079 L

.40366 .39227 L

.40001 .39374 L

.39636 .39523 L

.39271 .39672 L

.38906 .39821 L

.38541 .39972 L

.38176 .40123 L

.3781 .40275 L

.37445 .40427 L

.3708 .40581 L

.36715 .40735 L

.3635 .4089 L

.35985 .41045 L

.3562 .41202 L

.35255 .41359 L

.34889 .41517 L

.34524 .41676 L

.34159 .41836 L

.33794 .41996 L

.33429 .42158 L

.33064 .4232 L

.32699 .42483 L

.32333 .42648 L

.31968 .42813 L

.31603 .42979 L

.31238 .43145 L

.30873 .43313 L

.30508 .43482 L

.30143 .43652 L

.29778 .43822 L

.29412 .43994 L

.29047 .44166 L

.28682 .4434 L

.28317 .44514 L

.27952 .4469 L

.27587 .44866 L

.27222 .45043 L

.26856 .45221 L

.26491 .454 L

.26126 .4558 L

.25761 .45761 L

.25396 .45943 L

.25031 .46125 L

Mistroke

.24666 .46309 L

.24301 .46493 L

.23935 .46678 L

.2357 .46864 L

.23205 .4705 L

.2284 .47238 L

.22475 .47425 L

.2211 .47614 L

.21745 .47803 L

.21379 .47992 L

.21014 .48182 L

.20649 .48372 L

.20284 .48562 L

.19919 .48752 L

.19554 .48943 L

.19189 .49133 L

.18824 .49323 L

.18458 .49513 L

.18093 .49702 L

.17728 .49891 L

.17363 .50079 L

.16998 .50265 L

.16633 .5045 L

.16268 .50634 L

.15903 .50815 L

.15537 .50994 L

.15172 .5117 L

.14807 .51344 L

.14442 .51513 L

.14077 .51679 L

.13712 .51839 L

.13347 .51994 L

.12981 .52143 L

.12616 .52284 L

.12251 .52417 L

.11886 .52541 L

.11521 .52655 L

.11156 .52756 L

.10791 .52843 L

.10426 .52915 L

.1006 .52969 L

.09695 .53002 L

.0933 .53013 L

.08965 .52997 L

.086 .52951 L

.08235 .52872 L

.0787 .52753 L

.07504 .52589 L

.07139 .52374 L

.06774 .52101 L

Mistroke

.06409 .51759 L

.06044 .51339 L

.05679 .50827 L

.05314 .50208 L

.04949 .49461 L

.04583 .48559 L

.04218 .47466 L

.03853 .46128 L

.03488 .44457 L

.03123 .42292 L

.02758 .3923 L

.0275 .39153 L

.02743 .39075 L

.02736 .38996 L

.02729 .38917 L

.02721 .38836 L

.02714 .38754 L

.02707 .38672 L

.02699 .38588 L

.02692 .38503 L

.02685 .38417 L

.02677 .3833 L

.0267 .38242 L

.02663 .38152 L

.02656 .38061 L

.02648 .37969 L

.02641 .37875 L

.02634 .3778 L

.02626 .37683 L

.02619 .37585 L

.02612 .37485 L

.02604 .37383 L

.02597 .3728 L

.0259 .37174 L

.02583 .37066 L

.02575 .36957 L

.02568 .36845 L

.02561 .3673 L

.02553 .36613 L

.02546 .36494 L

.02539 .36371 L

.02531 .36246 L

.02524 .36117 L

.02517 .35984 L

.02509 .35848 L

.02502 .35708 L

.02495 .35563 L

.02488 .35413 L

.0248 .35258 L

.02473 .35096 L

Mistroke

.02466 .34928 L

.02458 .34752 L

.02451 .34567 L

.02444 .34372 L

.02436 .34165 L

.02429 .33944 L

.02422 .33704 L

.02415 .33441 L

.02407 .33147 L

.024 .32807 L

.02393 .32392 L

.02381 .30902 L

Mfstroke

.61106 .30468 m

.60814 .30356 L

.60449 .30216 L

.60083 .30076 L

.59718 .29937 L

.59353 .29798 L

.58988 .29659 L

.58623 .29521 L

.58258 .29383 L

.57893 .29245 L

.57528 .29108 L

.57162 .28971 L

.56797 .28834 L

.56432 .28697 L

.56067 .2856 L

.55702 .28424 L

.55337 .28287 L

.54972 .28151 L

.54607 .28015 L

.54241 .27879 L

.53876 .27743 L

.53511 .27607 L

.53146 .27471 L

.52781 .27335 L

.52416 .27199 L

.52051 .27063 L

.51685 .26927 L

.5132 .26791 L

.50955 .26655 L

.5059 .26518 L

.50225 .26382 L

.4986 .26245 L

.49495 .26108 L

.4913 .25971 L

.48764 .25834 L

.48399 .25697 L

.48034 .25559 L

.47669 .25421 L

.47304 .25283 L

.46939 .25144 L

.46574 .25005 L

.46208 .24866 L

.45843 .24726 L

.45478 .24586 L

.45113 .24446 L

.44748 .24305 L

.44383 .24164 L

.44018 .24022 L

.43653 .2388 L

.43287 .23737 L

Mistroke

.42922 .23594 L

.42557 .23451 L

.42192 .23306 L

.41827 .23162 L

.41462 .23016 L

.41097 .2287 L

.40731 .22724 L

.40366 .22577 L

.40001 .22429 L

.39636 .22281 L

.39271 .22132 L

.38906 .21982 L

.38541 .21832 L

.38176 .2168 L

.3781 .21529 L

.37445 .21376 L

.3708 .21223 L

.36715 .21069 L

.3635 .20914 L

.35985 .20758 L

.3562 .20602 L

.35255 .20445 L

.34889 .20286 L

.34524 .20128 L

.34159 .19968 L

.33794 .19807 L

.33429 .19646 L

.33064 .19483 L

.32699 .1932 L

.32333 .19156 L

.31968 .18991 L

.31603 .18825 L

.31238 .18658 L

.30873 .1849 L

.30508 .18321 L

.30143 .18152 L

.29778 .17981 L

.29412 .17809 L

.29047 .17637 L

.28682 .17463 L

.28317 .17289 L

.27952 .17114 L

.27587 .16937 L

.27222 .1676 L

.26856 .16582 L

.26491 .16403 L

.26126 .16223 L

.25761 .16042 L

.25396 .15861 L

.25031 .15678 L

Mistroke

.24666 .15495 L

.24301 .1531 L

.23935 .15125 L

.2357 .1494 L

.23205 .14753 L

.2284 .14566 L

.22475 .14378 L

.2211 .1419 L

.21745 .14001 L

.21379 .13811 L

.21014 .13622 L

.20649 .13432 L

.20284 .13241 L

.19919 .13051 L

.19554 .1286 L

.19189 .1267 L

.18824 .1248 L

.18458 .1229 L

.18093 .12101 L

.17728 .11912 L

.17363 .11725 L

.16998 .11538 L

.16633 .11353 L

.16268 .1117 L

.15903 .10988 L

.15537 .10809 L

.15172 .10633 L

.14807 .1046 L

.14442 .1029 L

.14077 .10125 L

.13712 .09964 L

.13347 .09809 L

.12981 .09661 L

.12616 .09519 L

.12251 .09386 L

.11886 .09262 L

.11521 .09149 L

.11156 .09048 L

.10791 .0896 L

.10426 .08889 L

.1006 .08835 L

.09695 .08801 L

.0933 .08791 L

.08965 .08806 L

.086 .08852 L

.08235 .08932 L

.0787 .09051 L

.07504 .09214 L

.07139 .09429 L

.06774 .09703 L

Mistroke

.06409 .10044 L

.06044 .10465 L

.05679 .10976 L

.05314 .11595 L

.04949 .12342 L

.04583 .13244 L

.04218 .14337 L

.03853 .15675 L

.03488 .17346 L

.03123 .19512 L

.02758 .22573 L

.0275 .22651 L

.02743 .22728 L

.02736 .22807 L

.02729 .22887 L

.02721 .22967 L

.02714 .23049 L

.02707 .23132 L

.02699 .23215 L

.02692 .233 L

.02685 .23386 L

.02677 .23473 L

.0267 .23561 L

.02663 .23651 L

.02656 .23742 L

.02648 .23834 L

.02641 .23928 L

.02634 .24023 L

.02626 .2412 L

.02619 .24218 L

.02612 .24318 L

.02604 .2442 L

.02597 .24524 L

.0259 .2463 L

.02583 .24737 L

.02575 .24847 L

.02568 .24959 L

.02561 .25073 L

.02553 .2519 L

.02546 .2531 L

.02539 .25432 L

.02531 .25558 L

.02524 .25687 L

.02517 .25819 L

.02509 .25955 L

.02502 .26096 L

.02495 .26241 L

.02488 .2639 L

.0248 .26546 L

.02473 .26707 L

Mistroke

.02466 .26875 L

.02458 .27051 L

.02451 .27236 L

.02444 .27431 L

.02436 .27638 L

.02429 .2786 L

.02422 .28099 L

.02415 .28362 L

.02407 .28656 L

.024 .28996 L

.02393 .29412 L

.02381 .30902 L

Mfstroke

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{567, 350.313},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.776525,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008g0001GPP10`40000100000800002008200000

P800P020P<30`<3L`:K:l00003<006H009T00<`00?l0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV

09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<003o03?o06Ko09Wo0<co

0?oo0000<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I

<c>I<fJI<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0

IYT0I/`0I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bI

I_nIIP3<IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0c

VC<cVFHcVITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<

VIW<VLc<VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`c

c?lcc01Vc3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03o

c3?oc6Koc9Woc<coc?ooc000oc<0ofH0oiT0ol`0ool0o`0coc<cofHcoiTcol`coolco`1Voc=VofIV

oiUVolaVoomVo`2Ioc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<o`3ooc?oofKooiWoolco

ooooo`0000410@820P<30`@410D51@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C

4a@D5?okl:2PY820P?l0003o0?oo0000ool0o`3oooooob3Q00<0hN40on7ohAKQ000Ph@030>7Q0?oQ

on4Fh@008>400`3Qh@3ohOoQ5^40023Q00<0hN40on7ohAKQ000Ph@030>7Q0?oQon4Fh@008>400`3Q

h@3ohOoQ5^40023Q00<0hN40on7ohAKQ000Ph@030>7Q0?oQon4Fh@008>400`3Qh@1`h@fnon6Hh@00

8>400`3Qh@1]h@>n3N44__oQU>40023Q00<0hN40J^43_QCQ1KkohHoQ000Ph@030>7Q06SQ0[hLh@03

_^7Q0?oQS>40023Q0P1Xh@03_^7Q01gQ0kkohH_Q000Ph@030>7Q06GQ0[hSh@>non68h@008>400`3Q

h@1Th@03_^7Q02KQ0[kohHKQ000Ph@030>7Q06;Q0[h[h@>non63h@008>400`3Qh@1Qh@03_^7Q02kQ

00>nhN40on60h@008>400`3Qh@1Qh@03_^7Q02oQ1;kohGkQ000Ph@030>7Q063Q00>nhN40=>400kkQ

h@3ohG_Q000Ph@030>7Q05oQ00>nhN40=^42__oQNn40023Q00<0hN40GN42_S_Q0kkohGSQ000Ph@03

0>7Q05cQ00>nhN40?^400kkQh@3ohGGQ000Ph@030>7Q05cQ00>nhN40?n42__oQMN40023Q00<0hN40

Fn400kkQh@12h@03_^7Q0?oQL^40023Q00<0hN40Fn400kkQh@13h@>non5ah@008>4205_Q00>nhN40

An42__oQKn40023Q00<0hN40FN400kkQh@1:h@03_^7Q0?oQK>40023Q00<0hN40FN400kkQh@1;h@:n

on5/h@008>400`3Qh@1Hh@03_^7Q04kQ00>nhN40on5Yh@008>400`3Qh@1Hh@03_^7Q04oQ0[kohFWQ

000Ph@030>7Q05OQ00>nhN40D^43__oQI^40023Q00<0hN40En400kkQh@1Eh@03_^7Q0?oQHn40023Q

00<0hN40E^400kkQh@1Gh@:non5Sh@008>400`3Qh@1Fh@03_^7Q05WQ00>nhN40on5Ph@008>400`3Q

h@1Eh@03_^7Q05_Q0[kohF3Q000?h@D00^400`3Qh@07h@030>7Q05GQ00>nhN40GN400kkQh@3ohEgQ

000Ah@070>7Qh@3Q0008h@030>7Q05CQ00>nhN40Gn43__oQG>4000_Q0`03h@070>7Qh@3Q0008h@@0

Dn400kkQh@1Rh@:non5Jh@004N401`3QhN40h@002>400`3Qh@1Dh@03_^7Q06CQ00>nhN40on5Gh@00

4N401`3QhN40h@002>400`3Qh@1Ch@03_^7Q06KQ0[kohEOQ000@h@801>400`3Qh@07h@030>7Q05?Q

00>nhN40J>400kkQh@3ohECQ000Ph@030>7Q05?Q00>nhN40JN42__oQE>40023Q00<0hN40D^400kkQ

h@1/h@>non5Ah@008>400`3Qh@1Bh@03_^7Q06oQ00>nhN40on5>h@008>400`3Qh@1Ah@03_^7Q077Q

0[kohDkQ000Ph@030>7Q057Q00>nhN40Ln400kkQh@3ohD_Q000Ph@030>7Q01WQ3@l[h@03_^7Q07CQ

0[kohD_Q000Ph@030>7Q01OQ0Pl=h@<?:>400kkQh@1fh@:non59h@008>400`3Qh@0Fh@033n7Q013Q

10lSh@03_^7Q07WQ0kkohDKQ000Ph@805N423aOQ0PlQh@03_^7Q07cQ00>nhN40on53h@008>400`3Q

h@0Bh@8?6n443agQ00>nhN40ON42__oQ@n40023Q00<0hN404N400`oQh@0Oh@8?6n400kkQh@1oh@03

_^7Q0?oQ@>40023Q00<0hN404>400`oQh@0Rh@8?6>400kkQh@21h@>non4oh@008>400`3Qh@0?h@03

3n7Q02GQ0PlFh@03_^7Q08CQ0[kohCgQ000Ph@030>7Q00kQ00<?hN40:>433a;Q00>nhN40Qn400kkQ

h@3ohC[Q000Ph@030>7Q00gQ00<?hN40;>423a3Q00>nhN40R>42__oQ>^40023Q00<0hN403N400`oQ

h@0^h@8?3^400kkQh@2:h@03_^7Q0?oQ=n40023Q00<0hN403>400`oQh@0ah@8?3>400kkQh@2;h@>n

on4fh@008>400`3Qh@0;h@033n7Q03CQ0Pl:h@03_^7Q08kQ0[kohCCQ000Ph@030>7Q00_Q00<?hN40

=^423`OQ00>nhN40TN400kkQh@3ohC7Q000Ph@030>7Q00[Q00<?hN40>N423`GQ00>nhN40T^43__oQ

<>40023Q00<0hN402N400`oQh@0lh@8?0n400kkQh@2Eh@:non4^h@008>4200[Q00<?hN40?^423`03

hKkQ09SQ00>nhN40on4[h@008>400`3Qh@08h@033n7Q047Q00<?_^40VN42__oQ:n40023Q00<0hN40

2>400`oQh@11h@03_Pl?09_Q0kkohBSQ000Ph@030>7Q00SQ00<?hN40@N400kkQh@023icQ00>nhN40

on4Uh@008>400`3Qh@07h@033n7Q04;Q00>nhN400^423i_Q0[kohBGQ000Ph@030>7Q00OQ00<?hN40

@^400kkQh@04h@8?Vn43__oQ8^40023Q00<0hN401^400`oQh@12h@03_^7Q00OQ0PnLh@03_^7Q0?oQ

7n40023Q00<0hN401^400`oQh@12h@03_^7Q00WQ0PnKh@>non4Nh@008>400`3Qh@06h@033n7Q04;Q

00>nhN402n423icQ0[kohAcQ000Ph@030>7Q00GQ00<?hN40@n400kkQh@0=h@8?W>400kkQh@3ohAWQ

000Ph@030>7Q00GQ00<?hN40@n400kkQh@0?h@033n7Q09[Q0kkohASQ000Ph@030>7Q00GQ00<?hN40

@^400kkQh@0Ah@8?WN42__oQ5^40023Q0P05h@033n7Q04?Q00>nhN404n423igQ0kkohA?Q000Ph@03

0>7Q00CQ00<?hN40@n400kkQh@0Eh@8?W^42__oQ4N40023Q00<0hN401>400`oQh@13h@03_^7Q01OQ

0PnNh@>non4>h@008>400`3Qh@04h@033n7Q04?Q00>nhN406N423ioQ00>nhN40on4;h@008>400`3Q

h@03h@033n7Q04CQ00>nhN406n423ikQ0kkoh@[Q000Ph@030>7Q00?Q00<?hN40A>400kkQh@0Mh@8?

Wn42__oQ2>40023Q00<0hN400n400`oQh@13h@03_^7Q023Q0PnOh@>non45h@008>400`3Qh@03h@03

3n7Q04?Q00>nhN408^433ioQ00>nhN40on42h@008>400`3Qh@03h@033n7Q04?Q00>nhN409N423ikQ

0kkoh@7Q000Ph@030>7Q00?Q00<?hN40@n400kkQh@0Wh@8?Wn42__kQ000Ph@030>7Q00;Q00<?hN40

A>400kkQh@0Yh@8?Wn43___Q000Ph@030>7Q00;Q00<?hN40@n400kkQh@0/h@8?X>43__SQ000Ph@80

0n400`oQh@13h@03_^7Q02kQ0PnQh@03_^7Q0?GQ000Ph@030>7Q00;Q00<?hN40@n400kkQh@0`h@8?

X>43__CQ000Ph@050>7Qh@l0A^400kkQh@0bh@8?XN43__7Q000Ph@050>7Qh@l0A^400kkQh@0dh@8?

X^42_^oQ000Ph@050>7Qh@l0A^400kkQh@0fh@033n7Q0:7Q0kk/h@008>401@3QhN4?04KQ00>nhN40

=n423jCQ0kkYh@008>401@3QhN4?04KQ00>nhN40>N443j?Q0[kWh@008>40103Qh@m7h@03_^7Q03gQ

0PnSh@>ni>40023Q00@0hN4?A^400kkQh@10h@8?Y>42_^;Q000Ph@040>7Q3dKQ00>nhN40@^423jCQ

0kkOh@008>40103Qh@m6h@03_^7Q04CQ0PnUh@Bnfn4001KQ00<0hN401n40103Qh@m6h@03_^7Q04KQ

0PnWh@>nf>4001GQ00<0h@002>40103Qh@m6h@03_^7Q04SQ00<?hN40Yn42_]KQ000@h@<01>400`3Q

h@06h@8000<?0>40AN400kkQh@19h@@?Yn42_]CQ000Eh@802N400`3Q3`17h@03_^7Q04gQ0PnWh@Bn

d>4001GQ00<0hN402>400`3Q3`17h@03_^7Q04oQ0PnYh@>ncN4001GQ0`08h@030>4?04OQ00>nhN40

DN423j[Q0[k;h@008>400`3Q3`17h@03_^7Q05?Q0PnZh@>nb>40023Q00<0h@l0An400kkQh@1Eh@8?

Zn43_/GQ000Ph@0300oQ04KQ00>nhN40F>433j_Q1;j>h@T?:^40023Q00<03n40A^400kkQh@1Kh@8?

[N43_WkQ3@lch@008>400`0?h@16h@03_^7Q05gQ0Pn^h@:nM>483d3Q000Ph@0300oQ04KQ00>nhN40

Gn423jkQ0kiZh@L?B>40023Q00<03n40A^400kkQh@1Qh@@?[N44_V3Q1Pm?h@008>400`0?h@16h@03

_^7Q06GQ0Pn_h@>nEn463eGQ000Ph@0300oQ04KQ00>nhN40In423k3Q1;i>h@D?Fn40023Q00<03n40

A^400kkQh@1Yh@8?/^44_TKQ10mPh@008>400`oQh@15h@03_^7Q06cQ0`nch@Bn?^443fCQ000Ph@03

3n7Q04GQ00>nhN40Kn423kGQ1;hfh@@?J>40023Q00<?hN40AN400kkQh@1ah@8?]n43_RoQ10m/h@00

8>400`oQh@15h@03_^7Q07?Q10nfh@Bn:>433g3Q000Ph@033n7Q04GQ00>nhN40Mn423kSQ1;hPh@@?

Ln40023Q00<?hN40AN400kkQh@1ih@8?^^44_Q[Q0Pmgh@008>400`oQh@15h@03_^7Q07_Q10njh@>n

4n443gWQ000Ph@033n7Q04GQ00>nhN40On400`oQh@2jh@Bn3N423ggQ000Ph@033n7Q04GQ00>nhN40

P>423kkQ1;h6h@<?On4001oQ0Pm7h@03_^7Q08;Q10nnh@Bn0Pn2h@007n400`l00016h@03_^7Q08KQ

0Pnlh@@?1;j0h@007n400`l0h@16h@03_^7Q08SQ0Pnhh@8?2>43_WgQ000Oh@033`3Q04KQ00>nhN40

R^443k;Q0Pl=h@BnNN4001oQ00<?0>40A^400kkQh@2>h@8?[>443a?Q1;ieh@007n400`l0h@16h@03

_^7Q093Q00<?hN40Yn423a_Q1;iah@007n400`l0h@16h@03_^7Q097Q10nTh@033n7Q01oQ0ki^h@00

7n400`l0h@16h@03_^7Q09GQ0PnNh@@?9N44_V[Q000Oh@033`3Q04KQ00>nhN40Un423i[Q0Pl]h@Rn

H^4001oQ00<?0>40A^400kkQh@2Ih@@?U>423cOQ1;iNh@007n400`l0h@16h@03_^7Q09gQ0Pn>h@@?

?N43_U_Q000Oh@033`3Q04KQ00>nhN40Wn443hSQ0Pm4h@BnEn4001oQ00<?0>40A^400kkQh@2Sh@03

3n7Q08?Q0Pm:h@RnCn4001oQ00<?0>40A^400kkQh@2Th@8?P^400`oQh@1Bh@BnBn4001oQ00<?0000

A^400kkQh@2Vh@@?N^443eWQ0ki8h@007n400`l0h@15h@03_^7Q0:_Q0Pmfh@8?H>44_TCQ000Nh@03

3n4004KQ00>nhN40[N443g3Q0PmVh@Rn?>4001kQ00<?h@00A^400kkQh@2ah@8?K>423g3Q0khih@00

7^400`oQ0016h@03_^7Q0;?Q0`mUh@@?MN44_SGQ000Nh@033n4004KQ00>nhN40]^423f7Q0Pmmh@Rn

;N4001kQ00<?h@00A^400kkQh@2hh@8?GN423hOQ0khZh@007^400`oQ0016h@03_^7Q0;[Q10mHh@03

3n7Q0;CQ000Nh@033n4004KQ00>nhN40_^423e;Q10ngh@007^400`oQ0016h@03_^7Q0<3Q10m<h@8?

^n4001kQ00<?h@00AN400`2n000200;Q0`12h@D000?Q0000A>4500;Q00<0hN409^423a[Q0`03h@03

0>7Q02GQ0PlLh@<00^4304CQ0`03h@<0C>4001kQ00<?h@00A^400kh0h@04h@030>7Q04?Q00L0hN7Q

0>4004GQ00L0hN7Q0>4002WQ00<?hN405n400`3Qh@02h@030>4002CQ0PlNh@030>7Q00;Q00<0hN40

A>400`3Qh@04h@030>7Q04_Q000Nh@043n4004GQ00>n0>400^4404CQ00L0hN7Q0>4004GQ00L0hN7Q

0>4002[Q10lFh@070>7Qh@3Q000Ph@@?8N400`3Qh@02h@030>7Q04CQ00@0hN7Q101<h@007^400`oQ

0016h@03_P3Q00;Q00<0h@00AN40103QhN4204KQ00<0hN400^400`3Qh@0]h@8?5>401`3QhN40h@00

7^423bGQ00<0hN400^400`3Qh@14h@070>7Qh@3Q001=h@007^400`oQ0016h@03_P3Q00?Q0P15h@05

0>7Qh@00An401`3QhN40h@00<>443`oQ00<0h@000^400`3Q000Mh@033n7Q02CQ00<0h@000^400`3Q

0014h@030>4000?Q0P1=h@007^400`oQ0016h@03_P3Q00CQ00<0hN40@^4200CQ0P14h@801>400`3Q

h@0ch@8?3^400`3Qh@02h@030>7Q01SQ10lXh@030>7Q00;Q00<0hN40A>400`3Qh@03h@030>7Q04_Q

000Nh@033n4004KQ00>nhN40dn443bSQ0Po<h@007^400`oQ0016h@03_^7Q0=OQ0PlTh@8?c^4001kQ

00<?h@00A^400kkQh@3Ih@033n7Q01gQ10o@h@007^400`oQ0016h@03_^7Q0=[Q10lIh@8?e>4001kQ

00<?h@00A^400kkQh@3Nh@8?5N423mKQ000Nh@033n4004KQ00>nhN40h>423a3Q0`oHh@007^400`oQ

0016h@03_^7Q0>;Q0`l;h@8?c>4400_Q000Nh@033n4004KQ00>nhN40iN423`OQ0Po>h@<03>4001;Q

30000`l000160003_P000>L01`o1017Q00<0hN402^4001kQ00<?h@004N400`3Qh@0@h@030>7Q013Q

00<0hN403>401KkQhN4001;Q00<0hN404>400`3Qh@0@h@030>7Q013Q00<0hN404>400`3Qh@0@h@03

0>7Q013Q00<0hN404>400`3Qh@0@h@030>7Q013Q00<0hN403n400`3Qh@0@h@040>7Qh@8?00?Q3`l0

2^400`3Qh@0@h@030>7Q013Q00<0hN404>400`3Qh@0@h@030>7Q013Q00<0hN404>400`3Qh@0@h@03

0>7Q013Q00<0hN404>400`3Qh@0Jh@803>4001kQ00<?h@004N400`3Qh@0@h@030>7Q013Q00<0hN40

3>401KkQhN4001;Q00<0hN404>400`3Qh@0@h@030>7Q013Q00<0hN404>400`3Qh@0@h@030>7Q013Q

00<0hN404>400`3Qh@0@h@030>7Q013Q00<0hN403n400`3Qh@0@h@040>4?3`GQ0Pl8h@030>7Q013Q

00<0hN404>400`3Qh@0@h@030>7Q013Q00<0hN404>400`3Qh@0@h@030>7Q013Q00<0hN404>400`3Q

h@0@h@030>7Q02SQ000Nh@033n4004KQ00FnhN7Q001;h@030>7Q04WQ00<0hN40An433`WQ10lmh@03

0>7Q04WQ00<0hN40C^4001kQ00<?h@00A^401KkQhN4004_Q00<0hN40BN400`3Qh@15h@8?00?Q0>40

3N423c_Q00<0hN40BN400`3Qh@1>h@007^400`oQ0016h@03_^7Q0=gQ10lDh@033n7Q0=GQ000Nh@03

3n4004KQ00>nhN40fn423aWQ10oCh@007^400`oQ0016h@03_^7Q0=WQ0PlOh@8?dN4001kQ00<?h@00

A^400kkQh@3Fh@<?8n423loQ000Nh@033n4004KQ00>nhN40e>423bSQ10o;h@007^400`oQ0016h@03

_^7Q0=3Q10l^h@8?bN4001kQ00<?h@00A^400kkQh@3>h@8?=>423lOQ000Nh@033n4004KQ00>nhN40

b^443cSQ0`o4h@007^4010oQ0015h@03_^7Q0<SQ0Ploh@8?`^4001kQ00<?h@00A^400kkQh@36h@8?

@n423l3Q000Nh@033n4004KQ00>nhN40`n433dOQ0Pnnh@007^400`oQ0016h@03_^7Q0<7Q0Pm<h@@?

^^4001kQ00<?h@00A^400kkQh@2mh@@?D^423kSQ000Nh@033n4004KQ00>nhN40^n423eSQ0Pnfh@00

7^400`oQ0016h@03_^7Q0;WQ0PmLh@033n7Q08?Q1[hZh@007^400`oQ0016h@03_^7Q0;GQ10mOh@@?

ON44_S3Q000Nh@033n4004KQ00>nhN40]>400`oQh@1Uh@8?Mn44_SCQ000Nh@033n4004KQ00>nhN40

/>443f[Q0Pm^h@Nn>>4001kQ00<?h@00A^400kkQh@2^h@8?L>423fSQ1;hoh@007n400`l0h@15h@03

_^7Q0:[Q10mdh@@?H>44_T?Q000Oh@033`0004KQ00>nhN40Yn423gcQ0PmGh@NnAn4001oQ00<?0>40

A^400kkQh@2Uh@8?P>423e7Q1;i>h@007n400`l0h@16h@03_^7Q0:;Q0`n4h@033n7Q04[Q1;iBh@00

7n400`l0h@16h@03_^7Q0:3Q0Pn8h@@?A>44_UKQ000Oh@033`3Q04KQ00>nhN40W>443hkQ0Plnh@Bn

F^4001oQ00<?0>40A^400kkQh@2Jh@8?U>423cGQ1kiNh@007n400`l0h@16h@03_^7Q09SQ0PnHh@@?

;N44_VGQ000Oh@033`3Q04KQ00>nhN40U>443ikQ0PlWh@BnJN4001oQ00<?0>40A^400kkQh@2Bh@8?

Y>423b7Q1;i]h@007n400`l0h@16h@03_^7Q093Q0PnXh@<?6n43_W7Q000Oh@033`3Q04KQ00>nhN40

SN433jgQ0PlEh@BnM>4001oQ00<?0>40A^400kkQh@2;h@8?/^423`oQ1;ihh@007n400`l00016h@03

_^7Q08OQ10nfh@@?1>47_WcQ000Oh@033`3Q04KQ00>nhN40QN423kkQ0Pl2_X?Q000Ph@033n7Q04GQ

00>nhN40Pn423kcQ1;h2h@@?PN40023Q00<?hN40AN400kkQh@1oh@@?^^44_P[Q00<?hN40O^40023Q

00<?hN40AN400kkQh@1nh@033n7Q0;SQ1;h?h@@?O>40023Q00<?hN40AN400kkQh@1lh@8?^>43_QOQ

0Pmjh@008>400`oQh@15h@03_^7Q07[Q0Pnfh@Bn7>443gKQ000Ph@033n7Q04GQ00>nhN40M^443kCQ

1;hTh@@?L^40023Q00<?hN40AN400kkQh@1dh@8?]N43_RcQ0Pm`h@008>400`oQh@15h@03_^7Q07;Q

0Pneh@:n<N433fgQ000Ph@033n7Q04GQ00>nhN40K^443kGQ0[hfh@@?JN40023Q00<03n40AN400kkQ

h@1]h@033n7Q0;?Q1;hlh@H?Hn40023Q00<03n40A^400kkQh@1Zh@8?/^44_TKQ10mOh@008>400`0?

h@16h@03_^7Q06SQ0Pn`h@BnC^453e[Q000Ph@0300oQ04KQ00>nhN40I>443jkQ1;iGh@@?E^40023Q

00<03n40A^400kkQh@1Rh@8?[n43_UoQ20m>h@008>400`0?h@16h@03_^7Q063Q0Pn]h@BnJ^473dOQ

000Ph@0300oQ04KQ00>nhN40G^423jcQ0kieh@X??N40023Q00<03n40A^400kkQh@1Jh@@?[>42_X;Q

3`l^h@008>400`3Q3`16h@03_^7Q05WQ00<?hN40Zn43_Y?Q10lZh@008>400`3Q3`17h@03_^7Q05KQ

0PnZh@Bna>40023Q00<0h@l0An400kkQh@1Dh@8?ZN43_/SQ000Ph@030>4?04OQ00>nhN40D^423jSQ

0kk;h@005^400`3Qh@07h@030>4?04OQ00>nhN40C^443jSQ0[k>h@005N400`3Q0008h@030>4?04OQ

00>nhN40C>423jWQ0kk@h@005n400`3Qh@06h@8000<?0>40AN400kkQh@1:h@8?Yn44_]?Q000Eh@80

2N40103Qh@m6h@03_^7Q04SQ0PnWh@:nen4001GQ00<0hN402>40103Qh@m6h@03_^7Q04OQ00<?hN40

YN42_]WQ000Eh@<02>40103Qh@m6h@03_^7Q04GQ0PnUh@>nfn40023Q00@0hN4?A^400kkQh@11h@@?

Xn44_]kQ000Ph@040>7Q3dKQ00>nhN40?n423jCQ0kkRh@008>40103Qh@m7h@03_^7Q03cQ0PnTh@:n

iN40023Q00D0hN7Q3`16h@03_^7Q03[Q0PnSh@>nin40023Q00D0hN7Q3`16h@03_^7Q03SQ0PnRh@>n

j^40023Q00D0hN7Q3`16h@03_^7Q03KQ0PnRh@:nkN40023Q00D0hN7Q3`16h@03_^7Q03GQ00<?hN40

Wn43_^oQ000Ph@050>7Qh@l0A^400kkQh@0ch@8?Wn43__;Q000Ph@800n400`oQh@13h@03_^7Q037Q

0PnPh@03_^7Q0??Q000Ph@030>7Q00;Q00<?hN40@n400kkQh@0_h@8?Wn43__KQ000Ph@030>7Q00;Q

00<?hN40A>400kkQh@0Zh@@?W^43__WQ000Ph@030>7Q00;Q00<?hN40A>400kkQh@0Xh@8?X>42__cQ

000Ph@030>7Q00?Q00<?hN40@n400kkQh@0Vh@8?Wn43__kQ000Ph@030>7Q00?Q00<?hN40@n400kkQ

h@0Th@8?X>400kkQh@3oh@008>400`3Qh@03h@033n7Q04?Q00>nhN408^423ioQ0kkoh@?Q000Ph@03

0>7Q00?Q00<?hN40A>400kkQh@0Ph@033n7Q09gQ0[koh@KQ000Ph@030>7Q00?Q00<?hN40A>400kkQ

h@0Nh@8?WN43__oQ2>40023Q00<0hN401>400`oQh@13h@03_^7Q01cQ0PnNh@03_^7Q0?oQ2N40023Q

00<0hN401>400`oQh@13h@03_^7Q01[Q0PnMh@>non4<h@008>400`3Qh@04h@033n7Q04?Q00>nhN40

6>423igQ0[koh@oQ000Ph@030>7Q00CQ00<?hN40@n400kkQh@0Fh@8?W>43__oQ4N40023Q0P05h@03

3n7Q04?Q00>nhN405>423icQ0[kohACQ000Ph@030>7Q00GQ00<?hN40@n400kkQh@0Ah@8?Vn43__oQ

5^40023Q00<0hN401N400`oQh@13h@03_^7Q00oQ0PnLh@03_^7Q0?oQ5n40023Q00<0hN401N400`oQ

h@13h@03_^7Q00kQ00<?hN40V^42__oQ6^40023Q00<0hN401^400`oQh@12h@03_^7Q00cQ0PnJh@>n

on4Lh@008>400`3Qh@06h@033n7Q04;Q00>nhN402^423i_Q00>nhN40on4Mh@008>400`3Qh@06h@03

3n7Q04;Q00>nhN402>423i[Q0kkohB3Q000Ph@030>7Q00OQ00<?hN40@^400kkQh@05h@8?V^42__oQ

8n40023Q00<0hN401n400`oQh@12h@03_^7Q00?Q0PnKh@03_^7Q0?oQ8n40023Q00<0hN402>400`oQ

h@11h@04_^7Qh@8?V^43__oQ9^40023Q00<0hN402>400`oQh@11h@04_^4?3i[Q0[kohBWQ000Ph@03

0>7Q00WQ00<?hN40@>423i_Q00>nhN40on4Yh@008>4200[Q00<?hN40?n400`oQ_P2Hh@>non4/h@00

8>400`3Qh@0:h@033n7Q03cQ0Pl2h@03_^7Q09CQ0[kohBoQ000Ph@030>7Q00[Q00<?hN40>^423`CQ

00>nhN40Tn400kkQh@3ohBoQ000Ph@030>7Q00_Q00<?hN40=n423`KQ00>nhN40TN42__oQ<^40023Q

00<0hN402n400`oQh@0eh@8?2N400kkQh@2=h@>non4dh@008>400`3Qh@0<h@033n7Q03;Q0Pl;h@03

_^7Q08cQ00>nhN40on4eh@008>400`3Qh@0=h@033n7Q02gQ10l=h@03_^7Q08[Q0[kohCSQ000Ph@03

0>7Q00kQ00<?hN40:^423a7Q00>nhN40RN400kkQh@3ohCSQ000Ph@030>7Q00oQ00<?hN409n423aCQ

00>nhN40QN43__oQ>n40023Q00<0hN404>400`oQh@0Uh@033n7Q01CQ00>nhN40Pn42__oQ?^40023Q

00<0hN404N400`oQh@0Rh@8?5n400kkQh@22h@03_^7Q0?oQ?^40023Q00<0hN404^400`oQh@0Mh@@?

6^400kkQh@1oh@:non51h@008>4201CQ00<?hN406^423akQ00>nhN40O^400kkQh@3ohD7Q000Ph@03

0>7Q01CQ00<?hN405n423b3Q00>nhN40Nn43__oQA>40023Q00<0hN405N423a?Q10lRh@03_^7Q07WQ

0[kohDOQ000Ph@030>7Q01OQ0`l;h@D?9n400kkQh@1gh@03_^7Q0?oQAn40023Q00<0hN406^4;3bcQ

00>nhN40MN42__oQB^40023Q00<0hN40DN400kkQh@1ch@:non5<h@008>400`3Qh@1Ah@03_^7Q073Q

0kkohDkQ000Ph@030>7Q05;Q00>nhN40K^400kkQh@3ohDoQ000Ph@030>7Q05;Q00>nhN40K>42__oQ

D^40023Q00<0hN40Dn400kkQh@1Zh@03_^7Q0?oQD^40023Q00<0hN40Dn400kkQh@1Xh@:non5Eh@00

3n4500;Q00<0hN401n400`3Qh@1Ch@03_^7Q06OQ00>nhN40on5Eh@004N401`3QhN40h@002>400`3Q

h@1Dh@03_^7Q06?Q0kkohESQ000Ah@070>7Qh@3Q0008h@@0Dn400kkQh@1Qh@:non5Kh@004N401`3Q

hN40h@002>400`3Qh@1Eh@03_^7Q05oQ00>nhN40on5Kh@004N401`3QhN40h@002>400`3Qh@1Eh@03

_^7Q05gQ0[kohEkQ000@h@801>400`3Qh@07h@030>7Q05KQ00>nhN40Fn400kkQh@3ohEkQ000Ph@03

0>7Q05KQ00>nhN40FN42__oQHN40023Q00<0hN40E^400kkQh@1Hh@03_^7Q0?oQHN40023Q00<0hN40

En400kkQh@1Dh@>non5Th@008>400`3Qh@1Gh@03_^7Q05;Q0[kohFOQ000Ph@030>7Q05SQ00>nhN40

D>400kkQh@3ohFOQ000Ph@030>7Q05WQ00>nhN40CN42__oQJ^40023Q00<0hN40FN400kkQh@1<h@03

_^7Q0?oQJ^40023Q00<0hN40F^400kkQh@18h@>non5]h@008>4205_Q00>nhN40A^42__oQL>40023Q

00<0hN40Fn400kkQh@14h@03_^7Q0?oQL>40023Q00<0hN40G>400kkQh@11h@:non5ch@008>400`3Q

h@1Lh@03_^7Q043Q00>nhN40on5ch@008>400`3Qh@1Mh@03_^7Q03cQ0kkohGKQ000Ph@030>7Q05kQ

00>nhN40>N42__oQNN40023Q00<0hN40Gn400kkQh@0gh@03_^7Q0?oQNN40023Q00<0hN40H>400kkQ

h@0ch@>non5lh@008>400`3Qh@1Qh@03_^7Q033Q0[kohGoQ000Ph@030>7Q06;Q00>nhN40;N42__oQ

PN40023Q00<0hN40Hn400kkQh@0Yh@>non63h@008>400`3Qh@1Th@03_^7Q02GQ0kkohHKQ000Ph@80

I^400kkQh@0Sh@03_^7Q0?oQQn40023Q00<0hN40I^42_R3Q0kkohH[Q000Ph@030>7Q06SQ0khJh@>n

on6=h@008>400`3Qh@1[h@03_^7Q01CQ0kkohI3Q000Ph@030>7Q06cQ1Kh;h@Jnon6Ch@008>400`3Q

h@1ah@^non6Ih@008>400`3Qh@3ohOoQ5^40023Q00<0hN40on7ohAKQ000Ph@030>7Q0?oQon4Fh@00

8>400`3Qh@3ohOoQ5^40023Q00<0hN40on7ohAKQ000Ph@030>7Q0?oQon4Fh@008>400`3Qh@3ohOoQ

5^40023Q00<0hN40on7ohAKQ003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQon4ih@00

on7ohCWQ003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQon4ih@00on4<h@8000CQ003Q

10001>400003h@030>7Q0?oQ6N400?oQ3N400`3Q0007h@030>7Q00;Q00<0h@00on4Jh@00on4=h@<0

0^4400;Q00L0hN7Q0>400?oQ6^400?oQ3N40103Q0007h@030>7Q00;Q00<0hN40on4Ih@007^420>cQ

00<0hN401n400`3Q0002h@030>400?oQ6^4001oQ00<0hN40jN4200[Q00<0hN400^400`3Qh@3ohAWQ

000Mh@<00^400`3Qh@3ohOoQ5>4001cQ00P0hN40h@3Q0?oQon4Eh@007>40203Qh@3Q0>40on7ohAGQ

000Mh@<000CQ0>40on7ohAGQ000Qh@030>400?oQon4Eh@008^400`3Qh@3ohOoQ5>400?oQon4ih@00

on7ohCWQ003ohOoQ>N400?oQon4ih@00on7ohCWQ0000\

\>"],

  ImageRangeCache->{{{0, 566}, {349.313, 0}} -> {11.1534, -12.9793, 0.0264183,

   0.0810305}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-0.986672 0.0785145 0.309017 0.0232808 [

[.26956 .29652 -6 -9 ]

[.26956 .29652 6 0 ]

[.42659 .29652 -6 -9 ]

[.42659 .29652 6 0 ]

[.58362 .29652 -6 -9 ]

[.58362 .29652 6 0 ]

[.74065 .29652 -6 -9 ]

[.74065 .29652 6 0 ]

[.89768 .29652 -6 -9 ]

[.89768 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.10003 .07621 -18 -4.5 ]

[.10003 .07621 0 4.5 ]

[.10003 .19261 -12 -4.5 ]

[.10003 .19261 0 4.5 ]

[.10003 .42542 -6 -4.5 ]

[.10003 .42542 0 4.5 ]

[.10003 .54182 -12 -4.5 ]

[.10003 .54182 0 4.5 ]

[.11253 .64303 -7 0 ]

[.11253 .64303 7 16 ]

[.5 .63053 -12 0 ]

[.5 .63053 12 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.26956 .30902 m

.26956 .31527 L

s

[(16)] .26956 .29652 0 1 Mshowa

.42659 .30902 m

.42659 .31527 L

s

[(18)] .42659 .29652 0 1 Mshowa

.58362 .30902 m

.58362 .31527 L

s

[(20)] .58362 .29652 0 1 Mshowa

.74065 .30902 m

.74065 .31527 L

s

[(22)] .74065 .29652 0 1 Mshowa

.89768 .30902 m

.89768 .31527 L

s

[(24)] .89768 .29652 0 1 Mshowa

.125 Mabswid

.15179 .30902 m

.15179 .31277 L

s

.19105 .30902 m

.19105 .31277 L

s

.2303 .30902 m

.2303 .31277 L

s

.30882 .30902 m

.30882 .31277 L

s

.34807 .30902 m

.34807 .31277 L

s

.38733 .30902 m

.38733 .31277 L

s

.46585 .30902 m

.46585 .31277 L

s

.5051 .30902 m

.5051 .31277 L

s

.54436 .30902 m

.54436 .31277 L

s

.62288 .30902 m

.62288 .31277 L

s

.66213 .30902 m

.66213 .31277 L

s

.70139 .30902 m

.70139 .31277 L

s

.7799 .30902 m

.7799 .31277 L

s

.81916 .30902 m

.81916 .31277 L

s

.85842 .30902 m

.85842 .31277 L

s

.07327 .30902 m

.07327 .31277 L

s

.03402 .30902 m

.03402 .31277 L

s

.93693 .30902 m

.93693 .31277 L

s

.97619 .30902 m

.97619 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.11253 .07621 m

.11878 .07621 L

s

[(-10)] .10003 .07621 1 0 Mshowa

.11253 .19261 m

.11878 .19261 L

s

[(-5)] .10003 .19261 1 0 Mshowa

.11253 .42542 m

.11878 .42542 L

s

[(5)] .10003 .42542 1 0 Mshowa

.11253 .54182 m

.11878 .54182 L

s

[(10)] .10003 .54182 1 0 Mshowa

.125 Mabswid

.11253 .09949 m

.11628 .09949 L

s

.11253 .12277 m

.11628 .12277 L

s

.11253 .14605 m

.11628 .14605 L

s

.11253 .16933 m

.11628 .16933 L

s

.11253 .21589 m

.11628 .21589 L

s

.11253 .23917 m

.11628 .23917 L

s

.11253 .26246 m

.11628 .26246 L

s

.11253 .28574 m

.11628 .28574 L

s

.11253 .3323 m

.11628 .3323 L

s

.11253 .35558 m

.11628 .35558 L

s

.11253 .37886 m

.11628 .37886 L

s

.11253 .40214 m

.11628 .40214 L

s

.11253 .4487 m

.11628 .4487 L

s

.11253 .47198 m

.11628 .47198 L

s

.11253 .49526 m

.11628 .49526 L

s

.11253 .51854 m

.11628 .51854 L

s

.11253 .05293 m

.11628 .05293 L

s

.11253 .02965 m

.11628 .02965 L

s

.11253 .00637 m

.11628 .00637 L

s

.11253 .56511 m

.11628 .56511 L

s

.11253 .58839 m

.11628 .58839 L

s

.11253 .61167 m

.11628 .61167 L

s

.25 Mabswid

.11253 0 m

.11253 .61803 L

s

gsave

.11253 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -73 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(k) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(33) show

83.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

1 0 0 r

.5 Mabswid

.57969 .23027 m

.57577 .23493 L

.57184 .23953 L

.56792 .24407 L

.56399 .24851 L

.56006 .25287 L

.55614 .25713 L

.55221 .26129 L

.54829 .26535 L

.54436 .2693 L

.54043 .27316 L

.53651 .27692 L

.53258 .28059 L

.52866 .28417 L

.52473 .28767 L

.52081 .29108 L

.51688 .29441 L

.51295 .29767 L

.50903 .30086 L

.5051 .30399 L

.50118 .30705 L

.49725 .31005 L

.49333 .313 L

.4894 .3159 L

.48547 .31874 L

.48155 .32155 L

.47762 .3243 L

.4737 .32702 L

.46977 .3297 L

.46585 .33235 L

.46192 .33496 L

.45799 .33754 L

.45407 .34009 L

.45014 .34262 L

.44622 .34512 L

.44229 .3476 L

.43837 .35005 L

.43444 .35249 L

.43051 .35491 L

.42659 .35731 L

.42266 .3597 L

.41874 .36208 L

.41481 .36444 L

.41089 .36679 L

.40696 .36913 L

.40303 .37146 L

.39911 .37379 L

.39518 .37611 L

.39126 .37842 L

.38733 .38073 L

Mistroke

.38341 .38304 L

.37948 .38534 L

.37555 .38765 L

.37163 .38995 L

.3677 .39225 L

.36378 .39456 L

.35985 .39687 L

.35593 .39918 L

.352 .40149 L

.34807 .40381 L

.34415 .40613 L

.34022 .40846 L

.3363 .41079 L

.33237 .41314 L

.32845 .41549 L

.32452 .41785 L

.32059 .42021 L

.31667 .42259 L

.31274 .42498 L

.30882 .42738 L

.30489 .42979 L

.30097 .43221 L

.29704 .43464 L

.29311 .43708 L

.28919 .43954 L

.28526 .44201 L

.28134 .44449 L

.27741 .44698 L

.27349 .44949 L

.26956 .45201 L

.26563 .45454 L

.26171 .45709 L

.25778 .45964 L

.25386 .46221 L

.24993 .46479 L

.24601 .46739 L

.24208 .46999 L

.23815 .4726 L

.23423 .47522 L

.2303 .47784 L

.22638 .48047 L

.22245 .48311 L

.21853 .48574 L

.2146 .48838 L

.21067 .49101 L

.20675 .49364 L

.20282 .49626 L

.1989 .49887 L

.19497 .50147 L

.19105 .50404 L

Mistroke

.18712 .5066 L

.18319 .50912 L

.17927 .51162 L

.17534 .51407 L

.17142 .51648 L

.16749 .51884 L

.16357 .52114 L

.15964 .52338 L

.15571 .52554 L

.15179 .52762 L

.14786 .52961 L

.14394 .53149 L

.14001 .53326 L

.13609 .5349 L

.13216 .53641 L

.12823 .53776 L

.12431 .53893 L

.12038 .53993 L

.11646 .54072 L

.11253 .54128 L

.10861 .5416 L

.10468 .54165 L

.10075 .5414 L

.09683 .54083 L

.0929 .5399 L

.08898 .53858 L

.08505 .53683 L

.08113 .5346 L

.0772 .53184 L

.07327 .5285 L

.06935 .5245 L

.06542 .51975 L

.0615 .51416 L

.05757 .50761 L

.05365 .49994 L

.04972 .49095 L

.04579 .48036 L

.04187 .46779 L

.03794 .45261 L

.03402 .4338 L

.02891 .37141 L

.02381 .30902 L

Mfstroke

.57969 .38776 m

.57577 .3831 L

.57184 .3785 L

.56792 .37397 L

.56399 .36952 L

.56006 .36516 L

.55614 .3609 L

.55221 .35675 L

.54829 .35269 L

.54436 .34873 L

.54043 .34487 L

.53651 .34111 L

.53258 .33744 L

.52866 .33386 L

.52473 .33037 L

.52081 .32696 L

.51688 .32362 L

.51295 .32036 L

.50903 .31717 L

.5051 .31405 L

.50118 .31098 L

.49725 .30798 L

.49333 .30503 L

.4894 .30214 L

.48547 .29929 L

.48155 .29649 L

.47762 .29373 L

.4737 .29101 L

.46977 .28833 L

.46585 .28569 L

.46192 .28308 L

.45799 .28049 L

.45407 .27794 L

.45014 .27542 L

.44622 .27292 L

.44229 .27044 L

.43837 .26798 L

.43444 .26554 L

.43051 .26312 L

.42659 .26072 L

.42266 .25833 L

.41874 .25596 L

.41481 .2536 L

.41089 .25124 L

.40696 .2489 L

.40303 .24657 L

.39911 .24424 L

.39518 .24192 L

.39126 .23961 L

.38733 .2373 L

Mistroke

.38341 .23499 L

.37948 .23269 L

.37555 .23039 L

.37163 .22808 L

.3677 .22578 L

.36378 .22347 L

.35985 .22117 L

.35593 .21886 L

.352 .21654 L

.34807 .21423 L

.34415 .2119 L

.34022 .20958 L

.3363 .20724 L

.33237 .2049 L

.32845 .20255 L

.32452 .20019 L

.32059 .19782 L

.31667 .19544 L

.31274 .19305 L

.30882 .19066 L

.30489 .18825 L

.30097 .18583 L

.29704 .1834 L

.29311 .18095 L

.28919 .1785 L

.28526 .17603 L

.28134 .17355 L

.27741 .17105 L

.27349 .16854 L

.26956 .16602 L

.26563 .16349 L

.26171 .16095 L

.25778 .15839 L

.25386 .15582 L

.24993 .15324 L

.24601 .15065 L

.24208 .14805 L

.23815 .14544 L

.23423 .14282 L

.2303 .14019 L

.22638 .13756 L

.22245 .13493 L

.21853 .13229 L

.2146 .12966 L

.21067 .12702 L

.20675 .12439 L

.20282 .12177 L

.1989 .11916 L

.19497 .11657 L

.19105 .11399 L

Mistroke

.18712 .11144 L

.18319 .10891 L

.17927 .10642 L

.17534 .10396 L

.17142 .10155 L

.16749 .09919 L

.16357 .09689 L

.15964 .09465 L

.15571 .09249 L

.15179 .09041 L

.14786 .08842 L

.14394 .08654 L

.14001 .08477 L

.13609 .08313 L

.13216 .08163 L

.12823 .08028 L

.12431 .0791 L

.12038 .07811 L

.11646 .07732 L

.11253 .07675 L

.10861 .07644 L

.10468 .07639 L

.10075 .07663 L

.09683 .07721 L

.0929 .07813 L

.08898 .07945 L

.08505 .0812 L

.08113 .08343 L

.0772 .08619 L

.07327 .08953 L

.06935 .09354 L

.06542 .09828 L

.0615 .10387 L

.05757 .11042 L

.05365 .11809 L

.04972 .12708 L

.04579 .13767 L

.04187 .15025 L

.03794 .16542 L

.03402 .18423 L

.02891 .24662 L

.02381 .30902 L

Mfstroke

0 .4 1 r

.58205 .4328 m

.58048 .43339 L

.57891 .43397 L

.57734 .43455 L

.57577 .43514 L

.5742 .43573 L

.57263 .43632 L

.57106 .43692 L

.56949 .43751 L

.56792 .43811 L

.56634 .43871 L

.56477 .43931 L

.5632 .43991 L

.56163 .44052 L

.56006 .44113 L

.55849 .44174 L

.55692 .44235 L

.55535 .44297 L

.55378 .44358 L

.55221 .4442 L

.55064 .44482 L

.54907 .44545 L

.5475 .44607 L

.54593 .4467 L

.54436 .44733 L

.54279 .44796 L

.54122 .4486 L

.53965 .44924 L

.53808 .44988 L

.53651 .45052 L

.53494 .45116 L

.53337 .45181 L

.5318 .45246 L

.53023 .45311 L

.52866 .45376 L

.52709 .45442 L

.52552 .45508 L

.52395 .45574 L

.52238 .45641 L

.52081 .45707 L

.51924 .45774 L

.51767 .45841 L

.5161 .45909 L

.51453 .45976 L

.51295 .46044 L

.51138 .46112 L

.50981 .46181 L

.50824 .4625 L

.50667 .46319 L

.5051 .46388 L

Mistroke

.50353 .46457 L

.50196 .46527 L

.50039 .46597 L

.49882 .46668 L

.49725 .46738 L

.49568 .46809 L

.49411 .4688 L

.49254 .46952 L

.49097 .47024 L

.4894 .47096 L

.48783 .47168 L

.48626 .47241 L

.48469 .47313 L

.48312 .47387 L

.48155 .4746 L

.47998 .47534 L

.47841 .47608 L

.47684 .47682 L

.47527 .47757 L

.4737 .47832 L

.47213 .47907 L

.47056 .47983 L

.46899 .48059 L

.46742 .48135 L

.46585 .48211 L

.46428 .48288 L

.46271 .48365 L

.46114 .48443 L

.45957 .48521 L

.45799 .48599 L

.45642 .48677 L

.45485 .48756 L

.45328 .48835 L

.45171 .48914 L

.45014 .48994 L

.44857 .49074 L

.447 .49155 L

.44543 .49235 L

.44386 .49316 L

.44229 .49398 L

.44072 .49479 L

.43915 .49562 L

.43758 .49644 L

.43601 .49727 L

.43444 .4981 L

.43287 .49893 L

.4313 .49977 L

.42973 .50061 L

.42816 .50146 L

.42659 .50231 L

Mistroke

.42502 .50316 L

.42345 .50401 L

.42188 .50487 L

.42031 .50574 L

.41874 .5066 L

.41717 .50747 L

.4156 .50835 L

.41403 .50922 L

.41246 .5101 L

.41089 .51099 L

.40932 .51188 L

.40775 .51277 L

.40618 .51366 L

.4046 .51456 L

.40303 .51547 L

.40146 .51637 L

.39989 .51728 L

.39832 .5182 L

.39675 .51911 L

.39518 .52004 L

.39361 .52096 L

.39204 .52189 L

.39047 .52282 L

.3889 .52376 L

.38733 .5247 L

.38576 .52564 L

.38419 .52658 L

.38262 .52754 L

.38105 .52849 L

.37948 .52945 L

.37791 .53041 L

.37634 .53137 L

.37477 .53234 L

.3732 .53331 L

.37163 .53428 L

.37006 .53526 L

.36849 .53624 L

.36692 .53723 L

.36535 .53821 L

.36378 .53921 L

.36221 .5402 L

.36064 .5412 L

.35907 .5422 L

.3575 .5432 L

.35593 .5442 L

.35436 .54521 L

.35279 .54622 L

.35122 .54724 L

.34964 .54825 L

.34807 .54927 L

Mistroke

.3465 .55029 L

.34493 .55131 L

.34336 .55234 L

.34179 .55336 L

.34022 .55439 L

.33865 .55542 L

.33708 .55645 L

.33551 .55748 L

.33394 .55851 L

.33237 .55954 L

.3308 .56058 L

.32923 .56161 L

.32766 .56264 L

.32609 .56367 L

.32452 .56471 L

.32295 .56574 L

.32138 .56677 L

.31981 .5678 L

.31824 .56882 L

.31667 .56985 L

.3151 .57087 L

.31353 .57189 L

.31196 .5729 L

.31039 .57392 L

.30882 .57493 L

.30725 .57593 L

.30568 .57693 L

.30411 .57792 L

.30254 .5789 L

.30097 .57988 L

.2994 .58085 L

.29783 .58181 L

.29625 .58277 L

.29468 .58371 L

.29311 .58465 L

.29154 .58557 L

.28997 .58648 L

.2884 .58738 L

.28683 .58827 L

.28526 .58914 L

.28369 .58999 L

.28212 .59083 L

.28055 .59166 L

.27898 .59246 L

.27741 .59325 L

.27584 .59402 L

.27427 .59476 L

.2727 .59548 L

.27113 .59619 L

.26956 .59686 L

Mistroke

.26799 .59751 L

.26642 .59813 L

.26485 .59873 L

.26328 .5993 L

.26171 .59983 L

.26014 .60033 L

.25857 .6008 L

.257 .60124 L

.25543 .60163 L

.25386 .60199 L

.25229 .60231 L

.25072 .60259 L

.24915 .60283 L

.24758 .60302 L

.24601 .60317 L

.24444 .60327 L

.24286 .60332 L

.24129 .60332 L

.23972 .60326 L

.23815 .60315 L

.23658 .60299 L

.23501 .60276 L

.23344 .60247 L

.23187 .60212 L

.2303 .60171 L

.22873 .60123 L

.22716 .60067 L

.22559 .60005 L

.22402 .59935 L

.22245 .59857 L

.22088 .59771 L

.21931 .59677 L

.21774 .59574 L

.21617 .59463 L

.2146 .59342 L

.21303 .59211 L

.21146 .5907 L

.20989 .58919 L

.20832 .58757 L

.20675 .58584 L

.20518 .58399 L

.20361 .58201 L

.20204 .57991 L

.20047 .57768 L

.1989 .5753 L

.19733 .57278 L

.19576 .5701 L

.19419 .56726 L

.19262 .56425 L

.19105 .56106 L

Mistroke

.18948 .55767 L

.1879 .55409 L

.18633 .55029 L

.18476 .54626 L

.18319 .54198 L

.18162 .53744 L

.18005 .53261 L

.17848 .52748 L

.17691 .52201 L

.17534 .51617 L

.17377 .50993 L

.1722 .50324 L

.17063 .49604 L

.16906 .48827 L

.16749 .47985 L

.16592 .47066 L

.16435 .46056 L

.16278 .44933 L

.16121 .43668 L

.15964 .42211 L

.15807 .40473 L

.1565 .38258 L

.15493 .30902 L

Mfstroke

.58205 .18523 m

.58048 .18465 L

.57891 .18407 L

.57734 .18348 L

.57577 .18289 L

.5742 .1823 L

.57263 .18171 L

.57106 .18112 L

.56949 .18052 L

.56792 .17993 L

.56634 .17933 L

.56477 .17872 L

.5632 .17812 L

.56163 .17751 L

.56006 .17691 L

.55849 .1763 L

.55692 .17568 L

.55535 .17507 L

.55378 .17445 L

.55221 .17383 L

.55064 .17321 L

.54907 .17259 L

.5475 .17196 L

.54593 .17133 L

.54436 .1707 L

.54279 .17007 L

.54122 .16944 L

.53965 .1688 L

.53808 .16816 L

.53651 .16752 L

.53494 .16687 L

.53337 .16622 L

.5318 .16558 L

.53023 .16492 L

.52866 .16427 L

.52709 .16361 L

.52552 .16295 L

.52395 .16229 L

.52238 .16163 L

.52081 .16096 L

.51924 .16029 L

.51767 .15962 L

.5161 .15895 L

.51453 .15827 L

.51295 .15759 L

.51138 .15691 L

.50981 .15622 L

.50824 .15554 L

.50667 .15485 L

.5051 .15415 L

Mistroke

.50353 .15346 L

.50196 .15276 L

.50039 .15206 L

.49882 .15136 L

.49725 .15065 L

.49568 .14994 L

.49411 .14923 L

.49254 .14852 L

.49097 .1478 L

.4894 .14708 L

.48783 .14635 L

.48626 .14563 L

.48469 .1449 L

.48312 .14417 L

.48155 .14343 L

.47998 .1427 L

.47841 .14195 L

.47684 .14121 L

.47527 .14046 L

.4737 .13971 L

.47213 .13896 L

.47056 .13821 L

.46899 .13745 L

.46742 .13668 L

.46585 .13592 L

.46428 .13515 L

.46271 .13438 L

.46114 .13361 L

.45957 .13283 L

.45799 .13205 L

.45642 .13126 L

.45485 .13047 L

.45328 .12968 L

.45171 .12889 L

.45014 .12809 L

.44857 .12729 L

.447 .12649 L

.44543 .12568 L

.44386 .12487 L

.44229 .12406 L

.44072 .12324 L

.43915 .12242 L

.43758 .12159 L

.43601 .12077 L

.43444 .11994 L

.43287 .1191 L

.4313 .11826 L

.42973 .11742 L

.42816 .11658 L

.42659 .11573 L

Mistroke

.42502 .11488 L

.42345 .11402 L

.42188 .11316 L

.42031 .1123 L

.41874 .11143 L

.41717 .11056 L

.4156 .10969 L

.41403 .10881 L

.41246 .10793 L

.41089 .10705 L

.40932 .10616 L

.40775 .10527 L

.40618 .10437 L

.4046 .10347 L

.40303 .10257 L

.40146 .10166 L

.39989 .10075 L

.39832 .09984 L

.39675 .09892 L

.39518 .098 L

.39361 .09707 L

.39204 .09615 L

.39047 .09521 L

.3889 .09428 L

.38733 .09334 L

.38576 .0924 L

.38419 .09145 L

.38262 .0905 L

.38105 .08955 L

.37948 .08859 L

.37791 .08763 L

.37634 .08666 L

.37477 .0857 L

.3732 .08472 L

.37163 .08375 L

.37006 .08277 L

.36849 .08179 L

.36692 .08081 L

.36535 .07982 L

.36378 .07883 L

.36221 .07783 L

.36064 .07684 L

.35907 .07584 L

.3575 .07484 L

.35593 .07383 L

.35436 .07282 L

.35279 .07181 L

.35122 .0708 L

.34964 .06978 L

.34807 .06876 L

Mistroke

.3465 .06774 L

.34493 .06672 L

.34336 .0657 L

.34179 .06467 L

.34022 .06364 L

.33865 .06262 L

.33708 .06159 L

.33551 .06055 L

.33394 .05952 L

.33237 .05849 L

.3308 .05746 L

.32923 .05642 L

.32766 .05539 L

.32609 .05436 L

.32452 .05333 L

.32295 .05229 L

.32138 .05127 L

.31981 .05024 L

.31824 .04921 L

.31667 .04819 L

.3151 .04716 L

.31353 .04614 L

.31196 .04513 L

.31039 .04412 L

.30882 .04311 L

.30725 .04211 L

.30568 .04111 L

.30411 .04012 L

.30254 .03913 L

.30097 .03815 L

.2994 .03718 L

.29783 .03622 L

.29625 .03527 L

.29468 .03432 L

.29311 .03339 L

.29154 .03246 L

.28997 .03155 L

.2884 .03066 L

.28683 .02977 L

.28526 .0289 L

.28369 .02804 L

.28212 .0272 L

.28055 .02638 L

.27898 .02557 L

.27741 .02478 L

.27584 .02402 L

.27427 .02327 L

.2727 .02255 L

.27113 .02185 L

.26956 .02117 L

Mistroke

.26799 .02052 L

.26642 .0199 L

.26485 .0193 L

.26328 .01874 L

.26171 .0182 L

.26014 .0177 L

.25857 .01723 L

.257 .0168 L

.25543 .0164 L

.25386 .01604 L

.25229 .01572 L

.25072 .01544 L

.24915 .0152 L

.24758 .01501 L

.24601 .01486 L

.24444 .01477 L

.24286 .01472 L

.24129 .01472 L

.23972 .01477 L

.23815 .01488 L

.23658 .01505 L

.23501 .01527 L

.23344 .01556 L

.23187 .01591 L

.2303 .01632 L

.22873 .01681 L

.22716 .01736 L

.22559 .01799 L

.22402 .01868 L

.22245 .01946 L

.22088 .02032 L

.21931 .02126 L

.21774 .02229 L

.21617 .02341 L

.2146 .02462 L

.21303 .02592 L

.21146 .02733 L

.20989 .02884 L

.20832 .03046 L

.20675 .0322 L

.20518 .03405 L

.20361 .03602 L

.20204 .03812 L

.20047 .04036 L

.1989 .04273 L

.19733 .04526 L

.19576 .04793 L

.19419 .05077 L

.19262 .05378 L

.19105 .05698 L

Mistroke

.18948 .06036 L

.1879 .06394 L

.18633 .06774 L

.18476 .07178 L

.18319 .07605 L

.18162 .08059 L

.18005 .08542 L

.17848 .09055 L

.17691 .09602 L

.17534 .10186 L

.17377 .1081 L

.1722 .1148 L

.17063 .12199 L

.16906 .12976 L

.16749 .13818 L

.16592 .14737 L

.16435 .15748 L

.16278 .1687 L

.16121 .18136 L

.15964 .19593 L

.15807 .2133 L

.1565 .23545 L

.15493 .30902 L

Mfstroke

1 0 0 r

.58754 .22086 m

.59147 .21616 L

.5954 .2115 L

.59932 .20692 L

.60325 .20244 L

.60717 .1981 L

.6111 .19392 L

.61502 .18992 L

.61895 .18613 L

.62288 .18256 L

.6268 .17921 L

.63073 .17609 L

.63465 .1732 L

.63858 .17052 L

.6425 .16806 L

.64643 .16581 L

.65036 .16374 L

.65428 .16186 L

.65821 .16016 L

.66213 .15861 L

.66606 .15722 L

.66998 .15596 L

.67391 .15483 L

.67784 .15383 L

.68176 .15293 L

.68569 .15214 L

.68961 .15145 L

.69354 .15084 L

.69746 .15032 L

.70139 .14987 L

.70532 .1495 L

.70924 .14919 L

.71317 .14894 L

.71709 .14875 L

.72102 .14861 L

.72494 .14852 L

.72887 .14848 L

.7328 .14847 L

.73672 .14851 L

.74065 .14859 L

.74457 .14869 L

.7485 .14883 L

.75242 .14901 L

.75635 .1492 L

.76028 .14943 L

.7642 .14968 L

.76813 .14995 L

.77205 .15024 L

.77598 .15055 L

.7799 .15088 L

Mistroke

.78383 .15123 L

.78776 .15159 L

.79168 .15197 L

.79561 .15236 L

.79953 .15276 L

.80346 .15318 L

.80738 .15361 L

.81131 .15405 L

.81524 .1545 L

.81916 .15495 L

.82309 .15542 L

.82701 .15589 L

.83094 .15637 L

.83486 .15686 L

.83879 .15735 L

.84272 .15785 L

.84664 .15836 L

.85057 .15887 L

.85449 .15938 L

.85842 .1599 L

.86234 .16042 L

.86627 .16095 L

.8702 .16147 L

.87412 .162 L

.87805 .16254 L

.88197 .16307 L

.8859 .16361 L

.88982 .16415 L

.89375 .16469 L

.89768 .16523 L

.9016 .16577 L

.90553 .16632 L

.90945 .16686 L

.91338 .1674 L

.9173 .16795 L

.92123 .16849 L

.92516 .16904 L

.92908 .16958 L

.93301 .17013 L

.93693 .17067 L

.94086 .17122 L

.94478 .17176 L

.94871 .1723 L

.95264 .17284 L

.95656 .17338 L

.96049 .17392 L

.96441 .17446 L

.96834 .175 L

.97226 .17553 L

.97619 .17607 L

Mistroke

Mfstroke

.58754 .39718 m

.59147 .40187 L

.5954 .40653 L

.59932 .41112 L

.60325 .41559 L

.60717 .41994 L

.6111 .42412 L

.61502 .42811 L

.61895 .4319 L

.62288 .43547 L

.6268 .43882 L

.63073 .44194 L

.63465 .44484 L

.63858 .44751 L

.6425 .44997 L

.64643 .45223 L

.65036 .45429 L

.65428 .45617 L

.65821 .45788 L

.66213 .45942 L

.66606 .46082 L

.66998 .46207 L

.67391 .4632 L

.67784 .46421 L

.68176 .4651 L

.68569 .46589 L

.68961 .46658 L

.69354 .46719 L

.69746 .46771 L

.70139 .46816 L

.70532 .46853 L

.70924 .46884 L

.71317 .46909 L

.71709 .46928 L

.72102 .46942 L

.72494 .46951 L

.72887 .46956 L

.7328 .46956 L

.73672 .46952 L

.74065 .46945 L

.74457 .46934 L

.7485 .4692 L

.75242 .46903 L

.75635 .46883 L

.76028 .46861 L

.7642 .46836 L

.76813 .46809 L

.77205 .4678 L

.77598 .46748 L

.7799 .46715 L

Mistroke

.78383 .46681 L

.78776 .46644 L

.79168 .46607 L

.79561 .46567 L

.79953 .46527 L

.80346 .46485 L

.80738 .46442 L

.81131 .46399 L

.81524 .46354 L

.81916 .46308 L

.82309 .46261 L

.82701 .46214 L

.83094 .46166 L

.83486 .46117 L

.83879 .46068 L

.84272 .46018 L

.84664 .45968 L

.85057 .45917 L

.85449 .45865 L

.85842 .45814 L

.86234 .45761 L

.86627 .45709 L

.8702 .45656 L

.87412 .45603 L

.87805 .4555 L

.88197 .45496 L

.8859 .45442 L

.88982 .45389 L

.89375 .45335 L

.89768 .4528 L

.9016 .45226 L

.90553 .45172 L

.90945 .45117 L

.91338 .45063 L

.9173 .45009 L

.92123 .44954 L

.92516 .449 L

.92908 .44845 L

.93301 .44791 L

.93693 .44736 L

.94086 .44682 L

.94478 .44628 L

.94871 .44573 L

.95264 .44519 L

.95656 .44465 L

.96049 .44411 L

.96441 .44358 L

.96834 .44304 L

.97226 .4425 L

.97619 .44197 L

Mistroke

Mfstroke

0 .4 1 r

.58754 .43079 m

.59147 .42936 L

.5954 .42794 L

.59932 .42654 L

.60325 .42515 L

.60717 .42376 L

.6111 .42239 L

.61502 .42104 L

.61895 .41969 L

.62288 .41835 L

.6268 .41702 L

.63073 .41571 L

.63465 .4144 L

.63858 .4131 L

.6425 .41182 L

.64643 .41054 L

.65036 .40927 L

.65428 .40802 L

.65821 .40677 L

.66213 .40553 L

.66606 .4043 L

.66998 .40307 L

.67391 .40186 L

.67784 .40066 L

.68176 .39946 L

.68569 .39827 L

.68961 .39709 L

.69354 .39592 L

.69746 .39476 L

.70139 .3936 L

.70532 .39245 L

.70924 .39131 L

.71317 .39017 L

.71709 .38905 L

.72102 .38793 L

.72494 .38681 L

.72887 .38571 L

.7328 .38461 L

.73672 .38352 L

.74065 .38243 L

.74457 .38135 L

.7485 .38028 L

.75242 .37921 L

.75635 .37815 L

.76028 .37709 L

.7642 .37604 L

.76813 .375 L

.77205 .37396 L

.77598 .37293 L

.7799 .3719 L

Mistroke

.78383 .37088 L

.78776 .36986 L

.79168 .36885 L

.79561 .36784 L

.79953 .36684 L

.80346 .36584 L

.80738 .36485 L

.81131 .36386 L

.81524 .36288 L

.81916 .3619 L

.82309 .36093 L

.82701 .35996 L

.83094 .35899 L

.83486 .35803 L

.83879 .35707 L

.84272 .35612 L

.84664 .35517 L

.85057 .35422 L

.85449 .35328 L

.85842 .35234 L

.86234 .35141 L

.86627 .35047 L

.8702 .34955 L

.87412 .34862 L

.87805 .3477 L

.88197 .34678 L

.8859 .34586 L

.88982 .34495 L

.89375 .34404 L

.89768 .34313 L

.9016 .34223 L

.90553 .34132 L

.90945 .34042 L

.91338 .33953 L

.9173 .33863 L

.92123 .33774 L

.92516 .33685 L

.92908 .33596 L

.93301 .33508 L

.93693 .33419 L

.94086 .33331 L

.94478 .33243 L

.94871 .33155 L

.95264 .33068 L

.95656 .3298 L

.96049 .32893 L

.96441 .32806 L

.96834 .32719 L

.97226 .32632 L

.97619 .32545 L

Mistroke

Mfstroke

.58754 .18725 m

.59147 .18868 L

.5954 .19009 L

.59932 .1915 L

.60325 .19289 L

.60717 .19427 L

.6111 .19564 L

.61502 .197 L

.61895 .19835 L

.62288 .19968 L

.6268 .20101 L

.63073 .20233 L

.63465 .20363 L

.63858 .20493 L

.6425 .20622 L

.64643 .20749 L

.65036 .20876 L

.65428 .21002 L

.65821 .21127 L

.66213 .21251 L

.66606 .21374 L

.66998 .21496 L

.67391 .21617 L

.67784 .21738 L

.68176 .21857 L

.68569 .21976 L

.68961 .22094 L

.69354 .22211 L

.69746 .22328 L

.70139 .22443 L

.70532 .22558 L

.70924 .22672 L

.71317 .22786 L

.71709 .22899 L

.72102 .23011 L

.72494 .23122 L

.72887 .23233 L

.7328 .23342 L

.73672 .23452 L

.74065 .2356 L

.74457 .23668 L

.7485 .23776 L

.75242 .23882 L

.75635 .23989 L

.76028 .24094 L

.7642 .24199 L

.76813 .24304 L

.77205 .24407 L

.77598 .24511 L

.7799 .24613 L

Mistroke

.78383 .24716 L

.78776 .24817 L

.79168 .24918 L

.79561 .25019 L

.79953 .25119 L

.80346 .25219 L

.80738 .25318 L

.81131 .25417 L

.81524 .25515 L

.81916 .25613 L

.82309 .25711 L

.82701 .25807 L

.83094 .25904 L

.83486 .26 L

.83879 .26096 L

.84272 .26191 L

.84664 .26286 L

.85057 .26381 L

.85449 .26475 L

.85842 .26569 L

.86234 .26663 L

.86627 .26756 L

.8702 .26849 L

.87412 .26941 L

.87805 .27034 L

.88197 .27126 L

.8859 .27217 L

.88982 .27308 L

.89375 .27399 L

.89768 .2749 L

.9016 .27581 L

.90553 .27671 L

.90945 .27761 L

.91338 .27851 L

.9173 .2794 L

.92123 .28029 L

.92516 .28118 L

.92908 .28207 L

.93301 .28296 L

.93693 .28384 L

.94086 .28472 L

.94478 .2856 L

.94871 .28648 L

.95264 .28736 L

.95656 .28823 L

.96049 .2891 L

.96441 .28998 L

.96834 .29085 L

.97226 .29171 L

.97619 .29258 L

Mistroke

Mfstroke

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{567, 350.313},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.776525,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008g0001GPP10`40000100000800002008200000

P800P020P<30`<3L`:K:l00003<006H009T00<`00?l0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV

09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<003o03?o06Ko09Wo0<co

0?oo0000<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I

<c>I<fJI<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0

IYT0I/`0I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bI

I_nIIP3<IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0c

VC<cVFHcVITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<

VIW<VLc<VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`c

c?lcc01Vc3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03o

c3?oc6Koc9Woc<coc?ooc000oc<0ofH0oiT0ol`0ool0o`0coc<cofHcoiTcol`coolco`1Voc=VofIV

oiUVolaVoomVo`2Ioc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<o`3ooc?oofKooiWoolco

ooooo`0000410@820P<30`@410D51@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C

4a@D5?okl:2PY820P?l0003o0?oo0000ool0o`3oooooodOQ00<0hN40on7^h@00An400`3Qh@3ohNkQ

0017h@030>7Q0?oQk^4004OQ0`3ohNkQ0017h@030>7Q0?oQk^4004OQ00<0hN40on7^h@00An400`3Q

h@3ohNkQ0017h@030>7Q0?oQk^4004OQ00<0hN40>n4;__oQZ>4004OQ00<0hN40>>43_P_Q1;kohJCQ

0017h@030>7Q03KQ0[hBh@>non6Qh@00An400`3Qh@0dh@:n5^43__oQWn4004OQ00<0hN40<^42_Q_Q

0kkohIcQ0017h@030>7Q03;Q00>nhN407>43__oQV^4004OQ00<0hN40<>42_R;Q0[kohISQ0017h@03

0>7Q02oQ00>nhN408n42__oQUn4004OQ0`0^h@03_^7Q02KQ0[kohIGQ0017h@030>7Q02kQ00>nhN40

:>42__oQTn4004OQ00<0hN40;N400kkQh@0[h@:non6Ah@00An400`3Qh@0/h@03_^7Q02kQ0[kohHoQ

0017h@030>7Q02_Q00>nhN40<>42__oQS^4004OQ00<0hN40:^400kkQh@0ch@:non6<h@00An400`3Q

h@0Yh@03_^7Q03KQ00>nhN40on69h@00An400`3Qh@0Yh@03_^7Q03KQ0[kohH[Q0017h@030>7Q02WQ

00>nhN40>>42__oQR>4004OQ00<0hN40:>400kkQh@0kh@03_^7Q0?oQQN4004OQ00<0hN409n400kkQ

h@0mh@:non65h@00An400`3Qh@0Wh@03_^7Q03oQ0[kohH?Q0017h@<09^400kkQh@12h@03_^7Q0?oQ

P>4004OQ00<0hN409N400kkQh@14h@:non60h@00An400`3Qh@0Uh@03_^7Q04KQ00>nhN40on5mh@00

An400`3Qh@0Uh@03_^7Q04OQ00>nhN40on5lh@00An400`3Qh@0Th@03_^7Q04WQ0[kohGcQ0017h@03

0>7Q02CQ00>nhN40Bn42__oQN^4004OQ00<0hN408n400kkQh@1>h@03_^7Q0?oQMn4004OQ00<0hN40

8n400kkQh@1?h@:non5gh@00An400`3Qh@0Rh@03_^7Q05;Q0[kohGGQ0017h@030>7Q02;Q00>nhN40

Dn42__oQM>4003KQ1@02h@030>7Q00OQ00<0hN408^400kkQh@1Eh@:non5bh@00>>401`3QhN40h@00

2>400`3Qh@0Qh@03_^7Q05SQ00>nhN40on5_h@00<^4300?Q00L0hN7Q0>4000/?00<0hN407^400kkQ

h@1Ih@03_^7Q0?oQK^4003SQ00<0h@l010l8h@030>7Q00@?7>400kkQh@1Kh@:non5^h@00>>423`;Q

00<0h@002>400`3Qh@04h@@?6>400kkQh@1Mh@:non5/h@00=^423`030>7Q00;Q00<0hN401n400`3Q

h@08h@8?5^400kkQh@1Nh@:non5[h@00=N400`oQh@0?h@030>7Q00[Q0PlDh@03_^7Q063Q0[kohFWQ

000dh@033n7Q013Q00<0hN403>423a;Q00>nhN40H^400kkQh@3ohFKQ000ch@033n7Q017Q00<0hN40

3^423`oQ00>nhN40I>42__oQI^4003;Q00<?hN404^400`3Qh@0@h@8?3N400kkQh@1Vh@:non5Th@00

<N400`oQh@0Ch@030>7Q01;Q0Pl;h@03_^7Q06OQ0[kohF?Q000`h@033n7Q01CQ00<0hN405>423`SQ

00>nhN40J^42__oQHN4002oQ00<?hN405N400`3Qh@0Fh@8?1^400kkQh@1/h@:non5Oh@00;^400`oQ

h@0Fh@030>7Q01SQ00<?hN400n400kkQh@1]h@>non5Mh@00;N400`oQh@0Gh@<06N401@oQhN6n07?Q

0[kohE_Q000]h@033n7Q01OQ00<0hN406^423`03hKkQ07?Q0[kohE[Q000/h@033n7Q01SQ00<0hN40

7>400`nnh@1eh@:non5Hh@00:n400`oQh@0Ih@030>7Q01cQ00Bnh@l?M^42__oQE^4002_Q00<?hN40

6N400`3Qh@0Lh@05_^7Qh@l0M^42__oQEN4002[Q00<?hN406^400`3Qh@0Lh@03_^7Q00;Q00<?hN40

MN43__oQD^4002WQ00<?hN406n400`3Qh@0Lh@03_^7Q00?Q0Pmgh@:non5Ah@00:N400`oQh@0Kh@03

0>7Q01cQ00>nhN401N423gOQ0[kohDoQ000Xh@033n7Q01cQ00<0hN407>400kkQh@07h@033n7Q07KQ

00>nhN40on5<h@00:>400`oQh@0Lh@030>7Q01cQ00>nhN402>400`oQh@1fh@>non5;h@00:>400`oQ

h@0Lh@030>7Q01_Q00>nhN402^423gWQ0[kohDWQ000Wh@033n7Q01gQ00<0hN406n400kkQh@0<h@8?

N>42__oQB>4002OQ00<?hN407N4301_Q00>nhN403^423gSQ0kkohDGQ000Vh@033n7Q01kQ00<0hN40

6^400kkQh@0Ah@033n7Q07OQ0[kohDCQ000Vh@033n7Q01kQ00<0hN406^400kkQh@0Bh@8?NN42__oQ

@^4002KQ00<?hN407^400`3Qh@0Jh@03_^7Q01CQ0Pmih@:non50h@009N400`oQh@0Oh@030>7Q01[Q

00>nhN405^400`oQh@1hh@:non4nh@009N400`oQh@0Oh@030>7Q01[Q00>nhN405n400`oQh@1ih@:n

on4lh@009N400`oQh@0Oh@030>7Q01WQ00>nhN406N423g_Q0[kohC[Q000Th@033n7Q023Q00<0hN40

6N400kkQh@0Kh@8?Nn42__oQ>>4002CQ00<?hN408>400`3Qh@0Ih@03_^7Q01gQ00<?hN40N^42__oQ

=^4002CQ00<?hN408>400`3Qh@0Ih@03_^7Q01kQ00<?hN40Nn43__oQ<n4002?Q00<?hN408N400`3Q

h@0Ih@03_^7Q01oQ0Pmmh@:non4bh@008n400`oQh@0Qh@030>7Q01SQ00>nhN408^400`oQh@1lh@>n

on4_h@008n400`oQh@0Qh@<06>400kkQh@0Sh@033n7Q07gQ0kkohBgQ000Rh@033n7Q02;Q00<0hN40

6>400kkQh@0Th@8?P>42_W7Q5@nTh@008^400`oQh@0Rh@030>7Q01SQ00>nhN409^423goQ0kiUh@X?

5N4?3iGQ000Rh@033n7Q02;Q00<0hN406>400kkQh@0Xh@033n7Q07oQ0kiLh@H?;^4:3h_Q000Qh@03

3n7Q02?Q00<0hN406>400kkQh@0Yh@033n7Q083Q0kiFh@@??^483h?Q000Qh@033n7Q02?Q00<0hN40

6>400kkQh@0Zh@8?Pn42_U;Q0Pm:h@X?NN40027Q00<?hN408n400`3Qh@0Hh@03_^7Q02cQ0Pn2h@>n

C>443eKQ1Pmch@008N400`oQh@0Sh@030>7Q01SQ00>nhN40;^400`oQh@22h@:nAn433f3Q20m[h@00

8>400`oQh@0Th@030>7Q01SQ00>nhN40;n400`oQh@23h@>n@^423f_Q2@mRh@008>400`oQh@0Th@03

0>7Q01OQ00>nhN40<N423hKQ0[hnh@8?M^463ecQ000Ph@033n7Q02CQ00<0hN405n400kkQh@0ch@8?

Q^43_SWQ0Pmnh@P?E>40023Q00<?hN409>400`3Qh@0Gh@03_^7Q03GQ00<?hN40Q^42_SGQ0Pn8h@H?

C^40023Q00<?hN409>4301OQ00>nhN40=^400`oQh@27h@>n<N400`oQh@2>h@P?A^4001oQ00<?hN40

9N400`3Qh@0Gh@03_^7Q03OQ0Pn:h@:n;^400`oQh@2Gh@P??^4001oQ00<?hN409N400`3Qh@0Gh@03

_^7Q03WQ0Pn:h@>n:N423j;Q1Plhh@007n400`oQh@0Uh@030>7Q01KQ00>nhN40?>423h[Q0khUh@8?

Z^483c3Q000Oh@033n7Q02GQ00<0hN405^400kkQh@0nh@033n7Q08[Q0[hRh@033n7Q0>;Q000Oh@03

3n7Q02GQ00<0hN405^400kkQh@0oh@033n7Q08_Q1;hMh@033n7Q0>?Q000Nh@033n7Q02KQ00<0hN40

5^400kkQh@10h@8?Sn42_Q[Q00<?hN40i>4001kQ00<?hN409^400`3Qh@0Fh@03_^7Q04;Q0Pn?h@>n

5^400`oQh@3Uh@007^400`oQh@0Vh@030>7Q01KQ00>nhN40A>400`oQh@2>h@>n4n400`oQh@3Vh@00

7^400`oQh@0Vh@030>7Q01KQ00>nhN40AN400`oQh@2Bh@03_^7Q00gQ00<?hN40in4001kQ00<?hN40

7>400`3Qh@07h@030>7Q01GQ00>nhN40An423i?Q0[h<h@033n7Q0>SQ000Nh@033n7Q01_Q00<0h@00

2>400`3Qh@0Eh@03_^7Q04WQ0PnCh@Bn1n400`oQh@3Yh@007^400`oQh@0Fh@<01>400`3Qh@06h@@0

5>400kkQh@1;h@8?UN42_PCQ00<?hN40j^4001kQ00<?hN406n4200WQ00<0hN405N400kkQh@1=h@8?

UN42_P03h@oQ0>cQ000Mh@033n7Q01cQ00<0hN402>400`3Qh@0Eh@03_^7Q04oQ0PnEh@Bnjn4001gQ

00<?hN407>4300SQ00<0hN405N400kkQh@1Ah@033n7Q097Q00<?hN400^42_^WQ000Mh@033n7Q02OQ

00<0hN405N400kkQh@1Bh@8?T>400`oQh@05h@BniN4001gQ00<?hN409n400`3Qh@0Eh@03_^7Q05CQ

0Pn=h@033n7Q00[Q0[kSh@007N400`oQh@0Wh@030>7Q01GQ00>nhN40E^423h[Q00<?hN403N44_]oQ

000Mh@033n7Q02OQ00<0hN405>400kkQh@1Ih@033n7Q08KQ00<?hN404^42_]gQ000Mh@033n7Q02OQ

00<0hN405>400kkQh@1Jh@033n7Q08CQ00<?hN405N44_]WQ000Mh@033n7Q02OQ00<0hN405>400kkQ

h@1Kh@8?Q>400`oQh@0Ih@>ne^4001gQ00<?hN409n400`3Qh@0Dh@03_^7Q05gQ0Pn1h@033n7Q01gQ

1;kBh@007N400`oQh@0Wh@030>7Q01CQ00>nhN40Gn423gkQ00<?hN408^42_]3Q000Lh@033n7Q02SQ

0`0Dh@03_^7Q067Q0Pmkh@033n7Q02GQ1;k<h@007>400`oQh@0Xh@030>7Q01CQ00>nhN40Hn400`oQ

h@1gh@033n7Q02[Q1;k8h@007>400`oQh@0Xh@030>7Q01CQ00>nhN40I>400`oQh@1fh@033n7Q02kQ

0[k6h@007>400`oQh@0Xh@030>7Q01CQ00>nhN40IN423gGQ00<?hN40<N44_/;Q000Lh@033n7Q02SQ

00<0hN405>400kkQh@1Wh@8?Zn42_/3Q000Lh@033n7Q02SQ00<0hN404n400kkQh@1Zh@8?Zn44_[cQ

000Lh@033n7Q02SQ00<0hN404n400kkQh@1/h@8?[N44_[SQ000Lh@033n7Q02SQ00<0hN404n400kkQ

h@1^h@033n7Q0:kQ1;jdh@007>400`oQh@0Xh@030>7Q01?Q00>nhN40Kn400`oQh@1Wh@033n7Q04OQ

0[jbh@007>400`oQh@0Xh@030>7Q01?Q00>nhN40L>423fKQ00<?hN40B^44_ZkQ000Lh@033n7Q02SQ

00<0hN404n400kkQh@1bh@8?Hn400`oQh@1?h@BnZ^4001_Q00<?hN40:N400`3Qh@0Ch@03_^7Q07CQ

0PmPh@033n7Q05CQ1;jVh@006n400`oQh@0Yh@<04n400kkQh@1fh@8?GN400`oQh@1Ih@:nY>4001_Q

00<?hN40:N400`3Qh@0Ch@03_^7Q07SQ00<?hN40FN400`oQh@1Lh@BnX>4001_Q00<?hN40:N400`3Q

h@0Ch@03_^7Q07WQ00<?hN40F>400`oQh@1Ph@FnVn4001_Q00<?hN40:N400`3Qh@0Ch@03_^7Q07[Q

0PmGh@033n7Q06KQ1;jGh@006n400`oQh@0Yh@030>7Q01?Q00>nhN40O>423eCQ00<?hN40Jn44_Y?Q

000Kh@033n7Q02WQ00<0hN404n400kkQh@1nh@8?DN400`oQh@1`h@BnSn4001_Q00<?hN40:N400`3Q

h@0Ch@03_^7Q083Q0Pm>h@033n7Q07GQ1;j;h@006n400`oQh@0Yh@030>7Q01?Q00>nhN40P^400`oQ

h@1:h@033n7Q07[Q1;j7h@006n400`oQh@0Yh@030>7Q01?Q00>nhN40Pn400`oQh@18h@033n7Q07oQ

1;j3h@006n400`oQh@0Yh@030>7Q01?Q00>nhN40Q>423dOQ00<?hN40Q>44_WoQ000Kh@033n7Q02WQ

00<0hN404n400kkQh@26h@8?A>400`oQh@29h@BnNn4001_Q00<?hN40:N400`3Qh@0Ch@03_^7Q08SQ

0Pm2h@033n7Q08gQ1;igh@006^400`oQh@0Zh@<04n400kkQh@2:h@8??n400`oQh@2Bh@BnLn4001[Q

00<?hN40:^400`3Qh@0Ch@03_^7Q08cQ00<?hN40>n400`oQh@2Gh@BnKn4001[Q00<?hN40:^400`3Q

h@0Ch@03_^7Q08gQ0Pljh@033n7Q09cQ1;i[h@006^400`oQh@0Zh@030>7Q01?Q00>nhN40Sn423cOQ

00<?hN40XN44_VOQ000Jh@033n7Q02[Q00<0hN404n400kkQh@2Ah@8?=>400`oQh@2Vh@FnH^4001[Q

00<?hN40:^400`3Qh@0Ch@03_^7Q09?Q00<?hN40;n423jkQ1;iNh@006^400`oQh@0Zh@030>7Q01?Q

00>nhN40U>400`oQh@0]h@033n7Q0;;Q1;iJh@006^400`oQh@0Zh@030>7Q01?Q00>nhN40UN423bcQ

00<?hN40]n44_UKQ000Jh@033n7Q02[Q00<0hN404n400kkQh@2Gh@8?:N400`oQh@2lh@BnD^4001[Q

00<?hN40:^400`3Qh@0Ch@03_^7Q09WQ00<?hN409N400`oQh@31h@JnC>4001[Q00<?hN40:^400`3Q

h@0Ch@03_^7Q03?Q1@000n400019h@D00^400`3Qh@0<h@033n7Q02?Q00<?hN405>4300?Q00<0hN40

B>4300;Q0`1:h@<00n4300SQ1;i8h@006^400`oQh@0Zh@030>7Q01?Q00>nhN40=N401`3QhN40h@00

B^401`3QhN40h@003^423b7Q0PlGh@030>7Q00;Q00<0h@00BN400`3Qh@02h@030>7Q04[Q00<0hN40

1>400`3Qh@0;h@BnA>4001[Q00<?hN40:^4301?Q00>nhN40=N401`3QhN40h@00B^401`3QhN40h@00

4>423akQ00<?hN406>401`3QhN40h@00B^400`3Qh@02h@030>7Q04[Q00@0hN7Q100@h@Bn@>4001[Q

00<?hN40:^400`3Qh@0Ch@03_^7Q03GQ00@0hN7Q0P1;h@030>7Q00;Q00<0hN404N400`oQh@0Jh@03

3n7Q01WQ00L0hN7Q0>4004[Q00<0hN400^400`3Qh@1:h@070>7Qh@3Q000Eh@Bn?>4001[Q00<?hN40

:^400`3Qh@0Ch@03_^7Q03GQ00D0hN7Q001<h@070>7Qh@3Q000Ch@033n7Q01SQ00<?hN406N400`3Q

0002h@030>4004WQ00<0h@000^400`3Q001:h@030>4000?Q0P0Ih@Jn=^4001[Q00<?hN40:^400`3Q

h@0Ch@03_^7Q03CQ0P04h@80BN4200CQ00<0hN404n423aOQ00<?hN406n400`3Qh@02h@030>7Q04WQ

00<0hN400^400`3Qh@1:h@030>7Q00?Q00<0hN407N44_S;Q000Ih@033n7Q02_Q00<0hN404n400kkQ

h@2Sh@8?5>400`oQh@3Yh@:n<>4001WQ00<?hN40:n400`3Qh@0Ch@03_^7Q0:GQ00<?hN404>400`oQ

h@3ohAgQ000Ih@033n7Q02_Q00<0hN404n400kkQh@2Vh@033n7Q00gQ0PoohB3Q000Ih@033n7Q02_Q

00<0hN404n400kkQh@2Wh@8?3>400`oQh@3ohB3Q000Ih@033n7Q02_Q00<0hN404n400kkQh@2Yh@03

3n7Q00SQ00<?hN40on4Qh@006N400`oQh@0[h@030>7Q01?Q00>nhN40Z^400`oQh@06h@033n7Q0?oQ

8^4001WQ00<?hN40:n400`3Qh@0Ch@03_^7Q0:_Q0Pl5h@033n7Q0?oQ3n44013Q000Ih@033n7Q02_Q

00<0hN404n400kkQh@2]h@033n7Q008?on4Bh@<04N4000cQ3@000`l000110003_P000:h00Poo00D0

4N400`3Qh@0?h@006N400`oQh@02h@030>7Q017Q00<0hN404^400`3Qh@0Ah@030>6n017Q00<0hN40

4^400`3Qh@0Ah@030>7Q017Q00<0hN404^400`3Qh@0Ah@030>7Q017Q00<0hN404^400`3Qh@0=h@<?

00?Q0>404n400`3Qh@0Ah@030>7Q017Q00<0hN404^400`3Qh@0Ah@030>7Q017Q00<0hN404^400`3Q

h@0Ah@030>7Q017Q00<0hN404^400`3Qh@0Ah@030>7Q017Q00<0hN406n42017Q000Ih@033n7Q00;Q

00<0hN404N400`3Qh@0Bh@030>7Q017Q00<0hKh04N400`3Qh@0Bh@030>7Q017Q00<0hN404N400`3Q

h@0Bh@030>7Q017Q00<0hN404N400`3Qh@0Bh@030>7Q00_Q0Pl3h@033`3Q01?Q00<0hN404N400`3Q

h@0Ah@030>7Q01;Q00<0hN404N400`3Qh@0Ah@030>7Q01;Q00<0hN404N400`3Qh@0Ah@030>7Q01;Q

00<0hN404N400`3Qh@0Ah@030>7Q02kQ000Ih@033n7Q02_Q00<0hN404n400kkQh@0hh@030>7Q04kQ

00<0hN407n400`oQh@04h@033n7Q02KQ00<0hN40C^400`3Qh@1?h@030>7Q05KQ000Ih@033n7Q02_Q

00<0hN404n400kkQh@0hh@030>7Q04kQ00<0hN407^400`oQh@06h@033n7Q02GQ00<0hN40C^400`3Q

h@1?h@030>7Q05KQ000Ih@033n7Q02_Q00<0hN404n400kkQh@2Xh@8?2^400`oQh@3ohB7Q000Ih@03

3n7Q02_Q00<0hN404n400kkQh@2Wh@033n7Q00_Q0PoohB7Q000Ih@033n7Q02_Q00<0hN404n400kkQ

h@2Vh@033n7Q00kQ00<?hN40on4Nh@006N400`oQh@0[h@030>7Q01?Q00>nhN40Y>423a;Q00<?hN40

on4Mh@006^400`oQh@0Zh@030>7Q01?Q00>nhN40Xn400`oQh@0Ch@033n7Q0>SQ0kh`h@006^400`oQ

h@0Zh@030>7Q01?Q00>nhN40X^400`oQh@0Eh@033n7Q0>?Q1;hch@006^400`oQh@0Zh@030>7Q01?Q

00>nhN40X>423aWQ0PoOh@Bn=n4001[Q00<?hN40:^4301?Q00>nhN40W^423agQ00<?hN40e^46_S_Q

000Jh@033n7Q02[Q00<0hN404n400kkQh@2Mh@033n7Q01kQ00<?hN40dN44_T7Q000Jh@033n7Q02[Q

00<0hN404n400kkQh@2Lh@033n7Q023Q00<?hN40c>44_TGQ000Jh@033n7Q02[Q00<0hN404n400kkQ

h@2Jh@8?9>400`oQh@37h@BnBN4001[Q00<?hN40:^400`3Qh@0Ch@03_^7Q09SQ0PlWh@033n7Q0<;Q

1;i=h@006^400`oQh@0Zh@030>7Q01?Q00>nhN40Un400`oQh@0Xh@033n7Q0;gQ1;iAh@006^400`oQ

h@0Zh@030>7Q01?Q00>nhN40U^400`oQh@0Zh@033n7Q0;SQ1;iEh@006^400`oQh@0Zh@030>7Q01?Q

00>nhN40U>423bkQ00<?hN40/N46_UWQ000Jh@033n7Q02[Q00<0hN404n400kkQh@2Bh@8?<N423jcQ

1KiOh@006^400`oQh@0Zh@030>7Q01?Q00>nhN40TN400`oQh@0ch@033n7Q0:GQ1;iTh@006^400`oQ

h@0Zh@030>7Q01?Q00>nhN40T>400`oQh@0eh@033n7Q0:3Q1;iXh@006^400`oQh@0Zh@030>7Q01?Q

00>nhN40S^423cWQ00<?hN40Vn44_VcQ000Jh@033n7Q02[Q0`0Ch@03_^7Q08_Q0`llh@033n7Q09KQ

1;i`h@006n400`oQh@0Yh@030>7Q01?Q00>nhN40RN423d3Q00<?hN40TN44_WCQ000Kh@033n7Q02WQ

00<0hN404n400kkQh@28h@033n7Q047Q00<?hN40S>44_WSQ000Kh@033n7Q02WQ00<0hN404n400kkQ

h@27h@033n7Q04?Q00<?hN40Qn44_WcQ000Kh@033n7Q02WQ00<0hN404n400kkQh@25h@8?An400`oQ

h@22h@BnP>4001_Q00<?hN40:N400`3Qh@0Ch@03_^7Q08?Q0Pm:h@033n7Q07gQ1;j4h@006n400`oQ

h@0Yh@030>7Q01?Q00>nhN40PN423dgQ00<?hN40N>44_XSQ000Kh@033n7Q02WQ00<0hN404n400kkQ

h@20h@033n7Q04gQ00<?hN40M>44_XcQ000Kh@033n7Q02WQ00<0hN404n400kkQh@1oh@033n7Q04oQ

00<?hN40Kn44_Y3Q000Kh@033n7Q02WQ00<0hN404n400kkQh@1mh@8?Dn400`oQh@1Zh@BnU>4001_Q

00<?hN40:N400`3Qh@0Ch@03_^7Q07_Q0PmFh@033n7Q06OQ0[jHh@006n400`oQh@0Yh@030>7Q01?Q

00>nhN40NN423eWQ00<?hN40HN45_Y[Q000Kh@033n7Q02WQ00<0hN404n400kkQh@1gh@8?G>400`oQ

h@1Lh@BnWn4001_Q00<?hN40:N4301?Q00>nhN40M^400`oQh@1Mh@033n7Q05OQ1;jSh@006n400`oQ

h@0Yh@030>7Q01?Q00>nhN40MN400`oQh@1Nh@033n7Q05?Q1;jWh@007>400`oQh@0Xh@030>7Q01?Q

00>nhN40Ln423f;Q00<?hN40D>42_Z_Q000Lh@033n7Q02SQ00<0hN404n400kkQh@1ah@8?IN400`oQ

h@1;h@Bn[N4001cQ00<?hN40:>400`3Qh@0Ch@03_^7Q06oQ0PmXh@033n7Q04KQ1;jah@007>400`oQ

h@0Xh@030>7Q01?Q00>nhN40KN423joQ1;jeh@007>400`oQh@0Xh@030>7Q01?Q00>nhN40K>400`oQ

h@2]h@:n^N4001cQ00<?hN40:>400`3Qh@0Ch@03_^7Q06_Q00<?hN40Z^44_[_Q000Lh@033n7Q02SQ

00<0hN405>400kkQh@1Xh@8?ZN44_[oQ000Lh@033n7Q02SQ00<0hN405>400kkQh@1Vh@8?M>400`oQ

h@0bh@:n`n4001cQ00<?hN40:>400`3Qh@0Dh@03_^7Q06CQ0Pmgh@033n7Q02gQ1;k5h@007>400`oQ

h@0Xh@030>7Q01CQ00>nhN40H^423g[Q00<?hN40:>44_/WQ000Lh@033n7Q02SQ0`0Dh@03_^7Q063Q

0Pmmh@033n7Q02GQ0[k=h@007N400`oQh@0Wh@030>7Q01CQ00>nhN40Gn400`oQh@1mh@033n7Q027Q

1;k?h@007N400`oQh@0Wh@030>7Q01CQ00>nhN40G^400`oQh@1oh@033n7Q01gQ0kkCh@007N400`oQ

h@0Wh@030>7Q01CQ00>nhN40G>423h?Q00<?hN406>44_]KQ000Mh@033n7Q02OQ00<0hN405>400kkQ

h@1Jh@8?Q^400`oQh@0Eh@:nf^4001gQ00<?hN409n400`3Qh@0Dh@03_^7Q05SQ0Pn9h@033n7Q013Q

1;kLh@007N400`oQh@0Wh@030>7Q01GQ00>nhN40E^400`oQh@29h@033n7Q00kQ0[kPh@007N400`oQ

h@0Wh@030>7Q01GQ00>nhN40EN400`oQh@2;h@033n7Q00WQ1;kRh@007N400`oQh@0Wh@030>7Q01GQ

00>nhN40Dn423hoQ00<?hN401^42_^KQ000Mh@033n7Q02OQ00<0hN405N400kkQh@1@h@<?T^4010oQ

hN44_^SQ000Mh@033n7Q01gQ00<0hN401n400`3Qh@0Eh@03_^7Q04kQ0PnFh@033kjn0>cQ000Nh@03

3n7Q01_Q00<0h@002>400`3Qh@0Eh@03_^7Q04cQ0PnGh@:n00<?hN40jn4001kQ00<?hN407N400`3Q

h@06h@@05>400kkQh@1;h@033n7Q09?Q1;h3h@033n7Q0>[Q000Nh@033n7Q01_Q0P09h@030>7Q01GQ

00>nhN40B^400`oQh@2Bh@:n2>400`oQh@3Yh@007^400`oQh@0Kh@030>7Q00SQ00<0hN405N400kkQ

h@18h@8?TN44_P_Q00<?hN40j>4001kQ00<?hN406n4300SQ00<0hN405^400kkQh@15h@8?Xn400`oQ

h@3Wh@007^400`oQh@0Vh@030>7Q01KQ00>nhN40@n423i3Q0khCh@033n7Q0>KQ000Nh@033n7Q02KQ

00<0hN405^400kkQh@12h@033n7Q08gQ0khGh@033n7Q0>GQ000Nh@033n7Q02KQ00<0hN405^400kkQ

h@11h@033n7Q08cQ0[hKh@033n7Q0>CQ000Oh@033n7Q02GQ00<0hN405^400kkQh@0oh@8?S>43_QkQ

00<?hN40hn4001oQ00<?hN409N400`3Qh@0Fh@03_^7Q03gQ0Pn;h@>n8^423k;Q00<?hN40;^4001oQ

00<?hN409N400`3Qh@0Fh@03_^7Q03cQ00<?hN40RN42_ROQ00<?hN40Yn483c7Q000Oh@033n7Q02GQ

00<0hN405n400kkQh@0jh@033n7Q08OQ0khZh@033n7Q0:3Q1Plih@007n400`oQh@0Uh@030>7Q01OQ

00>nhN40>>423hSQ0[h^h@8?V>483coQ000Ph@033n7Q02CQ0`0Gh@03_^7Q03KQ0Pn7h@>n<^423hkQ

20m7h@008>400`oQh@0Th@030>7Q01OQ00>nhN40=>423hOQ0[hgh@033n7Q08GQ1Pm?h@008>400`oQ

h@0Th@030>7Q01OQ00>nhN40<n400`oQh@24h@>n>^400`oQh@1lh@P?EN40023Q00<?hN409>400`3Q

h@0Gh@03_^7Q03;Q00<?hN40Pn43_SgQ0Pmeh@L?GN40023Q00<?hN409>400`3Qh@0Hh@03_^7Q02oQ

0Pn3h@>n@^433f[Q20mTh@008N400`oQh@0Sh@030>7Q01SQ00>nhN40;N423h?Q0ki7h@@?G^483fcQ

000Qh@033n7Q02?Q00<0hN406>400kkQh@0/h@033n7Q087Q0[i>h@8?E>483gCQ000Qh@033n7Q02?Q

00<0hN406>400kkQh@0[h@033n7Q083Q0kiAh@@?B>483gcQ000Qh@033n7Q02?Q00<0hN406>400kkQ

h@0Yh@8?PN42_USQ10llh@P?Q>4002;Q00<?hN408^400`3Qh@0Hh@03_^7Q02OQ0Pn0h@>nG^463bcQ

2Pn<h@008^400`oQh@0Rh@030>7Q01SQ00>nhN409^400`oQh@1nh@:nIn4<3`gQ4`nFh@008^400`oQ

h@0Rh@030>7Q01SQ00>nhN409N400`oQh@1mh@>nM>4=3jWQ000Sh@033n7Q027Q0`0Hh@03_^7Q02?Q

0Pmnh@:non4^h@008n400`oQh@0Qh@030>7Q01SQ00>nhN408^400`oQh@1lh@:non4`h@008n400`oQ

h@0Qh@030>7Q01WQ00>nhN408>400`oQh@1kh@:non4bh@009>400`oQh@0Ph@030>7Q01WQ00>nhN40

7^423gcQ0[kohCCQ000Th@033n7Q023Q00<0hN406N400kkQh@0Lh@8?Nn43__oQ=^4002CQ00<?hN40

8>400`3Qh@0Ih@03_^7Q01_Q00<?hN40NN43__oQ>>4002GQ00<?hN407n400`3Qh@0Ih@03_^7Q01[Q

00<?hN40N>42__oQ>n4002GQ00<?hN407n400`3Qh@0Jh@03_^7Q01OQ0Pmjh@:non4lh@009N400`oQ

h@0Oh@030>7Q01[Q00>nhN405N423gWQ0kkohCkQ000Vh@033n7Q01kQ00<0hN406^400kkQh@0Dh@03

3n7Q07SQ00>nhN40on4oh@009^400`oQh@0Nh@030>7Q01[Q00>nhN404n400`oQh@1fh@>non52h@00

9^400`oQh@0Nh@030>7Q01_Q00>nhN403n433gSQ00>nhN40on53h@009n400`oQh@0Mh@<06n400kkQ

h@0=h@8?NN42__oQA^4002OQ00<?hN407N400`3Qh@0Kh@03_^7Q00cQ00<?hN40Mn42__oQB>4002SQ

00<?hN407>400`3Qh@0Kh@03_^7Q00_Q00<?hN40M^42__oQB^4002SQ00<?hN407>400`3Qh@0Lh@03

_^7Q00SQ0Pmgh@:non5<h@00:N400`oQh@0Kh@030>7Q01cQ00>nhN401^423gOQ0[kohDkQ000Yh@03

3n7Q01_Q00<0hN407>400kkQh@05h@033n7Q07GQ0[kohE3Q000Zh@033n7Q01[Q00<0hN407>400kkQ

h@04h@033n7Q07GQ00>nhN40on5@h@00:^400`oQh@0Jh@030>7Q01cQ00>nhN400^423gKQ0[kohE?Q

000[h@033n7Q01WQ00<0hN407>400kkQh@023gKQ0[kohEGQ000[h@033n7Q01WQ00<0hN407>400kkQ

3`1fh@>non5Fh@00;>400`oQh@0Hh@030>7Q01gQ00>nhN40Ln42__oQFN4002gQ00<?hN405n400`3Q

h@0Kh@8?00>nhN40L^400kkQh@3ohEWQ000]h@033n7Q01OQ0`0Ih@8?0^400kkQh@1`h@:non5Lh@00

;^400`oQh@0Fh@030>7Q01OQ0Pl5h@03_^7Q06gQ0[kohEkQ000_h@033n7Q01GQ00<0hN405N423`OQ

00>nhN40K>42__oQGn40033Q00<?hN405>400`3Qh@0Dh@033n7Q00OQ00>nhN40J^42__oQHN40037Q

00<?hN404n400`3Qh@0Ch@033n7Q00WQ00>nhN40In42__oQHn4003;Q00<?hN404^400`3Qh@0Ah@8?

3>400kkQh@1Vh@:non5Th@00<n400`oQh@0Ah@030>7Q00oQ0Pl>h@03_^7Q06CQ0[kohFKQ000dh@03

3n7Q013Q00<0hN403N423a7Q00>nhN40H^400kkQh@3ohFKQ000eh@8?4>400`3Qh@09h@@?4n400kkQ

h@1Ph@:non5Yh@00=n423`kQ00<0hN401n423aOQ00>nhN40G^42__oQJn4003KQ0`033`03h@3Q00SQ

00<0hN401N423aWQ00>nhN40GN42__oQK>4003SQ00@0hN7Q0Pl00`3Qh@06h@030>4?00D?6n400kkQ

h@1Kh@:non5^h@00>>401P3QhN40h@/?0P0Ph@03_^7Q05SQ0[kohG3Q000hh@070>7Qh@3Q0008h@03

0>7Q027Q00>nhN40En42__oQLN4003SQ00L0hN7Q0>4000SQ00<0hN408^400kkQh@1Dh@:non5ch@00

=n4200CQ00<0hN401n400`3Qh@0Rh@03_^7Q05?Q00>nhN40on5ch@00An400`3Qh@0Sh@03_^7Q053Q

0[kohGKQ0017h@030>7Q02?Q00>nhN40C^42__oQN>4004OQ00<0hN409>400kkQh@1=h@03_^7Q0?oQ

Mn4004OQ00<0hN409>400kkQh@1;h@:non5jh@00An400`3Qh@0Uh@03_^7Q04SQ0[kohGcQ0017h@03

0>7Q02GQ00>nhN40An400kkQh@3ohGcQ0017h@030>7Q02GQ00>nhN40AN42__oQOn4004OQ00<0hN40

9N400kkQh@13h@:non61h@00An4302KQ00>nhN40@N42__oQP^4004OQ00<0hN409n400kkQh@0oh@03

_^7Q0?oQP^4004OQ00<0hN409n400kkQh@0mh@:non65h@00An400`3Qh@0Xh@03_^7Q03_Q00>nhN40

on65h@00An400`3Qh@0Yh@03_^7Q03SQ0[kohHSQ0017h@030>7Q02WQ00>nhN40=^42__oQR^4004OQ

00<0hN40:N400kkQh@0eh@:non6;h@00An400`3Qh@0Zh@03_^7Q03;Q0[kohHgQ0017h@030>7Q02_Q

00>nhN40<>400kkQh@3ohHgQ0017h@030>7Q02cQ00>nhN40;N42__oQT>4004OQ00<0hN40;N400kkQ

h@0Zh@:non6Bh@00An400`3Qh@0^h@03_^7Q02SQ00>nhN40on6Bh@00An4302kQ00>nhN409^42__oQ

UN4004OQ00<0hN40;n42_RCQ0[kohIOQ0017h@030>7Q037Q00>nhN407n42__oQVN4004OQ00<0hN40

<^400kkQh@0Lh@:non6Kh@00An400`3Qh@0ch@03_^7Q01WQ0[kohIgQ0017h@030>7Q03CQ0khEh@>n

on6Oh@00An400`3Qh@0fh@:n4N44__oQXN4004OQ00<0hN40>>44_PWQ1;kohJGQ0017h@030>7Q03cQ

2KkohJWQ0017h@030>7Q0?oQk^4004OQ00<0hN40on7^h@00An400`3Qh@3ohNkQ0017h@<0on7^h@00

An400`3Qh@3ohNkQ0017h@030>7Q0?oQk^4004OQ00<0hN40on7^h@00An400`3Qh@3ohNkQ003ohOoQ

>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQon4ih@00

on7ohCWQ003ohOoQ>N400?oQon4ih@00on47h@8000CQ003Q10000n400003h@80on4Ph@00on48h@03

0>4000WQ00<0hN400^400`3Qh@3ohAgQ003oh@SQ0`02h@@00^400`3Qh@02h@030>7Q0?oQ7^400?oQ

2>40103Q0008h@030>7Q00;Q00<0hN40on4Mh@00AN420<3Q00<0hN401n400`3Q0002h@030>400?oQ

7n4004KQ00<0hN40_N4200[Q00<0hN400^400`3Qh@3ohAkQ0014h@<00^400`3Qh@3ohNcQ0013h@08

0>7Q0>40h@3ohNgQ0013h@080>7Q0>40h@3ohNgQ0014h@<000CQ0>40on7]h@00B>400`3Q003ohNgQ

0019h@030>7Q0?oQk>400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQon4ih@00on7ohCWQ0000\

\>"],

  ImageRangeCache->{{{0, 566}, {349.313, 0}} -> {12.251, -13.2736, 0.0245716, 

  0.0828679}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-1.78959 0.138427 0.309017 0.0230521 [

[.14839 .29652 -6 -9 ]

[.14839 .29652 6 0 ]

[.28682 .29652 -6 -9 ]

[.28682 .29652 6 0 ]

[.42525 .29652 -6 -9 ]

[.42525 .29652 6 0 ]

[.56368 .29652 -6 -9 ]

[.56368 .29652 6 0 ]

[.7021 .29652 -6 -9 ]

[.7021 .29652 6 0 ]

[.84053 .29652 -6 -9 ]

[.84053 .29652 6 0 ]

[.97896 .29652 -6 -9 ]

[.97896 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[-0.00253 .0785 -18 -4.5 ]

[-0.00253 .0785 0 4.5 ]

[-0.00253 .19376 -12 -4.5 ]

[-0.00253 .19376 0 4.5 ]

[-0.00253 .42428 -6 -4.5 ]

[-0.00253 .42428 0 4.5 ]

[-0.00253 .53954 -12 -4.5 ]

[-0.00253 .53954 0 4.5 ]

[.00997 .64303 -7 0 ]

[.00997 .64303 7 16 ]

[.5 .63053 -12 0 ]

[.5 .63053 12 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.14839 .30902 m

.14839 .31527 L

s

[(14)] .14839 .29652 0 1 Mshowa

.28682 .30902 m

.28682 .31527 L

s

[(15)] .28682 .29652 0 1 Mshowa

.42525 .30902 m

.42525 .31527 L

s

[(16)] .42525 .29652 0 1 Mshowa

.56368 .30902 m

.56368 .31527 L

s

[(17)] .56368 .29652 0 1 Mshowa

.7021 .30902 m

.7021 .31527 L

s

[(18)] .7021 .29652 0 1 Mshowa

.84053 .30902 m

.84053 .31527 L

s

[(19)] .84053 .29652 0 1 Mshowa

.97896 .30902 m

.97896 .31527 L

s

[(20)] .97896 .29652 0 1 Mshowa

.125 Mabswid

.03765 .30902 m

.03765 .31277 L

s

.06534 .30902 m

.06534 .31277 L

s

.09302 .30902 m

.09302 .31277 L

s

.12071 .30902 m

.12071 .31277 L

s

.17608 .30902 m

.17608 .31277 L

s

.20377 .30902 m

.20377 .31277 L

s

.23145 .30902 m

.23145 .31277 L

s

.25914 .30902 m

.25914 .31277 L

s

.31451 .30902 m

.31451 .31277 L

s

.34219 .30902 m

.34219 .31277 L

s

.36988 .30902 m

.36988 .31277 L

s

.39756 .30902 m

.39756 .31277 L

s

.45293 .30902 m

.45293 .31277 L

s

.48062 .30902 m

.48062 .31277 L

s

.50831 .30902 m

.50831 .31277 L

s

.53599 .30902 m

.53599 .31277 L

s

.59136 .30902 m

.59136 .31277 L

s

.61905 .30902 m

.61905 .31277 L

s

.64673 .30902 m

.64673 .31277 L

s

.67442 .30902 m

.67442 .31277 L

s

.72979 .30902 m

.72979 .31277 L

s

.75748 .30902 m

.75748 .31277 L

s

.78516 .30902 m

.78516 .31277 L

s

.81285 .30902 m

.81285 .31277 L

s

.86822 .30902 m

.86822 .31277 L

s

.8959 .30902 m

.8959 .31277 L

s

.92359 .30902 m

.92359 .31277 L

s

.95127 .30902 m

.95127 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.00997 .0785 m

.01622 .0785 L

s

[(-10)] -0.00253 .0785 1 0 Mshowa

.00997 .19376 m

.01622 .19376 L

s

[(-5)] -0.00253 .19376 1 0 Mshowa

.00997 .42428 m

.01622 .42428 L

s

[(5)] -0.00253 .42428 1 0 Mshowa

.00997 .53954 m

.01622 .53954 L

s

[(10)] -0.00253 .53954 1 0 Mshowa

.125 Mabswid

.00997 .10155 m

.01372 .10155 L

s

.00997 .1246 m

.01372 .1246 L

s

.00997 .14765 m

.01372 .14765 L

s

.00997 .1707 m

.01372 .1707 L

s

.00997 .21681 m

.01372 .21681 L

s

.00997 .23986 m

.01372 .23986 L

s

.00997 .26291 m

.01372 .26291 L

s

.00997 .28596 m

.01372 .28596 L

s

.00997 .33207 m

.01372 .33207 L

s

.00997 .35512 m

.01372 .35512 L

s

.00997 .37817 m

.01372 .37817 L

s

.00997 .40123 m

.01372 .40123 L

s

.00997 .44733 m

.01372 .44733 L

s

.00997 .47038 m

.01372 .47038 L

s

.00997 .49343 m

.01372 .49343 L

s

.00997 .51649 m

.01372 .51649 L

s

.00997 .05544 m

.01372 .05544 L

s

.00997 .03239 m

.01372 .03239 L

s

.00997 .00934 m

.01372 .00934 L

s

.00997 .56259 m

.01372 .56259 L

s

.00997 .58564 m

.01372 .58564 L

s

.00997 .60869 m

.01372 .60869 L

s

.25 Mabswid

.00997 0 m

.00997 .61803 L

s

gsave

.00997 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -73 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(k) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(35) show

83.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

1 0 0 r

.5 Mabswid

.97619 .48931 m

.97342 .48833 L

.97065 .48725 L

.96788 .48609 L

.96512 .48483 L

.96235 .48346 L

.95958 .48197 L

.95681 .48035 L

.95404 .4786 L

.95127 .47669 L

.9485 .47462 L

.94574 .47237 L

.94297 .46993 L

.9402 .46728 L

.93743 .46441 L

.93466 .46131 L

.93189 .45798 L

.92913 .4544 L

.92636 .45058 L

.92359 .44653 L

.92082 .44228 L

.91805 .43784 L

.91528 .43327 L

.91251 .42859 L

.90975 .42386 L

.90698 .41912 L

.90421 .41441 L

.90144 .40976 L

.89867 .40519 L

.8959 .40074 L

.89313 .39641 L

.89037 .3922 L

.8876 .38813 L

.88483 .38419 L

.88206 .38039 L

.87929 .37671 L

.87652 .37315 L

.87375 .36972 L

.87099 .36639 L

.86822 .36317 L

.86545 .36006 L

.86268 .35704 L

.85991 .35411 L

.85714 .35126 L

.85437 .3485 L

.85161 .34581 L

.84884 .3432 L

.84607 .34065 L

.8433 .33817 L

.84053 .33574 L

Mistroke

.83776 .33338 L

.83499 .33107 L

.83223 .32881 L

.82946 .3266 L

.82669 .32444 L

.82392 .32232 L

.82115 .32025 L

.81838 .31821 L

.81561 .31621 L

.81285 .31425 L

.81008 .31232 L

.80731 .31043 L

.80454 .30857 L

.80177 .30673 L

.799 .30493 L

.79623 .30315 L

.79347 .30141 L

.7907 .29968 L

.78793 .29798 L

.78516 .2963 L

.78239 .29465 L

.77962 .29301 L

.77685 .2914 L

.77409 .2898 L

.77132 .28823 L

.76855 .28667 L

.76578 .28513 L

.76301 .2836 L

.76024 .28209 L

.75748 .2806 L

.75471 .27912 L

.75194 .27766 L

.74917 .27621 L

.7464 .27477 L

.74363 .27334 L

.74086 .27193 L

.7381 .27053 L

.73533 .26914 L

.73256 .26776 L

.72979 .26639 L

.72702 .26503 L

.72425 .26368 L

.72148 .26234 L

.71872 .26101 L

.71595 .25968 L

.71318 .25837 L

.71041 .25706 L

.70764 .25576 L

.70487 .25447 L

.7021 .25318 L

Mistroke

.69934 .25191 L

.69657 .25063 L

.6938 .24937 L

.69103 .24811 L

.68826 .24685 L

.68549 .2456 L

.68272 .24436 L

.67996 .24312 L

.67719 .24189 L

.67442 .24066 L

.67165 .23943 L

.66888 .23821 L

.66611 .237 L

.66334 .23578 L

.66058 .23457 L

.65781 .23337 L

.65504 .23217 L

.65227 .23097 L

.6495 .22977 L

.64673 .22858 L

.64396 .22739 L

.6412 .2262 L

.63843 .22502 L

.63566 .22383 L

.63289 .22265 L

.63012 .22147 L

.62735 .2203 L

.62458 .21912 L

.62182 .21795 L

.61905 .21678 L

.61628 .21561 L

.61351 .21444 L

.61074 .21327 L

.60797 .21211 L

.6052 .21094 L

.60244 .20978 L

.59967 .20861 L

.5969 .20745 L

.59413 .20629 L

.59136 .20513 L

.58859 .20397 L

.58583 .20281 L

.58306 .20165 L

.58029 .20049 L

.57752 .19933 L

.57475 .19818 L

.57198 .19702 L

.56921 .19586 L

.56645 .1947 L

.56368 .19355 L

Mistroke

.56091 .19239 L

.55814 .19123 L

.55537 .19007 L

.5526 .18892 L

.54983 .18776 L

.54707 .1866 L

.5443 .18544 L

.54153 .18429 L

.53876 .18313 L

.53599 .18197 L

.53322 .18081 L

.53045 .17965 L

.52769 .17849 L

.52492 .17733 L

.52215 .17617 L

.51938 .17501 L

.51661 .17385 L

.51384 .17269 L

.51107 .17153 L

.50831 .17037 L

.50554 .16921 L

.50277 .16805 L

.5 .16689 L

.49723 .16573 L

.49446 .16457 L

.49169 .16341 L

.48893 .16225 L

.48616 .16109 L

.48339 .15992 L

.48062 .15876 L

.47785 .1576 L

.47508 .15644 L

.47231 .15528 L

.46955 .15413 L

.46678 .15297 L

.46401 .15181 L

.46124 .15065 L

.45847 .14949 L

.4557 .14834 L

.45293 .14718 L

.45017 .14603 L

.4474 .14488 L

.44463 .14373 L

.44186 .14258 L

.43909 .14143 L

.43632 .14028 L

.43355 .13914 L

.43079 .13799 L

.42802 .13685 L

.42525 .13571 L

Mistroke

.42248 .13457 L

.41971 .13344 L

.41694 .13231 L

.41417 .13118 L

.41141 .13005 L

.40864 .12892 L

.40587 .1278 L

.4031 .12668 L

.40033 .12557 L

.39756 .12446 L

.3948 .12335 L

.39203 .12224 L

.38926 .12114 L

.38649 .12005 L

.38372 .11896 L

.38095 .11787 L

.37818 .11678 L

.37542 .11571 L

.37265 .11463 L

.36988 .11356 L

.36711 .1125 L

.36434 .11144 L

.36157 .11039 L

.3588 .10935 L

.35604 .10831 L

.35327 .10727 L

.3505 .10624 L

.34773 .10522 L

.34496 .10421 L

.34219 .1032 L

.33942 .10221 L

.33666 .10121 L

.33389 .10023 L

.33112 .09925 L

.32835 .09829 L

.32558 .09733 L

.32281 .09638 L

.32004 .09544 L

.31728 .09451 L

.31451 .09358 L

.31174 .09267 L

.30897 .09177 L

.3062 .09088 L

.30343 .08999 L

.30066 .08912 L

.2979 .08826 L

.29513 .08742 L

.29236 .08658 L

.28959 .08576 L

.28682 .08494 L

Mistroke

.28405 .08415 L

.28128 .08336 L

.27852 .08259 L

.27575 .08183 L

.27298 .08109 L

.27021 .08036 L

.26744 .07965 L

.26467 .07895 L

.2619 .07827 L

.25914 .0776 L

.25637 .07695 L

.2536 .07632 L

.25083 .0757 L

.24806 .07511 L

.24529 .07453 L

.24252 .07398 L

.23976 .07344 L

.23699 .07292 L

.23422 .07243 L

.23145 .07195 L

.22868 .0715 L

.22591 .07107 L

.22315 .07066 L

.22038 .07028 L

.21761 .06993 L

.21484 .0696 L

.21207 .06929 L

.2093 .06902 L

.20653 .06877 L

.20377 .06855 L

.201 .06836 L

.19823 .0682 L

.19546 .06808 L

.19269 .06798 L

.18992 .06792 L

.18715 .0679 L

.18439 .06791 L

.18162 .06796 L

.17885 .06805 L

.17608 .06817 L

.17331 .06834 L

.17054 .06855 L

.16777 .0688 L

.16501 .0691 L

.16224 .06945 L

.15947 .06984 L

.1567 .07028 L

.15393 .07078 L

.15116 .07133 L

.14839 .07193 L

Mistroke

.14563 .0726 L

.14286 .07332 L

.14009 .0741 L

.13732 .07495 L

.13455 .07587 L

.13178 .07685 L

.12901 .07791 L

.12625 .07904 L

.12348 .08025 L

.12071 .08155 L

.11794 .08292 L

.11517 .08439 L

.1124 .08595 L

.10963 .0876 L

.10687 .08936 L

.1041 .09122 L

.10133 .0932 L

.09856 .09529 L

.09579 .0975 L

.09302 .09985 L

.09025 .10233 L

.08749 .10495 L

.08472 .10773 L

.08195 .11067 L

.07918 .11378 L

.07641 .11708 L

.07364 .12058 L

.07087 .12429 L

.06811 .12822 L

.06534 .13241 L

.06257 .13686 L

.0598 .14161 L

.05703 .14668 L

.05426 .15212 L

.0515 .15796 L

.04873 .16425 L

.04596 .17108 L

.04319 .17852 L

.04042 .18669 L

.03765 .19576 L

.03488 .20597 L

.03212 .21772 L

.02935 .2317 L

.02658 .24948 L

.02381 .30902 L

Mfstroke

.97619 .12872 m

.97342 .12971 L

.97065 .13078 L

.96788 .13194 L

.96512 .13321 L

.96235 .13458 L

.95958 .13607 L

.95681 .13768 L

.95404 .13944 L

.95127 .14134 L

.9485 .14342 L

.94574 .14567 L

.94297 .14811 L

.9402 .15076 L

.93743 .15362 L

.93466 .15672 L

.93189 .16006 L

.92913 .16364 L

.92636 .16746 L

.92359 .1715 L

.92082 .17576 L

.91805 .18019 L

.91528 .18477 L

.91251 .18944 L

.90975 .19417 L

.90698 .19892 L

.90421 .20363 L

.90144 .20828 L

.89867 .21284 L

.8959 .21729 L

.89313 .22163 L

.89037 .22583 L

.8876 .2299 L

.88483 .23384 L

.88206 .23765 L

.87929 .24133 L

.87652 .24488 L

.87375 .24832 L

.87099 .25164 L

.86822 .25486 L

.86545 .25798 L

.86268 .261 L

.85991 .26393 L

.85714 .26677 L

.85437 .26954 L

.85161 .27222 L

.84884 .27484 L

.84607 .27739 L

.8433 .27987 L

.84053 .28229 L

Mistroke

.83776 .28465 L

.83499 .28696 L

.83223 .28922 L

.82946 .29143 L

.82669 .29359 L

.82392 .29571 L

.82115 .29779 L

.81838 .29982 L

.81561 .30182 L

.81285 .30378 L

.81008 .30571 L

.80731 .3076 L

.80454 .30947 L

.80177 .3113 L

.799 .3131 L

.79623 .31488 L

.79347 .31663 L

.7907 .31835 L

.78793 .32005 L

.78516 .32173 L

.78239 .32339 L

.77962 .32502 L

.77685 .32664 L

.77409 .32823 L

.77132 .32981 L

.76855 .33137 L

.76578 .33291 L

.76301 .33443 L

.76024 .33594 L

.75748 .33743 L

.75471 .33891 L

.75194 .34038 L

.74917 .34183 L

.7464 .34326 L

.74363 .34469 L

.74086 .3461 L

.7381 .3475 L

.73533 .3489 L

.73256 .35028 L

.72979 .35164 L

.72702 .353 L

.72425 .35435 L

.72148 .35569 L

.71872 .35703 L

.71595 .35835 L

.71318 .35967 L

.71041 .36097 L

.70764 .36227 L

.70487 .36356 L

.7021 .36485 L

Mistroke

.69934 .36613 L

.69657 .3674 L

.6938 .36867 L

.69103 .36993 L

.68826 .37118 L

.68549 .37243 L

.68272 .37367 L

.67996 .37491 L

.67719 .37615 L

.67442 .37738 L

.67165 .3786 L

.66888 .37982 L

.66611 .38104 L

.66334 .38225 L

.66058 .38346 L

.65781 .38467 L

.65504 .38587 L

.65227 .38707 L

.6495 .38826 L

.64673 .38946 L

.64396 .39065 L

.6412 .39183 L

.63843 .39302 L

.63566 .3942 L

.63289 .39538 L

.63012 .39656 L

.62735 .39774 L

.62458 .39891 L

.62182 .40009 L

.61905 .40126 L

.61628 .40243 L

.61351 .4036 L

.61074 .40476 L

.60797 .40593 L

.6052 .40709 L

.60244 .40826 L

.59967 .40942 L

.5969 .41058 L

.59413 .41174 L

.59136 .4129 L

.58859 .41406 L

.58583 .41522 L

.58306 .41638 L

.58029 .41754 L

.57752 .4187 L

.57475 .41986 L

.57198 .42102 L

.56921 .42217 L

.56645 .42333 L

.56368 .42449 L

Mistroke

.56091 .42564 L

.55814 .4268 L

.55537 .42796 L

.5526 .42912 L

.54983 .43027 L

.54707 .43143 L

.5443 .43259 L

.54153 .43375 L

.53876 .43491 L

.53599 .43606 L

.53322 .43722 L

.53045 .43838 L

.52769 .43954 L

.52492 .4407 L

.52215 .44186 L

.51938 .44302 L

.51661 .44418 L

.51384 .44534 L

.51107 .4465 L

.50831 .44766 L

.50554 .44882 L

.50277 .44998 L

.5 .45114 L

.49723 .4523 L

.49446 .45347 L

.49169 .45463 L

.48893 .45579 L

.48616 .45695 L

.48339 .45811 L

.48062 .45927 L

.47785 .46043 L

.47508 .46159 L

.47231 .46275 L

.46955 .46391 L

.46678 .46507 L

.46401 .46623 L

.46124 .46738 L

.45847 .46854 L

.4557 .46969 L

.45293 .47085 L

.45017 .472 L

.4474 .47316 L

.44463 .47431 L

.44186 .47546 L

.43909 .47661 L

.43632 .47775 L

.43355 .4789 L

.43079 .48004 L

.42802 .48118 L

.42525 .48232 L

Mistroke

.42248 .48346 L

.41971 .48459 L

.41694 .48573 L

.41417 .48686 L

.41141 .48799 L

.40864 .48911 L

.40587 .49023 L

.4031 .49135 L

.40033 .49246 L

.39756 .49358 L

.3948 .49469 L

.39203 .49579 L

.38926 .49689 L

.38649 .49799 L

.38372 .49908 L

.38095 .50017 L

.37818 .50125 L

.37542 .50233 L

.37265 .5034 L

.36988 .50447 L

.36711 .50553 L

.36434 .50659 L

.36157 .50764 L

.3588 .50869 L

.35604 .50973 L

.35327 .51076 L

.3505 .51179 L

.34773 .51281 L

.34496 .51382 L

.34219 .51483 L

.33942 .51583 L

.33666 .51682 L

.33389 .5178 L

.33112 .51878 L

.32835 .51975 L

.32558 .52071 L

.32281 .52166 L

.32004 .5226 L

.31728 .52353 L

.31451 .52445 L

.31174 .52536 L

.30897 .52627 L

.3062 .52716 L

.30343 .52804 L

.30066 .52891 L

.2979 .52977 L

.29513 .53062 L

.29236 .53145 L

.28959 .53228 L

.28682 .53309 L

Mistroke

.28405 .53389 L

.28128 .53467 L

.27852 .53545 L

.27575 .5362 L

.27298 .53695 L

.27021 .53768 L

.26744 .53839 L

.26467 .53909 L

.2619 .53977 L

.25914 .54043 L

.25637 .54109 L

.2536 .54172 L

.25083 .54233 L

.24806 .54292 L

.24529 .5435 L

.24252 .54406 L

.23976 .5446 L

.23699 .54511 L

.23422 .54561 L

.23145 .54608 L

.22868 .54653 L

.22591 .54696 L

.22315 .54737 L

.22038 .54775 L

.21761 .54811 L

.21484 .54844 L

.21207 .54874 L

.2093 .54902 L

.20653 .54926 L

.20377 .54948 L

.201 .54967 L

.19823 .54983 L

.19546 .54996 L

.19269 .55005 L

.18992 .55011 L

.18715 .55014 L

.18439 .55012 L

.18162 .55008 L

.17885 .54999 L

.17608 .54986 L

.17331 .5497 L

.17054 .54949 L

.16777 .54923 L

.16501 .54893 L

.16224 .54859 L

.15947 .54819 L

.1567 .54775 L

.15393 .54725 L

.15116 .54671 L

.14839 .5461 L

Mistroke

.14563 .54544 L

.14286 .54472 L

.14009 .54393 L

.13732 .54308 L

.13455 .54217 L

.13178 .54118 L

.12901 .54012 L

.12625 .53899 L

.12348 .53778 L

.12071 .53649 L

.11794 .53511 L

.11517 .53364 L

.1124 .53209 L

.10963 .53043 L

.10687 .52867 L

.1041 .52681 L

.10133 .52484 L

.09856 .52274 L

.09579 .52053 L

.09302 .51819 L

.09025 .51571 L

.08749 .51308 L

.08472 .5103 L

.08195 .50736 L

.07918 .50425 L

.07641 .50095 L

.07364 .49746 L

.07087 .49375 L

.06811 .48981 L

.06534 .48563 L

.06257 .48117 L

.0598 .47643 L

.05703 .47135 L

.05426 .46592 L

.0515 .46008 L

.04873 .45378 L

.04596 .44695 L

.04319 .43951 L

.04042 .43134 L

.03765 .42227 L

.03488 .41206 L

.03212 .40032 L

.02935 .38634 L

.02658 .36855 L

.02381 .30902 L

Mfstroke

0 .4 1 r

.97204 .42897 m

.96512 .43047 L

.95819 .43199 L

.95127 .43353 L

.94435 .43507 L

.93743 .43664 L

.93051 .43821 L

.92359 .4398 L

.91667 .44141 L

.90975 .44303 L

.90282 .44467 L

.8959 .44633 L

.88898 .44801 L

.88206 .4497 L

.87514 .45141 L

.86822 .45313 L

.8613 .45488 L

.85437 .45665 L

.84745 .45844 L

.84053 .46024 L

.83361 .46207 L

.82669 .46392 L

.81977 .4658 L

.81285 .46769 L

.80592 .46962 L

.799 .47156 L

.79208 .47353 L

.78516 .47553 L

.77824 .47755 L

.77132 .47961 L

.7644 .48169 L

.75748 .4838 L

.75055 .48595 L

.74363 .48812 L

.73671 .49033 L

.72979 .49258 L

.72287 .49486 L

.71595 .49718 L

.70903 .49954 L

.7021 .50193 L

.69518 .50437 L

.68826 .50686 L

.68134 .50939 L

.67442 .51197 L

.6675 .5146 L

.66058 .51728 L

.65365 .52001 L

.64673 .5228 L

.63981 .52565 L

.63289 .52856 L

Mistroke

.62597 .53152 L

.61905 .53456 L

.61213 .53765 L

.6052 .54081 L

.59828 .54404 L

.59136 .54732 L

.58444 .55067 L

.57752 .55407 L

.5706 .55753 L

.56368 .56102 L

.55676 .56454 L

.54983 .56807 L

.54291 .57159 L

.53599 .57508 L

.52907 .57849 L

.52215 .58181 L

.51523 .58499 L

.50831 .588 L

.50138 .5908 L

.49446 .59337 L

.48754 .59567 L

.48062 .5977 L

.4737 .59943 L

.46678 .60086 L

.45986 .60196 L

.45293 .60275 L

.44601 .6032 L

.43909 .60332 L

.43217 .60309 L

.42525 .6025 L

.41833 .60154 L

.41141 .60019 L

.40449 .59843 L

.39756 .59623 L

.39064 .59355 L

.38372 .59036 L

.3768 .58662 L

.36988 .58226 L

.36296 .57722 L

.35604 .57142 L

.34911 .56475 L

.34219 .5571 L

.33527 .54832 L

.32835 .5382 L

.32143 .52649 L

.31451 .51282 L

.30759 .49666 L

.30066 .47717 L

.29374 .45286 L

.28682 .42041 L

Mistroke

.2799 .36895 L

.27741 .30902 L

Mfstroke

.97204 .18907 m

.96512 .18756 L

.95819 .18604 L

.95127 .18451 L

.94435 .18296 L

.93743 .1814 L

.93051 .17982 L

.92359 .17823 L

.91667 .17662 L

.90975 .175 L

.90282 .17336 L

.8959 .1717 L

.88898 .17003 L

.88206 .16834 L

.87514 .16663 L

.86822 .1649 L

.8613 .16315 L

.85437 .16139 L

.84745 .1596 L

.84053 .15779 L

.83361 .15596 L

.82669 .15411 L

.81977 .15224 L

.81285 .15034 L

.80592 .14842 L

.799 .14647 L

.79208 .1445 L

.78516 .1425 L

.77824 .14048 L

.77132 .13843 L

.7644 .13634 L

.75748 .13423 L

.75055 .13209 L

.74363 .12991 L

.73671 .1277 L

.72979 .12546 L

.72287 .12318 L

.71595 .12086 L

.70903 .1185 L

.7021 .1161 L

.69518 .11366 L

.68826 .11117 L

.68134 .10864 L

.67442 .10606 L

.6675 .10344 L

.66058 .10076 L

.65365 .09802 L

.64673 .09523 L

.63981 .09239 L

.63289 .08948 L

Mistroke

.62597 .08651 L

.61905 .08348 L

.61213 .08038 L

.6052 .07722 L

.59828 .074 L

.59136 .07071 L

.58444 .06736 L

.57752 .06396 L

.5706 .06051 L

.56368 .05701 L

.55676 .05349 L

.54983 .04996 L

.54291 .04644 L

.53599 .04296 L

.52907 .03954 L

.52215 .03623 L

.51523 .03305 L

.50831 .03004 L

.50138 .02723 L

.49446 .02467 L

.48754 .02236 L

.48062 .02033 L

.4737 .0186 L

.46678 .01718 L

.45986 .01607 L

.45293 .01529 L

.44601 .01483 L

.43909 .01472 L

.43217 .01495 L

.42525 .01553 L

.41833 .01649 L

.41141 .01784 L

.40449 .0196 L

.39756 .02181 L

.39064 .02448 L

.38372 .02767 L

.3768 .03141 L

.36988 .03577 L

.36296 .04081 L

.35604 .04662 L

.34911 .05328 L

.34219 .06093 L

.33527 .06971 L

.32835 .07983 L

.32143 .09154 L

.31451 .10522 L

.30759 .12138 L

.30066 .14087 L

.29374 .16517 L

.28682 .19762 L

Mistroke

.2799 .24908 L

.27741 .30902 L

Mfstroke

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{567, 350.313},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.776525,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008g0001GPP10`40000100000800002008200000

P800P020P<30`<3L`:K:l00003<006H009T00<`00?l0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV

09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<003o03?o06Ko09Wo0<co

0?oo0000<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I

<c>I<fJI<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0

IYT0I/`0I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bI

I_nIIP3<IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0c

VC<cVFHcVITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<

VIW<VLc<VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`c

c?lcc01Vc3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03o

c3?oc6Koc9Woc<coc?ooc000oc<0ofH0oiT0ol`0ool0o`0coc<cofHcoiTcol`coolco`1Voc=VofIV

oiUVolaVoomVo`2Ioc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<o`3ooc?oofKooiWoolco

ooooo`0000410@820P<30`@410D51@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C

4a@D5?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooa_Q00<0hN40on7ohA_Q000Kh@030>7Q0?oQ

on4Kh@006n400`3Qh@3ohOoQ6n4001_Q00<0hN40on7ohA_Q000Kh@030>7Q0?oQon4Kh@006n430?oQ

on4Kh@006n400`3Qh@3ohOoQ6n4001_Q00<0hN40on7ohA_Q000Kh@030>7Q0=?Q4[kohCGQ000Kh@03

0>7Q0<cQ1khBh@Nnon4^h@006n400`3Qh@39h@>n8>44__oQ:^4001_Q00<0hN40a^43_ROQ0kkohBOQ

000Kh@030>7Q0<CQ0[h]h@Bnon4Sh@006n400`3Qh@32h@:n<n43__oQ8>4001_Q00<0hN40`>42_SSQ

0kkohAgQ000Kh@030>7Q0;kQ0[hmh@:non4Kh@006n400`3Qh@2kh@>n@N42__oQ6N4001_Q0`2jh@03

_^7Q04CQ0kkohAKQ000Kh@030>7Q0;WQ00>nhN40B>42__oQ5>4001_Q00<0hN40^>400kkQh@1;h@:n

on4Bh@006n400`3Qh@2fh@:nD>42__oQ4>4001_Q00<0hN40]>42_UCQ0[koh@kQ000Kh@030>7Q0;?Q

00>nhN40E^43__oQ2n4001_Q00<0hN40/^400kkQh@1Jh@:non49h@006n400`3Qh@2ah@03_^7Q05gQ

00>nhN40on46h@006n400`3Qh@2`h@03_^7Q05oQ0[koh@KQ000Kh@030>7Q0:oQ00>nhN40H^42__oQ

1>4001_Q00<0hN40[^400kkQh@1Uh@:non42h@006n400`3Qh@2]h@03_^7Q06SQ0[koh@006n430:cQ

00>nhN40Jn42__gQ000Kh@030>7Q0:_Q00>nhN40K^400kkQh@3jh@006n400`3Qh@2Zh@03_^7Q073Q

0[kjh@006n400`3Qh@2Yh@03_^7Q07?Q0kkgh@006n400`3Qh@2Xh@03_^7Q07OQ0[keh@006n400`3Q

h@2Wh@03_^7Q07[Q0[kch@006n400`3Qh@1Eh@T?BN400kkQh@1lh@:nlN4001_Q00<0hN40Bn4:3`WQ

30llh@03_^7Q07oQ0[k_h@006n400`3Qh@15h@H?7n473cCQ00>nhN40P^42_^gQ000Kh@030>7Q04;Q

0`l/h@@?<>400kkQh@24h@:njn4000_Q1@02h@030>7Q00KQ00<0hN40?n433c?Q1PlYh@03_^7Q08OQ

0[kYh@003N401`3QhN40h@001n400`3Qh@0lh@<??>443bCQ00>nhN40R^43_^KQ0007h@<00n401`3Q

hN40h@001n4403SQ0`m3h@D?7n400kkQh@2=h@:ni>4000gQ00L0hN7Q0>4000OQ00<0hN40=n423d_Q

0`lKh@03_^7Q093Q0[kRh@003N401`3QhN40h@001n400`3Qh@0eh@8?D>443aKQ00>nhN40Tn43_]oQ

000<h@801>400`3Qh@06h@030>7Q03CQ00<?hN40E>433a?Q00>nhN40U^42_]gQ000Kh@030>7Q03;Q

0PmJh@<?3n400kkQh@2Ih@03_^7Q0=[Q000Kh@030>7Q037Q00<?hN40GN443`_Q00>nhN40V^42_][Q

000Kh@030>7Q02kQ0`mTh@<?1n400kkQh@2Mh@>nen4001_Q00<0hN40;N400`oQh@1Xh@<?1>400kkQ

h@2Ph@>ne>4001_Q00<0hN40;>400`oQh@1/h@8?00?Q_^40YN42_];Q000Kh@030>7Q02_Q00<?hN40

Kn400`nn3`2Wh@:nd>4001_Q00<0hN40:^400`oQh@1`h@03_^7Q00<?Y^44_/cQ000Kh@030>7Q02SQ

0Pmch@03_^7Q00?Q0`nWh@:nb^4001_Q0`0Wh@033n7Q07;Q00>nhN401n433jKQ0[k8h@006n400`3Q

h@0Vh@033n7Q07?Q00>nhN402^433jGQ0kk5h@006n400`3Qh@0Uh@033n7Q07?Q00>nhN403^433jGQ

1;k1h@006n400`3Qh@0Th@033n7Q07?Q00>nhN404^433jKQ0[joh@006n400`3Qh@0Sh@033n7Q07CQ

00>nhN405N423jKQ0[jmh@006n400`3Qh@0Rh@033n7Q07CQ00>nhN406>423jKQ0kjjh@006n400`3Q

h@0Qh@033n7Q07GQ00>nhN406^433jKQ0kjgh@006n400`3Qh@0Ph@033n7Q07GQ00>nhN407^433jKQ

0kjdh@006n400`3Qh@0Ph@033n7Q07GQ00>nhN408N423jOQ0[jbh@006n400`3Qh@0Oh@033n7Q07GQ

00>nhN409>433jKQ0kj_h@006n400`3Qh@0Nh@033n7Q07KQ00>nhN409n423jOQ0kj/h@006n400`3Q

h@0Mh@033n7Q07OQ00>nhN40:N433jOQ1;jXh@006n4301gQ00<?hN40M^400kkQh@0]h@<?Z>43_ZGQ

000Kh@030>7Q01cQ00<?hN40Mn400kkQh@0`h@8?ZN43_Z;Q000Kh@030>7Q01_Q00<?hN40N>400kkQ

h@0bh@8?Z^42_WSQ0PlVh@006n400`3Qh@0Jh@033n7Q07SQ00>nhN40=N433jWQ0[idh@8?:>4001_Q

00<0hN406^400`oQh@1hh@03_^7Q03SQ0`nXh@BnKN433b[Q000Kh@030>7Q01WQ00<?hN40NN400kkQ

h@0kh@033n7Q0:WQ1;iXh@033n7Q02_Q000Kh@030>7Q01SQ00<?hN40N^400kkQh@0lh@<?[>43_V?Q

0Pl^h@006n400`3Qh@0Hh@033n7Q07WQ00>nhN40@>433jcQ1;iMh@8?<>4001_Q00<0hN405n400`oQ

h@1jh@03_^7Q04?Q0`n]h@>nF>423c;Q000Kh@030>7Q01OQ00<?hN40N^400kkQh@16h@033n7Q0:gQ

1;iCh@033n7Q03;Q000Kh@030>7Q01KQ00<?hN40N^400kkQh@18h@<?/>44_ToQ00<?hN40<^4001_Q

00<0hN405^400`oQh@1jh@03_^7Q04_Q0`nah@>nB^423cGQ000Kh@<05N400`oQh@1kh@03_^7Q04kQ

00<?hN40/N44_TGQ00<?hN40=N4001_Q00<0hN405N400`oQh@1jh@03_^7Q053Q0`ndh@>n@>423cSQ

000Kh@030>7Q01CQ00<?hN40Nn400kkQh@1Ch@<?]>44_S_Q00<?hN40>>4001_Q00<0hN405>400`oQ

h@1kh@03_^7Q05KQ00<?hN40]N44_SOQ00<?hN40>>4001_Q00<0hN404n400`oQh@1lh@03_^7Q05OQ

0`nhh@>n<^423c_Q000Kh@030>7Q01?Q00<?hN40Nn400kkQh@1Kh@<?^>44_RgQ00<?hN40>n4001_Q

00<0hN404^400`oQh@1lh@03_^7Q05kQ0Pnjh@>n:^400`oQh@0kh@006n400`3Qh@0Bh@033n7Q07cQ

00>nhN40H>423k_Q1;hUh@033n7Q03cQ000Kh@030>7Q017Q00<?hN40O>400kkQh@1Sh@<?_>43_R;Q

00<?hN40?>4001_Q00<0hN404N400`oQh@1lh@03_^7Q06KQ0Pnmh@Bn7N400`oQh@0mh@006n400`3Q

h@0@h@033n7Q07gQ00>nhN40J>433kkQ1khEh@033n7Q03kQ000Kh@030>7Q013Q00<?hN40ON400kkQ

h@1[h@8?`n44_Q3Q00<?hN40?n4001_Q0`0@h@033n7Q07cQ00>nhN40K^423lGQ0kh=h@033n7Q03oQ

000Kh@030>7Q00oQ00<?hN40ON400kkQh@1`h@<?aN44_PSQ00<?hN40@>4001_Q00<0hN403n400`oQ

h@1mh@03_^7Q07?Q00<?hN40a^44_P?Q00<?hN40@N4001_Q00<0hN403^400`oQh@1nh@03_^7Q07CQ

0`o9h@>n00<?hN40@N4001_Q00<0hN403^400`oQh@1nh@03_^7Q07OQ0`o8h@033kjn00Fn?N4001_Q

00<0hN403^400`oQh@1nh@03_^7Q07[Q00<?hN40aN400`oQh@05h@Bn>N4001_Q00<0hN403N400`oQ

h@1nh@03_^7Q07cQ0`o3h@033n7Q00[Q1;heh@006n400`3Qh@0=h@033n7Q07kQ00>nhN40On433koQ

00<?hN403n43_S;Q000Kh@030>7Q00gQ00<?hN40O^400kkQh@22h@8?_>400`oQh@0Ch@Nn:n4001_Q

00<0hN403N400`oQh@1nh@03_^7Q08CQ0Pnjh@033n7Q01[Q0khXh@004^400`3Qh@06h@030>7Q00gQ

00<?hN40O^400kkQh@26h@<?]n400`oQh@15h@004N400`3Q0007h@030>7Q00cQ00<?hN40On400kkQ

h@29h@8?]>400`oQh@16h@003>4300CQ00<0hN401N4400_Q00<?hN40O^400kkQh@2<h@<?/N400`oQ

h@16h@004N4200SQ00<0hN403>400`oQh@1nh@03_^7Q08oQ0Pn^h@033n7Q04OQ000Ah@030>7Q00OQ

00<0hN403>400`oQh@1nh@03_^7Q097Q0Pn[h@033n7Q04SQ000Ah@<01n400`3Qh@0;h@033n7Q07oQ

00>nhN40Tn433jSQ00<?hN40B>4001_Q00<0hN402n400`oQh@1oh@03_^7Q09KQ0`nTh@033n7Q04WQ

000Kh@030>7Q00[Q00<?hN40P>400kkQh@2Ih@033n7Q0:7Q00<?hN40BN4001_Q00<0hN402^400`oQ

h@1oh@03_^7Q09_Q0`nOh@033n7Q04[Q000Kh@030>7Q00[Q00<?hN40On400kkQh@2Nh@<?Vn400`oQ

h@1;h@006n400`3Qh@0:h@033n7Q07oQ00>nhN40XN400`oQh@2Hh@033n7Q04_Q000Kh@030>7Q00WQ

00<?hN40P>400kkQh@2Rh@<?U^400`oQh@1<h@006n400`3Qh@09h@033n7Q083Q00>nhN40YN433i?Q

00<?hN40C>4001_Q00<0hN402N400`oQh@20h@03_^7Q0:SQ00<?hN40Sn400`oQh@1=h@006n4300WQ

00<?hN40On400kkQh@2Zh@<?SN400`oQh@1>h@006n400`3Qh@09h@033n7Q07oQ00>nhN40[N433hWQ

00<?hN40Cn4001_Q00<0hN402>400`oQh@20h@03_^7Q0;3Q0Pn7h@033n7Q04oQ000Kh@030>7Q00SQ

00<?hN40P>400kkQh@2bh@8?Q>400`oQh@1@h@006n400`3Qh@08h@033n7Q083Q00>nhN40]>433h7Q

00<?hN40D>4001_Q00<0hN402>400`oQh@20h@03_^7Q0;OQ0Pmnh@033n7Q057Q000Kh@030>7Q00OQ

00<?hN40PN400kkQh@2ih@<?N^400`oQh@1Bh@006n400`3Qh@07h@033n7Q083Q00>nhN40_N400`oQ

h@1fh@033n7Q05?Q000Kh@030>7Q00OQ00<?hN40P>400kkQh@2nh@<?MN400`oQh@1Ch@006n400`3Q

h@07h@033n7Q083Q00>nhN40`N433g7Q00<?hN40E>4001_Q00<0hN401n400`oQh@20h@03_^7Q0<CQ

00<?hN40KN400`oQh@1Eh@006n400`3Qh@07h@033n7Q083Q00>nhN40aN433f_Q00<?hN40E^4001_Q

0`06h@033n7Q087Q00>nhN40b>423fWQ00<?hN40E^4001_Q00<0hN401^400`oQh@20h@03_^7Q0<_Q

0PmVh@033n7Q05OQ000Kh@030>7Q00KQ00<?hN40P>400kkQh@3=h@<?H^400`oQh@1Hh@006n400`3Q

h@06h@033n7Q083Q00>nhN40d>423eoQ00<?hN40FN4001_Q00<0hN401^400`oQh@20h@03_^7Q0=;Q

0`mLh@033n7Q05WQ000Kh@030>7Q00KQ00<?hN40P>400kkQh@3Eh@033n7Q05SQ00<?hN40F^4001_Q

00<0hN401^400`oQh@20h@03_^7Q0=KQ0`mFh@033n7Q05_Q000Kh@030>7Q00KQ00<?hN40P>400kkQ

h@3Ih@033n7Q05;Q00<?hN40G>4001_Q00<0hN401^400`oQh@20h@03_^7Q0=[Q0`m@h@033n7Q05gQ

000Kh@030>7Q00KQ00<?hN40P>400kkQh@3Mh@8?C^400`oQh@1Mh@006n400`3Qh@06h@033n7Q083Q

00>nhN40gn433dWQ0PmPh@006n4300KQ00<?hN40P>400kkQh@3Rh@033n7Q04GQ00<?hN40H>4001_Q

00<0hN401^400`oQh@20h@03_^7Q0>?Q00<?hN40A>400`oQh@1Ph@006n400`3Qh@05h@033n7Q087Q

00>nhN40i>433d7Q0PmSh@006n400`3Qh@05h@033n7Q087Q00>nhN40in423ckQ00<?hN40Hn4001_Q

00<0hN401N400`oQh@21h@03_^7Q0>WQ0`lkh@033n7Q06?Q000Kh@030>7Q00GQ00<?hN40PN400kkQ

h@3/h@033n7Q03KQ0PmVh@006n400`3Qh@05h@033n7Q087Q00>nhN40kN400`oQh@0dh@033n7Q06KQ

000Kh@030>7Q00GQ00<?hN40PN400kkQh@3^h@<?<n400`oQh@1Vh@006n400`3Qh@05h@033n7Q087Q

00>nhN40lN423c3Q00<?hN40In4001_Q00<0hN401N400`oQh@20h@03_^7Q0?CQ00<?hN40:n423f[Q

000Kh@030>7Q00GQ00<?hN40>>4500;Q0`0nh@03_P0000800^400`3Qh@0mh@D000?Q0000@>4500;Q

00<0hN40?^4500;Q00<0hN405n433bCQ1@000`l00010h@<00n400`3Qh@0Qh@006n400`3Qh@05h@03

3n7Q03[Q00<0hN400n400`3Qh@0mh@03_^4000?Q00<0h@00@>401`3QhN40h@00@N400`3Qh@02h@03

0>7Q043Q00L0hN7Q0>4001_Q0PlTh@040>7Q3`;Q00<0hN40?N400`3Qh@02h@030>4002;Q000Kh@<0

1N400`oQh@0jh@040>7Qh@@0?^400kkQ0005h@030>7Q03kQ00L0hN7Q0>40047Q00<0hN400^400`3Q

h@10h@070>7Qh@3Q000Mh@033n7Q027Q00<03`l00^42043Q00L0hN7Q0>4002;Q000Kh@030>7Q00GQ

00<?hN40>^401`3QhN40h@00?n400kkQ0003h@80@N40103QhN4204;Q00<0hN400n400`3Qh@0oh@03

0>7Q00;Q00<0hN407N400`oQh@0Ph@073n7Qh@3Q0010h@070>7Qh@3Q000Rh@006n400`3Qh@05h@03

3n7Q03[Q00<0hN400^4203oQ00>nh@000n400`3Qh@10h@050>7Qh@00@n401`3QhN40h@00@N401`3Q

hN40h@007n433agQ0Pl01`3QhN40h@00?n400`3Q0002h@030>4002;Q000Kh@030>7Q00GQ00<?hN40

>N4200GQ00<0hN40?N400kh00003h@<0?n4200CQ0P10h@800n43043Q0P04h@030>7Q027Q0PlJh@04

3n4000CQ0P10h@030>7Q00;Q00<0hN408N4001_Q00<0hN401N400`oQh@20h@03_^7Q0?oQ0^400`oQ

h@0Fh@033n7Q077Q000Kh@030>7Q00CQ00<?hN40PN400kkQh@3oh@?Q0PlDh@8?M>4001_Q00<0hN40

1>400`oQh@21h@03_^7Q0?oQ1N400`oQh@0@h@033n7Q07CQ000Kh@030>7Q00CQ00<?hN40PN400kkQ

h@3oh@KQ00<?hN403n400`oQh@1dh@006n400`3Qh@04h@033n7Q087Q00>nhN40on47h@<?3>423gOQ

000Kh@030>7Q00CQ00<?hN40PN400kkQh@3oh@[Q0Pl9h@033n7Q07OQ000Kh@030>7Q00CQ00<?hN40

PN400kkQh@3oh@cQ00<?hN401>423foQ1007h@006n400`3Qh@04h@033n7Q087Q00>nhN40on4=h@8?

0n400`oQh@1_h@<02>4001KQ30000`l000210003_P000?l03`033f<04N400`3Qh@06h@006n400`3Q

h@04h@033n7Q00GQ00<0hN402n400`3Qh@0;h@030>7Q00cQ00<0hN402n400`3Qh@0;h@030>7Q00cQ

00<0hN402n400`3Qh@0;h@030>7Q00OQ00>nhN400^400`3Qh@0;h@030>7Q00_Q00<0hN403>400`3Q

h@0;h@030>7Q00_Q00<0hN403>400`3Qh@0;h@030>7Q00_Q00<0hN403>400`3Qh@0;h@030>7Q00cQ

00<0hN402n400`3Qh@0;h@030>7Q00cQ00<0hN402n400`3Qh@0;h@030>7Q00cQ00<0hN402n400`3Q

h@07h@8?0^400`3Qh@0<h@030>7Q00_Q00<0hN402n400`3Qh@0<h@030>7Q00_Q00<0hN402n400`3Q

h@0Ih@802>4001_Q00<0hN401>400`oQh@05h@030>7Q00_Q00<0hN402n400`3Qh@0<h@030>7Q00_Q

00<0hN402n400`3Qh@0<h@030>7Q00_Q00<0hN402n400`3Qh@07h@03_^7Q00;Q00<0hN402n400`3Q

h@0;h@030>7Q00cQ00<0hN402n400`3Qh@0;h@030>7Q00cQ00<0hN402n400`3Qh@0;h@030>7Q00cQ

00<0hN402n400`3Qh@0<h@030>7Q00_Q00<0hN402n400`3Qh@0<h@030>7Q00_Q00<0hN402n400`3Q

h@0<h@030>7Q00_Q00<0hN401>433`;Q0Pl00`3Qh@0<h@030>7Q00_Q00<0hN402n400`3Qh@0<h@03

0>7Q00_Q00<0hN402n400`3Qh@0Sh@006n400`3Qh@04h@033n7Q03kQ00<0hN40@>400kkQh@02h@03

0>7Q04CQ00<0hN40AN400`3Qh@15h@030>7Q02kQ00<?hN401N400`oQh@0<h@030>7Q04CQ00<0hN40

8n4001_Q00<0hN401>400`oQh@0nh@030>7Q043Q00>nhN400^400`3Qh@14h@030>7Q04GQ00<0hN40

AN400`3Qh@0/h@8?2N423`cQ00<0hN40A>400`3Qh@0Sh@006n400`3Qh@04h@033n7Q087Q00>nhN40

on48h@033n7Q00_Q00<?hN40M^4001_Q00<0hN401>400`oQh@21h@03_^7Q0?oQ1^423`oQ0Pmfh@00

6n400`3Qh@04h@033n7Q087Q00>nhN40on45h@033n7Q017Q00<?hN40Ln4001_Q00<0hN401N400`oQ

h@20h@03_^7Q0?oQ1>400`oQh@0Ch@8?Ln4001_Q00<0hN401N400`oQh@20h@03_^7Q0?oQ0N433aSQ

00<?hN40L>4001_Q00<0hN401N400`oQh@20h@03_^7Q0?kQ0PlKh@033n7Q073Q000Kh@030>7Q00GQ

00<?hN40P>400kkQh@3mh@033n7Q01cQ00<?hN40Kn4001_Q0`05h@033n7Q083Q00>nhN40nn423b3Q

0Pm_h@006n400`3Qh@05h@033n7Q083Q00>nhN40n^400`oQh@0Rh@033n7Q06cQ000Kh@030>7Q00GQ

00<?hN40P>400kkQh@3gh@<?9^423fcQ000Kh@030>7Q00GQ00<?hN40P>400kkQh@3fh@033n7Q02WQ

00<?hN40JN4001_Q00<0hN401N400`oQh@21h@03_^7Q0??Q0Pl]h@033n7Q06SQ000Kh@030>7Q00GQ

00<?hN40PN400kkQh@3`h@<?<>400`oQh@1Wh@006n400`3Qh@05h@033n7Q087Q00>nhN40kn400`oQ

h@0bh@033n7Q06KQ000Kh@030>7Q00GQ00<?hN40PN400kkQh@3]h@8?=^400`oQh@1Uh@006n400`3Q

h@05h@033n7Q087Q00>nhN40jn423cWQ00<?hN40I>4001_Q00<0hN401N400`oQh@21h@03_^7Q0>WQ

0Pllh@033n7Q06?Q000Kh@030>7Q00GQ00<?hN40PN400kkQh@3Vh@<??n400`oQh@1Rh@006n400`3Q

h@05h@033n7Q087Q00>nhN40iN400`oQh@11h@033n7Q067Q000Kh@<01^400`oQh@20h@03_^7Q0>?Q

0Pm5h@033n7Q063Q000Kh@030>7Q00KQ00<?hN40P>400kkQh@3Qh@8?B>400`oQh@1Oh@006n400`3Q

h@06h@033n7Q083Q00>nhN40gn423d_Q00<?hN40G^4001_Q00<0hN401^400`oQh@20h@03_^7Q0=cQ

0`m>h@033n7Q05gQ000Kh@030>7Q00KQ00<?hN40P>400kkQh@3Kh@033n7Q053Q00<?hN40G>4001_Q

00<0hN401^400`oQh@20h@03_^7Q0=SQ0`mCh@033n7Q05cQ000Kh@030>7Q00KQ00<?hN40P>400kkQ

h@3Gh@033n7Q05GQ00<?hN40Fn4001_Q00<0hN401^400`oQh@20h@03_^7Q0=CQ0`mIh@033n7Q05[Q

000Kh@030>7Q00KQ00<?hN40P>400kkQh@3Bh@8?GN400`oQh@1Ih@006n400`3Qh@06h@033n7Q083Q

00>nhN40cn433eoQ00<?hN40FN4001_Q00<0hN401^400`oQh@20h@03_^7Q0<kQ00<?hN40HN400`oQ

h@1Hh@006n400`3Qh@06h@033n7Q087Q00>nhN40b^433fGQ0PmHh@006n4300OQ00<?hN40P>400kkQ

h@37h@<?JN400`oQh@1Fh@006n400`3Qh@07h@033n7Q083Q00>nhN40a^400`oQh@1[h@033n7Q05GQ

000Kh@030>7Q00OQ00<?hN40P>400kkQh@33h@<?Kn400`oQh@1Dh@006n400`3Qh@07h@033n7Q083Q

00>nhN40`N423g?Q00<?hN40Dn4001_Q00<0hN401n400`oQh@20h@03_^7Q0;oQ0Pmeh@033n7Q05?Q

000Kh@030>7Q00OQ00<?hN40P>400kkQh@2lh@<?N>400`oQh@1Bh@006n400`3Qh@07h@033n7Q087Q

00>nhN40^N423gcQ00<?hN40DN4001_Q00<0hN402>400`oQh@20h@03_^7Q0;KQ0`moh@033n7Q053Q

000Kh@030>7Q00SQ00<?hN40P>400kkQh@2eh@033n7Q083Q00<?hN40D>4001_Q00<0hN402>400`oQ

h@20h@03_^7Q0;;Q0`n4h@033n7Q04oQ000Kh@030>7Q00SQ00<?hN40P>400kkQh@2_h@<?Qn400`oQ

h@1?h@006n400`3Qh@09h@033n7Q07oQ00>nhN40[^400`oQh@28h@033n7Q04oQ000Kh@<02N400`oQ

h@20h@03_^7Q0:[Q0`n<h@033n7Q04kQ000Kh@030>7Q00WQ00<?hN40P>400kkQh@2Wh@<?T>400`oQ

h@1=h@006n400`3Qh@09h@033n7Q083Q00>nhN40Y^400`oQh@2Bh@033n7Q04cQ000Kh@030>7Q00WQ

00<?hN40P>400kkQh@2Sh@<?UN400`oQh@1<h@006n400`3Qh@0:h@033n7Q07oQ00>nhN40X>433iWQ

00<?hN40Bn4001_Q00<0hN402^400`oQh@1oh@03_^7Q09kQ0PnLh@033n7Q04_Q000Kh@030>7Q00[Q

00<?hN40On400kkQh@2Lh@8?Wn400`oQh@1:h@006n400`3Qh@0:h@033n7Q083Q00>nhN40V>433j;Q

00<?hN40BN4001_Q00<0hN402n400`oQh@1oh@03_^7Q09KQ0PnUh@033n7Q04WQ000Kh@030>7Q00_Q

00<?hN40On400kkQh@2Ch@<?Z>400`oQh@18h@004^400`3Qh@06h@030>7Q00cQ00<?hN40O^400kkQ

h@2@h@<?[>400`oQh@17h@004N400`3Q0007h@030>7Q00cQ00<?hN40O^400kkQh@2?h@033n7Q0:gQ

00<?hN40An4001?Q00<0hN401N4400_Q00<?hN40O^400kkQh@2<h@<?/N400`oQh@16h@004N4200SQ

00<0hN403>400`oQh@1oh@03_^7Q08SQ0`ndh@033n7Q04KQ000Ah@030>7Q00OQ00<0hN403N400`oQ

h@1nh@03_^7Q08OQ00<?hN40]^400`oQh@15h@004N4300OQ00<0hN403N400`oQh@1nh@03_^7Q08CQ

0`nih@033n7Q01OQ1[hXh@006n400`3Qh@0=h@033n7Q07kQ00>nhN40PN433kgQ00<?hN404n43_RkQ

000Kh@030>7Q00gQ00<?hN40O^400kkQh@20h@033n7Q0;kQ00<?hN403n44_S7Q000Kh@030>7Q00gQ

00<?hN40O^400kkQh@1mh@<?`^400`oQh@0;h@>n=N4001_Q00<0hN403^400`oQh@1nh@03_^7Q07WQ

0`o6h@033n7Q00;Q2;hhh@006n400`3Qh@0>h@033n7Q07kQ00>nhN40N>400`oQh@37h@033n6n00:n

@>4001_Q00<0hN403^400`oQh@1nh@03_^7Q07GQ0`o8h@Bn@n4001_Q00<0hN403n400`oQh@1mh@03

_^7Q07;Q0`o8h@>n1>400`oQh@10h@006n400`3Qh@0?h@033n7Q07gQ00>nhN40L>423lOQ1;h7h@03

3n7Q043Q000Kh@<04>400`oQh@1lh@03_^7Q06gQ0`o2h@Nn3>400`oQh@0oh@006n400`3Qh@0@h@03

3n7Q07gQ00>nhN40J^423l7Q1;hCh@033n7Q03oQ000Kh@030>7Q017Q00<?hN40O>400kkQh@1Xh@8?

`>43_QSQ00<?hN40?^4001_Q00<0hN404N400`oQh@1lh@03_^7Q06GQ0`nnh@Bn7>400`oQh@0mh@00

6n400`3Qh@0Ah@033n7Q07cQ00>nhN40H^433kgQ1;hQh@033n7Q03cQ000Kh@030>7Q01;Q00<?hN40

O>400kkQh@1Ph@033n7Q0;_Q0khUh@033n7Q03cQ000Kh@030>7Q01;Q00<?hN40O>400kkQh@1Mh@<?

^^44_RWQ00<?hN40>n4001_Q00<0hN404n400`oQh@1kh@03_^7Q05[Q0`njh@>n;^400`oQh@0jh@00

6n400`3Qh@0Ch@033n7Q07cQ00>nhN40F>400`oQh@2gh@Bn<^400`oQh@0ih@006n400`3Qh@0Dh@03

3n7Q07_Q00>nhN40EN433kOQ0khgh@033n7Q03SQ000Kh@030>7Q01CQ00<?hN40Nn400kkQh@1Bh@<?

]^44_S_Q00<?hN40=n4001_Q00<0hN405N400`oQh@1jh@03_^7Q057Q00<?hN40/n44_T3Q00<?hN40

=^4001_Q0`0Eh@033n7Q07_Q00>nhN40CN433k?Q0ki5h@033n7Q03GQ000Kh@030>7Q01KQ00<?hN40

N^400kkQh@1:h@<?/^44_TWQ00<?hN40=>4001_Q00<0hN405^400`oQh@1jh@03_^7Q04SQ0Pnbh@>n

C^423cCQ000Kh@030>7Q01OQ00<?hN40N^400kkQh@15h@8?/>44_U?Q00<?hN40<N4001_Q00<0hN40

5n400`oQh@1jh@03_^7Q04;Q0`n^h@BnF>423c7Q000Kh@030>7Q01SQ00<?hN40NN400kkQh@10h@8?

[^43_UkQ00<?hN40;^4001_Q00<0hN406>400`oQh@1jh@03_^7Q03cQ0`n/h@BnH^400`oQh@0]h@00

6n400`3Qh@0Ih@033n7Q07WQ00>nhN40>^423jcQ0kiWh@<?;>4001_Q00<0hN406^400`oQh@1hh@03

_^7Q03SQ0PnZh@BnKN423b[Q000Kh@030>7Q01[Q00<?hN40N>400kkQh@0eh@<?Z>44_W?Q0`lWh@00

6n400`3Qh@0Kh@033n7Q07SQ00>nhN40<N433jWQ0[ijh@033n7Q02CQ000Kh@030>7Q01cQ00<?hN40

Mn400kkQh@0_h@8?Z^42_Z?Q000Kh@<07N400`oQh@1fh@03_^7Q02gQ0PnYh@>nYN4001_Q00<0hN40

7N400`oQh@1gh@03_^7Q02WQ0`nXh@>nZ>4001_Q00<0hN407^400`oQh@1fh@03_^7Q02KQ0`nWh@Bn

Zn4001_Q00<0hN407n400`oQh@1eh@03_^7Q02?Q0`nWh@>n[n4001_Q00<0hN408>400`oQh@1eh@03

_^7Q027Q00<?hN40YN43_[;Q000Kh@030>7Q023Q00<?hN40MN400kkQh@0Nh@<?Y^42_[GQ000Kh@03

0>7Q027Q00<?hN40MN400kkQh@0Jh@<?Y^43_[OQ000Kh@030>7Q02;Q00<?hN40M>400kkQh@0Gh@<?

Y^43_[[Q000Kh@030>7Q02?Q00<?hN40M>400kkQh@0Dh@8?Y^43_[gQ000Kh@030>7Q02CQ00<?hN40

Ln400kkQh@0Ah@<?Y^42_/3Q000Kh@030>7Q02GQ00<?hN40Ln400kkQh@0>h@8?Yn42_/;Q000Kh@03

0>7Q02KQ00<?hN40Ln400kkQh@0:h@<?YN44_/CQ000Kh@<09n400`oQh@1bh@03_^7Q00SQ0PnUh@>n

b>4001_Q00<0hN40:>400`oQh@1bh@03_^7Q00CQ0`nUh@:nbn4001_Q00<0hN40:N423g;Q00BnhN7Q

0`nVh@:ncN4001_Q00<0hN40:n400`oQh@1`h@03_Pl?0:KQ0kk?h@006n400`3Qh@0/h@8?KN433`03

_^7Q0:CQ0[kBh@006n400`3Qh@0^h@033n7Q06KQ10l4h@03_^7Q0:7Q0[kDh@006n400`3Qh@0_h@03

3n7Q06;Q0`l8h@03_^7Q09kQ0kkFh@006n400`3Qh@0`h@8?Gn433`cQ00>nhN40Vn42_]WQ000Kh@03

0>7Q03;Q00<?hN40FN433`oQ00>nhN40V>43_]_Q000Kh@030>7Q03?Q0PmEh@@?4n400kkQh@2Eh@:n

g^4000_Q1@02h@030>7Q00KQ00<0hN40=N433doQ0`lGh@03_^7Q09?Q0[kPh@003N401`3QhN40h@00

1n400`3Qh@0hh@033n7Q04SQ10lKh@03_^7Q093Q0[kRh@003N401`3QhN40h@001n4403SQ0`m2h@D?

8>400kkQh@2=h@:ni>4000gQ00L0hN7Q0>4000OQ00<0hN40?>433c_Q10lVh@03_^7Q08[Q0[kVh@00

3N401`3QhN40h@001n400`3Qh@0oh@<?<^463b[Q00>nhN40Qn43_^SQ000<h@801>400`3Qh@06h@03

0>7Q04;Q10lYh@D?<N400kkQh@24h@:njn4001_Q00<0hN40A^463a_Q20lgh@03_^7Q08;Q00>nhN40

jn4001_Q00<0hN40C>4K3d3Q00>nhN40On42_^kQ000Kh@030>7Q0:OQ00>nhN40O>43__3Q000Kh@03

0>7Q0:SQ00>nhN40N>43__?Q000Kh@030>7Q0:SQ00>nhN40M^42__KQ000Kh@030>7Q0:WQ00>nhN40

M>400kkQh@3fh@006n400`3Qh@2Zh@03_^7Q077Q0[kih@006n400`3Qh@2[h@03_^7Q06kQ0[kkh@00

6n430:cQ00>nhN40Jn42__gQ000Kh@030>7Q0:gQ00>nhN40JN400kkQh@3mh@006n400`3Qh@2^h@03

_^7Q06KQ0[koh@7Q000Kh@030>7Q0:oQ0[iSh@>non43h@006n400`3Qh@2ah@03_^7Q05gQ0kkoh@KQ

000Kh@030>7Q0;;Q00>nhN40F^42__oQ2N4001_Q00<0hN40/n400kkQh@1Hh@03_^7Q0?oQ2N4001_Q

00<0hN40]>400kkQh@1Eh@:non4<h@006n400`3Qh@2eh@03_^7Q05;Q0[koh@kQ000Kh@030>7Q0;KQ

0[i@h@:non4@h@006n400`3Qh@2hh@03_^7Q04_Q0[kohA;Q000Kh@030>7Q0;WQ0[i8h@>non4Dh@00

6n430;_Q00>nhN40@n42__oQ5n4001_Q00<0hN40_>42_T3Q0kkohAWQ000Kh@030>7Q0;kQ0[hlh@:n

on4Lh@006n400`3Qh@30h@:n>>42__oQ7^4001_Q00<0hN40`^42_S?Q0kkohB3Q000Kh@030>7Q0<CQ

1;h/h@>non4Sh@006n400`3Qh@38h@Bn9>44__oQ9^4001_Q00<0hN40c>43_QkQ0kkohB[Q000Kh@03

0>7Q0<oQ1kh?h@Rnon4]h@006n400`3Qh@3Fh@nnon4eh@006n400`3Qh@3ohOoQ6n4001_Q00<0hN40

on7ohA_Q000Kh@<0on7ohA_Q000Kh@030>7Q0?oQon4Kh@006n400`3Qh@3ohOoQ6n4001_Q00<0hN40

on7ohA_Q000Kh@030>7Q0?oQon4Kh@006n400`3Qh@3ohOoQ6n400?oQon4ih@00on7ohCWQ003ohOoQ

>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQon4ih@00

on7ohCWQ003ohA3Q0P001>400>440003h@0000CQ00<0hN40on4Eh@00on4Ah@030>4000WQ00H0hN40

h@3ohAKQ003ohA7Q0`02h@@00^400`3Qh@03h@030>7Q0?oQ5>400?oQ4N40103Q0008h@030>7Q0080

on4Gh@006N420?GQ00<0hN401n400`3Q0002h@030>7Q0?oQ5^4001[Q00<0hN40l^4200[Q00@0hN7Q

0`3ohAKQ000Hh@<00^400`3Qh@3ohOoQ6N4001OQ00P0hN40h@3Q0?oQon4Jh@005n40203Qh@3Q0>40

on7ohA[Q000Hh@<000CQ0>40on7ohA[Q000Lh@030>400?oQon4Jh@007N400`3Qh@3ohOoQ6N400?oQ

on4ih@00on7ohCWQ003ohOoQ>N400?oQon4ih@00on7ohCWQ0000\

\>"],

  ImageRangeCache->{{{0, 566}, {349.313, 0}} -> {12.6144, -13.4053, 0.0139368,

   0.08369}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-1.84845 0.141303 0.309017 0.0231246 [

[.27109 .29652 -6 -9 ]

[.27109 .29652 6 0 ]

[.41239 .29652 -6 -9 ]

[.41239 .29652 6 0 ]

[.5537 .29652 -6 -9 ]

[.5537 .29652 6 0 ]

[.695 .29652 -6 -9 ]

[.695 .29652 6 0 ]

[.8363 .29652 -6 -9 ]

[.8363 .29652 6 0 ]

[.9776 .29652 -6 -9 ]

[.9776 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.11729 .07777 -18 -4.5 ]

[.11729 .07777 0 4.5 ]

[.11729 .19339 -12 -4.5 ]

[.11729 .19339 0 4.5 ]

[.11729 .42464 -6 -4.5 ]

[.11729 .42464 0 4.5 ]

[.11729 .54026 -12 -4.5 ]

[.11729 .54026 0 4.5 ]

[.12979 .64303 -7 0 ]

[.12979 .64303 7 16 ]

[.5 .63053 -12 0 ]

[.5 .63053 12 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.27109 .30902 m

.27109 .31527 L

s

[(15)] .27109 .29652 0 1 Mshowa

.41239 .30902 m

.41239 .31527 L

s

[(16)] .41239 .29652 0 1 Mshowa

.5537 .30902 m

.5537 .31527 L

s

[(17)] .5537 .29652 0 1 Mshowa

.695 .30902 m

.695 .31527 L

s

[(18)] .695 .29652 0 1 Mshowa

.8363 .30902 m

.8363 .31527 L

s

[(19)] .8363 .29652 0 1 Mshowa

.9776 .30902 m

.9776 .31527 L

s

[(20)] .9776 .29652 0 1 Mshowa

.125 Mabswid

.15805 .30902 m

.15805 .31277 L

s

.18631 .30902 m

.18631 .31277 L

s

.21457 .30902 m

.21457 .31277 L

s

.24283 .30902 m

.24283 .31277 L

s

.29935 .30902 m

.29935 .31277 L

s

.32761 .30902 m

.32761 .31277 L

s

.35587 .30902 m

.35587 .31277 L

s

.38413 .30902 m

.38413 .31277 L

s

.44065 .30902 m

.44065 .31277 L

s

.46891 .30902 m

.46891 .31277 L

s

.49717 .30902 m

.49717 .31277 L

s

.52543 .30902 m

.52543 .31277 L

s

.58196 .30902 m

.58196 .31277 L

s

.61022 .30902 m

.61022 .31277 L

s

.63848 .30902 m

.63848 .31277 L

s

.66674 .30902 m

.66674 .31277 L

s

.72326 .30902 m

.72326 .31277 L

s

.75152 .30902 m

.75152 .31277 L

s

.77978 .30902 m

.77978 .31277 L

s

.80804 .30902 m

.80804 .31277 L

s

.86456 .30902 m

.86456 .31277 L

s

.89282 .30902 m

.89282 .31277 L

s

.92108 .30902 m

.92108 .31277 L

s

.94934 .30902 m

.94934 .31277 L

s

.10153 .30902 m

.10153 .31277 L

s

.07327 .30902 m

.07327 .31277 L

s

.045 .30902 m

.045 .31277 L

s

.01674 .30902 m

.01674 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.12979 .07777 m

.13604 .07777 L

s

[(-10)] .11729 .07777 1 0 Mshowa

.12979 .19339 m

.13604 .19339 L

s

[(-5)] .11729 .19339 1 0 Mshowa

.12979 .42464 m

.13604 .42464 L

s

[(5)] .11729 .42464 1 0 Mshowa

.12979 .54026 m

.13604 .54026 L

s

[(10)] .11729 .54026 1 0 Mshowa

.125 Mabswid

.12979 .1009 m

.13354 .1009 L

s

.12979 .12402 m

.13354 .12402 L

s

.12979 .14714 m

.13354 .14714 L

s

.12979 .17027 m

.13354 .17027 L

s

.12979 .21652 m

.13354 .21652 L

s

.12979 .23964 m

.13354 .23964 L

s

.12979 .26277 m

.13354 .26277 L

s

.12979 .28589 m

.13354 .28589 L

s

.12979 .33214 m

.13354 .33214 L

s

.12979 .35527 m

.13354 .35527 L

s

.12979 .37839 m

.13354 .37839 L

s

.12979 .40152 m

.13354 .40152 L

s

.12979 .44776 m

.13354 .44776 L

s

.12979 .47089 m

.13354 .47089 L

s

.12979 .49401 m

.13354 .49401 L

s

.12979 .51714 m

.13354 .51714 L

s

.12979 .05465 m

.13354 .05465 L

s

.12979 .03152 m

.13354 .03152 L

s

.12979 .0084 m

.13354 .0084 L

s

.12979 .56339 m

.13354 .56339 L

s

.12979 .58651 m

.13354 .58651 L

s

.12979 .60964 m

.13354 .60964 L

s

.25 Mabswid

.12979 0 m

.12979 .61803 L

s

gsave

.12979 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -73 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(k) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(37) show

83.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

1 0 0 r

.5 Mabswid

.97478 .52682 m

.97195 .52728 L

.96913 .52773 L

.9663 .52819 L

.96347 .52864 L

.96065 .5291 L

.95782 .52955 L

.955 .53 L

.95217 .53045 L

.94934 .53091 L

.94652 .53135 L

.94369 .5318 L

.94086 .53225 L

.93804 .53269 L

.93521 .53314 L

.93239 .53357 L

.92956 .53401 L

.92673 .53445 L

.92391 .53488 L

.92108 .53531 L

.91826 .53573 L

.91543 .53615 L

.9126 .53656 L

.90978 .53697 L

.90695 .53737 L

.90413 .53777 L

.9013 .53816 L

.89847 .53854 L

.89565 .53891 L

.89282 .53927 L

.89 .53962 L

.88717 .53995 L

.88434 .54027 L

.88152 .54057 L

.87869 .54085 L

.87587 .54111 L

.87304 .54134 L

.87021 .54154 L

.86739 .5417 L

.86456 .54181 L

.86174 .54187 L

.85891 .54186 L

.85608 .54176 L

.85326 .54155 L

.85043 .54118 L

.8476 .54059 L

.84478 .53966 L

.84195 .53813 L

.83913 .53523 L

.83899 .535 L

Mistroke

.83884 .53476 L

.8387 .53451 L

.83856 .53425 L

.83842 .53395 L

.83828 .53365 L

.83814 .53331 L

.838 .53293 L

.83786 .53252 L

.83771 .53205 L

.83757 .53151 L

.83743 .53087 L

.83729 .53007 L

.83715 .52888 L

Mfstroke

.97478 .09121 m

.97195 .09076 L

.96913 .0903 L

.9663 .08985 L

.96347 .08939 L

.96065 .08894 L

.95782 .08848 L

.955 .08803 L

.95217 .08758 L

.94934 .08713 L

.94652 .08668 L

.94369 .08623 L

.94086 .08579 L

.93804 .08534 L

.93521 .0849 L

.93239 .08446 L

.92956 .08402 L

.92673 .08359 L

.92391 .08316 L

.92108 .08273 L

.91826 .08231 L

.91543 .08189 L

.9126 .08147 L

.90978 .08106 L

.90695 .08066 L

.90413 .08026 L

.9013 .07988 L

.89847 .07949 L

.89565 .07912 L

.89282 .07876 L

.89 .07842 L

.88717 .07808 L

.88434 .07776 L

.88152 .07746 L

.87869 .07718 L

.87587 .07692 L

.87304 .07669 L

.87021 .07649 L

.86739 .07633 L

.86456 .07622 L

.86174 .07616 L

.85891 .07617 L

.85608 .07627 L

.85326 .07649 L

.85043 .07686 L

.8476 .07745 L

.84478 .07838 L

.84195 .0799 L

.83913 .0828 L

.83899 .08303 L

Mistroke

.83884 .08327 L

.8387 .08352 L

.83856 .08378 L

.83842 .08408 L

.83828 .08438 L

.83814 .08472 L

.838 .0851 L

.83786 .08551 L

.83771 .08598 L

.83757 .08652 L

.83743 .08716 L

.83729 .08796 L

.83715 .08915 L

Mfstroke

0 .4 1 r

.97619 .4229 m

.97478 .42321 L

.97336 .42352 L

.97195 .42383 L

.97054 .42414 L

.96913 .42446 L

.96771 .42477 L

.9663 .42508 L

.96489 .4254 L

.96347 .42571 L

.96206 .42603 L

.96065 .42635 L

.95923 .42666 L

.95782 .42698 L

.95641 .4273 L

.955 .42762 L

.95358 .42794 L

.95217 .42826 L

.95076 .42858 L

.94934 .4289 L

.94793 .42922 L

.94652 .42955 L

.9451 .42987 L

.94369 .43019 L

.94228 .43052 L

.94086 .43084 L

.93945 .43117 L

.93804 .4315 L

.93663 .43182 L

.93521 .43215 L

.9338 .43248 L

.93239 .43281 L

.93097 .43314 L

.92956 .43347 L

.92815 .43381 L

.92673 .43414 L

.92532 .43447 L

.92391 .43481 L

.9225 .43514 L

.92108 .43548 L

.91967 .43581 L

.91826 .43615 L

.91684 .43649 L

.91543 .43683 L

.91402 .43717 L

.9126 .43751 L

.91119 .43785 L

.90978 .43819 L

.90837 .43853 L

.90695 .43888 L

Mistroke

.90554 .43922 L

.90413 .43957 L

.90271 .43991 L

.9013 .44026 L

.89989 .44061 L

.89847 .44096 L

.89706 .44131 L

.89565 .44166 L

.89423 .44201 L

.89282 .44236 L

.89141 .44271 L

.89 .44307 L

.88858 .44342 L

.88717 .44378 L

.88576 .44413 L

.88434 .44449 L

.88293 .44485 L

.88152 .44521 L

.8801 .44557 L

.87869 .44593 L

.87728 .4463 L

.87587 .44666 L

.87445 .44702 L

.87304 .44739 L

.87163 .44776 L

.87021 .44812 L

.8688 .44849 L

.86739 .44886 L

.86597 .44923 L

.86456 .44961 L

.86315 .44998 L

.86174 .45035 L

.86032 .45073 L

.85891 .45111 L

.8575 .45148 L

.85608 .45186 L

.85467 .45224 L

.85326 .45262 L

.85184 .45301 L

.85043 .45339 L

.84902 .45378 L

.8476 .45416 L

.84619 .45455 L

.84478 .45494 L

.84337 .45533 L

.84195 .45572 L

.84054 .45611 L

.83913 .45651 L

.83771 .4569 L

.8363 .4573 L

Mistroke

.83489 .4577 L

.83347 .45809 L

.83206 .4585 L

.83065 .4589 L

.82924 .4593 L

.82782 .45971 L

.82641 .46011 L

.825 .46052 L

.82358 .46093 L

.82217 .46134 L

.82076 .46175 L

.81934 .46217 L

.81793 .46258 L

.81652 .463 L

.81511 .46342 L

.81369 .46384 L

.81228 .46426 L

.81087 .46469 L

.80945 .46511 L

.80804 .46554 L

.80663 .46597 L

.80521 .4664 L

.8038 .46683 L

.80239 .46727 L

.80097 .46771 L

.79956 .46814 L

.79815 .46858 L

.79674 .46903 L

.79532 .46947 L

.79391 .46992 L

.7925 .47037 L

.79108 .47082 L

.78967 .47127 L

.78826 .47173 L

.78684 .47218 L

.78543 .47264 L

.78402 .4731 L

.78261 .47357 L

.78119 .47403 L

.77978 .4745 L

.77837 .47497 L

.77695 .47545 L

.77554 .47592 L

.77413 .4764 L

.77271 .47688 L

.7713 .47736 L

.76989 .47785 L

.76848 .47834 L

.76706 .47883 L

.76565 .47933 L

Mistroke

.76424 .47982 L

.76282 .48032 L

.76141 .48083 L

.76 .48133 L

.75858 .48184 L

.75717 .48235 L

.75576 .48287 L

.75435 .48339 L

.75293 .48391 L

.75152 .48444 L

.75011 .48496 L

.74869 .4855 L

.74728 .48603 L

.74587 .48657 L

.74445 .48712 L

.74304 .48766 L

.74163 .48822 L

.74021 .48877 L

.7388 .48933 L

.73739 .48989 L

.73598 .49046 L

.73456 .49103 L

.73315 .49161 L

.73174 .49219 L

.73032 .49278 L

.72891 .49337 L

.7275 .49396 L

.72608 .49456 L

.72467 .49517 L

.72326 .49578 L

.72185 .4964 L

.72043 .49702 L

.71902 .49765 L

.71761 .49828 L

.71619 .49892 L

.71478 .49957 L

.71337 .50022 L

.71195 .50088 L

.71054 .50154 L

.70913 .50222 L

.70772 .5029 L

.7063 .50358 L

.70489 .50428 L

.70348 .50498 L

.70206 .50569 L

.70065 .50641 L

.69924 .50714 L

.69782 .50788 L

.69641 .50862 L

.695 .50938 L

Mistroke

.69358 .51014 L

.69217 .51092 L

.69076 .51171 L

.68935 .5125 L

.68793 .51331 L

.68652 .51413 L

.68511 .51497 L

.68369 .51581 L

.68228 .51668 L

.68087 .51755 L

.67945 .51844 L

.67804 .51934 L

.67663 .52027 L

.67522 .5212 L

.6738 .52216 L

.67239 .52314 L

.67098 .52413 L

.66956 .52515 L

.66815 .52619 L

.66674 .52725 L

.66532 .52833 L

.66391 .52945 L

.6625 .53059 L

.66109 .53176 L

.65967 .53296 L

.65826 .5342 L

.65685 .53548 L

.65543 .53679 L

.65402 .53815 L

.65261 .53955 L

.65119 .54101 L

.64978 .54252 L

.64837 .54408 L

.64695 .54572 L

.64554 .54742 L

.64413 .5492 L

.64272 .55106 L

.6413 .55302 L

.63989 .55506 L

.63848 .5572 L

.63706 .55942 L

.63565 .56171 L

.63424 .56405 L

.63282 .56639 L

.63141 .56867 L

.63 .57085 L

.62859 .57288 L

.62717 .57473 L

.62576 .57641 L

.62435 .57792 L

Mistroke

.62293 .57927 L

.62152 .5805 L

.62011 .58161 L

.61869 .58263 L

.61728 .58356 L

.61587 .58441 L

.61446 .58521 L

.61304 .58595 L

.61163 .58664 L

.61022 .58729 L

.6088 .5879 L

.60739 .58848 L

.60598 .58904 L

.60456 .58956 L

.60315 .59006 L

.60174 .59054 L

.60032 .591 L

.59891 .59144 L

.5975 .59187 L

.59609 .59228 L

.59467 .59268 L

.59326 .59306 L

.59185 .59343 L

.59043 .59379 L

.58902 .59414 L

.58761 .59448 L

.58619 .5948 L

.58478 .59513 L

.58337 .59544 L

.58196 .59574 L

.58054 .59603 L

.57913 .59632 L

.57772 .5966 L

.5763 .59687 L

.57489 .59714 L

.57348 .5974 L

.57206 .59765 L

.57065 .5979 L

.56924 .59814 L

.56783 .59837 L

.56641 .5986 L

.565 .59882 L

.56359 .59904 L

.56217 .59925 L

.56076 .59946 L

.55935 .59966 L

.55793 .59985 L

.55652 .60004 L

.55511 .60023 L

.5537 .60041 L

Mistroke

.55228 .60059 L

.55087 .60075 L

.54946 .60092 L

.54804 .60108 L

.54663 .60123 L

.54522 .60138 L

.5438 .60152 L

.54239 .60166 L

.54098 .60179 L

.53956 .60192 L

.53815 .60204 L

.53674 .60216 L

.53533 .60228 L

.53391 .60238 L

.5325 .60248 L

.53109 .60258 L

.52967 .60267 L

.52826 .60275 L

.52685 .60283 L

.52543 .60291 L

.52402 .60297 L

.52261 .60304 L

.5212 .60309 L

.51978 .60314 L

.51837 .60319 L

.51696 .60322 L

.51554 .60326 L

.51413 .60328 L

.51272 .6033 L

.5113 .60331 L

.50989 .60332 L

.50848 .60332 L

.50707 .60331 L

.50565 .6033 L

.50424 .60327 L

.50283 .60324 L

.50141 .60321 L

.5 .60317 L

.49859 .60312 L

.49717 .60306 L

.49576 .60299 L

.49435 .60292 L

.49293 .60284 L

.49152 .60275 L

.49011 .60265 L

.4887 .60254 L

.48728 .60243 L

.48587 .6023 L

.48446 .60217 L

.48304 .60203 L

Mistroke

.48163 .60188 L

.48022 .60172 L

.4788 .60155 L

.47739 .60137 L

.47598 .60118 L

.47457 .60098 L

.47315 .60077 L

.47174 .60055 L

.47033 .60032 L

.46891 .60007 L

.4675 .59982 L

.46609 .59955 L

.46467 .59928 L

.46326 .59899 L

.46185 .59869 L

.46044 .59837 L

.45902 .59805 L

.45761 .59771 L

.4562 .59736 L

.45478 .59699 L

.45337 .59662 L

.45196 .59622 L

.45054 .59581 L

.44913 .59539 L

.44772 .59496 L

.4463 .59451 L

.44489 .59404 L

.44348 .59356 L

.44207 .59306 L

.44065 .59254 L

.43924 .59201 L

.43783 .59146 L

.43641 .59089 L

.435 .59031 L

.43359 .5897 L

.43217 .58908 L

.43076 .58844 L

.42935 .58778 L

.42794 .58709 L

.42652 .58639 L

.42511 .58567 L

.4237 .58492 L

.42228 .58415 L

.42087 .58336 L

.41946 .58255 L

.41804 .58171 L

.41663 .58085 L

.41522 .57996 L

.41381 .57905 L

.41239 .57811 L

Mistroke

.41098 .57714 L

.40957 .57615 L

.40815 .57513 L

.40674 .57408 L

.40533 .573 L

.40391 .57188 L

.4025 .57074 L

.40109 .56956 L

.39968 .56835 L

.39826 .56711 L

.39685 .56583 L

.39544 .56452 L

.39402 .56317 L

.39261 .56177 L

.3912 .56034 L

.38978 .55887 L

.38837 .55736 L

.38696 .5558 L

.38554 .5542 L

.38413 .55256 L

.38272 .55086 L

.38131 .54912 L

.37989 .54732 L

.37848 .54548 L

.37707 .54357 L

.37565 .54161 L

.37424 .5396 L

.37283 .53752 L

.37141 .53538 L

.37 .53317 L

.36859 .53089 L

.36718 .52855 L

.36576 .52613 L

.36435 .52363 L

.36294 .52105 L

.36152 .51838 L

.36011 .51563 L

.3587 .51278 L

.35728 .50984 L

.35587 .50679 L

.35446 .50363 L

.35305 .50036 L

.35163 .49696 L

.35022 .49343 L

.34881 .48977 L

.34739 .48595 L

.34598 .48198 L

.34457 .47783 L

.34315 .4735 L

.34174 .46897 L

Mistroke

.34033 .46421 L

.33891 .45921 L

.3375 .45394 L

.33609 .44837 L

.33468 .44245 L

.33326 .43615 L

.33185 .42939 L

.33044 .42209 L

.32902 .41414 L

.32761 .40538 L

.3262 .39555 L

.32478 .38423 L

.32337 .37062 L

.32196 .3526 L

.32055 .3148 L

.32055 .30902 L

Mfstroke

.97619 .19514 m

.97478 .19483 L

.97336 .19452 L

.97195 .1942 L

.97054 .19389 L

.96913 .19358 L

.96771 .19327 L

.9663 .19295 L

.96489 .19264 L

.96347 .19232 L

.96206 .19201 L

.96065 .19169 L

.95923 .19137 L

.95782 .19105 L

.95641 .19074 L

.955 .19042 L

.95358 .1901 L

.95217 .18978 L

.95076 .18946 L

.94934 .18913 L

.94793 .18881 L

.94652 .18849 L

.9451 .18817 L

.94369 .18784 L

.94228 .18752 L

.94086 .18719 L

.93945 .18686 L

.93804 .18654 L

.93663 .18621 L

.93521 .18588 L

.9338 .18555 L

.93239 .18522 L

.93097 .18489 L

.92956 .18456 L

.92815 .18423 L

.92673 .1839 L

.92532 .18356 L

.92391 .18323 L

.9225 .18289 L

.92108 .18256 L

.91967 .18222 L

.91826 .18188 L

.91684 .18155 L

.91543 .18121 L

.91402 .18087 L

.9126 .18053 L

.91119 .18019 L

.90978 .17984 L

.90837 .1795 L

.90695 .17916 L

Mistroke

.90554 .17881 L

.90413 .17847 L

.90271 .17812 L

.9013 .17777 L

.89989 .17743 L

.89847 .17708 L

.89706 .17673 L

.89565 .17638 L

.89423 .17603 L

.89282 .17567 L

.89141 .17532 L

.89 .17497 L

.88858 .17461 L

.88717 .17426 L

.88576 .1739 L

.88434 .17354 L

.88293 .17318 L

.88152 .17282 L

.8801 .17246 L

.87869 .1721 L

.87728 .17174 L

.87587 .17137 L

.87445 .17101 L

.87304 .17064 L

.87163 .17028 L

.87021 .16991 L

.8688 .16954 L

.86739 .16917 L

.86597 .1688 L

.86456 .16843 L

.86315 .16805 L

.86174 .16768 L

.86032 .1673 L

.85891 .16693 L

.8575 .16655 L

.85608 .16617 L

.85467 .16579 L

.85326 .16541 L

.85184 .16503 L

.85043 .16464 L

.84902 .16426 L

.8476 .16387 L

.84619 .16348 L

.84478 .1631 L

.84337 .16271 L

.84195 .16231 L

.84054 .16192 L

.83913 .16153 L

.83771 .16113 L

.8363 .16074 L

Mistroke

.83489 .16034 L

.83347 .15994 L

.83206 .15954 L

.83065 .15914 L

.82924 .15873 L

.82782 .15833 L

.82641 .15792 L

.825 .15751 L

.82358 .1571 L

.82217 .15669 L

.82076 .15628 L

.81934 .15587 L

.81793 .15545 L

.81652 .15503 L

.81511 .15461 L

.81369 .15419 L

.81228 .15377 L

.81087 .15335 L

.80945 .15292 L

.80804 .15249 L

.80663 .15206 L

.80521 .15163 L

.8038 .1512 L

.80239 .15076 L

.80097 .15033 L

.79956 .14989 L

.79815 .14945 L

.79674 .14901 L

.79532 .14856 L

.79391 .14812 L

.7925 .14767 L

.79108 .14722 L

.78967 .14676 L

.78826 .14631 L

.78684 .14585 L

.78543 .14539 L

.78402 .14493 L

.78261 .14447 L

.78119 .144 L

.77978 .14353 L

.77837 .14306 L

.77695 .14259 L

.77554 .14211 L

.77413 .14163 L

.77271 .14115 L

.7713 .14067 L

.76989 .14018 L

.76848 .13969 L

.76706 .1392 L

.76565 .13871 L

Mistroke

.76424 .13821 L

.76282 .13771 L

.76141 .13721 L

.76 .1367 L

.75858 .13619 L

.75717 .13568 L

.75576 .13517 L

.75435 .13465 L

.75293 .13412 L

.75152 .1336 L

.75011 .13307 L

.74869 .13254 L

.74728 .132 L

.74587 .13146 L

.74445 .13092 L

.74304 .13037 L

.74163 .12982 L

.74021 .12926 L

.7388 .1287 L

.73739 .12814 L

.73598 .12757 L

.73456 .127 L

.73315 .12642 L

.73174 .12584 L

.73032 .12526 L

.72891 .12467 L

.7275 .12407 L

.72608 .12347 L

.72467 .12286 L

.72326 .12225 L

.72185 .12164 L

.72043 .12102 L

.71902 .12039 L

.71761 .11975 L

.71619 .11911 L

.71478 .11847 L

.71337 .11782 L

.71195 .11716 L

.71054 .11649 L

.70913 .11582 L

.70772 .11514 L

.7063 .11445 L

.70489 .11376 L

.70348 .11305 L

.70206 .11234 L

.70065 .11162 L

.69924 .1109 L

.69782 .11016 L

.69641 .10941 L

.695 .10866 L

Mistroke

.69358 .10789 L

.69217 .10712 L

.69076 .10633 L

.68935 .10553 L

.68793 .10472 L

.68652 .1039 L

.68511 .10307 L

.68369 .10222 L

.68228 .10136 L

.68087 .10048 L

.67945 .09959 L

.67804 .09869 L

.67663 .09777 L

.67522 .09683 L

.6738 .09587 L

.67239 .0949 L

.67098 .0939 L

.66956 .09289 L

.66815 .09185 L

.66674 .09079 L

.66532 .0897 L

.66391 .08859 L

.6625 .08745 L

.66109 .08628 L

.65967 .08507 L

.65826 .08383 L

.65685 .08256 L

.65543 .08124 L

.65402 .07989 L

.65261 .07848 L

.65119 .07703 L

.64978 .07552 L

.64837 .07395 L

.64695 .07232 L

.64554 .07061 L

.64413 .06883 L

.64272 .06697 L

.6413 .06502 L

.63989 .06297 L

.63848 .06084 L

.63706 .05861 L

.63565 .05632 L

.63424 .05398 L

.63282 .05165 L

.63141 .04936 L

.63 .04719 L

.62859 .04516 L

.62717 .0433 L

.62576 .04163 L

.62435 .04012 L

Mistroke

.62293 .03876 L

.62152 .03753 L

.62011 .03642 L

.61869 .03541 L

.61728 .03448 L

.61587 .03362 L

.61446 .03283 L

.61304 .03209 L

.61163 .03139 L

.61022 .03074 L

.6088 .03013 L

.60739 .02955 L

.60598 .029 L

.60456 .02847 L

.60315 .02797 L

.60174 .02749 L

.60032 .02703 L

.59891 .02659 L

.5975 .02616 L

.59609 .02575 L

.59467 .02536 L

.59326 .02497 L

.59185 .0246 L

.59043 .02424 L

.58902 .0239 L

.58761 .02356 L

.58619 .02323 L

.58478 .02291 L

.58337 .0226 L

.58196 .0223 L

.58054 .022 L

.57913 .02171 L

.57772 .02144 L

.5763 .02116 L

.57489 .0209 L

.57348 .02064 L

.57206 .02038 L

.57065 .02014 L

.56924 .0199 L

.56783 .01966 L

.56641 .01943 L

.565 .01921 L

.56359 .01899 L

.56217 .01878 L

.56076 .01857 L

.55935 .01837 L

.55793 .01818 L

.55652 .01799 L

.55511 .0178 L

.5537 .01762 L

Mistroke

.55228 .01745 L

.55087 .01728 L

.54946 .01712 L

.54804 .01696 L

.54663 .0168 L

.54522 .01665 L

.5438 .01651 L

.54239 .01637 L

.54098 .01624 L

.53956 .01611 L

.53815 .01599 L

.53674 .01587 L

.53533 .01576 L

.53391 .01565 L

.5325 .01555 L

.53109 .01546 L

.52967 .01536 L

.52826 .01528 L

.52685 .0152 L

.52543 .01513 L

.52402 .01506 L

.52261 .015 L

.5212 .01494 L

.51978 .01489 L

.51837 .01485 L

.51696 .01481 L

.51554 .01478 L

.51413 .01475 L

.51272 .01473 L

.5113 .01472 L

.50989 .01472 L

.50848 .01472 L

.50707 .01472 L

.50565 .01474 L

.50424 .01476 L

.50283 .01479 L

.50141 .01482 L

.5 .01487 L

.49859 .01492 L

.49717 .01498 L

.49576 .01504 L

.49435 .01512 L

.49293 .0152 L

.49152 .01529 L

.49011 .01539 L

.4887 .01549 L

.48728 .01561 L

.48587 .01573 L

.48446 .01586 L

.48304 .01601 L

Mistroke

.48163 .01616 L

.48022 .01632 L

.4788 .01649 L

.47739 .01667 L

.47598 .01686 L

.47457 .01706 L

.47315 .01727 L

.47174 .01749 L

.47033 .01772 L

.46891 .01796 L

.4675 .01822 L

.46609 .01848 L

.46467 .01876 L

.46326 .01905 L

.46185 .01935 L

.46044 .01966 L

.45902 .01999 L

.45761 .02033 L

.4562 .02068 L

.45478 .02104 L

.45337 .02142 L

.45196 .02181 L

.45054 .02222 L

.44913 .02264 L

.44772 .02308 L

.4463 .02353 L

.44489 .02399 L

.44348 .02448 L

.44207 .02498 L

.44065 .02549 L

.43924 .02603 L

.43783 .02658 L

.43641 .02714 L

.435 .02773 L

.43359 .02833 L

.43217 .02895 L

.43076 .0296 L

.42935 .03026 L

.42794 .03094 L

.42652 .03164 L

.42511 .03237 L

.4237 .03311 L

.42228 .03388 L

.42087 .03467 L

.41946 .03548 L

.41804 .03632 L

.41663 .03718 L

.41522 .03807 L

.41381 .03898 L

.41239 .03992 L

Mistroke

.41098 .04089 L

.40957 .04188 L

.40815 .04291 L

.40674 .04396 L

.40533 .04504 L

.40391 .04615 L

.4025 .04729 L

.40109 .04847 L

.39968 .04968 L

.39826 .05092 L

.39685 .0522 L

.39544 .05352 L

.39402 .05487 L

.39261 .05626 L

.3912 .05769 L

.38978 .05916 L

.38837 .06067 L

.38696 .06223 L

.38554 .06383 L

.38413 .06548 L

.38272 .06717 L

.38131 .06892 L

.37989 .07071 L

.37848 .07256 L

.37707 .07446 L

.37565 .07642 L

.37424 .07844 L

.37283 .08052 L

.37141 .08266 L

.37 .08486 L

.36859 .08714 L

.36718 .08949 L

.36576 .09191 L

.36435 .09441 L

.36294 .09699 L

.36152 .09965 L

.36011 .1024 L

.3587 .10525 L

.35728 .1082 L

.35587 .11125 L

.35446 .1144 L

.35305 .11768 L

.35163 .12107 L

.35022 .1246 L

.34881 .12827 L

.34739 .13208 L

.34598 .13605 L

.34457 .1402 L

.34315 .14453 L

.34174 .14907 L

Mistroke

.34033 .15382 L

.33891 .15882 L

.3375 .16409 L

.33609 .16967 L

.33468 .17558 L

.33326 .18189 L

.33185 .18865 L

.33044 .19594 L

.32902 .20389 L

.32761 .21266 L

.3262 .22249 L

.32478 .2338 L

.32337 .24741 L

.32196 .26543 L

.32055 .30324 L

.32055 .30902 L

Mfstroke

1 0 0 r

.83729 .5225 m

.83743 .52128 L

.83757 .52024 L

.83771 .5193 L

.83786 .51842 L

.838 .51759 L

.83814 .51681 L

.83828 .51606 L

.83842 .51534 L

.83856 .51464 L

.8387 .51395 L

.83884 .51329 L

.83899 .51263 L

.83913 .51198 L

.83927 .51135 L

.83941 .51072 L

.83955 .51011 L

.83969 .5095 L

.83983 .5089 L

.83997 .50829 L

.84012 .50771 L

.84026 .50712 L

.8404 .50653 L

.84054 .50596 L

.84068 .50538 L

.84082 .50481 L

.84096 .50423 L

.8411 .50366 L

.84125 .5031 L

.84139 .50254 L

.84153 .50197 L

.84167 .50141 L

.84181 .50086 L

.84195 .5003 L

.84209 .49973 L

.84224 .49918 L

.84238 .49863 L

.84252 .49807 L

.84266 .49751 L

.8428 .49696 L

.84294 .4964 L

.84308 .49584 L

.84322 .49528 L

.84337 .49473 L

.84351 .49418 L

.84365 .49362 L

.84379 .49307 L

.84393 .4925 L

.84407 .49194 L

.84421 .49138 L

Mistroke

.84435 .49082 L

.8445 .49025 L

.84464 .48969 L

.84478 .48913 L

.84492 .48856 L

.84506 .48798 L

.8452 .48741 L

.84534 .48684 L

.84549 .48627 L

.84563 .48569 L

.84577 .48511 L

.84591 .48453 L

.84605 .48394 L

.84619 .48336 L

.84633 .48277 L

.84647 .48218 L

.84662 .4816 L

.84676 .48099 L

.8469 .4804 L

.84704 .4798 L

.84718 .47918 L

.84732 .47857 L

.84746 .47797 L

.8476 .47734 L

.84775 .47672 L

.84789 .4761 L

.84803 .47547 L

.84817 .47484 L

.84831 .4742 L

.84845 .47356 L

.84859 .47292 L

.84874 .47226 L

.84888 .47161 L

.84902 .47095 L

.84916 .47028 L

.8493 .46961 L

.84944 .46893 L

.84958 .46825 L

.84972 .46755 L

.84987 .46686 L

.85001 .46615 L

.85015 .46544 L

.85029 .46472 L

.85043 .46399 L

.85057 .46327 L

.85071 .46252 L

.85085 .46177 L

.851 .461 L

.85114 .46023 L

.85128 .45945 L

Mistroke

.85184 .45621 L

.85241 .45273 L

.85297 .44898 L

.85354 .44483 L

.8541 .4401 L

.85467 .4344 L

.85524 .42629 L

.85538 .42318 L

.85552 .4173 L

.85524 .40454 L

.85495 .40032 L

.85467 .39712 L

.85184 .3788 L

.84902 .36766 L

.84619 .35905 L

.84337 .35186 L

.84054 .3456 L

.83771 .34001 L

.83489 .33493 L

.83206 .33026 L

.82924 .32592 L

.82641 .32185 L

.82358 .31803 L

.82076 .31441 L

.81793 .31096 L

.81511 .30767 L

.81228 .30452 L

.80945 .30149 L

.80663 .29858 L

.8038 .29576 L

.80097 .29304 L

.79815 .2904 L

.79532 .28784 L

.7925 .28535 L

.78967 .28293 L

.78684 .28056 L

.78402 .27825 L

.78119 .276 L

.77837 .27379 L

.77554 .27163 L

.77271 .26952 L

.76989 .26744 L

.76706 .2654 L

.76424 .2634 L

.76141 .26143 L

.75858 .25949 L

.75576 .25758 L

.75293 .2557 L

.75011 .25385 L

.74728 .25202 L

Mistroke

.74445 .25021 L

.74163 .24843 L

.7388 .24667 L

.73598 .24493 L

.73315 .24321 L

.73032 .24151 L

.7275 .23983 L

.72467 .23817 L

.72185 .23652 L

.71902 .23488 L

.71619 .23326 L

.71337 .23166 L

.71054 .23007 L

.70772 .22849 L

.70489 .22692 L

.70206 .22537 L

.69924 .22383 L

.69641 .2223 L

.69358 .22078 L

.69076 .21927 L

.68793 .21777 L

.68511 .21627 L

.68228 .21479 L

.67945 .21332 L

.67663 .21185 L

.6738 .2104 L

.67098 .20895 L

.66815 .20751 L

.66532 .20607 L

.6625 .20465 L

.65967 .20323 L

.65685 .20182 L

.65402 .20041 L

.65119 .19901 L

.64837 .19762 L

.64554 .19623 L

.64272 .19485 L

.63989 .19347 L

.63706 .1921 L

.63424 .19074 L

.63141 .18938 L

.62859 .18803 L

.62576 .18668 L

.62293 .18534 L

.62011 .18401 L

.61728 .18268 L

.61446 .18135 L

.61163 .18003 L

.6088 .17871 L

.60598 .1774 L

Mistroke

.60315 .1761 L

.60032 .1748 L

.5975 .1735 L

.59467 .17222 L

.59185 .17093 L

.58902 .16965 L

.58619 .16838 L

.58337 .16711 L

.58054 .16585 L

.57772 .16459 L

.57489 .16334 L

.57206 .16209 L

.56924 .16085 L

.56641 .15961 L

.56359 .15838 L

.56076 .15716 L

.55793 .15594 L

.55511 .15472 L

.55228 .15352 L

.54946 .15231 L

.54663 .15112 L

.5438 .14993 L

.54098 .14874 L

.53815 .14756 L

.53533 .14639 L

.5325 .14522 L

.52967 .14406 L

.52685 .1429 L

.52402 .14175 L

.5212 .14061 L

.51837 .13947 L

.51554 .13834 L

.51272 .13721 L

.50989 .13609 L

.50707 .13497 L

.50424 .13387 L

.50141 .13276 L

.49859 .13167 L

.49576 .13058 L

.49293 .12949 L

.49011 .12841 L

.48728 .12734 L

.48446 .12627 L

.48163 .12521 L

.4788 .12416 L

.47598 .12311 L

.47315 .12207 L

.47033 .12103 L

.4675 .12 L

.46467 .11897 L

Mistroke

.46185 .11795 L

.45902 .11694 L

.4562 .11593 L

.45337 .11493 L

.45054 .11394 L

.44772 .11295 L

.44489 .11196 L

.44207 .11098 L

.43924 .11001 L

.43641 .10905 L

.43359 .10808 L

.43076 .10713 L

.42794 .10618 L

.42511 .10524 L

.42228 .1043 L

.41946 .10337 L

.41663 .10245 L

.41381 .10153 L

.41098 .10061 L

.40815 .09971 L

.40533 .09881 L

.4025 .09791 L

.39968 .09702 L

.39685 .09614 L

.39402 .09526 L

.3912 .09439 L

.38837 .09353 L

.38554 .09267 L

.38272 .09182 L

.37989 .09098 L

.37707 .09014 L

.37424 .08931 L

.37141 .08849 L

.36859 .08767 L

.36576 .08686 L

.36294 .08606 L

.36011 .08526 L

.35728 .08447 L

.35446 .08369 L

.35163 .08292 L

.34881 .08215 L

.34598 .0814 L

.34315 .08065 L

.34033 .07991 L

.3375 .07917 L

.33468 .07845 L

.33185 .07773 L

.32902 .07703 L

.3262 .07633 L

.32337 .07564 L

Mistroke

.32055 .07496 L

.31772 .07429 L

.31489 .07363 L

.31207 .07298 L

.30924 .07234 L

.30642 .07171 L

.30359 .0711 L

.30076 .07049 L

.29794 .06989 L

.29511 .06931 L

.29228 .06874 L

.28946 .06818 L

.28663 .06763 L

.28381 .0671 L

.28098 .06658 L

.27815 .06607 L

.27533 .06558 L

.2725 .0651 L

.26968 .06464 L

.26685 .06419 L

.26402 .06376 L

.2612 .06334 L

.25837 .06294 L

.25555 .06256 L

.25272 .06219 L

.24989 .06185 L

.24707 .06152 L

.24424 .06121 L

.24142 .06092 L

.23859 .06065 L

.23576 .0604 L

.23294 .06017 L

.23011 .05996 L

.22729 .05978 L

.22446 .05962 L

.22163 .05948 L

.21881 .05937 L

.21598 .05928 L

.21316 .05922 L

.21033 .05919 L

.2075 .05919 L

.20468 .05921 L

.20185 .05927 L

.19903 .05935 L

.1962 .05947 L

.19337 .05962 L

.19055 .05981 L

.18772 .06002 L

.18489 .06028 L

.18207 .06057 L

Mistroke

.17924 .0609 L

.17642 .06128 L

.17359 .06169 L

.17076 .06214 L

.16794 .06264 L

.16511 .06319 L

.16229 .06378 L

.15946 .06443 L

.15663 .06512 L

.15381 .06586 L

.15098 .06667 L

.14816 .06752 L

.14533 .06844 L

.1425 .06942 L

.13968 .07046 L

.13685 .07157 L

.13403 .07274 L

.1312 .07399 L

.12837 .07532 L

.12555 .07671 L

.12272 .0782 L

.1199 .07976 L

.11707 .08142 L

.11424 .08316 L

.11142 .08501 L

.10859 .08695 L

.10577 .089 L

.10294 .09116 L

.10011 .09344 L

.09729 .09584 L

.09446 .09837 L

.09163 .10104 L

.08881 .10386 L

.08598 .10683 L

.08316 .10997 L

.08033 .11328 L

.0775 .11677 L

.07468 .12047 L

.07185 .12439 L

.06903 .12853 L

.0662 .13294 L

.06337 .13762 L

.06055 .1426 L

.05772 .14792 L

.0549 .15362 L

.05207 .15974 L

.04924 .16635 L

.04642 .17351 L

.04359 .18133 L

.04077 .18995 L

Mistroke

.03794 .19955 L

.03511 .21043 L

.03229 .2231 L

.02946 .2385 L

.02664 .25911 L

.02381 .29745 L

.02381 .30902 L

Mfstroke

.83729 .09553 m

.83743 .09675 L

.83757 .0978 L

.83771 .09874 L

.83786 .09962 L

.838 .10044 L

.83814 .10123 L

.83828 .10197 L

.83842 .10269 L

.83856 .1034 L

.8387 .10408 L

.83884 .10475 L

.83899 .1054 L

.83913 .10605 L

.83927 .10668 L

.83941 .10731 L

.83955 .10792 L

.83969 .10853 L

.83983 .10914 L

.83997 .10974 L

.84012 .11033 L

.84026 .11092 L

.8404 .1115 L

.84054 .11208 L

.84068 .11265 L

.84082 .11323 L

.84096 .11381 L

.8411 .11438 L

.84125 .11493 L

.84139 .1155 L

.84153 .11606 L

.84167 .11662 L

.84181 .11718 L

.84195 .11774 L

.84209 .1183 L

.84224 .11885 L

.84238 .11941 L

.84252 .11996 L

.84266 .12052 L

.8428 .12108 L

.84294 .12163 L

.84308 .1222 L

.84322 .12275 L

.84337 .1233 L

.84351 .12385 L

.84365 .12441 L

.84379 .12497 L

.84393 .12553 L

.84407 .1261 L

.84421 .12665 L

Mistroke

.84435 .12722 L

.8445 .12778 L

.84464 .12835 L

.84478 .1289 L

.84492 .12947 L

.84506 .13005 L

.8452 .13062 L

.84534 .13119 L

.84549 .13177 L

.84563 .13234 L

.84577 .13293 L

.84591 .13351 L

.84605 .13409 L

.84619 .13468 L

.84633 .13526 L

.84647 .13586 L

.84662 .13644 L

.84676 .13705 L

.8469 .13763 L

.84704 .13824 L

.84718 .13885 L

.84732 .13946 L

.84746 .14007 L

.8476 .14069 L

.84775 .14131 L

.84789 .14193 L

.84803 .14256 L

.84817 .1432 L

.84831 .14383 L

.84845 .14447 L

.84859 .14512 L

.84874 .14577 L

.84888 .14643 L

.84902 .14709 L

.84916 .14775 L

.8493 .14843 L

.84944 .1491 L

.84958 .14979 L

.84972 .15048 L

.84987 .15117 L

.85001 .15188 L

.85015 .15259 L

.85029 .15331 L

.85043 .15404 L

.85057 .15477 L

.85071 .15552 L

.85085 .15627 L

.851 .15703 L

.85114 .1578 L

.85128 .15858 L

Mistroke

.85184 .16183 L

.85241 .1653 L

.85297 .16906 L

.85354 .1732 L

.8541 .17794 L

.85467 .18364 L

.85524 .19175 L

.85538 .19486 L

.85552 .20074 L

.85524 .2135 L

.85495 .21771 L

.85467 .22091 L

.85184 .23923 L

.84902 .25037 L

.84619 .25898 L

.84337 .26618 L

.84054 .27244 L

.83771 .27803 L

.83489 .28311 L

.83206 .28778 L

.82924 .29212 L

.82641 .29618 L

.82358 .30001 L

.82076 .30363 L

.81793 .30708 L

.81511 .31036 L

.81228 .31352 L

.80945 .31654 L

.80663 .31946 L

.8038 .32227 L

.80097 .325 L

.79815 .32763 L

.79532 .3302 L

.7925 .33269 L

.78967 .33511 L

.78684 .33747 L

.78402 .33978 L

.78119 .34203 L

.77837 .34424 L

.77554 .3464 L

.77271 .34852 L

.76989 .3506 L

.76706 .35263 L

.76424 .35464 L

.76141 .35661 L

.75858 .35855 L

.75576 .36046 L

.75293 .36234 L

.75011 .36419 L

.74728 .36602 L

Mistroke

.74445 .36782 L

.74163 .3696 L

.7388 .37136 L

.73598 .3731 L

.73315 .37482 L

.73032 .37652 L

.7275 .3782 L

.72467 .37987 L

.72185 .38152 L

.71902 .38315 L

.71619 .38477 L

.71337 .38638 L

.71054 .38797 L

.70772 .38954 L

.70489 .39111 L

.70206 .39266 L

.69924 .39421 L

.69641 .39574 L

.69358 .39726 L

.69076 .39877 L

.68793 .40027 L

.68511 .40176 L

.68228 .40324 L

.67945 .40471 L

.67663 .40618 L

.6738 .40764 L

.67098 .40908 L

.66815 .41053 L

.66532 .41196 L

.6625 .41339 L

.65967 .41481 L

.65685 .41622 L

.65402 .41762 L

.65119 .41902 L

.64837 .42042 L

.64554 .4218 L

.64272 .42318 L

.63989 .42456 L

.63706 .42593 L

.63424 .42729 L

.63141 .42865 L

.62859 .43 L

.62576 .43135 L

.62293 .43269 L

.62011 .43403 L

.61728 .43536 L

.61446 .43668 L

.61163 .438 L

.6088 .43932 L

.60598 .44063 L

Mistroke

.60315 .44193 L

.60032 .44323 L

.5975 .44453 L

.59467 .44582 L

.59185 .4471 L

.58902 .44838 L

.58619 .44965 L

.58337 .45092 L

.58054 .45219 L

.57772 .45344 L

.57489 .4547 L

.57206 .45594 L

.56924 .45718 L

.56641 .45842 L

.56359 .45965 L

.56076 .46088 L

.55793 .4621 L

.55511 .46331 L

.55228 .46452 L

.54946 .46572 L

.54663 .46692 L

.5438 .46811 L

.54098 .46929 L

.53815 .47047 L

.53533 .47165 L

.5325 .47281 L

.52967 .47398 L

.52685 .47513 L

.52402 .47628 L

.5212 .47743 L

.51837 .47857 L

.51554 .4797 L

.51272 .48082 L

.50989 .48195 L

.50707 .48306 L

.50424 .48417 L

.50141 .48527 L

.49859 .48637 L

.49576 .48746 L

.49293 .48854 L

.49011 .48962 L

.48728 .49069 L

.48446 .49176 L

.48163 .49282 L

.4788 .49388 L

.47598 .49492 L

.47315 .49597 L

.47033 .497 L

.4675 .49804 L

.46467 .49906 L

Mistroke

.46185 .50008 L

.45902 .50109 L

.4562 .5021 L

.45337 .5031 L

.45054 .5041 L

.44772 .50509 L

.44489 .50607 L

.44207 .50705 L

.43924 .50802 L

.43641 .50899 L

.43359 .50995 L

.43076 .5109 L

.42794 .51185 L

.42511 .5128 L

.42228 .51373 L

.41946 .51466 L

.41663 .51559 L

.41381 .51651 L

.41098 .51742 L

.40815 .51833 L

.40533 .51923 L

.4025 .52012 L

.39968 .52101 L

.39685 .52189 L

.39402 .52277 L

.3912 .52364 L

.38837 .5245 L

.38554 .52536 L

.38272 .52621 L

.37989 .52706 L

.37707 .52789 L

.37424 .52872 L

.37141 .52955 L

.36859 .53036 L

.36576 .53117 L

.36294 .53198 L

.36011 .53277 L

.35728 .53356 L

.35446 .53434 L

.35163 .53511 L

.34881 .53588 L

.34598 .53664 L

.34315 .53739 L

.34033 .53813 L

.3375 .53886 L

.33468 .53958 L

.33185 .5403 L

.32902 .54101 L

.3262 .54171 L

.32337 .54239 L

Mistroke

.32055 .54307 L

.31772 .54374 L

.31489 .5444 L

.31207 .54505 L

.30924 .54569 L

.30642 .54632 L

.30359 .54694 L

.30076 .54754 L

.29794 .54814 L

.29511 .54872 L

.29228 .54929 L

.28946 .54985 L

.28663 .5504 L

.28381 .55093 L

.28098 .55145 L

.27815 .55196 L

.27533 .55245 L

.2725 .55293 L

.26968 .5534 L

.26685 .55384 L

.26402 .55428 L

.2612 .55469 L

.25837 .55509 L

.25555 .55548 L

.25272 .55584 L

.24989 .55619 L

.24707 .55652 L

.24424 .55683 L

.24142 .55712 L

.23859 .55739 L

.23576 .55764 L

.23294 .55787 L

.23011 .55807 L

.22729 .55826 L

.22446 .55842 L

.22163 .55855 L

.21881 .55867 L

.21598 .55875 L

.21316 .55881 L

.21033 .55884 L

.2075 .55885 L

.20468 .55882 L

.20185 .55877 L

.19903 .55868 L

.1962 .55856 L

.19337 .55841 L

.19055 .55823 L

.18772 .55801 L

.18489 .55775 L

.18207 .55746 L

Mistroke

.17924 .55713 L

.17642 .55676 L

.17359 .55635 L

.17076 .55589 L

.16794 .55539 L

.16511 .55485 L

.16229 .55425 L

.15946 .55361 L

.15663 .55291 L

.15381 .55217 L

.15098 .55137 L

.14816 .55051 L

.14533 .54959 L

.1425 .54862 L

.13968 .54757 L

.13685 .54646 L

.13403 .54529 L

.1312 .54404 L

.12837 .54272 L

.12555 .54132 L

.12272 .53984 L

.1199 .53827 L

.11707 .53662 L

.11424 .53487 L

.11142 .53303 L

.10859 .53108 L

.10577 .52903 L

.10294 .52687 L

.10011 .52459 L

.09729 .52219 L

.09446 .51966 L

.09163 .51699 L

.08881 .51417 L

.08598 .5112 L

.08316 .50807 L

.08033 .50476 L

.0775 .50126 L

.07468 .49756 L

.07185 .49365 L

.06903 .4895 L

.0662 .4851 L

.06337 .48042 L

.06055 .47543 L

.05772 .47011 L

.0549 .46441 L

.05207 .45829 L

.04924 .45169 L

.04642 .44452 L

.04359 .4367 L

.04077 .42809 L

Mistroke

.03794 .41849 L

.03511 .4076 L

.03229 .39494 L

.02946 .37954 L

.02664 .35892 L

.02381 .32058 L

.02381 .30902 L

Mfstroke

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{567, 350.313},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.776525,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008g0001GPP10`40000100000800002008200000

P800P020P<30`<3L`:K:l00003<006H009T00<`00?l0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV

09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<003o03?o06Ko09Wo0<co

0?oo0000<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I

<c>I<fJI<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0

IYT0I/`0I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bI

I_nIIP3<IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0c

VC<cVFHcVITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<

VIW<VLc<VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`c

c?lcc01Vc3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03o

c3?oc6Koc9Woc<coc?ooc000oc<0ofH0oiT0ol`0ool0o`0coc<cofHcoiTcol`coolco`1Voc=VofIV

oiUVolaVoomVo`2Ioc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<o`3ooc?oofKooiWoolco

ooooo`0000410@820P<30`@410D51@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C

4a@D5?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooe3Q00<0hN40on7Uh@00D>400`3Qh@3ohNGQ

001@h@030>7Q0?oQiN40053Q00<0hN40on7Uh@00D>400`3Qh@3ohNGQ001@h@<0on7Uh@00D>400`3Q

h@3ohNGQ001@h@030>7Q0?oQiN40053Q00<0hN40]>4M__oQ5>40053Q00<0hN40[>48_QgQ2Kkoh@_Q

001@h@030>7Q0:SQ1Kh]h@Nnon44h@00D>400`3Qh@2Th@Bn>>47__gQ001@h@030>7Q0:7Q0ki2h@Fn

nN40053Q00<0hN40W^43_T[Q1;keh@00D>400`3Qh@2Lh@:nD>44__;Q001@h@030>7Q09WQ0kiFh@:n

l>40053Q00<0hN40Un43_U[Q0kk]h@00D>4309GQ0[iPh@:njn40053Q00<0hN40U>400kkQh@1Rh@03

_^7Q0>SQ001@h@030>7Q097Q0kiVh@:nj>40053Q00<0hN40T>42_V[Q00>nhN40iN40053Q00<0hN40

S^42_VgQ00>nhN40i>40053Q00<0hN40SN42_VoQ00>nhN40hn40053Q00<0hN40S>400kkQh@1_h@03

_^7Q0>?Q001@h@030>7Q08_Q00>nhN40LN400kkQh@3Rh@00D>400`3Qh@29h@:nMN400kkQh@3Qh@00

D>400`3Qh@29h@03_^7Q07GQ00>nhN40h>40053Q00<0hN40Qn42_WSQ00>nhN40h>40053Q00<0hN40

Q^400kkQh@1ih@03_^7Q0=oQ001@h@<0QN42_WcQ00>nhN40g^40053Q00<0hN40Q>400kkQh@1lh@03

_^7Q0=kQ001@h@030>7Q01WQ70m>h@03_^7Q07kQ00>nhN40gN40053Q00<0hN404^473acQ20m5h@:n

P>400kkQh@3Mh@00D>400`3Qh@0=h@D?:n483ccQ00>nhN40PN400kkQh@3Lh@00D>400`3Qh@09h@@?

>>463cGQ00>nhN40Pn400kkQh@3Kh@00D>400`3Qh@06h@<?@^443c7Q00>nhN40Q>400kkQh@3Jh@00

D>400`3Qh@03h@<?BN463b[Q00>nhN40QN400kkQh@3Jh@00D>400`3Qh@033e;Q10lUh@03_^7Q08OQ

00>nhN40fN4003oQ1@02h@030>7Q00OQ00<0h@l0FN453b3Q00>nhN40R>400kkQh@3Hh@00@N401`3Q

hN40h@001n433eoQ10lKh@03_^7Q08WQ0[kIh@00>n4300?Q00L0hN7Q0>4000GQ0Pl00n400002067Q

10lFh@03_^7Q08cQ00>nhN40Hn4D3eoQ0011h@070>7Qh@3Q0004h@053n7Qh@00J>433a;Q00>nhN40

S^400kkQh@1Ph@8?5>473eSQ0011h@080>7Qh@3Q0>433`CQ00<0hN40JN453`gQ00>nhN40S^42_V3Q

00<?hN406n473e7Q0010h@801>400`3Q3`07h@030>7Q06kQ0`l9h@03_^7Q097Q00>nhN40Fn423bGQ

1Pm;h@00A^423`SQ00<0hN40LN443`CQ00>nhN40Tn400kkQh@1Jh@033n7Q02[Q20m3h@00AN400`oQ

h@08h@030>7Q07GQ0`l00kkQh@2Eh@03_^7Q05SQ0Pldh@D??^4004?Q0Pl;h@030>7Q07SQ10nEh@03

_^7Q05OQ00<?hN40>>463cSQ0012h@033n7Q00_Q00<0hN40N>401;kQhN433i?Q0[jHh@P?<>40047Q

00<?hN403>400`3Qh@1gh@03_^7Q00GQ0`nBh@03_^7Q0<gQ0010h@033n7Q00gQ00<0hN40M^400kkQ

h@09h@<?T>42_/gQ000oh@033n7Q00kQ00<0hN40MN400kkQh@0=h@D?SN400kkQh@1Ah@033n7Q07KQ

000mh@8?4N400`3Qh@1eh@03_^7Q01;Q0Pn<h@:nDN423gOQ000lh@033n7Q017Q0`1eh@03_^7Q01CQ

0`n;h@03_^7Q04oQ00<?hN40MN4003cQ00<?hN404N400`3Qh@1dh@03_^7Q01SQ0`n9h@:nCn400`oQ

h@1eh@00>^423aCQ00<0hN40Ln400kkQh@0Lh@<?Qn43_TgQ00<?hN40MN4003WQ00<?hN405>400`3Q

h@1ch@03_^7Q01oQ0`n7h@03_^7Q04[Q00<?hN40MN4003WQ00<?hN405>400`3Qh@1ch@03_^7Q02;Q

0`n5h@:nB^423gKQ000gh@8?5n400`3Qh@1bh@03_^7Q02KQ0`n4h@:nBN400`oQh@1dh@00=^400`oQ

h@0Gh@030>7Q07;Q00>nhN40:N433h?Q0[i7h@033n7Q07CQ000fh@033n7Q01OQ00<0hN40LN400kkQ

h@0]h@<?P^42_TGQ00<?hN40M>4003GQ00<?hN406>400`3Qh@1`h@03_^7Q037Q0`n0h@>n@n423gGQ

000eh@033n7Q01SQ00<0hN40L>400kkQh@0dh@<?P>42_T;Q00<?hN40Ln4003CQ00<?hN406N400`3Q

h@1`h@03_^7Q03OQ0`moh@:n@>400`oQh@1ch@00<n400`oQh@0Jh@030>7Q073Q00>nhN40>^433gkQ

0khmh@033n7Q07?Q000bh@033n7Q01_Q0`1_h@03_^7Q03kQ00<?hN40ON43_S_Q0Pmdh@00<^400`oQ

h@0Kh@030>7Q06oQ00>nhN40?n433goQ0khih@033n7Q07;Q000ah@033n7Q01cQ00<0hN40K^400kkQ

h@13h@<?O^43_SOQ00<?hN40L^40033Q00<?hN407N400`3Qh@1^h@03_^7Q04KQ0`mnh@>n=>400`oQ

h@1bh@00;n400`oQh@0Nh@030>7Q06gQ00>nhN40B^433gkQ0[hbh@8?Ln4002oQ00<?hN407^400`3Q

h@1]h@03_^7Q04gQ00<?hN40ON43_S3Q00<?hN40LN4002kQ00<?hN407n400`3Qh@1]h@03_^7Q04kQ

0`moh@:n;^400`oQh@1ah@00;^400`oQh@0Oh@030>7Q06gQ00>nhN40DN433gkQ0kh[h@033n7Q077Q

000]h@033n7Q023Q00<0hN40K>400kkQh@1Eh@<?O^43_RSQ0Pmbh@00;>400`oQh@0Qh@030>7Q06cQ

00>nhN40F>423goQ0khVh@033n7Q073Q000/h@033n7Q027Q00<0hN40Jn400kkQh@1Kh@8?P>43_R?Q

00<?hN40L>4002_Q00<?hN408^400`3Qh@1[h@03_^7Q05gQ0`n0h@>n8>400`oQh@1`h@00:n400`oQ

h@0Rh@<0J^400kkQh@1Qh@8?P>44_QgQ00<?hN40L>4002[Q00<?hN408n400`3Qh@1Zh@03_^7Q06?Q

0`n1h@>n6n400`oQh@1_h@00:^400`oQh@0Sh@030>7Q06[Q00>nhN40I^400`oQh@21h@>n6>400`oQ

h@1_h@00:N400`oQh@0Th@030>7Q06[Q00>nhN40In433h?Q1;hDh@033n7Q06oQ000Yh@033n7Q02CQ

00<0hN40J^400kkQh@1Zh@<?Q>43_Q7Q00<?hN40Kn4002SQ00<?hN409N400`3Qh@1Zh@03_^7Q06gQ

0Pn5h@Bn3N400`oQh@1_h@00:>400`oQh@0Uh@030>7Q06WQ00>nhN40L>423hKQ1;h:h@8?L>4002OQ

00<?hN409^400`3Qh@1Yh@03_^7Q07;Q0Pn8h@>n2>400`oQh@1^h@009n400`oQh@0Vh@030>7Q06SQ

00>nhN40MN433hSQ1;h4h@033n7Q06kQ000Vh@033n7Q02OQ00<0hN40J>400kkQh@1hh@033n7Q08WQ

0kh00n4?h@1_h@009^400`oQh@0Wh@030>7Q06SQ00>nhN40NN433h_Q00Bn3kjnK^4002GQ00<?hN40

:>400`3Qh@1Xh@03_^7Q07cQ0`n9h@033n7Q00BnJ^4002GQ00<?hN40:>4306SQ00>nhN40On423hOQ

00<?hN401>44_VKQ000Th@033n7Q02WQ00<0hN40J>400kkQh@21h@<?Q>400`oQh@08h@BnH^4002CQ

00<?hN40:N400`3Qh@1Wh@03_^7Q08GQ00<?hN40P^400`oQh@0;h@>nGn4002CQ00<?hN40:N400`3Q

h@1Wh@03_^7Q08KQ0`n1h@033n7Q00kQ1KiJh@008n400`oQh@0Zh@030>7Q06OQ00>nhN40RN400`oQ

h@1nh@033n7Q01?Q1;iFh@008n400`oQh@0Zh@030>7Q06KQ00>nhN40Rn423gkQ00<?hN405^45_U;Q

000Sh@033n7Q02[Q00<0hN40I^400kkQh@2=h@<?Nn400`oQh@0Kh@BnC^4002?Q00<?hN40:^400`3Q

h@1Vh@03_^7Q093Q00<?hN40N>400`oQh@0Oh@BnB^4002;Q00<?hN40:n400`3Qh@1Uh@03_^7Q09;Q

0`mgh@033n7Q02?Q1;i6h@008^400`oQh@0[h@030>7Q06GQ00>nhN40UN423gGQ00<?hN409n45_T7Q

000Qh@033n7Q02;Q00<0hN401n400`3Qh@1Uh@03_^7Q09OQ0`mch@033n7Q02_Q1;hmh@008N400`oQ

h@0Qh@030>4000SQ00<0hN40IN400kkQh@2Jh@033n7Q073Q00<?hN40;n45_SSQ000Qh@033n7Q01cQ

0`04h@030>7Q00KQ101Th@03_^7Q09_Q0`m_h@033n7Q03?Q1Khdh@008N400`oQh@0Qh@802N400`3Q

h@1Uh@03_^7Q09kQ0Pm]h@033n7Q03SQ1;h`h@008>400`oQh@0Rh@030>7Q00SQ00<0hN40IN400kkQ

h@2Ph@033n7Q06[Q00<?hN40K>40023Q00<?hN408^4300SQ00<0hN40IN400kkQh@2Qh@<?JN400`oQ

h@1/h@008>400`oQh@0]h@030>7Q06CQ00>nhN40YN400`oQh@1Vh@033n7Q06cQ000Ph@033n7Q02gQ

00<0hN40I>400kkQh@2Vh@8?I^400`oQh@1/h@008>400`oQh@0]h@030>7Q06CQ00>nhN40Z>433f?Q

00<?hN40K>4001oQ00<?hN40;^400`3Qh@1Th@03_^7Q0:_Q00<?hN40H>400`oQh@1/h@007n400`oQ

h@0^h@030>7Q06?Q00>nhN40[N433eoQ00<?hN40K>4001oQ00<?hN40;^400`3Qh@1Sh@03_^7Q0;3Q

0PmMh@033n7Q06cQ000Oh@033n7Q02kQ00<0hN40Hn400kkQh@2bh@033n7Q05[Q00<?hN40K>4001kQ

00<?hN40;n400`3Qh@1Sh@03_^7Q0;?Q0PmJh@033n7Q06cQ000Nh@033n7Q02oQ0`1Sh@03_^7Q0;GQ

0PmHh@033n7Q06cQ000Nh@033n7Q02oQ00<0hN40H^400kkQh@2hh@8?E^400`oQh@1/h@007^400`oQ

h@0_h@030>7Q06;Q00>nhN40^^400`oQh@1Bh@033n7Q06gQ000Mh@033n7Q033Q00<0hN40H^400kkQ

h@2kh@<?DN400`oQh@1]h@007N400`oQh@0`h@030>7Q06;Q00>nhN40_^423doQ00<?hN40KN4001gQ

00<?hN40<>400`3Qh@1Rh@03_^7Q0<3Q00<?hN40C>400`oQh@1]h@007N400`oQh@0`h@030>7Q06;Q

00>nhN40`N423dcQ00<?hN40KN4001gQ00<?hN40<>400`3Qh@1Rh@03_^7Q0<?Q0`m9h@033n7Q06gQ

000Lh@033n7Q037Q00<0hN40H^400kkQh@36h@033n7Q04GQ00<?hN40K^4001cQ00<?hN40<N400`3Q

h@1Rh@03_^7Q0<OQ0Pm5h@033n7Q06kQ000Lh@033n7Q037Q00<0hN40H^400kkQh@39h@033n7Q04;Q

00<?hN40K^4001cQ00<?hN40<N400`3Qh@1Rh@03_^7Q0<[Q0Pm2h@033n7Q06kQ000Lh@033n7Q037Q

0`1Rh@03_^7Q0<cQ00<?hN40?n400`oQh@1^h@007>400`oQh@0ah@030>7Q067Q00>nhN40c^433ckQ

00<?hN40K^4001cQ00<?hN40<N400`3Qh@1Qh@03_^7Q0=7Q00<?hN40>^400`oQh@1_h@006n400`oQ

h@0bh@030>7Q067Q00>nhN40d^423c[Q00<?hN40Kn4001_Q00<?hN40<^400`3Qh@1Qh@03_^7Q0=CQ

00<?hN40=n400`oQh@1_h@006n400`oQh@0bh@030>7Q067Q00>nhN40eN423cKQ00<?hN40L>4001_Q

00<?hN40<^400`3Qh@1Qh@03_^7Q0=OQ00<?hN40<n400`oQh@1`h@006n400`oQh@0bh@030>7Q067Q

00>nhN40f>423c?Q00<?hN40L>4001[Q00<?hN40<n400`3Qh@1Qh@03_^7Q0=[Q00<?hN40;n400`oQ

h@1ah@006^400`oQh@0ch@030>7Q063Q00>nhN40g>423boQ00<?hN40LN4001[Q00<?hN40<n400`3Q

h@1Ph@03_^7Q0=kQ00<?hN40;>400`oQh@1ah@006^400`oQh@0ch@030>7Q063Q00>nhN40gn423bcQ

00<?hN40LN4001[Q00<?hN40<n43063Q00>nhN40hN400`oQh@0Xh@033n7Q07;Q000Jh@033n7Q03?Q

00<0hN40H>400kkQh@3Rh@033n7Q02OQ00<?hN40L^4001[Q00<?hN40<n400`3Qh@1Ph@03_^7Q0>?Q

0PlWh@033n7Q07;Q000Jh@033n7Q03?Q00<0hN40H>400kkQh@3Uh@033n7Q02?Q00<?hN40Ln4001[Q

00<?hN40<n400`3Qh@1Ph@03_^7Q0>KQ0PlSh@033n7Q07?Q000Jh@033n7Q03?Q00<0hN40H>400kkQ

h@3Xh@033n7Q01oQ00<?hN40M>4001[Q00<?hN40<n400`3Qh@1Ph@03_^7Q0>WQ0PlOh@033n7Q07CQ

000Jh@033n7Q03?Q00<0hN40H>400kkQh@3[h@033n7Q01_Q00<?hN40MN4001WQ00<?hN40=>400`3Q

h@1Ph@03_^7Q0>cQ0PlKh@033n7Q07GQ000Ih@033n7Q03CQ00<0hN40H>400kkQh@3]h@033n7Q01SQ

00<?hN40M^4001WQ00<?hN40=>400`3Qh@11h@D00^400`3Qh@0Eh@03_^7Q02OQ1@000n400011h@D0

0^400`3Qh@10h@D00^400`3Qh@0Zh@033n7Q01;Q1@000`l00012h@<00n400`3Qh@0[h@006N400`oQ

h@0dh@030>7Q04?Q00L0hN7Q0>4001KQ00>nhN40:N401`3QhN40h@00@^400`3Qh@02h@030>7Q04;Q

00L0hN7Q0>4002cQ0PlDh@030>4?00?Q00<0hN40?n400`3Qh@02h@030>4002cQ000Ih@033n7Q03CQ

0`13h@030>7Q00?Q00<0hN405>400kkQh@0Yh@070>7Qh@3Q0012h@030>7Q00;Q00<0hN40@^401`3Q

hN40h@00;^400`oQh@0Ah@0300oQ00;Q0P12h@070>7Qh@3Q000/h@006N400`oQh@0dh@030>7Q04?Q

00@0hN7Q0P0Gh@03_^7Q02WQ00@0hN7Q0P13h@030>7Q00?Q00<0hN40@N400`3Qh@02h@030>7Q02kQ

0PlAh@0700oQh@3Q0012h@070>7Qh@3Q000/h@006N400`oQh@0dh@030>7Q04?Q00D0hN7Q000Hh@03

_^7Q02WQ00D0hN7Q0014h@070>7Qh@3Q0013h@070>7Qh@3Q000`h@033n7Q00oQ00L?hN7Q0>40047Q

00<0h@000^400`3Q000/h@006N400`oQh@0dh@030>7Q04;Q0P03h@<05^400kkQh@0Xh@801>42047Q

0P03h@<0@^4200CQ00<0hN40<>400`oQh@0=h@0300oQ00?Q0P12h@030>7Q00;Q00<0hN40:n4001WQ

00<?hN40=>400`3Qh@1Ph@03_^7Q0?GQ0Pl=h@033n7Q07[Q000Ih@033n7Q03CQ00<0hN40H>400kkQ

h@3gh@033n7Q00WQ00<?hN40Nn4001WQ00<?hN40=>400`3Qh@1Ph@03_^7Q0?OQ00<?hN402N400`oQ

h@1kh@006N400`oQh@0dh@030>7Q063Q00>nhN40n>400`oQh@07h@033n7Q07cQ000Ih@033n7Q03CQ

00<0hN40H>400kkQh@3ih@8?1^400`oQh@1mh@006N400`oQh@0dh@030>7Q063Q00>nhN40n^400`oQ

h@03h@033n7Q07kQ000Ih@033n7Q03CQ00<0hN40H>400kkQh@3kh@033n7Q00;Q00<?hN40J^44013Q

000Ih@033n7Q03CQ00<0hN40H>400kkQh@3lh@043n4?3fgQ0`0Ah@003>4=00033`0009L000>n0000

o@000`l0001N017Q00<0hN403n4001GQ00D0hN7Q3`0:h@030>7Q00_Q00<0hN403>400`3Qh@0<h@03

0>7Q00_Q00<0hN403>400`3Qh@0<h@030>7Q00_Q00<0hN403>400`3Qh@0<h@030>7Q00SQ00BnhN40

3^400`3Qh@0;h@030>7Q00cQ00<0hN403>400`3Qh@0;h@030>7Q00cQ00<0hN403>400`3Qh@0;h@03

0>7Q00cQ00<0hN403>400`3Qh@0;h@030>7Q00cQ00<0hN403>400`3Qh@0;h@030>7Q00cQ00<0hN40

3>400`3Qh@0;h@040>7Qh@8?2N400`3Qh@0;h@030>7Q00cQ00<0hN403>400`3Qh@0;h@030>7Q00cQ

00<0hN406^42017Q000Eh@050>7Qh@l02^400`3Qh@0;h@030>7Q00cQ00<0hN403>400`3Qh@0;h@03

0>7Q00cQ00<0hN403>400`3Qh@0;h@030>7Q00cQ00<0hN403>400`3Qh@08h@04_^7Q00kQ00<0hN40

2n400`3Qh@0<h@030>7Q00cQ00<0hN402n400`3Qh@0<h@030>7Q00cQ00<0hN402n400`3Qh@0<h@03

0>7Q00cQ00<0hN402n400`3Qh@0<h@030>7Q00cQ00<0hN402n400`3Qh@0<h@030>7Q00cQ00<0hN40

2n40103Qh@l2h@033n7Q00KQ00<0hN402n400`3Qh@0<h@030>7Q00cQ00<0hN402n400`3Qh@0<h@03

0>7Q02gQ000Ih@033n7Q03CQ00<0hN40A^400`3Qh@0Gh@03_^7Q02cQ00<0hN40A^400`3Qh@17h@03

0>7Q03WQ00<?hN400^400`oQh@05h@030>7Q04KQ00<0hN40;N4001WQ00<?hN40=>400`3Qh@16h@03

0>7Q01OQ00>nhN40;>400`3Qh@16h@030>7Q04OQ00<0hN40>>400`oQh@03h@033n7Q00GQ00<0hN40

A^400`3Qh@0]h@006N400`oQh@0dh@030>7Q063Q00>nhN40nN400`oQh@05h@033n7Q07gQ000Ih@03

3n7Q03CQ00<0hN40H>400kkQh@3hh@033n7Q00OQ00<?hN40O>4001WQ00<?hN40=>400`3Qh@1Ph@03

_^7Q0?OQ00<?hN402N400`oQh@1kh@006N400`oQh@0dh@030>7Q063Q00>nhN40m^400`oQh@0:h@03

3n7Q07_Q000Ih@033n7Q03CQ00<0hN40H>400kkQh@3fh@033n7Q00_Q00<?hN40N^4001WQ00<?hN40

=>400`3Qh@1Ph@03_^7Q0?CQ0Pl?h@033n7Q07WQ000Ih@033n7Q03CQ00<0hN40H>400kkQh@3ch@03

3n7Q013Q00<?hN40N>4001WQ00<?hN40=>43063Q00>nhN40l^400`oQh@0Ah@033n7Q07SQ000Ih@03

3n7Q03CQ00<0hN40H>400kkQh@3ah@033n7Q01?Q00<?hN40Mn4001WQ00<?hN40=>400`3Qh@1Ph@03

_^7Q0?3Q00<?hN405>400`oQh@1gh@006N400`oQh@0dh@030>7Q063Q00>nhN40k^423aSQ00<?hN40

M^4001WQ00<?hN40=>400`3Qh@1Ph@03_^7Q0>gQ00<?hN406N400`oQh@1eh@006^400`oQh@0ch@03

0>7Q063Q00>nhN40jn423acQ00<?hN40MN4001[Q00<?hN40<n400`3Qh@1Ph@03_^7Q0>[Q00<?hN40

7N400`oQh@1dh@006^400`oQh@0ch@030>7Q063Q00>nhN40j^400`oQh@0Mh@033n7Q07CQ000Jh@03

3n7Q03?Q00<0hN40H>400kkQh@3Xh@8?8>400`oQh@1dh@006^400`oQh@0ch@030>7Q063Q00>nhN40

in400`oQh@0Qh@033n7Q07?Q000Jh@033n7Q03?Q00<0hN40H>400kkQh@3Uh@8?9>400`oQh@1ch@00

6^400`oQh@0ch@030>7Q063Q00>nhN40i>400`oQh@0Uh@033n7Q07;Q000Jh@033n7Q03?Q0`1Ph@03

_^7Q0>;Q0PlXh@033n7Q07;Q000Jh@033n7Q03?Q00<0hN40H>400kkQh@3Qh@033n7Q02WQ00<?hN40

LN4001[Q00<?hN40<n400`3Qh@1Ph@03_^7Q0>3Q00<?hN40:^400`oQh@1ah@006^400`oQh@0ch@03

0>7Q063Q00>nhN40g^423bgQ00<?hN40LN4001[Q00<?hN40<n400`3Qh@1Qh@03_^7Q0=cQ00<?hN40

;N400`oQh@1ah@006n400`oQh@0bh@030>7Q067Q00>nhN40f^423c7Q00<?hN40L>4001_Q00<?hN40

<^400`3Qh@1Qh@03_^7Q0=WQ00<?hN40<N400`oQh@1`h@006n400`oQh@0bh@030>7Q067Q00>nhN40

en423cCQ00<?hN40L>4001_Q00<?hN40<^400`3Qh@1Qh@03_^7Q0=KQ00<?hN40=>400`oQh@1`h@00

6n400`oQh@0bh@030>7Q067Q00>nhN40e>423cSQ00<?hN40Kn4001_Q00<?hN40<^400`3Qh@1Qh@03

_^7Q0=7Q0`ljh@033n7Q06oQ000Lh@033n7Q037Q00<0hN40HN400kkQh@3@h@033n7Q03_Q00<?hN40

Kn4001cQ00<?hN40<N4306;Q00>nhN40cN423coQ00<?hN40K^4001cQ00<?hN40<N400`3Qh@1Rh@03

_^7Q0<cQ00<?hN40?n400`oQh@1^h@007>400`oQh@0ah@030>7Q06;Q00>nhN40bn400`oQh@10h@03

3n7Q06kQ000Lh@033n7Q037Q00<0hN40H^400kkQh@39h@8?@n400`oQh@1^h@007>400`oQh@0ah@03

0>7Q06;Q00>nhN40a^433dGQ00<?hN40K^4001cQ00<?hN40<N400`3Qh@1Rh@03_^7Q0<GQ00<?hN40

A^400`oQh@1^h@007N400`oQh@0`h@030>7Q06;Q00>nhN40`n423d[Q00<?hN40KN4001gQ00<?hN40

<>400`3Qh@1Rh@03_^7Q0<;Q00<?hN40B^400`oQh@1]h@007N400`oQh@0`h@030>7Q06;Q00>nhN40

`>423dgQ00<?hN40KN4001gQ00<?hN40<>400`3Qh@1Rh@03_^7Q0;gQ0`m?h@033n7Q06gQ000Mh@03

3n7Q033Q00<0hN40H^400kkQh@2lh@033n7Q053Q00<?hN40KN4001kQ00<?hN40;n400`3Qh@1Rh@03

_^7Q0;[Q0PmCh@033n7Q06gQ000Nh@033n7Q02oQ0`1Sh@03_^7Q0;KQ0`mFh@033n7Q06cQ000Nh@03

3n7Q02oQ00<0hN40Hn400kkQh@2eh@033n7Q05OQ00<?hN40K>4001oQ00<?hN40;^400`3Qh@1Sh@03

_^7Q0;CQ00<?hN40F>400`oQh@1/h@007n400`oQh@0^h@030>7Q06?Q00>nhN40/N433e_Q00<?hN40

K>4001oQ00<?hN40;^400`3Qh@1Sh@03_^7Q0:oQ0PmNh@033n7Q06cQ000Oh@033n7Q02kQ00<0hN40

I>400kkQh@2]h@033n7Q05kQ00<?hN40K>4001oQ00<?hN40;^400`3Qh@1Th@03_^7Q0:[Q0`mQh@03

3n7Q06cQ000Ph@033n7Q02gQ00<0hN40I>400kkQh@2Xh@8?I>400`oQh@1/h@008>400`oQh@0]h@03

0>7Q06CQ00>nhN40Yn400`oQh@1Th@033n7Q06cQ000Ph@033n7Q02gQ00<0hN40I>400kkQh@2Th@<?

In400`oQh@1/h@008>400`oQh@0Sh@030>7Q00OQ00<0hN40IN400kkQh@2Qh@8?J^400`oQh@1/h@00

8>400`oQh@0Rh@030>4000SQ00<0hN40IN400kkQh@2Ph@033n7Q06[Q00<?hN40>n400kkQh@0^h@00

8N400`oQh@0Sh@030>7Q00KQ101Th@03_^7Q09gQ0`m]h@033n7Q03OQ1Kh`h@008N400`oQh@0Qh@80

2N400`3Qh@1Uh@03_^7Q09cQ00<?hN40K^400`oQh@0ch@Bn=N40027Q00<?hN408N400`3Qh@08h@03

0>7Q06GQ00>nhN40VN433g7Q00<?hN40;^45_SWQ000Qh@033n7Q027Q0`08h@030>7Q06GQ00>nhN40

Un423g?Q00<?hN40:n44_SkQ000Rh@033n7Q02_Q00<0hN40IN400kkQh@2Dh@<?MN400`oQh@0Vh@Fn

@^4002;Q00<?hN40:n400`3Qh@1Vh@03_^7Q09;Q00<?hN40M^400`oQh@0Rh@FnA^4002?Q00<?hN40

:^400`3Qh@1Vh@03_^7Q093Q0Pmih@033n7Q01kQ1;i;h@008n400`oQh@0Zh@030>7Q06KQ00>nhN40

SN433g_Q00<?hN406N45_ToQ000Sh@033n7Q02[Q00<0hN40I^400kkQh@2<h@033n7Q07cQ00<?hN40

5^43_UCQ000Sh@033n7Q02[Q00<0hN40In400kkQh@28h@<?On400`oQh@0Ah@FnEn4002CQ00<?hN40

:N400`3Qh@1Wh@03_^7Q08OQ00<?hN40P>400`oQh@0=h@BnG>4002CQ00<?hN40:N400`3Qh@1Wh@03

_^7Q08CQ0`n3h@033n7Q00[Q1;iOh@009N400`oQh@0Xh@<0J>400kkQh@21h@8?QN400`oQh@06h@Fn

Hn4002GQ00<?hN40:>400`3Qh@1Xh@03_^7Q07kQ0`n7h@033n7Q00?Q1;iWh@009^400`oQh@0Wh@03

0>7Q06SQ00>nhN40ON400`oQh@28h@033n6n00>nJn4002KQ00<?hN409n400`3Qh@1Xh@03_^7Q07[Q

0`n9h@:n00<?_^40K^4002KQ00<?hN409n400`3Qh@1Xh@03_^7Q07SQ0Pn9h@Bn00?Q3n40Kn4002OQ

00<?hN409^400`3Qh@1Yh@03_^7Q07CQ0`n7h@Bn1N400`oQh@1^h@009n400`oQh@0Vh@030>7Q06WQ

00>nhN40LN433hKQ1;h9h@033n7Q06kQ000Xh@033n7Q02GQ00<0hN40JN400kkQh@1`h@033n7Q08GQ

0kh;h@8?L>4002SQ00<?hN409N400`3Qh@1Zh@03_^7Q06cQ0`n4h@Bn3^400`oQh@1_h@00:N400`oQ

h@0Th@030>7Q06[Q00>nhN40Jn400`oQh@21h@Bn4^400`oQh@1_h@00:N400`oQh@0Th@030>7Q06[Q

00>nhN40J>433h7Q0khFh@033n7Q06oQ000Zh@033n7Q02?Q00<0hN40J^400kkQh@1Uh@<?PN44_QSQ

00<?hN40Kn4002[Q00<?hN408n4306[Q00>nhN40Hn423h7Q1;hJh@8?LN4002_Q00<?hN408^400`3Q

h@1[h@03_^7Q05oQ0`n0h@>n7^400`oQh@1`h@00:n400`oQh@0Rh@030>7Q06_Q00>nhN40G>433h3Q

0khQh@033n7Q073Q000/h@033n7Q027Q00<0hN40Jn400kkQh@1Kh@033n7Q07kQ0khTh@033n7Q073Q

000/h@033n7Q027Q00<0hN40K>400kkQh@1Gh@<?O^43_ROQ00<?hN40L>4002gQ00<?hN408>400`3Q

h@1/h@03_^7Q05CQ0`mnh@>n:N400`oQh@1ah@00;^400`oQh@0Oh@030>7Q06gQ00>nhN40D^400`oQ

h@1lh@>n;>400`oQh@1ah@00;^400`oQh@0Oh@030>7Q06gQ00>nhN40Cn433ggQ0[h_h@033n7Q077Q

000_h@033n7Q01kQ00<0hN40KN400kkQh@1<h@<?ON43_S7Q00<?hN40LN4002oQ00<?hN407^400`3Q

h@1]h@03_^7Q04WQ0`mnh@:n<n423g?Q000`h@033n7Q01gQ00<0hN40K^400kkQh@16h@8?O^43_SGQ

00<?hN40L^40037Q00<?hN407>400`3Qh@1^h@03_^7Q04?Q0`mnh@:n>>400`oQh@1bh@00<^400`oQ

h@0Kh@<0Kn400kkQh@10h@8?O^43_S[Q00<?hN40L^4003;Q00<?hN406n400`3Qh@1_h@03_^7Q03gQ

0`mnh@>n>n423gCQ000ch@033n7Q01[Q00<0hN40L>400kkQh@0ih@<?O^43_SkQ00<?hN40Ln4003CQ

00<?hN406N400`3Qh@1`h@03_^7Q03KQ0`moh@>n@>400`oQh@1ch@00=N400`oQh@0Hh@030>7Q073Q

00>nhN40<n433h7Q00>nhN40@N400`oQh@1ch@00=N400`oQh@0Hh@030>7Q077Q00>nhN40;n433h7Q

0ki3h@033n7Q07CQ000fh@033n7Q01OQ00<0hN40LN400kkQh@0]h@8?P^43_TGQ00<?hN40M>4003KQ

00<?hN405n400`3Qh@1bh@03_^7Q02WQ0`n2h@>nAn400`oQh@1dh@00=n400`oQh@0Fh@030>7Q07?Q

00>nhN409^423hCQ00>nhN40B>400`oQh@1dh@00>>423aKQ00<0hN40Ln400kkQh@0Sh@<?Pn43_T[Q

0Pmfh@00>N400`oQh@0Dh@030>7Q07?Q00>nhN407^453hGQ0[i<h@033n7Q07GQ000jh@033n7Q01?Q

00<0hN40M>400kkQh@0Jh@<?R>42_TkQ00<?hN40MN4003_Q0PlCh@<0M>400kkQh@0Gh@<?RN43_ToQ

00<?hN40MN4003cQ00<?hN404N400`3Qh@1eh@03_^7Q01?Q0`n;h@:nDN400`oQh@1eh@00?N400`oQ

h@0@h@030>7Q07GQ00>nhN404N423hcQ0[iBh@033n7Q07KQ000nh@8?4>400`3Qh@1eh@03_^7Q00kQ

0`n=h@:nDn400`oQh@1fh@00@>400`oQh@0=h@030>7Q07KQ00>nhN402^433hkQ0[k>h@00@N423`gQ

00<0hN40Mn400kkQh@04h@D?T>42_YcQ0`l`h@00@n400`oQh@0:h@030>7Q07SQ00>nhN400`nDh@03

_^7Q05KQ00<?hN40?N463c?Q0014h@8?2^400`3Qh@1hh@<?U^400kkQh@1Gh@033n7Q03OQ1Plih@00

A^400`oQh@07h@030>7Q07CQ10l00kkQh@2Dh@:nF^423c?Q1@loh@00An423`OQ00<0hN40LN433`GQ

00>nhN40Tn400kkQh@1Jh@033n7Q02WQ20m4h@00?n4500;Q00@0hN4?1^400`3Qh@1]h@@?2N400kkQ

h@2@h@:nGN400`oQh@0Sh@H?C>40047Q00L0hN7Q0>4000;Q0Pl4h@030>7Q06[Q0`l>h@03_^7Q08kQ

00>nhN40G^423acQ1`mBh@00@N401`3QhN40h@001>4010oQhN4406CQ1@lAh@03_^7Q08kQ00>nhN40

H>433a3Q2@mIh@00@N401`3QhN40h@001N4010oQh@1Sh@@?5n400kkQh@2;h@:nI^4@3f;Q0011h@07

0>7Qh@3Q0006h@<?Gn443acQ00>nhN40RN400kkQh@3Hh@00@>4200CQ00<0hN401n40100?3`mGh@D?

8N400kkQh@28h@03_^7Q0=SQ001@h@040>7Qh@8?DN443bKQ00>nhN40Qn400kkQh@3Ih@00D>400`3Q

h@03h@<?B>463b_Q00>nhN40QN400kkQh@3Jh@00D>400`3Qh@06h@@?@>443c;Q00>nhN40Q>400kkQ

h@3Jh@00D>400`3Qh@0:h@@?=>483cKQ0[j4h@03_^7Q0=_Q001@h@030>7Q00kQ1@lXh@L?@>400kkQ

h@20h@03_^7Q0=cQ001@h@030>7Q01?Q2@lEh@X?B>400kkQh@1nh@03_^7Q0=gQ001@h@030>7Q01cQ

5@mBh@03_^7Q07kQ00>nhN40gN40053Q00<0hN40Q>42_WgQ00>nhN40g^40053Q0`26h@03_^7Q07WQ

00>nhN40gn40053Q00<0hN40Q^42_W[Q00>nhN40gn40053Q00<0hN40R>400kkQh@1fh@03_^7Q0>3Q

001@h@030>7Q08WQ00>nhN40MN400kkQh@3Ph@00D>400`3Qh@2:h@03_^7Q07?Q00>nhN40hN40053Q

00<0hN40Rn400kkQh@1ah@03_^7Q0>;Q001@h@030>7Q08cQ0[i`h@03_^7Q0>?Q001@h@030>7Q08kQ

00>nhN40KN400kkQh@3Sh@00D>400`3Qh@2?h@:nJn42_^KQ001@h@030>7Q097Q00>nhN40J>400kkQ

h@3Uh@00D>400`3Qh@2Bh@:nI^42_^SQ001@h@030>7Q09CQ0[iSh@03_^7Q0>SQ001@h@<0U^400kkQ

h@1Mh@>njn40053Q00<0hN40Un43_U[Q0kk]h@00D>400`3Qh@2Ih@BnE>43__3Q001@h@030>7Q09cQ

0ki?h@Bnl^40053Q00<0hN40W^44_TOQ1Kkfh@00D>400`3Qh@2Qh@Bn@>44___Q001@h@030>7Q0:GQ

1;hfh@Jnon40053Q00<0hN40ZN46_RWQ1kkoh@KQ001@h@030>7Q0:oQ2;hFh@^non4=h@00D>400`3Q

h@2ghANnon4Gh@00D>400`3Qh@3ohNGQ001@h@030>7Q0?oQiN40053Q0`3ohNGQ001@h@030>7Q0?oQ

iN40053Q00<0hN40on7Uh@00D>400`3Qh@3ohNGQ001@h@030>7Q0?oQiN40053Q00<0hN40on7Uh@00

on7ohCWQ003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ

>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQ1n420004h@00h@@000?Q00001>400`3Qh@3ohAkQ

003oh@SQ00<0h@002N401@3QhN400?oQ8>400?oQ2>4300;Q1002h@030>7Q00;Q00<0hN40on4Nh@00

on48h@040>4000SQ00<0hN400^400`3Qh@3ohAgQ001>h@80]n400`3Qh@07h@030>4000;Q00<0h@00

on4Oh@00Cn400`3Qh@2dh@802^40103QhN430?oQ7n4004gQ0`02h@030>7Q0?oQhn4004cQ00P0hN40

h@3Q0?oQi>4004cQ00P0hN40h@3Q0?oQi>4004gQ0`001>40h@3ohNCQ001Ah@030>400?oQi>4005;Q

00<0hN40on7Sh@00on7ohCWQ003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400001\

\>"],

  ImageRangeCache->{{{0, 566}, {349.313, 0}} -> {12.906, -13.3633, 0.0136531, 

  0.0834276}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-1.86108 0.141935 0.309017 0.0231564 [

[.26794 .29652 -6 -9 ]

[.26794 .29652 6 0 ]

[.40987 .29652 -6 -9 ]

[.40987 .29652 6 0 ]

[.55181 .29652 -6 -9 ]

[.55181 .29652 6 0 ]

[.69374 .29652 -6 -9 ]

[.69374 .29652 6 0 ]

[.83568 .29652 -6 -9 ]

[.83568 .29652 6 0 ]

[.97761 .29652 -6 -9 ]

[.97761 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.1135 .07745 -18 -4.5 ]

[.1135 .07745 0 4.5 ]

[.1135 .19323 -12 -4.5 ]

[.1135 .19323 0 4.5 ]

[.1135 .4248 -6 -4.5 ]

[.1135 .4248 0 4.5 ]

[.1135 .54058 -12 -4.5 ]

[.1135 .54058 0 4.5 ]

[.126 .64303 -7 0 ]

[.126 .64303 7 16 ]

[.5 .63053 -17 0 ]

[.5 .63053 17 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.26794 .30902 m

.26794 .31527 L

s

[(15)] .26794 .29652 0 1 Mshowa

.40987 .30902 m

.40987 .31527 L

s

[(16)] .40987 .29652 0 1 Mshowa

.55181 .30902 m

.55181 .31527 L

s

[(17)] .55181 .29652 0 1 Mshowa

.69374 .30902 m

.69374 .31527 L

s

[(18)] .69374 .29652 0 1 Mshowa

.83568 .30902 m

.83568 .31527 L

s

[(19)] .83568 .29652 0 1 Mshowa

.97761 .30902 m

.97761 .31527 L

s

[(20)] .97761 .29652 0 1 Mshowa

.125 Mabswid

.15439 .30902 m

.15439 .31277 L

s

.18278 .30902 m

.18278 .31277 L

s

.21116 .30902 m

.21116 .31277 L

s

.23955 .30902 m

.23955 .31277 L

s

.29632 .30902 m

.29632 .31277 L

s

.32471 .30902 m

.32471 .31277 L

s

.3531 .30902 m

.3531 .31277 L

s

.38148 .30902 m

.38148 .31277 L

s

.43826 .30902 m

.43826 .31277 L

s

.46665 .30902 m

.46665 .31277 L

s

.49503 .30902 m

.49503 .31277 L

s

.52342 .30902 m

.52342 .31277 L

s

.58019 .30902 m

.58019 .31277 L

s

.60858 .30902 m

.60858 .31277 L

s

.63697 .30902 m

.63697 .31277 L

s

.66535 .30902 m

.66535 .31277 L

s

.72213 .30902 m

.72213 .31277 L

s

.75051 .30902 m

.75051 .31277 L

s

.7789 .30902 m

.7789 .31277 L

s

.80729 .30902 m

.80729 .31277 L

s

.86406 .30902 m

.86406 .31277 L

s

.89245 .30902 m

.89245 .31277 L

s

.92084 .30902 m

.92084 .31277 L

s

.94922 .30902 m

.94922 .31277 L

s

.09762 .30902 m

.09762 .31277 L

s

.06923 .30902 m

.06923 .31277 L

s

.04084 .30902 m

.04084 .31277 L

s

.01245 .30902 m

.01245 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.126 .07745 m

.13225 .07745 L

s

[(-10)] .1135 .07745 1 0 Mshowa

.126 .19323 m

.13225 .19323 L

s

[(-5)] .1135 .19323 1 0 Mshowa

.126 .4248 m

.13225 .4248 L

s

[(5)] .1135 .4248 1 0 Mshowa

.126 .54058 m

.13225 .54058 L

s

[(10)] .1135 .54058 1 0 Mshowa

.125 Mabswid

.126 .10061 m

.12975 .10061 L

s

.126 .12377 m

.12975 .12377 L

s

.126 .14692 m

.12975 .14692 L

s

.126 .17008 m

.12975 .17008 L

s

.126 .21639 m

.12975 .21639 L

s

.126 .23955 m

.12975 .23955 L

s

.126 .2627 m

.12975 .2627 L

s

.126 .28586 m

.12975 .28586 L

s

.126 .33217 m

.12975 .33217 L

s

.126 .35533 m

.12975 .35533 L

s

.126 .37849 m

.12975 .37849 L

s

.126 .40164 m

.12975 .40164 L

s

.126 .44796 m

.12975 .44796 L

s

.126 .47111 m

.12975 .47111 L

s

.126 .49427 m

.12975 .49427 L

s

.126 .51742 m

.12975 .51742 L

s

.126 .0543 m

.12975 .0543 L

s

.126 .03114 m

.12975 .03114 L

s

.126 .00798 m

.12975 .00798 L

s

.126 .56374 m

.12975 .56374 L

s

.126 .58689 m

.12975 .58689 L

s

.126 .61005 m

.12975 .61005 L

s

.25 Mabswid

.126 0 m

.126 .61803 L

s

gsave

.126 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -78 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(k) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(37.5) show

93.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

1 0 0 r

.5 Mabswid

.97619 .52703 m

.97477 .52728 L

.97335 .52753 L

.97193 .52778 L

.97051 .52803 L

.96909 .52828 L

.96767 .52853 L

.96626 .52878 L

.96484 .52903 L

.96342 .52928 L

.962 .52953 L

.96058 .52978 L

.95916 .53004 L

.95774 .53029 L

.95632 .53054 L

.9549 .53079 L

.95348 .53105 L

.95206 .5313 L

.95064 .53155 L

.94922 .53181 L

.9478 .53206 L

.94638 .53232 L

.94496 .53257 L

.94355 .53283 L

.94213 .53308 L

.94071 .53334 L

.93929 .53359 L

.93787 .53385 L

.93645 .5341 L

.93503 .53436 L

.93361 .53462 L

.93219 .53488 L

.93077 .53513 L

.92935 .53539 L

.92793 .53565 L

.92651 .53591 L

.92509 .53617 L

.92367 .53643 L

.92226 .53668 L

.92084 .53694 L

.91942 .5372 L

.918 .53746 L

.91658 .53772 L

.91516 .53798 L

.91374 .53824 L

.91232 .53851 L

.9109 .53877 L

.90948 .53903 L

.90806 .53929 L

.90664 .53955 L

Mistroke

.90522 .53981 L

.9038 .54008 L

.90238 .54034 L

.90097 .5406 L

.89955 .54087 L

.89813 .54113 L

.89671 .54139 L

.89529 .54166 L

.89387 .54192 L

.89245 .54218 L

.89103 .54245 L

.88961 .54271 L

.88819 .54298 L

.88677 .54324 L

.88535 .54351 L

.88393 .54377 L

.88251 .54404 L

.88109 .5443 L

.87967 .54457 L

.87826 .54483 L

.87684 .5451 L

.87542 .54537 L

.874 .54563 L

.87258 .5459 L

.87116 .54616 L

.86974 .54643 L

.86832 .5467 L

.8669 .54696 L

.86548 .54723 L

.86406 .5475 L

.86264 .54776 L

.86122 .54803 L

.8598 .54829 L

.85838 .54856 L

.85697 .54883 L

.85555 .54909 L

.85413 .54936 L

.85271 .54963 L

.85129 .54989 L

.84987 .55016 L

.84845 .55042 L

.84703 .55069 L

.84561 .55095 L

.84419 .55121 L

.84277 .55148 L

.84135 .55174 L

.83993 .552 L

.83851 .55227 L

.83709 .55253 L

.83568 .55279 L

Mistroke

.83426 .55305 L

.83284 .55331 L

.83142 .55357 L

.83 .55382 L

.82858 .55408 L

.82716 .55433 L

.82574 .55458 L

.82432 .55483 L

.8229 .55508 L

.82148 .55533 L

.82006 .55557 L

.81864 .55581 L

.81722 .55605 L

.8158 .55628 L

.81439 .5565 L

.81297 .55672 L

.81155 .55694 L

.81013 .55714 L

.80871 .55733 L

.80729 .55752 L

.80587 .55768 L

.80445 .55783 L

.80303 .55795 L

.80161 .55803 L

.80019 .55807 L

.79877 .55801 L

.79735 .55778 L

.79593 .55704 L

Mfstroke

.97619 .091 m

.97477 .09075 L

.97335 .0905 L

.97193 .09025 L

.97051 .09 L

.96909 .08975 L

.96767 .0895 L

.96626 .08925 L

.96484 .089 L

.96342 .08875 L

.962 .0885 L

.96058 .08825 L

.95916 .088 L

.95774 .08775 L

.95632 .08749 L

.9549 .08724 L

.95348 .08699 L

.95206 .08673 L

.95064 .08648 L

.94922 .08623 L

.9478 .08597 L

.94638 .08572 L

.94496 .08546 L

.94355 .08521 L

.94213 .08495 L

.94071 .0847 L

.93929 .08444 L

.93787 .08419 L

.93645 .08393 L

.93503 .08367 L

.93361 .08342 L

.93219 .08316 L

.93077 .0829 L

.92935 .08264 L

.92793 .08238 L

.92651 .08213 L

.92509 .08187 L

.92367 .08161 L

.92226 .08135 L

.92084 .08109 L

.91942 .08083 L

.918 .08057 L

.91658 .08031 L

.91516 .08005 L

.91374 .07979 L

.91232 .07953 L

.9109 .07927 L

.90948 .07901 L

.90806 .07874 L

.90664 .07848 L

Mistroke

.90522 .07822 L

.9038 .07796 L

.90238 .07769 L

.90097 .07743 L

.89955 .07717 L

.89813 .07691 L

.89671 .07664 L

.89529 .07638 L

.89387 .07611 L

.89245 .07585 L

.89103 .07559 L

.88961 .07532 L

.88819 .07506 L

.88677 .07479 L

.88535 .07453 L

.88393 .07426 L

.88251 .074 L

.88109 .07373 L

.87967 .07347 L

.87826 .0732 L

.87684 .07293 L

.87542 .07267 L

.874 .0724 L

.87258 .07214 L

.87116 .07187 L

.86974 .0716 L

.86832 .07134 L

.8669 .07107 L

.86548 .0708 L

.86406 .07054 L

.86264 .07027 L

.86122 .07001 L

.8598 .06974 L

.85838 .06947 L

.85697 .06921 L

.85555 .06894 L

.85413 .06867 L

.85271 .06841 L

.85129 .06814 L

.84987 .06788 L

.84845 .06761 L

.84703 .06735 L

.84561 .06708 L

.84419 .06682 L

.84277 .06656 L

.84135 .06629 L

.83993 .06603 L

.83851 .06577 L

.83709 .0655 L

.83568 .06524 L

Mistroke

.83426 .06499 L

.83284 .06473 L

.83142 .06447 L

.83 .06421 L

.82858 .06395 L

.82716 .0637 L

.82574 .06345 L

.82432 .0632 L

.8229 .06295 L

.82148 .06271 L

.82006 .06246 L

.81864 .06223 L

.81722 .06199 L

.8158 .06176 L

.81439 .06153 L

.81297 .06131 L

.81155 .0611 L

.81013 .06089 L

.80871 .0607 L

.80729 .06052 L

.80587 .06035 L

.80445 .0602 L

.80303 .06008 L

.80161 .06 L

.80019 .05997 L

.79877 .06003 L

.79735 .06025 L

.79593 .06099 L

Mfstroke

.84533 .46188 m

.84504 .46279 L

.84476 .46368 L

.84448 .46457 L

.84419 .46544 L

.84391 .46631 L

.84362 .46716 L

.84334 .468 L

.84306 .46884 L

.84277 .46966 L

.84249 .47048 L

.8422 .47129 L

.84192 .47209 L

.84164 .47288 L

.84135 .47367 L

.84107 .47444 L

.84078 .47521 L

.8405 .47597 L

.84022 .47673 L

.83993 .47747 L

.83965 .47822 L

.83937 .47895 L

.83908 .47968 L

.8388 .4804 L

.83851 .48112 L

.83823 .48183 L

.83795 .48253 L

.83766 .48323 L

.83738 .48392 L

.83709 .48461 L

.83681 .4853 L

.83653 .48597 L

.83624 .48665 L

.83596 .48731 L

.83568 .48798 L

.83539 .48863 L

.83511 .48929 L

.83482 .48994 L

.83454 .49058 L

.83426 .49122 L

.83397 .49185 L

.83369 .49249 L

.8334 .49311 L

.83312 .49373 L

.83284 .49435 L

.83255 .49496 L

.83227 .49557 L

.83198 .49618 L

.8317 .49678 L

.83142 .49738 L

Mistroke

.83113 .49797 L

.83085 .49856 L

.83057 .49915 L

.83028 .49974 L

.83 .50032 L

.82971 .5009 L

.82943 .50146 L

.82915 .50203 L

.82886 .5026 L

.82858 .50316 L

.82829 .50373 L

.82801 .50428 L

.82773 .50483 L

.82744 .50538 L

.82716 .50593 L

.82688 .50647 L

.82659 .50701 L

.82631 .50755 L

.82602 .50809 L

.82574 .50862 L

.82546 .50914 L

.82517 .50967 L

.82489 .51019 L

.8246 .51071 L

.82432 .51123 L

.82404 .51174 L

.82375 .51226 L

.82347 .51276 L

.82319 .51327 L

.8229 .51377 L

.82262 .51428 L

.82233 .51477 L

.82205 .51527 L

.82177 .51576 L

.82148 .51625 L

.8212 .51674 L

.82091 .51722 L

.82063 .51771 L

.82035 .51819 L

.82006 .51867 L

.81978 .51915 L

.81949 .51962 L

.81921 .52009 L

.81893 .52056 L

.81864 .52103 L

.81836 .52149 L

.81808 .52195 L

.81779 .52241 L

.81751 .52287 L

.81722 .52332 L

Mistroke

.81694 .52378 L

.81666 .52423 L

.81637 .52468 L

.81609 .52513 L

.8158 .52557 L

.81552 .52601 L

.81524 .52646 L

.81495 .5269 L

.81467 .52734 L

.81439 .52777 L

.8141 .5282 L

.81382 .52863 L

.81353 .52906 L

.81325 .52949 L

.81297 .52992 L

.81268 .53034 L

.8124 .53076 L

.81211 .53118 L

.81183 .5316 L

.81155 .53202 L

.81126 .53244 L

.81098 .53285 L

.81069 .53326 L

.81041 .53368 L

.81013 .53408 L

.80984 .53449 L

.80956 .53489 L

.80928 .5353 L

.80899 .5357 L

.80871 .5361 L

.80842 .5365 L

.80814 .5369 L

.80786 .5373 L

.80757 .5377 L

.80729 .53809 L

.807 .53849 L

.80672 .53888 L

.80644 .53927 L

.80615 .53966 L

.80587 .54005 L

.80559 .54044 L

.8053 .54082 L

.80502 .5412 L

.80473 .54159 L

.80445 .54198 L

.80417 .54236 L

.80388 .54274 L

.8036 .54312 L

.80331 .54351 L

.80303 .54389 L

Mistroke

.80275 .54427 L

.80246 .54465 L

.80218 .54503 L

.80189 .54541 L

.80161 .54579 L

.80133 .54618 L

.80104 .54656 L

.80076 .54694 L

.80048 .54732 L

.80019 .54771 L

.79991 .5481 L

.79962 .54848 L

.79934 .54888 L

.79906 .54928 L

.79877 .54967 L

.79849 .55007 L

.7982 .55048 L

.79792 .5509 L

.79764 .55132 L

.79735 .55176 L

.79707 .55221 L

.79679 .55268 L

.7965 .55317 L

.79622 .55371 L

.79593 .55432 L

.79565 .55516 L

Mfstroke

.84533 .15615 m

.84504 .15524 L

.84476 .15435 L

.84448 .15346 L

.84419 .15259 L

.84391 .15173 L

.84362 .15088 L

.84334 .15003 L

.84306 .1492 L

.84277 .14837 L

.84249 .14755 L

.8422 .14675 L

.84192 .14594 L

.84164 .14515 L

.84135 .14437 L

.84107 .14359 L

.84078 .14283 L

.8405 .14206 L

.84022 .14131 L

.83993 .14056 L

.83965 .13981 L

.83937 .13909 L

.83908 .13835 L

.8388 .13763 L

.83851 .13691 L

.83823 .1362 L

.83795 .1355 L

.83766 .1348 L

.83738 .13411 L

.83709 .13342 L

.83681 .13274 L

.83653 .13206 L

.83624 .13139 L

.83596 .13072 L

.83568 .13005 L

.83539 .1294 L

.83511 .12875 L

.83482 .12809 L

.83454 .12745 L

.83426 .12682 L

.83397 .12618 L

.83369 .12555 L

.8334 .12492 L

.83312 .1243 L

.83284 .12368 L

.83255 .12307 L

.83227 .12246 L

.83198 .12185 L

.8317 .12125 L

.83142 .12065 L

Mistroke

.83113 .12006 L

.83085 .11947 L

.83057 .11888 L

.83028 .11829 L

.83 .11772 L

.82971 .11714 L

.82943 .11657 L

.82915 .116 L

.82886 .11544 L

.82858 .11487 L

.82829 .11431 L

.82801 .11376 L

.82773 .1132 L

.82744 .11265 L

.82716 .11211 L

.82688 .11156 L

.82659 .11102 L

.82631 .11049 L

.82602 .10995 L

.82574 .10942 L

.82546 .10889 L

.82517 .10837 L

.82489 .10784 L

.8246 .10732 L

.82432 .10681 L

.82404 .10629 L

.82375 .10578 L

.82347 .10527 L

.82319 .10476 L

.8229 .10426 L

.82262 .10376 L

.82233 .10326 L

.82205 .10277 L

.82177 .10227 L

.82148 .10179 L

.8212 .10129 L

.82091 .10081 L

.82063 .10032 L

.82035 .09985 L

.82006 .09937 L

.81978 .09889 L

.81949 .09841 L

.81921 .09794 L

.81893 .09747 L

.81864 .09701 L

.81836 .09654 L

.81808 .09608 L

.81779 .09562 L

.81751 .09516 L

.81722 .09471 L

Mistroke

.81694 .09426 L

.81666 .0938 L

.81637 .09335 L

.81609 .0929 L

.8158 .09246 L

.81552 .09202 L

.81524 .09158 L

.81495 .09114 L

.81467 .0907 L

.81439 .09026 L

.8141 .08983 L

.81382 .0894 L

.81353 .08897 L

.81325 .08854 L

.81297 .08812 L

.81268 .08769 L

.8124 .08727 L

.81211 .08685 L

.81183 .08643 L

.81155 .08601 L

.81126 .0856 L

.81098 .08518 L

.81069 .08477 L

.81041 .08436 L

.81013 .08395 L

.80984 .08355 L

.80956 .08314 L

.80928 .08274 L

.80899 .08233 L

.80871 .08193 L

.80842 .08153 L

.80814 .08113 L

.80786 .08073 L

.80757 .08033 L

.80729 .07994 L

.807 .07955 L

.80672 .07915 L

.80644 .07876 L

.80615 .07837 L

.80587 .07798 L

.80559 .0776 L

.8053 .07721 L

.80502 .07683 L

.80473 .07644 L

.80445 .07606 L

.80417 .07567 L

.80388 .07529 L

.8036 .07491 L

.80331 .07453 L

.80303 .07415 L

Mistroke

.80275 .07377 L

.80246 .07338 L

.80218 .073 L

.80189 .07262 L

.80161 .07224 L

.80133 .07186 L

.80104 .07148 L

.80076 .07109 L

.80048 .07071 L

.80019 .07032 L

.79991 .06994 L

.79962 .06955 L

.79934 .06916 L

.79906 .06876 L

.79877 .06836 L

.79849 .06796 L

.7982 .06755 L

.79792 .06714 L

.79764 .06671 L

.79735 .06627 L

.79707 .06583 L

.79679 .06535 L

.7965 .06486 L

.79622 .06433 L

.79593 .06371 L

.79565 .06287 L

Mfstroke

.84575 .4605 m

.84589 .46004 L

.84604 .45957 L

.84618 .45909 L

.84632 .45862 L

.84646 .45813 L

.8466 .45765 L

.84675 .45717 L

.84689 .45667 L

.84703 .45619 L

.84717 .45569 L

.84731 .45519 L

.84746 .45467 L

.8476 .45416 L

.84774 .45366 L

.84788 .45314 L

.84802 .4526 L

.84817 .45209 L

.84831 .45155 L

.84845 .45102 L

.84859 .45047 L

.84873 .44993 L

.84888 .44937 L

.84902 .44881 L

.84916 .44824 L

.8493 .44768 L

.84944 .44711 L

.84958 .44653 L

.84973 .44594 L

.84987 .44534 L

.85001 .44475 L

.85015 .44413 L

.85029 .44352 L

.85044 .4429 L

.85058 .44226 L

.85072 .44163 L

.85086 .44097 L

.851 .44031 L

.85115 .43965 L

.85129 .43897 L

.85143 .43828 L

.85157 .43759 L

.85171 .43688 L

.85186 .43616 L

.852 .43542 L

.85214 .43469 L

.85228 .43392 L

.85242 .43315 L

.85257 .43236 L

.85271 .43156 L

Mistroke

.85285 .43073 L

.85299 .42987 L

.85313 .429 L

.85328 .42811 L

.85342 .4272 L

.85356 .42626 L

.8537 .42529 L

.85384 .4243 L

.85398 .42325 L

.85413 .42217 L

.85427 .42103 L

.85441 .41984 L

.85455 .4186 L

.85469 .41726 L

.85484 .41585 L

.85498 .41431 L

.85512 .41265 L

.85526 .41072 L

.8554 .4085 L

.85555 .40573 L

.85569 .40093 L

Mfstroke

.84575 .15753 m

.84589 .158 L

.84604 .15847 L

.84618 .15894 L

.84632 .15941 L

.84646 .1599 L

.8466 .16038 L

.84675 .16087 L

.84689 .16136 L

.84703 .16185 L

.84717 .16234 L

.84731 .16285 L

.84746 .16336 L

.8476 .16387 L

.84774 .16438 L

.84788 .1649 L

.84802 .16543 L

.84817 .16595 L

.84831 .16648 L

.84845 .16702 L

.84859 .16756 L

.84873 .16811 L

.84888 .16867 L

.84902 .16923 L

.84916 .16979 L

.8493 .17036 L

.84944 .17092 L

.84958 .17151 L

.84973 .17209 L

.84987 .1727 L

.85001 .17329 L

.85015 .1739 L

.85029 .17451 L

.85044 .17513 L

.85058 .17578 L

.85072 .17641 L

.85086 .17706 L

.851 .17772 L

.85115 .17839 L

.85129 .17906 L

.85143 .17975 L

.85157 .18045 L

.85171 .18116 L

.85186 .18187 L

.852 .18261 L

.85214 .18334 L

.85228 .18411 L

.85242 .18489 L

.85257 .18568 L

.85271 .18647 L

Mistroke

.85285 .18731 L

.85299 .18816 L

.85313 .18903 L

.85328 .18992 L

.85342 .19083 L

.85356 .19177 L

.8537 .19274 L

.85384 .19374 L

.85398 .19478 L

.85413 .19586 L

.85427 .197 L

.85441 .19819 L

.85455 .19943 L

.85469 .20077 L

.85484 .20218 L

.85498 .20372 L

.85512 .20539 L

.85526 .20731 L

.8554 .20953 L

.85555 .2123 L

.85569 .2171 L

Mfstroke

.8554 .38791 m

.85526 .38581 L

.85512 .384 L

.85498 .38244 L

.85484 .38102 L

.85469 .37972 L

.85455 .37851 L

.85441 .37738 L

.85427 .37631 L

.85413 .3753 L

.85129 .36075 L

.84845 .3509 L

.84561 .34306 L

.84277 .33639 L

.83993 .33054 L

.83709 .32527 L

.83426 .32047 L

.83142 .31602 L

.82858 .31188 L

.82574 .30799 L

.8229 .30431 L

.82006 .30082 L

.81722 .2975 L

.81439 .29431 L

.81155 .29126 L

.80871 .28832 L

.80587 .28548 L

.80303 .28274 L

.80019 .28009 L

.79735 .27751 L

.79451 .275 L

.79168 .27256 L

.78884 .27019 L

.786 .26787 L

.78316 .2656 L

.78032 .26338 L

.77748 .26121 L

.77464 .25908 L

.7718 .25698 L

.76897 .25493 L

.76613 .25292 L

.76329 .25093 L

.76045 .24898 L

.75761 .24706 L

.75477 .24516 L

.75193 .2433 L

.7491 .24145 L

.74626 .23964 L

.74342 .23784 L

.74058 .23607 L

Mistroke

.73774 .23431 L

.7349 .23258 L

.73206 .23086 L

.72922 .22917 L

.72639 .22749 L

.72355 .22582 L

.72071 .22418 L

.71787 .22254 L

.71503 .22092 L

.71219 .21932 L

.70935 .21773 L

.70651 .21615 L

.70368 .21458 L

.70084 .21303 L

.698 .21148 L

.69516 .20995 L

.69232 .20843 L

.68948 .20692 L

.68664 .20542 L

.68381 .20393 L

.68097 .20244 L

.67813 .20097 L

.67529 .19951 L

.67245 .19805 L

.66961 .19661 L

.66677 .19517 L

.66393 .19374 L

.6611 .19232 L

.65826 .1909 L

.65542 .1895 L

.65258 .1881 L

.64974 .18671 L

.6469 .18533 L

.64406 .18396 L

.64122 .18259 L

.63839 .18123 L

.63555 .17988 L

.63271 .17853 L

.62987 .1772 L

.62703 .17587 L

.62419 .17455 L

.62135 .17323 L

.61852 .17192 L

.61568 .17062 L

.61284 .16933 L

.61 .16805 L

.60716 .16677 L

.60432 .1655 L

.60148 .16423 L

.59864 .16298 L

Mistroke

.59581 .16173 L

.59297 .16049 L

.59013 .15926 L

.58729 .15803 L

.58445 .15681 L

.58161 .1556 L

.57877 .1544 L

.57593 .1532 L

.5731 .15202 L

.57026 .15083 L

.56742 .14966 L

.56458 .14849 L

.56174 .14734 L

.5589 .14618 L

.55606 .14504 L

.55323 .1439 L

.55039 .14277 L

.54755 .14165 L

.54471 .14053 L

.54187 .13943 L

.53903 .13832 L

.53619 .13723 L

.53335 .13614 L

.53052 .13506 L

.52768 .13399 L

.52484 .13292 L

.522 .13186 L

.51916 .1308 L

.51632 .12976 L

.51348 .12871 L

.51065 .12768 L

.50781 .12665 L

.50497 .12563 L

.50213 .12461 L

.49929 .1236 L

.49645 .1226 L

.49361 .1216 L

.49077 .12061 L

.48794 .11962 L

.4851 .11864 L

.48226 .11766 L

.47942 .11669 L

.47658 .11573 L

.47374 .11477 L

.4709 .11382 L

.46806 .11287 L

.46523 .11193 L

.46239 .11099 L

.45955 .11006 L

.45671 .10913 L

Mistroke

.45387 .10821 L

.45103 .1073 L

.44819 .10638 L

.44536 .10548 L

.44252 .10458 L

.43968 .10368 L

.43684 .10279 L

.434 .10191 L

.43116 .10103 L

.42832 .10016 L

.42548 .09929 L

.42265 .09842 L

.41981 .09756 L

.41697 .09671 L

.41413 .09586 L

.41129 .09502 L

.40845 .09418 L

.40561 .09335 L

.40277 .09252 L

.39994 .0917 L

.3971 .09088 L

.39426 .09007 L

.39142 .08927 L

.38858 .08847 L

.38574 .08767 L

.3829 .08689 L

.38007 .08611 L

.37723 .08533 L

.37439 .08456 L

.37155 .0838 L

.36871 .08304 L

.36587 .08229 L

.36303 .08155 L

.36019 .08081 L

.35736 .08008 L

.35452 .07936 L

.35168 .07864 L

.34884 .07793 L

.346 .07723 L

.34316 .07653 L

.34032 .07585 L

.33748 .07517 L

.33465 .0745 L

.33181 .07384 L

.32897 .07318 L

.32613 .07254 L

.32329 .0719 L

.32045 .07127 L

.31761 .07066 L

.31478 .07005 L

Mistroke

.31194 .06945 L

.3091 .06886 L

.30626 .06828 L

.30342 .06772 L

.30058 .06716 L

.29774 .06662 L

.2949 .06608 L

.29207 .06556 L

.28923 .06505 L

.28639 .06455 L

.28355 .06407 L

.28071 .0636 L

.27787 .06314 L

.27503 .06269 L

.2722 .06226 L

.26936 .06185 L

.26652 .06145 L

.26368 .06106 L

.26084 .06069 L

.258 .06034 L

.25516 .06001 L

.25232 .05969 L

.24949 .05939 L

.24665 .05911 L

.24381 .05885 L

.24097 .0586 L

.23813 .05838 L

.23529 .05818 L

.23245 .058 L

.22961 .05784 L

.22678 .05771 L

.22394 .0576 L

.2211 .05751 L

.21826 .05745 L

.21542 .05741 L

.21258 .0574 L

.20974 .05742 L

.20691 .05747 L

.20407 .05755 L

.20123 .05765 L

.19839 .05779 L

.19555 .05796 L

.19271 .05816 L

.18987 .0584 L

.18703 .05867 L

.1842 .05898 L

.18136 .05933 L

.17852 .05971 L

.17568 .06014 L

.17284 .06061 L

Mistroke

.17 .06113 L

.16716 .06168 L

.16432 .06229 L

.16149 .06294 L

.15865 .06364 L

.15581 .0644 L

.15297 .06521 L

.15013 .06607 L

.14729 .067 L

.14445 .06798 L

.14162 .06902 L

.13878 .07013 L

.13594 .07131 L

.1331 .07256 L

.13026 .07388 L

.12742 .07528 L

.12458 .07675 L

.12174 .07831 L

.11891 .07996 L

.11607 .0817 L

.11323 .08353 L

.11039 .08546 L

.10755 .0875 L

.10471 .08964 L

.10187 .0919 L

.09903 .09428 L

.0962 .09679 L

.09336 .09943 L

.09052 .10222 L

.08768 .10515 L

.08484 .10825 L

.082 .11152 L

.07916 .11497 L

.07633 .11862 L

.07349 .12247 L

.07065 .12656 L

.06781 .13089 L

.06497 .13548 L

.06213 .14038 L

.05929 .1456 L

.05645 .15117 L

.05362 .15716 L

.05078 .1636 L

.04794 .17057 L

.0451 .17817 L

.04226 .1865 L

.03942 .19574 L

.03658 .20615 L

.03374 .21811 L

.03091 .23239 L

Mistroke

.02807 .25066 L

.02381 .30902 L

Mfstroke

.8554 .23012 m

.85526 .23223 L

.85512 .23403 L

.85498 .2356 L

.85484 .23701 L

.85469 .23832 L

.85455 .23952 L

.85441 .24066 L

.85427 .24173 L

.85413 .24273 L

.85129 .25729 L

.84845 .26713 L

.84561 .27498 L

.84277 .28164 L

.83993 .28749 L

.83709 .29276 L

.83426 .29757 L

.83142 .30201 L

.82858 .30616 L

.82574 .31005 L

.8229 .31372 L

.82006 .31721 L

.81722 .32054 L

.81439 .32372 L

.81155 .32677 L

.80871 .32971 L

.80587 .33255 L

.80303 .33529 L

.80019 .33795 L

.79735 .34052 L

.79451 .34303 L

.79168 .34547 L

.78884 .34785 L

.786 .35017 L

.78316 .35244 L

.78032 .35466 L

.77748 .35683 L

.77464 .35896 L

.7718 .36105 L

.76897 .3631 L

.76613 .36512 L

.76329 .3671 L

.76045 .36905 L

.75761 .37098 L

.75477 .37287 L

.75193 .37474 L

.7491 .37658 L

.74626 .3784 L

.74342 .38019 L

.74058 .38197 L

Mistroke

.73774 .38372 L

.7349 .38545 L

.73206 .38717 L

.72922 .38887 L

.72639 .39055 L

.72355 .39221 L

.72071 .39386 L

.71787 .39549 L

.71503 .39711 L

.71219 .39871 L

.70935 .40031 L

.70651 .40189 L

.70368 .40345 L

.70084 .40501 L

.698 .40655 L

.69516 .40808 L

.69232 .40961 L

.68948 .41112 L

.68664 .41262 L

.68381 .41411 L

.68097 .41559 L

.67813 .41706 L

.67529 .41853 L

.67245 .41998 L

.66961 .42143 L

.66677 .42287 L

.66393 .4243 L

.6611 .42572 L

.65826 .42713 L

.65542 .42853 L

.65258 .42993 L

.64974 .43132 L

.6469 .4327 L

.64406 .43408 L

.64122 .43544 L

.63839 .4368 L

.63555 .43816 L

.63271 .4395 L

.62987 .44084 L

.62703 .44217 L

.62419 .44349 L

.62135 .4448 L

.61852 .44611 L

.61568 .44741 L

.61284 .4487 L

.61 .44999 L

.60716 .45127 L

.60432 .45254 L

.60148 .4538 L

.59864 .45505 L

Mistroke

.59581 .4563 L

.59297 .45754 L

.59013 .45878 L

.58729 .46 L

.58445 .46122 L

.58161 .46243 L

.57877 .46363 L

.57593 .46483 L

.5731 .46602 L

.57026 .4672 L

.56742 .46837 L

.56458 .46954 L

.56174 .4707 L

.5589 .47185 L

.55606 .47299 L

.55323 .47413 L

.55039 .47526 L

.54755 .47638 L

.54471 .4775 L

.54187 .47861 L

.53903 .47971 L

.53619 .4808 L

.53335 .48189 L

.53052 .48297 L

.52768 .48405 L

.52484 .48511 L

.522 .48618 L

.51916 .48723 L

.51632 .48828 L

.51348 .48932 L

.51065 .49035 L

.50781 .49138 L

.50497 .49241 L

.50213 .49342 L

.49929 .49443 L

.49645 .49544 L

.49361 .49644 L

.49077 .49743 L

.48794 .49841 L

.4851 .4994 L

.48226 .50037 L

.47942 .50134 L

.47658 .50231 L

.47374 .50326 L

.4709 .50422 L

.46806 .50516 L

.46523 .50611 L

.46239 .50704 L

.45955 .50798 L

.45671 .5089 L

Mistroke

.45387 .50982 L

.45103 .51074 L

.44819 .51165 L

.44536 .51255 L

.44252 .51346 L

.43968 .51435 L

.43684 .51524 L

.434 .51612 L

.43116 .517 L

.42832 .51788 L

.42548 .51875 L

.42265 .51961 L

.41981 .52047 L

.41697 .52132 L

.41413 .52217 L

.41129 .52302 L

.40845 .52385 L

.40561 .52469 L

.40277 .52551 L

.39994 .52634 L

.3971 .52715 L

.39426 .52796 L

.39142 .52877 L

.38858 .52957 L

.38574 .53036 L

.3829 .53115 L

.38007 .53193 L

.37723 .5327 L

.37439 .53347 L

.37155 .53424 L

.36871 .53499 L

.36587 .53574 L

.36303 .53649 L

.36019 .53723 L

.35736 .53796 L

.35452 .53868 L

.35168 .5394 L

.34884 .5401 L

.346 .54081 L

.34316 .5415 L

.34032 .54219 L

.33748 .54286 L

.33465 .54354 L

.33181 .5442 L

.32897 .54485 L

.32613 .54549 L

.32329 .54613 L

.32045 .54676 L

.31761 .54738 L

.31478 .54798 L

Mistroke

.31194 .54858 L

.3091 .54917 L

.30626 .54975 L

.30342 .55032 L

.30058 .55087 L

.29774 .55142 L

.2949 .55195 L

.29207 .55247 L

.28923 .55299 L

.28639 .55348 L

.28355 .55397 L

.28071 .55444 L

.27787 .5549 L

.27503 .55534 L

.2722 .55577 L

.26936 .55619 L

.26652 .55659 L

.26368 .55697 L

.26084 .55734 L

.258 .55769 L

.25516 .55803 L

.25232 .55834 L

.24949 .55864 L

.24665 .55893 L

.24381 .55919 L

.24097 .55943 L

.23813 .55965 L

.23529 .55985 L

.23245 .56003 L

.22961 .56019 L

.22678 .56032 L

.22394 .56044 L

.2211 .56052 L

.21826 .56058 L

.21542 .56062 L

.21258 .56063 L

.20974 .56061 L

.20691 .56057 L

.20407 .56049 L

.20123 .56038 L

.19839 .56025 L

.19555 .56008 L

.19271 .55987 L

.18987 .55964 L

.18703 .55936 L

.1842 .55905 L

.18136 .55871 L

.17852 .55832 L

.17568 .55789 L

.17284 .55742 L

Mistroke

.17 .55691 L

.16716 .55635 L

.16432 .55575 L

.16149 .55509 L

.15865 .55439 L

.15581 .55363 L

.15297 .55283 L

.15013 .55196 L

.14729 .55104 L

.14445 .55006 L

.14162 .54901 L

.13878 .5479 L

.13594 .54672 L

.1331 .54548 L

.13026 .54415 L

.12742 .54276 L

.12458 .54128 L

.12174 .53972 L

.11891 .53807 L

.11607 .53634 L

.11323 .5345 L

.11039 .53257 L

.10755 .53054 L

.10471 .52839 L

.10187 .52613 L

.09903 .52375 L

.0962 .52124 L

.09336 .5186 L

.09052 .51582 L

.08768 .51288 L

.08484 .50978 L

.082 .50652 L

.07916 .50306 L

.07633 .49942 L

.07349 .49556 L

.07065 .49148 L

.06781 .48715 L

.06497 .48255 L

.06213 .47766 L

.05929 .47244 L

.05645 .46686 L

.05362 .46088 L

.05078 .45443 L

.04794 .44746 L

.0451 .43987 L

.04226 .43153 L

.03942 .42229 L

.03658 .41189 L

.03374 .39992 L

.03091 .38564 L

Mistroke

.02807 .36737 L

.02381 .30902 L

Mfstroke

0 .4 1 r

.97619 .42124 m

.97477 .42156 L

.97335 .42187 L

.97193 .42219 L

.97051 .4225 L

.96909 .42282 L

.96767 .42313 L

.96626 .42345 L

.96484 .42377 L

.96342 .42409 L

.962 .4244 L

.96058 .42472 L

.95916 .42504 L

.95774 .42537 L

.95632 .42569 L

.9549 .42601 L

.95348 .42633 L

.95206 .42665 L

.95064 .42698 L

.94922 .4273 L

.9478 .42763 L

.94638 .42795 L

.94496 .42828 L

.94355 .42861 L

.94213 .42894 L

.94071 .42926 L

.93929 .42959 L

.93787 .42992 L

.93645 .43026 L

.93503 .43059 L

.93361 .43092 L

.93219 .43125 L

.93077 .43159 L

.92935 .43192 L

.92793 .43226 L

.92651 .43259 L

.92509 .43293 L

.92367 .43327 L

.92226 .43361 L

.92084 .43395 L

.91942 .43429 L

.918 .43463 L

.91658 .43497 L

.91516 .43531 L

.91374 .43566 L

.91232 .436 L

.9109 .43635 L

.90948 .43669 L

.90806 .43704 L

.90664 .43739 L

Mistroke

.90522 .43774 L

.9038 .43809 L

.90238 .43844 L

.90097 .43879 L

.89955 .43914 L

.89813 .43949 L

.89671 .43985 L

.89529 .4402 L

.89387 .44056 L

.89245 .44092 L

.89103 .44128 L

.88961 .44164 L

.88819 .442 L

.88677 .44236 L

.88535 .44272 L

.88393 .44308 L

.88251 .44345 L

.88109 .44381 L

.87967 .44418 L

.87826 .44455 L

.87684 .44492 L

.87542 .44529 L

.874 .44566 L

.87258 .44603 L

.87116 .4464 L

.86974 .44678 L

.86832 .44716 L

.8669 .44753 L

.86548 .44791 L

.86406 .44829 L

.86264 .44867 L

.86122 .44905 L

.8598 .44944 L

.85838 .44982 L

.85697 .45021 L

.85555 .45059 L

.85413 .45098 L

.85271 .45137 L

.85129 .45176 L

.84987 .45216 L

.84845 .45255 L

.84703 .45295 L

.84561 .45334 L

.84419 .45374 L

.84277 .45414 L

.84135 .45454 L

.83993 .45495 L

.83851 .45535 L

.83709 .45576 L

.83568 .45617 L

Mistroke

.83426 .45658 L

.83284 .45699 L

.83142 .4574 L

.83 .45782 L

.82858 .45823 L

.82716 .45865 L

.82574 .45907 L

.82432 .45949 L

.8229 .45992 L

.82148 .46034 L

.82006 .46077 L

.81864 .4612 L

.81722 .46163 L

.8158 .46206 L

.81439 .4625 L

.81297 .46293 L

.81155 .46337 L

.81013 .46382 L

.80871 .46426 L

.80729 .46471 L

.80587 .46515 L

.80445 .46561 L

.80303 .46606 L

.80161 .46651 L

.80019 .46697 L

.79877 .46743 L

.79735 .46789 L

.79593 .46836 L

.79451 .46883 L

.79309 .4693 L

.79168 .46977 L

.79026 .47025 L

.78884 .47073 L

.78742 .47121 L

.786 .47169 L

.78458 .47218 L

.78316 .47267 L

.78174 .47317 L

.78032 .47366 L

.7789 .47416 L

.77748 .47467 L

.77606 .47517 L

.77464 .47569 L

.77322 .4762 L

.7718 .47672 L

.77039 .47724 L

.76897 .47776 L

.76755 .47829 L

.76613 .47883 L

.76471 .47936 L

Mistroke

.76329 .47991 L

.76187 .48045 L

.76045 .481 L

.75903 .48156 L

.75761 .48212 L

.75619 .48268 L

.75477 .48325 L

.75335 .48382 L

.75193 .4844 L

.75051 .48499 L

.7491 .48558 L

.74768 .48617 L

.74626 .48678 L

.74484 .48738 L

.74342 .488 L

.742 .48862 L

.74058 .48925 L

.73916 .48988 L

.73774 .49052 L

.73632 .49117 L

.7349 .49182 L

.73348 .49248 L

.73206 .49316 L

.73064 .49384 L

.72922 .49452 L

.7278 .49522 L

.72639 .49593 L

.72497 .49664 L

.72355 .49737 L

.72213 .4981 L

.72071 .49885 L

.71929 .49961 L

.71787 .50038 L

.71645 .50116 L

.71503 .50196 L

.71361 .50277 L

.71219 .50359 L

.71077 .50443 L

.70935 .50529 L

.70793 .50616 L

.70651 .50705 L

.7051 .50796 L

.70368 .50889 L

.70226 .50985 L

.70084 .51082 L

.69942 .51182 L

.698 .51285 L

.69658 .5139 L

.69516 .51499 L

.69374 .51611 L

Mistroke

.69232 .51727 L

.6909 .51847 L

.68948 .51972 L

.68806 .52101 L

.68664 .52237 L

.68522 .52379 L

.68381 .52529 L

.68239 .52687 L

.68097 .52857 L

.67955 .53039 L

.67813 .53239 L

.67671 .53461 L

.67529 .53715 L

.67387 .5402 L

.67245 .5443 L

Mfstroke

.97619 .19679 m

.97477 .19648 L

.97335 .19616 L

.97193 .19585 L

.97051 .19553 L

.96909 .19522 L

.96767 .1949 L

.96626 .19458 L

.96484 .19427 L

.96342 .19395 L

.962 .19363 L

.96058 .19331 L

.95916 .19299 L

.95774 .19267 L

.95632 .19235 L

.9549 .19203 L

.95348 .1917 L

.95206 .19138 L

.95064 .19106 L

.94922 .19073 L

.9478 .19041 L

.94638 .19008 L

.94496 .18975 L

.94355 .18943 L

.94213 .1891 L

.94071 .18877 L

.93929 .18844 L

.93787 .18811 L

.93645 .18778 L

.93503 .18745 L

.93361 .18711 L

.93219 .18678 L

.93077 .18645 L

.92935 .18611 L

.92793 .18578 L

.92651 .18544 L

.92509 .1851 L

.92367 .18477 L

.92226 .18443 L

.92084 .18409 L

.91942 .18375 L

.918 .18341 L

.91658 .18306 L

.91516 .18272 L

.91374 .18238 L

.91232 .18203 L

.9109 .18169 L

.90948 .18134 L

.90806 .18099 L

.90664 .18065 L

Mistroke

.90522 .1803 L

.9038 .17995 L

.90238 .1796 L

.90097 .17925 L

.89955 .17889 L

.89813 .17854 L

.89671 .17818 L

.89529 .17783 L

.89387 .17747 L

.89245 .17712 L

.89103 .17676 L

.88961 .1764 L

.88819 .17604 L

.88677 .17568 L

.88535 .17531 L

.88393 .17495 L

.88251 .17459 L

.88109 .17422 L

.87967 .17385 L

.87826 .17349 L

.87684 .17312 L

.87542 .17275 L

.874 .17238 L

.87258 .172 L

.87116 .17163 L

.86974 .17125 L

.86832 .17088 L

.8669 .1705 L

.86548 .17012 L

.86406 .16974 L

.86264 .16936 L

.86122 .16898 L

.8598 .1686 L

.85838 .16821 L

.85697 .16783 L

.85555 .16744 L

.85413 .16705 L

.85271 .16666 L

.85129 .16627 L

.84987 .16588 L

.84845 .16548 L

.84703 .16509 L

.84561 .16469 L

.84419 .16429 L

.84277 .16389 L

.84135 .16349 L

.83993 .16309 L

.83851 .16268 L

.83709 .16228 L

.83568 .16187 L

Mistroke

.83426 .16146 L

.83284 .16105 L

.83142 .16063 L

.83 .16022 L

.82858 .1598 L

.82716 .15938 L

.82574 .15896 L

.82432 .15854 L

.8229 .15812 L

.82148 .15769 L

.82006 .15727 L

.81864 .15684 L

.81722 .15641 L

.8158 .15597 L

.81439 .15554 L

.81297 .1551 L

.81155 .15466 L

.81013 .15422 L

.80871 .15377 L

.80729 .15333 L

.80587 .15288 L

.80445 .15243 L

.80303 .15198 L

.80161 .15152 L

.80019 .15106 L

.79877 .1506 L

.79735 .15014 L

.79593 .14967 L

.79451 .14921 L

.79309 .14874 L

.79168 .14826 L

.79026 .14779 L

.78884 .14731 L

.78742 .14683 L

.786 .14634 L

.78458 .14585 L

.78316 .14536 L

.78174 .14487 L

.78032 .14437 L

.7789 .14387 L

.77748 .14337 L

.77606 .14286 L

.77464 .14235 L

.77322 .14183 L

.7718 .14132 L

.77039 .14079 L

.76897 .14027 L

.76755 .13974 L

.76613 .13921 L

.76471 .13867 L

Mistroke

.76329 .13813 L

.76187 .13758 L

.76045 .13703 L

.75903 .13648 L

.75761 .13592 L

.75619 .13535 L

.75477 .13478 L

.75335 .13421 L

.75193 .13363 L

.75051 .13305 L

.7491 .13246 L

.74768 .13186 L

.74626 .13126 L

.74484 .13065 L

.74342 .13004 L

.742 .12942 L

.74058 .12879 L

.73916 .12816 L

.73774 .12752 L

.73632 .12687 L

.7349 .12621 L

.73348 .12555 L

.73206 .12488 L

.73064 .1242 L

.72922 .12351 L

.7278 .12281 L

.72639 .12211 L

.72497 .12139 L

.72355 .12067 L

.72213 .11993 L

.72071 .11918 L

.71929 .11842 L

.71787 .11765 L

.71645 .11687 L

.71503 .11607 L

.71361 .11526 L

.71219 .11444 L

.71077 .1136 L

.70935 .11274 L

.70793 .11187 L

.70651 .11098 L

.7051 .11007 L

.70368 .10914 L

.70226 .10819 L

.70084 .10721 L

.69942 .10621 L

.698 .10519 L

.69658 .10413 L

.69516 .10304 L

.69374 .10192 L

Mistroke

.69232 .10076 L

.6909 .09957 L

.68948 .09832 L

.68806 .09702 L

.68664 .09567 L

.68522 .09425 L

.68381 .09275 L

.68239 .09116 L

.68097 .08947 L

.67955 .08764 L

.67813 .08564 L

.67671 .08343 L

.67529 .08089 L

.67387 .07784 L

.67245 .07374 L

Mfstroke

.67607 .57269 m

.676 .57237 L

.67593 .57204 L

.67586 .57177 L

.67579 .5715 L

.67571 .57125 L

.67564 .57102 L

.67557 .57079 L

.6755 .57055 L

.67543 .57034 L

.67536 .57013 L

.67529 .56991 L

.67522 .56971 L

.67515 .5695 L

.67508 .5693 L

.67501 .56909 L

.67493 .56889 L

.67486 .56869 L

.67479 .56849 L

.67472 .56829 L

.67465 .5681 L

.67458 .56791 L

.67451 .56771 L

.67444 .56752 L

.67437 .56732 L

.6743 .56713 L

.67422 .56692 L

.67415 .56673 L

.67408 .56653 L

.67401 .56632 L

.67394 .56613 L

.67387 .56594 L

.6738 .56573 L

.67373 .56552 L

.67366 .56532 L

.67359 .56512 L

.67352 .56491 L

.67344 .56469 L

.67337 .56448 L

.6733 .56426 L

.67323 .56404 L

.67316 .56382 L

.67309 .56359 L

.67302 .56336 L

.67295 .56313 L

.67288 .56289 L

.67281 .56265 L

.67273 .56241 L

.67266 .56217 L

.67259 .5619 L

Mistroke

.67252 .56164 L

.67245 .56137 L

.67238 .56111 L

.67231 .56081 L

.67224 .56052 L

.67217 .56021 L

.6721 .55989 L

.67202 .55956 L

.67195 .55923 L

.67188 .55887 L

.67181 .55848 L

.67174 .55807 L

.67167 .55763 L

.6716 .55714 L

.67153 .55662 L

.67146 .55601 L

.67139 .55522 L

.67132 .55403 L

Mfstroke

.67607 .04534 m

.676 .04566 L

.67593 .04599 L

.67586 .04626 L

.67579 .04653 L

.67571 .04679 L

.67564 .04701 L

.67557 .04725 L

.6755 .04749 L

.67543 .04769 L

.67536 .04791 L

.67529 .04812 L

.67522 .04833 L

.67515 .04854 L

.67508 .04874 L

.67501 .04894 L

.67493 .04914 L

.67486 .04935 L

.67479 .04954 L

.67472 .04974 L

.67465 .04993 L

.67458 .05013 L

.67451 .05032 L

.67444 .05052 L

.67437 .05071 L

.6743 .05091 L

.67422 .05111 L

.67415 .0513 L

.67408 .0515 L

.67401 .05171 L

.67394 .05191 L

.67387 .0521 L

.6738 .0523 L

.67373 .05252 L

.67366 .05271 L

.67359 .05292 L

.67352 .05312 L

.67344 .05334 L

.67337 .05356 L

.6733 .05378 L

.67323 .054 L

.67316 .05422 L

.67309 .05444 L

.67302 .05467 L

.67295 .0549 L

.67288 .05514 L

.67281 .05538 L

.67273 .05563 L

.67266 .05586 L

.67259 .05613 L

Mistroke

.67252 .05639 L

.67245 .05667 L

.67238 .05693 L

.67231 .05723 L

.67224 .05752 L

.67217 .05783 L

.6721 .05814 L

.67202 .05847 L

.67195 .05881 L

.67188 .05917 L

.67181 .05956 L

.67174 .05997 L

.67167 .0604 L

.6716 .06089 L

.67153 .06142 L

.67146 .06202 L

.67139 .06282 L

.67132 .064 L

Mfstroke

.63186 .59084 m

.63242 .59073 L

.63299 .59062 L

.63356 .59051 L

.63413 .5904 L

.6347 .59029 L

.63526 .59018 L

.63583 .59006 L

.6364 .58995 L

.63697 .58984 L

.63753 .58972 L

.6381 .58961 L

.63867 .58949 L

.63924 .58938 L

.63981 .58926 L

.64037 .58915 L

.64094 .58903 L

.64151 .58891 L

.64208 .58879 L

.64264 .58867 L

.64321 .58855 L

.64378 .58843 L

.64435 .58831 L

.64492 .58819 L

.64548 .58807 L

.64605 .58794 L

.64662 .58782 L

.64719 .58769 L

.64775 .58757 L

.64832 .58744 L

.64889 .58731 L

.64946 .58718 L

.65002 .58705 L

.65059 .58692 L

.65116 .58679 L

.65173 .58666 L

.6523 .58653 L

.65286 .58639 L

.65343 .58625 L

.654 .58612 L

.65457 .58598 L

.65513 .58584 L

.6557 .5857 L

.65627 .58555 L

.65684 .58541 L

.65741 .58526 L

.65797 .58511 L

.65854 .58497 L

.65911 .58481 L

.65968 .58466 L

Mistroke

.66024 .5845 L

.66081 .58434 L

.66138 .58418 L

.66195 .58402 L

.66252 .58385 L

.66308 .58368 L

.66365 .5835 L

.66422 .58333 L

.66479 .58314 L

.66535 .58296 L

.66592 .58276 L

.66649 .58257 L

.66706 .58236 L

.66762 .58215 L

.66819 .58194 L

.66876 .58171 L

.66933 .58147 L

.6699 .58123 L

.67046 .58097 L

.67103 .5807 L

.6716 .5804 L

.67217 .58008 L

.67273 .57974 L

.6733 .57936 L

.67387 .57893 L

.67444 .57844 L

.67501 .57783 L

.67557 .57702 L

.67614 .57547 L

Mfstroke

.63186 .02719 m

.63242 .0273 L

.63299 .02741 L

.63356 .02752 L

.63413 .02763 L

.6347 .02775 L

.63526 .02786 L

.63583 .02797 L

.6364 .02808 L

.63697 .0282 L

.63753 .02831 L

.6381 .02842 L

.63867 .02854 L

.63924 .02866 L

.63981 .02877 L

.64037 .02889 L

.64094 .029 L

.64151 .02912 L

.64208 .02924 L

.64264 .02936 L

.64321 .02948 L

.64378 .0296 L

.64435 .02972 L

.64492 .02985 L

.64548 .02997 L

.64605 .03009 L

.64662 .03022 L

.64719 .03034 L

.64775 .03047 L

.64832 .03059 L

.64889 .03072 L

.64946 .03085 L

.65002 .03098 L

.65059 .03111 L

.65116 .03124 L

.65173 .03137 L

.6523 .03151 L

.65286 .03164 L

.65343 .03178 L

.654 .03192 L

.65457 .03205 L

.65513 .0322 L

.6557 .03234 L

.65627 .03248 L

.65684 .03262 L

.65741 .03277 L

.65797 .03292 L

.65854 .03307 L

.65911 .03322 L

.65968 .03338 L

Mistroke

.66024 .03353 L

.66081 .03369 L

.66138 .03385 L

.66195 .03402 L

.66252 .03419 L

.66308 .03436 L

.66365 .03453 L

.66422 .03471 L

.66479 .03489 L

.66535 .03508 L

.66592 .03527 L

.66649 .03547 L

.66706 .03567 L

.66762 .03588 L

.66819 .0361 L

.66876 .03632 L

.66933 .03656 L

.6699 .0368 L

.67046 .03706 L

.67103 .03734 L

.6716 .03764 L

.67217 .03795 L

.67273 .03829 L

.6733 .03868 L

.67387 .0391 L

.67444 .0396 L

.67501 .0402 L

.67557 .04102 L

.67614 .04257 L

Mfstroke

.62987 .59122 m

.62845 .59149 L

.62703 .59175 L

.62561 .59201 L

.62419 .59228 L

.62277 .59253 L

.62135 .59279 L

.61993 .59304 L

.61852 .59329 L

.6171 .59354 L

.61568 .59378 L

.61426 .59402 L

.61284 .59426 L

.61142 .5945 L

.61 .59474 L

.60858 .59497 L

.60716 .5952 L

.60574 .59543 L

.60432 .59565 L

.6029 .59588 L

.60148 .5961 L

.60006 .59632 L

.59864 .59653 L

.59723 .59675 L

.59581 .59696 L

.59439 .59717 L

.59297 .59737 L

.59155 .59758 L

.59013 .59778 L

.58871 .59797 L

.58729 .59817 L

.58587 .59836 L

.58445 .59855 L

.58303 .59874 L

.58161 .59893 L

.58019 .59911 L

.57877 .59929 L

.57735 .59946 L

.57593 .59963 L

.57452 .5998 L

.5731 .59997 L

.57168 .60013 L

.57026 .60029 L

.56884 .60045 L

.56742 .6006 L

.566 .60075 L

.56458 .6009 L

.56316 .60104 L

.56174 .60118 L

.56032 .60132 L

Mistroke

.5589 .60145 L

.55748 .60158 L

.55606 .6017 L

.55464 .60182 L

.55323 .60194 L

.55181 .60205 L

.55039 .60216 L

.54897 .60226 L

.54755 .60236 L

.54613 .60246 L

.54471 .60255 L

.54329 .60263 L

.54187 .60271 L

.54045 .60279 L

.53903 .60286 L

.53761 .60293 L

.53619 .60299 L

.53477 .60305 L

.53335 .6031 L

.53194 .60315 L

.53052 .60319 L

.5291 .60323 L

.52768 .60326 L

.52626 .60328 L

.52484 .6033 L

.52342 .60331 L

.522 .60332 L

.52058 .60332 L

.51916 .60331 L

.51774 .6033 L

.51632 .60328 L

.5149 .60326 L

.51348 .60322 L

.51206 .60318 L

.51065 .60314 L

.50923 .60309 L

.50781 .60302 L

.50639 .60295 L

.50497 .60288 L

.50355 .6028 L

.50213 .6027 L

.50071 .6026 L

.49929 .60249 L

.49787 .60238 L

.49645 .60225 L

.49503 .60212 L

.49361 .60197 L

.49219 .60182 L

.49077 .60166 L

.48935 .60149 L

Mistroke

.48794 .60131 L

.48652 .60111 L

.4851 .60091 L

.48368 .6007 L

.48226 .60048 L

.48084 .60025 L

.47942 .6 L

.478 .59975 L

.47658 .59948 L

.47516 .5992 L

.47374 .59891 L

.47232 .59861 L

.4709 .59829 L

.46948 .59796 L

.46806 .59762 L

.46665 .59727 L

.46523 .5969 L

.46381 .59652 L

.46239 .59612 L

.46097 .59571 L

.45955 .59528 L

.45813 .59484 L

.45671 .59439 L

.45529 .59391 L

.45387 .59342 L

.45245 .59292 L

.45103 .59239 L

.44961 .59185 L

.44819 .5913 L

.44677 .59072 L

.44536 .59013 L

.44394 .58952 L

.44252 .58888 L

.4411 .58823 L

.43968 .58756 L

.43826 .58687 L

.43684 .58615 L

.43542 .58541 L

.434 .58465 L

.43258 .58387 L

.43116 .58307 L

.42974 .58224 L

.42832 .58139 L

.4269 .58051 L

.42548 .5796 L

.42407 .57867 L

.42265 .57771 L

.42123 .57672 L

.41981 .57571 L

.41839 .57467 L

Mistroke

.41697 .57359 L

.41555 .57249 L

.41413 .57135 L

.41271 .57018 L

.41129 .56898 L

.40987 .56774 L

.40845 .56646 L

.40703 .56515 L

.40561 .5638 L

.40419 .56242 L

.40277 .56099 L

.40136 .55953 L

.39994 .55802 L

.39852 .55646 L

.3971 .55486 L

.39568 .55322 L

.39426 .55153 L

.39284 .54979 L

.39142 .54799 L

.39 .54615 L

.38858 .54425 L

.38716 .54229 L

.38574 .54027 L

.38432 .53819 L

.3829 .53605 L

.38148 .53384 L

.38007 .53157 L

.37865 .52922 L

.37723 .5268 L

.37581 .5243 L

.37439 .52171 L

.37297 .51905 L

.37155 .51629 L

.37013 .51344 L

.36871 .51049 L

.36729 .50744 L

.36587 .50428 L

.36445 .501 L

.36303 .4976 L

.36161 .49406 L

.36019 .49039 L

.35878 .48657 L

.35736 .48259 L

.35594 .47844 L

.35452 .4741 L

.3531 .46956 L

.35168 .4648 L

.35026 .4598 L

.34884 .45452 L

.34742 .44894 L

Mistroke

.346 .44302 L

.34458 .43671 L

.34316 .42995 L

.34174 .42265 L

.34032 .4147 L

.3389 .40595 L

.33748 .39613 L

.33607 .38485 L

.33465 .37131 L

.33323 .35348 L

.33178 .30902 L

Mfstroke

.62987 .02681 m

.62845 .02655 L

.62703 .02628 L

.62561 .02602 L

.62419 .02576 L

.62277 .0255 L

.62135 .02525 L

.61993 .025 L

.61852 .02475 L

.6171 .0245 L

.61568 .02425 L

.61426 .02401 L

.61284 .02377 L

.61142 .02353 L

.61 .0233 L

.60858 .02307 L

.60716 .02283 L

.60574 .0226 L

.60432 .02238 L

.6029 .02216 L

.60148 .02194 L

.60006 .02172 L

.59864 .0215 L

.59723 .02129 L

.59581 .02108 L

.59439 .02087 L

.59297 .02066 L

.59155 .02046 L

.59013 .02026 L

.58871 .02006 L

.58729 .01986 L

.58587 .01967 L

.58445 .01948 L

.58303 .01929 L

.58161 .01911 L

.58019 .01893 L

.57877 .01875 L

.57735 .01857 L

.57593 .0184 L

.57452 .01823 L

.5731 .01807 L

.57168 .0179 L

.57026 .01774 L

.56884 .01759 L

.56742 .01743 L

.566 .01728 L

.56458 .01714 L

.56316 .01699 L

.56174 .01685 L

.56032 .01672 L

Mistroke

.5589 .01659 L

.55748 .01646 L

.55606 .01633 L

.55464 .01621 L

.55323 .0161 L

.55181 .01599 L

.55039 .01588 L

.54897 .01577 L

.54755 .01567 L

.54613 .01558 L

.54471 .01549 L

.54329 .0154 L

.54187 .01532 L

.54045 .01524 L

.53903 .01517 L

.53761 .0151 L

.53619 .01504 L

.53477 .01498 L

.53335 .01493 L

.53194 .01489 L

.53052 .01484 L

.5291 .01481 L

.52768 .01478 L

.52626 .01475 L

.52484 .01474 L

.52342 .01472 L

.522 .01472 L

.52058 .01472 L

.51916 .01472 L

.51774 .01473 L

.51632 .01475 L

.5149 .01478 L

.51348 .01481 L

.51206 .01485 L

.51065 .0149 L

.50923 .01495 L

.50781 .01501 L

.50639 .01508 L

.50497 .01516 L

.50355 .01524 L

.50213 .01533 L

.50071 .01543 L

.49929 .01554 L

.49787 .01566 L

.49645 .01578 L

.49503 .01592 L

.49361 .01606 L

.49219 .01621 L

.49077 .01638 L

.48935 .01655 L

Mistroke

.48794 .01673 L

.48652 .01692 L

.4851 .01712 L

.48368 .01733 L

.48226 .01755 L

.48084 .01779 L

.47942 .01803 L

.478 .01829 L

.47658 .01855 L

.47516 .01883 L

.47374 .01912 L

.47232 .01943 L

.4709 .01974 L

.46948 .02007 L

.46806 .02041 L

.46665 .02077 L

.46523 .02114 L

.46381 .02152 L

.46239 .02191 L

.46097 .02233 L

.45955 .02275 L

.45813 .02319 L

.45671 .02365 L

.45529 .02412 L

.45387 .02461 L

.45245 .02512 L

.45103 .02564 L

.44961 .02618 L

.44819 .02674 L

.44677 .02731 L

.44536 .0279 L

.44394 .02852 L

.44252 .02915 L

.4411 .0298 L

.43968 .03048 L

.43826 .03117 L

.43684 .03188 L

.43542 .03262 L

.434 .03338 L

.43258 .03416 L

.43116 .03497 L

.42974 .03579 L

.42832 .03665 L

.4269 .03753 L

.42548 .03843 L

.42407 .03937 L

.42265 .04032 L

.42123 .04131 L

.41981 .04232 L

.41839 .04337 L

Mistroke

.41697 .04444 L

.41555 .04555 L

.41413 .04668 L

.41271 .04786 L

.41129 .04906 L

.40987 .0503 L

.40845 .05157 L

.40703 .05288 L

.40561 .05423 L

.40419 .05561 L

.40277 .05704 L

.40136 .05851 L

.39994 .06002 L

.39852 .06157 L

.3971 .06317 L

.39568 .06481 L

.39426 .0665 L

.39284 .06825 L

.39142 .07004 L

.39 .07189 L

.38858 .07379 L

.38716 .07575 L

.38574 .07776 L

.38432 .07984 L

.3829 .08198 L

.38148 .08419 L

.38007 .08647 L

.37865 .08882 L

.37723 .09124 L

.37581 .09374 L

.37439 .09632 L

.37297 .09899 L

.37155 .10174 L

.37013 .10459 L

.36871 .10754 L

.36729 .1106 L

.36587 .11376 L

.36445 .11704 L

.36303 .12044 L

.36161 .12397 L

.36019 .12764 L

.35878 .13146 L

.35736 .13544 L

.35594 .13959 L

.35452 .14393 L

.3531 .14847 L

.35168 .15323 L

.35026 .15824 L

.34884 .16351 L

.34742 .16909 L

Mistroke

.346 .17501 L

.34458 .18132 L

.34316 .18808 L

.34174 .19538 L

.34032 .20333 L

.3389 .21209 L

.33748 .2219 L

.33607 .23318 L

.33465 .24672 L

.33323 .26455 L

.33178 .30902 L

Mfstroke

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{567, 350.313},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.776525,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008g0001GPP10`40000100000800002008200000

P800P020P<30`<3L`:K:l00003<006H009T00<`00?l0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV

09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<003o03?o06Ko09Wo0<co

0?oo0000<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I

<c>I<fJI<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0

IYT0I/`0I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bI

I_nIIP3<IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0c

VC<cVFHcVITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<

VIW<VLc<VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`c

c?lcc01Vc3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03o

c3?oc6Koc9Woc<coc?ooc000oc<0ofH0oiT0ol`0ool0o`0coc<cofHcoiTcol`coolco`1Voc=VofIV

oiUVolaVoomVo`2Ioc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<o`3ooc?oofKooiWoolco

ooooo`0000410@820P<30`@410D51@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C

4a@D5?okl:2PY820P?l0003o0?oo0000ool0o`3oooooodkQ00<0hN40on7Wh@00C^400`3Qh@3ohNOQ

001>h@030>7Q0?oQin4004kQ00<0hN40on7Wh@00C^430?oQin4004kQ00<0hN40on7Wh@00C^400`3Q

h@3ohNOQ001>h@030>7Q0?oQin4004kQ00<0hN40_>4N__oQ3N4004kQ00<0hN40]N47_QkQ2kkoh@;Q

001>h@030>7Q0:oQ1[h_h@VnnN4004kQ00<0hN40[>44_SgQ1[kch@00C^400`3Qh@2Xh@BnAn46_^gQ

001>h@030>7Q0:GQ0kiAh@Jnin4004kQ00<0hN40Xn42_U[Q1[kQh@00C^400`3Qh@2Qh@:nHN46_]cQ

001>h@<0Wn42_VSQ1KkHh@00C^400`3Qh@2Lh@>nK^45_]CQ001>h@030>7Q09_Q0[ieh@Bnd>4004kQ

00<0hN40VN42_W[Q0kk>h@00C^400`3Qh@2Hh@:nON43_/cQ001>h@030>7Q09KQ0[j1h@:nbn4004kQ

00<0hN40UN42_X?Q00>nhN40bN4004kQ00<0hN40Tn42__oQD^4004kQ00<0hN40T^42_XKQ00>nhN40

bN4004kQ00<0hN40TN400kkQh@25h@:nbn4004kQ00<0hN40T>42_XOQ00>nhN40b^4004kQ00<0hN40

Sn400kkQh@27h@03_^7Q0<[Q001>h@<0S^400kkQh@27h@:nc>4004kQ00<0hN40SN400kkQh@28h@03

_^7Q0<_Q001>h@030>7Q01kQ6PmDh@03_^7Q08WQ00>nhN40bn4004kQ00<0hN405^483a[Q2Pm9h@03

_^7Q08[Q00>nhN40?^453hSQ001>h@030>7Q017Q1@l/h@L?@N400kkQh@2:h@03_^7Q03kQ00<?hN40

0n473h7Q001>h@030>7Q00kQ0`lhh@H?>^400kkQh@2;h@03_^7Q03kQ00<?hN402N473g_Q001>h@03

0>7Q00WQ1@m1h@H?<n400kkQh@3=h@8?4>463gKQ001>h@030>7Q00KQ0`m<h@D?;^400kkQh@3>h@03

3n7Q01?Q1Pmah@00C^400`3Qh@05h@033n7Q05;Q1PlVh@:ndN423a[Q1Pm[h@00C^400`3Qh@02h@<?

Fn443b;Q00>nhN40dN423akQ1PmVh@00?N4500;Q00<0hN401n400`3Q3`023f;Q10lMh@03_^7Q093Q

00>nhN40@>400`oQh@0Rh@D?HN4003oQ00L0hN7Q0>4000SQ0PmYh@<?6N400kkQh@2Ah@03_^7Q047Q

00<?hN409^453ecQ000ih@<00n401`3QhN40h@001n400`l0000206[Q1@lCh@03_^7Q09?Q00>nhN40

@>423bcQ1PmFh@00?n401`3QhN40h@001N423`03h@3Q077Q10l?h@03_^7Q09?Q00>nhN40@N423c7Q

1@mAh@00?n401`3QhN40h@001>401@oQhN4007KQ1@l:h@03_^7Q09?Q00>nhN40@^400`oQh@0dh@H?

Bn4003kQ0P04h@030>7Q00<?1>400`3Qh@1ih@8?1n400kkQh@2Eh@03_^7Q04;Q00<?hN40>N453dKQ

0016h@033n7Q00GQ00<0hN40Nn453`03hKkQ09OQ00>nhN40@^423coQ1Pm0h@00AN400`oQh@06h@03

0>7Q083Q00>n3`l0V>400kkQh@12h@033n7Q04?Q1@lkh@00A>400`oQh@07h@030>7Q083Q00>nhN40

10nEh@03_^7Q04;Q00<?hN40An463cGQ0013h@033n7Q00SQ00<0hN40On400kkQh@05h@<?T^42_T?Q

0Pm>h@D?<>40047Q0Pl;h@030>7Q07kQ00>nhN402N433i7Q00>nhN40@N400`oQh@21h@00@>400`oQ

h@0;h@030>7Q07kQ00>nhN403>453hgQ00>nhN40@N400`oQh@20h@00?^423`kQ00<0hN40ON400kkQ

h@0Bh@8?Rn42_T;Q0Pn1h@00?N400`oQh@0>h@030>7Q07gQ00>nhN405>433h[Q00>nhN40@>400`oQ

h@1oh@00?N400`oQh@0>h@<0O>400kkQh@0Hh@<?Qn42_T7Q0Pn0h@00>n423a7Q00<0hN40O>400kkQ

h@0Kh@D?Q>400kkQh@0oh@033n7Q07kQ000jh@033n7Q017Q00<0hN40Nn400kkQh@0Qh@<?P^400kkQ

h@0oh@033n7Q07gQ000jh@033n7Q017Q00<0hN40N^400kkQh@0Uh@<?P>42_SoQ00<?hN40ON4003SQ

0PlDh@030>7Q07[Q00>nhN40:>433goQ00>nhN40?N400`oQh@1lh@00=n400`oQh@0Dh@030>7Q07[Q

00>nhN40:n433ggQ0[hmh@8?ON4003OQ00<?hN405>400`3Qh@1jh@03_^7Q02kQ0Pmmh@03_^7Q03_Q

00<?hN40Nn4003KQ00<?hN405N400`3Qh@1ih@03_^7Q037Q0`mkh@:n>n423gcQ000eh@033n7Q01KQ

00<0hN40N>400kkQh@0eh@<?N^42_S[Q00<?hN40N^4003CQ00<?hN405n400`3Qh@1hh@03_^7Q03SQ

0`mih@03_^7Q03OQ0Pmkh@00=>400`oQh@0Gh@030>7Q07SQ00>nhN40>n433gOQ0khgh@033n7Q07WQ

000ch@033n7Q01SQ00<0hN40N>400kkQh@0nh@<?M^43_SGQ0Pmjh@00<^400`oQh@0Ih@<0Mn400kkQ

h@12h@<?M^400kkQh@0ch@033n7Q07SQ000ah@033n7Q01[Q00<0hN40M^400kkQh@16h@<?M>43_S;Q

00<?hN40N>40037Q00<?hN406^400`3Qh@1fh@03_^7Q04WQ0`mch@>n<N400`oQh@1gh@00<>400`oQ

h@0Kh@030>7Q07GQ00>nhN40CN433g;Q0kh_h@033n7Q07OQ000`h@033n7Q01_Q00<0hN40MN400kkQ

h@1@h@033n7Q07;Q0[h^h@033n7Q07KQ000_h@033n7Q01cQ00<0hN40MN400kkQh@1Ah@<?Ln43_R_Q

00<?hN40M^4002kQ00<?hN407N400`3Qh@1eh@03_^7Q05CQ0`mch@:n:N423gOQ000^h@033n7Q01gQ

00<0hN40MN400kkQh@1Gh@<?L^43_ROQ00<?hN40MN4002gQ00<?hN407^400`3Qh@1dh@03_^7Q05_Q

0`mah@>n9N400`oQh@1eh@00;N400`oQh@0Nh@030>7Q07CQ00>nhN40G^423g;Q0khSh@033n7Q07CQ

000/h@033n7Q01oQ00<0hN40Ln400kkQh@1Qh@<?L^43_R3Q00<?hN40M>4002cQ00<?hN407n400`3Q

h@1ch@03_^7Q06CQ0`mah@Bn7N423gGQ000[h@033n7Q023Q0`1bh@03_^7Q06SQ00<?hN40LN44_Q_Q

00<?hN40Ln4002_Q00<?hN408>400`3Qh@1bh@03_^7Q06WQ0`mch@>n6N400`oQh@1ch@00:^400`oQ

h@0Qh@030>7Q07;Q00>nhN40K>433g?Q1;hEh@8?M>4002[Q00<?hN408N400`3Qh@1bh@03_^7Q06oQ

00<?hN40M>43_Q?Q00<?hN40L^4002WQ00<?hN408^400`3Qh@1bh@03_^7Q073Q0`mfh@>n4>400`oQ

h@1bh@00:N400`oQh@0Rh@030>7Q077Q00>nhN40M>433gKQ1;h<h@8?Ln4002SQ00<?hN408n400`3Q

h@1ah@03_^7Q07OQ0Pmgh@Bn2^400`oQh@1ah@00:>400`oQh@0Sh@030>7Q077Q00>nhN40NN433gOQ

1;h7h@033n7Q077Q000Wh@033n7Q02CQ00<0hN40L>400kkQh@1mh@033n7Q07SQ0kh4h@033n7Q077Q

000Wh@033n7Q02CQ00<0hN40L>400kkQh@1nh@<?N^44_P03h@oQ077Q000Vh@033n7Q02GQ00<0hN40

L>400kkQh@21h@8?O>44_W3Q000Vh@033n7Q02GQ00<0hN40Kn400kkQh@24h@<?N^400`oQ_P03_VgQ

000Uh@033n7Q02KQ0`1_h@03_^7Q08OQ00<?hN40Mn423`CQ1;iYh@009N400`oQh@0Vh@030>7Q06oQ

00>nhN40R>433gOQ00<?hN401^44_VGQ000Uh@033n7Q02KQ00<0hN40Kn400kkQh@2;h@033n7Q07CQ

00<?hN402N45_V7Q000Th@033n7Q02OQ00<0hN40Kn400kkQh@2<h@<?Ln400`oQh@0>h@BnGN4002CQ

00<?hN409n400`3Qh@1_h@03_^7Q08oQ0Pmah@033n7Q017Q1;iJh@009>400`oQh@0Wh@030>7Q06kQ

00>nhN40T^433foQ00<?hN405>45_UGQ000Sh@033n7Q02SQ00<0hN40K^400kkQh@2Eh@033n7Q06cQ

00<?hN406N44_U7Q000Sh@033n7Q02SQ00<0hN40K^400kkQh@2Fh@8?K>400`oQh@0Lh@FnCN4002;Q

00<?hN40:N400`3Qh@1]h@03_^7Q09WQ0`mYh@033n7Q027Q1;i9h@008^400`oQh@0Yh@030>7Q06gQ

00>nhN40W>400`oQh@1Vh@033n7Q02GQ1;i5h@008^400`oQh@0Oh@030>7Q00OQ00<0hN40KN400kkQ

h@2Mh@<?IN423b[Q1;i1h@008^400`oQh@0Nh@030>4000SQ00<0hN40KN400kkQh@2Ph@8?I>400`oQ

h@0/h@Fn?>40027Q00<?hN406^4300CQ00<0hN401^4406_Q00>nhN40Xn400`oQh@1Qh@033n7Q037Q

1;hhh@008N400`oQh@0Oh@802N400`3Qh@1/h@03_^7Q0:CQ0`mPh@033n7Q03GQ1Khch@008N400`oQ

h@0Oh@030>7Q00SQ00<0hN40K>400kkQh@2Wh@033n7Q05gQ00<?hN40>N44_S3Q000Qh@033n7Q01oQ

0`08h@030>7Q06cQ00>nhN40Z>423egQ00<?hN40KN40023Q00<?hN40:n400`3Qh@1/h@03_^7Q0:[Q

0`mJh@033n7Q06gQ000Ph@033n7Q02_Q00<0hN40K>400kkQh@2]h@033n7Q05OQ00<?hN40KN4001oQ

00<?hN40;>400`3Qh@1/h@03_^7Q0:kQ0PmHh@033n7Q06cQ000Oh@033n7Q02cQ00<0hN40K>400kkQ

h@2`h@<?EN400`oQh@1/h@007n400`oQh@0/h@030>7Q06_Q00>nhN40]>400`oQh@1Bh@033n7Q06cQ

000Oh@033n7Q02cQ00<0hN40Jn400kkQh@2eh@8?D^400`oQh@1/h@007^400`oQh@0]h@030>7Q06_Q

00>nhN40]n400`oQh@1?h@033n7Q06cQ000Nh@033n7Q02gQ00<0hN40Jn400kkQh@2hh@<?C^400`oQ

h@1/h@007^400`oQh@0]h@<0Jn400kkQh@2kh@8?C>400`oQh@1/h@007^400`oQh@0]h@030>7Q06[Q

00>nhN40_^400`oQh@19h@033n7Q06cQ000Nh@033n7Q02gQ00<0hN40J^400kkQh@2oh@8?^>4001gQ

00<?hN40;^400`3Qh@1Zh@03_^7Q0<7Q00<?hN40]N4001gQ00<?hN40;^400`3Qh@1Zh@03_^7Q0<;Q

0`ndh@007N400`oQh@0^h@030>7Q06[Q00>nhN40aN400`oQh@2ah@007N400`oQh@0^h@030>7Q06[Q

00>nhN40a^423k7Q000Lh@033n7Q02oQ00<0hN40J^400kkQh@38h@033n7Q03oQ00<?hN40K>4001cQ

00<?hN40;n400`3Qh@1Zh@03_^7Q0<WQ0Ploh@033n7Q06cQ000Lh@033n7Q02oQ00<0hN40J^400kkQ

h@3;h@033n7Q03cQ00<?hN40K>4001cQ00<?hN40;n400`3Qh@1Zh@03_^7Q0<cQ0Pllh@033n7Q06cQ

000Lh@033n7Q02oQ00<0hN40J^400kkQh@3>h@<?>>400`oQh@1]h@007>400`oQh@0_h@<0J^400kkQ

h@3Ah@033n7Q03GQ00<?hN40KN4001cQ00<?hN40;n400`3Qh@1Yh@03_^7Q0=?Q0Pleh@033n7Q06gQ

000Kh@033n7Q033Q00<0hN40JN400kkQh@3Eh@033n7Q03;Q00<?hN40KN4001_Q00<?hN40<>400`3Q

h@1Yh@03_^7Q0=KQ0Plbh@033n7Q06gQ000Kh@033n7Q033Q00<0hN40JN400kkQh@3Hh@033n7Q02oQ

00<?hN40KN4001_Q00<?hN40<>400`3Qh@1Yh@03_^7Q0=WQ0Pl_h@033n7Q06gQ000Kh@033n7Q033Q

00<0hN40JN400kkQh@3Kh@033n7Q02_Q00<?hN40K^4001_Q00<?hN40<>400`3Qh@1Yh@03_^7Q0=cQ

00<?hN40:^400`oQh@1^h@006n400`oQh@0`h@030>7Q06WQ00>nhN40gN423b[Q00<?hN40K^4001_Q

00<?hN40<>400`3Qh@1Xh@03_^7Q0>3Q00<?hN409n400`oQh@1^h@006n400`oQh@0`h@030>7Q06SQ

00>nhN40hN423bOQ00<?hN40K^4001_Q00<?hN40<>400`3Qh@1Xh@03_^7Q0>;Q00<?hN409N400`oQ

h@1^h@006n400`oQh@0`h@<0J>400kkQh@3Sh@033n7Q02?Q00<?hN40Kn4001_Q00<?hN40<>400`3Q

h@1Xh@03_^7Q0>CQ0PlSh@033n7Q06oQ000Jh@033n7Q037Q00<0hN40J>400kkQh@3Vh@033n7Q01oQ

00<?hN40L>4001[Q00<?hN40<N400`3Qh@1Xh@03_^7Q0>OQ0PlOh@033n7Q073Q000Jh@033n7Q037Q

00<0hN40J>400kkQh@3Yh@033n7Q01cQ00<?hN40L>4001[Q00<?hN40<N400`3Qh@1Xh@03_^7Q0>[Q

0PlKh@033n7Q077Q000Jh@033n7Q037Q00<0hN40J>400kkQh@3[h@033n7Q01WQ00<?hN40LN4001[Q

00<?hN40<N400`3Qh@1Xh@03_^7Q0>cQ00<?hN406>400`oQh@1ah@006^400`oQh@0ah@030>7Q06SQ

00>nhN40kN423aOQ00<?hN40L^4001[Q00<?hN40<N400`3Qh@1Xh@03_^7Q0>oQ00<?hN405>400`oQ

h@1bh@006^400`oQh@0ah@030>7Q047Q1@02h@030>7Q01gQ00>nhN408>450003h@00047Q1@02h@03

0>7Q043Q1@02h@030>7Q03?Q00<?hN402^450004h@003d7Q0`03h@030>7Q02_Q000Jh@033n7Q037Q

00<0hN40@n401`3QhN40h@007^400kkQh@0Rh@070>7Qh@3Q0012h@030>7Q00;Q00<0hN40@^401`3Q

hN40h@00=N400`oQh@0;h@030>7Q00?Q00<?hN40?n400`3Qh@02h@030>4002cQ000Jh@033n7Q037Q

0`13h@030>7Q00?Q00<0hN407>400kkQh@0Rh@070>7Qh@3Q0012h@030>7Q00;Q00<0hN40@^401`3Q

hN40h@00=^400`oQh@0:h@030>7Q00;Q00<?0>40@N401`3QhN40h@00;>4001[Q00<?hN40<N400`3Q

h@13h@040>7Qh@807^400kkQh@0Sh@040>7Qh@80@n400`3Qh@03h@030>7Q047Q00<0hN400^400`3Q

h@0fh@033n7Q00WQ00L0hN7Q00l004;Q00L0hN7Q0>4002cQ000Jh@033n7Q037Q00<0hN40@n401@3Q

hN4001oQ00>nhN408n401@3QhN4004CQ00L0hN7Q0>4004?Q00L0hN7Q0>4003SQ00<?hN402>401`3Q

hN4?h@00@N400`3Q0002h@030>4002cQ000Jh@033n7Q037Q00<0hN40@^4200?Q0`0Mh@03_^7Q02;Q

0P04h@80@N4200?Q0`12h@801>400`3Qh@0hh@033n7Q00KQ0P03h@033`0004;Q00<0hN400^400`3Q

h@0[h@006^400`oQh@0ah@030>7Q06OQ00>nhN40m^400`oQh@0:h@033n7Q07KQ000Ih@033n7Q03;Q

00<0hN40In400kkQh@3gh@033n7Q00SQ00<?hN40Mn4001WQ00<?hN40<^400`3Qh@1Wh@03_^7Q0?SQ

0Pl8h@033n7Q07OQ000Ih@033n7Q03;Q00<0hN40In400kkQh@3ih@033n7Q00GQ00<?hN40N>4001WQ

00<?hN40<^400`3Qh@1Wh@03_^7Q0?[Q00<?hN401>400`oQh@1hh@006N400`oQh@0bh@030>7Q06OQ

00>nhN40nn400`oQh@02h@033n7Q07WQ000Ih@033n7Q03;Q00<0hN40In400kkQh@3lh@043n7Q3fSQ

100@h@006N400`oQh@0bh@030>7Q06OQ00>nhN40o>4010oQh@mXh@<04N4000cQ3@000`l0002L0003

_P000?d00PmJ017Q00<0hN403n4001?Q00<0hN400n400`oQh@06h@030>7Q00_Q00<0hN403>400`3Q

h@0<h@030>7Q00_Q00<0hN403>400`3Qh@0<h@030>7Q00cQ00<0hN402n400`3Qh@0<h@030>7Q00cQ

00@0hN6n2^400`3Qh@0<h@030>7Q00cQ00<0hN403>400`3Qh@0;h@030>7Q00cQ00<0hN403>400`3Q

h@0;h@030>7Q00cQ00<0hN403>400`3Qh@0<h@030>7Q00_Q00<0hN403>400`3Qh@0<h@030>7Q00_Q

00<0hN403>400`3Qh@0<h@030>7Q00KQ0Pl4h@030>7Q00_Q00<0hN403>400`3Qh@0<h@030>7Q00_Q

00<0hN403>400`3Qh@0Jh@804N4001?Q00<0hN400n400`oQh@06h@030>7Q00_Q00<0hN403>400`3Q

h@0<h@030>7Q00_Q00<0hN403>400`3Qh@0<h@030>7Q00cQ00<0hN402n400`3Qh@0<h@030>7Q00cQ

00@0hN6n2^400`3Qh@0<h@030>7Q00cQ00<0hN403>400`3Qh@0;h@030>7Q00cQ00<0hN403>400`3Q

h@0;h@030>7Q00cQ00<0hN403>400`3Qh@0<h@030>7Q00_Q00<0hN403>400`3Qh@0<h@030>7Q00_Q

00<0hN403>400`3Qh@0<h@030>7Q00GQ00@?hN4?0n400`3Qh@0;h@030>7Q00cQ00<0hN403>400`3Q

h@0;h@030>7Q00cQ00<0hN40;N4001WQ00<?hN40<^400`3Qh@16h@030>7Q01kQ00>nhN409^400`3Q

h@16h@030>7Q04OQ00<0hN40@>4010oQh@l3h@030>7Q04KQ00<0hN40;N4001WQ00<?hN40<^400`3Q

h@16h@030>7Q01kQ00>nhN409^400`3Qh@16h@030>7Q04OQ00<0hN40?n400`oQh@02h@043n7Q04SQ

00<0hN40;N4001WQ00<?hN40<^400`3Qh@1Wh@03_^7Q0?[Q00<?hN401>400`oQh@1hh@006N400`oQ

h@0bh@030>7Q06OQ00>nhN40nN400`oQh@06h@033n7Q07OQ000Ih@033n7Q03;Q00<0hN40In400kkQ

h@3hh@033n7Q00OQ00<?hN40Mn4001[Q00<?hN40<N400`3Qh@1Wh@03_^7Q0?OQ00<?hN402N400`oQ

h@1fh@006^400`oQh@0ah@030>7Q06OQ00>nhN40m^400`oQh@0:h@033n7Q07KQ000Jh@033n7Q037Q

00<0hN40In400kkQh@3fh@033n7Q00_Q00<?hN40MN4001[Q00<?hN40<N400`3Qh@1Wh@03_^7Q0?GQ

00<?hN403>400`oQh@1eh@006^400`oQh@0ah@<0J>400kkQh@3ch@033n7Q00kQ00<?hN40M>4001[Q

00<?hN40<N400`3Qh@1Xh@03_^7Q0?;Q00<?hN403n400`oQh@1dh@006^400`oQh@0ah@030>7Q06SQ

00>nhN40lN400`oQh@0Ah@033n7Q07?Q000Jh@033n7Q037Q00<0hN40J>400kkQh@3_h@8?5>400`oQ

h@1ch@006^400`oQh@0ah@030>7Q06SQ00>nhN40k^400`oQh@0Eh@033n7Q07;Q000Jh@033n7Q037Q

00<0hN40J>400kkQh@3^h@033n7Q01GQ00<?hN40L^4001[Q00<?hN40<N400`3Qh@1Xh@03_^7Q0>cQ

0PlIh@033n7Q077Q000Jh@033n7Q037Q00<0hN40J>400kkQh@3[h@033n7Q01WQ00<?hN40LN4001[Q

00<?hN40<N400`3Qh@1Xh@03_^7Q0>WQ0PlLh@033n7Q077Q000Jh@033n7Q037Q00<0hN40J>400kkQ

h@3Xh@033n7Q01gQ00<?hN40L>4001[Q00<?hN40<N400`3Qh@1Xh@03_^7Q0>SQ00<?hN407N400`oQ

h@1`h@006^400`oQh@0ah@030>7Q06SQ00>nhN40i^423b3Q00<?hN40L>4001_Q00<?hN40<>4306SQ

00>nhN40iN400`oQh@0Qh@033n7Q06oQ000Kh@033n7Q033Q00<0hN40J>400kkQh@3Sh@8?9>400`oQ

h@1_h@006n400`oQh@0`h@030>7Q06SQ00>nhN40h^400`oQh@0Uh@033n7Q06kQ000Kh@033n7Q033Q

00<0hN40J>400kkQh@3Ph@8?:>400`oQh@1^h@006n400`oQh@0`h@030>7Q06SQ00>nhN40gn400`oQ

h@0Xh@033n7Q06kQ000Kh@033n7Q033Q00<0hN40JN400kkQh@3Lh@8?:n400`oQh@1^h@006n400`oQ

h@0`h@030>7Q06WQ00>nhN40fn400`oQh@0[h@033n7Q06kQ000Kh@033n7Q033Q00<0hN40JN400kkQ

h@3Jh@033n7Q02cQ00<?hN40K^4001_Q00<?hN40<>400`3Qh@1Yh@03_^7Q0=SQ0Pl`h@033n7Q06gQ

000Kh@033n7Q033Q00<0hN40JN400kkQh@3Gh@033n7Q033Q00<?hN40KN4001_Q00<?hN40<>400`3Q

h@1Yh@03_^7Q0=GQ0Plch@033n7Q06gQ000Kh@033n7Q033Q00<0hN40JN400kkQh@3Dh@033n7Q03?Q

00<?hN40KN4001cQ00<?hN40;n4306WQ00>nhN40d^423cKQ00<?hN40KN4001cQ00<?hN40;n400`3Q

h@1Zh@03_^7Q0=3Q00<?hN40=^400`oQh@1]h@007>400`oQh@0_h@030>7Q06[Q00>nhN40c^423cWQ

0Pm^h@007>400`oQh@0_h@030>7Q06[Q00>nhN40cN400`oQh@0jh@033n7Q06cQ000Lh@033n7Q02oQ

00<0hN40J^400kkQh@3;h@8??N400`oQh@1/h@007>400`oQh@0_h@030>7Q06[Q00>nhN40b^400`oQ

h@0mh@033n7Q06cQ000Mh@033n7Q02kQ00<0hN40J^400kkQh@38h@8?[n4001gQ00<?hN40;^400`3Q

h@1Zh@03_^7Q0<GQ0`nah@007N400`oQh@0^h@030>7Q06[Q00>nhN40a>400`oQh@2bh@007N400`oQ

h@0^h@030>7Q06[Q00>nhN40`^423kGQ000Nh@033n7Q02gQ00<0hN40J^400kkQh@31h@033n7Q0;GQ

000Nh@033n7Q02gQ00<0hN40J^400kkQh@30h@033n7Q0;KQ000Nh@033n7Q02gQ0`1Zh@03_^7Q0;kQ

0Pm:h@033n7Q06cQ000Nh@033n7Q02gQ00<0hN40Jn400kkQh@2jh@<?C>400`oQh@1/h@007^400`oQ

h@0]h@030>7Q06_Q00>nhN40^N400`oQh@1=h@033n7Q06cQ000Oh@033n7Q02cQ00<0hN40Jn400kkQ

h@2gh@8?D>400`oQh@1/h@007n400`oQh@0/h@030>7Q06_Q00>nhN40]^400`oQh@1@h@033n7Q06cQ

000Oh@033n7Q02cQ00<0hN40Jn400kkQh@2ch@<?Dn400`oQh@1/h@007n400`oQh@0/h@030>7Q06cQ

00>nhN40/>423eKQ00<?hN40K>4001oQ00<?hN40;>400`3Qh@1/h@03_^7Q0:oQ00<?hN40E^400`oQ

h@1/h@008>400`oQh@0[h@030>7Q06cQ00>nhN40[>433eSQ00<?hN40KN40023Q00<?hN40:n400`3Q

h@1/h@03_^7Q0:[Q0PmKh@033n7Q06gQ000Qh@033n7Q023Q00<0hN401n400`3Qh@1/h@03_^7Q0:WQ

00<?hN40Fn400`oQh@1]h@008N400`oQh@0Oh@030>4000SQ00<0hN40K>400kkQh@2Vh@<?G^400`oQ

h@0ih@Bn<>40027Q00<?hN408N400`3Qh@06h@@0Jn400kkQh@2Th@8?HN400`oQh@0dh@Fn=>40027Q

00<?hN407n4200WQ00<0hN40K>400kkQh@2Sh@033n7Q067Q00<?hN40<>45_SSQ000Rh@033n7Q01kQ

00<0hN402>400`3Qh@1]h@03_^7Q09oQ0`mTh@033n7Q02_Q1Khmh@008^400`oQh@0Nh@<02>400`3Q

h@1]h@03_^7Q09kQ00<?hN40I>423bWQ1Ki1h@008^400`oQh@0Yh@030>7Q06gQ00>nhN40Vn433fOQ

00<?hN409>44_TKQ000Rh@033n7Q02WQ00<0hN40KN400kkQh@2Ih@8?J^400`oQh@0Oh@FnB^4002?Q

00<?hN40:>400`3Qh@1^h@03_^7Q09OQ00<?hN40J^400`oQh@0Lh@>nCn4002?Q00<?hN40:>400`3Q

h@1^h@03_^7Q09CQ0`m]h@033n7Q01OQ1KiBh@009>400`oQh@0Wh@030>7Q06kQ00>nhN40T^423foQ

0PlEh@BnEn4002CQ00<?hN409n400`3Qh@1_h@03_^7Q08kQ0`mah@033n7Q013Q1KiJh@009>400`oQ

h@0Wh@030>7Q06oQ00>nhN40SN400`oQh@1bh@033n7Q00cQ1;iOh@009N400`oQh@0Vh@030>7Q06oQ

00>nhN40R^433gGQ00<?hN402N44_V;Q000Uh@033n7Q02KQ0`1_h@03_^7Q08SQ0Pmhh@033n7Q00GQ

1;iVh@009N400`oQh@0Vh@030>7Q06oQ00>nhN40Q^423gWQ0Pl3h@BnJ^4002KQ00<?hN409N400`3Q

h@1_h@03_^7Q08CQ0Pmkh@033n6n00>nKN4002KQ00<?hN409N400`3Qh@1`h@03_^7Q083Q0`mkh@Bn

LN4002OQ00<?hN409>400`3Qh@1`h@03_^7Q07oQ00<?hN40N>44_P03h@l?07;Q000Wh@033n7Q02CQ

00<0hN40L>400kkQh@1lh@<?N>44_PCQ00<?hN40LN4002SQ00<?hN408n400`3Qh@1ah@03_^7Q07WQ

0Pmhh@>n2>400`oQh@1ah@00:>400`oQh@0Sh@030>7Q077Q00>nhN40M^433gKQ1;h;h@033n7Q077Q

000Yh@033n7Q02;Q00<0hN40LN400kkQh@1eh@033n7Q07CQ0kh>h@8?Ln4002WQ00<?hN408^400`3Q

h@1bh@03_^7Q077Q0`mdh@>n4N400`oQh@1bh@00:^400`oQh@0Qh@030>7Q07;Q00>nhN40K^433g?Q

1;hDh@033n7Q07;Q000Zh@033n7Q027Q00<0hN40L^400kkQh@1/h@8?Ln44_QKQ00<?hN40Ln4002_Q

00<?hN408>4307;Q00>nhN40J^423g?Q0khIh@033n7Q07?Q000[h@033n7Q023Q00<0hN40L^400kkQ

h@1Wh@<?L^43_QcQ00<?hN40Ln4002cQ00<?hN407n400`3Qh@1ch@03_^7Q06CQ0Pmbh@>n7^400`oQ

h@1dh@00;>400`oQh@0Oh@030>7Q07?Q00>nhN40HN433g7Q0khQh@033n7Q07CQ000]h@033n7Q01kQ

00<0hN40M>400kkQh@1Mh@<?LN44_R;Q0Pmfh@00;N400`oQh@0Nh@030>7Q07CQ00>nhN40F^433g;Q

0khUh@033n7Q07GQ000^h@033n7Q01gQ00<0hN40MN400kkQh@1Hh@033n7Q073Q1;hWh@033n7Q07GQ

000_h@033n7Q01cQ00<0hN40MN400kkQh@1Eh@<?LN43_RWQ0Pmgh@00;n400`oQh@0Lh@030>7Q07GQ

00>nhN40D^433g;Q0[h/h@033n7Q07KQ000`h@033n7Q01_Q00<0hN40MN400kkQh@1?h@<?L^43_RgQ

0Pmhh@00<>400`oQh@0Kh@030>7Q07KQ00>nhN40Bn433g?Q0[h`h@033n7Q07OQ000ah@033n7Q01[Q

00<0hN40M^400kkQh@18h@<?M>42_S7Q0Pmih@00<N400`oQh@0Jh@<0Mn400kkQh@14h@<?MN42_S?Q

00<?hN40N>4003;Q00<?hN406N400`3Qh@1gh@03_^7Q04?Q00<?hN40M>42_SGQ00<?hN40N>4003?Q

00<?hN406>400`3Qh@1hh@03_^7Q03oQ0`meh@:n=^400`oQh@1ih@00=>400`oQh@0Gh@030>7Q07SQ

00>nhN40?>433gKQ0[hhh@033n7Q07WQ000dh@033n7Q01OQ00<0hN40N>400kkQh@0ih@<?Mn42_SWQ

0Pmkh@00=N400`oQh@0Fh@030>7Q07SQ00>nhN40=^433gWQ00>nhN40>N400`oQh@1jh@00=^400`oQ

h@0Eh@030>7Q07WQ00>nhN40<^433g[Q0[hkh@8?O>4003OQ00<?hN405>400`3Qh@1jh@03_^7Q02gQ

10mkh@:n?N400`oQh@1kh@00>>400`oQh@0Ch@030>7Q07[Q00>nhN40:^433ggQ0[hnh@8?ON4003WQ

00<?hN404^400`3Qh@1jh@03_^7Q02OQ0`moh@:n?^423gkQ000jh@033n7Q017Q00<0hN40Nn400kkQ

h@0Sh@<?PN400kkQh@0nh@033n7Q07gQ000jh@033n7Q017Q00<0hN40Nn400kkQh@0Ph@<?Pn400kkQ

h@0nh@8?On4003_Q00<?hN404>4307cQ00>nhN407>433hCQ0[i1h@033n7Q07kQ000lh@8?4>400`3Q

h@1mh@03_^7Q01SQ0`n6h@03_^7Q043Q0Pn0h@00?^400`oQh@0=h@030>7Q07gQ00>nhN404n453hSQ

0[i2h@033n7Q07oQ000oh@033n7Q00cQ00<0hN40ON400kkQh@0Ah@8?S>400kkQh@11h@033n7Q083Q

0010h@033n7Q00_Q00<0hN40O^400kkQh@0=h@<?SN42_T;Q0Pn2h@00@N400`oQh@0:h@030>7Q07oQ

00>nhN401n453hoQ00>nhN40@^400`oQh@1@h@033n7Q02kQ0012h@8?2^400`3Qh@1oh@03_^7Q00CQ

0`nCh@03_^7Q04;Q0Pm<h@H?<N4004CQ00<?hN401n400`3Qh@20h@03_^7Q00<?U^400kkQh@11h@8?

B>463cKQ0015h@8?1n400`3Qh@1oh@043kh?3iSQ00>nhN40@^400`oQh@11h@H??>4004OQ00<?hN40

1>400`3Qh@1jh@D?0^400kkQh@2Fh@03_^7Q04;Q0Plnh@H?@N4003gQ1@02h@040>7Qh@8?1>400`3Q

h@1hh@8?2>400kkQh@2Dh@03_^7Q04;Q0Plih@H?An4003oQ00L0hN7Q0>4000CQ00D?hN7Q001eh@D?

2n400kkQh@2Ch@03_^7Q04;Q00<?hN40<n463dcQ000oh@070>7Qh@3Q0005h@033n7Q00@0Kn433a3Q

00>nhN40Tn400kkQh@11h@8?;n463e;Q000oh@070>7Qh@3Q0006h@8?00<0hN40K>443aCQ00>nhN40

TN400kkQh@11h@8?:^473eOQ000oh@070>7Qh@3Q0008h@<?In453aWQ00>nhN40T>400kkQh@10h@8?

9^463egQ000nh@801>400`3Qh@07h@040>7Q3f;Q10lOh@03_^7Q0=;Q00<?hN408>463f;Q001>h@04

0>7Qh@<?Fn443b?Q00>nhN40dN400`oQh@0Lh@D?J>4004kQ00<0hN401>433e;Q1PlXh@03_^7Q0<oQ

0PlHh@H?KN4004kQ00<0hN401n433d[Q1@l_h@03_^7Q0<kQ00<?hN404^453g?Q001>h@030>7Q00[Q

0`m1h@H?=>400kkQh@2<h@03_^7Q03kQ00<?hN403^453gSQ001>h@030>7Q00gQ1@leh@L?>n400kkQ

h@2;h@03_^7Q03kQ00<?hN402>463ggQ001>h@030>7Q01;Q1@lYh@L?@n42_X_Q0[hoh@/?Pn4004kQ

00<0hN405n4;3a;Q30m;h@03_^7Q08[Q00>nhN40bn4004kQ00<0hN408^4B3eSQ00>nhN40RN400kkQ

h@3;h@00C^4308gQ0[j9h@03_^7Q0<_Q001>h@030>7Q08kQ00>nhN40Qn42_/cQ001>h@030>7Q08oQ

0[j8h@03_^7Q0<[Q001>h@030>7Q097Q00>nhN40QN400kkQh@3:h@00C^400`3Qh@2Ah@:nQ^42_/_Q

001>h@030>7Q09?Q00>nhN40Q>400kkQh@39h@00C^400`3Qh@2Ch@:nQN400kkQh@39h@00C^400`3Q

h@2Eh@:nPn400kkQh@39h@00C^400`3Qh@2Fh@:nP>42_/cQ001>h@030>7Q09SQ0[imh@:ncN4004kQ

00<0hN40VN43_WSQ0kk?h@00C^400`3Qh@2Lh@03_^7Q077Q1KkAh@00C^4309gQ0ki/h@FneN4004kQ

00<0hN40Wn43_VKQ1KkIh@00C^400`3Qh@2Qh@>nGn46_]gQ001>h@030>7Q0:CQ0[iGh@Jnhn4004kQ

00<0hN40Y^43_ToQ1[kXh@00C^400`3Qh@2Yh@BnAN46_^kQ001>h@030>7Q0:cQ1Khih@Rnm>4004kQ

00<0hN40/N45_RcQ2Kkkh@00C^400`3Qh@2fh@Vn5n4<__oQ1N4004kQ00<0hN40_n4H__oQ4>4004kQ

00<0hN40on7Wh@00C^400`3Qh@3ohNOQ001>h@<0on7Wh@00C^400`3Qh@3ohNOQ001>h@030>7Q0?oQ

in4004kQ00<0hN40on7Wh@00C^400`3Qh@3ohNOQ001>h@030>7Q0?oQin400?oQon4ih@00on7ohCWQ

003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQ

on4ih@00on7ohCWQ003oh@;Q0P001>400>440003h@0000CQ00<0hN400^400`3Qh@02h@030>7Q0?oQ

6N400?oQ0n400`3Q0009h@050>7Qh@002>400`3Q003ohA[Q003oh@?Q0`02h@@00^400`3Qh@02h@03

0>7Q00SQ00<0hN40on4Hh@00on43h@040>4000SQ00<0hN400^400`3Qh@05h@80on4Kh@00C>420;CQ

00<0hN401n400`3Q0002h@030>4000OQ00<0hN40on4Jh@00CN400`3Qh@2ah@802^40103QhN4300OQ

0`3ohA[Q001;h@<00^400`3Qh@3ohNGQ001:h@080>7Q0>40h@3ohNKQ001:h@080>7Q0>40h@3ohNKQ

001;h@<000CQ0>40on7Vh@00Cn400`3Q003ohNKQ001@h@030>7Q0?oQiN400?oQon4ih@00on7ohCWQ

003ohOoQ>N400?oQon4ih@00on7ohCWQ0000\

\>"],

  ImageRangeCache->{{{0, 566}, {349.313, 0}} -> {12.9375, -13.3449, 0.0135923,

   0.083313}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-1.85165 0.140864 0.309017 0.0231404 [

[.26131 .29652 -6 -9 ]

[.26131 .29652 6 0 ]

[.40217 .29652 -6 -9 ]

[.40217 .29652 6 0 ]

[.54303 .29652 -6 -9 ]

[.54303 .29652 6 0 ]

[.6839 .29652 -6 -9 ]

[.6839 .29652 6 0 ]

[.82476 .29652 -6 -9 ]

[.82476 .29652 6 0 ]

[.96563 .29652 -6 -9 ]

[.96563 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.10794 .07761 -18 -4.5 ]

[.10794 .07761 0 4.5 ]

[.10794 .19332 -12 -4.5 ]

[.10794 .19332 0 4.5 ]

[.10794 .42472 -6 -4.5 ]

[.10794 .42472 0 4.5 ]

[.10794 .54042 -12 -4.5 ]

[.10794 .54042 0 4.5 ]

[.12044 .64303 -7 0 ]

[.12044 .64303 7 16 ]

[.5 .63053 -12 0 ]

[.5 .63053 12 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.26131 .30902 m

.26131 .31527 L

s

[(15)] .26131 .29652 0 1 Mshowa

.40217 .30902 m

.40217 .31527 L

s

[(16)] .40217 .29652 0 1 Mshowa

.54303 .30902 m

.54303 .31527 L

s

[(17)] .54303 .29652 0 1 Mshowa

.6839 .30902 m

.6839 .31527 L

s

[(18)] .6839 .29652 0 1 Mshowa

.82476 .30902 m

.82476 .31527 L

s

[(19)] .82476 .29652 0 1 Mshowa

.96563 .30902 m

.96563 .31527 L

s

[(20)] .96563 .29652 0 1 Mshowa

.125 Mabswid

.14861 .30902 m

.14861 .31277 L

s

.17679 .30902 m

.17679 .31277 L

s

.20496 .30902 m

.20496 .31277 L

s

.23313 .30902 m

.23313 .31277 L

s

.28948 .30902 m

.28948 .31277 L

s

.31765 .30902 m

.31765 .31277 L

s

.34582 .30902 m

.34582 .31277 L

s

.374 .30902 m

.374 .31277 L

s

.43034 .30902 m

.43034 .31277 L

s

.45852 .30902 m

.45852 .31277 L

s

.48669 .30902 m

.48669 .31277 L

s

.51486 .30902 m

.51486 .31277 L

s

.57121 .30902 m

.57121 .31277 L

s

.59938 .30902 m

.59938 .31277 L

s

.62755 .30902 m

.62755 .31277 L

s

.65573 .30902 m

.65573 .31277 L

s

.71207 .30902 m

.71207 .31277 L

s

.74024 .30902 m

.74024 .31277 L

s

.76842 .30902 m

.76842 .31277 L

s

.79659 .30902 m

.79659 .31277 L

s

.85293 .30902 m

.85293 .31277 L

s

.88111 .30902 m

.88111 .31277 L

s

.90928 .30902 m

.90928 .31277 L

s

.93745 .30902 m

.93745 .31277 L

s

.09227 .30902 m

.09227 .31277 L

s

.0641 .30902 m

.0641 .31277 L

s

.03592 .30902 m

.03592 .31277 L

s

.00775 .30902 m

.00775 .31277 L

s

.9938 .30902 m

.9938 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.12044 .07761 m

.12669 .07761 L

s

[(-10)] .10794 .07761 1 0 Mshowa

.12044 .19332 m

.12669 .19332 L

s

[(-5)] .10794 .19332 1 0 Mshowa

.12044 .42472 m

.12669 .42472 L

s

[(5)] .10794 .42472 1 0 Mshowa

.12044 .54042 m

.12669 .54042 L

s

[(10)] .10794 .54042 1 0 Mshowa

.125 Mabswid

.12044 .10075 m

.12419 .10075 L

s

.12044 .12389 m

.12419 .12389 L

s

.12044 .14703 m

.12419 .14703 L

s

.12044 .17017 m

.12419 .17017 L

s

.12044 .21646 m

.12419 .21646 L

s

.12044 .2396 m

.12419 .2396 L

s

.12044 .26274 m

.12419 .26274 L

s

.12044 .28588 m

.12419 .28588 L

s

.12044 .33216 m

.12419 .33216 L

s

.12044 .3553 m

.12419 .3553 L

s

.12044 .37844 m

.12419 .37844 L

s

.12044 .40158 m

.12419 .40158 L

s

.12044 .44786 m

.12419 .44786 L

s

.12044 .471 m

.12419 .471 L

s

.12044 .49414 m

.12419 .49414 L

s

.12044 .51728 m

.12419 .51728 L

s

.12044 .05447 m

.12419 .05447 L

s

.12044 .03133 m

.12419 .03133 L

s

.12044 .00819 m

.12419 .00819 L

s

.12044 .56356 m

.12419 .56356 L

s

.12044 .5867 m

.12419 .5867 L

s

.12044 .60984 m

.12419 .60984 L

s

.25 Mabswid

.12044 0 m

.12044 .61803 L

s

gsave

.12044 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -73 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(k) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(38) show

83.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 1 .4 r

.5 Mabswid

.96422 .09293 m

.96281 .09269 L

.9614 .09244 L

.95999 .09219 L

.95858 .09195 L

.95717 .0917 L

.95577 .09145 L

.95436 .09121 L

.95295 .09096 L

.95154 .09071 L

.95013 .09047 L

.94872 .09022 L

.94731 .08997 L

.9459 .08972 L

.9445 .08947 L

.94309 .08922 L

.94168 .08897 L

.94027 .08872 L

.93886 .08847 L

.93745 .08823 L

.93604 .08798 L

.93464 .08772 L

.93323 .08747 L

.93182 .08722 L

.93041 .08697 L

.929 .08672 L

.92759 .08647 L

.92618 .08622 L

.92478 .08597 L

.92337 .08572 L

.92196 .08546 L

.92055 .08521 L

.91914 .08496 L

.91773 .08471 L

.91632 .08445 L

.91491 .0842 L

.91351 .08395 L

.9121 .08369 L

.91069 .08344 L

.90928 .08319 L

.90787 .08293 L

.90646 .08268 L

.90505 .08243 L

.90365 .08217 L

.90224 .08192 L

.90083 .08166 L

.89942 .08141 L

.89801 .08115 L

.8966 .0809 L

.89519 .08064 L

Mistroke

.89379 .08039 L

.89238 .08013 L

.89097 .07988 L

.88956 .07962 L

.88815 .07937 L

.88674 .07911 L

.88533 .07886 L

.88392 .0786 L

.88252 .07835 L

.88111 .07809 L

.8797 .07784 L

.87829 .07758 L

.87688 .07733 L

.87547 .07707 L

.87406 .07681 L

.87266 .07656 L

.87125 .0763 L

.86984 .07605 L

.86843 .07579 L

.86702 .07554 L

.86561 .07528 L

.8642 .07503 L

.8628 .07477 L

.86139 .07452 L

.85998 .07426 L

.85857 .07401 L

.85716 .07376 L

.85575 .0735 L

.85434 .07325 L

.85293 .073 L

.85153 .07274 L

.85012 .07249 L

.84871 .07224 L

.8473 .07199 L

.84589 .07173 L

.84448 .07148 L

.84307 .07123 L

.84167 .07098 L

.84026 .07073 L

.83885 .07048 L

.83744 .07023 L

.83603 .06998 L

.83462 .06973 L

.83321 .06949 L

.8318 .06924 L

.8304 .06899 L

.82899 .06875 L

.82758 .0685 L

.82617 .06826 L

.82476 .06801 L

Mistroke

.82335 .06777 L

.82194 .06753 L

.82054 .06729 L

.81913 .06705 L

.81772 .06681 L

.81631 .06658 L

.8149 .06634 L

.81349 .0661 L

.81208 .06587 L

.81068 .06564 L

.80927 .0654 L

.80786 .06518 L

.80645 .06495 L

.80504 .06472 L

.80363 .06449 L

.80222 .06427 L

.80081 .06405 L

.79941 .06383 L

.798 .06362 L

.79659 .0634 L

.79518 .06319 L

.79377 .06298 L

.79236 .06277 L

.79095 .06257 L

.78955 .06236 L

.78814 .06216 L

.78673 .06197 L

.78532 .06178 L

.78391 .06159 L

.7825 .0614 L

.78109 .06122 L

.77969 .06104 L

.77828 .06086 L

.77687 .0607 L

.77546 .06053 L

.77405 .06037 L

.77264 .06021 L

.77123 .06006 L

.76982 .05992 L

.76842 .05978 L

.76701 .05964 L

.7656 .05952 L

.76419 .0594 L

.76278 .05929 L

.76137 .05918 L

.75996 .05908 L

.75856 .05899 L

.75715 .05891 L

.75574 .05884 L

.75433 .05877 L

Mistroke

.75292 .05872 L

.75151 .05867 L

.7501 .05864 L

.7487 .05862 L

.74729 .05861 L

.74588 .05861 L

.74447 .05862 L

.74306 .05865 L

.74165 .05869 L

.74024 .05874 L

.73883 .05882 L

.73743 .0589 L

.73602 .059 L

.73461 .05912 L

.7332 .05926 L

.73179 .05942 L

.73038 .0596 L

.72897 .05979 L

.72757 .06002 L

.72616 .06026 L

.72475 .06053 L

.72334 .06083 L

.72193 .06115 L

.72052 .0615 L

.71911 .06188 L

.71771 .06229 L

.7163 .06274 L

.71489 .06323 L

.71348 .06376 L

.71207 .06433 L

.71066 .06495 L

.70925 .06563 L

.70784 .06636 L

.70644 .06717 L

.70503 .06805 L

.70362 .06901 L

.70221 .07009 L

.7008 .07129 L

.69939 .07266 L

.69798 .07425 L

.69658 .07617 L

.69517 .07865 L

.69376 .08264 L

Mfstroke

1 0 0 r

.54585 .13486 m

.54867 .13589 L

.55149 .13692 L

.5543 .13796 L

.55712 .13901 L

.55994 .14006 L

.56275 .14112 L

.56557 .14219 L

.56839 .14327 L

.57121 .14436 L

.57402 .14545 L

.57684 .14655 L

.57966 .14766 L

.58248 .14878 L

.58529 .14991 L

.58811 .15105 L

.59093 .1522 L

.59374 .15336 L

.59656 .15452 L

.59938 .1557 L

.6022 .15688 L

.60501 .15808 L

.60783 .15928 L

.61065 .1605 L

.61347 .16172 L

.61628 .16296 L

.6191 .1642 L

.62192 .16545 L

.62473 .16672 L

.62755 .16799 L

.63037 .16928 L

.63319 .17057 L

.636 .17188 L

.63882 .17319 L

.64164 .17452 L

.64446 .17585 L

.64727 .1772 L

.65009 .17856 L

.65291 .17992 L

.65573 .1813 L

.65854 .18269 L

.66136 .18408 L

.66418 .18549 L

.66699 .18691 L

.66981 .18834 L

.67263 .18978 L

.67545 .19123 L

.67826 .19269 L

.68108 .19416 L

.6839 .19564 L

Mistroke

.68672 .19714 L

.68953 .19864 L

.69235 .20016 L

.69517 .20169 L

.69798 .20323 L

.7008 .20479 L

.70362 .20635 L

.70644 .20793 L

.70925 .20953 L

.71207 .21113 L

.71489 .21275 L

.71771 .21439 L

.72052 .21604 L

.72334 .21771 L

.72616 .2194 L

.72897 .2211 L

.73179 .22282 L

.73461 .22456 L

.73743 .22631 L

.74024 .22809 L

.74306 .22989 L

.74588 .23172 L

.7487 .23356 L

.75151 .23544 L

.75433 .23733 L

.75715 .23926 L

.75996 .24122 L

.76278 .2432 L

.7656 .24522 L

.76842 .24728 L

.77123 .24937 L

.77405 .25151 L

.77687 .25368 L

.77969 .2559 L

.7825 .25817 L

.78532 .26049 L

.78814 .26287 L

.79095 .26531 L

.79377 .26782 L

.79659 .27039 L

.79941 .27305 L

.80222 .27579 L

.80504 .27862 L

.80786 .28156 L

.81068 .28461 L

.81349 .2878 L

.81631 .29113 L

.81913 .29462 L

.82194 .29831 L

.82476 .30221 L

Mistroke

.82758 .30638 L

.8304 .31085 L

.83321 .31571 L

.83603 .32104 L

.83885 .327 L

.84167 .33385 L

.84448 .34203 L

Mfstroke

.84603 .2706 m

.84617 .27006 L

.84631 .26952 L

.84645 .26896 L

.8466 .2684 L

.84674 .26782 L

.84688 .26724 L

.84702 .26664 L

.84716 .26602 L

.8473 .2654 L

.84744 .26476 L

.84758 .26411 L

.84772 .26344 L

.84786 .26276 L

.848 .26206 L

.84815 .26133 L

.84829 .26059 L

.84843 .25982 L

.84857 .25903 L

.84871 .25821 L

.84885 .25737 L

.84899 .25647 L

.84913 .25556 L

.84927 .2546 L

.84941 .25359 L

.84955 .25253 L

.84969 .25139 L

.84984 .25017 L

.84998 .24887 L

.85012 .24744 L

.85026 .24581 L

.8504 .24399 L

.85054 .24176 L

.85068 .23872 L

s

.85068 .22688 m

.85054 .22369 L

.8504 .22138 L

.85026 .21945 L

.85012 .21774 L

.84998 .2162 L

.84984 .21477 L

.84969 .21345 L

.84955 .21221 L

.84941 .21104 L

.84927 .20992 L

.84913 .20886 L

.84899 .20784 L

.84885 .20685 L

.84871 .2059 L

.84857 .20498 L

.84843 .20408 L

.84829 .20321 L

.84815 .20236 L

.848 .20154 L

.84786 .20073 L

.84772 .19995 L

.84758 .19918 L

.84744 .19843 L

.8473 .19769 L

.84716 .19697 L

.84702 .19625 L

.84688 .19555 L

.84674 .19486 L

.8466 .19419 L

.84645 .19352 L

.84631 .19287 L

.84617 .19222 L

.84603 .19158 L

.84589 .19096 L

.84575 .19034 L

.84561 .18972 L

.84547 .18912 L

.84533 .18852 L

.84519 .18793 L

.84505 .18736 L

.84491 .18678 L

.84476 .18622 L

.84462 .18566 L

.84448 .18509 L

.84434 .18455 L

.8442 .184 L

.84406 .18347 L

.84392 .18294 L

.84378 .1824 L

Mistroke

.84307 .17984 L

.84237 .17738 L

.84167 .17502 L

.84096 .17274 L

.84026 .17055 L

.83955 .16841 L

.83885 .16636 L

.83814 .16434 L

.83744 .1624 L

.83674 .1605 L

.83603 .15865 L

.83533 .15684 L

.83462 .15508 L

.83392 .15335 L

.83321 .15165 L

.83251 .15 L

.8318 .14837 L

.8311 .14679 L

.8304 .14523 L

.82969 .14369 L

.82899 .14219 L

.82828 .14071 L

.82758 .13926 L

.82687 .13783 L

.82617 .13643 L

.82547 .13504 L

.82476 .13369 L

.82406 .13235 L

.82335 .13103 L

.82265 .12973 L

.82194 .12845 L

.82124 .1272 L

.82054 .12595 L

.81983 .12473 L

.81913 .12352 L

.81842 .12234 L

.81772 .12116 L

.81701 .12001 L

.81631 .11887 L

.81561 .11775 L

.8149 .11664 L

.8142 .11554 L

.81349 .11446 L

.81279 .11339 L

.81208 .11234 L

.81138 .1113 L

.81068 .11028 L

.80997 .10927 L

.80927 .10827 L

.80856 .10728 L

Mistroke

.80786 .10631 L

.80715 .10535 L

.80645 .1044 L

.80575 .10346 L

.80504 .10254 L

.80434 .10163 L

.80363 .10073 L

.80293 .09984 L

.80222 .09896 L

.80152 .09809 L

.80081 .09723 L

.80011 .09638 L

.79941 .09554 L

.7987 .09471 L

.798 .0939 L

.79729 .09309 L

.79659 .09229 L

.79588 .09151 L

.79518 .09073 L

.79448 .08996 L

.79377 .0892 L

.79307 .08845 L

.79236 .08771 L

.79166 .08698 L

.79095 .08626 L

.79025 .08555 L

.78955 .08484 L

.78884 .08414 L

.78814 .08346 L

.78743 .08278 L

.78673 .08211 L

.78602 .08145 L

.78532 .08079 L

.78462 .08015 L

.78391 .07951 L

.78321 .07888 L

.7825 .07826 L

.7818 .07764 L

.78109 .07704 L

.78039 .07644 L

.77969 .07585 L

.77898 .07526 L

.77828 .07469 L

.77757 .07412 L

.77687 .07355 L

.77616 .073 L

.77546 .07246 L

.77476 .07191 L

.77405 .07138 L

.77335 .07085 L

Mistroke

.77264 .07033 L

.77194 .06982 L

.77123 .06931 L

.77053 .06881 L

.76982 .06832 L

.76912 .06783 L

.76842 .06735 L

.76771 .06687 L

.76701 .0664 L

.7663 .06594 L

.7656 .06548 L

.76489 .06503 L

.76419 .06458 L

.76349 .06415 L

.76278 .06371 L

.76208 .06328 L

.76137 .06286 L

.76067 .06244 L

.75996 .06203 L

.75926 .06163 L

.75856 .06123 L

.75785 .06083 L

.75715 .06044 L

.75644 .06006 L

.75574 .05967 L

.75503 .0593 L

.75433 .05893 L

.75363 .05856 L

.75292 .05821 L

.75222 .05785 L

.75151 .0575 L

.75081 .05715 L

.7501 .05681 L

.7494 .05647 L

.7487 .05614 L

.74799 .05581 L

.74729 .05548 L

.74658 .05516 L

.74588 .05485 L

.74517 .05454 L

.74447 .05423 L

.74377 .05392 L

.74306 .05362 L

.74236 .05332 L

.74165 .05303 L

.74095 .05274 L

.74024 .05246 L

.73954 .05217 L

.73883 .0519 L

.73813 .05162 L

Mistroke

.73743 .05135 L

.73672 .05108 L

.73602 .05081 L

.73531 .05055 L

.73461 .05029 L

.7339 .05004 L

.7332 .04978 L

.7325 .04953 L

.73179 .04928 L

.73109 .04904 L

.73038 .0488 L

.72968 .04856 L

.72897 .04832 L

.72827 .04809 L

.72757 .04786 L

.72686 .04763 L

.72616 .0474 L

.72545 .04718 L

.72475 .04696 L

.72404 .04674 L

.72334 .04652 L

.72264 .0463 L

.72193 .04609 L

.72123 .04588 L

.72052 .04567 L

.71982 .04546 L

.71911 .04526 L

.71841 .04505 L

.71771 .04485 L

.717 .04465 L

.7163 .04446 L

.71559 .04426 L

.71489 .04406 L

.71418 .04387 L

.71348 .04368 L

.71277 .04349 L

.71207 .0433 L

.71137 .04311 L

.71066 .04293 L

.70996 .04274 L

.70925 .04256 L

.70855 .04238 L

.70784 .0422 L

.70714 .04202 L

.70644 .04184 L

.70573 .04167 L

.70503 .04149 L

.70432 .04131 L

.70362 .04114 L

.70291 .04097 L

Mistroke

.70221 .0408 L

.70151 .04063 L

.7008 .04046 L

.7001 .04029 L

.69939 .04013 L

.69869 .03996 L

.69798 .03979 L

.69728 .03963 L

.69658 .03947 L

.69587 .0393 L

.69517 .03914 L

.69446 .03898 L

.69376 .03882 L

.69305 .03866 L

.69235 .0385 L

.69165 .03834 L

.69094 .03818 L

.69024 .03803 L

.68953 .03787 L

.68883 .03772 L

.68812 .03756 L

.68742 .03741 L

.68672 .03725 L

.68601 .0371 L

.68531 .03695 L

.6846 .0368 L

.6839 .03665 L

.68319 .03649 L

.68249 .03634 L

.68178 .03619 L

.68108 .03604 L

.68038 .0359 L

.67967 .03575 L

.67897 .0356 L

.67826 .03545 L

.67756 .03531 L

.67685 .03516 L

.67615 .03501 L

.67545 .03487 L

.67474 .03472 L

.67404 .03458 L

.67333 .03443 L

.67263 .03429 L

.67192 .03415 L

.67122 .034 L

.67052 .03386 L

.66981 .03372 L

.66911 .03358 L

.6684 .03344 L

.6677 .03329 L

Mistroke

.66699 .03315 L

.66629 .03301 L

.66559 .03287 L

.66488 .03273 L

.66418 .03259 L

.66347 .03245 L

.66277 .03232 L

.66206 .03218 L

.66136 .03204 L

.66066 .0319 L

.65995 .03176 L

.65925 .03163 L

.65854 .03149 L

.65784 .03136 L

.65713 .03122 L

.65643 .03108 L

.65573 .03095 L

.65502 .03081 L

.65432 .03068 L

.65361 .03054 L

.65291 .03041 L

.6522 .03028 L

.6515 .03014 L

.65079 .03001 L

.65009 .02988 L

.64939 .02974 L

.64868 .02961 L

.64798 .02948 L

.64727 .02935 L

.64657 .02922 L

.64586 .02909 L

.64516 .02896 L

.64446 .02883 L

.64375 .0287 L

.64305 .02857 L

.64234 .02844 L

.64164 .02831 L

.64093 .02818 L

.64023 .02805 L

.63953 .02793 L

.63882 .0278 L

.63812 .02767 L

.63741 .02754 L

.63671 .02742 L

.636 .02729 L

.6353 .02717 L

.6346 .02704 L

.63389 .02691 L

.63319 .02679 L

.63248 .02667 L

Mistroke

.63178 .02654 L

.63107 .02642 L

.63037 .02629 L

.62967 .02617 L

.62896 .02605 L

.62826 .02593 L

.62755 .02581 L

.62685 .02568 L

.62614 .02556 L

.62544 .02544 L

.62473 .02532 L

.62403 .0252 L

.62333 .02508 L

.62262 .02496 L

.62192 .02484 L

.62121 .02473 L

.62051 .02461 L

.6198 .02449 L

.6191 .02437 L

.6184 .02426 L

.61769 .02414 L

.61699 .02402 L

.61628 .02391 L

.61558 .02379 L

.61487 .02368 L

.61417 .02356 L

.61347 .02345 L

.61276 .02333 L

.61206 .02322 L

.61135 .02311 L

.61065 .023 L

.60994 .02289 L

.60924 .02277 L

.60854 .02266 L

.60783 .02255 L

.60713 .02244 L

.60642 .02234 L

.60572 .02223 L

.60501 .02212 L

.60431 .02201 L

.60361 .0219 L

.6029 .0218 L

.6022 .02169 L

.60149 .02158 L

.60079 .02148 L

.60008 .02137 L

.59938 .02127 L

.59868 .02116 L

.59797 .02106 L

.59727 .02096 L

Mistroke

.59656 .02086 L

.59586 .02076 L

.59515 .02066 L

.59445 .02056 L

.59374 .02045 L

.59304 .02036 L

.59234 .02026 L

.59163 .02016 L

.59093 .02006 L

.59022 .01997 L

.58952 .01987 L

.58881 .01977 L

.58811 .01968 L

.58741 .01958 L

.5867 .01949 L

.586 .0194 L

.58529 .0193 L

.58459 .01921 L

.58388 .01912 L

.58318 .01903 L

.58248 .01894 L

.58177 .01885 L

.58107 .01876 L

.58036 .01868 L

.57966 .01859 L

.57895 .0185 L

.57825 .01842 L

.57755 .01833 L

.57684 .01825 L

.57614 .01817 L

.57543 .01808 L

.57473 .018 L

.57402 .01792 L

.57332 .01784 L

.57262 .01776 L

.57191 .01768 L

.57121 .0176 L

.5705 .01753 L

.5698 .01745 L

.56909 .01737 L

.56839 .0173 L

.56769 .01723 L

.56698 .01715 L

.56628 .01708 L

.56557 .01701 L

.56487 .01694 L

.56416 .01687 L

.56346 .0168 L

.56275 .01674 L

.56205 .01667 L

Mistroke

.56064 .01654 L

.55923 .01641 L

.55782 .01629 L

.55642 .01617 L

.55501 .01605 L

.5536 .01594 L

.55219 .01583 L

.55078 .01573 L

.54937 .01563 L

.54796 .01554 L

.54656 .01545 L

.54515 .01537 L

.54374 .01528 L

.54233 .01521 L

.54092 .01514 L

.53951 .01507 L

.5381 .01501 L

.5367 .01496 L

.53529 .01491 L

.53388 .01487 L

.53247 .01483 L

.53106 .01479 L

.52965 .01477 L

.52824 .01474 L

.52683 .01473 L

.52543 .01472 L

.52402 .01472 L

.52261 .01472 L

.5212 .01473 L

.51979 .01475 L

.51838 .01477 L

.51697 .0148 L

.51557 .01484 L

.51416 .01488 L

.51275 .01493 L

.51134 .01499 L

.50993 .01506 L

.50852 .01514 L

.50711 .01522 L

.5057 .01531 L

.5043 .01541 L

.50289 .01552 L

.50148 .01563 L

.50007 .01576 L

.49866 .0159 L

.49725 .01604 L

.49584 .01619 L

.49444 .01636 L

.49303 .01653 L

.49162 .01671 L

Mistroke

.49021 .0169 L

.4888 .01711 L

.48739 .01732 L

.48598 .01755 L

.48458 .01778 L

.48317 .01803 L

.48176 .01829 L

.48035 .01856 L

.47894 .01885 L

.47753 .01914 L

.47612 .01945 L

.47471 .01977 L

.47331 .0201 L

.4719 .02045 L

.47049 .02081 L

.46908 .02119 L

.46767 .02158 L

.46626 .02199 L

.46485 .02241 L

.46345 .02284 L

.46204 .02329 L

.46063 .02376 L

.45922 .02424 L

.45781 .02474 L

.4564 .02526 L

.45499 .0258 L

.45359 .02635 L

.45218 .02692 L

.45077 .02751 L

.44936 .02812 L

.44795 .02875 L

.44654 .0294 L

.44513 .03007 L

.44372 .03076 L

.44232 .03147 L

.44091 .03221 L

.4395 .03297 L

.43809 .03375 L

.43668 .03455 L

.43527 .03538 L

.43386 .03623 L

.43246 .03711 L

.43105 .03802 L

.42964 .03895 L

.42823 .03991 L

.42682 .04089 L

.42541 .04191 L

.424 .04296 L

.4226 .04403 L

.42119 .04514 L

Mistroke

.41978 .04628 L

.41837 .04745 L

.41696 .04866 L

.41555 .0499 L

.41414 .05118 L

.41273 .0525 L

.41133 .05385 L

.40992 .05524 L

.40851 .05667 L

.4071 .05814 L

.40569 .05966 L

.40428 .06122 L

.40287 .06283 L

.40147 .06448 L

.40006 .06618 L

.39865 .06793 L

.39724 .06974 L

.39583 .07159 L

.39442 .0735 L

.39301 .07547 L

.39161 .0775 L

.3902 .07959 L

.38879 .08175 L

.38738 .08397 L

.38597 .08626 L

.38456 .08862 L

.38315 .09106 L

.38174 .09357 L

.38034 .09617 L

.37893 .09885 L

.37752 .10163 L

.37611 .10449 L

.3747 .10746 L

.37329 .11053 L

.37188 .11372 L

.37048 .11701 L

.36907 .12044 L

.36766 .12399 L

.36625 .12769 L

.36484 .13153 L

.36343 .13554 L

.36202 .13971 L

.36062 .14408 L

.35921 .14865 L

.3578 .15344 L

.35639 .15848 L

.35498 .1638 L

.35357 .16941 L

.35216 .17538 L

.35075 .18173 L

Mistroke

.34935 .18855 L

.34794 .19591 L

.34653 .20393 L

.34512 .21278 L

.34371 .2227 L

.3423 .23415 L

.34089 .24795 L

.33949 .26636 L

.33816 .30902 L

Mfstroke

0 1 .4 r

.6939 .09192 m

.69404 .09246 L

.69418 .09296 L

.69432 .09343 L

.69446 .09386 L

.69517 .09571 L

.69587 .09725 L

.69658 .0986 L

.69728 .09982 L

.69798 .10094 L

.69869 .10198 L

.69939 .10295 L

.7001 .10388 L

.7008 .10476 L

.70151 .1056 L

.70221 .1064 L

.70291 .10718 L

.70362 .10792 L

.70432 .10865 L

.70503 .10935 L

.70573 .11003 L

.70644 .11069 L

.70714 .11134 L

.70784 .11197 L

.70855 .11259 L

.70925 .11319 L

.70996 .11377 L

.71066 .11435 L

.71137 .11492 L

.71207 .11547 L

.71277 .11601 L

.71348 .11655 L

.71418 .11707 L

.71489 .11759 L

.71559 .1181 L

.7163 .1186 L

.717 .11909 L

.71771 .11957 L

.71841 .12005 L

.71911 .12053 L

.71982 .12099 L

.72052 .12145 L

.72123 .1219 L

.72193 .12235 L

.72264 .12279 L

.72334 .12323 L

.72404 .12366 L

.72475 .12409 L

.72545 .12451 L

.72616 .12493 L

Mistroke

.72686 .12534 L

.72757 .12575 L

.72827 .12615 L

.72897 .12655 L

.72968 .12695 L

.73038 .12734 L

.73109 .12773 L

.73179 .12812 L

.7325 .1285 L

.7332 .12888 L

.7339 .12925 L

.73461 .12962 L

.73531 .12999 L

.73602 .13036 L

.73672 .13072 L

.73743 .13108 L

.73813 .13144 L

.73883 .13179 L

.73954 .13214 L

.74024 .13249 L

.74095 .13283 L

.74165 .13318 L

.74236 .13352 L

.74306 .13386 L

.74377 .13419 L

.74447 .13452 L

.74517 .13485 L

.74588 .13518 L

.74658 .13551 L

.74729 .13583 L

.74799 .13616 L

.7487 .13648 L

.7494 .13679 L

.7501 .13711 L

.75081 .13743 L

.75151 .13774 L

.75222 .13805 L

.75292 .13836 L

.75363 .13866 L

.75433 .13897 L

.75503 .13927 L

.75574 .13957 L

.75644 .13987 L

.75715 .14017 L

.75785 .14046 L

.75856 .14076 L

.75926 .14105 L

.75996 .14134 L

.76067 .14163 L

.76137 .14192 L

Mistroke

.76208 .14221 L

.76278 .14249 L

.76349 .14278 L

.76419 .14306 L

.76489 .14334 L

.7656 .14362 L

.7663 .1439 L

.76701 .14418 L

.76771 .14445 L

.76842 .14473 L

.76912 .145 L

.76982 .14527 L

.77053 .14555 L

.77123 .14581 L

.77194 .14608 L

.77264 .14635 L

.77335 .14662 L

.77405 .14688 L

.77476 .14715 L

.77546 .14741 L

.77616 .14767 L

.77687 .14793 L

.77757 .14819 L

.77828 .14845 L

.77898 .14871 L

.77969 .14896 L

.78039 .14922 L

.78109 .14947 L

.7818 .14972 L

.7825 .14998 L

.78321 .15023 L

.78391 .15048 L

.78462 .15073 L

.78532 .15098 L

.78602 .15122 L

.78673 .15147 L

.78743 .15172 L

.78814 .15196 L

.78884 .15221 L

.78955 .15245 L

.79025 .15269 L

.79095 .15293 L

.79166 .15317 L

.79236 .15341 L

.79307 .15365 L

.79377 .15389 L

.79448 .15413 L

.79518 .15437 L

.79588 .1546 L

.79659 .15484 L

Mistroke

.79729 .15507 L

.798 .15531 L

.7987 .15554 L

.79941 .15577 L

.80011 .156 L

.80081 .15623 L

.80152 .15646 L

.80222 .15669 L

.80293 .15692 L

.80363 .15715 L

.80434 .15738 L

.80504 .1576 L

.80575 .15783 L

.80645 .15806 L

.80715 .15828 L

.80786 .1585 L

.80856 .15873 L

.80927 .15895 L

.80997 .15917 L

.81068 .15939 L

.81138 .15962 L

.81208 .15984 L

.81279 .16006 L

.81349 .16027 L

.8142 .16049 L

.8149 .16071 L

.81561 .16093 L

.81631 .16115 L

.81701 .16136 L

.81772 .16158 L

.81842 .16179 L

.81913 .16201 L

.81983 .16222 L

.82054 .16243 L

.82124 .16265 L

.82194 .16286 L

.82265 .16307 L

.82335 .16328 L

.82406 .16349 L

.82476 .16371 L

.82547 .16392 L

.82617 .16412 L

.82687 .16433 L

.82758 .16454 L

.82828 .16475 L

.82899 .16496 L

.82969 .16516 L

.8304 .16537 L

.8311 .16558 L

.8318 .16578 L

Mistroke

.83251 .16599 L

.83321 .16619 L

.83392 .1664 L

.83462 .1666 L

.83533 .1668 L

.83603 .16701 L

.83674 .16721 L

.83744 .16741 L

.83814 .16761 L

.83885 .16781 L

.83955 .16802 L

.84026 .16822 L

.84096 .16842 L

.84167 .16861 L

.84237 .16881 L

.84307 .16901 L

.84378 .16921 L

.84448 .16941 L

.84519 .16961 L

.84589 .1698 L

.8466 .17 L

.8473 .1702 L

.848 .17039 L

.84871 .17059 L

.84941 .17078 L

.85012 .17098 L

.85082 .17117 L

.85153 .17137 L

.85223 .17156 L

.85293 .17175 L

.85364 .17195 L

.85434 .17214 L

.85505 .17233 L

.85575 .17252 L

.85646 .17272 L

.85716 .17291 L

.85786 .1731 L

.85857 .17329 L

.85927 .17348 L

.85998 .17367 L

.86068 .17386 L

.86139 .17405 L

.86209 .17424 L

.8628 .17442 L

.8635 .17461 L

.8642 .1748 L

.86491 .17499 L

.86561 .17517 L

.86632 .17536 L

.86702 .17555 L

Mistroke

.86773 .17573 L

.86843 .17592 L

.86913 .17611 L

.86984 .17629 L

.87054 .17648 L

.87125 .17666 L

.87195 .17685 L

.87266 .17703 L

.87336 .17721 L

.87406 .1774 L

.87477 .17758 L

.87547 .17776 L

.87618 .17795 L

.87688 .17813 L

.87759 .17831 L

.87829 .17849 L

.87899 .17867 L

.8797 .17886 L

.8804 .17904 L

.88111 .17922 L

.88181 .1794 L

.88252 .17958 L

.88322 .17976 L

.88392 .17994 L

.88463 .18012 L

.88533 .1803 L

.88604 .18048 L

.88674 .18065 L

.88745 .18083 L

.88815 .18101 L

.88885 .18119 L

.88956 .18137 L

.89026 .18154 L

.89097 .18172 L

.89167 .1819 L

.89238 .18207 L

.89308 .18225 L

.89379 .18243 L

.89449 .1826 L

.89519 .18278 L

.8959 .18295 L

.8966 .18313 L

.89731 .1833 L

.89801 .18348 L

.89872 .18365 L

.89942 .18383 L

.90012 .184 L

.90083 .18417 L

.90153 .18435 L

.90224 .18452 L

Mistroke

.90294 .18469 L

.90365 .18487 L

.90435 .18504 L

.90505 .18521 L

.90576 .18538 L

.90646 .18556 L

.90717 .18573 L

.90787 .1859 L

.90858 .18607 L

.90928 .18624 L

.90998 .18641 L

.91069 .18658 L

.91139 .18675 L

.9121 .18692 L

.9128 .18709 L

.91351 .18726 L

.91421 .18743 L

.91491 .1876 L

.91562 .18777 L

.91632 .18794 L

.91703 .18811 L

.91773 .18828 L

.91844 .18845 L

.91914 .18861 L

.91984 .18878 L

.92055 .18895 L

.92125 .18912 L

.92196 .18929 L

.92266 .18945 L

.92337 .18962 L

.92407 .18979 L

.92478 .18995 L

.92548 .19012 L

.92618 .19029 L

.92689 .19045 L

.92759 .19062 L

.9283 .19078 L

.929 .19095 L

.92971 .19111 L

.93041 .19128 L

.93111 .19144 L

.93182 .19161 L

.93252 .19177 L

.93323 .19194 L

.93393 .1921 L

.93464 .19227 L

.93534 .19243 L

.93604 .19259 L

.93675 .19276 L

.93745 .19292 L

Mistroke

.93816 .19308 L

.93886 .19325 L

.93957 .19341 L

.94027 .19357 L

.94097 .19373 L

.94168 .1939 L

.94238 .19406 L

.94309 .19422 L

.94379 .19438 L

.9445 .19454 L

.9452 .1947 L

.9459 .19487 L

.94661 .19503 L

.94731 .19519 L

.94802 .19535 L

.94872 .19551 L

.94943 .19567 L

.95013 .19583 L

.95083 .19599 L

.95154 .19615 L

.95224 .19631 L

.95295 .19647 L

.95365 .19663 L

.95436 .19679 L

.95506 .19695 L

.95577 .1971 L

.95647 .19726 L

.95717 .19742 L

.95788 .19758 L

.95858 .19774 L

.95929 .1979 L

.95999 .19806 L

.9607 .19821 L

.9614 .19837 L

.9621 .19853 L

.96281 .19869 L

.96351 .19884 L

.96422 .199 L

.96492 .19916 L

.96563 .19931 L

.96633 .19947 L

.96703 .19963 L

.96774 .19978 L

.96844 .19994 L

.96915 .2001 L

.96985 .20025 L

.97056 .20041 L

.97126 .20056 L

.97196 .20072 L

.97267 .20088 L

Mistroke

.97337 .20103 L

.97408 .20119 L

.97478 .20134 L

.97549 .2015 L

.97619 .20165 L

Mfstroke

1 0 0 r

.54163 .13334 m

.54022 .13284 L

.53881 .13233 L

.5374 .13183 L

.53599 .13133 L

.53458 .13084 L

.53317 .13034 L

.53176 .12985 L

.53036 .12935 L

.52895 .12886 L

.52754 .12837 L

.52613 .12788 L

.52472 .1274 L

.52331 .12691 L

.5219 .12643 L

.5205 .12594 L

.51909 .12546 L

.51768 .12498 L

.51627 .12451 L

.51486 .12403 L

.51345 .12355 L

.51204 .12308 L

.51064 .12261 L

.50923 .12214 L

.50782 .12167 L

.50641 .1212 L

.505 .12073 L

.50359 .12027 L

.50218 .1198 L

.50077 .11934 L

.49937 .11888 L

.49796 .11841 L

.49655 .11795 L

.49514 .1175 L

.49373 .11704 L

.49232 .11658 L

.49091 .11613 L

.48951 .11568 L

.4881 .11522 L

.48669 .11477 L

.48528 .11432 L

.48387 .11387 L

.48246 .11342 L

.48105 .11298 L

.47965 .11253 L

.47824 .11209 L

.47683 .11164 L

.47542 .1112 L

.47401 .11076 L

.4726 .11032 L

Mistroke

.47119 .10988 L

.46978 .10944 L

.46838 .10901 L

.46697 .10857 L

.46556 .10814 L

.46415 .1077 L

.46274 .10727 L

.46133 .10684 L

.45992 .10641 L

.45852 .10598 L

.45711 .10555 L

.4557 .10513 L

.45429 .1047 L

.45288 .10427 L

.45147 .10385 L

.45006 .10343 L

.44866 .103 L

.44725 .10258 L

.44584 .10216 L

.44443 .10174 L

.44302 .10133 L

.44161 .10091 L

.4402 .10049 L

.43879 .10008 L

.43739 .09967 L

.43598 .09925 L

.43457 .09884 L

.43316 .09843 L

.43175 .09802 L

.43034 .09761 L

.42893 .0972 L

.42753 .0968 L

.42612 .09639 L

.42471 .09599 L

.4233 .09558 L

.42189 .09518 L

.42048 .09478 L

.41907 .09438 L

.41767 .09398 L

.41626 .09358 L

.41485 .09319 L

.41344 .09279 L

.41203 .09239 L

.41062 .092 L

.40921 .09161 L

.4078 .09122 L

.4064 .09083 L

.40499 .09044 L

.40358 .09005 L

.40217 .08966 L

Mistroke

.40076 .08928 L

.39935 .08889 L

.39794 .08851 L

.39654 .08813 L

.39513 .08774 L

.39372 .08736 L

.39231 .08698 L

.3909 .08661 L

.38949 .08623 L

.38808 .08586 L

.38667 .08548 L

.38527 .08511 L

.38386 .08474 L

.38245 .08437 L

.38104 .084 L

.37963 .08363 L

.37822 .08326 L

.37681 .0829 L

.37541 .08254 L

.374 .08217 L

.37259 .08181 L

.37118 .08145 L

.36977 .0811 L

.36836 .08074 L

.36695 .08038 L

.36555 .08003 L

.36414 .07968 L

.36273 .07933 L

.36132 .07898 L

.35991 .07863 L

.3585 .07828 L

.35709 .07794 L

.35568 .07759 L

.35428 .07725 L

.35287 .07691 L

.35146 .07657 L

.35005 .07624 L

.34864 .0759 L

.34723 .07557 L

.34582 .07524 L

.34442 .07491 L

.34301 .07458 L

.3416 .07425 L

.34019 .07393 L

.33878 .07361 L

.33737 .07328 L

.33596 .07296 L

.33456 .07265 L

.33315 .07233 L

.33174 .07202 L

Mistroke

.33033 .07171 L

.32892 .0714 L

.32751 .07109 L

.3261 .07078 L

.32469 .07048 L

.32329 .07018 L

.32188 .06988 L

.32047 .06958 L

.31906 .06928 L

.31765 .06899 L

.31624 .0687 L

.31483 .06841 L

.31343 .06813 L

.31202 .06784 L

.31061 .06756 L

.3092 .06728 L

.30779 .06701 L

.30638 .06673 L

.30497 .06646 L

.30357 .06619 L

.30216 .06592 L

.30075 .06566 L

.29934 .0654 L

.29793 .06514 L

.29652 .06488 L

.29511 .06463 L

.2937 .06438 L

.2923 .06413 L

.29089 .06389 L

.28948 .06365 L

.28807 .0634 L

.28666 .06317 L

.28525 .06294 L

.28384 .06271 L

.28244 .06248 L

.28103 .06225 L

.27962 .06203 L

.27821 .06182 L

.2768 .0616 L

.27539 .06139 L

.27398 .06119 L

.27258 .06098 L

.27117 .06078 L

.26976 .06059 L

.26835 .06039 L

.26694 .0602 L

.26553 .06002 L

.26412 .05984 L

.26271 .05966 L

.26131 .05948 L

Mistroke

.2599 .05931 L

.25849 .05915 L

.25708 .05898 L

.25567 .05883 L

.25426 .05867 L

.25285 .05852 L

.25145 .05838 L

.25004 .05824 L

.24863 .0581 L

.24722 .05797 L

.24581 .05784 L

.2444 .05772 L

.24299 .0576 L

.24159 .05749 L

.24018 .05738 L

.23877 .05727 L

.23736 .05717 L

.23595 .05708 L

.23454 .05699 L

.23313 .05691 L

.23172 .05683 L

.23032 .05676 L

.22891 .05669 L

.2275 .05663 L

.22609 .05657 L

.22468 .05652 L

.22327 .05648 L

.22186 .05644 L

.22046 .05641 L

.21905 .05638 L

.21764 .05636 L

.21623 .05635 L

.21482 .05634 L

.21341 .05634 L

.212 .05635 L

.2106 .05636 L

.20919 .05638 L

.20778 .0564 L

.20637 .05644 L

.20496 .05648 L

.20355 .05653 L

.20214 .05658 L

.20073 .05664 L

.19933 .05671 L

.19792 .05679 L

.19651 .05688 L

.1951 .05697 L

.19369 .05707 L

.19228 .05718 L

.19087 .0573 L

Mistroke

.18524 .05786 L

.17961 .05857 L

.17397 .05944 L

.16834 .06047 L

.1627 .06168 L

.15707 .06309 L

.15143 .0647 L

.1458 .06653 L

.14016 .0686 L

.13453 .07093 L

.12889 .07355 L

.12326 .07647 L

.11762 .07971 L

.11199 .08332 L

.10636 .08733 L

.10072 .09178 L

.09509 .0967 L

.08945 .10217 L

.08382 .10824 L

.07818 .115 L

.07255 .12254 L

.06691 .13099 L

.06128 .14053 L

.05564 .15137 L

.05001 .16384 L

.04438 .17847 L

.03874 .19611 L

.03311 .21861 L

.02747 .25147 L

.02381 .30902 L

Mfstroke

0 1 .4 r

.96422 .5251 m

.96281 .52535 L

.9614 .52559 L

.95999 .52584 L

.95858 .52609 L

.95717 .52633 L

.95577 .52658 L

.95436 .52683 L

.95295 .52707 L

.95154 .52732 L

.95013 .52757 L

.94872 .52782 L

.94731 .52806 L

.9459 .52831 L

.9445 .52856 L

.94309 .52881 L

.94168 .52906 L

.94027 .52931 L

.93886 .52956 L

.93745 .52981 L

.93604 .53006 L

.93464 .53031 L

.93323 .53056 L

.93182 .53081 L

.93041 .53106 L

.929 .53131 L

.92759 .53156 L

.92618 .53182 L

.92478 .53207 L

.92337 .53232 L

.92196 .53257 L

.92055 .53282 L

.91914 .53308 L

.91773 .53333 L

.91632 .53358 L

.91491 .53383 L

.91351 .53409 L

.9121 .53434 L

.91069 .53459 L

.90928 .53485 L

.90787 .5351 L

.90646 .53535 L

.90505 .53561 L

.90365 .53586 L

.90224 .53612 L

.90083 .53637 L

.89942 .53663 L

.89801 .53688 L

.8966 .53714 L

.89519 .53739 L

Mistroke

.89379 .53765 L

.89238 .5379 L

.89097 .53816 L

.88956 .53841 L

.88815 .53867 L

.88674 .53892 L

.88533 .53918 L

.88392 .53943 L

.88252 .53969 L

.88111 .53994 L

.8797 .5402 L

.87829 .54045 L

.87688 .54071 L

.87547 .54096 L

.87406 .54122 L

.87266 .54147 L

.87125 .54173 L

.86984 .54199 L

.86843 .54224 L

.86702 .54249 L

.86561 .54275 L

.8642 .54301 L

.8628 .54326 L

.86139 .54351 L

.85998 .54377 L

.85857 .54402 L

.85716 .54428 L

.85575 .54453 L

.85434 .54478 L

.85293 .54504 L

.85153 .54529 L

.85012 .54554 L

.84871 .5458 L

.8473 .54605 L

.84589 .5463 L

.84448 .54655 L

.84307 .5468 L

.84167 .54705 L

.84026 .5473 L

.83885 .54755 L

.83744 .5478 L

.83603 .54805 L

.83462 .5483 L

.83321 .54855 L

.8318 .5488 L

.8304 .54904 L

.82899 .54929 L

.82758 .54953 L

.82617 .54978 L

.82476 .55002 L

Mistroke

.82335 .55026 L

.82194 .5505 L

.82054 .55074 L

.81913 .55098 L

.81772 .55122 L

.81631 .55146 L

.8149 .5517 L

.81349 .55193 L

.81208 .55216 L

.81068 .5524 L

.80927 .55263 L

.80786 .55286 L

.80645 .55309 L

.80504 .55331 L

.80363 .55354 L

.80222 .55376 L

.80081 .55398 L

.79941 .5542 L

.798 .55442 L

.79659 .55463 L

.79518 .55484 L

.79377 .55505 L

.79236 .55526 L

.79095 .55547 L

.78955 .55567 L

.78814 .55587 L

.78673 .55607 L

.78532 .55626 L

.78391 .55645 L

.7825 .55664 L

.78109 .55682 L

.77969 .55699 L

.77828 .55717 L

.77687 .55734 L

.77546 .5575 L

.77405 .55767 L

.77264 .55782 L

.77123 .55797 L

.76982 .55812 L

.76842 .55826 L

.76701 .55839 L

.7656 .55851 L

.76419 .55863 L

.76278 .55875 L

.76137 .55885 L

.75996 .55895 L

.75856 .55904 L

.75715 .55913 L

.75574 .5592 L

.75433 .55926 L

Mistroke

.75292 .55932 L

.75151 .55936 L

.7501 .5594 L

.7487 .55942 L

.74729 .55943 L

.74588 .55943 L

.74447 .55941 L

.74306 .55939 L

.74165 .55935 L

.74024 .55929 L

.73883 .55922 L

.73743 .55913 L

.73602 .55903 L

.73461 .55891 L

.7332 .55877 L

.73179 .55861 L

.73038 .55844 L

.72897 .55824 L

.72757 .55801 L

.72616 .55777 L

.72475 .5575 L

.72334 .55721 L

.72193 .55689 L

.72052 .55654 L

.71911 .55616 L

.71771 .55574 L

.7163 .55529 L

.71489 .5548 L

.71348 .55428 L

.71207 .5537 L

.71066 .55308 L

.70925 .5524 L

.70784 .55167 L

.70644 .55087 L

.70503 .54999 L

.70362 .54902 L

.70221 .54795 L

.7008 .54675 L

.69939 .54538 L

.69798 .54378 L

.69658 .54187 L

.69517 .53938 L

.69376 .5354 L

Mfstroke

1 0 0 r

.54585 .48317 m

.54867 .48214 L

.55149 .48111 L

.5543 .48007 L

.55712 .47903 L

.55994 .47797 L

.56275 .47691 L

.56557 .47584 L

.56839 .47476 L

.57121 .47368 L

.57402 .47258 L

.57684 .47148 L

.57966 .47037 L

.58248 .46925 L

.58529 .46812 L

.58811 .46698 L

.59093 .46583 L

.59374 .46468 L

.59656 .46351 L

.59938 .46234 L

.6022 .46115 L

.60501 .45996 L

.60783 .45875 L

.61065 .45754 L

.61347 .45631 L

.61628 .45508 L

.6191 .45383 L

.62192 .45258 L

.62473 .45131 L

.62755 .45004 L

.63037 .44876 L

.63319 .44746 L

.636 .44616 L

.63882 .44484 L

.64164 .44352 L

.64446 .44218 L

.64727 .44083 L

.65009 .43948 L

.65291 .43811 L

.65573 .43673 L

.65854 .43535 L

.66136 .43395 L

.66418 .43254 L

.66699 .43112 L

.66981 .4297 L

.67263 .42826 L

.67545 .42681 L

.67826 .42535 L

.68108 .42387 L

.6839 .42239 L

Mistroke

.68672 .4209 L

.68953 .41939 L

.69235 .41787 L

.69517 .41634 L

.69798 .4148 L

.7008 .41325 L

.70362 .41168 L

.70644 .4101 L

.70925 .40851 L

.71207 .4069 L

.71489 .40528 L

.71771 .40364 L

.72052 .40199 L

.72334 .40032 L

.72616 .39864 L

.72897 .39694 L

.73179 .39522 L

.73461 .39348 L

.73743 .39172 L

.74024 .38994 L

.74306 .38814 L

.74588 .38632 L

.7487 .38447 L

.75151 .3826 L

.75433 .3807 L

.75715 .37877 L

.75996 .37682 L

.76278 .37483 L

.7656 .37281 L

.76842 .37075 L

.77123 .36866 L

.77405 .36653 L

.77687 .36435 L

.77969 .36213 L

.7825 .35986 L

.78532 .35754 L

.78814 .35516 L

.79095 .35272 L

.79377 .35022 L

.79659 .34764 L

.79941 .34499 L

.80222 .34225 L

.80504 .33941 L

.80786 .33647 L

.81068 .33342 L

.81349 .33023 L

.81631 .32691 L

.81913 .32341 L

.82194 .31973 L

.82476 .31582 L

Mistroke

.82758 .31166 L

.8304 .30718 L

.83321 .30233 L

.83603 .297 L

.83885 .29103 L

.84167 .28419 L

.84448 .27601 L

Mfstroke

.84603 .34743 m

.84617 .34797 L

.84631 .34852 L

.84645 .34907 L

.8466 .34963 L

.84674 .35021 L

.84688 .3508 L

.84702 .3514 L

.84716 .35201 L

.8473 .35263 L

.84744 .35327 L

.84758 .35392 L

.84772 .35459 L

.84786 .35528 L

.848 .35598 L

.84815 .3567 L

.84829 .35745 L

.84843 .35821 L

.84857 .359 L

.84871 .35982 L

.84885 .36067 L

.84899 .36156 L

.84913 .36247 L

.84927 .36343 L

.84941 .36445 L

.84955 .36551 L

.84969 .36664 L

.84984 .36786 L

.84998 .36916 L

.85012 .3706 L

.85026 .37222 L

.8504 .37404 L

.85054 .37627 L

.85068 .37932 L

s

.85068 .39115 m

.85054 .39434 L

.8504 .39665 L

.85026 .39859 L

.85012 .4003 L

.84998 .40184 L

.84984 .40326 L

.84969 .40458 L

.84955 .40582 L

.84941 .40699 L

.84927 .40812 L

.84913 .40917 L

.84899 .4102 L

.84885 .41119 L

.84871 .41213 L

.84857 .41306 L

.84843 .41395 L

.84829 .41482 L

.84815 .41567 L

.848 .41649 L

.84786 .4173 L

.84772 .41809 L

.84758 .41885 L

.84744 .41961 L

.8473 .42034 L

.84716 .42107 L

.84702 .42178 L

.84688 .42249 L

.84674 .42317 L

.8466 .42384 L

.84645 .42451 L

.84631 .42516 L

.84617 .42581 L

.84603 .42645 L

.84589 .42707 L

.84575 .42769 L

.84561 .42831 L

.84547 .42892 L

.84533 .42951 L

.84519 .4301 L

.84505 .43068 L

.84491 .43125 L

.84476 .43182 L

.84462 .43238 L

.84448 .43294 L

.84434 .43349 L

.8442 .43403 L

.84406 .43457 L

.84392 .4351 L

.84378 .43563 L

Mistroke

.84307 .43819 L

.84237 .44065 L

.84167 .44301 L

.84096 .44529 L

.84026 .44749 L

.83955 .44962 L

.83885 .45168 L

.83814 .45369 L

.83744 .45564 L

.83674 .45753 L

.83603 .45938 L

.83533 .46119 L

.83462 .46296 L

.83392 .46468 L

.83321 .46638 L

.83251 .46803 L

.8318 .46966 L

.8311 .47125 L

.8304 .4728 L

.82969 .47434 L

.82899 .47584 L

.82828 .47732 L

.82758 .47878 L

.82687 .4802 L

.82617 .48161 L

.82547 .48299 L

.82476 .48435 L

.82406 .48569 L

.82335 .48701 L

.82265 .4883 L

.82194 .48958 L

.82124 .49084 L

.82054 .49208 L

.81983 .4933 L

.81913 .49451 L

.81842 .4957 L

.81772 .49687 L

.81701 .49803 L

.81631 .49916 L

.81561 .50029 L

.8149 .5014 L

.8142 .50249 L

.81349 .50357 L

.81279 .50464 L

.81208 .50569 L

.81138 .50673 L

.81068 .50775 L

.80997 .50877 L

.80927 .50976 L

.80856 .51075 L

Mistroke

.80786 .51172 L

.80715 .51268 L

.80645 .51363 L

.80575 .51457 L

.80504 .51549 L

.80434 .51641 L

.80363 .51731 L

.80293 .5182 L

.80222 .51908 L

.80152 .51995 L

.80081 .52081 L

.80011 .52166 L

.79941 .52249 L

.7987 .52332 L

.798 .52414 L

.79729 .52494 L

.79659 .52574 L

.79588 .52653 L

.79518 .52731 L

.79448 .52807 L

.79377 .52883 L

.79307 .52958 L

.79236 .53032 L

.79166 .53105 L

.79095 .53178 L

.79025 .53249 L

.78955 .53319 L

.78884 .53389 L

.78814 .53458 L

.78743 .53526 L

.78673 .53592 L

.78602 .53659 L

.78532 .53724 L

.78462 .53788 L

.78391 .53852 L

.78321 .53915 L

.7825 .53978 L

.7818 .54039 L

.78109 .541 L

.78039 .54159 L

.77969 .54219 L

.77898 .54277 L

.77828 .54335 L

.77757 .54392 L

.77687 .54448 L

.77616 .54503 L

.77546 .54558 L

.77476 .54612 L

.77405 .54666 L

.77335 .54718 L

Mistroke

.77264 .5477 L

.77194 .54822 L

.77123 .54872 L

.77053 .54922 L

.76982 .54972 L

.76912 .55021 L

.76842 .55069 L

.76771 .55117 L

.76701 .55163 L

.7663 .5521 L

.7656 .55255 L

.76489 .553 L

.76419 .55345 L

.76349 .55389 L

.76278 .55432 L

.76208 .55475 L

.76137 .55517 L

.76067 .55559 L

.75996 .556 L

.75926 .55641 L

.75856 .55681 L

.75785 .5572 L

.75715 .55759 L

.75644 .55798 L

.75574 .55836 L

.75503 .55873 L

.75433 .5591 L

.75363 .55947 L

.75292 .55983 L

.75222 .56019 L

.75151 .56054 L

.75081 .56088 L

.7501 .56122 L

.7494 .56156 L

.7487 .5619 L

.74799 .56222 L

.74729 .56255 L

.74658 .56287 L

.74588 .56319 L

.74517 .5635 L

.74447 .56381 L

.74377 .56411 L

.74306 .56441 L

.74236 .56471 L

.74165 .565 L

.74095 .56529 L

.74024 .56558 L

.73954 .56586 L

.73883 .56614 L

.73813 .56641 L

Mistroke

.73743 .56669 L

.73672 .56695 L

.73602 .56722 L

.73531 .56748 L

.73461 .56774 L

.7339 .568 L

.7332 .56825 L

.7325 .5685 L

.73179 .56875 L

.73109 .56899 L

.73038 .56924 L

.72968 .56947 L

.72897 .56971 L

.72827 .56995 L

.72757 .57018 L

.72686 .57041 L

.72616 .57063 L

.72545 .57086 L

.72475 .57108 L

.72404 .5713 L

.72334 .57151 L

.72264 .57173 L

.72193 .57194 L

.72123 .57216 L

.72052 .57236 L

.71982 .57257 L

.71911 .57278 L

.71841 .57298 L

.71771 .57318 L

.717 .57338 L

.7163 .57358 L

.71559 .57378 L

.71489 .57397 L

.71418 .57416 L

.71348 .57436 L

.71277 .57455 L

.71207 .57473 L

.71137 .57492 L

.71066 .57511 L

.70996 .57529 L

.70925 .57547 L

.70855 .57565 L

.70784 .57584 L

.70714 .57601 L

.70644 .57619 L

.70573 .57637 L

.70503 .57654 L

.70432 .57672 L

.70362 .57689 L

.70291 .57706 L

Mistroke

.70221 .57724 L

.70151 .5774 L

.7008 .57757 L

.7001 .57774 L

.69939 .57791 L

.69869 .57808 L

.69798 .57824 L

.69728 .57841 L

.69658 .57857 L

.69587 .57873 L

.69517 .57889 L

.69446 .57905 L

.69376 .57922 L

.69305 .57938 L

.69235 .57953 L

.69165 .57969 L

.69094 .57985 L

.69024 .58001 L

.68953 .58016 L

.68883 .58032 L

.68812 .58047 L

.68742 .58063 L

.68672 .58078 L

.68601 .58093 L

.68531 .58109 L

.6846 .58124 L

.6839 .58139 L

.68319 .58154 L

.68249 .58169 L

.68178 .58184 L

.68108 .58199 L

.68038 .58214 L

.67967 .58229 L

.67897 .58243 L

.67826 .58258 L

.67756 .58273 L

.67685 .58287 L

.67615 .58302 L

.67545 .58317 L

.67474 .58331 L

.67404 .58346 L

.67333 .5836 L

.67263 .58374 L

.67192 .58389 L

.67122 .58403 L

.67052 .58417 L

.66981 .58432 L

.66911 .58446 L

.6684 .5846 L

.6677 .58474 L

Mistroke

.66699 .58488 L

.66629 .58502 L

.66559 .58516 L

.66488 .5853 L

.66418 .58544 L

.66347 .58558 L

.66277 .58572 L

.66206 .58586 L

.66136 .58599 L

.66066 .58613 L

.65995 .58627 L

.65925 .58641 L

.65854 .58654 L

.65784 .58668 L

.65713 .58682 L

.65643 .58695 L

.65573 .58709 L

.65502 .58722 L

.65432 .58736 L

.65361 .58749 L

.65291 .58762 L

.6522 .58776 L

.6515 .58789 L

.65079 .58802 L

.65009 .58816 L

.64939 .58829 L

.64868 .58842 L

.64798 .58855 L

.64727 .58868 L

.64657 .58881 L

.64586 .58895 L

.64516 .58908 L

.64446 .58921 L

.64375 .58934 L

.64305 .58946 L

.64234 .58959 L

.64164 .58972 L

.64093 .58985 L

.64023 .58998 L

.63953 .59011 L

.63882 .59024 L

.63812 .59036 L

.63741 .59049 L

.63671 .59062 L

.636 .59074 L

.6353 .59087 L

.6346 .59099 L

.63389 .59112 L

.63319 .59124 L

.63248 .59137 L

Mistroke

.63178 .59149 L

.63107 .59161 L

.63037 .59174 L

.62967 .59186 L

.62896 .59198 L

.62826 .59211 L

.62755 .59223 L

.62685 .59235 L

.62614 .59247 L

.62544 .59259 L

.62473 .59271 L

.62403 .59283 L

.62333 .59295 L

.62262 .59307 L

.62192 .59319 L

.62121 .59331 L

.62051 .59343 L

.6198 .59354 L

.6191 .59366 L

.6184 .59378 L

.61769 .5939 L

.61699 .59401 L

.61628 .59413 L

.61558 .59424 L

.61487 .59436 L

.61417 .59447 L

.61347 .59459 L

.61276 .5947 L

.61206 .59481 L

.61135 .59492 L

.61065 .59504 L

.60994 .59515 L

.60924 .59526 L

.60854 .59537 L

.60783 .59548 L

.60713 .59559 L

.60642 .5957 L

.60572 .59581 L

.60501 .59592 L

.60431 .59603 L

.60361 .59613 L

.6029 .59624 L

.6022 .59634 L

.60149 .59645 L

.60079 .59655 L

.60008 .59666 L

.59938 .59677 L

.59868 .59687 L

.59797 .59697 L

.59727 .59707 L

Mistroke

.59656 .59718 L

.59586 .59728 L

.59515 .59738 L

.59445 .59748 L

.59374 .59758 L

.59304 .59768 L

.59234 .59778 L

.59163 .59787 L

.59093 .59797 L

.59022 .59807 L

.58952 .59817 L

.58881 .59826 L

.58811 .59836 L

.58741 .59845 L

.5867 .59855 L

.586 .59864 L

.58529 .59873 L

.58459 .59882 L

.58388 .59891 L

.58318 .599 L

.58248 .59909 L

.58177 .59918 L

.58107 .59927 L

.58036 .59936 L

.57966 .59945 L

.57895 .59953 L

.57825 .59962 L

.57755 .5997 L

.57684 .59979 L

.57614 .59987 L

.57543 .59995 L

.57473 .60003 L

.57402 .60011 L

.57332 .60019 L

.57262 .60027 L

.57191 .60035 L

.57121 .60043 L

.5705 .60051 L

.5698 .60058 L

.56909 .60066 L

.56839 .60073 L

.56769 .60081 L

.56698 .60088 L

.56628 .60095 L

.56557 .60102 L

.56487 .6011 L

.56416 .60116 L

.56346 .60123 L

.56275 .6013 L

.56205 .60137 L

Mistroke

.56064 .6015 L

.55923 .60163 L

.55782 .60175 L

.55642 .60187 L

.55501 .60198 L

.5536 .60209 L

.55219 .6022 L

.55078 .6023 L

.54937 .6024 L

.54796 .6025 L

.54656 .60258 L

.54515 .60267 L

.54374 .60275 L

.54233 .60283 L

.54092 .6029 L

.53951 .60296 L

.5381 .60302 L

.5367 .60308 L

.53529 .60312 L

.53388 .60317 L

.53247 .60321 L

.53106 .60324 L

.52965 .60327 L

.52824 .60329 L

.52683 .60331 L

.52543 .60331 L

.52402 .60332 L

.52261 .60331 L

.5212 .60331 L

.51979 .60329 L

.51838 .60327 L

.51697 .60323 L

.51557 .6032 L

.51416 .60315 L

.51275 .6031 L

.51134 .60304 L

.50993 .60297 L

.50852 .6029 L

.50711 .60282 L

.5057 .60272 L

.5043 .60262 L

.50289 .60252 L

.50148 .6024 L

.50007 .60228 L

.49866 .60214 L

.49725 .602 L

.49584 .60184 L

.49444 .60168 L

.49303 .60151 L

.49162 .60132 L

Mistroke

.49021 .60113 L

.4888 .60093 L

.48739 .60071 L

.48598 .60049 L

.48458 .60025 L

.48317 .6 L

.48176 .59974 L

.48035 .59947 L

.47894 .59919 L

.47753 .59889 L

.47612 .59858 L

.47471 .59826 L

.47331 .59793 L

.4719 .59758 L

.47049 .59722 L

.46908 .59684 L

.46767 .59645 L

.46626 .59605 L

.46485 .59563 L

.46345 .59519 L

.46204 .59474 L

.46063 .59427 L

.45922 .59379 L

.45781 .59329 L

.4564 .59277 L

.45499 .59224 L

.45359 .59168 L

.45218 .59111 L

.45077 .59052 L

.44936 .58991 L

.44795 .58928 L

.44654 .58863 L

.44513 .58796 L

.44372 .58727 L

.44232 .58656 L

.44091 .58583 L

.4395 .58507 L

.43809 .58429 L

.43668 .58349 L

.43527 .58266 L

.43386 .5818 L

.43246 .58092 L

.43105 .58002 L

.42964 .57909 L

.42823 .57813 L

.42682 .57714 L

.42541 .57612 L

.424 .57508 L

.4226 .574 L

.42119 .57289 L

Mistroke

.41978 .57175 L

.41837 .57058 L

.41696 .56937 L

.41555 .56813 L

.41414 .56685 L

.41273 .56554 L

.41133 .56419 L

.40992 .56279 L

.40851 .56136 L

.4071 .55989 L

.40569 .55837 L

.40428 .55681 L

.40287 .55521 L

.40147 .55355 L

.40006 .55185 L

.39865 .5501 L

.39724 .5483 L

.39583 .54644 L

.39442 .54453 L

.39301 .54256 L

.39161 .54053 L

.3902 .53844 L

.38879 .53629 L

.38738 .53407 L

.38597 .53178 L

.38456 .52942 L

.38315 .52698 L

.38174 .52446 L

.38034 .52186 L

.37893 .51918 L

.37752 .51641 L

.37611 .51354 L

.3747 .51057 L

.37329 .5075 L

.37188 .50432 L

.37048 .50102 L

.36907 .4976 L

.36766 .49404 L

.36625 .49035 L

.36484 .4865 L

.36343 .4825 L

.36202 .47832 L

.36062 .47395 L

.35921 .46938 L

.3578 .46459 L

.35639 .45955 L

.35498 .45424 L

.35357 .44862 L

.35216 .44266 L

.35075 .4363 L

Mistroke

.34935 .42948 L

.34794 .42212 L

.34653 .4141 L

.34512 .40526 L

.34371 .39533 L

.3423 .38389 L

.34089 .37008 L

.33949 .35167 L

.33816 .30902 L

Mfstroke

0 1 .4 r

.6939 .52611 m

.69404 .52557 L

.69418 .52507 L

.69432 .52461 L

.69446 .52418 L

.69517 .52232 L

.69587 .52078 L

.69658 .51943 L

.69728 .51822 L

.69798 .5171 L

.69869 .51606 L

.69939 .51508 L

.7001 .51416 L

.7008 .51328 L

.70151 .51244 L

.70221 .51163 L

.70291 .51086 L

.70362 .51011 L

.70432 .50939 L

.70503 .50868 L

.70573 .508 L

.70644 .50734 L

.70714 .50669 L

.70784 .50606 L

.70855 .50545 L

.70925 .50485 L

.70996 .50426 L

.71066 .50368 L

.71137 .50312 L

.71207 .50256 L

.71277 .50202 L

.71348 .50149 L

.71418 .50096 L

.71489 .50045 L

.71559 .49994 L

.7163 .49944 L

.717 .49894 L

.71771 .49846 L

.71841 .49798 L

.71911 .49751 L

.71982 .49704 L

.72052 .49658 L

.72123 .49613 L

.72193 .49568 L

.72264 .49524 L

.72334 .4948 L

.72404 .49437 L

.72475 .49395 L

.72545 .49352 L

.72616 .4931 L

Mistroke

.72686 .49269 L

.72757 .49228 L

.72827 .49188 L

.72897 .49148 L

.72968 .49108 L

.73038 .49069 L

.73109 .4903 L

.73179 .48992 L

.7325 .48953 L

.7332 .48916 L

.7339 .48878 L

.73461 .48841 L

.73531 .48804 L

.73602 .48768 L

.73672 .48731 L

.73743 .48695 L

.73813 .4866 L

.73883 .48624 L

.73954 .48589 L

.74024 .48555 L

.74095 .4852 L

.74165 .48486 L

.74236 .48452 L

.74306 .48418 L

.74377 .48384 L

.74447 .48351 L

.74517 .48318 L

.74588 .48285 L

.74658 .48252 L

.74729 .4822 L

.74799 .48188 L

.7487 .48156 L

.7494 .48124 L

.7501 .48092 L

.75081 .48061 L

.75151 .4803 L

.75222 .47999 L

.75292 .47968 L

.75363 .47937 L

.75433 .47907 L

.75503 .47876 L

.75574 .47846 L

.75644 .47816 L

.75715 .47787 L

.75785 .47757 L

.75856 .47727 L

.75926 .47698 L

.75996 .47669 L

.76067 .4764 L

.76137 .47611 L

Mistroke

.76208 .47583 L

.76278 .47554 L

.76349 .47526 L

.76419 .47497 L

.76489 .47469 L

.7656 .47441 L

.7663 .47413 L

.76701 .47386 L

.76771 .47358 L

.76842 .47331 L

.76912 .47303 L

.76982 .47276 L

.77053 .47249 L

.77123 .47222 L

.77194 .47195 L

.77264 .47168 L

.77335 .47142 L

.77405 .47115 L

.77476 .47089 L

.77546 .47063 L

.77616 .47036 L

.77687 .4701 L

.77757 .46984 L

.77828 .46959 L

.77898 .46933 L

.77969 .46907 L

.78039 .46882 L

.78109 .46856 L

.7818 .46831 L

.7825 .46806 L

.78321 .46781 L

.78391 .46755 L

.78462 .46731 L

.78532 .46706 L

.78602 .46681 L

.78673 .46656 L

.78743 .46632 L

.78814 .46607 L

.78884 .46583 L

.78955 .46558 L

.79025 .46534 L

.79095 .4651 L

.79166 .46486 L

.79236 .46462 L

.79307 .46438 L

.79377 .46414 L

.79448 .4639 L

.79518 .46367 L

.79588 .46343 L

.79659 .4632 L

Mistroke

.79729 .46296 L

.798 .46273 L

.7987 .46249 L

.79941 .46226 L

.80011 .46203 L

.80081 .4618 L

.80152 .46157 L

.80222 .46134 L

.80293 .46111 L

.80363 .46088 L

.80434 .46066 L

.80504 .46043 L

.80575 .4602 L

.80645 .45998 L

.80715 .45975 L

.80786 .45953 L

.80856 .45931 L

.80927 .45908 L

.80997 .45886 L

.81068 .45864 L

.81138 .45842 L

.81208 .4582 L

.81279 .45798 L

.81349 .45776 L

.8142 .45754 L

.8149 .45732 L

.81561 .45711 L

.81631 .45689 L

.81701 .45667 L

.81772 .45646 L

.81842 .45624 L

.81913 .45603 L

.81983 .45581 L

.82054 .4556 L

.82124 .45539 L

.82194 .45517 L

.82265 .45496 L

.82335 .45475 L

.82406 .45454 L

.82476 .45433 L

.82547 .45412 L

.82617 .45391 L

.82687 .4537 L

.82758 .45349 L

.82828 .45328 L

.82899 .45308 L

.82969 .45287 L

.8304 .45266 L

.8311 .45246 L

.8318 .45225 L

Mistroke

.83251 .45205 L

.83321 .45184 L

.83392 .45164 L

.83462 .45143 L

.83533 .45123 L

.83603 .45103 L

.83674 .45082 L

.83744 .45062 L

.83814 .45042 L

.83885 .45022 L

.83955 .45002 L

.84026 .44982 L

.84096 .44962 L

.84167 .44942 L

.84237 .44922 L

.84307 .44902 L

.84378 .44882 L

.84448 .44862 L

.84519 .44843 L

.84589 .44823 L

.8466 .44803 L

.8473 .44784 L

.848 .44764 L

.84871 .44745 L

.84941 .44725 L

.85012 .44706 L

.85082 .44686 L

.85153 .44667 L

.85223 .44647 L

.85293 .44628 L

.85364 .44609 L

.85434 .44589 L

.85505 .4457 L

.85575 .44551 L

.85646 .44532 L

.85716 .44513 L

.85786 .44494 L

.85857 .44475 L

.85927 .44456 L

.85998 .44437 L

.86068 .44418 L

.86139 .44399 L

.86209 .4438 L

.8628 .44361 L

.8635 .44342 L

.8642 .44323 L

.86491 .44305 L

.86561 .44286 L

.86632 .44267 L

.86702 .44249 L

Mistroke

.86773 .4423 L

.86843 .44211 L

.86913 .44193 L

.86984 .44174 L

.87054 .44156 L

.87125 .44137 L

.87195 .44119 L

.87266 .441 L

.87336 .44082 L

.87406 .44064 L

.87477 .44045 L

.87547 .44027 L

.87618 .44009 L

.87688 .4399 L

.87759 .43972 L

.87829 .43954 L

.87899 .43936 L

.8797 .43918 L

.8804 .439 L

.88111 .43882 L

.88181 .43864 L

.88252 .43846 L

.88322 .43828 L

.88392 .4381 L

.88463 .43792 L

.88533 .43774 L

.88604 .43756 L

.88674 .43738 L

.88745 .4372 L

.88815 .43702 L

.88885 .43685 L

.88956 .43667 L

.89026 .43649 L

.89097 .43631 L

.89167 .43614 L

.89238 .43596 L

.89308 .43578 L

.89379 .43561 L

.89449 .43543 L

.89519 .43526 L

.8959 .43508 L

.8966 .43491 L

.89731 .43473 L

.89801 .43456 L

.89872 .43438 L

.89942 .43421 L

.90012 .43403 L

.90083 .43386 L

.90153 .43369 L

.90224 .43351 L

Mistroke

.90294 .43334 L

.90365 .43317 L

.90435 .43299 L

.90505 .43282 L

.90576 .43265 L

.90646 .43248 L

.90717 .43231 L

.90787 .43213 L

.90858 .43196 L

.90928 .43179 L

.90998 .43162 L

.91069 .43145 L

.91139 .43128 L

.9121 .43111 L

.9128 .43094 L

.91351 .43077 L

.91421 .4306 L

.91491 .43043 L

.91562 .43026 L

.91632 .43009 L

.91703 .42992 L

.91773 .42976 L

.91844 .42959 L

.91914 .42942 L

.91984 .42925 L

.92055 .42908 L

.92125 .42892 L

.92196 .42875 L

.92266 .42858 L

.92337 .42841 L

.92407 .42825 L

.92478 .42808 L

.92548 .42792 L

.92618 .42775 L

.92689 .42758 L

.92759 .42742 L

.9283 .42725 L

.929 .42709 L

.92971 .42692 L

.93041 .42676 L

.93111 .42659 L

.93182 .42643 L

.93252 .42626 L

.93323 .4261 L

.93393 .42593 L

.93464 .42577 L

.93534 .4256 L

.93604 .42544 L

.93675 .42528 L

.93745 .42511 L

Mistroke

.93816 .42495 L

.93886 .42479 L

.93957 .42463 L

.94027 .42446 L

.94097 .4243 L

.94168 .42414 L

.94238 .42398 L

.94309 .42381 L

.94379 .42365 L

.9445 .42349 L

.9452 .42333 L

.9459 .42317 L

.94661 .42301 L

.94731 .42285 L

.94802 .42269 L

.94872 .42253 L

.94943 .42237 L

.95013 .42221 L

.95083 .42205 L

.95154 .42189 L

.95224 .42173 L

.95295 .42157 L

.95365 .42141 L

.95436 .42125 L

.95506 .42109 L

.95577 .42093 L

.95647 .42077 L

.95717 .42061 L

.95788 .42045 L

.95858 .42029 L

.95929 .42014 L

.95999 .41998 L

.9607 .41982 L

.9614 .41966 L

.9621 .4195 L

.96281 .41935 L

.96351 .41919 L

.96422 .41903 L

.96492 .41888 L

.96563 .41872 L

.96633 .41856 L

.96703 .41841 L

.96774 .41825 L

.96844 .41809 L

.96915 .41794 L

.96985 .41778 L

.97056 .41763 L

.97126 .41747 L

.97196 .41731 L

.97267 .41716 L

Mistroke

.97337 .417 L

.97408 .41685 L

.97478 .41669 L

.97549 .41654 L

.97619 .41638 L

Mfstroke

1 0 0 r

.54163 .48469 m

.54022 .4852 L

.53881 .4857 L

.5374 .4862 L

.53599 .4867 L

.53458 .4872 L

.53317 .48769 L

.53176 .48819 L

.53036 .48868 L

.52895 .48917 L

.52754 .48966 L

.52613 .49015 L

.52472 .49064 L

.52331 .49112 L

.5219 .49161 L

.5205 .49209 L

.51909 .49257 L

.51768 .49305 L

.51627 .49353 L

.51486 .494 L

.51345 .49448 L

.51204 .49495 L

.51064 .49543 L

.50923 .4959 L

.50782 .49637 L

.50641 .49684 L

.505 .4973 L

.50359 .49777 L

.50218 .49823 L

.50077 .4987 L

.49937 .49916 L

.49796 .49962 L

.49655 .50008 L

.49514 .50054 L

.49373 .50099 L

.49232 .50145 L

.49091 .50191 L

.48951 .50236 L

.4881 .50281 L

.48669 .50326 L

.48528 .50371 L

.48387 .50416 L

.48246 .50461 L

.48105 .50506 L

.47965 .5055 L

.47824 .50595 L

.47683 .50639 L

.47542 .50683 L

.47401 .50727 L

.4726 .50771 L

Mistroke

.47119 .50815 L

.46978 .50859 L

.46838 .50903 L

.46697 .50946 L

.46556 .5099 L

.46415 .51033 L

.46274 .51076 L

.46133 .51119 L

.45992 .51162 L

.45852 .51205 L

.45711 .51248 L

.4557 .51291 L

.45429 .51334 L

.45288 .51376 L

.45147 .51418 L

.45006 .51461 L

.44866 .51503 L

.44725 .51545 L

.44584 .51587 L

.44443 .51629 L

.44302 .51671 L

.44161 .51712 L

.4402 .51754 L

.43879 .51795 L

.43739 .51837 L

.43598 .51878 L

.43457 .51919 L

.43316 .5196 L

.43175 .52001 L

.43034 .52042 L

.42893 .52083 L

.42753 .52124 L

.42612 .52164 L

.42471 .52205 L

.4233 .52245 L

.42189 .52285 L

.42048 .52325 L

.41907 .52365 L

.41767 .52405 L

.41626 .52445 L

.41485 .52485 L

.41344 .52524 L

.41203 .52564 L

.41062 .52603 L

.40921 .52643 L

.4078 .52682 L

.4064 .52721 L

.40499 .5276 L

.40358 .52798 L

.40217 .52837 L

Mistroke

.40076 .52876 L

.39935 .52914 L

.39794 .52953 L

.39654 .52991 L

.39513 .53029 L

.39372 .53067 L

.39231 .53105 L

.3909 .53143 L

.38949 .5318 L

.38808 .53218 L

.38667 .53255 L

.38527 .53292 L

.38386 .5333 L

.38245 .53367 L

.38104 .53404 L

.37963 .5344 L

.37822 .53477 L

.37681 .53513 L

.37541 .5355 L

.374 .53586 L

.37259 .53622 L

.37118 .53658 L

.36977 .53694 L

.36836 .5373 L

.36695 .53765 L

.36555 .538 L

.36414 .53836 L

.36273 .53871 L

.36132 .53906 L

.35991 .5394 L

.3585 .53975 L

.35709 .5401 L

.35568 .54044 L

.35428 .54078 L

.35287 .54112 L

.35146 .54146 L

.35005 .5418 L

.34864 .54213 L

.34723 .54246 L

.34582 .5428 L

.34442 .54313 L

.34301 .54345 L

.3416 .54378 L

.34019 .54411 L

.33878 .54443 L

.33737 .54475 L

.33596 .54507 L

.33456 .54539 L

.33315 .5457 L

.33174 .54602 L

Mistroke

.33033 .54633 L

.32892 .54664 L

.32751 .54695 L

.3261 .54725 L

.32469 .54756 L

.32329 .54786 L

.32188 .54816 L

.32047 .54845 L

.31906 .54875 L

.31765 .54904 L

.31624 .54933 L

.31483 .54962 L

.31343 .54991 L

.31202 .55019 L

.31061 .55047 L

.3092 .55075 L

.30779 .55103 L

.30638 .5513 L

.30497 .55157 L

.30357 .55184 L

.30216 .55211 L

.30075 .55238 L

.29934 .55264 L

.29793 .55289 L

.29652 .55315 L

.29511 .55341 L

.2937 .55365 L

.2923 .5539 L

.29089 .55415 L

.28948 .55439 L

.28807 .55463 L

.28666 .55487 L

.28525 .5551 L

.28384 .55533 L

.28244 .55555 L

.28103 .55578 L

.27962 .556 L

.27821 .55622 L

.2768 .55643 L

.27539 .55664 L

.27398 .55685 L

.27258 .55705 L

.27117 .55725 L

.26976 .55745 L

.26835 .55764 L

.26694 .55783 L

.26553 .55802 L

.26412 .5582 L

.26271 .55838 L

.26131 .55855 L

Mistroke

.2599 .55872 L

.25849 .55889 L

.25708 .55905 L

.25567 .55921 L

.25426 .55936 L

.25285 .55951 L

.25145 .55966 L

.25004 .5598 L

.24863 .55994 L

.24722 .56007 L

.24581 .56019 L

.2444 .56032 L

.24299 .56044 L

.24159 .56055 L

.24018 .56066 L

.23877 .56076 L

.23736 .56086 L

.23595 .56095 L

.23454 .56104 L

.23313 .56112 L

.23172 .5612 L

.23032 .56128 L

.22891 .56134 L

.2275 .5614 L

.22609 .56146 L

.22468 .56151 L

.22327 .56156 L

.22186 .56159 L

.22046 .56162 L

.21905 .56165 L

.21764 .56167 L

.21623 .56168 L

.21482 .56169 L

.21341 .56169 L

.212 .56169 L

.2106 .56168 L

.20919 .56165 L

.20778 .56163 L

.20637 .5616 L

.20496 .56156 L

.20355 .56151 L

.20214 .56145 L

.20073 .56139 L

.19933 .56132 L

.19792 .56124 L

.19651 .56115 L

.1951 .56106 L

.19369 .56096 L

.19228 .56085 L

.19087 .56073 L

Mistroke

.18524 .56017 L

.17961 .55946 L

.17397 .5586 L

.16834 .55756 L

.1627 .55635 L

.15707 .55495 L

.15143 .55334 L

.1458 .55151 L

.14016 .54943 L

.13453 .5471 L

.12889 .54449 L

.12326 .54157 L

.11762 .53832 L

.11199 .53471 L

.10636 .5307 L

.10072 .52626 L

.09509 .52133 L

.08945 .51586 L

.08382 .50979 L

.07818 .50303 L

.07255 .49549 L

.06691 .48704 L

.06128 .47751 L

.05564 .46667 L

.05001 .45419 L

.04438 .43957 L

.03874 .42192 L

.03311 .39943 L

.02747 .36656 L

.02381 .30902 L

Mfstroke

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{567, 350.313},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.776525,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008g0001GPP10`40000100000800002008200000

P800P020P<30`<3L`:K:l00003<006H009T00<`00?l0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV

09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<003o03?o06Ko09Wo0<co

0?oo0000<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I

<c>I<fJI<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0

IYT0I/`0I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bI

I_nIIP3<IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0c

VC<cVFHcVITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<

VIW<VLc<VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`c

c?lcc01Vc3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03o

c3?oc6Koc9Woc<coc?ooc000oc<0ofH0oiT0ol`0ool0o`0coc<cofHcoiTcol`coolco`1Voc=VofIV

oiUVolaVoomVo`2Ioc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<o`3ooc?oofKooiWoolco

ooooo`0000410@820P<30`@410D51@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C

4a@D5?okl:2PY820P?l0003o0?oo0000ool0o`3ooooood_Q00<0hN40on7Zh@00Bn400`3Qh@3ohN[Q

001;h@030>7Q0?oQj^4004_Q00<0hN40on7Zh@00Bn430?oQj^4004_Q00<0hN40on7Zh@00Bn400`3Q

h@3ohN[Q001;h@030>7Q0?oQj^4004_Q00<0hN40`N4M3ooQ3>4004_Q00<0hN40^^473agQ2`ooh@7Q

001;h@030>7Q0;CQ1Pl^h@T?n>4004_Q00<0hN40/N443c_Q20oah@00Bn400`3Qh@2^h@<?A^473n_Q

001;h@030>7Q0:_Q0`m?h@L?iN4004_Q00<0hN40Z>433eWQ1PoOh@00Bn400`3Qh@2Vh@8?HN463m[Q

001;h@<0Y>423fWQ1@oEh@00Bn400`3Qh@2Rh@8?L>453m3Q001;h@030>7Q0:7Q00<?hN40MN463l[Q

001;h@030>7Q09oQ0Pmmh@D?a^4004_Q00<0hN40WN423hCQ1@o1h@00Bn400`3Qh@2Lh@033n7Q08SQ

1@nmh@00Bn400`3Qh@2Jh@8?Sn453kWQ001;h@030>7Q09WQ00<?hN40Tn443kKQ001;h@030>7Q09SQ

0PnIh@@?/^4004_Q00<0hN40U^423ikQ10n_h@00Bn400`3Qh@2Fh@033n7Q0:3Q0`n]h@00Bn400`3Q

h@2Dh@8?Y^433j[Q001;h@<0U>400`oQh@2Wh@@?Yn4004_Q00<0hN40:>4<3eoQ00<?hN40Zn433jGQ

001;h@030>7Q01gQ2`l<h@h?Cn423k3Q0`nSh@00Bn400`3Qh@0Hh@D?9>493dOQ00<?hN40Xn4>:08?

2RRHh@00Bn400`3Qh@0Bh@H?<^473coQ00<?hN40Wn45:13Q0Pl7h@PXTN4004_Q00<0hN403n433coQ

1Plhh@033n7Q09kQ0bPFh@8?3N46:8_Q001;h@030>7Q00cQ0`m8h@H?<N400`oQh@2Mh@8X6^433a7Q

1bR4h@00Bn400`3Qh@09h@<?D>453bcQ00<?hN40W>42:1kQ0PlGh@HXO^4004_Q00<0hN401^433eSQ

1@lVh@033n7Q09cQ00<XhN407n423acQ1RQhh@00Bn400`3Qh@03h@<?H>453b7Q00<?hN40Vn400bSQ

h@0Rh@8?7n46:7?Q000jh@D00^400`3Qh@07h@040>7Qh@8?In453acQ00<?hN40Vn400bSQh@0Th@8?

9>46:6gQ000lh@070>7Qh@3Q0008h@040>4?3fkQ10lGh@033n7Q09_Q00<XhN409^423bSQ1RQXh@00

=^4300?Q00L0hN7Q0>4000SQ00@03`00L^453a7Q00<?hN40Vn400bSQh@0Xh@<?;>46:6;Q000lh@07

0>7Qh@3Q0007h@8?NN453`gQ00<?hN40Vn400bSQh@0Zh@8?<>46:5gQ000lh@070>7Qh@3Q0005h@8?

00?Q0>40ON443`SQ00<?hN40Vn400bSQh@0/h@8?=N46:5OQ000kh@801>400`3Qh@02h@8?0n400`3Q

h@1oh@@?1N400`oQh@2Kh@03:>7Q02gQ0Plih@HXD^4004CQ0Pl5h@030>7Q08?Q1@o?h@8??^46:4cQ

0013h@033n7Q00GQ00<0hN40Q^400`oQ3`023lgQ0Pm3h@DXAn4004;Q00<?hN401^400`3Qh@26h@03

3n7Q00;Q10o:h@8?An46:47Q0012h@033n7Q00KQ00<0hN40QN400`oQh@07h@@?an423dcQ1RPkh@00

@N400`oQh@07h@030>7Q08CQ00<?hN402n443i3Q00<XhN40<^423e7Q1BPfh@00?n423`[Q00<0hN40

Q>400`oQh@0?h@<?SN400bSQh@0ch@033n7Q08[Q000nh@033n7Q00[Q00<0hN40Pn400`oQh@0Ch@@?

R^400bSQh@0ch@033n7Q08WQ000mh@033n7Q00_Q00<0hN40Pn400`oQh@0Gh@@?Q^400bSQh@0ch@8?

R^4003cQ00<?hN403>4308;Q00<?hN406n443hCQ00<XhN40=>400`oQh@27h@00>n400`oQh@0=h@03

0>7Q08;Q00<?hN407n433h7Q0RPeh@8?R>4003[Q00<?hN403^400`3Qh@21h@033n7Q02?Q10mnh@8X

=N400`oQh@26h@00>N400`oQh@0?h@030>7Q087Q00<?hN409n433gcQ00<XhN40=>400`oQh@25h@00

>>400`oQh@0@h@030>7Q087Q00<?hN40:N443g[Q00<XhN40<n423hKQ000gh@033n7Q017Q00<0hN40

P>400`oQh@0^h@<?Mn42:3GQ0Pn5h@00=^400`oQh@0Bh@030>7Q07oQ00<?hN40<^433gKQ00<XhN40

<n400`oQh@23h@00=^400`oQh@0Bh@030>7Q07oQ00<?hN40=N443g?Q0RPdh@033n7Q08;Q000eh@03

3n7Q01?Q00<0hN40O^400`oQh@0jh@<?LN42:3?Q00<?hN40P^4003CQ00<?hN405>400`3Qh@1nh@03

3n7Q03gQ0`m_h@8X<n400`oQh@21h@00<n400`oQh@0Eh@030>7Q07kQ00<?hN40?n443fkQ0RPah@8?

P^4003?Q00<?hN405N400`3Qh@1nh@033n7Q04;Q10m/h@8X<N400`oQh@20h@00<^400`oQh@0Fh@<0

ON400`oQh@17h@<?Jn42:33Q00<?hN40On40037Q00<?hN405n400`3Qh@1lh@033n7Q04_Q0`mYh@8X

;n423h3Q000`h@033n7Q01SQ00<0hN40O>400`oQh@1>h@<?J>42:2kQ00<?hN40O^40033Q00<?hN40

6>400`3Qh@1kh@033n7Q05;Q0`mWh@8X;>423goQ000_h@033n7Q01WQ00<0hN40Nn400`oQh@1Eh@8?

I^43:2_Q00<?hN40ON4002kQ00<?hN406^400`3Qh@1kh@033n7Q05OQ0`mVh@8X:N423gkQ000^h@03

3n7Q01[Q00<0hN40Nn400`oQh@1Kh@033n7Q06CQ0RPXh@033n7Q07cQ000]h@033n7Q01_Q00<0hN40

Nn400`oQh@1Lh@<?IN43:2KQ00<?hN40Nn4002gQ00<?hN406n400`3Qh@1jh@033n7Q063Q0`mTh@<X

9>400`oQh@1kh@00;>400`oQh@0Lh@030>7Q07[Q00<?hN40Hn433f?Q0bPSh@033n7Q07[Q000[h@03

3n7Q01gQ00<0hN40NN400`oQh@1Wh@<?Hn43:23Q00<?hN40N^4002_Q00<?hN407N400`3Qh@1ih@03

3n7Q06[Q00<?hN40H^43:1kQ0Pmkh@00:^400`oQh@0Nh@<0NN400`oQh@1[h@<?I>43:1cQ00<?hN40

NN4002[Q00<?hN407^400`3Qh@1ih@033n7Q06kQ0`mSh@<X6n400`oQh@1hh@00:N400`oQh@0Oh@03

0>7Q07WQ00<?hN40LN433f?Q0bPHh@033n7Q07SQ000Yh@033n7Q01oQ00<0hN40N>400`oQh@1eh@8?

I>43:1GQ00<?hN40N>4002SQ00<?hN408>400`3Qh@1hh@033n7Q07OQ0`mTh@<X4n400`oQh@1gh@00

:>400`oQh@0Ph@030>7Q07OQ00<?hN40Nn400`oQh@1Th@<X4>400`oQh@1gh@009n400`oQh@0Qh@03

0>7Q07OQ00<?hN40O>433fKQ0bP>h@033n7Q07KQ000Wh@033n7Q027Q00<0hN40Mn400`oQh@1oh@<?

I^44:0[Q00<?hN40M^4002KQ00<?hN408^400`3Qh@1fh@033n7Q08?Q00<?hN40I^44:0OQ00<?hN40

M^4002KQ00<?hN408^400`3Qh@1fh@033n7Q08CQ0`mXh@@X1N400`oQh@1eh@009^400`oQh@0Rh@03

0>7Q07KQ00<?hN40Qn423f[Q12P00n4?h@1fh@009N400`oQh@0Sh@030>7Q07KQ00<?hN40RN433f[Q

12Qfh@009N400`oQh@0Sh@<0M^400`oQh@2<h@033n7Q06[Q00<?:2P00RQbh@009>400`oQh@0Th@03

0>7Q07KQ00<?hN40SN433fWQ00@?hN7Q12Q_h@009>400`oQh@0Th@030>7Q07GQ00<?hN40TN400`oQ

h@1Vh@033n7Q00GQ12Q[h@009>400`oQh@0Th@030>7Q07GQ00<?hN40T^433fKQ00<?hN401n45:6OQ

000Sh@033n7Q02GQ00<0hN40MN400`oQh@2Eh@8?I>400`oQh@0;h@DXHn4002?Q00<?hN409N400`3Q

h@1dh@033n7Q09SQ0`mQh@033n7Q00oQ1BQOh@008n400`oQh@0Uh@030>7Q07CQ00<?hN40Vn400`oQ

h@1Nh@033n7Q01?Q1BQKh@008^400`oQh@0Vh@030>7Q07CQ00<?hN40W>423eoQ00<?hN405^45:5OQ

000Rh@033n7Q02KQ00<0hN40Ln400`oQh@2Oh@<?G>400`oQh@0Jh@DXDn4002;Q00<?hN409^400`3Q

h@1ch@033n7Q0:;Q00<?hN40FN400`oQh@0Nh@DXCn40027Q00<?hN407N400`3Qh@07h@030>7Q07?Q

00<?hN40Xn423eWQ0PlSh@DXBn40027Q00<?hN407>400`3Q0008h@030>7Q07?Q00<?hN40YN423eSQ

00<?hN409N45:4OQ000Qh@033n7Q01OQ0`04h@030>7Q00KQ101bh@033n7Q0:OQ0PmFh@033n7Q02WQ

1BQ3h@008>400`oQh@0Mh@802N400`3Qh@1ch@033n7Q0:WQ00<?hN40Dn400`oQh@0^h@DX?^40023Q

00<?hN407N400`3Qh@08h@030>7Q07?Q00<?hN40Z^433e;Q00<?hN40<^45:3[Q000Ph@033n7Q01gQ

0`08h@030>7Q07?Q00<?hN40[N423e7Q00<?hN40=N46:3GQ000Ph@033n7Q02SQ00<0hN40L^400`oQ

h@2`h@033n7Q04kQ00<?hN40>^45:37Q000Oh@033n7Q02WQ00<0hN40L^400`oQh@2ah@8?C^400`oQ

h@0oh@03:>7Q02kQ000Oh@033n7Q02WQ00<0hN40L^400`oQh@2ch@<?Bn400`oQh@1`h@007n400`oQ

h@0Yh@030>7Q07;Q00<?hN40]^400`oQh@18h@033n7Q073Q000Oh@033n7Q02WQ00<0hN40LN400`oQ

h@2hh@8?B>400`oQh@1`h@007n400`oQh@0Yh@030>7Q077Q00<?hN40^^400`oQh@16h@033n7Q06oQ

000Oh@033n7Q02WQ00<0hN40LN400`oQh@2kh@<?AN400`oQh@1_h@007^400`oQh@0Zh@030>7Q077Q

00<?hN40_^400`oQh@12h@033n7Q06oQ000Nh@033n7Q02[Q0`1ah@033n7Q0;oQ0Pm2h@033n7Q06oQ

000Nh@033n7Q02[Q00<0hN40LN400`oQh@31h@033n7Q03oQ00<?hN40Kn4001kQ00<?hN40:^400`3Q

h@1ah@033n7Q0<;Q0Ploh@033n7Q06oQ000Nh@033n7Q02[Q00<0hN40LN400`oQh@34h@033n7Q03cQ

00<?hN40Kn4001kQ00<?hN40:^400`3Qh@1ah@033n7Q0<GQ0Pllh@033n7Q06oQ000Mh@033n7Q02_Q

00<0hN40LN400`oQh@37h@<?>N400`oQh@1_h@007N400`oQh@0[h@030>7Q077Q00<?hN40b^400`oQ

h@0fh@033n7Q06oQ000Mh@033n7Q02_Q00<0hN40L>400`oQh@3<h@8?Z>4001gQ00<?hN40:n400`3Q

h@1`h@033n7Q0<kQ00<?hN40YN4001gQ00<?hN40:n400`3Qh@1`h@033n7Q0<oQ00<?hN40Y>4001gQ

00<?hN40:n400`3Qh@1`h@033n7Q0=3Q0PnTh@007>400`oQh@0/h@030>7Q073Q00<?hN40d^400`oQ

h@2Qh@007>400`oQh@0/h@<0L>400`oQh@3Ch@8?;n400`oQh@1_h@007>400`oQh@0/h@030>7Q073Q

00<?hN40eN400`oQh@0/h@033n7Q06oQ000Lh@033n7Q02cQ00<0hN40Kn400`oQh@3Gh@8?;>400`oQ

h@1_h@007>400`oQh@0/h@030>7Q06oQ00<?hN40fN400`oQh@0Yh@033n7Q06oQ000Lh@033n7Q02cQ

00<0hN40Kn400`oQh@3Jh@8?:N400`oQh@1_h@006n400`oQh@0]h@030>7Q06oQ00<?hN40g>400`oQ

h@0Vh@033n7Q06oQ000Kh@033n7Q02gQ00<0hN40Kn400`oQh@3Mh@033n7Q02GQ00<?hN40Kn4001_Q

00<?hN40;N400`3Qh@1_h@033n7Q0=kQ00<?hN409>400`oQh@1_h@006n400`oQh@0]h@030>7Q06oQ

00<?hN40gn400`oQh@0Sh@033n7Q06oQ000Kh@033n7Q02gQ00<0hN40Kn400`oQh@3Ph@033n7Q027Q

00<?hN40L>4001_Q00<?hN40;N400`3Qh@1^h@033n7Q0>;Q0PlQh@033n7Q073Q000Kh@033n7Q02gQ

00<0hN40K^400`oQh@3Th@033n7Q01kQ00<?hN40L>4001_Q00<?hN40;N4306kQ00<?hN40iN423akQ

00<?hN40L>4001_Q00<?hN40;N400`3Qh@1^h@033n7Q0>KQ00<?hN407>400`oQh@1`h@006n400`oQ

h@0]h@030>7Q06kQ00<?hN40in400`oQh@0Jh@8?L^4001[Q00<?hN40;^400`3Qh@1^h@033n7Q0>SQ

0PlJh@033n7Q077Q000Jh@033n7Q02kQ00<0hN40K^400`oQh@3Zh@033n7Q01OQ00<?hN40LN4001[Q

00<?hN40;^400`3Qh@1^h@033n7Q0>_Q00<?hN40R^4001[Q00<?hN40;^400`3Qh@1^h@033n7Q0>cQ

00<?hN40RN4001[Q00<?hN40;^400`3Qh@1^h@033n7Q0>gQ00<?hN404n400`oQh@1bh@006^400`oQ

h@0^h@030>7Q06kQ00<?hN40k^400`oQh@0Bh@033n7Q07;Q000Jh@033n7Q02kQ00<0hN40K^400`oQ

h@3_h@033n7Q013Q00<?hN40Ln4001[Q00<?hN40;^400`3Qh@11h@D00^400`3Qh@0Sh@033n7Q01WQ

1@000n400011h@D00^400`3Qh@0oh@D00^400`3Qh@0kh@043n7Qh@D000?Q00001^400`oQh@0ih@<0

0n400`3Qh@0ah@006^400`oQh@0^h@030>7Q04?Q00L0hN7Q0>4002CQ00<?hN406n401`3QhN40h@00

@^400`3Qh@02h@030>7Q047Q00L0hN7Q0>4003gQ00<?hN400^400`3Qh@03h@030>7Q00?Q00<?hN40

>N400`3Qh@02h@030>4003;Q000Jh@033n7Q02kQ0`13h@030>7Q00?Q00<0hN408^400`oQh@0Kh@07

0>7Qh@3Q0012h@030>7Q00;Q00<0hN40@N401`3QhN40h@00?^401@oQhN4000CQ0P04h@033n7Q03_Q

00L0hN7Q0>4003;Q000Jh@033n7Q02kQ00<0hN40@n40103QhN4202GQ00<?hN406n40103QhN4204?Q

00<0hN400n400`3Qh@10h@030>7Q00;Q00<0hN40?^4010oQh@03h@030>4000CQ00<?hN40>n401`3Q

hN40h@00<^4001[Q00<?hN40;^400`3Qh@13h@050>7Qh@009^400`oQh@0Kh@050>7Qh@00A>401`3Q

hN40h@00@^401`3QhN40h@00?n4010oQh@03h@030>4000?Q00<?hN40>n400`3Q0002h@030>4003;Q

000Jh@033n7Q02kQ00<0hN40@^4200?Q0`0Th@033n7Q01[Q0P04h@80@N4200?Q0`11h@801>400`3Q

h@0oh@033`0000CQ0P03h@033n7Q03cQ00<0hN400^400`3Qh@0ah@006^400`oQh@0^h@030>7Q06kQ

00<?hN40mN400`oQh@08h@033n7Q07GQ000Ih@033n7Q02oQ00<0hN40K^400`oQh@3fh@033n7Q00KQ

00<?hN40M^4001WQ00<?hN40;n400`3Qh@1^h@033n7Q0?KQ00<?hN401^400`oQh@1fh@006N400`oQ

h@0_h@030>7Q06kQ00<?hN40mn400`oQh@04h@033n7Q07OQ000Ih@033n7Q02oQ00<0hN40K^400`oQ

h@3hh@033n7Q00?Q00<?hN40Mn4001WQ00<?hN40;n400`3Qh@1^h@033n7Q0?WQ00D?hN7Q3`1jh@00

6N400`oQh@0_h@030>7Q06kQ00<?hN40nN4010oQh@mWh@@04>4001WQ00<?hN40;n400`3Qh@1^h@03

3n7Q0?[Q00<?h@l0In43017Q000<h@d000<?0000X0000`l0003k00033`0005L04N400`3Qh@0?h@00

4>400`3Qh@06h@033n7Q00?Q00<0hN403>400`3Qh@0;h@030>7Q00cQ00<0hN402n400`3Qh@0<h@03

0>7Q00cQ00<0hN402n400`3Qh@0<h@030>7Q00_Q00<0hN403>400`3Qh@08h@053n7Qh@003N400`3Q

h@0<h@030>7Q00_Q00<0hN403>400`3Qh@0<h@030>7Q00_Q00<0hN403>400`3Qh@0;h@030>7Q00cQ

00<0hN403>400`3Qh@0;h@030>7Q00cQ00<0hN402n400`3Qh@0<h@030>7Q00cQ00<0hN402n400`3Q

h@0<h@040>4?3`[Q00<0hN403>400`3Qh@0<h@030>7Q00_Q00<0hN403>400`3Qh@0;h@030>7Q01;Q

0P0Ah@004>400`3Qh@06h@033n7Q00?Q00<0hN403>400`3Qh@0;h@030>7Q00cQ00<0hN402n400`3Q

h@0<h@030>7Q00cQ00<0hN402n400`3Qh@0<h@030>7Q00_Q00<0hN403>400`3Qh@08h@053n7Qh@00

3N400`3Qh@0<h@030>7Q00_Q00<0hN403>400`3Qh@0<h@030>7Q00_Q00<0hN403>400`3Qh@0;h@03

0>7Q00cQ00<0hN403>400`3Qh@0;h@030>7Q00cQ00<0hN402n400`3Qh@0<h@030>7Q00cQ00<0hN40

2n400`3Qh@0<h@0400oQ3`[Q00<0hN403>400`3Qh@0<h@030>7Q00_Q00<0hN403>400`3Qh@0;h@03

0>7Q02GQ000Ih@033n7Q02oQ00<0hN40A^400`3Qh@0Uh@033n7Q01kQ00<0hN40A^400`3Qh@16h@03

0>7Q04KQ00D?hN7Q3`14h@030>7Q03?Q000Ih@033n7Q02oQ00<0hN40A^400`3Qh@0Uh@033n7Q01kQ

00<0hN40A^400`3Qh@16h@030>7Q04KQ00D?hN7Q3`14h@030>7Q03?Q000Ih@033n7Q02oQ00<0hN40

K^400`oQh@3hh@033n7Q00?Q00<?hN40Mn4001WQ00<?hN40;n400`3Qh@1^h@033n7Q0?OQ00<?hN40

1>400`oQh@1gh@006N400`oQh@0_h@030>7Q06kQ00<?hN40m^400`oQh@06h@033n7Q07KQ000Jh@03

3n7Q02kQ00<0hN40K^400`oQh@3fh@033n7Q00KQ00<?hN40M^4001[Q00<?hN40;^400`3Qh@1^h@03

3n7Q0?GQ00<?hN402>400`oQh@1eh@006^400`oQh@0^h@030>7Q06kQ00<?hN40m>400`oQh@09h@03

3n7Q07GQ000Jh@033n7Q02kQ00<0hN40K^400`oQh@3ch@033n7Q00_Q00<?hN40M>4001[Q00<?hN40

;^4306kQ00<?hN40l^400`oQh@0<h@033n7Q07CQ000Jh@033n7Q02kQ00<0hN40K^400`oQh@3bh@03

3n7Q00gQ00<?hN40Ln4001[Q00<?hN40;^400`3Qh@1^h@033n7Q0?7Q00<?hN403^400`oQh@1ch@00

6^400`oQh@0^h@030>7Q06kQ00<?hN40l>400`oQh@0?h@033n7Q07?Q000Jh@033n7Q02kQ00<0hN40

K^400`oQh@3_h@033n7Q017Q00<?hN40L^4001[Q00<?hN40;^400`3Qh@1^h@033n7Q0>kQ00<?hN40

4^400`oQh@1bh@006^400`oQh@0^h@030>7Q06kQ00<?hN40kN400`oQh@28h@006^400`oQh@0^h@03

0>7Q06kQ00<?hN40k>400`oQh@29h@006^400`oQh@0^h@030>7Q06kQ00<?hN40j^423aSQ00<?hN40

LN4001[Q00<?hN40;^400`3Qh@1^h@033n7Q0>WQ00<?hN406>400`oQh@1ah@006^400`oQh@0^h@03

0>7Q06kQ00<?hN40jN400`oQh@0Hh@033n7Q077Q000Kh@033n7Q02gQ00<0hN40K^400`oQh@3Wh@8?

6n423g;Q000Kh@033n7Q02gQ0`1^h@033n7Q0>KQ00<?hN407>400`oQh@1`h@006n400`oQh@0]h@03

0>7Q06kQ00<?hN40iN400`oQh@0Mh@033n7Q073Q000Kh@033n7Q02gQ00<0hN40K^400`oQh@3Th@03

3n7Q01kQ00<?hN40L>4001_Q00<?hN40;N400`3Qh@1^h@033n7Q0>?Q00<?hN407n400`oQh@1`h@00

6n400`oQh@0]h@030>7Q06oQ00<?hN40h>423b;Q00<?hN40L>4001_Q00<?hN40;N400`3Qh@1_h@03

3n7Q0=oQ00<?hN408n400`oQh@1_h@006n400`oQh@0]h@030>7Q06oQ00<?hN40g^400`oQh@0Th@03

3n7Q06oQ000Kh@033n7Q02gQ00<0hN40Kn400`oQh@3Lh@8?9n400`oQh@1_h@006n400`oQh@0]h@03

0>7Q06oQ00<?hN40fn400`oQh@0Wh@033n7Q06oQ000Lh@033n7Q02cQ00<0hN40Kn400`oQh@3Ih@8?

:^400`oQh@1_h@007>400`oQh@0/h@030>7Q06oQ00<?hN40f>400`oQh@0Zh@033n7Q06oQ000Lh@03

3n7Q02cQ00<0hN40Kn400`oQh@3Gh@033n7Q02_Q00<?hN40Kn4001cQ00<?hN40;>43073Q00<?hN40

eN400`oQh@0/h@033n7Q06oQ000Lh@033n7Q02cQ00<0hN40L>400`oQh@3Dh@033n7Q02gQ00<?hN40

Kn4001cQ00<?hN40;>400`3Qh@1`h@033n7Q0=;Q0PnRh@007N400`oQh@0[h@030>7Q073Q00<?hN40

cn433jCQ000Mh@033n7Q02_Q00<0hN40L>400`oQh@3>h@033n7Q0:GQ000Mh@033n7Q02_Q00<0hN40

L>400`oQh@3=h@033n7Q0:KQ000Mh@033n7Q02_Q00<0hN40L>400`oQh@3;h@8?ZN4001gQ00<?hN40

:n400`3Qh@1ah@033n7Q0<WQ00<?hN40=n400`oQh@1_h@007N400`oQh@0[h@030>7Q077Q00<?hN40

an423c[Q00<?hN40Kn4001kQ00<?hN40:^400`3Qh@1ah@033n7Q0<KQ00<?hN40>^400`oQh@1_h@00

7^400`oQh@0Zh@030>7Q077Q00<?hN40a>423cgQ00<?hN40Kn4001kQ00<?hN40:^400`3Qh@1ah@03

3n7Q0<?Q00<?hN40?N400`oQh@1_h@007^400`oQh@0Zh@<0LN400`oQh@31h@8?@>400`oQh@1_h@00

7^400`oQh@0Zh@030>7Q077Q00<?hN40_^433d;Q00<?hN40Kn4001kQ00<?hN40:^400`3Qh@1ah@03

3n7Q0;gQ00<?hN40@n400`oQh@1_h@007n400`oQh@0Yh@030>7Q077Q00<?hN40^n423dKQ00<?hN40

Kn4001oQ00<?hN40:N400`3Qh@1ah@033n7Q0;[Q00<?hN40AN423g7Q000Oh@033n7Q02WQ00<0hN40

L^400`oQh@2hh@033n7Q04KQ00<?hN40L>4001oQ00<?hN40:N400`3Qh@1bh@033n7Q0;GQ0`m9h@03

3n7Q073Q000Oh@033n7Q02WQ00<0hN40L^400`oQh@2ch@8?C>400`oQh@1`h@007n400`oQh@0Yh@03

0>7Q07;Q00<?hN40/^400`oQh@1<h@033n7Q03gQ0bP`h@008>400`oQh@0Xh@030>7Q07;Q00<?hN40

/>423doQ00<?hN40>N45:3;Q000Ph@033n7Q01kQ00<0hN401n400`3Qh@1ch@033n7Q0:cQ0`m@h@8?

=^45:3OQ000Ph@033n7Q01gQ00<0h@002>400`3Qh@1ch@033n7Q0:_Q00<?hN40DN400`oQh@0ah@DX

>n40023Q00<?hN407n400`3Qh@06h@@0L^400`oQh@2Yh@8?E>400`oQh@0]h@DX?n40027Q00<?hN40

7>4200WQ00<0hN40Ln400`oQh@2Vh@<?E^400`oQh@0Xh@DXA>40027Q00<?hN407>400`3Qh@08h@03

0>7Q07?Q00<?hN40YN400`oQh@1Gh@033n7Q02CQ1BQ8h@008N400`oQh@0Lh@<02>400`3Qh@1ch@03

3n7Q0:CQ00<?hN40En423b;Q1BQ<h@008^400`oQh@0Vh@030>7Q07?Q00<?hN40XN433e[Q00<?hN40

7N44:57Q000Rh@033n7Q02KQ00<0hN40M>400`oQh@2Nh@8?GN400`oQh@0Ih@@XEN4002;Q00<?hN40

9^400`3Qh@1dh@033n7Q09gQ00<?hN40GN400`oQh@0Eh@@XFN4002?Q00<?hN409N400`3Qh@1dh@03

3n7Q09[Q0`mOh@033n7Q01;Q12QMh@008n400`oQh@0Uh@030>7Q07CQ00<?hN40V>423f;Q00<?hN40

3^44:67Q000Sh@033n7Q02GQ00<0hN40MN400`oQh@2Dh@<?I>400`oQh@0:h@@XIN4002CQ00<?hN40

9>400`3Qh@1eh@033n7Q09?Q00<?hN40IN400`oQh@06h@DXJ>4002CQ00<?hN409>400`3Qh@1eh@03

3n7Q093Q0`mWh@033n7Q00CQ12Q/h@009>400`oQh@0Th@<0M^400`oQh@2>h@033n7Q06SQ00<?hN40

12Q`h@009N400`oQh@0Sh@030>7Q07KQ00<?hN40Rn433f_Q12Qch@009N400`oQh@0Sh@030>7Q07KQ

00<?hN40RN423f[Q12Qgh@009^400`oQh@0Rh@030>7Q07KQ00<?hN40Q^433fWQ12P2h@033n7Q07GQ

000Vh@033n7Q02;Q00<0hN40M^400`oQh@25h@033n7Q06KQ12P5h@033n7Q07KQ000Vh@033n7Q02;Q

00<0hN40M^400`oQh@22h@<?I^44:0SQ00<?hN40M^4002OQ00<?hN408N400`3Qh@1gh@033n7Q07oQ

0PmVh@@X2n400`oQh@1fh@009n400`oQh@0Qh@030>7Q07OQ00<?hN40O>433fGQ0bP>h@033n7Q07OQ

000Xh@033n7Q023Q00<0hN40N>400`oQh@1ih@8?IN43:17Q00<?hN40Mn4002SQ00<?hN408>400`3Q

h@1hh@033n7Q07OQ0PmTh@@X4n400`oQh@1gh@00:N400`oQh@0Oh@030>7Q07SQ00<?hN40M>433f?Q

12PEh@033n7Q07SQ000Yh@033n7Q01oQ00<0hN40NN400`oQh@1`h@<?Hn44:1SQ00<?hN40N>4002[Q

00<?hN407^4307WQ00<?hN40Kn400`oQh@1Rh@<X6^423g[Q000Zh@033n7Q01kQ00<0hN40NN400`oQ

h@1/h@<?H^43:1gQ00<?hN40NN4002_Q00<?hN407N400`3Qh@1ih@033n7Q06WQ0`mRh@@X7^400`oQ

h@1jh@00:n400`oQh@0Mh@030>7Q07WQ00<?hN40I^433f?Q0bPQh@033n7Q07[Q000/h@033n7Q01cQ

00<0hN40N^400`oQh@1Rh@<?I>43:2;Q0Pmlh@00;N400`oQh@0Kh@030>7Q07[Q00<?hN40HN400`oQ

h@1Rh@<X9N400`oQh@1kh@00;N400`oQh@0Kh@030>7Q07_Q00<?hN40GN433f?Q0bPWh@033n7Q07_Q

000^h@033n7Q01[Q00<0hN40Nn400`oQh@1Ih@043n4?3fCQ0bPXh@033n7Q07cQ000^h@033n7Q01[Q

00<0hN40Nn400`oQh@1Fh@<?I^43:2WQ00<?hN40ON4002oQ00<?hN406N400`3Qh@1kh@033n7Q05?Q

0`mWh@<X:n400`oQh@1mh@00<>400`oQh@0Hh@030>7Q07cQ00<?hN40D>433fOQ0bP/h@033n7Q07kQ

000`h@033n7Q01SQ00<0hN40O>400`oQh@1=h@<?J>43:2kQ00<?hN40O^40037Q00<?hN405n4307gQ

00<?hN40B>443f[Q0RP_h@033n7Q07oQ000bh@033n7Q01KQ00<0hN40ON400`oQh@16h@<?Jn42:37Q

00<?hN40On4003?Q00<?hN405N400`3Qh@1nh@033n7Q04;Q0`m]h@8X<N400`oQh@20h@00<n400`oQ

h@0Eh@030>7Q07kQ00<?hN40?n433fkQ0RPbh@033n7Q087Q000dh@033n7Q01CQ00<0hN40O^400`oQ

h@0lh@<?L>42:3?Q00<?hN40PN4003GQ00<?hN404n400`3Qh@1nh@033n7Q03WQ0`mbh@03:>7Q03;Q

00<?hN40P^4003KQ00<?hN404^400`3Qh@1oh@033n7Q03CQ10mch@8X=>423hCQ000gh@033n7Q017Q

00<0hN40P>400`oQh@0`h@@?M^400bSQh@0ch@033n7Q08?Q000hh@033n7Q013Q00<0hN40P>400`oQ

h@0]h@@?Mn42:3GQ00<?hN40Q>4003WQ00<?hN403n400`3Qh@21h@033n7Q02WQ0`mjh@8X=N400`oQ

h@25h@00>N400`oQh@0?h@030>7Q087Q00<?hN409N443ggQ00<XhN40<n423hOQ000jh@033n7Q00kQ

00<0hN40PN400`oQh@0Rh@<?P>400bSQh@0dh@033n7Q08KQ000kh@033n7Q00gQ0`22h@033n7Q01kQ

0`n2h@8X=N400`oQh@27h@00?>423`gQ00<0hN40Pn400`oQh@0Jh@<?Q>42:3GQ0Pn9h@00?^400`oQ

h@0:h@030>7Q08?Q00<?hN405^443hOQ00<XhN40<n423h[Q000oh@033n7Q00WQ00<0hN40Pn400`oQ

h@0Bh@@?Rn400bSQh@0bh@8?Rn40043Q00<?hN402>400`3Qh@24h@033n7Q00kQ10n=h@03:>7Q03?Q

00<?hN40D^42:3KQ0011h@033n7Q00OQ00<0hN40QN400`oQh@09h@@?TN400bSQh@0bh@033n7Q04kQ

1RPgh@00@^400`oQh@06h@030>7Q08GQ00<?hN401N443lWQ0Pm:h@LX?>4004?Q00<?hN401N400`3Q

h@26h@043n7Qh@@?bn400`oQh@15h@HX@^4004CQ0Pl5h@030>7Q08KQ10o>h@033n7Q047Q1BQ8h@00

A^400`oQh@02h@030>7Q08;Q10l00n4?h@3>h@8??N46:4gQ000jh@D00^400`3Qh@03h@8?0^400`3Q

h@1oh@@?1N400`oQh@2Kh@03:>7Q02gQ0Plhh@HXDn4003cQ00L0hN7Q0>4000KQ00<?h@00O>453`[Q

00<?hN40V^400bSQh@0/h@033n7Q03?Q1BQIh@00?>401`3QhN40h@001n423`<0MN453`kQ00<?hN40

Vn400bSQh@0Zh@033n7Q02kQ1RQNh@00?>401`3QhN40h@002>400`0?3`1bh@@?5>400`oQh@2Jh@03

:>7Q02SQ0Pl/h@DXI>4003cQ00L0hN7Q0>4000SQ00<0hN400Pm/h@D?6>400`oQh@2Jh@03:>7Q02KQ

0PlWh@HXJN4003_Q0P04h@030>7Q00OQ00<0hN400^423fKQ10lNh@033n7Q09[Q00<XhN409>423b;Q

1RQ_h@00Bn400`3Qh@04h@8?G^463b;Q00<?hN40Vn400bSQh@0Qh@<?7^45:7GQ001;h@030>7Q00KQ

0`mGh@D?:>400`oQh@2Kh@8X8>423a[Q1RQjh@00Bn400`3Qh@09h@<?Cn453bkQ00<?hN40W>400bSQ

h@0Lh@8?5N46:83Q001;h@030>7Q00cQ0`m6h@H?<n400`oQh@2Mh@<X6N423a7Q1bR5h@00Bn400`3Q

h@0?h@<??N463c[Q00<?hN40Wn43:1CQ0`l;h@LXS>4004_Q00<0hN404^463c3Q1`m1h@033n7Q0:7Q

12P>h@<?1>49:9?Q001;h@030>7Q01SQ1@lQh@X?BN400`oQh@2Th@dX0Pl7:9_Q001;h@030>7Q01gQ

8PmCh@033n7Q0:gQ0`nTh@00Bn4309?Q00<?hN40Z^433jKQ001;h@030>7Q09CQ00<?hN40Yn433jSQ

001;h@030>7Q09GQ00<?hN40Xn433j_Q001;h@030>7Q09KQ00<?hN40Wn443jgQ001;h@030>7Q09OQ

00<?hN40Vn443k3Q001;h@030>7Q09SQ0PnHh@@?/n4004_Q00<0hN40VN423i?Q10ngh@00Bn400`3Q

h@2Kh@8?SN453k[Q001;h@030>7Q09cQ0Pn8h@D?_^4004_Q00<0hN40W^423h7Q1Po2h@00Bn400`3Q

h@2Oh@8?Nn463lOQ001;h@030>7Q0:7Q0Pmdh@H?c>4004_Q0`2Sh@8?K^453m7Q001;h@030>7Q0:CQ

0`mVh@H?e^4004_Q00<0hN40Yn423eoQ1PoKh@00Bn400`3Qh@2Yh@<?E^463n7Q001;h@030>7Q0:cQ

0`m=h@H?in4004_Q00<0hN40[n433d?Q20o/h@00Bn400`3Qh@2ah@D?>>483o?Q001;h@030>7Q0;KQ

1@l[h@T?n^4004_Q00<0hN40^n493aKQ30ooh@CQ001;h@030>7Q0<CQ5`ooh@oQ001;h@030>7Q0?oQ

j^4004_Q00<0hN40on7Zh@00Bn430?oQj^4004_Q00<0hN40on7Zh@00Bn400`3Qh@3ohN[Q001;h@03

0>7Q0?oQj^4004_Q00<0hN40on7Zh@00Bn400`3Qh@3ohN[Q003ohOoQ>N400?oQon4ih@00on7ohCWQ

003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQ

on4ih@00on47h@8000CQ003Q10000n400004h@030>7Q0?oQ7^400?oQ2>400`3Q0009h@060>7Q0>40

on4Oh@00on48h@<00^4400;Q00L0hN7Q0>400?oQ7n400?oQ2>40103Q0008h@050>7Qh@00on4Ph@00

BN420;cQ00<0hN401n400`3Q0002h@030>400?oQ7n4004[Q00<0hN40^N4200[Q00<0hN400^400`3Q

h@3ohAkQ0018h@<00^400`3Qh@3ohNSQ0017h@080>7Q0>40h@3ohNWQ0017h@080>7Q0>40h@3ohNWQ

0018h@<000CQ0>40on7Yh@00C>400`3Q003ohNWQ001=h@030>7Q0?oQj>400?oQon4ih@00on7ohCWQ

003ohOoQ>N400?oQon4ih@00on7ohCWQ0000\

\>"],

  ImageRangeCache->{{{0, 566}, {349.313, 0}} -> {12.969, -13.3541, 0.0136957, 

  0.0833706}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-1.65934 0.125561 0.309017 0.0226592 [

[.22408 .29652 -6 -9 ]

[.22408 .29652 6 0 ]

[.34964 .29652 -6 -9 ]

[.34964 .29652 6 0 ]

[.4752 .29652 -6 -9 ]

[.4752 .29652 6 0 ]

[.60076 .29652 -6 -9 ]

[.60076 .29652 6 0 ]

[.72632 .29652 -6 -9 ]

[.72632 .29652 6 0 ]

[.85188 .29652 -6 -9 ]

[.85188 .29652 6 0 ]

[.97745 .29652 -6 -9 ]

[.97745 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.08602 .08243 -18 -4.5 ]

[.08602 .08243 0 4.5 ]

[.08602 .19572 -12 -4.5 ]

[.08602 .19572 0 4.5 ]

[.08602 .42231 -6 -4.5 ]

[.08602 .42231 0 4.5 ]

[.08602 .53561 -12 -4.5 ]

[.08602 .53561 0 4.5 ]

[.09852 .64303 -7 0 ]

[.09852 .64303 7 16 ]

[.5 .63053 -19.5 0 ]

[.5 .63053 19.5 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.22408 .30902 m

.22408 .31527 L

s

[(15)] .22408 .29652 0 1 Mshowa

.34964 .30902 m

.34964 .31527 L

s

[(16)] .34964 .29652 0 1 Mshowa

.4752 .30902 m

.4752 .31527 L

s

[(17)] .4752 .29652 0 1 Mshowa

.60076 .30902 m

.60076 .31527 L

s

[(18)] .60076 .29652 0 1 Mshowa

.72632 .30902 m

.72632 .31527 L

s

[(19)] .72632 .29652 0 1 Mshowa

.85188 .30902 m

.85188 .31527 L

s

[(20)] .85188 .29652 0 1 Mshowa

.97745 .30902 m

.97745 .31527 L

s

[(21)] .97745 .29652 0 1 Mshowa

.125 Mabswid

.12363 .30902 m

.12363 .31277 L

s

.14874 .30902 m

.14874 .31277 L

s

.17386 .30902 m

.17386 .31277 L

s

.19897 .30902 m

.19897 .31277 L

s

.24919 .30902 m

.24919 .31277 L

s

.2743 .30902 m

.2743 .31277 L

s

.29942 .30902 m

.29942 .31277 L

s

.32453 .30902 m

.32453 .31277 L

s

.37475 .30902 m

.37475 .31277 L

s

.39987 .30902 m

.39987 .31277 L

s

.42498 .30902 m

.42498 .31277 L

s

.45009 .30902 m

.45009 .31277 L

s

.50031 .30902 m

.50031 .31277 L

s

.52543 .30902 m

.52543 .31277 L

s

.55054 .30902 m

.55054 .31277 L

s

.57565 .30902 m

.57565 .31277 L

s

.62588 .30902 m

.62588 .31277 L

s

.65099 .30902 m

.65099 .31277 L

s

.6761 .30902 m

.6761 .31277 L

s

.70121 .30902 m

.70121 .31277 L

s

.75144 .30902 m

.75144 .31277 L

s

.77655 .30902 m

.77655 .31277 L

s

.80166 .30902 m

.80166 .31277 L

s

.82677 .30902 m

.82677 .31277 L

s

.877 .30902 m

.877 .31277 L

s

.90211 .30902 m

.90211 .31277 L

s

.92722 .30902 m

.92722 .31277 L

s

.95233 .30902 m

.95233 .31277 L

s

.07341 .30902 m

.07341 .31277 L

s

.04829 .30902 m

.04829 .31277 L

s

.02318 .30902 m

.02318 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.09852 .08243 m

.10477 .08243 L

s

[(-10)] .08602 .08243 1 0 Mshowa

.09852 .19572 m

.10477 .19572 L

s

[(-5)] .08602 .19572 1 0 Mshowa

.09852 .42231 m

.10477 .42231 L

s

[(5)] .08602 .42231 1 0 Mshowa

.09852 .53561 m

.10477 .53561 L

s

[(10)] .08602 .53561 1 0 Mshowa

.125 Mabswid

.09852 .10508 m

.10227 .10508 L

s

.09852 .12774 m

.10227 .12774 L

s

.09852 .1504 m

.10227 .1504 L

s

.09852 .17306 m

.10227 .17306 L

s

.09852 .21838 m

.10227 .21838 L

s

.09852 .24104 m

.10227 .24104 L

s

.09852 .2637 m

.10227 .2637 L

s

.09852 .28636 m

.10227 .28636 L

s

.09852 .33168 m

.10227 .33168 L

s

.09852 .35434 m

.10227 .35434 L

s

.09852 .37699 m

.10227 .37699 L

s

.09852 .39965 m

.10227 .39965 L

s

.09852 .44497 m

.10227 .44497 L

s

.09852 .46763 m

.10227 .46763 L

s

.09852 .49029 m

.10227 .49029 L

s

.09852 .51295 m

.10227 .51295 L

s

.09852 .05977 m

.10227 .05977 L

s

.09852 .03711 m

.10227 .03711 L

s

.09852 .01445 m

.10227 .01445 L

s

.09852 .55827 m

.10227 .55827 L

s

.09852 .58093 m

.10227 .58093 L

s

.09852 .60359 m

.10227 .60359 L

s

.25 Mabswid

.09852 0 m

.09852 .61803 L

s

gsave

.09852 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -80.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(k) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(39.65) show

98.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

1 0 0 r

.5 Mabswid

.41368 .58145 m

.41242 .58055 L

.41117 .57962 L

.40991 .57867 L

.40865 .57769 L

.4074 .57669 L

.40614 .57565 L

.40489 .57458 L

.40363 .57349 L

.40238 .57236 L

.40112 .5712 L

.39987 .57 L

.39861 .56877 L

.39735 .56751 L

.3961 .56621 L

.39484 .56488 L

.39359 .56351 L

.39233 .5621 L

.39108 .56065 L

.38982 .55916 L

.38856 .55762 L

.38731 .55605 L

.38605 .55442 L

.3848 .55275 L

.38354 .55104 L

.38229 .54927 L

.38103 .54746 L

.37978 .54559 L

.37852 .54367 L

.37726 .54169 L

.37601 .53965 L

.37475 .53756 L

.3735 .5354 L

.37224 .53318 L

.37099 .53089 L

.36973 .52853 L

.36847 .52609 L

.36722 .52358 L

.36596 .521 L

.36471 .51833 L

.36345 .51557 L

.3622 .51272 L

.36094 .50978 L

.35969 .50674 L

.35843 .50359 L

.35717 .50033 L

.35592 .49695 L

.35466 .49345 L

.35341 .48981 L

.35215 .48603 L

Mistroke

.3509 .4821 L

.34964 .47801 L

.34838 .47374 L

.34713 .46927 L

.34587 .4646 L

.34462 .4597 L

.34336 .45455 L

.34211 .44911 L

.34085 .44335 L

.3396 .43723 L

.33834 .4307 L

.33708 .42367 L

.33583 .41606 L

.33457 .40772 L

.33332 .39844 L

.33206 .38791 L

.33081 .37552 L

.32955 .35993 L

.3283 .33608 L

.32804 .30902 L

Mfstroke

.41368 .03659 m

.41242 .03749 L

.41117 .03841 L

.40991 .03936 L

.40865 .04034 L

.4074 .04135 L

.40614 .04238 L

.40489 .04345 L

.40363 .04455 L

.40238 .04568 L

.40112 .04684 L

.39987 .04803 L

.39861 .04926 L

.39735 .05052 L

.3961 .05182 L

.39484 .05315 L

.39359 .05452 L

.39233 .05594 L

.39108 .05739 L

.38982 .05888 L

.38856 .06041 L

.38731 .06199 L

.38605 .06361 L

.3848 .06528 L

.38354 .067 L

.38229 .06876 L

.38103 .07058 L

.37978 .07244 L

.37852 .07437 L

.37726 .07634 L

.37601 .07838 L

.37475 .08048 L

.3735 .08264 L

.37224 .08486 L

.37099 .08715 L

.36973 .08951 L

.36847 .09194 L

.36722 .09445 L

.36596 .09704 L

.36471 .09971 L

.36345 .10246 L

.3622 .10531 L

.36094 .10826 L

.35969 .1113 L

.35843 .11445 L

.35717 .11771 L

.35592 .12108 L

.35466 .12459 L

.35341 .12822 L

.35215 .132 L

Mistroke

.3509 .13593 L

.34964 .14003 L

.34838 .1443 L

.34713 .14876 L

.34587 .15343 L

.34462 .15833 L

.34336 .16349 L

.34211 .16893 L

.34085 .17468 L

.3396 .1808 L

.33834 .18734 L

.33708 .19436 L

.33583 .20198 L

.33457 .21032 L

.33332 .21959 L

.33206 .23012 L

.33081 .24251 L

.32955 .2581 L

.3283 .28196 L

.32804 .30902 L

Mfstroke

.41242 .58003 m

.41493 .58232 L

.41744 .58399 L

.41995 .58556 L

.42247 .58704 L

.42498 .58844 L

.42749 .58975 L

.43 .59098 L

.43251 .59213 L

.43502 .59321 L

.43753 .59422 L

.44004 .59516 L

.44256 .59603 L

.44507 .59685 L

.44758 .5976 L

.45009 .5983 L

.4526 .59894 L

.45511 .59953 L

.45762 .60007 L

.46013 .60056 L

.46265 .60101 L

.46516 .60141 L

.46767 .60177 L

.47018 .60208 L

.47269 .60236 L

.4752 .6026 L

.47771 .6028 L

.48022 .60297 L

.48274 .6031 L

.48525 .6032 L

.48776 .60327 L

.49027 .60331 L

.49278 .60332 L

.49529 .6033 L

.4978 .60326 L

.50031 .60319 L

.50283 .60309 L

.50534 .60297 L

.50785 .60283 L

.51036 .60267 L

.51287 .60248 L

.51538 .60228 L

.51789 .60205 L

.5204 .60181 L

.52291 .60155 L

.52543 .60127 L

.52794 .60097 L

.53045 .60065 L

.53296 .60032 L

.53547 .59997 L

Mistroke

.53798 .59961 L

.54049 .59924 L

.543 .59885 L

.54552 .59844 L

.54803 .59802 L

.55054 .59759 L

.55305 .59715 L

.55556 .59669 L

.55807 .59622 L

.56058 .59574 L

.56309 .59525 L

.56561 .59474 L

.56812 .59422 L

.57063 .5937 L

.57314 .59316 L

.57565 .59261 L

.57816 .59204 L

.58067 .59147 L

.58318 .59089 L

.5857 .59029 L

.58821 .58968 L

.59072 .58906 L

.59323 .58843 L

.59574 .58779 L

.59825 .58714 L

.60076 .58647 L

.60327 .5858 L

.60579 .58511 L

.6083 .5844 L

.61081 .58369 L

.61332 .58296 L

.61583 .58221 L

.61834 .58146 L

.62085 .58068 L

.62336 .57989 L

.62588 .57909 L

.62839 .57827 L

.6309 .57743 L

.63341 .57657 L

.63592 .5757 L

.63843 .5748 L

.64094 .57389 L

.64345 .57295 L

.64596 .57199 L

.64848 .57101 L

.65099 .57001 L

.6535 .56898 L

.65601 .56792 L

.65852 .56684 L

.66103 .56573 L

Mistroke

.66354 .56458 L

.66605 .56341 L

.66857 .5622 L

.67108 .56096 L

.67359 .55969 L

.6761 .55838 L

.67861 .55702 L

.68112 .55563 L

.68363 .5542 L

.68614 .55272 L

.68866 .55119 L

.69117 .54962 L

.69368 .548 L

.69619 .54632 L

.6987 .54459 L

.70121 .5428 L

.70372 .54095 L

.70623 .53904 L

.70875 .53707 L

.71126 .53502 L

.71377 .53291 L

.71628 .53072 L

.71879 .52845 L

.7213 .5261 L

.72381 .52367 L

.72632 .52115 L

.72884 .51854 L

.73135 .51583 L

.73386 .51302 L

.73637 .5101 L

.73888 .50707 L

.74139 .50392 L

.7439 .50065 L

.74641 .49724 L

.74892 .49371 L

.75144 .49002 L

.75395 .48617 L

.75646 .48216 L

.75897 .47796 L

.76148 .47358 L

.76399 .46898 L

.7665 .46414 L

.76901 .45906 L

.77153 .45368 L

.77404 .44798 L

.77655 .44189 L

.77906 .43536 L

.78157 .42827 L

.78408 .42049 L

.78659 .41176 L

Mistroke

.7891 .4016 L

.79162 .3889 L

.79413 .368 L

Mfstroke

.41242 .038 m

.41493 .03572 L

.41744 .03405 L

.41995 .03247 L

.42247 .03099 L

.42498 .0296 L

.42749 .02829 L

.43 .02706 L

.43251 .0259 L

.43502 .02483 L

.43753 .02382 L

.44004 .02287 L

.44256 .022 L

.44507 .02118 L

.44758 .02043 L

.45009 .01973 L

.4526 .01909 L

.45511 .0185 L

.45762 .01796 L

.46013 .01747 L

.46265 .01702 L

.46516 .01663 L

.46767 .01627 L

.47018 .01595 L

.47269 .01567 L

.4752 .01544 L

.47771 .01523 L

.48022 .01507 L

.48274 .01493 L

.48525 .01484 L

.48776 .01476 L

.49027 .01473 L

.49278 .01472 L

.49529 .01473 L

.4978 .01478 L

.50031 .01485 L

.50283 .01494 L

.50534 .01506 L

.50785 .0152 L

.51036 .01537 L

.51287 .01555 L

.51538 .01576 L

.51789 .01598 L

.5204 .01623 L

.52291 .01649 L

.52543 .01677 L

.52794 .01707 L

.53045 .01738 L

.53296 .01771 L

.53547 .01806 L

Mistroke

.53798 .01842 L

.54049 .0188 L

.543 .01919 L

.54552 .01959 L

.54803 .02001 L

.55054 .02044 L

.55305 .02089 L

.55556 .02135 L

.55807 .02181 L

.56058 .02229 L

.56309 .02279 L

.56561 .02329 L

.56812 .02381 L

.57063 .02434 L

.57314 .02488 L

.57565 .02543 L

.57816 .02599 L

.58067 .02656 L

.58318 .02715 L

.5857 .02774 L

.58821 .02835 L

.59072 .02897 L

.59323 .0296 L

.59574 .03024 L

.59825 .03089 L

.60076 .03156 L

.60327 .03224 L

.60579 .03293 L

.6083 .03363 L

.61081 .03435 L

.61332 .03508 L

.61583 .03582 L

.61834 .03658 L

.62085 .03735 L

.62336 .03814 L

.62588 .03895 L

.62839 .03977 L

.6309 .04061 L

.63341 .04146 L

.63592 .04234 L

.63843 .04323 L

.64094 .04415 L

.64345 .04509 L

.64596 .04604 L

.64848 .04702 L

.65099 .04803 L

.6535 .04906 L

.65601 .05011 L

.65852 .0512 L

.66103 .05231 L

Mistroke

.66354 .05345 L

.66605 .05462 L

.66857 .05583 L

.67108 .05707 L

.67359 .05835 L

.6761 .05966 L

.67861 .06101 L

.68112 .0624 L

.68363 .06384 L

.68614 .06532 L

.68866 .06684 L

.69117 .06841 L

.69368 .07004 L

.69619 .07171 L

.6987 .07345 L

.70121 .07523 L

.70372 .07708 L

.70623 .07899 L

.70875 .08097 L

.71126 .08301 L

.71377 .08513 L

.71628 .08732 L

.71879 .08958 L

.7213 .09193 L

.72381 .09436 L

.72632 .09688 L

.72884 .0995 L

.73135 .10221 L

.73386 .10502 L

.73637 .10794 L

.73888 .11097 L

.74139 .11411 L

.7439 .11738 L

.74641 .12079 L

.74892 .12433 L

.75144 .12802 L

.75395 .13186 L

.75646 .13587 L

.75897 .14007 L

.76148 .14445 L

.76399 .14905 L

.7665 .15389 L

.76901 .15898 L

.77153 .16436 L

.77404 .17006 L

.77655 .17614 L

.77906 .18268 L

.78157 .18976 L

.78408 .19754 L

.78659 .20627 L

Mistroke

.7891 .21643 L

.79162 .22913 L

.79413 .25003 L

Mfstroke

.67736 .44247 m

.67798 .44196 L

.67861 .44143 L

.67924 .44088 L

.67987 .44032 L

.68049 .43975 L

.68112 .43917 L

.68175 .43857 L

.68238 .43798 L

.68301 .43737 L

.68363 .43675 L

.68426 .43615 L

.68489 .43554 L

.68552 .43491 L

.68614 .4343 L

.68677 .43368 L

.6874 .43306 L

.68803 .43244 L

.68866 .43183 L

.68928 .43121 L

.68991 .4306 L

.69054 .42999 L

.69117 .42938 L

.69179 .42876 L

.69242 .42815 L

.69305 .42755 L

.69368 .42694 L

.69431 .42634 L

.69493 .42573 L

.69556 .42513 L

.69619 .42453 L

.69682 .42393 L

.69744 .42334 L

.69807 .42274 L

.6987 .42214 L

.69933 .42155 L

.69996 .42096 L

.70058 .42036 L

.70121 .41977 L

.70184 .41918 L

.70247 .4186 L

.7031 .418 L

.70372 .41742 L

.70435 .41683 L

.70498 .41625 L

.70561 .41566 L

.70623 .41507 L

.70686 .41449 L

.70749 .41391 L

.70812 .41332 L

Mistroke

.70875 .41274 L

.70937 .41216 L

.71 .41157 L

.71063 .41099 L

.71126 .41041 L

.71188 .40982 L

.71251 .40924 L

.71314 .40866 L

.71377 .40808 L

.7144 .40749 L

.71502 .40691 L

.71565 .40633 L

.71628 .40574 L

.71691 .40516 L

.71753 .40457 L

.71816 .40399 L

.71879 .4034 L

.71942 .40282 L

.72005 .40223 L

.72067 .40164 L

.7213 .40105 L

.72193 .40046 L

.72256 .39987 L

.72318 .39928 L

.72381 .39869 L

.72444 .39809 L

.72507 .3975 L

.7257 .3969 L

.72632 .3963 L

.72695 .3957 L

.72758 .3951 L

.72821 .3945 L

.72884 .3939 L

.72946 .39329 L

.73009 .39269 L

.73072 .39208 L

.73135 .39147 L

.73197 .39085 L

.7326 .39024 L

.73323 .38963 L

.73386 .38901 L

.73449 .38839 L

.73511 .38776 L

.73574 .38714 L

.73637 .38651 L

.737 .38588 L

.73762 .38525 L

.73825 .38461 L

.73888 .38398 L

.73951 .38334 L

Mistroke

.74014 .38269 L

.74076 .38205 L

.74139 .3814 L

.74202 .38075 L

.74265 .38009 L

.74327 .37943 L

.7439 .37877 L

.74453 .3781 L

.74516 .37743 L

.74579 .37676 L

.74641 .37608 L

.74704 .3754 L

.74767 .37472 L

.7483 .37403 L

.74892 .37333 L

.74955 .37264 L

.75018 .37193 L

.75081 .37123 L

.75144 .37051 L

.75206 .3698 L

.75269 .36908 L

.75332 .36835 L

.75395 .36761 L

.75458 .36688 L

.7552 .36613 L

.75583 .36538 L

.75646 .36462 L

.75709 .36386 L

.75771 .36309 L

.75834 .36231 L

.75897 .36153 L

.7596 .36074 L

.76023 .35994 L

.76085 .35913 L

.76148 .35832 L

.76211 .3575 L

.76274 .35667 L

.76336 .35583 L

.76399 .35498 L

.76462 .35412 L

.76525 .35325 L

.76588 .35238 L

.7665 .35149 L

.76713 .35059 L

.76776 .34968 L

.76839 .34875 L

.76901 .34782 L

.76964 .34687 L

.77027 .34591 L

.7709 .34493 L

Mistroke

.77153 .34394 L

.77215 .34294 L

.77278 .34191 L

.77341 .34087 L

.77404 .33982 L

.77466 .33874 L

.77529 .33765 L

.77592 .33654 L

.77655 .3354 L

.77718 .33424 L

.7778 .33305 L

.77843 .33185 L

.77906 .33061 L

.77969 .32935 L

.78032 .32805 L

.78094 .32672 L

.78157 .32536 L

.7822 .32396 L

.78283 .32251 L

.78345 .32102 L

.78408 .31949 L

.78471 .3179 L

.78534 .31625 L

.78597 .31454 L

.78659 .31275 L

.78722 .31088 L

.78785 .30892 L

.78848 .30686 L

.7891 .30467 L

.78973 .30234 L

.79036 .29984 L

.79099 .29712 L

.79162 .29412 L

.79224 .29077 L

.79287 .28687 L

.7935 .28211 L

.79413 .27548 L

Mfstroke

.67736 .17556 m

.67798 .17608 L

.67861 .17661 L

.67924 .17716 L

.67987 .17771 L

.68049 .17828 L

.68112 .17886 L

.68175 .17946 L

.68238 .18006 L

.68301 .18066 L

.68363 .18128 L

.68426 .18189 L

.68489 .1825 L

.68552 .18312 L

.68614 .18374 L

.68677 .18436 L

.6874 .18497 L

.68803 .18559 L

.68866 .18621 L

.68928 .18682 L

.68991 .18743 L

.69054 .18804 L

.69117 .18866 L

.69179 .18927 L

.69242 .18988 L

.69305 .19049 L

.69368 .19109 L

.69431 .1917 L

.69493 .1923 L

.69556 .1929 L

.69619 .1935 L

.69682 .1941 L

.69744 .1947 L

.69807 .19529 L

.6987 .19589 L

.69933 .19648 L

.69996 .19708 L

.70058 .19767 L

.70121 .19826 L

.70184 .19885 L

.70247 .19944 L

.7031 .20003 L

.70372 .20062 L

.70435 .2012 L

.70498 .20179 L

.70561 .20237 L

.70623 .20296 L

.70686 .20354 L

.70749 .20413 L

.70812 .20471 L

Mistroke

.70875 .2053 L

.70937 .20588 L

.71 .20646 L

.71063 .20704 L

.71126 .20763 L

.71188 .20821 L

.71251 .20879 L

.71314 .20938 L

.71377 .20996 L

.7144 .21054 L

.71502 .21112 L

.71565 .21171 L

.71628 .21229 L

.71691 .21288 L

.71753 .21346 L

.71816 .21405 L

.71879 .21463 L

.71942 .21522 L

.72005 .21581 L

.72067 .21639 L

.7213 .21698 L

.72193 .21757 L

.72256 .21816 L

.72318 .21876 L

.72381 .21935 L

.72444 .21994 L

.72507 .22054 L

.7257 .22114 L

.72632 .22173 L

.72695 .22233 L

.72758 .22293 L

.72821 .22353 L

.72884 .22414 L

.72946 .22474 L

.73009 .22535 L

.73072 .22596 L

.73135 .22657 L

.73197 .22718 L

.7326 .22779 L

.73323 .22841 L

.73386 .22903 L

.73449 .22965 L

.73511 .23027 L

.73574 .2309 L

.73637 .23152 L

.737 .23215 L

.73762 .23279 L

.73825 .23342 L

.73888 .23406 L

.73951 .2347 L

Mistroke

.74014 .23534 L

.74076 .23599 L

.74139 .23664 L

.74202 .23729 L

.74265 .23795 L

.74327 .2386 L

.7439 .23927 L

.74453 .23993 L

.74516 .2406 L

.74579 .24127 L

.74641 .24195 L

.74704 .24263 L

.74767 .24332 L

.7483 .24401 L

.74892 .2447 L

.74955 .2454 L

.75018 .2461 L

.75081 .24681 L

.75144 .24752 L

.75206 .24824 L

.75269 .24896 L

.75332 .24969 L

.75395 .25042 L

.75458 .25116 L

.7552 .2519 L

.75583 .25265 L

.75646 .25341 L

.75709 .25417 L

.75771 .25494 L

.75834 .25572 L

.75897 .2565 L

.7596 .25729 L

.76023 .25809 L

.76085 .2589 L

.76148 .25971 L

.76211 .26054 L

.76274 .26137 L

.76336 .2622 L

.76399 .26305 L

.76462 .26391 L

.76525 .26478 L

.76588 .26566 L

.7665 .26655 L

.76713 .26745 L

.76776 .26836 L

.76839 .26928 L

.76901 .27022 L

.76964 .27116 L

.77027 .27213 L

.7709 .2731 L

Mistroke

.77153 .27409 L

.77215 .2751 L

.77278 .27612 L

.77341 .27716 L

.77404 .27821 L

.77466 .27929 L

.77529 .28039 L

.77592 .2815 L

.77655 .28264 L

.77718 .28379 L

.7778 .28498 L

.77843 .28619 L

.77906 .28742 L

.77969 .28869 L

.78032 .28998 L

.78094 .29131 L

.78157 .29267 L

.7822 .29408 L

.78283 .29552 L

.78345 .29701 L

.78408 .29855 L

.78471 .30014 L

.78534 .30179 L

.78597 .3035 L

.78659 .30528 L

.78722 .30715 L

.78785 .30911 L

.78848 .31118 L

.7891 .31336 L

.78973 .31569 L

.79036 .31819 L

.79099 .32092 L

.79162 .32391 L

.79224 .32726 L

.79287 .33116 L

.7935 .33593 L

.79413 .34255 L

Mfstroke

.6648 .44897 m

.66229 .44956 L

.65978 .45033 L

.65727 .45107 L

.65475 .45178 L

.65224 .45248 L

.64973 .45318 L

.64722 .45386 L

.64471 .45455 L

.6422 .45522 L

.63969 .4559 L

.63718 .45657 L

.63466 .45724 L

.63215 .45791 L

.62964 .45858 L

.62713 .45925 L

.62462 .45991 L

.62211 .46058 L

.6196 .46125 L

.61709 .46192 L

.61457 .46258 L

.61206 .46325 L

.60955 .46392 L

.60704 .46459 L

.60453 .46526 L

.60202 .46593 L

.59951 .4666 L

.597 .46727 L

.59448 .46794 L

.59197 .46861 L

.58946 .46929 L

.58695 .46996 L

.58444 .47063 L

.58193 .47131 L

.57942 .47199 L

.57691 .47266 L

.57439 .47334 L

.57188 .47402 L

.56937 .47469 L

.56686 .47537 L

.56435 .47605 L

.56184 .47673 L

.55933 .47742 L

.55682 .4781 L

.55431 .47878 L

.55179 .47946 L

.54928 .48015 L

.54677 .48083 L

.54426 .48152 L

.54175 .4822 L

Mistroke

.53924 .48289 L

.53673 .48358 L

.53422 .48426 L

.5317 .48495 L

.52919 .48564 L

.52668 .48633 L

.52417 .48702 L

.52166 .48771 L

.51915 .4884 L

.51664 .4891 L

.51413 .48979 L

.51161 .49048 L

.5091 .49117 L

.50659 .49187 L

.50408 .49256 L

.50157 .49326 L

.49906 .49395 L

.49655 .49465 L

.49404 .49534 L

.49152 .49604 L

.48901 .49673 L

.4865 .49743 L

.48399 .49813 L

.48148 .49882 L

.47897 .49952 L

.47646 .50022 L

.47395 .50092 L

.47143 .50161 L

.46892 .50231 L

.46641 .50301 L

.4639 .5037 L

.46139 .5044 L

.45888 .5051 L

.45637 .50579 L

.45386 .50649 L

.45135 .50719 L

.44883 .50788 L

.44632 .50858 L

.44381 .50927 L

.4413 .50997 L

.43879 .51066 L

.43628 .51136 L

.43377 .51205 L

.43126 .51275 L

.42874 .51344 L

.42623 .51413 L

.42372 .51482 L

.42121 .51551 L

.4187 .5162 L

.41619 .51689 L

Mistroke

.41368 .51758 L

.41117 .51826 L

.40865 .51895 L

.40614 .51963 L

.40363 .52031 L

.40112 .52099 L

.39861 .52167 L

.3961 .52235 L

.39359 .52303 L

.39108 .5237 L

.38856 .52438 L

.38605 .52505 L

.38354 .52572 L

.38103 .52639 L

.37852 .52705 L

.37601 .52772 L

.3735 .52838 L

.37099 .52904 L

.36847 .5297 L

.36596 .53035 L

.36345 .531 L

.36094 .53165 L

.35843 .5323 L

.35592 .53294 L

.35341 .53358 L

.3509 .53422 L

.34838 .53485 L

.34587 .53548 L

.34336 .53611 L

.34085 .53673 L

.33834 .53735 L

.33583 .53797 L

.33332 .53858 L

.33081 .53919 L

.3283 .53979 L

.32578 .54039 L

.32327 .54098 L

.32076 .54157 L

.31825 .54215 L

.31574 .54273 L

.31323 .54331 L

.31072 .54387 L

.30821 .54444 L

.30569 .54499 L

.30318 .54554 L

.30067 .54608 L

.29816 .54662 L

.29565 .54715 L

.29314 .54767 L

.29063 .54819 L

Mistroke

.28812 .5487 L

.2856 .5492 L

.28309 .54969 L

.28058 .55017 L

.27807 .55065 L

.27556 .55112 L

.27305 .55157 L

.27054 .55202 L

.26803 .55246 L

.26551 .55289 L

.263 .55331 L

.26049 .55372 L

.25798 .55411 L

.25547 .5545 L

.25296 .55487 L

.25045 .55524 L

.24794 .55559 L

.24542 .55592 L

.24291 .55625 L

.2404 .55656 L

.23789 .55685 L

.23538 .55713 L

.23287 .5574 L

.23036 .55765 L

.22785 .55789 L

.22534 .55811 L

.22282 .55831 L

.22031 .5585 L

.2178 .55866 L

.21529 .55881 L

.21278 .55894 L

.21027 .55905 L

.20776 .55914 L

.20525 .55921 L

.20273 .55925 L

.20022 .55928 L

.19771 .55928 L

.1952 .55926 L

.19269 .55921 L

.19018 .55914 L

.18767 .55904 L

.18516 .55891 L

.18264 .55876 L

.18013 .55857 L

.17762 .55836 L

.17511 .55811 L

.1726 .55784 L

.17009 .55753 L

.16758 .55718 L

.16507 .5568 L

Mistroke

.16255 .55639 L

.16004 .55593 L

.15753 .55544 L

.15502 .55491 L

.15251 .55433 L

.15 .55372 L

.14749 .55305 L

.14498 .55234 L

.14246 .55158 L

.13995 .55077 L

.13744 .54991 L

.13493 .549 L

.13242 .54803 L

.12991 .547 L

.1274 .54591 L

.12489 .54475 L

.12237 .54353 L

.11986 .54225 L

.11735 .54089 L

.11484 .53946 L

.11233 .53795 L

.10982 .53636 L

.10731 .53469 L

.1048 .53293 L

.10229 .53107 L

.09977 .52912 L

.09726 .52707 L

.09475 .52492 L

.09224 .52265 L

.08973 .52026 L

.08722 .51775 L

.08471 .5151 L

.0822 .51232 L

.07968 .50939 L

.07717 .50631 L

.07466 .50306 L

.07215 .49963 L

.06964 .496 L

.06713 .49218 L

.06462 .48813 L

.06211 .48384 L

.05959 .47928 L

.05708 .47444 L

.05457 .46928 L

.05206 .46377 L

.04955 .45785 L

.04704 .45149 L

.04453 .44461 L

.04202 .43711 L

.0395 .42889 L

Mistroke

.03699 .41977 L

.03448 .4095 L

.03197 .39768 L

.02946 .38355 L

.02695 .36541 L

.02632 .35976 L

.02569 .35336 L

.02507 .3458 L

.02444 .33611 L

Mfstroke

.66417 .16907 m

.66229 .16847 L

.65978 .1677 L

.65727 .16697 L

.65475 .16625 L

.65224 .16555 L

.64973 .16486 L

.64722 .16417 L

.64471 .16349 L

.6422 .16281 L

.63969 .16214 L

.63718 .16146 L

.63466 .16079 L

.63215 .16012 L

.62964 .15946 L

.62713 .15879 L

.62462 .15812 L

.62211 .15745 L

.6196 .15678 L

.61709 .15612 L

.61457 .15545 L

.61206 .15478 L

.60955 .15411 L

.60704 .15344 L

.60453 .15277 L

.60202 .1521 L

.59951 .15143 L

.597 .15076 L

.59448 .15009 L

.59197 .14942 L

.58946 .14875 L

.58695 .14807 L

.58444 .1474 L

.58193 .14672 L

.57942 .14605 L

.57691 .14537 L

.57439 .1447 L

.57188 .14402 L

.56937 .14334 L

.56686 .14266 L

.56435 .14198 L

.56184 .1413 L

.55933 .14062 L

.55682 .13994 L

.55431 .13925 L

.55179 .13857 L

.54928 .13789 L

.54677 .1372 L

.54426 .13652 L

.54175 .13583 L

Mistroke

.53924 .13514 L

.53673 .13446 L

.53422 .13377 L

.5317 .13308 L

.52919 .13239 L

.52668 .1317 L

.52417 .13101 L

.52166 .13032 L

.51915 .12963 L

.51664 .12894 L

.51413 .12825 L

.51161 .12755 L

.5091 .12686 L

.50659 .12617 L

.50408 .12547 L

.50157 .12478 L

.49906 .12408 L

.49655 .12339 L

.49404 .12269 L

.49152 .122 L

.48901 .1213 L

.4865 .1206 L

.48399 .11991 L

.48148 .11921 L

.47897 .11851 L

.47646 .11782 L

.47395 .11712 L

.47143 .11642 L

.46892 .11572 L

.46641 .11503 L

.4639 .11433 L

.46139 .11363 L

.45888 .11294 L

.45637 .11224 L

.45386 .11154 L

.45135 .11085 L

.44883 .11015 L

.44632 .10945 L

.44381 .10876 L

.4413 .10806 L

.43879 .10737 L

.43628 .10668 L

.43377 .10598 L

.43126 .10529 L

.42874 .1046 L

.42623 .1039 L

.42372 .10321 L

.42121 .10252 L

.4187 .10183 L

.41619 .10115 L

Mistroke

.41368 .10046 L

.41117 .09977 L

.40865 .09909 L

.40614 .0984 L

.40363 .09772 L

.40112 .09704 L

.39861 .09636 L

.3961 .09568 L

.39359 .095 L

.39108 .09433 L

.38856 .09366 L

.38605 .09298 L

.38354 .09231 L

.38103 .09165 L

.37852 .09098 L

.37601 .09032 L

.3735 .08965 L

.37099 .08899 L

.36847 .08834 L

.36596 .08768 L

.36345 .08703 L

.36094 .08638 L

.35843 .08573 L

.35592 .08509 L

.35341 .08445 L

.3509 .08381 L

.34838 .08318 L

.34587 .08255 L

.34336 .08192 L

.34085 .0813 L

.33834 .08068 L

.33583 .08006 L

.33332 .07945 L

.33081 .07885 L

.3283 .07824 L

.32578 .07764 L

.32327 .07705 L

.32076 .07646 L

.31825 .07588 L

.31574 .0753 L

.31323 .07473 L

.31072 .07416 L

.30821 .0736 L

.30569 .07304 L

.30318 .07249 L

.30067 .07195 L

.29816 .07141 L

.29565 .07088 L

.29314 .07036 L

.29063 .06984 L

Mistroke

.28812 .06934 L

.2856 .06884 L

.28309 .06834 L

.28058 .06786 L

.27807 .06738 L

.27556 .06692 L

.27305 .06646 L

.27054 .06601 L

.26803 .06557 L

.26551 .06514 L

.263 .06472 L

.26049 .06432 L

.25798 .06392 L

.25547 .06353 L

.25296 .06316 L

.25045 .0628 L

.24794 .06245 L

.24542 .06211 L

.24291 .06179 L

.2404 .06148 L

.23789 .06118 L

.23538 .0609 L

.23287 .06063 L

.23036 .06038 L

.22785 .06014 L

.22534 .05992 L

.22282 .05972 L

.22031 .05954 L

.2178 .05937 L

.21529 .05922 L

.21278 .05909 L

.21027 .05898 L

.20776 .05889 L

.20525 .05883 L

.20273 .05878 L

.20022 .05876 L

.19771 .05876 L

.1952 .05878 L

.19269 .05883 L

.19018 .0589 L

.18767 .059 L

.18516 .05912 L

.18264 .05928 L

.18013 .05946 L

.17762 .05968 L

.17511 .05992 L

.1726 .0602 L

.17009 .06051 L

.16758 .06085 L

.16507 .06123 L

Mistroke

.16255 .06165 L

.16004 .0621 L

.15753 .06259 L

.15502 .06313 L

.15251 .0637 L

.15 .06432 L

.14749 .06498 L

.14498 .06569 L

.14246 .06645 L

.13995 .06726 L

.13744 .06812 L

.13493 .06904 L

.13242 .07001 L

.12991 .07104 L

.1274 .07213 L

.12489 .07328 L

.12237 .0745 L

.11986 .07578 L

.11735 .07714 L

.11484 .07857 L

.11233 .08008 L

.10982 .08167 L

.10731 .08334 L

.1048 .08511 L

.10229 .08696 L

.09977 .08891 L

.09726 .09096 L

.09475 .09312 L

.09224 .09539 L

.08973 .09778 L

.08722 .10029 L

.08471 .10293 L

.0822 .10571 L

.07968 .10864 L

.07717 .11172 L

.07466 .11498 L

.07215 .11841 L

.06964 .12203 L

.06713 .12586 L

.06462 .12991 L

.06211 .1342 L

.05959 .13875 L

.05708 .14359 L

.05457 .14875 L

.05206 .15427 L

.04955 .16018 L

.04704 .16654 L

.04453 .17343 L

.04202 .18092 L

.0395 .18914 L

Mistroke

.03699 .19826 L

.03448 .20853 L

.03197 .22036 L

.02946 .23448 L

.02695 .25263 L

.02632 .25827 L

.02569 .26467 L

.02507 .27224 L

.02444 .28193 L

Mfstroke

0 1 .4 r

.67861 .4491 m

.67987 .44836 L

.68112 .4477 L

.68238 .44712 L

.68363 .44659 L

.68489 .4461 L

.68614 .44565 L

.6874 .44522 L

.68866 .44481 L

.68991 .44441 L

.69117 .44403 L

.69242 .44365 L

.69368 .44329 L

.69493 .44293 L

.69619 .44257 L

.69744 .44222 L

.6987 .44188 L

.69996 .44154 L

.70121 .4412 L

.70247 .44086 L

.70372 .44053 L

.70498 .4402 L

.70623 .43987 L

.70749 .43954 L

.70875 .43921 L

.71 .43889 L

.71126 .43856 L

.71251 .43824 L

.71377 .43792 L

.71502 .4376 L

.71628 .43728 L

.71753 .43696 L

.71879 .43664 L

.72005 .43632 L

.7213 .43601 L

.72256 .43569 L

.72381 .43538 L

.72507 .43506 L

.72632 .43475 L

.72758 .43444 L

.72884 .43413 L

.73009 .43381 L

.73135 .4335 L

.7326 .43319 L

.73386 .43288 L

.73511 .43257 L

.73637 .43226 L

.73762 .43195 L

.73888 .43164 L

.74014 .43133 L

Mistroke

.74139 .43103 L

.74265 .43072 L

.7439 .43041 L

.74516 .43011 L

.74641 .4298 L

.74767 .42949 L

.74892 .42919 L

.75018 .42888 L

.75144 .42858 L

.75269 .42827 L

.75395 .42797 L

.7552 .42767 L

.75646 .42736 L

.75771 .42706 L

.75897 .42676 L

.76023 .42645 L

.76148 .42615 L

.76274 .42585 L

.76399 .42555 L

.76525 .42525 L

.7665 .42494 L

.76776 .42464 L

.76901 .42434 L

.77027 .42404 L

.77153 .42374 L

.77278 .42344 L

.77404 .42315 L

.77529 .42285 L

.77655 .42255 L

.7778 .42225 L

.77906 .42195 L

.78032 .42165 L

.78157 .42136 L

.78283 .42106 L

.78408 .42076 L

.78534 .42046 L

.78659 .42017 L

.78785 .41987 L

.7891 .41958 L

.79036 .41928 L

.79162 .41898 L

.79287 .41869 L

.79413 .41839 L

.79538 .4181 L

.79664 .4178 L

.79789 .41751 L

.79915 .41722 L

.8004 .41692 L

.80166 .41663 L

.80292 .41634 L

Mistroke

.80417 .41604 L

.80543 .41575 L

.80668 .41546 L

.80794 .41516 L

.80919 .41487 L

.81045 .41458 L

.81171 .41429 L

.81296 .414 L

.81422 .41371 L

.81547 .41342 L

.81673 .41313 L

.81798 .41283 L

.81924 .41254 L

.82049 .41225 L

.82175 .41196 L

.82301 .41167 L

.82426 .41139 L

.82552 .4111 L

.82677 .41081 L

.82803 .41052 L

.82928 .41023 L

.83054 .40994 L

.8318 .40965 L

.83305 .40937 L

.83431 .40908 L

.83556 .40879 L

.83682 .4085 L

.83807 .40822 L

.83933 .40793 L

.84058 .40764 L

.84184 .40736 L

.8431 .40707 L

.84435 .40679 L

.84561 .4065 L

.84686 .40621 L

.84812 .40593 L

.84937 .40564 L

.85063 .40536 L

.85188 .40507 L

.85314 .40479 L

.8544 .40451 L

.85565 .40422 L

.85691 .40394 L

.85816 .40365 L

.85942 .40337 L

.86067 .40309 L

.86193 .4028 L

.86319 .40252 L

.86444 .40224 L

.8657 .40196 L

Mistroke

.86695 .40167 L

.86821 .40139 L

.86946 .40111 L

.87072 .40083 L

.87197 .40055 L

.87323 .40026 L

.87449 .39998 L

.87574 .3997 L

.877 .39942 L

.87825 .39914 L

.87951 .39886 L

.88076 .39858 L

.88202 .3983 L

.88328 .39802 L

.88453 .39774 L

.88579 .39746 L

.88704 .39718 L

.8883 .3969 L

.88955 .39662 L

.89081 .39634 L

.89206 .39607 L

.89332 .39579 L

.89458 .39551 L

.89583 .39523 L

.89709 .39495 L

.89834 .39467 L

.8996 .3944 L

.90085 .39412 L

.90211 .39384 L

.90337 .39356 L

.90462 .39329 L

.90588 .39301 L

.90713 .39273 L

.90839 .39246 L

.90964 .39218 L

.9109 .3919 L

.91215 .39163 L

.91341 .39135 L

.91467 .39108 L

.91592 .3908 L

.91718 .39052 L

.91843 .39025 L

.91969 .38997 L

.92094 .3897 L

.9222 .38942 L

.92345 .38915 L

.92471 .38887 L

.92597 .3886 L

.92722 .38832 L

.92848 .38805 L

Mistroke

.92973 .38778 L

.93099 .3875 L

.93224 .38723 L

.9335 .38695 L

.93476 .38668 L

.93601 .38641 L

.93727 .38613 L

.93852 .38586 L

.93978 .38559 L

.94103 .38531 L

.94229 .38504 L

.94354 .38477 L

.9448 .3845 L

.94606 .38422 L

.94731 .38395 L

.94857 .38368 L

.94982 .38341 L

.95108 .38314 L

.95233 .38286 L

.95359 .38259 L

.95485 .38232 L

.9561 .38205 L

.95736 .38178 L

.95861 .38151 L

.95987 .38124 L

.96112 .38096 L

.96238 .38069 L

.96363 .38042 L

.96489 .38015 L

.96615 .37988 L

.9674 .37961 L

.96866 .37934 L

.96991 .37907 L

.97117 .3788 L

.97242 .37853 L

.97368 .37826 L

.97493 .37799 L

.97619 .37772 L

Mfstroke

.67861 .16893 m

.67987 .16968 L

.68112 .17033 L

.68238 .17091 L

.68363 .17144 L

.68489 .17193 L

.68614 .17239 L

.6874 .17282 L

.68866 .17323 L

.68991 .17362 L

.69117 .17401 L

.69242 .17438 L

.69368 .17475 L

.69493 .17511 L

.69619 .17547 L

.69744 .17581 L

.6987 .17616 L

.69996 .1765 L

.70121 .17684 L

.70247 .17717 L

.70372 .17751 L

.70498 .17784 L

.70623 .17817 L

.70749 .1785 L

.70875 .17882 L

.71 .17915 L

.71126 .17947 L

.71251 .17979 L

.71377 .18012 L

.71502 .18044 L

.71628 .18076 L

.71753 .18108 L

.71879 .18139 L

.72005 .18171 L

.7213 .18203 L

.72256 .18234 L

.72381 .18266 L

.72507 .18297 L

.72632 .18328 L

.72758 .1836 L

.72884 .18391 L

.73009 .18422 L

.73135 .18453 L

.7326 .18484 L

.73386 .18515 L

.73511 .18546 L

.73637 .18577 L

.73762 .18608 L

.73888 .18639 L

.74014 .1867 L

Mistroke

.74139 .18701 L

.74265 .18731 L

.7439 .18762 L

.74516 .18793 L

.74641 .18823 L

.74767 .18854 L

.74892 .18885 L

.75018 .18915 L

.75144 .18946 L

.75269 .18976 L

.75395 .19006 L

.7552 .19037 L

.75646 .19067 L

.75771 .19097 L

.75897 .19128 L

.76023 .19158 L

.76148 .19188 L

.76274 .19219 L

.76399 .19249 L

.76525 .19279 L

.7665 .19309 L

.76776 .19339 L

.76901 .19369 L

.77027 .19399 L

.77153 .19429 L

.77278 .19459 L

.77404 .19489 L

.77529 .19519 L

.77655 .19549 L

.7778 .19578 L

.77906 .19608 L

.78032 .19638 L

.78157 .19668 L

.78283 .19698 L

.78408 .19727 L

.78534 .19757 L

.78659 .19787 L

.78785 .19816 L

.7891 .19846 L

.79036 .19875 L

.79162 .19905 L

.79287 .19934 L

.79413 .19964 L

.79538 .19994 L

.79664 .20023 L

.79789 .20052 L

.79915 .20082 L

.8004 .20111 L

.80166 .2014 L

.80292 .2017 L

Mistroke

.80417 .20199 L

.80543 .20228 L

.80668 .20258 L

.80794 .20287 L

.80919 .20316 L

.81045 .20345 L

.81171 .20374 L

.81296 .20404 L

.81422 .20433 L

.81547 .20462 L

.81673 .20491 L

.81798 .2052 L

.81924 .20549 L

.82049 .20578 L

.82175 .20607 L

.82301 .20636 L

.82426 .20665 L

.82552 .20694 L

.82677 .20723 L

.82803 .20752 L

.82928 .2078 L

.83054 .20809 L

.8318 .20838 L

.83305 .20867 L

.83431 .20895 L

.83556 .20924 L

.83682 .20953 L

.83807 .20982 L

.83933 .2101 L

.84058 .21039 L

.84184 .21068 L

.8431 .21096 L

.84435 .21125 L

.84561 .21153 L

.84686 .21182 L

.84812 .2121 L

.84937 .21239 L

.85063 .21267 L

.85188 .21296 L

.85314 .21324 L

.8544 .21353 L

.85565 .21381 L

.85691 .2141 L

.85816 .21438 L

.85942 .21466 L

.86067 .21495 L

.86193 .21523 L

.86319 .21551 L

.86444 .2158 L

.8657 .21608 L

Mistroke

.86695 .21636 L

.86821 .21664 L

.86946 .21692 L

.87072 .21721 L

.87197 .21749 L

.87323 .21777 L

.87449 .21805 L

.87574 .21833 L

.877 .21861 L

.87825 .21889 L

.87951 .21917 L

.88076 .21945 L

.88202 .21973 L

.88328 .22001 L

.88453 .22029 L

.88579 .22057 L

.88704 .22085 L

.8883 .22113 L

.88955 .22141 L

.89081 .22169 L

.89206 .22197 L

.89332 .22225 L

.89458 .22253 L

.89583 .2228 L

.89709 .22308 L

.89834 .22336 L

.8996 .22364 L

.90085 .22392 L

.90211 .22419 L

.90337 .22447 L

.90462 .22475 L

.90588 .22502 L

.90713 .2253 L

.90839 .22558 L

.90964 .22585 L

.9109 .22613 L

.91215 .22641 L

.91341 .22668 L

.91467 .22696 L

.91592 .22723 L

.91718 .22751 L

.91843 .22779 L

.91969 .22806 L

.92094 .22834 L

.9222 .22861 L

.92345 .22889 L

.92471 .22916 L

.92597 .22944 L

.92722 .22971 L

.92848 .22998 L

Mistroke

.92973 .23026 L

.93099 .23053 L

.93224 .23081 L

.9335 .23108 L

.93476 .23135 L

.93601 .23163 L

.93727 .2319 L

.93852 .23217 L

.93978 .23245 L

.94103 .23272 L

.94229 .23299 L

.94354 .23326 L

.9448 .23354 L

.94606 .23381 L

.94731 .23408 L

.94857 .23435 L

.94982 .23463 L

.95108 .2349 L

.95233 .23517 L

.95359 .23544 L

.95485 .23571 L

.9561 .23598 L

.95736 .23626 L

.95861 .23653 L

.95987 .2368 L

.96112 .23707 L

.96238 .23734 L

.96363 .23761 L

.96489 .23788 L

.96615 .23815 L

.9674 .23842 L

.96866 .23869 L

.96991 .23896 L

.97117 .23923 L

.97242 .2395 L

.97368 .23977 L

.97493 .24004 L

.97619 .24031 L

Mfstroke

.97619 .48895 m

.97493 .48913 L

.97368 .48931 L

.97242 .48949 L

.97117 .48968 L

.96991 .48986 L

.96866 .49004 L

.9674 .49022 L

.96615 .4904 L

.96489 .49058 L

.96363 .49076 L

.96238 .49094 L

.96112 .49112 L

.95987 .4913 L

.95861 .49148 L

.95736 .49166 L

.9561 .49185 L

.95485 .49203 L

.95359 .49221 L

.95233 .49239 L

.95108 .49257 L

.94982 .49275 L

.94857 .49293 L

.94731 .49311 L

.94606 .49329 L

.9448 .49347 L

.94354 .49365 L

.94229 .49383 L

.94103 .49401 L

.93978 .49419 L

.93852 .49437 L

.93727 .49455 L

.93601 .49473 L

.93476 .49491 L

.9335 .49509 L

.93224 .49527 L

.93099 .49545 L

.92973 .49563 L

.92848 .49581 L

.92722 .49599 L

.92597 .49617 L

.92471 .49635 L

.92345 .49653 L

.9222 .49671 L

.92094 .49688 L

.91969 .49706 L

.91843 .49724 L

.91718 .49742 L

.91592 .4976 L

.91467 .49777 L

Mistroke

.91341 .49795 L

.91215 .49813 L

.9109 .49831 L

.90964 .49848 L

.90839 .49866 L

.90713 .49884 L

.90588 .49901 L

.90462 .49919 L

.90337 .49936 L

.90211 .49954 L

.90085 .49971 L

.8996 .49989 L

.89834 .50006 L

.89709 .50024 L

.89583 .50041 L

.89458 .50058 L

.89332 .50076 L

.89206 .50093 L

.89081 .5011 L

.88955 .50127 L

.8883 .50145 L

.88704 .50162 L

.88579 .50179 L

.88453 .50196 L

.88328 .50213 L

.88202 .5023 L

.88076 .50247 L

.87951 .50264 L

.87825 .5028 L

.877 .50297 L

.87574 .50314 L

.87449 .50331 L

.87323 .50347 L

.87197 .50364 L

.87072 .5038 L

.86946 .50397 L

.86821 .50413 L

.86695 .5043 L

.8657 .50446 L

.86444 .50462 L

.86319 .50478 L

.86193 .50494 L

.86067 .5051 L

.85942 .50526 L

.85816 .50542 L

.85691 .50558 L

.85565 .50574 L

.8544 .50589 L

.85314 .50605 L

.85188 .50621 L

Mistroke

.85063 .50636 L

.84937 .50651 L

.84812 .50667 L

.84686 .50682 L

.84561 .50697 L

.84435 .50712 L

.8431 .50727 L

.84184 .50742 L

.84058 .50756 L

.83933 .50771 L

.83807 .50786 L

.83682 .508 L

.83556 .50814 L

.83431 .50829 L

.83305 .50843 L

.8318 .50857 L

.83054 .50871 L

.82928 .50884 L

.82803 .50898 L

.82677 .50912 L

.82552 .50925 L

.82426 .50938 L

.82301 .50951 L

.82175 .50964 L

.82049 .50977 L

.81924 .5099 L

.81798 .51003 L

.81673 .51015 L

.81547 .51027 L

.81422 .5104 L

.81296 .51052 L

.81171 .51064 L

.81045 .51075 L

.80919 .51087 L

.80794 .51098 L

.80668 .51109 L

.80543 .5112 L

.80417 .51131 L

.80292 .51142 L

.80166 .51152 L

.8004 .51163 L

.79915 .51173 L

.79789 .51183 L

.79664 .51192 L

.79538 .51202 L

.79413 .51211 L

.79287 .5122 L

.79162 .51229 L

.79036 .51238 L

.7891 .51246 L

Mistroke

.78785 .51254 L

.78659 .51262 L

.78534 .5127 L

.78408 .51278 L

.78283 .51285 L

.78157 .51292 L

.78032 .51298 L

.77906 .51305 L

.7778 .51311 L

.77655 .51317 L

.77529 .51322 L

.77404 .51328 L

.77278 .51333 L

.77153 .51337 L

.77027 .51342 L

.76901 .51346 L

.76776 .51349 L

.7665 .51353 L

.76525 .51356 L

.76399 .51358 L

.76274 .51361 L

.76148 .51363 L

.76023 .51364 L

.75897 .51366 L

.75771 .51367 L

.75646 .51367 L

.7552 .51367 L

.75395 .51367 L

.75269 .51366 L

.75144 .51365 L

.75018 .51363 L

.74892 .51361 L

.74767 .51358 L

.74641 .51355 L

.74516 .51352 L

.7439 .51348 L

.74265 .51343 L

.74139 .51338 L

.74014 .51333 L

.73888 .51326 L

.73762 .5132 L

.73637 .51313 L

.73511 .51305 L

.73386 .51296 L

.7326 .51287 L

.73135 .51278 L

.73009 .51267 L

.72884 .51256 L

.72758 .51244 L

.72632 .51232 L

Mistroke

.72507 .51219 L

.72381 .51205 L

.72256 .5119 L

.7213 .51175 L

.72005 .51159 L

.71879 .51141 L

.71753 .51124 L

.71628 .51105 L

.71502 .51085 L

.71377 .51064 L

.71251 .51043 L

.71126 .5102 L

.71 .50996 L

.70875 .50971 L

.70749 .50945 L

.70623 .50918 L

.70498 .5089 L

.70372 .5086 L

.70247 .50829 L

.70121 .50796 L

.69996 .50763 L

.6987 .50727 L

.69744 .5069 L

.69619 .50651 L

.69493 .50611 L

.69368 .50569 L

.69242 .50524 L

.69117 .50478 L

.68991 .50429 L

.68866 .50378 L

.6874 .50325 L

.68614 .50268 L

.68489 .50209 L

.68363 .50146 L

.68238 .5008 L

.68112 .5001 L

.67987 .49935 L

.67861 .49856 L

.67736 .49771 L

.6761 .49681 L

.67484 .49582 L

.67359 .49476 L

.67233 .49359 L

.67108 .49229 L

.66982 .49083 L

.66857 .48913 L

.66731 .48711 L

.66605 .48447 L

.6648 .48019 L

Mfstroke

.97619 .12908 m

.97493 .1289 L

.97368 .12872 L

.97242 .12854 L

.97117 .12836 L

.96991 .12818 L

.96866 .128 L

.9674 .12782 L

.96615 .12764 L

.96489 .12745 L

.96363 .12727 L

.96238 .12709 L

.96112 .12691 L

.95987 .12673 L

.95861 .12655 L

.95736 .12637 L

.9561 .12619 L

.95485 .12601 L

.95359 .12583 L

.95233 .12565 L

.95108 .12547 L

.94982 .12529 L

.94857 .1251 L

.94731 .12492 L

.94606 .12474 L

.9448 .12456 L

.94354 .12438 L

.94229 .1242 L

.94103 .12402 L

.93978 .12384 L

.93852 .12366 L

.93727 .12348 L

.93601 .1233 L

.93476 .12312 L

.9335 .12294 L

.93224 .12276 L

.93099 .12258 L

.92973 .1224 L

.92848 .12222 L

.92722 .12204 L

.92597 .12186 L

.92471 .12169 L

.92345 .12151 L

.9222 .12133 L

.92094 .12115 L

.91969 .12097 L

.91843 .12079 L

.91718 .12061 L

.91592 .12044 L

.91467 .12026 L

Mistroke

.91341 .12008 L

.91215 .1199 L

.9109 .11973 L

.90964 .11955 L

.90839 .11937 L

.90713 .1192 L

.90588 .11902 L

.90462 .11885 L

.90337 .11867 L

.90211 .1185 L

.90085 .11832 L

.8996 .11815 L

.89834 .11797 L

.89709 .1178 L

.89583 .11762 L

.89458 .11745 L

.89332 .11728 L

.89206 .1171 L

.89081 .11693 L

.88955 .11676 L

.8883 .11659 L

.88704 .11642 L

.88579 .11625 L

.88453 .11608 L

.88328 .11591 L

.88202 .11574 L

.88076 .11557 L

.87951 .1154 L

.87825 .11523 L

.877 .11506 L

.87574 .11489 L

.87449 .11473 L

.87323 .11456 L

.87197 .1144 L

.87072 .11423 L

.86946 .11407 L

.86821 .1139 L

.86695 .11374 L

.8657 .11358 L

.86444 .11341 L

.86319 .11325 L

.86193 .11309 L

.86067 .11293 L

.85942 .11277 L

.85816 .11261 L

.85691 .11245 L

.85565 .1123 L

.8544 .11214 L

.85314 .11198 L

.85188 .11183 L

Mistroke

.85063 .11167 L

.84937 .11152 L

.84812 .11137 L

.84686 .11122 L

.84561 .11107 L

.84435 .11092 L

.8431 .11077 L

.84184 .11062 L

.84058 .11047 L

.83933 .11032 L

.83807 .11018 L

.83682 .11003 L

.83556 .10989 L

.83431 .10975 L

.83305 .10961 L

.8318 .10947 L

.83054 .10933 L

.82928 .10919 L

.82803 .10905 L

.82677 .10892 L

.82552 .10878 L

.82426 .10865 L

.82301 .10852 L

.82175 .10839 L

.82049 .10826 L

.81924 .10813 L

.81798 .10801 L

.81673 .10788 L

.81547 .10776 L

.81422 .10764 L

.81296 .10752 L

.81171 .1074 L

.81045 .10728 L

.80919 .10717 L

.80794 .10705 L

.80668 .10694 L

.80543 .10683 L

.80417 .10672 L

.80292 .10662 L

.80166 .10651 L

.8004 .10641 L

.79915 .10631 L

.79789 .10621 L

.79664 .10611 L

.79538 .10601 L

.79413 .10592 L

.79287 .10583 L

.79162 .10574 L

.79036 .10566 L

.7891 .10557 L

Mistroke

.78785 .10549 L

.78659 .10541 L

.78534 .10533 L

.78408 .10526 L

.78283 .10519 L

.78157 .10512 L

.78032 .10505 L

.77906 .10499 L

.7778 .10492 L

.77655 .10487 L

.77529 .10481 L

.77404 .10476 L

.77278 .10471 L

.77153 .10466 L

.77027 .10462 L

.76901 .10458 L

.76776 .10454 L

.7665 .10451 L

.76525 .10448 L

.76399 .10445 L

.76274 .10443 L

.76148 .10441 L

.76023 .10439 L

.75897 .10438 L

.75771 .10437 L

.75646 .10436 L

.7552 .10436 L

.75395 .10437 L

.75269 .10437 L

.75144 .10439 L

.75018 .1044 L

.74892 .10442 L

.74767 .10445 L

.74641 .10448 L

.74516 .10452 L

.7439 .10456 L

.74265 .1046 L

.74139 .10465 L

.74014 .10471 L

.73888 .10477 L

.73762 .10484 L

.73637 .10491 L

.73511 .10499 L

.73386 .10507 L

.7326 .10516 L

.73135 .10526 L

.73009 .10536 L

.72884 .10547 L

.72758 .10559 L

.72632 .10571 L

Mistroke

.72507 .10585 L

.72381 .10598 L

.72256 .10613 L

.7213 .10629 L

.72005 .10645 L

.71879 .10662 L

.71753 .1068 L

.71628 .10699 L

.71502 .10718 L

.71377 .10739 L

.71251 .10761 L

.71126 .10784 L

.71 .10807 L

.70875 .10832 L

.70749 .10858 L

.70623 .10885 L

.70498 .10914 L

.70372 .10944 L

.70247 .10975 L

.70121 .11007 L

.69996 .11041 L

.6987 .11076 L

.69744 .11113 L

.69619 .11152 L

.69493 .11192 L

.69368 .11235 L

.69242 .11279 L

.69117 .11326 L

.68991 .11374 L

.68866 .11425 L

.6874 .11479 L

.68614 .11535 L

.68489 .11595 L

.68363 .11657 L

.68238 .11723 L

.68112 .11794 L

.67987 .11868 L

.67861 .11947 L

.67736 .12032 L

.6761 .12123 L

.67484 .12221 L

.67359 .12328 L

.67233 .12445 L

.67108 .12574 L

.66982 .12721 L

.66857 .1289 L

.66731 .13093 L

.66605 .13356 L

.6648 .13785 L

Mfstroke

.6648 .48019 m

.66442 .47503 L

.66455 .47321 L

.66467 .47222 L

.6648 .47142 L

.66505 .47014 L

.66568 .46774 L

.66631 .46585 L

.66693 .46425 L

.66756 .46283 L

.66819 .46155 L

.66944 .45926 L

.67032 .45783 L

.67083 .45706 L

.67183 .45565 L

.67233 .45498 L

.67359 .45347 L

.67484 .45214 L

.67579 .45125 L

.67612 .45095 L

.67736 .44997 L

.67836 .44926 L

.67861 .4491 L

s

.6648 .13785 m

.66442 .143 L

.66455 .14482 L

.66467 .14582 L

.6648 .14661 L

.66505 .14789 L

.66568 .1503 L

.66631 .15218 L

.66693 .15379 L

.66756 .1552 L

.66819 .15649 L

.66944 .15877 L

.67032 .1602 L

.67083 .16097 L

.67183 .16238 L

.67233 .16305 L

.67359 .16457 L

.67484 .16589 L

.67579 .16678 L

.67612 .16709 L

.67736 .16807 L

.67836 .16877 L

.67861 .16893 L

s

1 0 0 r

.67798 .44196 m

.67736 .44247 L

.6761 .44342 L

.67484 .44427 L

.67359 .44504 L

.67233 .44572 L

.67108 .44634 L

.66982 .4469 L

.66857 .44741 L

.66731 .44789 L

.66605 .44833 L

.6648 .44876 L

.66417 .44897 L

.66229 .44956 L

.65978 .45033 L

.65727 .45107 L

.65475 .45178 L

.65224 .45248 L

.64973 .45318 L

.64722 .45386 L

.64471 .45455 L

.6422 .45522 L

.63969 .4559 L

.63718 .45657 L

.63466 .45724 L

.63215 .45791 L

.62964 .45858 L

.62713 .45925 L

.62462 .45991 L

.62211 .46058 L

.6196 .46125 L

.61709 .46192 L

.61457 .46258 L

.61206 .46325 L

.60955 .46392 L

.60704 .46459 L

.60453 .46526 L

.60202 .46593 L

.59951 .4666 L

.597 .46727 L

.59448 .46794 L

.59197 .46861 L

.58946 .46929 L

.58695 .46996 L

.58444 .47063 L

.58193 .47131 L

.57942 .47199 L

.57691 .47266 L

.57439 .47334 L

.57188 .47402 L

Mistroke

.56937 .47469 L

.56686 .47537 L

.56435 .47605 L

.56184 .47673 L

.55933 .47742 L

.55682 .4781 L

.55431 .47878 L

.55179 .47946 L

.54928 .48015 L

.54677 .48083 L

.54426 .48152 L

.54175 .4822 L

.53924 .48289 L

.53673 .48358 L

.53422 .48426 L

.5317 .48495 L

.52919 .48564 L

.52668 .48633 L

.52417 .48702 L

.52166 .48771 L

.51915 .4884 L

.51664 .4891 L

.51413 .48979 L

.51161 .49048 L

.5091 .49117 L

.50659 .49187 L

.50408 .49256 L

.50157 .49326 L

.49906 .49395 L

.49655 .49465 L

.49404 .49534 L

.49152 .49604 L

.48901 .49673 L

.4865 .49743 L

.48399 .49813 L

.48148 .49882 L

.47897 .49952 L

.47646 .50022 L

.47395 .50092 L

.47143 .50161 L

.46892 .50231 L

.46641 .50301 L

.4639 .5037 L

.46139 .5044 L

.45888 .5051 L

.45637 .50579 L

.45386 .50649 L

.45135 .50719 L

.44883 .50788 L

.44632 .50858 L

Mistroke

.44381 .50927 L

.4413 .50997 L

.43879 .51066 L

.43628 .51136 L

.43377 .51205 L

.43126 .51275 L

.42874 .51344 L

.42623 .51413 L

.42372 .51482 L

.42121 .51551 L

.4187 .5162 L

.41619 .51689 L

.41368 .51758 L

.41117 .51826 L

.40865 .51895 L

.40614 .51963 L

.40363 .52031 L

.40112 .52099 L

.39861 .52167 L

.3961 .52235 L

.39359 .52303 L

.39108 .5237 L

.38856 .52438 L

.38605 .52505 L

.38354 .52572 L

.38103 .52639 L

.37852 .52705 L

.37601 .52772 L

.3735 .52838 L

.37099 .52904 L

.36847 .5297 L

.36596 .53035 L

.36345 .531 L

.36094 .53165 L

.35843 .5323 L

.35592 .53294 L

.35341 .53358 L

.3509 .53422 L

.34838 .53485 L

.34587 .53548 L

.34336 .53611 L

.34085 .53673 L

.33834 .53735 L

.33583 .53797 L

.33332 .53858 L

.33081 .53919 L

.3283 .53979 L

.32578 .54039 L

.32327 .54098 L

.32076 .54157 L

Mistroke

.31825 .54215 L

.31574 .54273 L

.31323 .54331 L

.31072 .54387 L

.30821 .54444 L

.30569 .54499 L

.30318 .54554 L

.30067 .54608 L

.29816 .54662 L

.29565 .54715 L

.29314 .54767 L

.29063 .54819 L

.28812 .5487 L

.2856 .5492 L

.28309 .54969 L

.28058 .55017 L

.27807 .55065 L

.27556 .55112 L

.27305 .55157 L

.27054 .55202 L

.26803 .55246 L

.26551 .55289 L

.263 .55331 L

.26049 .55372 L

.25798 .55411 L

.25547 .5545 L

.25296 .55487 L

.25045 .55524 L

.24794 .55559 L

.24542 .55592 L

.24291 .55625 L

.2404 .55656 L

.23789 .55685 L

.23538 .55713 L

.23287 .5574 L

.23036 .55765 L

.22785 .55789 L

.22534 .55811 L

.22282 .55831 L

.22031 .5585 L

.2178 .55866 L

.21529 .55881 L

.21278 .55894 L

.21027 .55905 L

.20776 .55914 L

.20525 .55921 L

.20273 .55925 L

.20022 .55928 L

.19771 .55928 L

.1952 .55926 L

Mistroke

.19269 .55921 L

.19018 .55914 L

.18767 .55904 L

.18516 .55891 L

.18264 .55876 L

.18013 .55857 L

.17762 .55836 L

.17511 .55811 L

.1726 .55784 L

.17009 .55753 L

.16758 .55718 L

.16507 .5568 L

.16255 .55639 L

.16004 .55593 L

.15753 .55544 L

.15502 .55491 L

.15251 .55433 L

.15 .55372 L

.14749 .55305 L

.14498 .55234 L

.14246 .55158 L

.13995 .55077 L

.13744 .54991 L

.13493 .549 L

.13242 .54803 L

.12991 .547 L

.1274 .54591 L

.12489 .54475 L

.12237 .54353 L

.11986 .54225 L

.11735 .54089 L

.11484 .53946 L

.11233 .53795 L

.10982 .53636 L

.10731 .53469 L

.1048 .53293 L

.10229 .53107 L

.09977 .52912 L

.09726 .52707 L

.09475 .52492 L

.09224 .52265 L

.08973 .52026 L

.08722 .51775 L

.08471 .5151 L

.0822 .51232 L

.07968 .50939 L

.07717 .50631 L

.07466 .50306 L

.07215 .49963 L

.06964 .496 L

Mistroke

.06713 .49218 L

.06462 .48813 L

.06211 .48384 L

.05959 .47928 L

.05708 .47444 L

.05457 .46928 L

.05206 .46377 L

.04955 .45785 L

.04704 .45149 L

.04453 .44461 L

.04202 .43711 L

.0395 .42889 L

.03699 .41977 L

.03448 .4095 L

.03197 .39768 L

.02946 .38355 L

.02695 .36541 L

.02632 .35976 L

.02569 .35336 L

.02507 .3458 L

.02444 .33611 L

.02381 .30902 L

Mfstroke

.67798 .17608 m

.67736 .17556 L

.6761 .17461 L

.67484 .17376 L

.67359 .17299 L

.67233 .17231 L

.67108 .17169 L

.66982 .17114 L

.66857 .17063 L

.66731 .17015 L

.66605 .1697 L

.6648 .16927 L

.66417 .16907 L

.66229 .16847 L

.65978 .1677 L

.65727 .16697 L

.65475 .16625 L

.65224 .16555 L

.64973 .16486 L

.64722 .16417 L

.64471 .16349 L

.6422 .16281 L

.63969 .16214 L

.63718 .16146 L

.63466 .16079 L

.63215 .16012 L

.62964 .15946 L

.62713 .15879 L

.62462 .15812 L

.62211 .15745 L

.6196 .15678 L

.61709 .15612 L

.61457 .15545 L

.61206 .15478 L

.60955 .15411 L

.60704 .15344 L

.60453 .15277 L

.60202 .1521 L

.59951 .15143 L

.597 .15076 L

.59448 .15009 L

.59197 .14942 L

.58946 .14875 L

.58695 .14807 L

.58444 .1474 L

.58193 .14672 L

.57942 .14605 L

.57691 .14537 L

.57439 .1447 L

.57188 .14402 L

Mistroke

.56937 .14334 L

.56686 .14266 L

.56435 .14198 L

.56184 .1413 L

.55933 .14062 L

.55682 .13994 L

.55431 .13925 L

.55179 .13857 L

.54928 .13789 L

.54677 .1372 L

.54426 .13652 L

.54175 .13583 L

.53924 .13514 L

.53673 .13446 L

.53422 .13377 L

.5317 .13308 L

.52919 .13239 L

.52668 .1317 L

.52417 .13101 L

.52166 .13032 L

.51915 .12963 L

.51664 .12894 L

.51413 .12825 L

.51161 .12755 L

.5091 .12686 L

.50659 .12617 L

.50408 .12547 L

.50157 .12478 L

.49906 .12408 L

.49655 .12339 L

.49404 .12269 L

.49152 .122 L

.48901 .1213 L

.4865 .1206 L

.48399 .11991 L

.48148 .11921 L

.47897 .11851 L

.47646 .11782 L

.47395 .11712 L

.47143 .11642 L

.46892 .11572 L

.46641 .11503 L

.4639 .11433 L

.46139 .11363 L

.45888 .11294 L

.45637 .11224 L

.45386 .11154 L

.45135 .11085 L

.44883 .11015 L

.44632 .10945 L

Mistroke

.44381 .10876 L

.4413 .10806 L

.43879 .10737 L

.43628 .10668 L

.43377 .10598 L

.43126 .10529 L

.42874 .1046 L

.42623 .1039 L

.42372 .10321 L

.42121 .10252 L

.4187 .10183 L

.41619 .10115 L

.41368 .10046 L

.41117 .09977 L

.40865 .09909 L

.40614 .0984 L

.40363 .09772 L

.40112 .09704 L

.39861 .09636 L

.3961 .09568 L

.39359 .095 L

.39108 .09433 L

.38856 .09366 L

.38605 .09298 L

.38354 .09231 L

.38103 .09165 L

.37852 .09098 L

.37601 .09032 L

.3735 .08965 L

.37099 .08899 L

.36847 .08834 L

.36596 .08768 L

.36345 .08703 L

.36094 .08638 L

.35843 .08573 L

.35592 .08509 L

.35341 .08445 L

.3509 .08381 L

.34838 .08318 L

.34587 .08255 L

.34336 .08192 L

.34085 .0813 L

.33834 .08068 L

.33583 .08006 L

.33332 .07945 L

.33081 .07885 L

.3283 .07824 L

.32578 .07764 L

.32327 .07705 L

.32076 .07646 L

Mistroke

.31825 .07588 L

.31574 .0753 L

.31323 .07473 L

.31072 .07416 L

.30821 .0736 L

.30569 .07304 L

.30318 .07249 L

.30067 .07195 L

.29816 .07141 L

.29565 .07088 L

.29314 .07036 L

.29063 .06984 L

.28812 .06934 L

.2856 .06884 L

.28309 .06834 L

.28058 .06786 L

.27807 .06738 L

.27556 .06692 L

.27305 .06646 L

.27054 .06601 L

.26803 .06557 L

.26551 .06514 L

.263 .06472 L

.26049 .06432 L

.25798 .06392 L

.25547 .06353 L

.25296 .06316 L

.25045 .0628 L

.24794 .06245 L

.24542 .06211 L

.24291 .06179 L

.2404 .06148 L

.23789 .06118 L

.23538 .0609 L

.23287 .06063 L

.23036 .06038 L

.22785 .06014 L

.22534 .05992 L

.22282 .05972 L

.22031 .05954 L

.2178 .05937 L

.21529 .05922 L

.21278 .05909 L

.21027 .05898 L

.20776 .05889 L

.20525 .05883 L

.20273 .05878 L

.20022 .05876 L

.19771 .05876 L

.1952 .05878 L

Mistroke

.19269 .05883 L

.19018 .0589 L

.18767 .059 L

.18516 .05912 L

.18264 .05928 L

.18013 .05946 L

.17762 .05968 L

.17511 .05992 L

.1726 .0602 L

.17009 .06051 L

.16758 .06085 L

.16507 .06123 L

.16255 .06165 L

.16004 .0621 L

.15753 .06259 L

.15502 .06313 L

.15251 .0637 L

.15 .06432 L

.14749 .06498 L

.14498 .06569 L

.14246 .06645 L

.13995 .06726 L

.13744 .06812 L

.13493 .06904 L

.13242 .07001 L

.12991 .07104 L

.1274 .07213 L

.12489 .07328 L

.12237 .0745 L

.11986 .07578 L

.11735 .07714 L

.11484 .07857 L

.11233 .08008 L

.10982 .08167 L

.10731 .08334 L

.1048 .08511 L

.10229 .08696 L

.09977 .08891 L

.09726 .09096 L

.09475 .09312 L

.09224 .09539 L

.08973 .09778 L

.08722 .10029 L

.08471 .10293 L

.0822 .10571 L

.07968 .10864 L

.07717 .11172 L

.07466 .11498 L

.07215 .11841 L

.06964 .12203 L

Mistroke

.06713 .12586 L

.06462 .12991 L

.06211 .1342 L

.05959 .13875 L

.05708 .14359 L

.05457 .14875 L

.05206 .15427 L

.04955 .16018 L

.04704 .16654 L

.04453 .17343 L

.04202 .18092 L

.0395 .18914 L

.03699 .19826 L

.03448 .20853 L

.03197 .22036 L

.02946 .23448 L

.02695 .25263 L

.02632 .25827 L

.02569 .26467 L

.02507 .27224 L

.02444 .28193 L

.02381 .30902 L

Mfstroke

.67736 .44247 m

.67798 .44196 L

.67861 .44143 L

.67924 .44088 L

.67987 .44032 L

.68049 .43975 L

.68112 .43917 L

.68175 .43857 L

.68238 .43798 L

.68301 .43737 L

.68363 .43675 L

.68426 .43615 L

.68489 .43554 L

.68552 .43491 L

.68614 .4343 L

.68677 .43368 L

.6874 .43306 L

.68803 .43244 L

.68866 .43183 L

.68928 .43121 L

.68991 .4306 L

.69054 .42999 L

.69117 .42938 L

.69179 .42876 L

.69242 .42815 L

.69305 .42755 L

.69368 .42694 L

.69431 .42634 L

.69493 .42573 L

.69556 .42513 L

.69619 .42453 L

.69682 .42393 L

.69744 .42334 L

.69807 .42274 L

.6987 .42214 L

.69933 .42155 L

.69996 .42096 L

.70058 .42036 L

.70121 .41977 L

.70184 .41918 L

.70247 .4186 L

.7031 .418 L

.70372 .41742 L

.70435 .41683 L

.70498 .41625 L

.70561 .41566 L

.70623 .41507 L

.70686 .41449 L

.70749 .41391 L

.70812 .41332 L

Mistroke

.70875 .41274 L

.70937 .41216 L

.71 .41157 L

.71063 .41099 L

.71126 .41041 L

.71188 .40982 L

.71251 .40924 L

.71314 .40866 L

.71377 .40808 L

.7144 .40749 L

.71502 .40691 L

.71565 .40633 L

.71628 .40574 L

.71691 .40516 L

.71753 .40457 L

.71816 .40399 L

.71879 .4034 L

.71942 .40282 L

.72005 .40223 L

.72067 .40164 L

.7213 .40105 L

.72193 .40046 L

.72256 .39987 L

.72318 .39928 L

.72381 .39869 L

.72444 .39809 L

.72507 .3975 L

.7257 .3969 L

.72632 .3963 L

.72695 .3957 L

.72758 .3951 L

.72821 .3945 L

.72884 .3939 L

.72946 .39329 L

.73009 .39269 L

.73072 .39208 L

.73135 .39147 L

.73197 .39085 L

.7326 .39024 L

.73323 .38963 L

.73386 .38901 L

.73449 .38839 L

.73511 .38776 L

.73574 .38714 L

.73637 .38651 L

.737 .38588 L

.73762 .38525 L

.73825 .38461 L

.73888 .38398 L

.73951 .38334 L

Mistroke

.74014 .38269 L

.74076 .38205 L

.74139 .3814 L

.74202 .38075 L

.74265 .38009 L

.74327 .37943 L

.7439 .37877 L

.74453 .3781 L

.74516 .37743 L

.74579 .37676 L

.74641 .37608 L

.74704 .3754 L

.74767 .37472 L

.7483 .37403 L

.74892 .37333 L

.74955 .37264 L

.75018 .37193 L

.75081 .37123 L

.75144 .37051 L

.75206 .3698 L

.75269 .36908 L

.75332 .36835 L

.75395 .36761 L

.75458 .36688 L

.7552 .36613 L

.75583 .36538 L

.75646 .36462 L

.75709 .36386 L

.75771 .36309 L

.75834 .36231 L

.75897 .36153 L

.7596 .36074 L

.76023 .35994 L

.76085 .35913 L

.76148 .35832 L

.76211 .3575 L

.76274 .35667 L

.76336 .35583 L

.76399 .35498 L

.76462 .35412 L

.76525 .35325 L

.76588 .35238 L

.7665 .35149 L

.76713 .35059 L

.76776 .34968 L

.76839 .34875 L

.76901 .34782 L

.76964 .34687 L

.77027 .34591 L

.7709 .34493 L

Mistroke

.77153 .34394 L

.77215 .34294 L

.77278 .34191 L

.77341 .34087 L

.77404 .33982 L

.77466 .33874 L

.77529 .33765 L

.77592 .33654 L

.77655 .3354 L

.77718 .33424 L

.7778 .33305 L

.77843 .33185 L

.77906 .33061 L

.77969 .32935 L

.78032 .32805 L

.78094 .32672 L

.78157 .32536 L

.7822 .32396 L

.78283 .32251 L

.78345 .32102 L

.78408 .31949 L

.78471 .3179 L

.78534 .31625 L

.78597 .31454 L

.78659 .31275 L

.78722 .31088 L

.78785 .30892 L

.78848 .30686 L

.7891 .30467 L

.78973 .30234 L

.79036 .29984 L

.79099 .29712 L

.79162 .29412 L

.79224 .29077 L

.79287 .28687 L

.7935 .28211 L

.79413 .27548 L

.79475 .26276 L

.79413 .25003 L

Mfstroke

.67736 .17556 m

.67798 .17608 L

.67861 .17661 L

.67924 .17716 L

.67987 .17771 L

.68049 .17828 L

.68112 .17886 L

.68175 .17946 L

.68238 .18006 L

.68301 .18066 L

.68363 .18128 L

.68426 .18189 L

.68489 .1825 L

.68552 .18312 L

.68614 .18374 L

.68677 .18436 L

.6874 .18497 L

.68803 .18559 L

.68866 .18621 L

.68928 .18682 L

.68991 .18743 L

.69054 .18804 L

.69117 .18866 L

.69179 .18927 L

.69242 .18988 L

.69305 .19049 L

.69368 .19109 L

.69431 .1917 L

.69493 .1923 L

.69556 .1929 L

.69619 .1935 L

.69682 .1941 L

.69744 .1947 L

.69807 .19529 L

.6987 .19589 L

.69933 .19648 L

.69996 .19708 L

.70058 .19767 L

.70121 .19826 L

.70184 .19885 L

.70247 .19944 L

.7031 .20003 L

.70372 .20062 L

.70435 .2012 L

.70498 .20179 L

.70561 .20237 L

.70623 .20296 L

.70686 .20354 L

.70749 .20413 L

.70812 .20471 L

Mistroke

.70875 .2053 L

.70937 .20588 L

.71 .20646 L

.71063 .20704 L

.71126 .20763 L

.71188 .20821 L

.71251 .20879 L

.71314 .20938 L

.71377 .20996 L

.7144 .21054 L

.71502 .21112 L

.71565 .21171 L

.71628 .21229 L

.71691 .21288 L

.71753 .21346 L

.71816 .21405 L

.71879 .21463 L

.71942 .21522 L

.72005 .21581 L

.72067 .21639 L

.7213 .21698 L

.72193 .21757 L

.72256 .21816 L

.72318 .21876 L

.72381 .21935 L

.72444 .21994 L

.72507 .22054 L

.7257 .22114 L

.72632 .22173 L

.72695 .22233 L

.72758 .22293 L

.72821 .22353 L

.72884 .22414 L

.72946 .22474 L

.73009 .22535 L

.73072 .22596 L

.73135 .22657 L

.73197 .22718 L

.7326 .22779 L

.73323 .22841 L

.73386 .22903 L

.73449 .22965 L

.73511 .23027 L

.73574 .2309 L

.73637 .23152 L

.737 .23215 L

.73762 .23279 L

.73825 .23342 L

.73888 .23406 L

.73951 .2347 L

Mistroke

.74014 .23534 L

.74076 .23599 L

.74139 .23664 L

.74202 .23729 L

.74265 .23795 L

.74327 .2386 L

.7439 .23927 L

.74453 .23993 L

.74516 .2406 L

.74579 .24127 L

.74641 .24195 L

.74704 .24263 L

.74767 .24332 L

.7483 .24401 L

.74892 .2447 L

.74955 .2454 L

.75018 .2461 L

.75081 .24681 L

.75144 .24752 L

.75206 .24824 L

.75269 .24896 L

.75332 .24969 L

.75395 .25042 L

.75458 .25116 L

.7552 .2519 L

.75583 .25265 L

.75646 .25341 L

.75709 .25417 L

.75771 .25494 L

.75834 .25572 L

.75897 .2565 L

.7596 .25729 L

.76023 .25809 L

.76085 .2589 L

.76148 .25971 L

.76211 .26054 L

.76274 .26137 L

.76336 .2622 L

.76399 .26305 L

.76462 .26391 L

.76525 .26478 L

.76588 .26566 L

.7665 .26655 L

.76713 .26745 L

.76776 .26836 L

.76839 .26928 L

.76901 .27022 L

.76964 .27116 L

.77027 .27213 L

.7709 .2731 L

Mistroke

.77153 .27409 L

.77215 .2751 L

.77278 .27612 L

.77341 .27716 L

.77404 .27821 L

.77466 .27929 L

.77529 .28039 L

.77592 .2815 L

.77655 .28264 L

.77718 .28379 L

.7778 .28498 L

.77843 .28619 L

.77906 .28742 L

.77969 .28869 L

.78032 .28998 L

.78094 .29131 L

.78157 .29267 L

.7822 .29408 L

.78283 .29552 L

.78345 .29701 L

.78408 .29855 L

.78471 .30014 L

.78534 .30179 L

.78597 .3035 L

.78659 .30528 L

.78722 .30715 L

.78785 .30911 L

.78848 .31118 L

.7891 .31336 L

.78973 .31569 L

.79036 .31819 L

.79099 .32092 L

.79162 .32391 L

.79224 .32726 L

.79287 .33116 L

.7935 .33593 L

.79413 .34255 L

.79475 .35528 L

.79413 .368 L

Mfstroke

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{567, 350.313},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.776525,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008g0001GPP10`40000100000800002008200000

P800P020P<30`<3L`:K:l00003<006H009T00<`00?l0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV

09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<003o03?o06Ko09Wo0<co

0?oo0000<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I

<c>I<fJI<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0

IYT0I/`0I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bI

I_nIIP3<IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0c

VC<cVFHcVITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<

VIW<VLc<VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`c

c?lcc01Vc3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03o

c3?oc6Koc9Woc<coc?ooc000oc<0ofH0oiT0ol`0ool0o`0coc<cofHcoiTcol`coolco`1Voc=VofIV

oiUVolaVoomVo`2Ioc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<o`3ooc?oofKooiWoolco

ooooo`0000410@820P<30`@410D51@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C

4a@D5?okl:2PY820P?l0003o0?oo0000ool0o`3oooooocoQ00<0hN40on7fh@00?n400`3Qh@3ohOKQ

000oh@030>7Q0?oQm^4003oQ00<0hN40on7fh@00?n400`3Qh@3ohOKQ000oh@030>7Q0?oQm^4003oQ

00<0hN40on7fh@00?n400`3Qh@3ohOKQ000oh@<0_^4J3ooQ7^4003oQ00<0hN40^>463a[Q20oohAKQ

000oh@030>7Q0;CQ10lXh@H?on4@h@00?n400`3Qh@2ah@<?<^473ooQ2N4003oQ00<0hN40[^433ccQ

10ooh@GQ000oh@030>7Q0:cQ0Pm3h@D?on4003oQ00<0hN40ZN433d[Q10okh@00?n400`3Qh@2Xh@03

3n7Q04oQ10ogh@00?n400`3Qh@2Uh@<?E^433oCQ000oh@030>7Q0:CQ00<?hN40F^443o3Q000oh@03

0>7Q0:?Q00<?hN40Gn443ncQ000oh@<0XN423fKQ0`oYh@00?n400`3Qh@2Oh@8?Jn443nGQ000oh@03

0>7Q09kQ0Pm`h@8?hn4003oQ00<0hN40WN423g?Q0`oPh@00?n400`3Qh@2Lh@033n7Q07KQ0`oMh@00

?n400`3Qh@2Jh@8?O>423m_Q000oh@030>7Q09[Q00<?hN40ON433mSQ000oh@030>7Q09SQ0Pn3h@8?

e^4003oQ00<0hN40V>400`oQh@24h@<?dn4003oQ00<0hN40U^423h[Q0`o@h@00?n400`3Qh@2Fh@03

3n7Q08cQ00<?hN40cN4003oQ00<0hN40UN400`oQh@2>h@<?c>4003oQ0`0ThAl?DN400`oQh@2Bh@03

3n7Q0<WQ000oh@030>7Q01gQ1`lOh@P?B>423iGQ00<?hN40b>4003oQ00<0hN406N443bkQ1Pm1h@03

3n7Q09KQ0`o7h@00?n400`3Qh@0Fh@<?>>473c[Q00<?hN40VN400`oQh@34h@00?n400`3Qh@0Bh@@?

@^453cCQ00<?hN40Vn400`oQh@33h@00?n400`3Qh@0?h@<?Bn453boQ00<?hN40W>433l;Q000oh@03

0>7Q00kQ00<?hN40DN453bWQ00<?hN40X>400`oQh@2oh@00?n400`3Qh@0;h@<?FN443bCQ00<?hN40

X^423koQ000oh@030>7Q00SQ0`mPh@@?8>400`oQh@2Th@033n7Q0;cQ000oh@030>7Q00OQ00<?hN40

IN453a[Q00<?hN40Y^400`oQh@2kh@00;n4500;Q00<0hN401^400`3Qh@06h@033n7Q06_Q10lEh@03

3n7Q0:SQ00<?hN40^^40037Q00L0hN7Q0>4000OQ00<0hN401N400`oQh@1`h@@?4N400`oQh@2Yh@8?

^^4002_Q0`03h@070>7Qh@3Q0007h@D00`mgh@@?3>400`oQh@2/h@033n7Q0;OQ000ah@070>7Qh@3Q

0007h@050>7Qh@l0O^443`OQ00<?hN40[^400`oQh@2fh@00<N401`3QhN40h@001n40103Q3`n3h@@?

0n400`oQh@2_h@8?]^40033Q0P04h@030>7Q00KQ00<03n40R>443k;Q00<?hN40]>4003oQ00<?hN40

R^400`oQ3`033joQ00<?hN40/n4003gQ0Pl00`3Qh@29h@033n7Q00CQ0`n]h@033n7Q0;;Q000lh@04

3n7Q08_Q00<?hN401n443j[Q0Pnbh@00?>4010oQh@2:h@033n7Q00cQ10nXh@033n7Q0:oQ000kh@05

3n7Qh@00RN400`oQh@0Ah@<?YN400`oQh@2_h@00>^400`oQh@02h@030>7Q08OQ00<?hN405>443j;Q

00<?hN40[^4003WQ00<?hN400n400`3Qh@27h@033n7Q01SQ10nOh@033n7Q0:gQ000hh@033n7Q00CQ

00<0hN40Q^400`oQh@0Mh@@?W>400`oQh@0D:9SQ000gh@033n7Q00GQ0`26h@033n7Q027Q0`nBh@/X

4^4@:8WQ000fh@033n7Q00KQ00<0hN40QN400`oQh@0Uh@<?RN46:0WQ00<?hN408>4;:7oQ000eh@03

3n7Q00OQ00<0hN40QN400`oQh@0Xh@@?PN44:0oQ00<?hN40:n49:7KQ000dh@033n7Q00SQ00<0hN40

QN400`oQh@0/h@@?N^44:1?Q00<?hN40<n49:6gQ000ch@033n7Q00WQ00<0hN40Q>400`oQh@0ah@@?

Ln43:1SQ0Plkh@PXI^4003?Q00<?hN402N400`3Qh@24h@033n7Q03GQ0Pm_h@<X6n400`oQh@11h@LX

Gn4003;Q00<?hN402^400`3Qh@23h@033n7Q03SQ10mYh@<X7^400`oQh@17h@PXEn4003;Q00<?hN40

2^400`3Qh@23h@033n7Q03cQ10mTh@8X8>400`oQh@1>h@PXD>40033Q0Pl=h@030>7Q08?Q00<?hN40

@>443eoQ00<XhN408N400`oQh@1Dh@PXBN4002oQ00<?hN403N400`3Qh@22h@033n7Q04GQ0`mKh@03

:>7Q02?Q00<?hN40Fn47:4;Q000_h@033n7Q00gQ00<0hN40P^400`oQh@18h@@?EN42:2OQ00<?hN40

HN47:3_Q000_h@033n7Q00gQ0`22h@033n7Q04cQ10mAh@03:>7Q02KQ00<?hN40In48:3CQ000^h@03

3n7Q00kQ00<0hN40P^400`oQh@1@h@<?CN400bSQh@0Xh@033n7Q06gQ1BP`h@00;^400`oQh@0>h@03

0>7Q087Q00<?hN40E>443dSQ00<XhN40:N400`oQh@2Rh@00;N400`oQh@0?h@030>7Q087Q00<?hN40

F>433dGQ00<XhN40:^400`oQh@2Qh@00;N400`oQh@0?h@030>7Q083Q00<?hN40G>443d7Q00<XhN40

:^400`oQh@2Qh@00;>400`oQh@0@h@030>7Q083Q00<?hN40H>443ccQ00<XhN40;>400`oQh@2Ph@00

:n400`oQh@0Ah@030>7Q083Q00<?hN40I>443cSQ00<XhN40;N400`oQh@2Oh@00:n400`oQh@0Ah@03

0>7Q083Q00<?hN40J>443cCQ00<XhN40;^400`oQh@2Nh@00:^400`oQh@0Bh@030>7Q07oQ00<?hN40

KN433c7Q00<XhN40;^400`oQh@2Nh@00:^400`oQh@0Bh@030>7Q07oQ00<?hN40L>433bkQ00<XhN40

;n400`oQh@2Mh@00:N400`oQh@0Ch@030>7Q07kQ00<?hN40M>443b[Q00<XhN40;n400`oQh@2Mh@00

:N400`oQh@0Ch@030>7Q07kQ00<?hN40N>443bKQ00<XhN40<>400`oQh@2Lh@00:>400`oQh@0Dh@<0

O^400`oQh@1lh@@?8^400bSQh@0ah@033n7Q09_Q000Xh@033n7Q01CQ00<0hN40O^400`oQh@20h@@?

7n400bSQh@0`h@033n7Q09_Q000Wh@033n7Q01GQ00<0hN40O^400`oQh@24h@@?6n400bSQh@0ah@03

3n7Q09[Q000Wh@033n7Q01GQ00<0hN40ON400`oQh@29h@@?5n42:3;Q00<?hN40V^4002KQ00<?hN40

5^400`3Qh@1mh@033n7Q08gQ0`lEh@03:>7Q037Q00<?hN40VN4002KQ00<?hN405^400`3Qh@1mh@03

3n7Q093Q0`lCh@03:>7Q033Q00<?hN40VN4002KQ00<?hN405^400`3Qh@1lh@033n7Q09CQ10l?h@8X

<N400`oQh@2Ih@009N400`oQh@0Gh@030>7Q07cQ00<?hN40V>443`cQ0RPah@033n7Q09SQ000Uh@03

3n7Q01OQ00<0hN40O>400`oQh@2Lh@@?2N400bSQh@0`h@033n7Q09OQ000Uh@033n7Q01OQ00<0hN40

O>400`oQh@2Ph@8?2>400bSQh@0_h@033n7Q09OQ000Th@033n7Q01SQ00<0hN40O>400`oQh@2Rh@@?

1N42:33Q00<?hN40U^4002CQ00<?hN406>400`3Qh@1lh@033n7Q0:KQ0Pl5h@8X;^400`oQh@2Fh@00

8n400`oQh@0Ih@<0Nn400`oQh@2Yh@8?1N44:2_Q00<?hN40UN4002?Q00<?hN406N400`3Qh@1kh@03

3n7Q0:_Q0Pl6h@DX9n400`oQh@2Eh@008^400`oQh@0Jh@030>7Q07_Q00<?hN40[>423`WQ12PTh@03

3n7Q09GQ000Rh@033n7Q01[Q00<0hN40N^400`oQh@2^h@8?2n45:23Q00<?hN40UN4002;Q00<?hN40

6^400`3Qh@1jh@033n7Q0:oQ0Pl>h@DX7N400`oQh@2Dh@008^400`oQh@0Jh@030>7Q07[Q00<?hN40

/>423a7Q12PJh@033n7Q09CQ000Qh@033n7Q01_Q00<0hN40N^400`oQh@2ah@8?5>45:1GQ00<?hN40

U>40027Q00<?hN406n400`3Qh@1jh@033n7Q0;;Q0PlHh@@X4N400`oQh@2Dh@008N400`oQh@0Kh@03

0>7Q07[Q00<?hN40/n423a_Q12P>h@033n7Q09?Q000Qh@033n7Q01_Q00<0hN40NN400`oQh@2eh@8?

7^44:0[Q00<?hN40Tn40027Q00<?hN404^400`3Qh@06h@030>7Q07WQ00<?hN40]^423b7Q12P6h@03

3n7Q09?Q000Ph@033n7Q01;Q00<0h@001n400`3Qh@1ih@033n7Q0;SQ00<?hN408^44:0?Q00<?hN40

T^40023Q00<?hN403N4300CQ00<0hN401N4507OQ00<?hN40^N400`oQh@0Uh@DXTn40023Q00<?hN40

4^4200SQ00<0hN40N>400`oQh@2jh@8?:^45:8oQ000Ph@033n7Q01;Q00<0hN401n400`3Qh@1hh@03

3n7Q0;_Q0PlYh@043n7Qh@DXRn4001oQ00<?hN404n4300OQ00<0hN40N>400`oQh@2mh@033n7Q02KQ

00<?hN401^45:8KQ000Oh@033n7Q01gQ00<0hN40N>400`oQh@2nh@033n7Q02KQ00<?hN402N45:8;Q

000Nh@033n7Q01kQ00<0hN40N>400`oQh@2oh@033n7Q02GQ00<?hN403N45:7kQ000Nh@033n7Q01kQ

00<0hN40N>400`oQh@30h@8?9N400`oQh@0Bh@DXNN4001kQ00<?hN407^400`3Qh@1hh@033n7Q0<7Q

0PlTh@033n7Q01KQ1BQeh@007^400`oQh@0Nh@030>7Q07SQ00<?hN40`^423bCQ00<?hN406N45:77Q

000Mh@033n7Q01oQ00<0hN40N>400`oQh@33h@8?8n400`oQh@0Nh@DXK>4001gQ00<?hN407n400`3Q

h@1gh@033n7Q0<GQ0PlRh@033n7Q02;Q1BQXh@007N400`oQh@0Oh@<0Mn400`oQh@36h@8?8N400`oQ

h@0Wh@@XI>4001gQ00<?hN407n400`3Qh@1gh@033n7Q0<OQ0PlQh@033n7Q02[Q1BQOh@007N400`oQ

h@0Oh@030>7Q07OQ00<?hN40b>423b3Q00<?hN40;^45:5_Q000Mh@033n7Q01oQ00<0hN40Mn400`oQ

h@39h@8?7n400`oQh@0ch@DXE^4001gQ00<?hN407n400`3Qh@1fh@033n7Q0<_Q0PlNh@033n7Q03SQ

1BQAh@007>400`oQh@0Ph@030>7Q07KQ00<?hN40c>423akQ00<?hN40>n45:4gQ000Lh@033n7Q023Q

00<0hN40M^400`oQh@3=h@8?7N400`oQh@10h@DXB>4001cQ00<?hN408>400`3Qh@1fh@033n7Q0<kQ

0PlLh@033n7Q04CQ1BQ4h@007>400`oQh@0Ph@030>7Q07KQ00<?hN40cn423a_Q00<?hN40BN45:3oQ

000Lh@033n7Q023Q00<0hN40M^400`oQh@3@h@8?6^400`oQh@1=h@DX>n4001cQ00<?hN408>400`3Q

h@1fh@033n7Q0=7Q0PlIh@033n7Q05;Q1BPfh@007>400`oQh@0Ph@030>7Q07KQ00<?hN40d^423aSQ

00<?hN40En45:37Q000Kh@033n7Q027Q0`1fh@033n7Q0=?Q0PlHh@033n7Q05_Q00<XhN40;^4001_Q

00<?hN408N400`3Qh@1fh@033n7Q0=CQ0PlGh@033n7Q08cQ000Kh@033n7Q027Q00<0hN40M^400`oQ

h@3Eh@8?5^400`oQh@2<h@006n400`oQh@0Qh@030>7Q07KQ00<?hN40e^423aGQ00<?hN40S>4001[Q

00<?hN408^400`3Qh@1fh@033n7Q0=OQ0PlDh@033n7Q08cQ000Jh@033n7Q02;Q00<0hN40MN400`oQ

h@3Ih@033n7Q01;Q00<?hN40S>4001[Q00<?hN408^400`3Qh@1eh@033n7Q0=[Q00<?hN404N400`oQ

h@2<h@006^400`oQh@0Rh@030>7Q07GQ00<?hN40f^423a;Q00<?hN40S>4001[Q00<?hN408^400`3Q

h@1eh@033n7Q0=_Q0PlAh@033n7Q08cQ000Jh@033n7Q02;Q00<0hN40MN400`oQh@3Lh@8?4>400`oQ

h@2<h@006^400`oQh@0Rh@030>7Q07GQ00<?hN40gN400`oQh@0>h@033n7Q08cQ000Jh@033n7Q02;Q

00<0hN40MN400`oQh@3Nh@033n7Q00gQ00<?hN40S>4001[Q00<?hN408^4307GQ00<?hN40g^423`kQ

00<?hN40S>4001[Q00<?hN408^400`3Qh@1eh@033n7Q0=oQ0Pl=h@033n7Q08cQ000Ih@033n7Q02?Q

00<0hN40MN400`oQh@3Ph@033n7Q00_Q00<?hN40S>4001WQ00<?hN408n400`3Qh@1eh@033n7Q0>7Q

00<?hN402^400`oQh@2<h@006N400`oQh@0Sh@030>7Q07GQ00<?hN40hN423`_Q00<?hN40S>4001WQ

00<?hN408n400`3Qh@1eh@033n7Q0>;Q00<?hN402N400`oQh@2<h@006N400`oQh@0Sh@030>7Q07GQ

00<?hN40hn400`oQh@08h@033n7Q08cQ000Ih@033n7Q02?Q00<0hN40MN400`oQh@3Sh@8?2N400`oQ

h@2<h@006N400`oQh@0Sh@030>7Q07GQ00<?hN40i>400`oQh@07h@033n7Q08cQ000Ih@033n7Q02?Q

00<0hN40>^4500;Q00<0hN40<N400`oQh@03h@D000?Q0000>N4500;Q00<0hN40=n4500;Q00<0hN40

=n450003h@0001KQ0Pl8h@033n7Q01OQ0`03h@030>7Q03SQ0`000n40000302_Q000Ih@033n7Q02?Q

00<0hN40?>401`3QhN40h@00<^400`oQh@05h@070>7Qh@3Q000jh@030>7Q00;Q00<0hN40>N401`3Q

hN40h@00>^400`3Qh@03h@030>7Q01CQ00<?hN401^400`oQh@0Gh@030>7Q00;Q00<0h@00>N400`3Q

h@03h@030>7Q02_Q000Ih@033n7Q02?Q00<0hN40?>400`3Qh@03h@030>7Q033Q00<?hN401N401`3Q

hN40h@00>^400`3Qh@02h@030>7Q03WQ00L0hN7Q0>4003[Q00<0hN400^4201OQ00<?hN401>400`oQ

h@0Ih@070>7Qh@3Q000jh@030>7Q00;Q00<0hN40:n4001WQ00<?hN408n4303cQ00@0hN7Q0P0ch@03

3n7Q00GQ00@0hN7Q0P0kh@030>7Q00?Q00<0hN40>>400`3Qh@02h@030>7Q03WQ00L0hN7Q0>4001OQ

00<?hN401>400`oQh@0Ih@070>7Qh@3Q000jh@030>7Q00;Q00<0hN40:n4001WQ00<?hN408n400`3Q

h@0lh@050>7Qh@00=>400`oQh@05h@050>7Qh@00?>401`3QhN40h@00>^401`3QhN40h@00>^401`3Q

hN40h@005n423`GQ00<?hN406>400`3Q0002h@030>4003WQ00<0h@000n400`3Qh@0[h@006N400`oQ

h@0Sh@030>7Q03_Q0P03h@<0<^400`oQh@04h@801>4203WQ0P03h@<0>N4200CQ00<0hN40>>4200CQ

0P0Hh@033n7Q00?Q00<?hN406N400`3Qh@02h@030>7Q03WQ00@0hN7Q0P0]h@006N400`oQh@0Sh@03

0>7Q07GQ00<?hN40in400`oQh@03h@033n7Q08gQ000Ih@033n7Q02?Q00<0hN40M>400`oQh@3Yh@03

3n7Q00;Q00<?hN40SN4001WQ00<?hN408n400`3Qh@1dh@033n7Q0>WQ00D?hN7Q3`2@h@006N400`oQ

h@0Sh@030>7Q07CQ00<?hN40j^4010oQh@n@h@006N400`oQh@0Sh@030>7Q07CQ00<?hN40j^4010oQ

h@n@h@006N400`oQh@0Sh@030>7Q07CQ00<?hN40j^4010oQh@n@h@006N400`oQh@0Sh@030>7Q07CQ

00<?hN40jn423ggQ100@h@006N400`oQh@0Sh@030>7Q07CQ00<?hN40jn423ggQ0`0Ah@003>4=0003

3`0009X000<?0000k0000`l0001/017Q00<0hN403n4001SQ00<03n402^400`3Qh@0:h@030>7Q00[Q

00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Qh@0;h@030>7Q00[Q00<0hN402^400`3Q

h@0:h@030>7Q00[Q00<03n402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q

00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Q

h@0:h@030>7Q00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN400^423`KQ00<0hN402^400`3Q

h@0:h@030>7Q00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Qh@0Jh@804N4001SQ

00<03n402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Q

h@0;h@030>7Q00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q00<03n402^400`3Qh@0:h@030>7Q00[Q

00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Q

h@0:h@030>7Q00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q

00<0hN400^423`KQ00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q

00<0hN402^400`3Qh@0]h@006N400`oQh@0Sh@030>7Q03oQ00<0hN40<^400`oQh@09h@030>7Q03kQ

00<0hN40?^400`3Qh@0nh@030>7Q01cQ0PlPh@030>7Q03kQ00<0hN40;N4001WQ00<?hN408n400`3Q

h@0oh@030>7Q03;Q00<?hN402N400`3Qh@0nh@030>7Q03kQ00<0hN40?^400`3Qh@0Kh@043n7Q3aoQ

00<0hN40?^400`3Qh@0]h@006N400`oQh@0Sh@030>7Q07CQ00<?hN40j^4010oQh@n@h@006N400`oQ

h@0Sh@030>7Q07CQ00<?hN40j^4010oQh@n@h@006N400`oQh@0Sh@030>7Q07CQ00<?hN40jN401@oQ

hN4?093Q000Ih@033n7Q02?Q00<0hN40MN400`oQh@3Xh@033n7Q00;Q00<?hN40SN4001WQ00<?hN40

8n400`3Qh@1eh@033n7Q0>OQ00<?hN400n400`oQh@2=h@006N400`oQh@0Sh@030>7Q07GQ00<?hN40

in400`oQh@03h@033n7Q08gQ000Ih@033n7Q02?Q00<0hN40MN400`oQh@3Vh@033n7Q00CQ00<?hN40

SN4001WQ00<?hN408n4307GQ00<?hN40i^400`oQh@04h@033n7Q08gQ000Ih@033n7Q02?Q00<0hN40

MN400`oQh@3Uh@8?1^400`oQh@2=h@006N400`oQh@0Sh@030>7Q07GQ00<?hN40iN400`oQh@06h@03

3n7Q08cQ000Ih@033n7Q02?Q00<0hN40MN400`oQh@3Th@8?2>400`oQh@2<h@006N400`oQh@0Sh@03

0>7Q07GQ00<?hN40i>400`oQh@07h@033n7Q08cQ000Ih@033n7Q02?Q00<0hN40MN400`oQh@3Sh@03

3n7Q00SQ00<?hN40S>4001WQ00<?hN408n400`3Qh@1eh@033n7Q0>;Q0Pl:h@033n7Q08cQ000Ih@03

3n7Q02?Q00<0hN40MN400`oQh@3Rh@033n7Q00WQ00<?hN40S>4001WQ00<?hN408n400`3Qh@1eh@03

3n7Q0>7Q00<?hN402^400`oQh@2<h@006N400`oQh@0Sh@030>7Q07GQ00<?hN40h>423`cQ00<?hN40

S>4001[Q00<?hN408^400`3Qh@1eh@033n7Q0>3Q00<?hN402n400`oQh@2<h@006^400`oQh@0Rh@03

0>7Q07GQ00<?hN40gn400`oQh@0<h@033n7Q08cQ000Jh@033n7Q02;Q0`1eh@033n7Q0=kQ0Pl>h@03

3n7Q08cQ000Jh@033n7Q02;Q00<0hN40MN400`oQh@3Mh@8?3n400`oQh@2<h@006^400`oQh@0Rh@03

0>7Q07GQ00<?hN40gN400`oQh@0>h@033n7Q08cQ000Jh@033n7Q02;Q00<0hN40MN400`oQh@3Lh@03

3n7Q00oQ00<?hN40S>4001[Q00<?hN408^400`3Qh@1eh@033n7Q0=_Q0PlAh@033n7Q08cQ000Jh@03

3n7Q02;Q00<0hN40MN400`oQh@3Jh@8?4^400`oQh@2<h@006^400`oQh@0Rh@030>7Q07GQ00<?hN40

fN423a?Q00<?hN40S>4001[Q00<?hN408^400`3Qh@1eh@033n7Q0=WQ00<?hN404^400`oQh@2<h@00

6^400`oQh@0Rh@030>7Q07KQ00<?hN40en400`oQh@0Ch@033n7Q08cQ000Kh@033n7Q027Q00<0hN40

M^400`oQh@3Fh@8?5N400`oQh@2<h@006n400`oQh@0Qh@030>7Q07KQ00<?hN40eN423aKQ00<?hN40

S>4001_Q00<?hN408N400`3Qh@1fh@033n7Q0=CQ0PlGh@033n7Q08cQ000Kh@033n7Q027Q0`1fh@03

3n7Q0=?Q0PlHh@033n7Q05WQ0bP`h@007>400`oQh@0Ph@030>7Q07KQ00<?hN40d^423aSQ00<?hN40

E^45:3;Q000Lh@033n7Q023Q00<0hN40M^400`oQh@3Ah@8?6N400`oQh@1Ah@DX=n4001cQ00<?hN40

8>400`3Qh@1fh@033n7Q0=3Q0PlJh@033n7Q04cQ1BPlh@007>400`oQh@0Ph@030>7Q07KQ00<?hN40

cn423a_Q00<?hN40B>44:47Q000Lh@033n7Q023Q00<0hN40M^400`oQh@3>h@8?7>400`oQh@13h@DX

AN4001cQ00<?hN408>400`3Qh@1fh@033n7Q0<gQ0PlMh@033n7Q03kQ1BQ:h@007N400`oQh@0Oh@03

0>7Q07KQ00<?hN40c>423akQ00<?hN40>^45:4kQ000Mh@033n7Q01oQ00<0hN40M^400`oQh@3;h@8?

7^400`oQh@0fh@DXDn4001gQ00<?hN407n400`3Qh@1gh@033n7Q0<WQ0PlOh@033n7Q03;Q1BQGh@00

7N400`oQh@0Oh@030>7Q07OQ00<?hN40b>423b3Q00<?hN40;N45:5cQ000Mh@033n7Q01oQ0`1gh@03

3n7Q0<OQ0PlPh@033n7Q02[Q1BQPh@007N400`oQh@0Oh@030>7Q07OQ00<?hN40a^423b7Q00<?hN40

9^45:6CQ000Mh@033n7Q01oQ00<0hN40Mn400`oQh@35h@8?8^400`oQh@0Qh@DXJN4001kQ00<?hN40

7^400`3Qh@1hh@033n7Q0<?Q0PlSh@033n7Q01gQ1BQ]h@007^400`oQh@0Nh@030>7Q07SQ00<?hN40

`^400`oQh@0Rh@033n7Q01WQ1BQbh@007^400`oQh@0Nh@030>7Q07SQ00<?hN40`N400`oQh@0Sh@03

3n7Q01GQ12Qgh@007^400`oQh@0Nh@030>7Q07SQ00<?hN40`>400`oQh@0Th@033n7Q017Q1BQjh@00

7n400`oQh@0Mh@030>7Q07SQ00<?hN40_^423bOQ00<?hN403>45:7oQ000Oh@033n7Q01gQ00<0hN40

N>400`oQh@2mh@8?:>400`oQh@08h@@XQ>4001oQ00<?hN407N400`3Qh@1hh@033n7Q0;cQ0PlXh@03

3n7Q00GQ12R8h@008>400`oQh@0Ch@030>7Q00KQ00<0hN40N>400`oQh@2kh@8?:N4010oQhN44:8cQ

000Ph@033n7Q01;Q00<0h@001n400`3Qh@1hh@033n7Q0;[Q0PlYh@DXT>40023Q00<?hN405>400`3Q

h@05h@D0Mn400`oQh@2hh@8?9^44:0033n7Q09;Q000Ph@033n7Q01;Q0P08h@030>7Q07WQ00<?hN40

]n423b?Q1BP3h@033n7Q09;Q000Qh@033n7Q017Q00<0hN401n400`3Qh@1ih@033n7Q0;KQ0PlPh@@X

1n400`oQh@2Ch@008N400`oQh@0Ah@<01n400`3Qh@1jh@033n7Q0;CQ0PlLh@DX2n400`oQh@2Ch@00

8N400`oQh@0Kh@030>7Q07[Q00<?hN40/n423aWQ1BP?h@033n7Q09?Q000Qh@033n7Q01_Q00<0hN40

N^400`oQh@2bh@8?5^45:1;Q00<?hN40U>4002;Q00<?hN406^400`3Qh@1jh@033n7Q0;7Q0PlCh@DX

5^400`oQh@2Dh@008^400`oQh@0Jh@030>7Q07[Q00<?hN40/>423a7Q12PJh@033n7Q09CQ000Rh@03

3n7Q01[Q00<0hN40N^400`oQh@2_h@8?3^44:1kQ00<?hN40U>4002;Q00<?hN406^400`3Qh@1jh@03

3n7Q0:kQ0Pl;h@@X8N400`oQh@2Eh@008^400`oQh@0Jh@030>7Q07_Q00<?hN40[>400`oQh@07h@@X

9N400`oQh@2Eh@008n400`oQh@0Ih@030>7Q07_Q00<?hN40Z^423`OQ0bPYh@033n7Q09GQ000Sh@03

3n7Q01WQ0`1kh@033n7Q0:WQ0Pl4h@@X:n400`oQh@2Fh@009>400`oQh@0Hh@030>7Q07cQ00<?hN40

YN433`CQ0bP^h@033n7Q09KQ000Th@033n7Q01SQ00<0hN40O>400`oQh@2Sh@<?1>43:2oQ00<?hN40

Un4002GQ00<?hN405n400`3Qh@1lh@033n7Q09oQ10l7h@03:>7Q02oQ00<?hN40Un4002GQ00<?hN40

5n400`3Qh@1lh@033n7Q09_Q10l:h@03:>7Q02oQ00<?hN40V>4002GQ00<?hN405n400`3Qh@1lh@03

3n7Q09OQ10l=h@03:>7Q033Q00<?hN40V>4002KQ00<?hN405^400`3Qh@1lh@033n7Q09CQ0`l@h@03

:>7Q033Q00<?hN40VN4002KQ00<?hN405^400`3Qh@1mh@033n7Q08oQ10lBh@03:>7Q037Q00<?hN40

VN4002KQ00<?hN405^400`3Qh@1mh@033n7Q08cQ0`lFh@03:>7Q037Q00<?hN40VN4002OQ00<?hN40

5N400`3Qh@1nh@033n7Q08OQ10lHh@03:>7Q037Q00<?hN40V^4002OQ00<?hN405N400`3Qh@1nh@03

3n7Q08?Q10lLh@03:>7Q037Q00<?hN40V^4002SQ00<?hN405>400`3Qh@1nh@033n7Q07oQ10lPh@03

:>7Q033Q00<?hN40Vn4002WQ00<?hN404n4307kQ00<?hN40Nn443b?Q00<XhN40<>400`oQh@2Lh@00

:N400`oQh@0Ch@030>7Q07kQ00<?hN40Mn443bOQ00<XhN40<>400`oQh@2Lh@00:^400`oQh@0Bh@03

0>7Q07oQ00<?hN40Ln433b_Q00<XhN40;n400`oQh@2Mh@00:^400`oQh@0Bh@030>7Q07oQ00<?hN40

Kn443bkQ00<XhN40;n400`oQh@2Mh@00:^400`oQh@0Bh@030>7Q07oQ00<?hN40K>433c;Q00<XhN40

;^400`oQh@2Nh@00:n400`oQh@0Ah@030>7Q083Q00<?hN40In443cGQ00<XhN40;^400`oQh@2Nh@00

:n400`oQh@0Ah@030>7Q083Q00<?hN40Hn443cWQ00<XhN40;N400`oQh@2Oh@00;>400`oQh@0@h@03

0>7Q083Q00<?hN40Gn443cgQ00<XhN40;>400`oQh@2Ph@00;N400`oQh@0?h@030>7Q083Q00<?hN40

G>433d;Q00<XhN40:^400`oQh@2Qh@00;N400`oQh@0?h@030>7Q087Q00<?hN40En443dGQ00<XhN40

:^400`oQh@2Qh@00;^400`oQh@0>h@030>7Q087Q00<?hN40Dn443dWQ00<XhN40:N400`oQh@2Rh@00

;^400`oQh@0>h@<0P^400`oQh@1?h@<?C^400bSQh@0Xh@033n7Q06_Q1bP`h@00;n400`oQh@0=h@03

0>7Q08;Q00<?hN40C>433e;Q00<XhN409^400`oQh@1Vh@LX=^4002oQ00<?hN403N400`3Qh@22h@03

3n7Q04SQ10mFh@03:>7Q02GQ00<?hN40Gn47:3gQ000`h@033n7Q00cQ00<0hN40P^400`oQh@14h@@?

Fn400bSQh@0Sh@033n7Q05WQ1bQ4h@00<N400`oQh@0;h@030>7Q08?Q00<?hN40?n443f3Q00<XhN40

8N400`oQh@1Ch@LXBn4003;Q00<?hN402^400`3Qh@23h@033n7Q03_Q10mUh@8X8>400`oQh@1<h@PX

D^4003;Q00<?hN402^400`3Qh@23h@033n7Q03WQ0Pm[h@8X7^400`oQh@15h@PXFN4003?Q00<?hN40

2N400`3Qh@24h@033n7Q03CQ10m_h@8X6n400`oQh@0nh@TXH>4003?Q00<?hN402N400`3Qh@24h@03

3n7Q033Q10meh@<X5n400`oQh@0hh@PXJ>4003CQ00<?hN402>400`3Qh@25h@033n7Q02_Q10mlh@@X

4^400`oQh@0ah@PXL>4003GQ0Pl8h@030>7Q08GQ00<?hN40:>433h?Q1BP=h@033n7Q02SQ2RQhh@00

=^400`oQh@06h@030>7Q08GQ00<?hN409>443h[Q1bP7h@033n7Q01gQ2bR2h@00=n400`oQh@05h@<0

Q^400`oQh@0Ph@<?UN4W:8gQ000hh@033n7Q00CQ00<0hN40Qn400`oQh@0Kh@@?WN400`oQh@2/h@00

>N400`oQh@03h@030>7Q08OQ00<?hN405n443j3Q00<?hN40[N4003[Q00<?hN400^400`3Qh@27h@03

3n7Q01CQ0`nSh@033n7Q0:kQ000kh@053n7Qh@00R^400`oQh@0?h@@?YN400`oQh@2_h@00?>4010oQ

h@2:h@033n7Q00_Q10nXh@033n7Q0;3Q000mh@033n4008_Q00<?hN401^443jcQ00<?hN40/>4003kQ

0Pn;h@033n7Q00?Q0`n^h@8?/n4003oQ00<03n40R^453k3Q00<?hN40/n4003oQ00<0h@l0Qn453k;Q

00<?hN40]>4002oQ1@02h@030>7Q00KQ00<0hN400Pn1h@@?1>400`oQh@2^h@8?]n40037Q00L0hN7Q

0>4000OQ00<0hN400^400`oQh@1jh@@?2>400`oQh@2]h@033n7Q0;OQ000ah@070>7Qh@3Q0007h@D0

00?Q3n40M^443`gQ00<?hN40[>400`oQh@2gh@00<N401`3QhN40h@001n400`3Qh@04h@8?LN443a;Q

00<?hN40Z^400`oQh@2hh@00<N401`3QhN40h@001n400`3Qh@06h@033n7Q06[Q10lFh@033n7Q0:SQ

0Pnkh@00<>4200CQ00<0hN401^400`3Qh@07h@8?I^443a_Q00<?hN40Y^400`oQh@2kh@00?n400`3Q

h@09h@8?Gn453b3Q00<?hN40Xn423kkQ000oh@030>7Q00_Q0PmIh@@?9N400`oQh@2Qh@8?`>4003oQ

00<0hN403N433e7Q1@lZh@033n7Q09oQ00<?hN40`>4003oQ00<0hN404>433dWQ1@l`h@033n7Q09gQ

00<?hN40`N4003oQ00<0hN404n443d3Q1@leh@033n7Q09_Q0Po4h@00?n400`3Qh@0Gh@8?=n473c_Q

00<?hN40V>423lKQ000oh@030>7Q01WQ1@l/h@H?@^423iOQ0Po8h@00?n400`3Qh@0Nh@P?6N4;3d[Q

00<?hN40Tn400`oQh@38h@00?n4302KQ6@mEh@033n7Q097Q0Po;h@00?n400`3Qh@2Eh@033n7Q08kQ

0Po=h@00?n400`3Qh@2Fh@033n7Q08_Q0Po?h@00?n400`3Qh@2Gh@033n7Q08OQ0`oAh@00?n400`3Q

h@2Hh@033n7Q08GQ00<?hN40d^4003oQ00<0hN40VN400`oQh@21h@<?eN4003oQ00<0hN40V^400`oQ

h@1mh@<?f>4003oQ00<0hN40Vn423g_Q0PoKh@00?n400`3Qh@2Lh@033n7Q07KQ0`oMh@00?n400`3Q

h@2Mh@8?L^443n3Q000oh@030>7Q09kQ0Pm_h@8?i>4003oQ0`2Oh@8?Jn433nKQ000oh@030>7Q0:7Q

00<?hN40I>443nWQ000oh@030>7Q0:;Q0PmPh@@?kN4003oQ00<0hN40Y>423ecQ0Poah@00?n400`3Q

h@2Vh@8?E^443o?Q000oh@030>7Q0:SQ00<?hN40C^453oOQ000oh@030>7Q0:WQ0`m9h@@?o>4003oQ

00<0hN40[>423d;Q1@ooh@7Q000oh@030>7Q0:kQ0`lih@H?on46h@00?n400`3Qh@2ah@@?<>453ooQ

3>4003oQ00<0hN40]N453bGQ1PoohA7Q000oh@030>7Q0;[Q1PlDh@/?on4Gh@00?n430<3Q50oohB;Q

000oh@030>7Q0?oQm^4003oQ00<0hN40on7fh@00?n400`3Qh@3ohOKQ000oh@030>7Q0?oQm^4003oQ

00<0hN40on7fh@00?n400`3Qh@3ohOKQ000oh@030>7Q0?oQm^4003oQ00<0hN40on7fh@00on7ohCWQ

003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQ

on4ih@00on7ohCWQ003ohOoQ>N400?kQ0P001>400>440003h@0000?Q0P04h@040>7Qh@801>400`3Q

h@3ohAOQ003oh@030>4000WQ00<0hN400^400`3Qh@05h@030>4000;Q00<0h@00on4Hh@00on4300;Q

1002h@030>7Q00;Q0P07h@030>4000CQ00<0hN40on4Fh@00on40103Q0008h@060>7Q0>401n4200?Q

0P3ohAWQ000mh@80`>400`3Qh@07h@030>4000;Q00<0h@001n400`3Qh@02h@030>7Q0?oQ6>4003kQ

00<0hN40_N4200[Q00<0hN400^4200SQ0P02h@<0on4Hh@00?>4300;Q00<0hN40on7dh@00>n40203Q

h@3Q0>40on7eh@00>n40203Qh@3Q0>40on7eh@00?>430004h@3Q0?oQmN40043Q00<0h@00on7eh@00

@N400`3Qh@3ohOCQ003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQon4ih@00\

\>"],

  ImageRangeCache->{{{0, 566}, {349.313, 0}} -> {13.018, -13.6377, 0.0153649, 

  0.0851411}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-1.65768 0.125422 0.309017 0.022637 [

[.22366 .29652 -6 -9 ]

[.22366 .29652 6 0 ]

[.34908 .29652 -6 -9 ]

[.34908 .29652 6 0 ]

[.4745 .29652 -6 -9 ]

[.4745 .29652 6 0 ]

[.59992 .29652 -6 -9 ]

[.59992 .29652 6 0 ]

[.72535 .29652 -6 -9 ]

[.72535 .29652 6 0 ]

[.85077 .29652 -6 -9 ]

[.85077 .29652 6 0 ]

[.97619 .29652 -6 -9 ]

[.97619 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.08574 .08265 -18 -4.5 ]

[.08574 .08265 0 4.5 ]

[.08574 .19583 -12 -4.5 ]

[.08574 .19583 0 4.5 ]

[.08574 .4222 -6 -4.5 ]

[.08574 .4222 0 4.5 ]

[.08574 .53539 -12 -4.5 ]

[.08574 .53539 0 4.5 ]

[.09824 .64303 -7 0 ]

[.09824 .64303 7 16 ]

[.5 .63053 -27 0 ]

[.5 .63053 27 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.22366 .30902 m

.22366 .31527 L

s

[(15)] .22366 .29652 0 1 Mshowa

.34908 .30902 m

.34908 .31527 L

s

[(16)] .34908 .29652 0 1 Mshowa

.4745 .30902 m

.4745 .31527 L

s

[(17)] .4745 .29652 0 1 Mshowa

.59992 .30902 m

.59992 .31527 L

s

[(18)] .59992 .29652 0 1 Mshowa

.72535 .30902 m

.72535 .31527 L

s

[(19)] .72535 .29652 0 1 Mshowa

.85077 .30902 m

.85077 .31527 L

s

[(20)] .85077 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(21)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.12332 .30902 m

.12332 .31277 L

s

.1484 .30902 m

.1484 .31277 L

s

.17349 .30902 m

.17349 .31277 L

s

.19857 .30902 m

.19857 .31277 L

s

.24874 .30902 m

.24874 .31277 L

s

.27383 .30902 m

.27383 .31277 L

s

.29891 .30902 m

.29891 .31277 L

s

.324 .30902 m

.324 .31277 L

s

.37416 .30902 m

.37416 .31277 L

s

.39925 .30902 m

.39925 .31277 L

s

.42433 .30902 m

.42433 .31277 L

s

.44942 .30902 m

.44942 .31277 L

s

.49959 .30902 m

.49959 .31277 L

s

.52467 .30902 m

.52467 .31277 L

s

.54975 .30902 m

.54975 .31277 L

s

.57484 .30902 m

.57484 .31277 L

s

.62501 .30902 m

.62501 .31277 L

s

.65009 .30902 m

.65009 .31277 L

s

.67518 .30902 m

.67518 .31277 L

s

.70026 .30902 m

.70026 .31277 L

s

.75043 .30902 m

.75043 .31277 L

s

.77551 .30902 m

.77551 .31277 L

s

.8006 .30902 m

.8006 .31277 L

s

.82568 .30902 m

.82568 .31277 L

s

.87585 .30902 m

.87585 .31277 L

s

.90094 .30902 m

.90094 .31277 L

s

.92602 .30902 m

.92602 .31277 L

s

.95111 .30902 m

.95111 .31277 L

s

.07315 .30902 m

.07315 .31277 L

s

.04807 .30902 m

.04807 .31277 L

s

.02298 .30902 m

.02298 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.09824 .08265 m

.10449 .08265 L

s

[(-10)] .08574 .08265 1 0 Mshowa

.09824 .19583 m

.10449 .19583 L

s

[(-5)] .08574 .19583 1 0 Mshowa

.09824 .4222 m

.10449 .4222 L

s

[(5)] .08574 .4222 1 0 Mshowa

.09824 .53539 m

.10449 .53539 L

s

[(10)] .08574 .53539 1 0 Mshowa

.125 Mabswid

.09824 .10528 m

.10199 .10528 L

s

.09824 .12792 m

.10199 .12792 L

s

.09824 .15056 m

.10199 .15056 L

s

.09824 .17319 m

.10199 .17319 L

s

.09824 .21847 m

.10199 .21847 L

s

.09824 .24111 m

.10199 .24111 L

s

.09824 .26374 m

.10199 .26374 L

s

.09824 .28638 m

.10199 .28638 L

s

.09824 .33165 m

.10199 .33165 L

s

.09824 .35429 m

.10199 .35429 L

s

.09824 .37693 m

.10199 .37693 L

s

.09824 .39957 m

.10199 .39957 L

s

.09824 .44484 m

.10199 .44484 L

s

.09824 .46748 m

.10199 .46748 L

s

.09824 .49011 m

.10199 .49011 L

s

.09824 .51275 m

.10199 .51275 L

s

.09824 .06001 m

.10199 .06001 L

s

.09824 .03737 m

.10199 .03737 L

s

.09824 .01474 m

.10199 .01474 L

s

.09824 .55802 m

.10199 .55802 L

s

.09824 .58066 m

.10199 .58066 L

s

.09824 .6033 m

.10199 .6033 L

s

.25 Mabswid

.09824 0 m

.09824 .61803 L

s

gsave

.09824 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(k) show

78.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

88.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(39.7) show

113.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

1 0 0 r

.5 Mabswid

.70026 .50635 m

.69901 .506 L

.69775 .50562 L

.6965 .50524 L

.69524 .50484 L

.69399 .50441 L

.69274 .50397 L

.69148 .50351 L

.69023 .50303 L

.68897 .50252 L

.68772 .50199 L

.68647 .50143 L

.68396 .50022 L

.68145 .49888 L

.67894 .49737 L

.67643 .49566 L

.67392 .49368 L

.67141 .49133 L

.66891 .48842 L

.6674 .48623 L

.6664 .48446 L

.66489 .48094 L

.66389 .47699 L

.66383 .47662 L

.66376 .47621 L

.6637 .47575 L

.66364 .47519 L

.66358 .47453 L

s

.70026 .11169 m

.69901 .11204 L

.69775 .11241 L

.6965 .1128 L

.69524 .1132 L

.69399 .11362 L

.69274 .11406 L

.69148 .11452 L

.69023 .11501 L

.68897 .11552 L

.68772 .11605 L

.68647 .11661 L

.68396 .11781 L

.68145 .11916 L

.67894 .12066 L

.67643 .12237 L

.67392 .12435 L

.67141 .1267 L

.66891 .12961 L

.6674 .1318 L

.6664 .13357 L

.66489 .13709 L

.66389 .14105 L

.66383 .14141 L

.66376 .14183 L

.6637 .14228 L

.66364 .14285 L

.66358 .1435 L

s

.66314 .45604 m

.66326 .45616 L

.66339 .45628 L

.66351 .45643 L

.66364 .45659 L

.66376 .45678 L

.66389 .457 L

.66395 .45713 L

s

.66314 .162 m

.66326 .16188 L

.66339 .16175 L

.66351 .1616 L

.66364 .16144 L

.66376 .16125 L

.66389 .16103 L

.66395 .1609 L

s

.66188 .45531 m

.66063 .45497 L

.65937 .45482 L

.65762 .45477 L

.65511 .45491 L

.6526 .45519 L

.65009 .45555 L

.64758 .45597 L

.64508 .45644 L

.64257 .45693 L

.64006 .45745 L

.63755 .45799 L

.63504 .45854 L

.63253 .45911 L

.63003 .45968 L

.62752 .46027 L

.62501 .46086 L

.6225 .46146 L

.61999 .46207 L

.61748 .46268 L

.61497 .46329 L

.61247 .46391 L

.60996 .46454 L

.60745 .46516 L

.60494 .46579 L

.60243 .46643 L

.59992 .46707 L

.59742 .46771 L

.59491 .46835 L

.5924 .46899 L

.58989 .46964 L

.58738 .47029 L

.58487 .47094 L

.58236 .47159 L

.57986 .47225 L

.57735 .4729 L

.57484 .47356 L

.57233 .47422 L

.56982 .47488 L

.56731 .47554 L

.56481 .47621 L

.5623 .47687 L

.55979 .47754 L

.55728 .47821 L

.55477 .47888 L

.55226 .47955 L

.54975 .48022 L

.54725 .48089 L

.54474 .48157 L

.54223 .48224 L

Mistroke

.53972 .48292 L

.53721 .48359 L

.5347 .48427 L

.5322 .48495 L

.52969 .48563 L

.52718 .48631 L

.52467 .48699 L

.52216 .48767 L

.51965 .48836 L

.51715 .48904 L

.51464 .48973 L

.51213 .49041 L

.50962 .4911 L

.50711 .49178 L

.5046 .49247 L

.50209 .49316 L

.49959 .49385 L

.49708 .49453 L

.49457 .49522 L

.49206 .49591 L

.48955 .4966 L

.48704 .49729 L

.48454 .49798 L

.48203 .49868 L

.47952 .49937 L

.47701 .50006 L

.4745 .50075 L

.47199 .50144 L

.46948 .50214 L

.46698 .50283 L

.46447 .50352 L

.46196 .50421 L

.45945 .50491 L

.45694 .5056 L

.45443 .50629 L

.45193 .50698 L

.44942 .50767 L

.44691 .50837 L

.4444 .50906 L

.44189 .50975 L

.43938 .51044 L

.43688 .51113 L

.43437 .51182 L

.43186 .51251 L

.42935 .5132 L

.42684 .51389 L

.42433 .51457 L

.42182 .51526 L

.41932 .51595 L

.41681 .51663 L

Mistroke

.4143 .51732 L

.41179 .518 L

.40928 .51868 L

.40677 .51936 L

.40427 .52004 L

.40176 .52072 L

.39925 .5214 L

.39674 .52208 L

.39423 .52275 L

.39172 .52342 L

.38921 .5241 L

.38671 .52476 L

.3842 .52543 L

.38169 .5261 L

.37918 .52676 L

.37667 .52743 L

.37416 .52808 L

.37166 .52874 L

.36915 .5294 L

.36664 .53005 L

.36413 .5307 L

.36162 .53135 L

.35911 .53199 L

.3566 .53264 L

.3541 .53327 L

.35159 .53391 L

.34908 .53454 L

.34657 .53517 L

.34406 .5358 L

.34155 .53642 L

.33905 .53704 L

.33654 .53765 L

.33403 .53826 L

.33152 .53887 L

.32901 .53947 L

.3265 .54007 L

.324 .54066 L

.32149 .54125 L

.31898 .54184 L

.31647 .54241 L

.31396 .54299 L

.31145 .54355 L

.30894 .54412 L

.30644 .54467 L

.30393 .54522 L

.30142 .54577 L

.29891 .5463 L

.2964 .54683 L

.29389 .54736 L

.29139 .54787 L

Mistroke

.28888 .54838 L

.28637 .54888 L

.28386 .54938 L

.28135 .54986 L

.27884 .55034 L

.27633 .55081 L

.27383 .55127 L

.27132 .55172 L

.26881 .55216 L

.2663 .55259 L

.26379 .55301 L

.26128 .55342 L

.25878 .55382 L

.25627 .55421 L

.25376 .55459 L

.25125 .55495 L

.24874 .5553 L

.24623 .55564 L

.24372 .55597 L

.24122 .55628 L

.23871 .55658 L

.2362 .55687 L

.23369 .55714 L

.23118 .5574 L

.22867 .55764 L

.22617 .55786 L

.22366 .55807 L

.22115 .55826 L

.21864 .55843 L

.21613 .55859 L

.21362 .55872 L

.21112 .55884 L

.20861 .55893 L

.2061 .55901 L

.20359 .55906 L

.20108 .55909 L

.19857 .5591 L

.19606 .55908 L

.19356 .55905 L

.19105 .55898 L

.18854 .55889 L

.18603 .55877 L

.18352 .55863 L

.18101 .55845 L

.17851 .55825 L

.176 .55802 L

.17349 .55775 L

.17098 .55745 L

.16847 .55712 L

.16596 .55676 L

Mistroke

.16345 .55635 L

.16095 .55591 L

.15844 .55543 L

.15593 .55492 L

.15342 .55436 L

.15091 .55376 L

.1484 .55311 L

.1459 .55241 L

.14339 .55167 L

.14088 .55088 L

.13837 .55004 L

.13586 .54915 L

.13335 .5482 L

.13084 .54719 L

.12834 .54612 L

.12583 .545 L

.12332 .5438 L

.12081 .54254 L

.1183 .54121 L

.11579 .53981 L

.11329 .53833 L

.11078 .53677 L

.10827 .53513 L

.10576 .53341 L

.10325 .53159 L

.10074 .52968 L

.09824 .52766 L

.09573 .52555 L

.09322 .52332 L

.09071 .52098 L

.0882 .51852 L

.08569 .51593 L

.08318 .5132 L

.08068 .51033 L

.07817 .50731 L

.07566 .50412 L

.07315 .50076 L

.07064 .49722 L

.06813 .49347 L

.06563 .48951 L

.06312 .48531 L

.06061 .48087 L

.0581 .47614 L

.05559 .47111 L

.05308 .46573 L

.05057 .45998 L

.04807 .4538 L

.04556 .44712 L

.04305 .43988 L

.04054 .43195 L

Mistroke

.03803 .4232 L

.03552 .41341 L

.03302 .40224 L

.03051 .38911 L

.028 .37282 L

.02549 .34971 L

.02465 .32936 L

.02381 .30902 L

Mfstroke

.66188 .16272 m

.66063 .16306 L

.65937 .16321 L

.65762 .16326 L

.65511 .16312 L

.6526 .16284 L

.65009 .16248 L

.64758 .16206 L

.64508 .1616 L

.64257 .1611 L

.64006 .16058 L

.63755 .16005 L

.63504 .15949 L

.63253 .15893 L

.63003 .15835 L

.62752 .15777 L

.62501 .15717 L

.6225 .15657 L

.61999 .15597 L

.61748 .15536 L

.61497 .15474 L

.61247 .15412 L

.60996 .1535 L

.60745 .15287 L

.60494 .15224 L

.60243 .1516 L

.59992 .15097 L

.59742 .15033 L

.59491 .14969 L

.5924 .14904 L

.58989 .14839 L

.58738 .14775 L

.58487 .1471 L

.58236 .14644 L

.57986 .14579 L

.57735 .14513 L

.57484 .14447 L

.57233 .14381 L

.56982 .14315 L

.56731 .14249 L

.56481 .14183 L

.5623 .14116 L

.55979 .14049 L

.55728 .13983 L

.55477 .13916 L

.55226 .13849 L

.54975 .13782 L

.54725 .13714 L

.54474 .13647 L

.54223 .13579 L

Mistroke

.53972 .13512 L

.53721 .13444 L

.5347 .13376 L

.5322 .13308 L

.52969 .1324 L

.52718 .13172 L

.52467 .13104 L

.52216 .13036 L

.51965 .12968 L

.51715 .12899 L

.51464 .12831 L

.51213 .12762 L

.50962 .12694 L

.50711 .12625 L

.5046 .12556 L

.50209 .12488 L

.49959 .12419 L

.49708 .1235 L

.49457 .12281 L

.49206 .12212 L

.48955 .12143 L

.48704 .12074 L

.48454 .12005 L

.48203 .11936 L

.47952 .11867 L

.47701 .11797 L

.4745 .11728 L

.47199 .11659 L

.46948 .1159 L

.46698 .11521 L

.46447 .11451 L

.46196 .11382 L

.45945 .11313 L

.45694 .11244 L

.45443 .11174 L

.45193 .11105 L

.44942 .11036 L

.44691 .10967 L

.4444 .10898 L

.44189 .10828 L

.43938 .10759 L

.43688 .1069 L

.43437 .10621 L

.43186 .10552 L

.42935 .10483 L

.42684 .10415 L

.42433 .10346 L

.42182 .10277 L

.41932 .10209 L

.41681 .1014 L

Mistroke

.4143 .10072 L

.41179 .10003 L

.40928 .09935 L

.40677 .09867 L

.40427 .09799 L

.40176 .09731 L

.39925 .09663 L

.39674 .09596 L

.39423 .09528 L

.39172 .09461 L

.38921 .09394 L

.38671 .09327 L

.3842 .0926 L

.38169 .09194 L

.37918 .09127 L

.37667 .09061 L

.37416 .08995 L

.37166 .08929 L

.36915 .08864 L

.36664 .08798 L

.36413 .08733 L

.36162 .08669 L

.35911 .08604 L

.3566 .0854 L

.3541 .08476 L

.35159 .08412 L

.34908 .08349 L

.34657 .08286 L

.34406 .08223 L

.34155 .08161 L

.33905 .08099 L

.33654 .08038 L

.33403 .07977 L

.33152 .07916 L

.32901 .07856 L

.3265 .07796 L

.324 .07737 L

.32149 .07678 L

.31898 .0762 L

.31647 .07562 L

.31396 .07505 L

.31145 .07448 L

.30894 .07392 L

.30644 .07336 L

.30393 .07281 L

.30142 .07227 L

.29891 .07173 L

.2964 .0712 L

.29389 .07068 L

.29139 .07016 L

Mistroke

.28888 .06965 L

.28637 .06915 L

.28386 .06866 L

.28135 .06817 L

.27884 .06769 L

.27633 .06723 L

.27383 .06677 L

.27132 .06632 L

.26881 .06588 L

.2663 .06544 L

.26379 .06502 L

.26128 .06461 L

.25878 .06422 L

.25627 .06383 L

.25376 .06345 L

.25125 .06308 L

.24874 .06273 L

.24623 .06239 L

.24372 .06206 L

.24122 .06175 L

.23871 .06145 L

.2362 .06116 L

.23369 .06089 L

.23118 .06064 L

.22867 .0604 L

.22617 .06017 L

.22366 .05997 L

.22115 .05978 L

.21864 .0596 L

.21613 .05945 L

.21362 .05931 L

.21112 .0592 L

.20861 .0591 L

.2061 .05903 L

.20359 .05898 L

.20108 .05894 L

.19857 .05893 L

.19606 .05895 L

.19356 .05899 L

.19105 .05905 L

.18854 .05914 L

.18603 .05926 L

.18352 .05941 L

.18101 .05958 L

.17851 .05978 L

.176 .06002 L

.17349 .06028 L

.17098 .06058 L

.16847 .06091 L

.16596 .06128 L

Mistroke

.16345 .06168 L

.16095 .06212 L

.15844 .0626 L

.15593 .06312 L

.15342 .06368 L

.15091 .06428 L

.1484 .06493 L

.1459 .06562 L

.14339 .06636 L

.14088 .06715 L

.13837 .06799 L

.13586 .06889 L

.13335 .06984 L

.13084 .07084 L

.12834 .07191 L

.12583 .07304 L

.12332 .07423 L

.12081 .07549 L

.1183 .07682 L

.11579 .07822 L

.11329 .0797 L

.11078 .08126 L

.10827 .0829 L

.10576 .08463 L

.10325 .08645 L

.10074 .08836 L

.09824 .09037 L

.09573 .09249 L

.09322 .09471 L

.09071 .09705 L

.0882 .09951 L

.08569 .10211 L

.08318 .10483 L

.08068 .1077 L

.07817 .11073 L

.07566 .11391 L

.07315 .11727 L

.07064 .12082 L

.06813 .12456 L

.06563 .12852 L

.06312 .13272 L

.06061 .13717 L

.0581 .1419 L

.05559 .14693 L

.05308 .1523 L

.05057 .15805 L

.04807 .16424 L

.04556 .17091 L

.04305 .17816 L

.04054 .18608 L

Mistroke

.03803 .19483 L

.03552 .20463 L

.03302 .2158 L

.03051 .22892 L

.028 .24522 L

.02549 .26832 L

.02465 .28867 L

.02381 .30902 L

Mfstroke

0 .4 1 r

.70026 .4251 m

.69963 .42585 L

.69901 .42662 L

.69838 .42742 L

.69775 .42824 L

.69713 .42911 L

.6965 .43003 L

.69587 .43105 L

.69524 .43224 L

.69499 .43282 L

.69474 .43358 L

.69468 .43385 L

s

.70026 .19293 m

.69963 .19218 L

.69901 .19141 L

.69838 .19062 L

.69775 .18979 L

.69713 .18893 L

.6965 .18801 L

.69587 .18699 L

.69524 .18579 L

.69499 .18521 L

.69474 .18445 L

.69468 .18418 L

s

.70152 .42365 m

.70277 .42224 L

.70402 .42087 L

.70528 .41953 L

.70653 .41822 L

.70779 .41692 L

.70904 .41563 L

.7103 .41436 L

.71155 .4131 L

.7128 .41185 L

.71406 .41061 L

.71531 .40937 L

.71657 .40814 L

.71782 .40691 L

.71907 .40568 L

.72033 .40446 L

.72158 .40324 L

.72284 .40201 L

.72409 .40079 L

.72535 .39956 L

.7266 .39834 L

.72785 .3971 L

.72911 .39587 L

.73036 .39463 L

.73162 .39339 L

.73287 .39214 L

.73413 .39088 L

.73538 .38962 L

.73663 .38835 L

.73789 .38707 L

.73914 .38579 L

.7404 .38449 L

.74165 .38318 L

.74291 .38186 L

.74416 .38053 L

.74541 .37919 L

.74667 .37783 L

.74792 .37646 L

.74918 .37508 L

.75043 .37367 L

.75168 .37225 L

.75294 .37081 L

.75419 .36935 L

.75545 .36787 L

.7567 .36637 L

.75796 .36484 L

.75921 .36328 L

.76046 .3617 L

.76172 .36009 L

.76297 .35845 L

Mistroke

.76423 .35677 L

.76548 .35506 L

.76674 .35331 L

.76799 .35152 L

.76924 .34968 L

.7705 .34779 L

.77175 .34585 L

.77301 .34385 L

.77426 .34179 L

.77551 .33966 L

.77677 .33745 L

.77802 .33515 L

.77928 .33276 L

.78053 .33027 L

.78179 .32764 L

.78304 .32488 L

.78429 .32195 L

.78555 .31883 L

.7868 .31548 L

.78806 .31184 L

.78931 .30783 L

.79057 .30334 L

.79182 .29814 L

.79307 .29186 L

.79433 .28334 L

Mfstroke

.70152 .19439 m

.70277 .19579 L

.70402 .19716 L

.70528 .1985 L

.70653 .19982 L

.70779 .20112 L

.70904 .2024 L

.7103 .20367 L

.71155 .20493 L

.7128 .20618 L

.71406 .20743 L

.71531 .20866 L

.71657 .2099 L

.71782 .21112 L

.71907 .21235 L

.72033 .21357 L

.72158 .2148 L

.72284 .21602 L

.72409 .21724 L

.72535 .21847 L

.7266 .2197 L

.72785 .22093 L

.72911 .22216 L

.73036 .2234 L

.73162 .22465 L

.73287 .22589 L

.73413 .22715 L

.73538 .22841 L

.73663 .22968 L

.73789 .23096 L

.73914 .23225 L

.7404 .23354 L

.74165 .23485 L

.74291 .23617 L

.74416 .2375 L

.74541 .23884 L

.74667 .2402 L

.74792 .24157 L

.74918 .24296 L

.75043 .24436 L

.75168 .24578 L

.75294 .24722 L

.75419 .24868 L

.75545 .25016 L

.7567 .25167 L

.75796 .25319 L

.75921 .25475 L

.76046 .25633 L

.76172 .25794 L

.76297 .25958 L

Mistroke

.76423 .26126 L

.76548 .26297 L

.76674 .26472 L

.76799 .26652 L

.76924 .26835 L

.7705 .27024 L

.77175 .27218 L

.77301 .27418 L

.77426 .27624 L

.77551 .27837 L

.77677 .28058 L

.77802 .28288 L

.77928 .28527 L

.78053 .28777 L

.78179 .29039 L

.78304 .29315 L

.78429 .29608 L

.78555 .2992 L

.7868 .30256 L

.78806 .30619 L

.78931 .31021 L

.79057 .3147 L

.79182 .31989 L

.79307 .32618 L

.79433 .33469 L

Mfstroke

.78555 .41786 m

.78304 .42584 L

.78053 .43308 L

.77802 .43973 L

.77551 .44592 L

.77301 .45171 L

.7705 .45717 L

.76799 .46233 L

.76548 .46723 L

.76297 .47189 L

.76046 .47634 L

.75796 .48058 L

.75545 .48464 L

.75294 .48853 L

.75043 .49226 L

.74792 .49585 L

.74541 .49929 L

.74291 .5026 L

.7404 .50578 L

.73789 .50885 L

.73538 .5118 L

.73287 .51464 L

.73036 .51738 L

.72785 .52003 L

.72535 .52258 L

.72284 .52504 L

.72033 .52741 L

.71782 .5297 L

.71531 .53192 L

.7128 .53406 L

.7103 .53613 L

.70779 .53813 L

.70528 .54006 L

.70277 .54193 L

.70026 .54374 L

.69775 .54549 L

.69524 .54719 L

.69274 .54883 L

.69023 .55043 L

.68772 .55197 L

.68521 .55347 L

.6827 .55492 L

.68019 .55633 L

.67769 .55769 L

.67518 .55902 L

.67267 .56031 L

.67016 .56157 L

.66765 .56279 L

.66514 .56398 L

.66263 .56513 L

Mistroke

.66013 .56626 L

.65762 .56735 L

.65511 .56842 L

.6526 .56946 L

.65009 .57048 L

.64758 .57147 L

.64508 .57244 L

.64257 .57339 L

.64006 .57431 L

.63755 .57522 L

.63504 .5761 L

.63253 .57697 L

.63003 .57781 L

.62752 .57864 L

.62501 .57946 L

.6225 .58025 L

.61999 .58103 L

.61748 .5818 L

.61497 .58255 L

.61247 .58329 L

.60996 .58401 L

.60745 .58472 L

.60494 .58542 L

.60243 .58611 L

.59992 .58678 L

.59742 .58744 L

.59491 .58808 L

.5924 .58872 L

.58989 .58935 L

.58738 .58996 L

.58487 .59056 L

.58236 .59115 L

.57986 .59173 L

.57735 .5923 L

.57484 .59286 L

.57233 .5934 L

.56982 .59394 L

.56731 .59446 L

.56481 .59497 L

.5623 .59547 L

.55979 .59596 L

.55728 .59643 L

.55477 .5969 L

.55226 .59735 L

.54975 .59779 L

.54725 .59821 L

.54474 .59862 L

.54223 .59902 L

.53972 .59941 L

.53721 .59978 L

Mistroke

.5347 .60013 L

.5322 .60047 L

.52969 .60079 L

.52718 .6011 L

.52467 .60139 L

.52216 .60167 L

.51965 .60192 L

.51715 .60216 L

.51464 .60237 L

.51213 .60257 L

.50962 .60275 L

.50711 .6029 L

.5046 .60303 L

.50209 .60314 L

.49959 .60322 L

.49708 .60328 L

.49457 .60331 L

.49206 .60332 L

.48955 .6033 L

.48704 .60324 L

.48454 .60316 L

.48203 .60304 L

.47952 .6029 L

.47701 .60272 L

.4745 .6025 L

.47199 .60224 L

.46948 .60195 L

.46698 .60162 L

.46447 .60124 L

.46196 .60082 L

.45945 .60036 L

.45694 .59985 L

.45443 .59928 L

.45193 .59867 L

.44942 .59801 L

.44691 .59728 L

.4444 .59651 L

.44189 .59567 L

.43938 .59476 L

.43688 .59379 L

.43437 .59275 L

.43186 .59164 L

.42935 .59046 L

.42684 .5892 L

.42433 .58785 L

.42182 .58642 L

.41932 .5849 L

.41681 .58329 L

.4143 .58158 L

.41179 .57977 L

Mistroke

.40928 .57785 L

.40677 .57581 L

.40427 .57366 L

.40176 .57138 L

.39925 .56898 L

.39674 .56643 L

.39423 .56374 L

.39172 .5609 L

.38921 .55789 L

.38671 .55471 L

.3842 .55134 L

.38169 .54779 L

.37918 .54402 L

.37667 .54003 L

.37416 .53581 L

.37166 .53132 L

.36915 .52657 L

.36664 .52151 L

.36413 .51612 L

.36162 .51038 L

.35911 .50424 L

.3566 .49766 L

.3541 .49059 L

.35159 .48296 L

.34908 .47468 L

.34657 .46565 L

.34406 .45572 L

.34155 .44469 L

.33905 .43225 L

.33654 .4179 L

.33403 .40076 L

.33152 .37875 L

.33039 .36581 L

.32964 .35509 L

.32901 .34356 L

.32838 .30902 L

Mfstroke

.78555 .20018 m

.78304 .1922 L

.78053 .18496 L

.77802 .1783 L

.77551 .17211 L

.77301 .16632 L

.7705 .16086 L

.76799 .1557 L

.76548 .1508 L

.76297 .14614 L

.76046 .1417 L

.75796 .13745 L

.75545 .13339 L

.75294 .1295 L

.75043 .12577 L

.74792 .12219 L

.74541 .11875 L

.74291 .11544 L

.7404 .11225 L

.73789 .10919 L

.73538 .10624 L

.73287 .10339 L

.73036 .10065 L

.72785 .09801 L

.72535 .09546 L

.72284 .093 L

.72033 .09062 L

.71782 .08833 L

.71531 .08611 L

.7128 .08398 L

.7103 .08191 L

.70779 .07991 L

.70528 .07797 L

.70277 .0761 L

.70026 .07429 L

.69775 .07254 L

.69524 .07084 L

.69274 .0692 L

.69023 .06761 L

.68772 .06606 L

.68521 .06457 L

.6827 .06312 L

.68019 .06171 L

.67769 .06034 L

.67518 .05901 L

.67267 .05772 L

.67016 .05647 L

.66765 .05525 L

.66514 .05406 L

.66263 .0529 L

Mistroke

.66013 .05178 L

.65762 .05068 L

.65511 .04961 L

.6526 .04857 L

.65009 .04755 L

.64758 .04656 L

.64508 .04559 L

.64257 .04465 L

.64006 .04372 L

.63755 .04282 L

.63504 .04193 L

.63253 .04107 L

.63003 .04022 L

.62752 .03939 L

.62501 .03858 L

.6225 .03778 L

.61999 .037 L

.61748 .03623 L

.61497 .03548 L

.61247 .03474 L

.60996 .03402 L

.60745 .03331 L

.60494 .03261 L

.60243 .03193 L

.59992 .03126 L

.59742 .0306 L

.59491 .02995 L

.5924 .02931 L

.58989 .02869 L

.58738 .02808 L

.58487 .02747 L

.58236 .02688 L

.57986 .0263 L

.57735 .02573 L

.57484 .02518 L

.57233 .02463 L

.56982 .0241 L

.56731 .02358 L

.56481 .02306 L

.5623 .02257 L

.55979 .02208 L

.55728 .0216 L

.55477 .02114 L

.55226 .02068 L

.54975 .02025 L

.54725 .01982 L

.54474 .01941 L

.54223 .01901 L

.53972 .01863 L

.53721 .01826 L

Mistroke

.5347 .0179 L

.5322 .01756 L

.52969 .01724 L

.52718 .01693 L

.52467 .01664 L

.52216 .01637 L

.51965 .01611 L

.51715 .01588 L

.51464 .01566 L

.51213 .01546 L

.50962 .01529 L

.50711 .01513 L

.5046 .015 L

.50209 .0149 L

.49959 .01481 L

.49708 .01475 L

.49457 .01472 L

.49206 .01472 L

.48955 .01474 L

.48704 .01479 L

.48454 .01487 L

.48203 .01499 L

.47952 .01514 L

.47701 .01532 L

.4745 .01553 L

.47199 .01579 L

.46948 .01608 L

.46698 .01642 L

.46447 .01679 L

.46196 .01721 L

.45945 .01768 L

.45694 .01819 L

.45443 .01875 L

.45193 .01936 L

.44942 .02003 L

.44691 .02075 L

.4444 .02153 L

.44189 .02237 L

.43938 .02327 L

.43688 .02424 L

.43437 .02528 L

.43186 .02639 L

.42935 .02757 L

.42684 .02884 L

.42433 .03018 L

.42182 .03161 L

.41932 .03313 L

.41681 .03474 L

.4143 .03645 L

.41179 .03827 L

Mistroke

.40928 .04019 L

.40677 .04222 L

.40427 .04437 L

.40176 .04665 L

.39925 .04906 L

.39674 .0516 L

.39423 .05429 L

.39172 .05714 L

.38921 .06015 L

.38671 .06333 L

.3842 .06669 L

.38169 .07025 L

.37918 .07401 L

.37667 .078 L

.37416 .08223 L

.37166 .08671 L

.36915 .09147 L

.36664 .09653 L

.36413 .10191 L

.36162 .10766 L

.35911 .11379 L

.3566 .12037 L

.3541 .12745 L

.35159 .13508 L

.34908 .14335 L

.34657 .15238 L

.34406 .16231 L

.34155 .17334 L

.33905 .18578 L

.33654 .20013 L

.33403 .21728 L

.33152 .23929 L

.33039 .25222 L

.32964 .26294 L

.32901 .27448 L

.32838 .30902 L

Mfstroke

1 0 0 r

.70152 .50669 m

.70277 .50701 L

.70402 .50732 L

.70528 .50762 L

.70653 .50791 L

.70779 .50818 L

.70904 .50844 L

.7103 .50869 L

.71155 .50893 L

.7128 .50916 L

.71406 .50938 L

.71531 .50959 L

.71657 .50979 L

.71782 .50998 L

.71907 .51016 L

.72033 .51034 L

.72158 .5105 L

.72284 .51066 L

.72409 .51081 L

.72535 .51095 L

.7266 .51108 L

.72785 .51121 L

.72911 .51133 L

.73036 .51144 L

.73162 .51155 L

.73287 .51165 L

.73413 .51175 L

.73538 .51183 L

.73663 .51191 L

.73789 .51199 L

.73914 .51206 L

.7404 .51213 L

.74165 .51219 L

.74291 .51224 L

.74416 .51229 L

.74541 .51233 L

.74667 .51237 L

.74792 .5124 L

.74918 .51243 L

.75043 .51246 L

.75168 .51248 L

.75294 .51249 L

.75419 .5125 L

.75545 .51251 L

.7567 .51252 L

.75796 .51251 L

.75921 .51251 L

.76046 .5125 L

.76172 .51249 L

.76297 .51247 L

Mistroke

.76423 .51245 L

.76548 .51243 L

.76674 .5124 L

.76799 .51237 L

.76924 .51234 L

.7705 .5123 L

.77175 .51226 L

.77301 .51222 L

.77426 .51217 L

.77551 .51212 L

.77677 .51207 L

.77802 .51201 L

.77928 .51196 L

.78053 .5119 L

.78179 .51183 L

.78304 .51177 L

.78429 .5117 L

.78555 .51163 L

.7868 .51155 L

.78806 .51148 L

.78931 .5114 L

.79057 .51132 L

.79182 .51124 L

.79307 .51115 L

.79433 .51106 L

.79558 .51098 L

.79684 .51088 L

.79809 .51079 L

.79935 .51069 L

.8006 .5106 L

.80185 .5105 L

.80311 .51039 L

.80436 .51029 L

.80562 .51019 L

.80687 .51008 L

.80812 .50997 L

.80938 .50986 L

.81063 .50975 L

.81189 .50963 L

.81314 .50952 L

.8144 .5094 L

.81565 .50928 L

.8169 .50916 L

.81816 .50904 L

.81941 .50892 L

.82067 .50879 L

.82192 .50867 L

.82318 .50854 L

.82443 .50841 L

.82568 .50828 L

Mistroke

.82694 .50815 L

.82819 .50802 L

.82945 .50789 L

.8307 .50775 L

.83195 .50762 L

.83321 .50748 L

.83446 .50734 L

.83572 .5072 L

.83697 .50706 L

.83823 .50692 L

.83948 .50678 L

.84073 .50663 L

.84199 .50649 L

.84324 .50634 L

.8445 .5062 L

.84575 .50605 L

.84701 .5059 L

.84826 .50575 L

.84951 .5056 L

.85077 .50545 L

.85202 .5053 L

.85328 .50515 L

.85453 .50499 L

.85579 .50484 L

.85704 .50469 L

.85829 .50453 L

.85955 .50437 L

.8608 .50422 L

.86206 .50406 L

.86331 .5039 L

.86456 .50374 L

.86582 .50358 L

.86707 .50342 L

.86833 .50326 L

.86958 .5031 L

.87084 .50294 L

.87209 .50277 L

.87334 .50261 L

.8746 .50245 L

.87585 .50228 L

.87711 .50212 L

.87836 .50195 L

.87962 .50179 L

.88087 .50162 L

.88212 .50145 L

.88338 .50129 L

.88463 .50112 L

.88589 .50095 L

.88714 .50078 L

.88839 .50061 L

Mistroke

.88965 .50044 L

.8909 .50027 L

.89216 .5001 L

.89341 .49993 L

.89467 .49976 L

.89592 .49959 L

.89717 .49942 L

.89843 .49925 L

.89968 .49908 L

.90094 .4989 L

.90219 .49873 L

.90345 .49856 L

.9047 .49838 L

.90595 .49821 L

.90721 .49804 L

.90846 .49786 L

.90972 .49769 L

.91097 .49751 L

.91223 .49734 L

.91348 .49716 L

.91473 .49699 L

.91599 .49681 L

.91724 .49664 L

.9185 .49646 L

.91975 .49628 L

.921 .49611 L

.92226 .49593 L

.92351 .49575 L

.92477 .49558 L

.92602 .4954 L

.92728 .49522 L

.92853 .49505 L

.92978 .49487 L

.93104 .49469 L

.93229 .49451 L

.93355 .49434 L

.9348 .49416 L

.93606 .49398 L

.93731 .4938 L

.93856 .49362 L

.93982 .49345 L

.94107 .49327 L

.94233 .49309 L

.94358 .49291 L

.94483 .49273 L

.94609 .49255 L

.94734 .49237 L

.9486 .49219 L

.94985 .49202 L

.95111 .49184 L

Mistroke

.95236 .49166 L

.95361 .49148 L

.95487 .4913 L

.95612 .49112 L

.95738 .49094 L

.95863 .49076 L

.95989 .49058 L

.96114 .4904 L

.96239 .49022 L

.96365 .49004 L

.9649 .48987 L

.96616 .48969 L

.96741 .48951 L

.96867 .48933 L

.96992 .48915 L

.97117 .48897 L

.97243 .48879 L

.97368 .48861 L

.97494 .48843 L

.97619 .48825 L

Mfstroke

.70152 .11135 m

.70277 .11102 L

.70402 .11071 L

.70528 .11041 L

.70653 .11013 L

.70779 .10985 L

.70904 .10959 L

.7103 .10934 L

.71155 .1091 L

.7128 .10887 L

.71406 .10865 L

.71531 .10844 L

.71657 .10824 L

.71782 .10805 L

.71907 .10787 L

.72033 .1077 L

.72158 .10753 L

.72284 .10737 L

.72409 .10723 L

.72535 .10708 L

.7266 .10695 L

.72785 .10682 L

.72911 .1067 L

.73036 .10659 L

.73162 .10648 L

.73287 .10638 L

.73413 .10629 L

.73538 .1062 L

.73663 .10612 L

.73789 .10604 L

.73914 .10597 L

.7404 .10591 L

.74165 .10585 L

.74291 .1058 L

.74416 .10575 L

.74541 .1057 L

.74667 .10566 L

.74792 .10563 L

.74918 .1056 L

.75043 .10558 L

.75168 .10556 L

.75294 .10554 L

.75419 .10553 L

.75545 .10552 L

.7567 .10552 L

.75796 .10552 L

.75921 .10552 L

.76046 .10553 L

.76172 .10555 L

.76297 .10556 L

Mistroke

.76423 .10558 L

.76548 .10561 L

.76674 .10563 L

.76799 .10566 L

.76924 .1057 L

.7705 .10573 L

.77175 .10577 L

.77301 .10582 L

.77426 .10586 L

.77551 .10591 L

.77677 .10596 L

.77802 .10602 L

.77928 .10608 L

.78053 .10614 L

.78179 .1062 L

.78304 .10627 L

.78429 .10633 L

.78555 .10641 L

.7868 .10648 L

.78806 .10656 L

.78931 .10663 L

.79057 .10671 L

.79182 .1068 L

.79307 .10688 L

.79433 .10697 L

.79558 .10706 L

.79684 .10715 L

.79809 .10724 L

.79935 .10734 L

.8006 .10744 L

.80185 .10754 L

.80311 .10764 L

.80436 .10774 L

.80562 .10785 L

.80687 .10795 L

.80812 .10806 L

.80938 .10817 L

.81063 .10829 L

.81189 .1084 L

.81314 .10852 L

.8144 .10863 L

.81565 .10875 L

.8169 .10887 L

.81816 .10899 L

.81941 .10911 L

.82067 .10924 L

.82192 .10937 L

.82318 .10949 L

.82443 .10962 L

.82568 .10975 L

Mistroke

.82694 .10988 L

.82819 .11001 L

.82945 .11015 L

.8307 .11028 L

.83195 .11042 L

.83321 .11056 L

.83446 .11069 L

.83572 .11083 L

.83697 .11097 L

.83823 .11111 L

.83948 .11126 L

.84073 .1114 L

.84199 .11154 L

.84324 .11169 L

.8445 .11184 L

.84575 .11198 L

.84701 .11213 L

.84826 .11228 L

.84951 .11243 L

.85077 .11258 L

.85202 .11273 L

.85328 .11289 L

.85453 .11304 L

.85579 .11319 L

.85704 .11335 L

.85829 .1135 L

.85955 .11366 L

.8608 .11382 L

.86206 .11397 L

.86331 .11413 L

.86456 .11429 L

.86582 .11445 L

.86707 .11461 L

.86833 .11477 L

.86958 .11493 L

.87084 .1151 L

.87209 .11526 L

.87334 .11542 L

.8746 .11559 L

.87585 .11575 L

.87711 .11592 L

.87836 .11608 L

.87962 .11625 L

.88087 .11641 L

.88212 .11658 L

.88338 .11675 L

.88463 .11691 L

.88589 .11708 L

.88714 .11725 L

.88839 .11742 L

Mistroke

.88965 .11759 L

.8909 .11776 L

.89216 .11793 L

.89341 .1181 L

.89467 .11827 L

.89592 .11844 L

.89717 .11861 L

.89843 .11879 L

.89968 .11896 L

.90094 .11913 L

.90219 .1193 L

.90345 .11948 L

.9047 .11965 L

.90595 .11982 L

.90721 .12 L

.90846 .12017 L

.90972 .12035 L

.91097 .12052 L

.91223 .1207 L

.91348 .12087 L

.91473 .12105 L

.91599 .12122 L

.91724 .1214 L

.9185 .12157 L

.91975 .12175 L

.921 .12193 L

.92226 .1221 L

.92351 .12228 L

.92477 .12246 L

.92602 .12263 L

.92728 .12281 L

.92853 .12299 L

.92978 .12317 L

.93104 .12334 L

.93229 .12352 L

.93355 .1237 L

.9348 .12388 L

.93606 .12405 L

.93731 .12423 L

.93856 .12441 L

.93982 .12459 L

.94107 .12477 L

.94233 .12495 L

.94358 .12512 L

.94483 .1253 L

.94609 .12548 L

.94734 .12566 L

.9486 .12584 L

.94985 .12602 L

.95111 .1262 L

Mistroke

.95236 .12638 L

.95361 .12656 L

.95487 .12673 L

.95612 .12691 L

.95738 .12709 L

.95863 .12727 L

.95989 .12745 L

.96114 .12763 L

.96239 .12781 L

.96365 .12799 L

.9649 .12817 L

.96616 .12835 L

.96741 .12853 L

.96867 .12871 L

.96992 .12889 L

.97117 .12906 L

.97243 .12924 L

.97368 .12942 L

.97494 .1296 L

.97619 .12978 L

Mfstroke

0 .4 1 r

.73852 .43004 m

.73839 .43007 L

.73826 .4301 L

.73814 .43013 L

.73801 .43016 L

.73789 .43019 L

.73776 .43021 L

.73764 .43024 L

.73751 .43027 L

.73739 .4303 L

.73726 .43033 L

.73714 .43035 L

.73701 .43038 L

.73688 .43041 L

.73676 .43044 L

.73663 .43047 L

.73651 .43049 L

.73638 .43052 L

.73626 .43055 L

.73613 .43058 L

.73601 .43061 L

.73588 .43063 L

.73576 .43066 L

.73563 .43069 L

.73551 .43072 L

.73538 .43075 L

.73525 .43077 L

.73513 .4308 L

.735 .43083 L

.73488 .43086 L

.73475 .43089 L

.73463 .43091 L

.7345 .43094 L

.73438 .43097 L

.73425 .431 L

.73413 .43102 L

.734 .43105 L

.73387 .43108 L

.73375 .43111 L

.73362 .43114 L

.7335 .43116 L

.73337 .43119 L

.73325 .43122 L

.73312 .43125 L

.733 .43127 L

.73287 .4313 L

.73275 .43133 L

.73262 .43136 L

.7325 .43138 L

.73237 .43141 L

Mistroke

.73224 .43144 L

.73212 .43147 L

.73199 .4315 L

.73187 .43152 L

.73174 .43155 L

.73162 .43158 L

.73149 .43161 L

.73137 .43163 L

.73124 .43166 L

.73112 .43169 L

.73099 .43172 L

.73086 .43174 L

.73074 .43177 L

.73061 .4318 L

.73049 .43183 L

.73036 .43185 L

.73024 .43188 L

.73011 .43191 L

.72999 .43194 L

.72986 .43196 L

.72974 .43199 L

.72961 .43202 L

.72949 .43205 L

.72936 .43207 L

.72923 .4321 L

.72911 .43213 L

.72898 .43216 L

.72886 .43218 L

.72873 .43221 L

.72861 .43224 L

.72848 .43227 L

.72836 .43229 L

.72823 .43232 L

.72811 .43235 L

.72798 .43237 L

.72785 .4324 L

.72773 .43243 L

.7276 .43246 L

.72748 .43248 L

.72735 .43251 L

.72723 .43254 L

.7271 .43256 L

.72698 .43259 L

.72685 .43262 L

.72673 .43265 L

.7266 .43267 L

.72647 .4327 L

.72635 .43273 L

.72622 .43275 L

.7261 .43278 L

Mistroke

.72597 .43281 L

.72585 .43283 L

.72572 .43286 L

.7256 .43289 L

.72547 .43291 L

.72535 .43294 L

.72522 .43297 L

.7251 .433 L

.72497 .43302 L

.72484 .43305 L

.72472 .43308 L

.72459 .4331 L

.72447 .43313 L

.72434 .43316 L

.72422 .43318 L

.72409 .43321 L

.72397 .43324 L

.72384 .43326 L

.72372 .43329 L

.72359 .43332 L

.72346 .43334 L

.72334 .43337 L

.72321 .43339 L

.72309 .43342 L

.72296 .43345 L

.72284 .43347 L

.72271 .4335 L

.72259 .43353 L

.72246 .43355 L

.72234 .43358 L

.72221 .4336 L

.72209 .43363 L

.72196 .43366 L

.72183 .43368 L

.72171 .43371 L

.72158 .43374 L

.72146 .43376 L

.72133 .43379 L

.72121 .43382 L

.72108 .43384 L

.72096 .43387 L

.72083 .43389 L

.72071 .43392 L

.72058 .43395 L

.72045 .43397 L

.72033 .434 L

.7202 .43402 L

.72008 .43405 L

.71995 .43407 L

.71983 .4341 L

Mistroke

.7197 .43412 L

.71958 .43415 L

.71945 .43418 L

.71933 .4342 L

.7192 .43423 L

.71907 .43425 L

.71895 .43428 L

.71882 .4343 L

.7187 .43433 L

.71857 .43436 L

.71845 .43438 L

.71832 .43441 L

.7182 .43443 L

.71807 .43446 L

.71795 .43448 L

.71782 .43451 L

.7177 .43453 L

.71757 .43456 L

.71744 .43458 L

.71732 .43461 L

.71719 .43463 L

.71707 .43466 L

.71694 .43468 L

.71682 .43471 L

.71669 .43473 L

.71657 .43476 L

.71644 .43478 L

.71632 .43481 L

.71619 .43483 L

.71606 .43486 L

.71594 .43488 L

.71581 .4349 L

.71569 .43493 L

.71556 .43495 L

.71544 .43498 L

.71531 .435 L

.71519 .43503 L

.71506 .43505 L

.71494 .43507 L

.71481 .4351 L

.71469 .43512 L

.71456 .43515 L

.71443 .43517 L

.71431 .43519 L

.71418 .43522 L

.71406 .43524 L

.71393 .43527 L

.71381 .43529 L

.71368 .43531 L

.71356 .43534 L

Mistroke

.71343 .43536 L

.71331 .43538 L

.71318 .4354 L

.71305 .43543 L

.71293 .43545 L

.7128 .43548 L

.71268 .4355 L

.71255 .43552 L

.71243 .43555 L

.7123 .43557 L

.71218 .43559 L

.71205 .43561 L

.71193 .43564 L

.7118 .43566 L

.71168 .43568 L

.71155 .4357 L

.71142 .43573 L

.7113 .43575 L

.71117 .43577 L

.71105 .43579 L

.71092 .43582 L

.7108 .43584 L

.71067 .43586 L

.71055 .43588 L

.71042 .4359 L

.7103 .43592 L

.71017 .43595 L

.71004 .43597 L

.70992 .43599 L

.70979 .43601 L

.70967 .43603 L

.70954 .43605 L

.70942 .43607 L

.70929 .43609 L

.70917 .43611 L

.70904 .43613 L

.70892 .43615 L

.70879 .43617 L

.70866 .43619 L

.70854 .43621 L

.70841 .43623 L

.70829 .43625 L

.70816 .43627 L

.70804 .43629 L

.70791 .43631 L

.70779 .43633 L

.70766 .43635 L

.70754 .43637 L

.70741 .43639 L

.70729 .43641 L

Mistroke

.70716 .43643 L

.70703 .43645 L

.70691 .43647 L

.70678 .43649 L

.70666 .43651 L

.70653 .43652 L

.70641 .43654 L

.70628 .43656 L

.70616 .43658 L

.70603 .4366 L

.70591 .43661 L

.70578 .43663 L

.70565 .43665 L

.70553 .43666 L

.7054 .43668 L

.70528 .4367 L

.70515 .43671 L

.70503 .43673 L

.7049 .43674 L

.70478 .43676 L

.70465 .43678 L

.70453 .43679 L

.7044 .43681 L

.70428 .43682 L

.70415 .43684 L

.70402 .43685 L

.7039 .43686 L

.70377 .43688 L

.70365 .43689 L

.70352 .43691 L

.7034 .43692 L

.70327 .43693 L

.70315 .43694 L

.70302 .43696 L

.7029 .43697 L

.70277 .43698 L

.70264 .43699 L

.70252 .437 L

.70239 .43701 L

.70227 .43702 L

.70214 .43703 L

.70202 .43704 L

.70189 .43705 L

.70177 .43706 L

.70164 .43707 L

.70152 .43708 L

.70139 .43709 L

.70127 .4371 L

.70114 .4371 L

.70101 .43711 L

Mistroke

.70089 .43712 L

.70076 .43712 L

.70064 .43713 L

.70051 .43713 L

.70039 .43713 L

.70026 .43714 L

.70014 .43714 L

.70001 .43714 L

.69989 .43714 L

.69976 .43715 L

.69963 .43715 L

.69951 .43715 L

.69938 .43714 L

.69926 .43714 L

.69913 .43714 L

.69901 .43714 L

.69888 .43713 L

.69876 .43713 L

.69863 .43712 L

.69851 .43711 L

.69838 .4371 L

.69825 .4371 L

.69813 .43708 L

.698 .43707 L

.69788 .43706 L

.69775 .43704 L

.69763 .43703 L

.6975 .437 L

.69738 .43698 L

.69725 .43696 L

.69713 .43694 L

.697 .43691 L

.69688 .43688 L

.69675 .43685 L

.69662 .43682 L

.6965 .43678 L

.69637 .43674 L

.69625 .4367 L

.69612 .43666 L

.696 .43659 L

.69587 .43655 L

.69575 .43649 L

.69562 .43641 L

.6955 .43633 L

.69537 .43624 L

.69524 .43613 L

.69512 .43601 L

.69499 .43586 L

.69487 .43567 L

.69474 .43541 L

Mistroke

.69462 .43489 L

Mfstroke

.73852 .18799 m

.73839 .18796 L

.73826 .18793 L

.73814 .18791 L

.73801 .18788 L

.73789 .18785 L

.73776 .18782 L

.73764 .18779 L

.73751 .18776 L

.73739 .18774 L

.73726 .18771 L

.73714 .18768 L

.73701 .18765 L

.73688 .18762 L

.73676 .1876 L

.73663 .18757 L

.73651 .18754 L

.73638 .18751 L

.73626 .18748 L

.73613 .18746 L

.73601 .18743 L

.73588 .1874 L

.73576 .18737 L

.73563 .18734 L

.73551 .18732 L

.73538 .18729 L

.73525 .18726 L

.73513 .18723 L

.735 .1872 L

.73488 .18718 L

.73475 .18715 L

.73463 .18712 L

.7345 .18709 L

.73438 .18707 L

.73425 .18704 L

.73413 .18701 L

.734 .18698 L

.73387 .18695 L

.73375 .18693 L

.73362 .1869 L

.7335 .18687 L

.73337 .18684 L

.73325 .18681 L

.73312 .18679 L

.733 .18676 L

.73287 .18673 L

.73275 .1867 L

.73262 .18668 L

.7325 .18665 L

.73237 .18662 L

Mistroke

.73224 .18659 L

.73212 .18657 L

.73199 .18654 L

.73187 .18651 L

.73174 .18648 L

.73162 .18646 L

.73149 .18643 L

.73137 .1864 L

.73124 .18637 L

.73112 .18635 L

.73099 .18632 L

.73086 .18629 L

.73074 .18626 L

.73061 .18623 L

.73049 .18621 L

.73036 .18618 L

.73024 .18615 L

.73011 .18612 L

.72999 .1861 L

.72986 .18607 L

.72974 .18604 L

.72961 .18601 L

.72949 .18599 L

.72936 .18596 L

.72923 .18593 L

.72911 .1859 L

.72898 .18588 L

.72886 .18585 L

.72873 .18582 L

.72861 .1858 L

.72848 .18577 L

.72836 .18574 L

.72823 .18571 L

.72811 .18569 L

.72798 .18566 L

.72785 .18563 L

.72773 .1856 L

.7276 .18558 L

.72748 .18555 L

.72735 .18552 L

.72723 .1855 L

.7271 .18547 L

.72698 .18544 L

.72685 .18541 L

.72673 .18539 L

.7266 .18536 L

.72647 .18533 L

.72635 .18531 L

.72622 .18528 L

.7261 .18525 L

Mistroke

.72597 .18523 L

.72585 .1852 L

.72572 .18517 L

.7256 .18515 L

.72547 .18512 L

.72535 .18509 L

.72522 .18506 L

.7251 .18504 L

.72497 .18501 L

.72484 .18498 L

.72472 .18496 L

.72459 .18493 L

.72447 .1849 L

.72434 .18488 L

.72422 .18485 L

.72409 .18482 L

.72397 .1848 L

.72384 .18477 L

.72372 .18474 L

.72359 .18472 L

.72346 .18469 L

.72334 .18467 L

.72321 .18464 L

.72309 .18461 L

.72296 .18459 L

.72284 .18456 L

.72271 .18453 L

.72259 .18451 L

.72246 .18448 L

.72234 .18445 L

.72221 .18443 L

.72209 .1844 L

.72196 .18438 L

.72183 .18435 L

.72171 .18432 L

.72158 .1843 L

.72146 .18427 L

.72133 .18424 L

.72121 .18422 L

.72108 .18419 L

.72096 .18417 L

.72083 .18414 L

.72071 .18411 L

.72058 .18409 L

.72045 .18406 L

.72033 .18404 L

.7202 .18401 L

.72008 .18399 L

.71995 .18396 L

.71983 .18394 L

Mistroke

.7197 .18391 L

.71958 .18388 L

.71945 .18386 L

.71933 .18383 L

.7192 .18381 L

.71907 .18378 L

.71895 .18375 L

.71882 .18373 L

.7187 .1837 L

.71857 .18368 L

.71845 .18365 L

.71832 .18363 L

.7182 .1836 L

.71807 .18358 L

.71795 .18355 L

.71782 .18353 L

.7177 .1835 L

.71757 .18348 L

.71744 .18345 L

.71732 .18343 L

.71719 .1834 L

.71707 .18338 L

.71694 .18335 L

.71682 .18333 L

.71669 .1833 L

.71657 .18328 L

.71644 .18325 L

.71632 .18323 L

.71619 .1832 L

.71606 .18318 L

.71594 .18315 L

.71581 .18313 L

.71569 .18311 L

.71556 .18308 L

.71544 .18306 L

.71531 .18303 L

.71519 .18301 L

.71506 .18298 L

.71494 .18296 L

.71481 .18294 L

.71469 .18291 L

.71456 .18289 L

.71443 .18286 L

.71431 .18284 L

.71418 .18282 L

.71406 .18279 L

.71393 .18277 L

.71381 .18275 L

.71368 .18272 L

.71356 .1827 L

Mistroke

.71343 .18268 L

.71331 .18265 L

.71318 .18263 L

.71305 .18261 L

.71293 .18258 L

.7128 .18256 L

.71268 .18254 L

.71255 .18251 L

.71243 .18249 L

.7123 .18247 L

.71218 .18244 L

.71205 .18242 L

.71193 .1824 L

.7118 .18237 L

.71168 .18235 L

.71155 .18233 L

.71142 .18231 L

.7113 .18229 L

.71117 .18226 L

.71105 .18224 L

.71092 .18222 L

.7108 .1822 L

.71067 .18217 L

.71055 .18215 L

.71042 .18213 L

.7103 .18211 L

.71017 .18209 L

.71004 .18207 L

.70992 .18205 L

.70979 .18202 L

.70967 .182 L

.70954 .18198 L

.70942 .18196 L

.70929 .18194 L

.70917 .18192 L

.70904 .1819 L

.70892 .18188 L

.70879 .18186 L

.70866 .18184 L

.70854 .18182 L

.70841 .1818 L

.70829 .18178 L

.70816 .18176 L

.70804 .18174 L

.70791 .18172 L

.70779 .1817 L

.70766 .18168 L

.70754 .18166 L

.70741 .18164 L

.70729 .18162 L

Mistroke

.70716 .1816 L

.70703 .18158 L

.70691 .18157 L

.70678 .18155 L

.70666 .18153 L

.70653 .18151 L

.70641 .18149 L

.70628 .18147 L

.70616 .18146 L

.70603 .18144 L

.70591 .18142 L

.70578 .1814 L

.70565 .18139 L

.70553 .18137 L

.7054 .18135 L

.70528 .18134 L

.70515 .18132 L

.70503 .18131 L

.7049 .18129 L

.70478 .18127 L

.70465 .18126 L

.70453 .18124 L

.7044 .18123 L

.70428 .18121 L

.70415 .1812 L

.70402 .18118 L

.7039 .18117 L

.70377 .18116 L

.70365 .18114 L

.70352 .18113 L

.7034 .18111 L

.70327 .1811 L

.70315 .18109 L

.70302 .18108 L

.7029 .18106 L

.70277 .18105 L

.70264 .18104 L

.70252 .18103 L

.70239 .18102 L

.70227 .18101 L

.70214 .181 L

.70202 .18099 L

.70189 .18098 L

.70177 .18097 L

.70164 .18096 L

.70152 .18095 L

.70139 .18095 L

.70127 .18094 L

.70114 .18093 L

.70101 .18093 L

Mistroke

.70089 .18092 L

.70076 .18091 L

.70064 .18091 L

.70051 .1809 L

.70039 .1809 L

.70026 .1809 L

.70014 .18089 L

.70001 .18089 L

.69989 .18089 L

.69976 .18089 L

.69963 .18089 L

.69951 .18089 L

.69938 .18089 L

.69926 .18089 L

.69913 .18089 L

.69901 .1809 L

.69888 .1809 L

.69876 .18091 L

.69863 .18091 L

.69851 .18092 L

.69838 .18093 L

.69825 .18094 L

.69813 .18095 L

.698 .18096 L

.69788 .18097 L

.69775 .18099 L

.69763 .18101 L

.6975 .18103 L

.69738 .18105 L

.69725 .18107 L

.69713 .1811 L

.697 .18112 L

.69688 .18115 L

.69675 .18118 L

.69662 .18122 L

.6965 .18125 L

.69637 .18129 L

.69625 .18134 L

.69612 .18137 L

.696 .18144 L

.69587 .18148 L

.69575 .18155 L

.69562 .18162 L

.6955 .1817 L

.69537 .1818 L

.69524 .1819 L

.69512 .18203 L

.69499 .18217 L

.69487 .18236 L

.69474 .18263 L

Mistroke

.69462 .18314 L

Mfstroke

.78806 .40884 m

.78818 .40835 L

.78831 .40786 L

.78843 .40736 L

.78856 .40687 L

.78868 .40637 L

.78881 .40586 L

.78894 .40535 L

.78906 .40484 L

.78919 .40431 L

.78931 .40379 L

.78944 .40325 L

.78956 .40272 L

.78969 .40218 L

.78981 .40163 L

.78994 .40108 L

.79006 .40053 L

.79019 .39996 L

.79031 .39939 L

.79044 .39881 L

.79057 .39823 L

.79069 .39764 L

.79082 .39704 L

.79094 .39644 L

.79107 .39583 L

.79119 .39521 L

.79132 .39457 L

.79144 .39394 L

.79157 .39328 L

.79169 .39263 L

.79182 .39196 L

.79195 .39128 L

.79207 .3906 L

.7922 .38988 L

.79232 .38918 L

.79245 .38843 L

.79257 .38769 L

.7927 .38694 L

.79282 .38617 L

.79295 .38538 L

.79307 .38457 L

.7932 .38373 L

.79332 .38288 L

.79345 .38199 L

.79358 .38109 L

.7937 .38016 L

.79383 .3792 L

.79395 .3782 L

.79408 .37715 L

.7942 .37605 L

Mistroke

.79433 .37493 L

.79445 .37373 L

.79458 .37246 L

.7947 .37109 L

.79483 .36961 L

.79496 .36796 L

.79508 .36612 L

.79521 .36394 L

.79533 .36114 L

.79539 .3592 L

Mfstroke

.78806 .2092 m

.78818 .20969 L

.78831 .21018 L

.78843 .21067 L

.78856 .21117 L

.78868 .21167 L

.78881 .21217 L

.78894 .21268 L

.78906 .2132 L

.78919 .21372 L

.78931 .21425 L

.78944 .21478 L

.78956 .21531 L

.78969 .21585 L

.78981 .2164 L

.78994 .21695 L

.79006 .21751 L

.79019 .21807 L

.79031 .21864 L

.79044 .21922 L

.79057 .2198 L

.79069 .2204 L

.79082 .221 L

.79094 .2216 L

.79107 .22221 L

.79119 .22283 L

.79132 .22346 L

.79144 .2241 L

.79157 .22475 L

.79169 .22541 L

.79182 .22607 L

.79195 .22675 L

.79207 .22744 L

.7922 .22815 L

.79232 .22886 L

.79245 .2296 L

.79257 .23034 L

.7927 .23109 L

.79282 .23186 L

.79295 .23265 L

.79307 .23347 L

.7932 .23431 L

.79332 .23515 L

.79345 .23605 L

.79358 .23695 L

.7937 .23787 L

.79383 .23883 L

.79395 .23983 L

.79408 .24088 L

.7942 .24198 L

Mistroke

.79433 .2431 L

.79445 .2443 L

.79458 .24558 L

.7947 .24694 L

.79483 .24842 L

.79496 .25007 L

.79508 .25191 L

.79521 .25409 L

.79533 .25689 L

.79539 .25884 L

Mfstroke

.73789 .43019 m

.73914 .4299 L

.7404 .42962 L

.74165 .42934 L

.74291 .42906 L

.74416 .42877 L

.74541 .42849 L

.74667 .4282 L

.74792 .42792 L

.74918 .42763 L

.75043 .42734 L

.75168 .42706 L

.75294 .42677 L

.75419 .42648 L

.75545 .4262 L

.7567 .42591 L

.75796 .42562 L

.75921 .42533 L

.76046 .42505 L

.76172 .42476 L

.76297 .42447 L

.76423 .42418 L

.76548 .42389 L

.76674 .4236 L

.76799 .42332 L

.76924 .42303 L

.7705 .42274 L

.77175 .42245 L

.77301 .42216 L

.77426 .42187 L

.77551 .42158 L

.77677 .42129 L

.77802 .42101 L

.77928 .42072 L

.78053 .42043 L

.78179 .42014 L

.78304 .41985 L

.78429 .41956 L

.78555 .41927 L

.7868 .41899 L

.78806 .4187 L

.78931 .41841 L

.79057 .41812 L

.79182 .41783 L

.79307 .41755 L

.79433 .41726 L

.79558 .41697 L

.79684 .41668 L

.79809 .41639 L

.79935 .41611 L

Mistroke

.8006 .41582 L

.80185 .41553 L

.80311 .41525 L

.80436 .41496 L

.80562 .41467 L

.80687 .41438 L

.80812 .4141 L

.80938 .41381 L

.81063 .41353 L

.81189 .41324 L

.81314 .41295 L

.8144 .41267 L

.81565 .41238 L

.8169 .4121 L

.81816 .41181 L

.81941 .41152 L

.82067 .41124 L

.82192 .41095 L

.82318 .41067 L

.82443 .41038 L

.82568 .4101 L

.82694 .40981 L

.82819 .40953 L

.82945 .40925 L

.8307 .40896 L

.83195 .40868 L

.83321 .40839 L

.83446 .40811 L

.83572 .40783 L

.83697 .40754 L

.83823 .40726 L

.83948 .40698 L

.84073 .40669 L

.84199 .40641 L

.84324 .40613 L

.8445 .40584 L

.84575 .40556 L

.84701 .40528 L

.84826 .405 L

.84951 .40472 L

.85077 .40443 L

.85202 .40415 L

.85328 .40387 L

.85453 .40359 L

.85579 .40331 L

.85704 .40303 L

.85829 .40275 L

.85955 .40247 L

.8608 .40219 L

.86206 .40191 L

Mistroke

.86331 .40163 L

.86456 .40134 L

.86582 .40106 L

.86707 .40079 L

.86833 .40051 L

.86958 .40023 L

.87084 .39995 L

.87209 .39967 L

.87334 .39939 L

.8746 .39911 L

.87585 .39883 L

.87711 .39855 L

.87836 .39827 L

.87962 .398 L

.88087 .39772 L

.88212 .39744 L

.88338 .39716 L

.88463 .39688 L

.88589 .39661 L

.88714 .39633 L

.88839 .39605 L

.88965 .39577 L

.8909 .3955 L

.89216 .39522 L

.89341 .39494 L

.89467 .39467 L

.89592 .39439 L

.89717 .39411 L

.89843 .39384 L

.89968 .39356 L

.90094 .39329 L

.90219 .39301 L

.90345 .39273 L

.9047 .39246 L

.90595 .39218 L

.90721 .39191 L

.90846 .39163 L

.90972 .39136 L

.91097 .39108 L

.91223 .39081 L

.91348 .39053 L

.91473 .39026 L

.91599 .38999 L

.91724 .38971 L

.9185 .38944 L

.91975 .38916 L

.921 .38889 L

.92226 .38862 L

.92351 .38834 L

.92477 .38807 L

Mistroke

.92602 .3878 L

.92728 .38752 L

.92853 .38725 L

.92978 .38698 L

.93104 .3867 L

.93229 .38643 L

.93355 .38616 L

.9348 .38589 L

.93606 .38561 L

.93731 .38534 L

.93856 .38507 L

.93982 .3848 L

.94107 .38453 L

.94233 .38425 L

.94358 .38398 L

.94483 .38371 L

.94609 .38344 L

.94734 .38317 L

.9486 .3829 L

.94985 .38263 L

.95111 .38235 L

.95236 .38208 L

.95361 .38181 L

.95487 .38154 L

.95612 .38127 L

.95738 .381 L

.95863 .38073 L

.95989 .38046 L

.96114 .38019 L

.96239 .37992 L

.96365 .37965 L

.9649 .37938 L

.96616 .37911 L

.96741 .37884 L

.96867 .37857 L

.96992 .3783 L

.97117 .37803 L

.97243 .37776 L

.97368 .37749 L

.97494 .37722 L

.97619 .37695 L

Mfstroke

.73789 .18785 m

.73914 .18813 L

.7404 .18841 L

.74165 .1887 L

.74291 .18898 L

.74416 .18926 L

.74541 .18955 L

.74667 .18983 L

.74792 .19012 L

.74918 .1904 L

.75043 .19069 L

.75168 .19098 L

.75294 .19126 L

.75419 .19155 L

.75545 .19184 L

.7567 .19213 L

.75796 .19241 L

.75921 .1927 L

.76046 .19299 L

.76172 .19328 L

.76297 .19357 L

.76423 .19385 L

.76548 .19414 L

.76674 .19443 L

.76799 .19472 L

.76924 .19501 L

.7705 .1953 L

.77175 .19558 L

.77301 .19587 L

.77426 .19616 L

.77551 .19645 L

.77677 .19674 L

.77802 .19703 L

.77928 .19732 L

.78053 .19761 L

.78179 .19789 L

.78304 .19818 L

.78429 .19847 L

.78555 .19876 L

.7868 .19905 L

.78806 .19934 L

.78931 .19962 L

.79057 .19991 L

.79182 .2002 L

.79307 .20049 L

.79433 .20078 L

.79558 .20106 L

.79684 .20135 L

.79809 .20164 L

.79935 .20193 L

Mistroke

.8006 .20221 L

.80185 .2025 L

.80311 .20279 L

.80436 .20308 L

.80562 .20336 L

.80687 .20365 L

.80812 .20394 L

.80938 .20422 L

.81063 .20451 L

.81189 .20479 L

.81314 .20508 L

.8144 .20537 L

.81565 .20565 L

.8169 .20594 L

.81816 .20622 L

.81941 .20651 L

.82067 .2068 L

.82192 .20708 L

.82318 .20737 L

.82443 .20765 L

.82568 .20793 L

.82694 .20822 L

.82819 .2085 L

.82945 .20879 L

.8307 .20907 L

.83195 .20936 L

.83321 .20964 L

.83446 .20992 L

.83572 .21021 L

.83697 .21049 L

.83823 .21077 L

.83948 .21106 L

.84073 .21134 L

.84199 .21162 L

.84324 .21191 L

.8445 .21219 L

.84575 .21247 L

.84701 .21275 L

.84826 .21304 L

.84951 .21332 L

.85077 .2136 L

.85202 .21388 L

.85328 .21416 L

.85453 .21444 L

.85579 .21472 L

.85704 .21501 L

.85829 .21529 L

.85955 .21557 L

.8608 .21585 L

.86206 .21613 L

Mistroke

.86331 .21641 L

.86456 .21669 L

.86582 .21697 L

.86707 .21725 L

.86833 .21753 L

.86958 .21781 L

.87084 .21809 L

.87209 .21837 L

.87334 .21865 L

.8746 .21892 L

.87585 .2192 L

.87711 .21948 L

.87836 .21976 L

.87962 .22004 L

.88087 .22032 L

.88212 .22059 L

.88338 .22087 L

.88463 .22115 L

.88589 .22143 L

.88714 .22171 L

.88839 .22198 L

.88965 .22226 L

.8909 .22254 L

.89216 .22281 L

.89341 .22309 L

.89467 .22337 L

.89592 .22364 L

.89717 .22392 L

.89843 .2242 L

.89968 .22447 L

.90094 .22475 L

.90219 .22502 L

.90345 .2253 L

.9047 .22558 L

.90595 .22585 L

.90721 .22613 L

.90846 .2264 L

.90972 .22668 L

.91097 .22695 L

.91223 .22723 L

.91348 .2275 L

.91473 .22777 L

.91599 .22805 L

.91724 .22832 L

.9185 .2286 L

.91975 .22887 L

.921 .22914 L

.92226 .22942 L

.92351 .22969 L

.92477 .22997 L

Mistroke

.92602 .23024 L

.92728 .23051 L

.92853 .23078 L

.92978 .23106 L

.93104 .23133 L

.93229 .2316 L

.93355 .23188 L

.9348 .23215 L

.93606 .23242 L

.93731 .23269 L

.93856 .23296 L

.93982 .23324 L

.94107 .23351 L

.94233 .23378 L

.94358 .23405 L

.94483 .23432 L

.94609 .2346 L

.94734 .23487 L

.9486 .23514 L

.94985 .23541 L

.95111 .23568 L

.95236 .23595 L

.95361 .23622 L

.95487 .23649 L

.95612 .23676 L

.95738 .23703 L

.95863 .2373 L

.95989 .23757 L

.96114 .23784 L

.96239 .23811 L

.96365 .23838 L

.9649 .23865 L

.96616 .23892 L

.96741 .23919 L

.96867 .23946 L

.96992 .23973 L

.97117 .24 L

.97243 .24027 L

.97368 .24054 L

.97494 .24081 L

.97619 .24108 L

Mfstroke

1 0 0 r

.66314 .45604 m

.66326 .45616 L

.66339 .45628 L

.66351 .45643 L

.66364 .45659 L

.66376 .45678 L

.66389 .457 L

.66395 .45713 L

.66358 .47453 L

s

.66314 .162 m

.66326 .16188 L

.66339 .16175 L

.66351 .1616 L

.66364 .16144 L

.66376 .16125 L

.66389 .16103 L

.66395 .1609 L

.66358 .1435 L

s

0 .4 1 r

.78555 .41786 m

.78806 .40884 L

.78818 .40835 L

.78831 .40786 L

.78843 .40736 L

.78856 .40687 L

.78868 .40637 L

.78881 .40586 L

.78894 .40535 L

.78906 .40484 L

.78919 .40431 L

.78931 .40379 L

.78944 .40325 L

.78956 .40272 L

.78969 .40218 L

.78981 .40163 L

.78994 .40108 L

.79006 .40053 L

.79019 .39996 L

.79031 .39939 L

.79044 .39881 L

.79057 .39823 L

.79069 .39764 L

.79082 .39704 L

.79094 .39644 L

.79107 .39583 L

.79119 .39521 L

.79132 .39457 L

.79144 .39394 L

.79157 .39328 L

.79169 .39263 L

.79182 .39196 L

.79195 .39128 L

.79207 .3906 L

.7922 .38988 L

.79232 .38918 L

.79245 .38843 L

.79257 .38769 L

.7927 .38694 L

.79282 .38617 L

.79295 .38538 L

.79307 .38457 L

.7932 .38373 L

.79332 .38288 L

.79345 .38199 L

.79358 .38109 L

.7937 .38016 L

.79383 .3792 L

.79395 .3782 L

.79408 .37715 L

Mistroke

.7942 .37605 L

.79433 .37493 L

.79445 .37373 L

.79458 .37246 L

.7947 .37109 L

.79483 .36961 L

.79496 .36796 L

.79508 .36612 L

.79521 .36394 L

.79533 .36114 L

.79539 .3592 L

.79546 .35298 L

Mfstroke

.78555 .20018 m

.78806 .2092 L

.78818 .20969 L

.78831 .21018 L

.78843 .21067 L

.78856 .21117 L

.78868 .21167 L

.78881 .21217 L

.78894 .21268 L

.78906 .2132 L

.78919 .21372 L

.78931 .21425 L

.78944 .21478 L

.78956 .21531 L

.78969 .21585 L

.78981 .2164 L

.78994 .21695 L

.79006 .21751 L

.79019 .21807 L

.79031 .21864 L

.79044 .21922 L

.79057 .2198 L

.79069 .2204 L

.79082 .221 L

.79094 .2216 L

.79107 .22221 L

.79119 .22283 L

.79132 .22346 L

.79144 .2241 L

.79157 .22475 L

.79169 .22541 L

.79182 .22607 L

.79195 .22675 L

.79207 .22744 L

.7922 .22815 L

.79232 .22886 L

.79245 .2296 L

.79257 .23034 L

.7927 .23109 L

.79282 .23186 L

.79295 .23265 L

.79307 .23347 L

.7932 .23431 L

.79332 .23515 L

.79345 .23605 L

.79358 .23695 L

.7937 .23787 L

.79383 .23883 L

.79395 .23983 L

.79408 .24088 L

Mistroke

.7942 .24198 L

.79433 .2431 L

.79445 .2443 L

.79458 .24558 L

.7947 .24694 L

.79483 .24842 L

.79496 .25007 L

.79508 .25191 L

.79521 .25409 L

.79533 .25689 L

.79539 .25884 L

.79546 .26506 L

Mfstroke

.70152 .42365 m

.70277 .42224 L

.70402 .42087 L

.70528 .41953 L

.70653 .41822 L

.70779 .41692 L

.70904 .41563 L

.7103 .41436 L

.71155 .4131 L

.7128 .41185 L

.71406 .41061 L

.71531 .40937 L

.71657 .40814 L

.71782 .40691 L

.71907 .40568 L

.72033 .40446 L

.72158 .40324 L

.72284 .40201 L

.72409 .40079 L

.72535 .39956 L

.7266 .39834 L

.72785 .3971 L

.72911 .39587 L

.73036 .39463 L

.73162 .39339 L

.73287 .39214 L

.73413 .39088 L

.73538 .38962 L

.73663 .38835 L

.73789 .38707 L

.73914 .38579 L

.7404 .38449 L

.74165 .38318 L

.74291 .38186 L

.74416 .38053 L

.74541 .37919 L

.74667 .37783 L

.74792 .37646 L

.74918 .37508 L

.75043 .37367 L

.75168 .37225 L

.75294 .37081 L

.75419 .36935 L

.75545 .36787 L

.7567 .36637 L

.75796 .36484 L

.75921 .36328 L

.76046 .3617 L

.76172 .36009 L

.76297 .35845 L

Mistroke

.76423 .35677 L

.76548 .35506 L

.76674 .35331 L

.76799 .35152 L

.76924 .34968 L

.7705 .34779 L

.77175 .34585 L

.77301 .34385 L

.77426 .34179 L

.77551 .33966 L

.77677 .33745 L

.77802 .33515 L

.77928 .33276 L

.78053 .33027 L

.78179 .32764 L

.78304 .32488 L

.78429 .32195 L

.78555 .31883 L

.7868 .31548 L

.78806 .31184 L

.78931 .30783 L

.79057 .30334 L

.79182 .29814 L

.79307 .29186 L

.79433 .28334 L

.79496 .27695 L

.79508 .27523 L

.79546 .26506 L

Mfstroke

.70152 .19439 m

.70277 .19579 L

.70402 .19716 L

.70528 .1985 L

.70653 .19982 L

.70779 .20112 L

.70904 .2024 L

.7103 .20367 L

.71155 .20493 L

.7128 .20618 L

.71406 .20743 L

.71531 .20866 L

.71657 .2099 L

.71782 .21112 L

.71907 .21235 L

.72033 .21357 L

.72158 .2148 L

.72284 .21602 L

.72409 .21724 L

.72535 .21847 L

.7266 .2197 L

.72785 .22093 L

.72911 .22216 L

.73036 .2234 L

.73162 .22465 L

.73287 .22589 L

.73413 .22715 L

.73538 .22841 L

.73663 .22968 L

.73789 .23096 L

.73914 .23225 L

.7404 .23354 L

.74165 .23485 L

.74291 .23617 L

.74416 .2375 L

.74541 .23884 L

.74667 .2402 L

.74792 .24157 L

.74918 .24296 L

.75043 .24436 L

.75168 .24578 L

.75294 .24722 L

.75419 .24868 L

.75545 .25016 L

.7567 .25167 L

.75796 .25319 L

.75921 .25475 L

.76046 .25633 L

.76172 .25794 L

.76297 .25958 L

Mistroke

.76423 .26126 L

.76548 .26297 L

.76674 .26472 L

.76799 .26652 L

.76924 .26835 L

.7705 .27024 L

.77175 .27218 L

.77301 .27418 L

.77426 .27624 L

.77551 .27837 L

.77677 .28058 L

.77802 .28288 L

.77928 .28527 L

.78053 .28777 L

.78179 .29039 L

.78304 .29315 L

.78429 .29608 L

.78555 .2992 L

.7868 .30256 L

.78806 .30619 L

.78931 .31021 L

.79057 .3147 L

.79182 .31989 L

.79307 .32618 L

.79433 .33469 L

.79496 .34108 L

.79508 .34281 L

.79546 .35298 L

Mfstroke

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{567, 350.313},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.776525,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008g0001GPP10`40000100000800002008200000

P800P020P<30`<3L`:K:l00003<006H009T00<`00?l0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV

09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<003o03?o06Ko09Wo0<co

0?oo0000<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I

<c>I<fJI<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0

IYT0I/`0I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bI

I_nIIP3<IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0c

VC<cVFHcVITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<

VIW<VLc<VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`c

c?lcc01Vc3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03o

c3?oc6Koc9Woc<coc?ooc000oc<0ofH0oiT0ol`0ool0o`0coc<cofHcoiTcol`coolco`1Voc=VofIV

oiUVolaVoomVo`2Ioc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<o`3ooc?oofKooiWoolco

ooooo`0000410@820P<30`@410D51@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C

4a@D5?okl:2PY820P?l0003o0?oo0000ool0o`3oooooocoQ00<0hN40on7fh@00?n400`3Qh@3ohOKQ

000oh@030>7Q0?oQm^4003oQ00<0hN40on7fh@00?n400`3Qh@3ohOKQ000oh@030>7Q0?oQm^4003oQ

00<0hN40on7fh@00?n400`3Qh@3ohOKQ000oh@<0_n4H__oQ7n4003oQ00<0hN40^N46_QSQ2[kohAGQ

000oh@030>7Q0;GQ1;hXh@Jnon4?h@00?n400`3Qh@2ah@Bn<^45__oQ2^4003oQ00<0hN40[^43_S_Q

1Kkoh@GQ000oh@030>7Q0:cQ0[i3h@Bnon41h@00?n400`3Qh@2Yh@>nBN46__[Q000oh@030>7Q0:SQ

00>nhN40D>43__OQ000oh@030>7Q0:KQ0[iFh@Bnln4003oQ00<0hN40Y>42_UcQ1;k_h@00?n400`3Q

h@2Rh@:nH^43_^cQ000oh@030>7Q0:7Q00>nhN40IN44_^SQ000oh@<0X>400kkQh@1Zh@:ni^4003oQ

00<0hN40W^42_VoQ1;kRh@00?n400`3Qh@2Mh@03_^7Q07?Q0kkOh@00?n400`3Qh@2Lh@03_^7Q07OQ

0[kMh@00?n400`3Qh@2Kh@03_^7Q07[Q0kkJh@00?n400`3Qh@2Jh@03_^7Q07kQ0kkGh@00?n400`3Q

h@2Ih@03_^7Q08;Q0[kEh@00?n400`3Qh@2Hh@03_^7Q08GQ0[kCh@00?n400`3Qh@2Gh@03_^7Q08SQ

0[kAh@00?n400`3Qh@2Fh@03_^7Q08_Q0kk>h@00?n400`3Qh@2Eh@03_^7Q08oQ00>nhN40bn4003oQ

0`0ThAh?D^400kkQh@2Ah@>nb^4003oQ00<0hN407^463akQ20m9h@03_^7Q09GQ00>nhN40an4003oQ

00<0hN406^443bcQ1`m2h@03_^7Q09KQ00>nhN40a^4003oQ00<0hN405^443cOQ1Plkh@03_^7Q09SQ

0kk5h@00?n400`3Qh@0Bh@@?@N453cGQ00>nhN40W>400kkQh@32h@00?n400`3Qh@0?h@<?B^453boQ

00>nhN40W^400kkQh@31h@00?n400`3Qh@0=h@8?D^453b[Q00>nhN40Wn42_/7Q000oh@030>7Q00cQ

00<?hN40En443bGQ00>nhN40X^400kkQh@2nh@00?n400`3Qh@09h@<?G^453b3Q00>nhN40Xn400kkQ

h@2mh@00?n400`3Qh@08h@033n7Q06CQ10lKh@03_^7Q0:GQ0[jmh@00;n4500;Q00<0hN401^400`3Q

h@05h@<?Jn443aOQ00>nhN40Yn400kkQh@2jh@00<N401`3QhN40h@001n400`3Qh@04h@033n7Q073Q

1@lAh@03_^7Q0:WQ00>nhN40^N4002_Q0`03h@070>7Qh@3Q0007h@D00Pmhh@@?3>400kkQh@2[h@:n

^N40037Q00L0hN7Q0>4000OQ00D0hN7Q3`1nh@@?1n400kkQh@2^h@03_^7Q0;KQ000ah@070>7Qh@3Q

0007h@040>7Q3h?Q10l3h@03_^7Q0:oQ00>nhN40]N40033Q0P04h@030>7Q00KQ00<0h@l0R>433`03

_^7Q0;3Q00>nhN40]>4003oQ0Pn;h@03_^4?00<?[n42_[CQ000nh@033`3Q08_Q00>nhN400n423joQ

00>nhN40/N4003gQ00<?h@00Rn400kkQh@06h@@?Zn400kkQh@2ah@00>n423`;Q00<0hN40R>400kkQ

h@0;h@@?Z>400kkQh@2`h@00>^400`oQh@02h@030>7Q08SQ00>nhN403n443jGQ0[j`h@00>^400`oQ

h@02h@030>7Q08OQ00>nhN405>443j?Q00>nhN40[N4003WQ00<?hN400n400`3Qh@27h@03_^7Q01SQ

10nOh@03_^7Q0:gQ000hh@033n7Q00CQ00<0hN40Qn400kkQh@0Lh@<?WN400kkQh@2/h@00=n400`oQ

h@05h@<0Q^400kkQh@0Ph@@?Un4Q3i3Q000fh@033n7Q00KQ00<0hN40Q^400kkQh@0Th@<?SN483`?Q

00>nhN406^4<3hCQ000eh@033n7Q00OQ00<0hN40QN400kkQh@0Xh@@?Q>453`cQ00>nhN409N4:3g[Q

000eh@033n7Q00OQ00<0hN40QN400kkQh@0/h@@?O>443a;Q00>nhN40;^493g7Q000dh@033n7Q00SQ

00<0hN40Q>400kkQh@0ah@<?M^433aKQ00>nhN40=^483f[Q000ch@033n7Q00WQ00<0hN40Q>400kkQ

h@0dh@@?L>433aWQ00>nhN40?N483f;Q000bh@033n7Q00[Q00<0hN40Pn400kkQh@0ih@@?J^423agQ

00>nhN40A>483e[Q000ah@033n7Q00_Q00<0hN40Pn400kkQh@0mh@@?IN400`oQh@0Nh@03_^7Q04_Q

1`mCh@00<N400`oQh@0;h@030>7Q08?Q00>nhN40@N433f3Q0PlQh@03_^7Q05;Q1`m<h@00<>400`oQ

h@0<h@030>7Q08?Q00>nhN40A>433ecQ00<?hN408^400kkQh@1Hh@P?A>40033Q00<?hN403>400`3Q

h@22h@03_^7Q04SQ10mGh@033n7Q02CQ00>nhN40G^473ckQ000_h@033n7Q00gQ0`22h@03_^7Q04cQ

10mAh@8?:>400kkQh@1Th@L?=n4002kQ00<?hN403^400`3Qh@22h@03_^7Q053Q10m<h@033n7Q02WQ

00>nhN40J^473c3Q000]h@033n7Q00oQ00<0hN40PN400kkQh@1Eh@@?An400`oQh@0Zh@03_^7Q0:7Q

000]h@033n7Q00oQ00<0hN40PN400kkQh@1Ih@8?AN400`oQh@0[h@03_^7Q0:3Q000/h@033n7Q013Q

00<0hN40PN400kkQh@1Kh@@?@>400`oQh@0/h@03_^7Q0:3Q000/h@033n7Q013Q00<0hN40P>400kkQ

h@1Ph@@??>400`oQh@0]h@03_^7Q09oQ000[h@033n7Q017Q00<0hN40P>400kkQh@1Th@@?=n400`oQ

h@0_h@03_^7Q09kQ000[h@033n7Q017Q00<0hN40On400kkQh@1Yh@@?<n400`oQh@0_h@03_^7Q09kQ

000Zh@033n7Q01;Q00<0hN40On400kkQh@1]h@@?;n400`oQh@0`h@03_^7Q09gQ000Yh@033n7Q01?Q

00<0hN40On400kkQh@1ah@@?:n400`oQh@0`h@03_^7Q09gQ000Yh@033n7Q01?Q00<0hN40On400kkQ

h@1eh@@?9n400`oQh@0ah@03_^7Q09cQ000Yh@033n7Q01?Q00<0hN40O^400kkQh@1jh@<?9>400`oQ

h@0ah@03_^7Q09cQ000Xh@033n7Q01CQ0`1nh@03_^7Q07gQ10lPh@033n7Q03;Q00>nhN40Vn4002SQ

00<?hN405>400`3Qh@1nh@03_^7Q087Q10lLh@033n7Q03;Q00>nhN40Vn4002SQ00<?hN405>400`3Q

h@1nh@03_^7Q08GQ10lIh@033n7Q03;Q00>nhN40V^4002OQ00<?hN405N400`3Qh@1nh@03_^7Q08WQ

10lEh@033n7Q03;Q00>nhN40V^4002OQ00<?hN405N400`3Qh@1mh@03_^7Q08kQ10lAh@033n7Q03?Q

00>nhN40VN4002KQ00<?hN405^400`3Qh@1mh@03_^7Q09;Q1@l<h@033n7Q03?Q00>nhN40VN4002KQ

00<?hN405^400`3Qh@1mh@03_^7Q09OQ1@l6h@8?=^400kkQh@2Hh@009N400`oQh@0Gh@030>7Q07gQ

00>nhN40W>463cSQ00>nhN40V>4002GQ00<?hN405n400`3Qh@1lh@03_^7Q0=cQ00>nhN40Un4002CQ

00<?hN406>400`3Qh@1lh@03_^7Q0=cQ00>nhN40Un4002CQ00<?hN406>400`3Qh@1lh@03_^7Q0=gQ

00>nhN40U^4002CQ00<?hN406>400`3Qh@1kh@03_^7Q0=kQ00>nhN40U^4002CQ00<?hN406>4307_Q

00>nhN40g^400kkQh@2Fh@008n400`oQh@0Ih@030>7Q07_Q00>nhN40gn400kkQh@2Eh@008n400`oQ

h@0Ih@030>7Q07_Q00>nhN40gn400kkQh@2Eh@008n400`oQh@0Ih@030>7Q07[Q00>nhN40hN400kkQ

h@2Dh@008^400`oQh@0Jh@030>7Q07[Q00>nhN40]^48_R?Q00>nhN40U>4002;Q00<?hN406^400`3Q

h@1jh@03_^7Q0;GQ0[h6h@Jn7n400kkQh@2Ch@008N400`oQh@0Kh@030>7Q07[Q00>nhN40]N42_P_Q

1[hJh@03_^7Q09?Q000Qh@033n7Q01_Q00<0hN40N^400kkQh@2fh@03_^7Q00kQ1[hEh@03_^7Q09?Q

000Qh@033n7Q01_Q00<0hN40N^400kkQh@2fh@:n5>45_Q7Q00>nhN40Tn40023Q00<?hN407>400`3Q

h@1jh@03_^7Q0;OQ0[hGh@Fn3^400kkQh@2Bh@008>400`oQh@0Ch@030>7Q00KQ00<0hN40NN400kkQ

h@2ih@03_^7Q01[Q1;h:h@03_^7Q09;Q000Ph@033n7Q01;Q00<0h@001n400`3Qh@1ih@03_^7Q0;[Q

00>nhN407N45_PGQ00>nhN40T^40023Q00<?hN403N4300CQ00<0hN401N4507OQ00>nhN40^n400kkQ

h@0Ph@Fn0^400kkQh@2Ah@008>400`oQh@0Bh@802>400`3Qh@1ih@03_^7Q0;cQ00>nhN409>44_Y;Q

000Oh@033n7Q01?Q00<0hN401n400`3Qh@1ih@03_^7Q0;gQ00>nhN409^46_XgQ000Oh@033n7Q01?Q

0`07h@030>7Q07WQ00>nhN40_^400kkQh@0Uh@03_^7Q00;Q1Kj9h@007n400`oQh@0Mh@030>7Q07WQ

00>nhN40_n400kkQh@0Th@03_^7Q00OQ1Kj4h@007n400`oQh@0Mh@030>7Q07SQ00>nhN40`N400kkQ

h@0Th@03_^7Q00[Q1Kj0h@007^400`oQh@0Nh@030>7Q07SQ00>nhN40`N42_RGQ00>nhN403^45_WcQ

000Nh@033n7Q01kQ00<0hN40N>400kkQh@33h@03_^7Q02;Q00>nhN404n45_WOQ000Nh@033n7Q01kQ

00<0hN40N>400kkQh@33h@:n8n400kkQh@0Gh@FnLn4001gQ00<?hN407n400`3Qh@1gh@03_^7Q0<KQ

00>nhN408>400kkQh@0Lh@FnK^4001gQ00<?hN407n400`3Qh@1gh@03_^7Q0<KQ0[hRh@03_^7Q023Q

1;iZh@007N400`oQh@0Oh@<0Mn400kkQh@38h@03_^7Q01oQ00>nhN408n45_VKQ000Mh@033n7Q01oQ

00<0hN40Mn400kkQh@39h@03_^7Q01kQ00>nhN40:>45_V7Q000Mh@033n7Q01oQ00<0hN40Mn400kkQ

h@3:h@03_^7Q01gQ00>nhN40;N44_UgQ000Lh@033n7Q023Q00<0hN40Mn400kkQh@3;h@03_^7Q01cQ

0[hbh@FnF>4001cQ00<?hN408>400`3Qh@1gh@03_^7Q0<cQ00>nhN407>400kkQh@0eh@FnDn4001cQ

00<?hN408>400`3Qh@1gh@03_^7Q0<gQ00>nhN406n400kkQh@0ih@FnCn4001cQ00<?hN408>400`3Q

h@1fh@03_^7Q0<oQ00>nhN406^400kkQh@0nh@FnB^4001cQ00<?hN408>400`3Qh@1fh@03_^7Q0=3Q

00>nhN406N400kkQh@12h@FnA^4001cQ00<?hN408>400`3Qh@1fh@03_^7Q0=3Q0[hJh@03_^7Q04OQ

1Ki1h@007>400`oQh@0Ph@030>7Q07KQ00>nhN40d^400kkQh@0Hh@03_^7Q04[Q1[hlh@006n400`oQ

h@0Qh@030>7Q07KQ00>nhN40d^42_QWQ00>nhN40D>45_SOQ000Kh@033n7Q027Q00<0hN40M^400kkQ

h@3Dh@03_^7Q01KQ00>nhN40E>45_S?Q000Kh@033n7Q027Q0`1fh@03_^7Q0=CQ0[hGh@03_^7Q05WQ

0kh`h@006n400`oQh@0Qh@030>7Q07KQ00>nhN40e^400kkQh@0Dh@03_^7Q08cQ000Kh@033n7Q027Q

00<0hN40M^400kkQh@3Fh@03_^7Q01CQ00>nhN40S>4001_Q00<?hN408N400`3Qh@1fh@03_^7Q0=OQ

0[hDh@03_^7Q08cQ000Kh@033n7Q027Q00<0hN40M^400kkQh@3Hh@03_^7Q01;Q00>nhN40S>4001_Q

00<?hN408N400`3Qh@1fh@03_^7Q0=WQ00>nhN404N400kkQh@2<h@006n400`oQh@0Qh@030>7Q07KQ

00>nhN40f^400kkQh@0@h@03_^7Q08cQ000Kh@033n7Q027Q00<0hN40M^400kkQh@3Kh@03_^7Q013Q

00>nhN40Rn4001[Q00<?hN408^400`3Qh@1fh@03_^7Q0=cQ00>nhN403n400kkQh@2;h@006^400`oQ

h@0Rh@030>7Q07GQ00>nhN40gN400kkQh@0?h@03_^7Q08_Q000Jh@033n7Q02;Q00<0hN40MN400kkQ

h@3Nh@03_^7Q00kQ00>nhN40Rn4001[Q00<?hN408^400`3Qh@1eh@03_^7Q0=kQ0[h?h@03_^7Q08_Q

000Jh@033n7Q02;Q0`1eh@03_^7Q0>3Q00>nhN403>400kkQh@2;h@006^400`oQh@0Rh@030>7Q07GQ

00>nhN40h>400kkQh@0<h@03_^7Q08_Q000Jh@033n7Q02;Q00<0hN40MN400kkQh@3Qh@03_^7Q00_Q

00>nhN40Rn4001[Q00<?hN408^400`3Qh@1eh@03_^7Q0>;Q00>nhN402^400kkQh@2;h@006^400`oQ

h@0Rh@030>7Q07GQ00>nhN40h^400kkQh@09h@03_^7Q08cQ000Jh@033n7Q02;Q00<0hN40MN400kkQ

h@3Sh@03_^7Q00SQ00>nhN40S>4001[Q00<?hN408^400`3Qh@1eh@03_^7Q0>CQ00>nhN401n400kkQ

h@2<h@006^400`oQh@0Rh@030>7Q07GQ00>nhN40i>400kkQh@07h@03_^7Q08cQ000Ih@033n7Q02?Q

00<0hN40MN400kkQh@3Th@03_^7Q00OQ00>nhN40S>4001WQ00<?hN408n400`3Qh@0ih@D00^400`3Q

h@0bh@03_^7Q00;Q1@000n40000ih@D00^400`3Qh@0gh@D00^400`3Qh@0gh@D000?Q00006>400kkQ

h@06h@03_^7Q01KQ0`03h@030>7Q03SQ0`000n40000302cQ000Ih@033n7Q02?Q00<0hN40>n401`3Q

hN40h@00<n400kkQh@04h@070>7Qh@3Q000jh@030>7Q00;Q00<0hN40>N401`3QhN40h@00>^400`3Q

h@03h@030>7Q01KQ00>nhN401N400kkQh@0Fh@030>7Q00;Q00<0h@00>N400`3Qh@03h@030>7Q02cQ

000Ih@033n7Q02?Q00<0hN40>n400`3Qh@03h@030>7Q037Q00>nhN401>401`3QhN40h@00>^400`3Q

h@02h@030>7Q03WQ00L0hN7Q0>4003[Q00<0hN400^4201SQ00>nhN401N400kkQh@0Gh@070>7Qh@3Q

000jh@030>7Q00;Q00<0hN40;>4001WQ00<?hN408n4303_Q00@0hN7Q0P0dh@03_^7Q00CQ00@0hN7Q

0P0kh@030>7Q00?Q00<0hN40>>400`3Qh@02h@030>7Q03WQ00L0hN7Q0>4001WQ00>nhN400n400kkQ

h@0Hh@070>7Qh@3Q000jh@030>7Q00;Q00<0hN40;>4001WQ00<?hN408n400`3Qh@0kh@050>7Qh@00

=N400kkQh@04h@050>7Qh@00?>401`3QhN40h@00>^401`3QhN40h@00>^401`3QhN40h@006N400kkQ

h@03h@03_^7Q01OQ00<0h@000^400`3Q000ih@030>4000?Q00<0hN40;>4001WQ00<?hN408n400`3Q

h@0jh@800n4303?Q00>nhN400n4200CQ0P0ih@800n4303WQ0P04h@030>7Q03SQ0P04h@806^400kkQ

h@02h@03_^7Q01SQ00<0hN400^400`3Qh@0ih@040>7Qh@80;^4001WQ00<?hN408n400`3Qh@1eh@03

_^7Q0>SQ00>nhN400^400kkQh@2=h@006N400`oQh@0Sh@030>7Q07GQ00>nhN40j>400kkQh@02h@03

_^7Q08gQ000Ih@033n7Q02?Q00<0hN40MN400kkQh@3Yh@05_^7QhKh0Sn4001WQ00<?hN408n400`3Q

h@1eh@03_^7Q0>[Q00BnhN6nSn4001WQ00<?hN408n400`3Qh@1eh@03_^7Q0>[Q00>nhKh0T>4001WQ

00<?hN408n400`3Qh@1eh@03_^7Q0>[Q00>nhKh0T>4001WQ00<?hN408n400`3Qh@1eh@03_^7Q0>[Q

00>nhKh0O>44013Q000Ih@033n7Q02?Q00<0hN40MN400kkQh@3[h@03_^7Q07_Q0`0Ah@003>4=0003

3`0009/000>n0000j`000kh0001/017Q00<0hN403n4001SQ00<03n402^400`3Qh@0:h@030>7Q00[Q

00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Q

h@0:h@030>7Q00[Q00@0hN6n2N400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q

00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Q

h@0:h@030>7Q00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN401>400kkQh@03h@030>7Q00[Q

00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN406n42017Q

000Hh@0300oQ00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q

00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Qh@0:h@040>7Q_PWQ00<0hN402^400`3Q

h@0:h@030>7Q00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q

00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Q

h@0:h@030>7Q00CQ00>nhN400n400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q

00<0hN402^400`3Qh@0:h@030>7Q02kQ000Ih@033n7Q02?Q00<0hN40?^400`3Qh@0dh@03_^7Q00OQ

00<0hN40?^400`3Qh@0nh@030>7Q03kQ00<0hN407N400kkQ_P0Nh@030>7Q03kQ00<0hN40;^4001WQ

00<?hN408n400`3Qh@0nh@030>7Q03CQ00>nhN401n400`3Qh@0nh@030>7Q03kQ00<0hN40?^400`3Q

h@0Mh@03_^6n01kQ00<0hN40?^400`3Qh@0^h@006N400`oQh@0Sh@030>7Q07GQ00>nhN40j^401;kQ

hKj?h@006N400`oQh@0Sh@030>7Q07GQ00>nhN40jN401KkQhN6n08oQ000Ih@033n7Q02?Q00<0hN40

MN400kkQh@3Yh@05_^7QhKh0Sn4001WQ00<?hN408n400`3Qh@1eh@03_^7Q0>SQ00>nhN400^400kkQ

h@2=h@006N400`oQh@0Sh@030>7Q07GQ00>nhN40j>400kkQh@02h@03_^7Q08gQ000Ih@033n7Q02?Q

00<0hN40MN400kkQh@3Xh@03_^7Q00;Q00>nhN40SN4001WQ00<?hN408n400`3Qh@1eh@03_^7Q0>OQ

00>nhN400n400kkQh@2=h@006N400`oQh@0Sh@<0MN400kkQh@3Vh@03_^7Q00GQ00>nhN40S>4001WQ

00<?hN408n400`3Qh@1eh@03_^7Q0>KQ00>nhN401N400kkQh@2<h@006N400`oQh@0Sh@030>7Q07GQ

00>nhN40i^400kkQh@05h@03_^7Q08cQ000Ih@033n7Q02?Q00<0hN40MN400kkQh@3Uh@03_^7Q00KQ

00>nhN40S>4001WQ00<?hN408n400`3Qh@1eh@03_^7Q0>CQ00>nhN401n400kkQh@2<h@006^400`oQ

h@0Rh@030>7Q07GQ00>nhN40i>400kkQh@07h@03_^7Q08cQ000Jh@033n7Q02;Q00<0hN40MN400kkQ

h@3Sh@03_^7Q00SQ00>nhN40S>4001[Q00<?hN408^400`3Qh@1eh@03_^7Q0>;Q00>nhN402N400kkQ

h@2<h@006^400`oQh@0Rh@030>7Q07GQ00>nhN40h^400kkQh@09h@03_^7Q08cQ000Jh@033n7Q02;Q

00<0hN40MN400kkQh@3Qh@03_^7Q00_Q00>nhN40Rn4001[Q00<?hN408^400`3Qh@1eh@03_^7Q0>3Q

00>nhN403>400kkQh@2;h@006^400`oQh@0Rh@030>7Q07GQ00>nhN40h>400kkQh@0<h@03_^7Q08_Q

000Jh@033n7Q02;Q0`1eh@03_^7Q0=oQ00>nhN403N400kkQh@2;h@006^400`oQh@0Rh@030>7Q07GQ

00>nhN40g^400kkQh@0>h@03_^7Q08_Q000Jh@033n7Q02;Q00<0hN40MN400kkQh@3Nh@03_^7Q00kQ

00>nhN40Rn4001[Q00<?hN408^400`3Qh@1eh@03_^7Q0=gQ00>nhN403n400kkQh@2;h@006n400`oQ

h@0Qh@030>7Q07KQ00>nhN40fn42_Q7Q00>nhN40Rn4001_Q00<?hN408N400`3Qh@1fh@03_^7Q0=[Q

00>nhN404N400kkQh@2;h@006n400`oQh@0Qh@030>7Q07KQ00>nhN40f^400kkQh@0@h@03_^7Q08cQ

000Kh@033n7Q027Q00<0hN40M^400kkQh@3Ih@03_^7Q017Q00>nhN40S>4001_Q00<?hN408N400`3Q

h@1fh@03_^7Q0=SQ00>nhN404^400kkQh@2<h@006n400`oQh@0Qh@030>7Q07KQ00>nhN40en400kkQ

h@0Ch@03_^7Q08cQ000Kh@033n7Q027Q00<0hN40M^400kkQh@3Fh@03_^7Q01CQ00>nhN40S>4001_Q

00<?hN408N400`3Qh@1fh@03_^7Q0=GQ0[hFh@03_^7Q08cQ000Kh@033n7Q027Q0`1fh@03_^7Q0=CQ

00>nhN405^400kkQh@1Gh@Fn<>4001_Q00<?hN408N400`3Qh@1fh@03_^7Q0=?Q0[hHh@03_^7Q05?Q

1Khdh@007>400`oQh@0Ph@030>7Q07KQ00>nhN40d^400kkQh@0Hh@03_^7Q04kQ1Khih@007>400`oQ

h@0Ph@030>7Q07KQ00>nhN40dN42_Q[Q00>nhN40B^45_SgQ000Lh@033n7Q023Q00<0hN40M^400kkQ

h@3@h@03_^7Q01WQ00>nhN40A^45_T;Q000Lh@033n7Q023Q00<0hN40M^400kkQh@3?h@:n6n400kkQ

h@11h@FnAn4001cQ00<?hN408>400`3Qh@1fh@03_^7Q0<oQ00>nhN406^400kkQh@0lh@FnC>4001cQ

00<?hN408>400`3Qh@1gh@03_^7Q0<cQ0[hMh@03_^7Q03SQ1Ki@h@007>400`oQh@0Ph@030>7Q07OQ

00>nhN40c>400kkQh@0Lh@03_^7Q03?Q1KiEh@007>400`oQh@0Ph@030>7Q07OQ00>nhN40b^42_QkQ

0[hah@FnFN4001gQ00<?hN407n400`3Qh@1gh@03_^7Q0<[Q00>nhN407N400kkQh@0[h@FnG^4001gQ

00<?hN407n4307OQ00>nhN40b>42_R3Q00>nhN409n45_V;Q000Mh@033n7Q01oQ00<0hN40Mn400kkQ

h@38h@03_^7Q01oQ00>nhN408n44_VOQ000Mh@033n7Q01oQ00<0hN40Mn400kkQh@36h@:n8N42_R3Q

1Ki[h@007N400`oQh@0Oh@030>7Q07OQ00>nhN40aN42_R;Q00>nhN406n45_VoQ000Nh@033n7Q01kQ

00<0hN40N>400kkQh@33h@03_^7Q02;Q00>nhN405^45_WCQ000Nh@033n7Q01kQ00<0hN40N>400kkQ

h@32h@:n9>400kkQh@0Bh@FnN>4001oQ00<?hN407N400`3Qh@1hh@03_^7Q0<7Q00>nhN409>400kkQ

h@0=h@FnON4001oQ00<?hN407N400`3Qh@1hh@03_^7Q0<3Q0[hVh@03_^7Q00WQ1;j2h@007n400`oQ

h@0Mh@030>7Q07WQ00>nhN40_n400kkQh@0Th@03_^7Q00KQ1Kj5h@007n400`oQh@0Mh@030>7Q07WQ

00>nhN40_N42_ROQ00BnhN7Q1Kj:h@007n400`oQh@0Dh@030>7Q00KQ00<0hN40NN400kkQh@2mh@03

_^7Q02KQ1;j?h@008>400`oQh@0Bh@030>4000OQ00<0hN40NN400kkQh@2kh@:n9N45_Y;Q000Ph@03

3n7Q01CQ00<0hN401N4507OQ00>nhN40^n400kkQh@0Oh@Fn0n400kkQh@2Ah@008>400`oQh@0Bh@80

2>400`3Qh@1ih@03_^7Q0;[Q00>nhN407>44_POQ00>nhN40T^40023Q00<?hN404^400`3Qh@07h@03

0>7Q07[Q00>nhN40^>400kkQh@0Ih@Fn2^400kkQh@2Bh@008>400`oQh@0Bh@<01n400`3Qh@1jh@03

_^7Q0;OQ00>nhN405N45_PoQ00>nhN40T^40027Q00<?hN406n400`3Qh@1jh@03_^7Q0;KQ0[hBh@Fn

4n400kkQh@2Ch@008N400`oQh@0Kh@030>7Q07[Q00>nhN40]^400kkQh@0=h@Fn5n400kkQh@2Ch@00

8N400`oQh@0Kh@030>7Q07[Q00>nhN40]N42_P[Q1[hKh@03_^7Q09?Q000Rh@033n7Q01[Q00<0hN40

N^400kkQh@2eh@:n1>47_R3Q00>nhN40Tn4002;Q00<?hN406^400`3Qh@1jh@03_^7Q0;KQ1[hUh@03

_^7Q09CQ000Sh@033n7Q01WQ00<0hN40Nn400kkQh@3Ph@03_^7Q09CQ000Sh@033n7Q01WQ00<0hN40

Nn400kkQh@3Oh@03_^7Q09GQ000Sh@033n7Q01WQ00<0hN40Nn400kkQh@3Oh@03_^7Q09GQ000Th@03

3n7Q01SQ0`1kh@03_^7Q0=kQ00>nhN40U^4002CQ00<?hN406>400`3Qh@1kh@03_^7Q0=kQ00>nhN40

U^4002CQ00<?hN406>400`3Qh@1lh@03_^7Q0=cQ00>nhN40Un4002GQ00<?hN405n400`3Qh@1lh@03

_^7Q0=cQ00>nhN40Un4002GQ00<?hN405n400`3Qh@1mh@03_^7Q0=_Q00>nhN40Un4002GQ00<?hN40

5n400`3Qh@1mh@03_^7Q09_Q1`lhh@03_^7Q09SQ000Vh@033n7Q01KQ00<0hN40ON400kkQh@2Fh@D?

1n423cKQ00>nhN40V>4002KQ00<?hN405^400`3Qh@1mh@03_^7Q097Q1@l=h@033n7Q03?Q00>nhN40

VN4002OQ00<?hN405N400`3Qh@1mh@03_^7Q08gQ10lBh@033n7Q03?Q00>nhN40VN4002OQ00<?hN40

5N400`3Qh@1nh@03_^7Q08SQ10lFh@033n7Q03;Q00>nhN40V^4002SQ00<?hN405>400`3Qh@1nh@03

_^7Q08CQ10lJh@033n7Q037Q00>nhN40Vn4002SQ00<?hN405>400`3Qh@1nh@03_^7Q083Q10lMh@03

3n7Q03;Q00>nhN40Vn4002SQ00<?hN405>4307kQ00>nhN40O>443b7Q00<?hN40<^400kkQh@2Kh@00

:N400`oQh@0Ch@030>7Q07kQ00>nhN40NN433bGQ00<?hN40<N400kkQh@2Lh@00:N400`oQh@0Ch@03

0>7Q07oQ00>nhN40M>443bSQ00<?hN40<N400kkQh@2Lh@00:^400`oQh@0Bh@030>7Q07oQ00>nhN40

L>443bcQ00<?hN40<>400kkQh@2Mh@00:^400`oQh@0Bh@030>7Q07oQ00>nhN40K>443c3Q00<?hN40

<>400kkQh@2Mh@00:n400`oQh@0Ah@030>7Q083Q00>nhN40In443cCQ00<?hN40;n400kkQh@2Nh@00

;>400`oQh@0@h@030>7Q083Q00>nhN40Hn443cWQ00<?hN40;N400kkQh@2Oh@00;>400`oQh@0@h@03

0>7Q087Q00>nhN40Gn433cgQ00<?hN40;>400kkQh@2Ph@00;N400`oQh@0?h@030>7Q087Q00>nhN40

G>433d7Q00<?hN40:n400kkQh@2Ph@00;N400`oQh@0?h@030>7Q087Q00>nhN40F>443dCQ00<?hN40

:^400kkQh@2Qh@00;N400`oQh@0?h@030>7Q08;Q00>nhN40Dn443dWQ00<?hN40:N400kkQh@1_h@8?

<>4002kQ00<?hN403^4308;Q00>nhN40Cn443dgQ00<?hN40:>400kkQh@1Yh@L?<^4002oQ00<?hN40

3N400`3Qh@22h@03_^7Q04_Q10mBh@033n7Q02KQ00>nhN40Hn473cWQ000`h@033n7Q00cQ00<0hN40

P^400kkQh@18h@<?En423bGQ00>nhN40GN473d3Q000`h@033n7Q00cQ00<0hN40Pn400kkQh@13h@@?

G>400`oQh@0Rh@03_^7Q05KQ20m6h@00<N400`oQh@0;h@030>7Q08?Q00>nhN40@>433f7Q00<?hN40

8>400kkQh@1@h@L?C^40037Q00<?hN402n400`3Qh@23h@03_^7Q03cQ10mUh@<?7n400kkQh@18h@P?

EN4003;Q00<?hN402^400`3Qh@23h@03_^7Q03SQ10m/h@8?7>400kkQh@12h@L?GN4003?Q0Pl:h@03

0>7Q08CQ00>nhN40=>433g7Q0`lIh@03_^7Q03_Q20mTh@00=>400`oQh@08h@030>7Q08CQ00>nhN40

<>443gOQ10lDh@03_^7Q03CQ2@m[h@00=N400`oQh@07h@030>7Q08GQ00>nhN40:n443gkQ1@l?h@03

_^7Q02cQ2@mdh@00=N400`oQh@07h@030>7Q08GQ00>nhN409n443hKQ1Pl:h@03_^7Q02;Q2`mlh@00

=^400`oQh@06h@030>7Q08KQ00>nhN408n433hoQ2`lGh@h?Qn4003OQ00<?hN401N4308KQ00>nhN40

8>433i_Q00>n3`l05PnEh@00>>400`oQh@04h@030>7Q08OQ00>nhN406n443igQ00>nhN40[>4003WQ

00<?hN400n400`3Qh@27h@03_^7Q01OQ10nPh@03_^7Q0:gQ000jh@033n7Q00;Q00<0hN40Qn400kkQ

h@0Ch@@?Xn400kkQh@2^h@00>n401@oQhN4008[Q00>nhN403^443jOQ00>nhN40[^4003cQ0Pl00n40

h@29h@03_^7Q00[Q10nYh@:n/N4003gQ00<?h@00Rn400kkQh@07h@8?[>400kkQh@2ah@00?^400`l0

h@2;h@03_^7Q00;Q10n]h@03_^7Q0;;Q000oh@033n7Q08[Q00>n3`l00Pnah@03_^7Q0;;Q000oh@03

00l?08OQ10l00kkQh@2`h@:n]N4002oQ1@02h@030>7Q00KQ00@0hN4?P^443`CQ00>nhN40[n400kkQ

h@2eh@00<N401`3QhN40h@001n401@3QhN4?07gQ10l8h@03_^7Q0:kQ00>nhN40]^40037Q00L0hN7Q

0>4000OQ1@033gKQ10l=h@03_^7Q0:cQ00>nhN40]n40037Q00L0hN7Q0>4000OQ00<0hN401N400`oQ

h@1_h@@?4^400kkQh@2Yh@:n^^40037Q00L0hN7Q0>4000OQ00<0hN401^400`oQh@1Yh@D?5n400kkQ

h@2Wh@03_^7Q0;[Q000`h@801>400`3Qh@06h@030>7Q00OQ0`mTh@@?7>400kkQh@2Vh@03_^7Q0;_Q

000oh@030>7Q00[Q00<?hN40GN443b7Q00>nhN40Xn42_[kQ000oh@030>7Q00_Q0`mGh@D?9N400kkQ

h@2Rh@03_^7Q0;kQ000oh@030>7Q00kQ0Pm@h@D?:n400kkQh@2Ph@03_^7Q0;oQ000oh@030>7Q013Q

0`m8h@D?<>400kkQh@2Mh@>n`^4003oQ00<0hN404n433d3Q1@lfh@03_^7Q09_Q00>nhN40`n4003oQ

00<0hN405^443cGQ1`llh@03_^7Q09WQ00>nhN40a>4003oQ00<0hN406^453b[Q1Pm4h@03_^7Q09KQ

0[k7h@00?n4301oQ20lGh@/?Bn400kkQh@2Ch@:nbN4003oQ00<0hN409n4G3eKQ00>nhN40TN42_/_Q

000oh@030>7Q09GQ00>nhN40S^42_/gQ000oh@030>7Q09KQ0[j<h@:ncn4003oQ00<0hN40Un400kkQ

h@28h@:ndN4003oQ00<0hN40V>400kkQh@24h@>ndn4003oQ00<0hN40VN400kkQh@21h@:ne^4003oQ

00<0hN40V^42_WkQ0kkHh@00?n400`3Qh@2Kh@03_^7Q07WQ0kkKh@00?n400`3Qh@2Lh@03_^7Q07KQ

0[kNh@00?n400`3Qh@2Mh@03_^7Q07;Q0kkPh@00?n400`3Qh@2Nh@03_^7Q06oQ0[kSh@00?n4309oQ

0[i[h@BniN4003oQ00<0hN40XN400kkQh@1Uh@>njN4003oQ00<0hN40X^43_V3Q1;k/h@00?n400`3Q

h@2Uh@03_^7Q05WQ1;k`h@00?n400`3Qh@2Vh@03_^7Q05CQ1;kdh@00?n400`3Qh@2Wh@>nD>43__SQ

000oh@030>7Q0:[Q0ki7h@Jnnn4003oQ00<0hN40[N42_T7Q1;koh@;Q000oh@030>7Q0:oQ0khih@Fn

on46h@00?n400`3Qh@2bh@:n<N46__oQ2n4003oQ00<0hN40]>46_RCQ1kkohA7Q000oh@030>7Q0;[Q

1khDh@Vnon4Hh@00?n430<7Q5;kohB7Q000oh@030>7Q0?oQm^4003oQ00<0hN40on7fh@00?n400`3Q

h@3ohOKQ000oh@030>7Q0?oQm^4003oQ00<0hN40on7fh@00?n400`3Qh@3ohOKQ000oh@030>7Q0?oQ

m^4003oQ00<0hN40on7fh@00on7ohCWQ003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQ

on4ih@00on7ohCWQ003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?cQ0P000n400006h@@0

1^4200?Q0P04h@030>7Q00;Q00<0hN40on4Dh@00oN400`3Q000Ch@030>7Q00;Q00<0hN401^400`3Q

h@3ohACQ003mh@<01n4400OQ00<0hN400^4200SQ00<0hN40on4Dh@00oN40103Q000Bh@060>7Q0>40

2N400`3Qh@3ohA?Q000mh@80_^400`3Qh@0Ah@030>4000;Q00<0h@001n400`3Q003ohAGQ000nh@03

0>7Q0;_Q0P0Dh@030>7Q00;Q0P07h@<0on4Eh@00?>4300;Q00<0hN40on7dh@00>n40203Qh@3Q0>40

on7eh@00>n40203Qh@3Q0>40on7eh@00?>430004h@3Q0?oQmN40043Q00<0h@00on7eh@00@N400`3Q

h@3ohOCQ003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQon4ih@00\

\>"],

  ImageRangeCache->{{{0, 566}, {349.313, 0}} -> {13.0192, -13.6511, 0.0153819,

   0.0852246}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-1.92154 0.144959 0.309017 0.0224991 [

[.25284 .29652 -6 -9 ]

[.25284 .29652 6 0 ]

[.3978 .29652 -6 -9 ]

[.3978 .29652 6 0 ]

[.54276 .29652 -6 -9 ]

[.54276 .29652 6 0 ]

[.68772 .29652 -6 -9 ]

[.68772 .29652 6 0 ]

[.83268 .29652 -6 -9 ]

[.83268 .29652 6 0 ]

[.97764 .29652 -6 -9 ]

[.97764 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.09539 .08403 -18 -4.5 ]

[.09539 .08403 0 4.5 ]

[.09539 .19652 -12 -4.5 ]

[.09539 .19652 0 4.5 ]

[.09539 .42151 -6 -4.5 ]

[.09539 .42151 0 4.5 ]

[.09539 .53401 -12 -4.5 ]

[.09539 .53401 0 4.5 ]

[.10789 .64303 -7 0 ]

[.10789 .64303 7 16 ]

[.5 .63053 -12 0 ]

[.5 .63053 12 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.25284 .30902 m

.25284 .31527 L

s

[(15)] .25284 .29652 0 1 Mshowa

.3978 .30902 m

.3978 .31527 L

s

[(16)] .3978 .29652 0 1 Mshowa

.54276 .30902 m

.54276 .31527 L

s

[(17)] .54276 .29652 0 1 Mshowa

.68772 .30902 m

.68772 .31527 L

s

[(18)] .68772 .29652 0 1 Mshowa

.83268 .30902 m

.83268 .31527 L

s

[(19)] .83268 .29652 0 1 Mshowa

.97764 .30902 m

.97764 .31527 L

s

[(20)] .97764 .29652 0 1 Mshowa

.125 Mabswid

.13688 .30902 m

.13688 .31277 L

s

.16587 .30902 m

.16587 .31277 L

s

.19486 .30902 m

.19486 .31277 L

s

.22385 .30902 m

.22385 .31277 L

s

.28184 .30902 m

.28184 .31277 L

s

.31083 .30902 m

.31083 .31277 L

s

.33982 .30902 m

.33982 .31277 L

s

.36881 .30902 m

.36881 .31277 L

s

.4268 .30902 m

.4268 .31277 L

s

.45579 .30902 m

.45579 .31277 L

s

.48478 .30902 m

.48478 .31277 L

s

.51377 .30902 m

.51377 .31277 L

s

.57175 .30902 m

.57175 .31277 L

s

.60075 .30902 m

.60075 .31277 L

s

.62974 .30902 m

.62974 .31277 L

s

.65873 .30902 m

.65873 .31277 L

s

.71671 .30902 m

.71671 .31277 L

s

.74571 .30902 m

.74571 .31277 L

s

.7747 .30902 m

.7747 .31277 L

s

.80369 .30902 m

.80369 .31277 L

s

.86167 .30902 m

.86167 .31277 L

s

.89066 .30902 m

.89066 .31277 L

s

.91966 .30902 m

.91966 .31277 L

s

.94865 .30902 m

.94865 .31277 L

s

.07889 .30902 m

.07889 .31277 L

s

.0499 .30902 m

.0499 .31277 L

s

.02091 .30902 m

.02091 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.10789 .08403 m

.11414 .08403 L

s

[(-10)] .09539 .08403 1 0 Mshowa

.10789 .19652 m

.11414 .19652 L

s

[(-5)] .09539 .19652 1 0 Mshowa

.10789 .42151 m

.11414 .42151 L

s

[(5)] .09539 .42151 1 0 Mshowa

.10789 .53401 m

.11414 .53401 L

s

[(10)] .09539 .53401 1 0 Mshowa

.125 Mabswid

.10789 .10652 m

.11164 .10652 L

s

.10789 .12902 m

.11164 .12902 L

s

.10789 .15152 m

.11164 .15152 L

s

.10789 .17402 m

.11164 .17402 L

s

.10789 .21902 m

.11164 .21902 L

s

.10789 .24152 m

.11164 .24152 L

s

.10789 .26402 m

.11164 .26402 L

s

.10789 .28652 m

.11164 .28652 L

s

.10789 .33152 m

.11164 .33152 L

s

.10789 .35402 m

.11164 .35402 L

s

.10789 .37651 m

.11164 .37651 L

s

.10789 .39901 m

.11164 .39901 L

s

.10789 .44401 m

.11164 .44401 L

s

.10789 .46651 m

.11164 .46651 L

s

.10789 .48901 m

.11164 .48901 L

s

.10789 .51151 m

.11164 .51151 L

s

.10789 .06153 m

.11164 .06153 L

s

.10789 .03903 m

.11164 .03903 L

s

.10789 .01653 m

.11164 .01653 L

s

.10789 .55651 m

.11164 .55651 L

s

.10789 .57901 m

.11164 .57901 L

s

.10789 .60151 m

.11164 .60151 L

s

.25 Mabswid

.10789 0 m

.10789 .61803 L

s

gsave

.10789 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -73 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(k) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(40) show

83.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 .4 1 r

.5 Mabswid

.75875 .56902 m

.7573 .56953 L

.75585 .57004 L

.7544 .57054 L

.75295 .57103 L

.7515 .57151 L

.75005 .57199 L

.7486 .57247 L

.74716 .57294 L

.74571 .5734 L

.74426 .57386 L

.74281 .57432 L

.74136 .57477 L

.73991 .57521 L

.73846 .57565 L

.73701 .57609 L

.73556 .57652 L

.73411 .57694 L

.73266 .57737 L

.73121 .57778 L

.72976 .5782 L

.72831 .57861 L

.72686 .57901 L

.72541 .57941 L

.72396 .57981 L

.72251 .5802 L

.72106 .58059 L

.71961 .58098 L

.71816 .58136 L

.71671 .58174 L

.71526 .58212 L

.71381 .58249 L

.71237 .58286 L

.71092 .58322 L

.70947 .58358 L

.70802 .58394 L

.70657 .58429 L

.70512 .58464 L

.70367 .58499 L

.70222 .58534 L

.70077 .58568 L

.69932 .58602 L

.69787 .58636 L

.69642 .58669 L

.69497 .58702 L

.69352 .58735 L

.69207 .58767 L

.69062 .58799 L

.68917 .58831 L

.68772 .58863 L

Mistroke

.68627 .58894 L

.68482 .58925 L

.68337 .58956 L

.68192 .58986 L

.68047 .59016 L

.67902 .59046 L

.67757 .59076 L

.67613 .59105 L

.67468 .59134 L

.67323 .59163 L

.67178 .59191 L

.67033 .5922 L

.66888 .59247 L

.66743 .59275 L

.66598 .59303 L

.66453 .5933 L

.66308 .59357 L

.66163 .59383 L

.66018 .59409 L

.65873 .59435 L

.65728 .59461 L

.65583 .59487 L

.65438 .59512 L

.65293 .59537 L

.65148 .59561 L

.65003 .59585 L

.64858 .59609 L

.64713 .59633 L

.64568 .59656 L

.64423 .59679 L

.64278 .59702 L

.64134 .59724 L

.63989 .59747 L

.63844 .59769 L

.63699 .5979 L

.63554 .59811 L

.63409 .59832 L

.63264 .59852 L

.63119 .59873 L

.62974 .59892 L

.62829 .59912 L

.62684 .59931 L

.62539 .5995 L

.62394 .59968 L

.62249 .59987 L

.62104 .60004 L

.61959 .60021 L

.61814 .60038 L

.61669 .60055 L

.61524 .60071 L

Mistroke

.61379 .60087 L

.61234 .60102 L

.61089 .60117 L

.60944 .60131 L

.60799 .60145 L

.60654 .60159 L

.6051 .60172 L

.60365 .60185 L

.6022 .60197 L

.60075 .60209 L

.5993 .6022 L

.59785 .60231 L

.5964 .60241 L

.59495 .60251 L

.5935 .60261 L

.59205 .6027 L

.5906 .60278 L

.58915 .60286 L

.5877 .60293 L

.58625 .60299 L

.5848 .60305 L

.58335 .60311 L

.5819 .60315 L

.58045 .6032 L

.579 .60324 L

.57755 .60326 L

.5761 .60329 L

.57465 .60331 L

.5732 .60332 L

.57175 .60332 L

.57031 .60332 L

.56886 .60331 L

.56741 .60329 L

.56596 .60326 L

.56451 .60323 L

.56306 .60319 L

.56161 .60314 L

.56016 .60309 L

.55871 .60303 L

.55726 .60295 L

.55581 .60287 L

.55436 .60279 L

.55291 .60269 L

.55146 .60258 L

.55001 .60247 L

.54856 .60234 L

.54711 .60221 L

.54566 .60206 L

.54421 .60191 L

.54276 .60175 L

Mistroke

.54131 .60157 L

.53986 .60139 L

.53841 .60119 L

.53696 .60099 L

.53551 .60077 L

.53407 .60054 L

.53262 .6003 L

.53117 .60005 L

.52972 .59979 L

.52827 .59951 L

.52682 .59922 L

.52537 .59892 L

.52392 .59861 L

.52247 .59828 L

.52102 .59794 L

.51957 .59759 L

.51812 .59722 L

.51667 .59683 L

.51522 .59644 L

.51377 .59602 L

.51232 .59559 L

.51087 .59515 L

.50942 .59469 L

.50797 .59422 L

.50652 .59372 L

.50507 .59321 L

.50362 .59269 L

.50217 .59214 L

.50072 .59158 L

.49928 .591 L

.49783 .5904 L

.49638 .58978 L

.49493 .58914 L

.49348 .58848 L

.49203 .58779 L

.49058 .58709 L

.48913 .58637 L

.48768 .58563 L

.48623 .58486 L

.48478 .58407 L

.48333 .58325 L

.48188 .58241 L

.48043 .58155 L

.47898 .58066 L

.47753 .57975 L

.47608 .57881 L

.47463 .57784 L

.47318 .57684 L

.47173 .57582 L

.47028 .57477 L

Mistroke

.46883 .57368 L

.46738 .57257 L

.46593 .57142 L

.46449 .57025 L

.46304 .56904 L

.46159 .56779 L

.46014 .56651 L

.45869 .5652 L

.45724 .56385 L

.45579 .56246 L

.45434 .56103 L

.45289 .55956 L

.45144 .55806 L

.44999 .5565 L

.44854 .55491 L

.44709 .55327 L

.44564 .55159 L

.44419 .54985 L

.44274 .54807 L

.44129 .54624 L

.43984 .54436 L

.43839 .54242 L

.43694 .54043 L

.43549 .53838 L

.43404 .53626 L

.43259 .53409 L

.43114 .53185 L

.42969 .52955 L

.42825 .52717 L

.4268 .52472 L

.42535 .5222 L

.4239 .5196 L

.42245 .51691 L

.421 .51414 L

.41955 .51128 L

.4181 .50832 L

.41665 .50527 L

.4152 .50211 L

.41375 .49883 L

.4123 .49544 L

.41085 .49193 L

.4094 .48828 L

.40795 .48449 L

.4065 .48054 L

.40505 .47643 L

.4036 .47215 L

.40215 .46767 L

.4007 .46299 L

.39925 .45807 L

.3978 .4529 L

Mistroke

.39635 .44744 L

.3949 .44166 L

.39346 .43552 L

.39201 .42895 L

.39056 .42188 L

.38911 .41421 L

.38766 .4058 L

.38621 .39643 L

.38476 .38575 L

.38318 .35986 L

.38084 .33444 L

.38005 .30902 L

Mfstroke

.75875 .04901 m

.7573 .0485 L

.75585 .048 L

.7544 .0475 L

.75295 .04701 L

.7515 .04652 L

.75005 .04604 L

.7486 .04557 L

.74716 .0451 L

.74571 .04463 L

.74426 .04417 L

.74281 .04372 L

.74136 .04327 L

.73991 .04282 L

.73846 .04238 L

.73701 .04195 L

.73556 .04152 L

.73411 .04109 L

.73266 .04067 L

.73121 .04025 L

.72976 .03984 L

.72831 .03943 L

.72686 .03902 L

.72541 .03862 L

.72396 .03822 L

.72251 .03783 L

.72106 .03744 L

.71961 .03705 L

.71816 .03667 L

.71671 .03629 L

.71526 .03592 L

.71381 .03555 L

.71237 .03518 L

.71092 .03481 L

.70947 .03445 L

.70802 .03409 L

.70657 .03374 L

.70512 .03339 L

.70367 .03304 L

.70222 .03269 L

.70077 .03235 L

.69932 .03201 L

.69787 .03168 L

.69642 .03134 L

.69497 .03101 L

.69352 .03069 L

.69207 .03036 L

.69062 .03004 L

.68917 .02972 L

.68772 .02941 L

Mistroke

.68627 .02909 L

.68482 .02878 L

.68337 .02848 L

.68192 .02817 L

.68047 .02787 L

.67902 .02757 L

.67757 .02728 L

.67613 .02698 L

.67468 .02669 L

.67323 .02641 L

.67178 .02612 L

.67033 .02584 L

.66888 .02556 L

.66743 .02528 L

.66598 .02501 L

.66453 .02474 L

.66308 .02447 L

.66163 .0242 L

.66018 .02394 L

.65873 .02368 L

.65728 .02342 L

.65583 .02317 L

.65438 .02292 L

.65293 .02267 L

.65148 .02242 L

.65003 .02218 L

.64858 .02194 L

.64713 .02171 L

.64568 .02147 L

.64423 .02124 L

.64278 .02101 L

.64134 .02079 L

.63989 .02057 L

.63844 .02035 L

.63699 .02014 L

.63554 .01992 L

.63409 .01971 L

.63264 .01951 L

.63119 .01931 L

.62974 .01911 L

.62829 .01891 L

.62684 .01872 L

.62539 .01854 L

.62394 .01835 L

.62249 .01817 L

.62104 .01799 L

.61959 .01782 L

.61814 .01765 L

.61669 .01748 L

.61524 .01732 L

Mistroke

.61379 .01717 L

.61234 .01701 L

.61089 .01686 L

.60944 .01672 L

.60799 .01658 L

.60654 .01644 L

.6051 .01631 L

.60365 .01618 L

.6022 .01606 L

.60075 .01594 L

.5993 .01583 L

.59785 .01572 L

.5964 .01562 L

.59495 .01552 L

.5935 .01543 L

.59205 .01534 L

.5906 .01526 L

.58915 .01518 L

.5877 .01511 L

.58625 .01504 L

.5848 .01498 L

.58335 .01493 L

.5819 .01488 L

.58045 .01484 L

.579 .0148 L

.57755 .01477 L

.5761 .01475 L

.57465 .01473 L

.5732 .01472 L

.57175 .01472 L

.57031 .01472 L

.56886 .01473 L

.56741 .01474 L

.56596 .01477 L

.56451 .0148 L

.56306 .01484 L

.56161 .01489 L

.56016 .01494 L

.55871 .01501 L

.55726 .01508 L

.55581 .01516 L

.55436 .01525 L

.55291 .01535 L

.55146 .01545 L

.55001 .01557 L

.54856 .01569 L

.54711 .01583 L

.54566 .01597 L

.54421 .01612 L

.54276 .01629 L

Mistroke

.54131 .01646 L

.53986 .01665 L

.53841 .01684 L

.53696 .01705 L

.53551 .01726 L

.53407 .01749 L

.53262 .01773 L

.53117 .01798 L

.52972 .01825 L

.52827 .01852 L

.52682 .01881 L

.52537 .01911 L

.52392 .01942 L

.52247 .01975 L

.52102 .02009 L

.51957 .02045 L

.51812 .02082 L

.51667 .0212 L

.51522 .0216 L

.51377 .02201 L

.51232 .02244 L

.51087 .02288 L

.50942 .02334 L

.50797 .02382 L

.50652 .02431 L

.50507 .02482 L

.50362 .02535 L

.50217 .02589 L

.50072 .02646 L

.49928 .02704 L

.49783 .02764 L

.49638 .02826 L

.49493 .0289 L

.49348 .02956 L

.49203 .03024 L

.49058 .03094 L

.48913 .03166 L

.48768 .03241 L

.48623 .03318 L

.48478 .03397 L

.48333 .03478 L

.48188 .03562 L

.48043 .03648 L

.47898 .03737 L

.47753 .03829 L

.47608 .03923 L

.47463 .0402 L

.47318 .04119 L

.47173 .04222 L

.47028 .04327 L

Mistroke

.46883 .04435 L

.46738 .04546 L

.46593 .04661 L

.46449 .04779 L

.46304 .049 L

.46159 .05024 L

.46014 .05152 L

.45869 .05284 L

.45724 .05419 L

.45579 .05558 L

.45434 .057 L

.45289 .05847 L

.45144 .05998 L

.44999 .06153 L

.44854 .06312 L

.44709 .06476 L

.44564 .06645 L

.44419 .06818 L

.44274 .06996 L

.44129 .07179 L

.43984 .07368 L

.43839 .07561 L

.43694 .07761 L

.43549 .07966 L

.43404 .08177 L

.43259 .08394 L

.43114 .08618 L

.42969 .08849 L

.42825 .09086 L

.4268 .09331 L

.42535 .09583 L

.4239 .09844 L

.42245 .10112 L

.421 .10389 L

.41955 .10675 L

.4181 .10971 L

.41665 .11277 L

.4152 .11593 L

.41375 .1192 L

.4123 .12259 L

.41085 .12611 L

.4094 .12976 L

.40795 .13355 L

.4065 .13749 L

.40505 .1416 L

.4036 .14588 L

.40215 .15036 L

.4007 .15505 L

.39925 .15997 L

.3978 .16514 L

Mistroke

.39635 .1706 L

.3949 .17637 L

.39346 .18252 L

.39201 .18909 L

.39056 .19615 L

.38911 .20382 L

.38766 .21223 L

.38621 .2216 L

.38476 .23228 L

.38318 .25817 L

.38084 .28359 L

.38005 .30902 L

Mfstroke

1 0 0 r

.3949 .53505 m

.39201 .53566 L

.38911 .53626 L

.38621 .53686 L

.38331 .53746 L

.38041 .53806 L

.37751 .53865 L

.37461 .53923 L

.37171 .53982 L

.36881 .54039 L

.36591 .54096 L

.36301 .54153 L

.36011 .5421 L

.35722 .54265 L

.35432 .5432 L

.35142 .54375 L

.34852 .54429 L

.34562 .54482 L

.34272 .54535 L

.33982 .54587 L

.33692 .54639 L

.33402 .54689 L

.33112 .54739 L

.32822 .54789 L

.32532 .54837 L

.32243 .54885 L

.31953 .54932 L

.31663 .54978 L

.31373 .55023 L

.31083 .55067 L

.30793 .5511 L

.30503 .55153 L

.30213 .55194 L

.29923 .55234 L

.29633 .55274 L

.29343 .55312 L

.29053 .55349 L

.28763 .55385 L

.28474 .55419 L

.28184 .55453 L

.27894 .55485 L

.27604 .55516 L

.27314 .55545 L

.27024 .55574 L

.26734 .556 L

.26444 .55625 L

.26154 .55649 L

.25864 .55671 L

.25574 .55691 L

.25284 .5571 L

Mistroke

.24995 .55727 L

.24705 .55742 L

.24415 .55756 L

.24125 .55767 L

.23835 .55776 L

.23545 .55783 L

.23255 .55789 L

.22965 .55792 L

.22675 .55793 L

.22385 .55791 L

.22095 .55787 L

.21805 .55781 L

.21516 .55772 L

.21226 .55761 L

.20936 .55746 L

.20646 .55729 L

.20356 .55709 L

.20066 .55686 L

.19776 .5566 L

.19486 .5563 L

.19196 .55598 L

.18906 .55562 L

.18616 .55522 L

.18326 .55479 L

.18037 .55432 L

.17747 .55381 L

.17457 .55326 L

.17167 .55266 L

.16877 .55203 L

.16587 .55135 L

.16297 .55062 L

.16007 .54984 L

.15717 .54901 L

.15427 .54813 L

.15137 .54719 L

.14847 .5462 L

.14558 .54515 L

.14268 .54404 L

.13978 .54287 L

.13688 .54163 L

.13398 .54032 L

.13108 .53894 L

.12818 .53749 L

.12528 .53595 L

.12238 .53434 L

.11948 .53264 L

.11658 .53086 L

.11368 .52898 L

.11078 .527 L

.10789 .52492 L

Mistroke

.10499 .52273 L

.10209 .52043 L

.09919 .51801 L

.09629 .51546 L

.09339 .51279 L

.09049 .50997 L

.08759 .507 L

.08469 .50387 L

.08179 .50057 L

.07889 .49709 L

.07599 .49342 L

.0731 .48954 L

.0702 .48542 L

.0673 .48106 L

.0644 .47644 L

.0615 .47151 L

.0586 .46626 L

.0557 .46064 L

.0528 .45461 L

.0499 .4481 L

.047 .44105 L

.0441 .43336 L

.0412 .42488 L

.03831 .41544 L

.03541 .40473 L

.03251 .39226 L

.02961 .37706 L

.02671 .35655 L

.02381 .30902 L

Mfstroke

.3949 .08299 m

.39201 .08238 L

.38911 .08177 L

.38621 .08117 L

.38331 .08057 L

.38041 .07998 L

.37751 .07939 L

.37461 .0788 L

.37171 .07822 L

.36881 .07764 L

.36591 .07707 L

.36301 .0765 L

.36011 .07594 L

.35722 .07538 L

.35432 .07483 L

.35142 .07428 L

.34852 .07374 L

.34562 .07321 L

.34272 .07268 L

.33982 .07216 L

.33692 .07165 L

.33402 .07114 L

.33112 .07064 L

.32822 .07015 L

.32532 .06966 L

.32243 .06919 L

.31953 .06872 L

.31663 .06826 L

.31373 .06781 L

.31083 .06736 L

.30793 .06693 L

.30503 .06651 L

.30213 .06609 L

.29923 .06569 L

.29633 .0653 L

.29343 .06492 L

.29053 .06455 L

.28763 .06419 L

.28474 .06384 L

.28184 .0635 L

.27894 .06318 L

.27604 .06287 L

.27314 .06258 L

.27024 .0623 L

.26734 .06203 L

.26444 .06178 L

.26154 .06154 L

.25864 .06132 L

.25574 .06112 L

.25284 .06093 L

Mistroke

.24995 .06076 L

.24705 .06061 L

.24415 .06048 L

.24125 .06037 L

.23835 .06027 L

.23545 .0602 L

.23255 .06015 L

.22965 .06012 L

.22675 .06011 L

.22385 .06012 L

.22095 .06016 L

.21805 .06022 L

.21516 .06031 L

.21226 .06043 L

.20936 .06057 L

.20646 .06074 L

.20356 .06094 L

.20066 .06117 L

.19776 .06143 L

.19486 .06173 L

.19196 .06206 L

.18906 .06242 L

.18616 .06281 L

.18326 .06324 L

.18037 .06372 L

.17747 .06423 L

.17457 .06478 L

.17167 .06537 L

.16877 .06601 L

.16587 .06669 L

.16297 .06742 L

.16007 .0682 L

.15717 .06902 L

.15427 .0699 L

.15137 .07084 L

.14847 .07183 L

.14558 .07288 L

.14268 .07399 L

.13978 .07516 L

.13688 .0764 L

.13398 .07771 L

.13108 .07909 L

.12818 .08055 L

.12528 .08208 L

.12238 .08369 L

.11948 .08539 L

.11658 .08718 L

.11368 .08906 L

.11078 .09104 L

.10789 .09312 L

Mistroke

.10499 .0953 L

.10209 .0976 L

.09919 .10002 L

.09629 .10257 L

.09339 .10525 L

.09049 .10807 L

.08759 .11104 L

.08469 .11416 L

.08179 .11746 L

.07889 .12094 L

.07599 .12462 L

.0731 .1285 L

.0702 .13261 L

.0673 .13697 L

.0644 .1416 L

.0615 .14652 L

.0586 .15177 L

.0557 .15739 L

.0528 .16343 L

.0499 .16993 L

.047 .17698 L

.0441 .18468 L

.0412 .19315 L

.03831 .2026 L

.03541 .21331 L

.03251 .22578 L

.02961 .24098 L

.02671 .26148 L

.02381 .30902 L

Mfstroke

.97619 .50094 m

.97474 .50107 L

.97329 .5012 L

.97184 .50132 L

.97039 .50145 L

.96894 .50157 L

.96749 .50169 L

.96604 .50182 L

.96459 .50194 L

.96314 .50205 L

.96169 .50217 L

.96024 .50229 L

.9588 .5024 L

.95735 .50252 L

.9559 .50263 L

.95445 .50274 L

.953 .50285 L

.95155 .50296 L

.9501 .50307 L

.94865 .50317 L

.9472 .50328 L

.94575 .50338 L

.9443 .50348 L

.94285 .50358 L

.9414 .50367 L

.93995 .50377 L

.9385 .50386 L

.93705 .50396 L

.9356 .50405 L

.93415 .50414 L

.9327 .50422 L

.93125 .50431 L

.9298 .50439 L

.92835 .50447 L

.9269 .50455 L

.92545 .50463 L

.92401 .5047 L

.92256 .50478 L

.92111 .50485 L

.91966 .50492 L

.91821 .50498 L

.91676 .50505 L

.91531 .50511 L

.91386 .50517 L

.91241 .50523 L

.91096 .50528 L

.90951 .50533 L

.90806 .50538 L

.90661 .50543 L

.90516 .50547 L

Mistroke

.90371 .50551 L

.90226 .50555 L

.90081 .50559 L

.89936 .50562 L

.89791 .50565 L

.89646 .50568 L

.89501 .5057 L

.89356 .50573 L

.89211 .50574 L

.89066 .50576 L

.88922 .50577 L

.88777 .50578 L

.88632 .50578 L

.88487 .50578 L

.88342 .50578 L

.88197 .50578 L

.88052 .50577 L

.87907 .50575 L

.87762 .50574 L

.87617 .50572 L

.87472 .50569 L

.87327 .50566 L

.87182 .50563 L

.87037 .50559 L

.86892 .50555 L

.86747 .5055 L

.86602 .50545 L

.86457 .5054 L

.86312 .50533 L

.86167 .50527 L

.86022 .5052 L

.85877 .50512 L

.85732 .50504 L

.85587 .50496 L

.85442 .50487 L

.85298 .50477 L

.85153 .50467 L

.85008 .50456 L

.84863 .50445 L

.84718 .50433 L

.84573 .5042 L

.84428 .50407 L

.84283 .50393 L

.84138 .50378 L

.83993 .50363 L

.83848 .50347 L

.83703 .5033 L

.83558 .50313 L

.83413 .50294 L

.83268 .50275 L

Mistroke

.83123 .50256 L

.82978 .50235 L

.82833 .50213 L

.82688 .50191 L

.82543 .50168 L

.82398 .50143 L

.82253 .50118 L

.82108 .50092 L

.81963 .50065 L

.81819 .50036 L

.81674 .50007 L

.81529 .49976 L

.81384 .49945 L

.81239 .49912 L

.81094 .49878 L

.80949 .49842 L

.80804 .49805 L

.80659 .49767 L

.80514 .49727 L

.80369 .49685 L

.80224 .49642 L

.80079 .49597 L

.79934 .49551 L

.79789 .49502 L

.79644 .49452 L

.79499 .49399 L

.79354 .49345 L

.79209 .49288 L

.79064 .49228 L

.78919 .49166 L

.78774 .49102 L

.78629 .49034 L

.78484 .48963 L

.78339 .48889 L

.78195 .48812 L

.7805 .48731 L

.77905 .48645 L

.7776 .48556 L

.77615 .48463 L

.7747 .48365 L

.77325 .48262 L

.7718 .48155 L

.77035 .48044 L

.7689 .47928 L

.76745 .47809 L

.766 .47688 L

.76455 .47567 L

.7631 .47447 L

.76165 .47332 L

.7602 .47223 L

Mistroke

.75875 .47122 L

.7573 .4703 L

.75585 .46948 L

.7544 .46875 L

.75295 .46812 L

.7515 .46758 L

.75005 .46712 L

.7486 .46673 L

.74716 .4664 L

.74571 .46612 L

.74426 .4659 L

.74281 .46572 L

.74136 .46557 L

.73991 .46547 L

.73846 .46539 L

.73701 .46534 L

.73556 .46532 L

.73411 .46532 L

.73266 .46534 L

.73121 .46537 L

.72976 .46543 L

.72831 .4655 L

.72686 .46558 L

.72541 .46568 L

.72396 .46579 L

.72251 .46591 L

.72106 .46604 L

.71961 .46618 L

.71816 .46633 L

.71671 .46649 L

.71526 .46665 L

.71381 .46682 L

.71237 .467 L

.71092 .46719 L

.70947 .46738 L

.70802 .46757 L

.70657 .46778 L

.70512 .46798 L

.70367 .46819 L

.70222 .46841 L

.70077 .46863 L

.69932 .46885 L

.69787 .46908 L

.69642 .46932 L

.69497 .46955 L

.69352 .46979 L

.69207 .47003 L

.69062 .47027 L

.68917 .47052 L

.68772 .47077 L

Mistroke

.68627 .47102 L

.68482 .47128 L

.68337 .47154 L

.68192 .4718 L

.68047 .47206 L

.67902 .47232 L

.67757 .47259 L

.67613 .47286 L

.67468 .47313 L

.67323 .4734 L

.67178 .47368 L

.67033 .47395 L

.66888 .47423 L

.66743 .47451 L

.66598 .47479 L

.66453 .47507 L

.66308 .47535 L

.66163 .47564 L

.66018 .47593 L

.65873 .47621 L

.65728 .4765 L

.65583 .47679 L

.65438 .47708 L

.65293 .47738 L

.65148 .47767 L

.65003 .47797 L

.64858 .47826 L

.64713 .47856 L

.64568 .47886 L

.64423 .47915 L

.64278 .47945 L

.64134 .47976 L

.63989 .48006 L

.63844 .48036 L

.63699 .48066 L

.63554 .48097 L

.63409 .48127 L

.63264 .48158 L

.63119 .48189 L

.62974 .48219 L

.62829 .4825 L

.62684 .48281 L

.62539 .48312 L

.62394 .48343 L

.62249 .48374 L

.62104 .48406 L

.61959 .48437 L

.61814 .48468 L

.61669 .485 L

.61524 .48531 L

Mistroke

.61379 .48563 L

.61234 .48594 L

.61089 .48626 L

.60944 .48658 L

.60799 .48689 L

.60654 .48721 L

.6051 .48753 L

.60365 .48785 L

.6022 .48817 L

.60075 .48849 L

.5993 .48881 L

.59785 .48913 L

.5964 .48945 L

.59495 .48977 L

.5935 .4901 L

.59205 .49042 L

.5906 .49074 L

.58915 .49107 L

.5877 .49139 L

.58625 .49172 L

.5848 .49204 L

.58335 .49237 L

.5819 .49269 L

.58045 .49302 L

.579 .49334 L

.57755 .49367 L

.5761 .494 L

.57465 .49433 L

.5732 .49465 L

.57175 .49498 L

.57031 .49531 L

.56886 .49564 L

.56741 .49597 L

.56596 .4963 L

.56451 .49663 L

.56306 .49696 L

.56161 .49729 L

.56016 .49762 L

.55871 .49795 L

.55726 .49828 L

.55581 .49861 L

.55436 .49894 L

.55291 .49927 L

.55146 .49961 L

.55001 .49994 L

.54856 .50027 L

.54711 .5006 L

.54566 .50093 L

.54421 .50127 L

.54276 .5016 L

Mistroke

.54131 .50193 L

.53986 .50227 L

.53841 .5026 L

.53696 .50293 L

.53551 .50327 L

.53407 .5036 L

.53262 .50394 L

.53117 .50427 L

.52972 .5046 L

.52827 .50494 L

.52682 .50527 L

.52537 .50561 L

.52392 .50594 L

.52247 .50628 L

.52102 .50661 L

.51957 .50695 L

.51812 .50728 L

.51667 .50761 L

.51522 .50795 L

.51377 .50828 L

.51232 .50862 L

.51087 .50895 L

.50942 .50929 L

.50797 .50962 L

.50652 .50996 L

.50507 .51029 L

.50362 .51063 L

.50217 .51096 L

.50072 .5113 L

.49928 .51163 L

.49783 .51197 L

.49638 .5123 L

.49493 .51264 L

.49348 .51297 L

.49203 .51331 L

.49058 .51364 L

.48913 .51398 L

.48768 .51431 L

.48623 .51464 L

.48478 .51498 L

.48333 .51531 L

.48188 .51565 L

.48043 .51598 L

.47898 .51631 L

.47753 .51665 L

.47608 .51698 L

.47463 .51731 L

.47318 .51765 L

.47173 .51798 L

.47028 .51831 L

Mistroke

.46883 .51864 L

.46738 .51897 L

.46593 .51931 L

.46449 .51964 L

.46304 .51997 L

.46159 .5203 L

.46014 .52063 L

.45869 .52096 L

.45724 .52129 L

.45579 .52162 L

.45434 .52195 L

.45289 .52228 L

.45144 .52261 L

.44999 .52294 L

.44854 .52326 L

.44709 .52359 L

.44564 .52392 L

.44419 .52425 L

.44274 .52457 L

.44129 .5249 L

.43984 .52522 L

.43839 .52555 L

.43694 .52587 L

.43549 .5262 L

.43404 .52652 L

.43259 .52685 L

.43114 .52717 L

.42969 .52749 L

.42825 .52781 L

.4268 .52813 L

.42535 .52846 L

.4239 .52878 L

.42245 .5291 L

.421 .52941 L

.41955 .52973 L

.4181 .53005 L

.41665 .53037 L

.4152 .53069 L

.41375 .531 L

.4123 .53132 L

.41085 .53163 L

.4094 .53195 L

.40795 .53226 L

.4065 .53257 L

.40505 .53288 L

.4036 .53319 L

.40215 .5335 L

.4007 .53381 L

.39925 .53412 L

.3978 .53443 L

Mistroke

Mfstroke

.97619 .11709 m

.97474 .11697 L

.97329 .11684 L

.97184 .11671 L

.97039 .11659 L

.96894 .11646 L

.96749 .11634 L

.96604 .11622 L

.96459 .1161 L

.96314 .11598 L

.96169 .11586 L

.96024 .11575 L

.9588 .11563 L

.95735 .11552 L

.9559 .1154 L

.95445 .11529 L

.953 .11518 L

.95155 .11507 L

.9501 .11497 L

.94865 .11486 L

.9472 .11476 L

.94575 .11466 L

.9443 .11456 L

.94285 .11446 L

.9414 .11436 L

.93995 .11426 L

.9385 .11417 L

.93705 .11408 L

.9356 .11399 L

.93415 .1139 L

.9327 .11381 L

.93125 .11373 L

.9298 .11364 L

.92835 .11356 L

.9269 .11348 L

.92545 .11341 L

.92401 .11333 L

.92256 .11326 L

.92111 .11319 L

.91966 .11312 L

.91821 .11305 L

.91676 .11299 L

.91531 .11293 L

.91386 .11287 L

.91241 .11281 L

.91096 .11275 L

.90951 .1127 L

.90806 .11265 L

.90661 .11261 L

.90516 .11256 L

Mistroke

.90371 .11252 L

.90226 .11248 L

.90081 .11244 L

.89936 .11241 L

.89791 .11238 L

.89646 .11235 L

.89501 .11233 L

.89356 .11231 L

.89211 .11229 L

.89066 .11228 L

.88922 .11226 L

.88777 .11226 L

.88632 .11225 L

.88487 .11225 L

.88342 .11225 L

.88197 .11226 L

.88052 .11227 L

.87907 .11228 L

.87762 .1123 L

.87617 .11232 L

.87472 .11234 L

.87327 .11237 L

.87182 .11241 L

.87037 .11244 L

.86892 .11249 L

.86747 .11253 L

.86602 .11258 L

.86457 .11264 L

.86312 .1127 L

.86167 .11277 L

.86022 .11283 L

.85877 .11291 L

.85732 .11299 L

.85587 .11308 L

.85442 .11317 L

.85298 .11326 L

.85153 .11337 L

.85008 .11347 L

.84863 .11359 L

.84718 .11371 L

.84573 .11384 L

.84428 .11397 L

.84283 .11411 L

.84138 .11425 L

.83993 .11441 L

.83848 .11457 L

.83703 .11473 L

.83558 .11491 L

.83413 .11509 L

.83268 .11528 L

Mistroke

.83123 .11548 L

.82978 .11569 L

.82833 .1159 L

.82688 .11613 L

.82543 .11636 L

.82398 .1166 L

.82253 .11685 L

.82108 .11712 L

.81963 .11739 L

.81819 .11767 L

.81674 .11796 L

.81529 .11827 L

.81384 .11859 L

.81239 .11892 L

.81094 .11926 L

.80949 .11961 L

.80804 .11998 L

.80659 .12037 L

.80514 .12077 L

.80369 .12118 L

.80224 .12161 L

.80079 .12206 L

.79934 .12253 L

.79789 .12301 L

.79644 .12351 L

.79499 .12404 L

.79354 .12459 L

.79209 .12516 L

.79064 .12575 L

.78919 .12637 L

.78774 .12702 L

.78629 .1277 L

.78484 .1284 L

.78339 .12914 L

.78195 .12992 L

.7805 .13073 L

.77905 .13158 L

.7776 .13247 L

.77615 .13341 L

.7747 .13439 L

.77325 .13541 L

.7718 .13648 L

.77035 .1376 L

.7689 .13876 L

.76745 .13994 L

.766 .14115 L

.76455 .14236 L

.7631 .14356 L

.76165 .14471 L

.7602 .1458 L

Mistroke

.75875 .14682 L

.7573 .14774 L

.75585 .14856 L

.7544 .14928 L

.75295 .14991 L

.7515 .15045 L

.75005 .15092 L

.7486 .15131 L

.74716 .15164 L

.74571 .15191 L

.74426 .15214 L

.74281 .15232 L

.74136 .15246 L

.73991 .15257 L

.73846 .15264 L

.73701 .15269 L

.73556 .15272 L

.73411 .15272 L

.73266 .1527 L

.73121 .15266 L

.72976 .15261 L

.72831 .15254 L

.72686 .15245 L

.72541 .15235 L

.72396 .15225 L

.72251 .15213 L

.72106 .152 L

.71961 .15185 L

.71816 .15171 L

.71671 .15155 L

.71526 .15138 L

.71381 .15121 L

.71237 .15103 L

.71092 .15085 L

.70947 .15066 L

.70802 .15046 L

.70657 .15026 L

.70512 .15005 L

.70367 .14984 L

.70222 .14962 L

.70077 .1494 L

.69932 .14918 L

.69787 .14895 L

.69642 .14872 L

.69497 .14848 L

.69352 .14825 L

.69207 .148 L

.69062 .14776 L

.68917 .14751 L

.68772 .14726 L

Mistroke

.68627 .14701 L

.68482 .14675 L

.68337 .1465 L

.68192 .14624 L

.68047 .14597 L

.67902 .14571 L

.67757 .14544 L

.67613 .14517 L

.67468 .1449 L

.67323 .14463 L

.67178 .14436 L

.67033 .14408 L

.66888 .14381 L

.66743 .14353 L

.66598 .14325 L

.66453 .14296 L

.66308 .14268 L

.66163 .1424 L

.66018 .14211 L

.65873 .14182 L

.65728 .14153 L

.65583 .14124 L

.65438 .14095 L

.65293 .14066 L

.65148 .14036 L

.65003 .14007 L

.64858 .13977 L

.64713 .13948 L

.64568 .13918 L

.64423 .13888 L

.64278 .13858 L

.64134 .13828 L

.63989 .13798 L

.63844 .13767 L

.63699 .13737 L

.63554 .13707 L

.63409 .13676 L

.63264 .13645 L

.63119 .13615 L

.62974 .13584 L

.62829 .13553 L

.62684 .13522 L

.62539 .13491 L

.62394 .1346 L

.62249 .13429 L

.62104 .13398 L

.61959 .13366 L

.61814 .13335 L

.61669 .13304 L

.61524 .13272 L

Mistroke

.61379 .13241 L

.61234 .13209 L

.61089 .13177 L

.60944 .13146 L

.60799 .13114 L

.60654 .13082 L

.6051 .1305 L

.60365 .13018 L

.6022 .12986 L

.60075 .12954 L

.5993 .12922 L

.59785 .1289 L

.5964 .12858 L

.59495 .12826 L

.5935 .12794 L

.59205 .12761 L

.5906 .12729 L

.58915 .12697 L

.5877 .12664 L

.58625 .12632 L

.5848 .12599 L

.58335 .12567 L

.5819 .12534 L

.58045 .12502 L

.579 .12469 L

.57755 .12436 L

.5761 .12404 L

.57465 .12371 L

.5732 .12338 L

.57175 .12305 L

.57031 .12272 L

.56886 .12239 L

.56741 .12207 L

.56596 .12174 L

.56451 .12141 L

.56306 .12108 L

.56161 .12075 L

.56016 .12042 L

.55871 .12009 L

.55726 .11975 L

.55581 .11942 L

.55436 .11909 L

.55291 .11876 L

.55146 .11843 L

.55001 .1181 L

.54856 .11776 L

.54711 .11743 L

.54566 .1171 L

.54421 .11677 L

.54276 .11643 L

Mistroke

.54131 .1161 L

.53986 .11577 L

.53841 .11543 L

.53696 .1151 L

.53551 .11477 L

.53407 .11443 L

.53262 .1141 L

.53117 .11376 L

.52972 .11343 L

.52827 .1131 L

.52682 .11276 L

.52537 .11243 L

.52392 .11209 L

.52247 .11176 L

.52102 .11142 L

.51957 .11109 L

.51812 .11075 L

.51667 .11042 L

.51522 .11008 L

.51377 .10975 L

.51232 .10941 L

.51087 .10908 L

.50942 .10874 L

.50797 .10841 L

.50652 .10807 L

.50507 .10774 L

.50362 .1074 L

.50217 .10707 L

.50072 .10673 L

.49928 .1064 L

.49783 .10607 L

.49638 .10573 L

.49493 .1054 L

.49348 .10506 L

.49203 .10473 L

.49058 .10439 L

.48913 .10406 L

.48768 .10372 L

.48623 .10339 L

.48478 .10306 L

.48333 .10272 L

.48188 .10239 L

.48043 .10205 L

.47898 .10172 L

.47753 .10139 L

.47608 .10105 L

.47463 .10072 L

.47318 .10039 L

.47173 .10006 L

.47028 .09972 L

Mistroke

.46883 .09939 L

.46738 .09906 L

.46593 .09873 L

.46449 .0984 L

.46304 .09807 L

.46159 .09774 L

.46014 .0974 L

.45869 .09707 L

.45724 .09674 L

.45579 .09641 L

.45434 .09608 L

.45289 .09576 L

.45144 .09543 L

.44999 .0951 L

.44854 .09477 L

.44709 .09444 L

.44564 .09412 L

.44419 .09379 L

.44274 .09346 L

.44129 .09314 L

.43984 .09281 L

.43839 .09248 L

.43694 .09216 L

.43549 .09184 L

.43404 .09151 L

.43259 .09119 L

.43114 .09087 L

.42969 .09054 L

.42825 .09022 L

.4268 .0899 L

.42535 .08958 L

.4239 .08926 L

.42245 .08894 L

.421 .08862 L

.41955 .0883 L

.4181 .08798 L

.41665 .08767 L

.4152 .08735 L

.41375 .08703 L

.4123 .08672 L

.41085 .0864 L

.4094 .08609 L

.40795 .08578 L

.4065 .08546 L

.40505 .08515 L

.4036 .08484 L

.40215 .08453 L

.4007 .08422 L

.39925 .08391 L

.3978 .0836 L

Mistroke

Mfstroke

0 .4 1 r

.76093 .56825 m

.76165 .56799 L

.76238 .56773 L

.7631 .56746 L

.76383 .56719 L

.76455 .56692 L

.76528 .56665 L

.766 .56638 L

.76672 .56611 L

.76745 .56584 L

.76817 .56556 L

.7689 .56528 L

.76962 .565 L

.77035 .56471 L

.77107 .56443 L

.7718 .56415 L

.77252 .56386 L

.77325 .56357 L

.77397 .56328 L

.7747 .56298 L

.77542 .56269 L

.77615 .56239 L

.77687 .56209 L

.7776 .56179 L

.77832 .56149 L

.77905 .56118 L

.77977 .56087 L

.7805 .56056 L

.78122 .56025 L

.78195 .55994 L

.78267 .55962 L

.78339 .5593 L

.78412 .55898 L

.78484 .55866 L

.78557 .55834 L

.78629 .55801 L

.78702 .55768 L

.78774 .55735 L

.78847 .55701 L

.78919 .55668 L

.78992 .55634 L

.79064 .556 L

.79137 .55565 L

.79209 .55531 L

.79282 .55496 L

.79354 .55461 L

.79427 .55425 L

.79499 .5539 L

.79572 .55354 L

.79644 .55317 L

Mistroke

.79717 .55281 L

.79789 .55244 L

.79862 .55207 L

.79934 .5517 L

.80007 .55132 L

.80079 .55094 L

.80151 .55056 L

.80224 .55018 L

.80296 .54979 L

.80369 .5494 L

.80441 .54901 L

.80514 .54861 L

.80586 .54821 L

.80659 .54781 L

.80731 .54741 L

.80804 .547 L

.80876 .54659 L

.80949 .54617 L

.81021 .54575 L

.81094 .54533 L

.81166 .54491 L

.81239 .54448 L

.81311 .54405 L

.81384 .54362 L

.81456 .54318 L

.81529 .54274 L

.81601 .54229 L

.81674 .54184 L

.81746 .54139 L

.81819 .54094 L

.81891 .54047 L

.81963 .54001 L

.82036 .53955 L

.82108 .53907 L

.82181 .5386 L

.82253 .53812 L

.82326 .53764 L

.82398 .53716 L

.82471 .53666 L

.82543 .53617 L

.82616 .53567 L

.82688 .53517 L

.82761 .53466 L

.82833 .53415 L

.82906 .53364 L

.82978 .53312 L

.83051 .53259 L

.83123 .53207 L

.83196 .53153 L

.83268 .531 L

Mistroke

.83341 .53045 L

.83413 .52991 L

.83486 .52936 L

.83558 .5288 L

.8363 .52824 L

.83703 .52768 L

.83775 .52711 L

.83848 .52653 L

.8392 .52595 L

.83993 .52537 L

.84065 .52478 L

.84138 .52418 L

.8421 .52359 L

.84283 .52298 L

.84355 .52237 L

.84428 .52176 L

.845 .52114 L

.84573 .52051 L

.84645 .51988 L

.84718 .51924 L

.8479 .5186 L

.84863 .51795 L

.84935 .51729 L

.85008 .51663 L

.8508 .51596 L

.85153 .51529 L

.85225 .51461 L

.85298 .51393 L

.8537 .51324 L

.85442 .51254 L

.85515 .51184 L

.85587 .51113 L

.8566 .51041 L

.85732 .50969 L

Mfstroke

.76093 .04978 m

.76165 .05005 L

.76238 .05031 L

.7631 .05057 L

.76383 .05084 L

.76455 .05111 L

.76528 .05138 L

.766 .05165 L

.76672 .05192 L

.76745 .0522 L

.76817 .05248 L

.7689 .05275 L

.76962 .05304 L

.77035 .05332 L

.77107 .0536 L

.7718 .05389 L

.77252 .05418 L

.77325 .05447 L

.77397 .05476 L

.7747 .05505 L

.77542 .05535 L

.77615 .05564 L

.77687 .05594 L

.7776 .05624 L

.77832 .05655 L

.77905 .05685 L

.77977 .05716 L

.7805 .05747 L

.78122 .05778 L

.78195 .0581 L

.78267 .05841 L

.78339 .05873 L

.78412 .05905 L

.78484 .05937 L

.78557 .0597 L

.78629 .06003 L

.78702 .06035 L

.78774 .06069 L

.78847 .06102 L

.78919 .06136 L

.78992 .0617 L

.79064 .06204 L

.79137 .06238 L

.79209 .06273 L

.79282 .06308 L

.79354 .06343 L

.79427 .06378 L

.79499 .06414 L

.79572 .0645 L

.79644 .06486 L

Mistroke

.79717 .06523 L

.79789 .06559 L

.79862 .06596 L

.79934 .06633 L

.80007 .06671 L

.80079 .06709 L

.80151 .06747 L

.80224 .06785 L

.80296 .06824 L

.80369 .06863 L

.80441 .06903 L

.80514 .06942 L

.80586 .06982 L

.80659 .07022 L

.80731 .07063 L

.80804 .07103 L

.80876 .07145 L

.80949 .07186 L

.81021 .07228 L

.81094 .0727 L

.81166 .07313 L

.81239 .07355 L

.81311 .07398 L

.81384 .07442 L

.81456 .07486 L

.81529 .0753 L

.81601 .07574 L

.81674 .07619 L

.81746 .07664 L

.81819 .0771 L

.81891 .07756 L

.81963 .07802 L

.82036 .07849 L

.82108 .07896 L

.82181 .07943 L

.82253 .07991 L

.82326 .08039 L

.82398 .08088 L

.82471 .08137 L

.82543 .08186 L

.82616 .08236 L

.82688 .08286 L

.82761 .08337 L

.82833 .08388 L

.82906 .0844 L

.82978 .08492 L

.83051 .08544 L

.83123 .08597 L

.83196 .0865 L

.83268 .08704 L

Mistroke

.83341 .08758 L

.83413 .08812 L

.83486 .08867 L

.83558 .08923 L

.8363 .08979 L

.83703 .09036 L

.83775 .09092 L

.83848 .0915 L

.8392 .09208 L

.83993 .09266 L

.84065 .09325 L

.84138 .09385 L

.8421 .09445 L

.84283 .09505 L

.84355 .09566 L

.84428 .09628 L

.845 .0969 L

.84573 .09752 L

.84645 .09816 L

.84718 .09879 L

.8479 .09944 L

.84863 .10009 L

.84935 .10074 L

.85008 .1014 L

.8508 .10207 L

.85153 .10274 L

.85225 .10342 L

.85298 .1041 L

.8537 .10479 L

.85442 .10549 L

.85515 .10619 L

.85587 .1069 L

.8566 .10762 L

.85732 .10834 L

Mfstroke

.85805 .50896 m

.85877 .50823 L

.8595 .50749 L

.86022 .50674 L

.86095 .50598 L

.86167 .50522 L

.8624 .50445 L

.86312 .50367 L

.86385 .50288 L

.86457 .50209 L

.8653 .50129 L

.86602 .50048 L

.86675 .49967 L

.86747 .49884 L

.8682 .49801 L

.86892 .49718 L

.86965 .49633 L

.87037 .49547 L

.8711 .49461 L

.87182 .49374 L

.87254 .49285 L

.87327 .49197 L

.87399 .49107 L

.87472 .49016 L

.87544 .48924 L

.87617 .48832 L

.87689 .48738 L

.87762 .48644 L

.87834 .48548 L

.87907 .48452 L

.87979 .48354 L

.88052 .48256 L

.88124 .48157 L

.88197 .48056 L

.88269 .47954 L

.88342 .47852 L

.88414 .47748 L

.88487 .47643 L

.88559 .47537 L

.88632 .47429 L

.88704 .47321 L

.88777 .47211 L

.88849 .471 L

.88922 .46988 L

.88994 .46874 L

.89066 .4676 L

.89139 .46643 L

.89211 .46526 L

.89284 .46407 L

.89356 .46286 L

Mistroke

.89429 .46163 L

.89501 .4604 L

.89574 .45915 L

.89646 .45788 L

.89719 .45659 L

.89791 .45529 L

.89864 .45397 L

.89936 .45263 L

.90009 .45128 L

.90081 .4499 L

.90154 .4485 L

.90226 .44709 L

.90299 .44565 L

.90371 .44419 L

.90444 .44271 L

.90516 .4412 L

.90589 .43966 L

.90661 .4381 L

.90733 .43652 L

.90806 .4349 L

.90878 .43326 L

.90951 .43159 L

.91023 .42988 L

.91096 .42813 L

.91168 .42635 L

.91241 .42453 L

.91313 .42267 L

.91386 .42077 L

.91458 .41882 L

.91531 .41681 L

.91603 .41475 L

.91676 .41263 L

.91748 .41044 L

.91821 .40819 L

.91893 .40584 L

.91966 .40341 L

.92038 .40088 L

.92111 .39824 L

.92183 .39545 L

.92256 .39251 L

.92328 .38939 L

.92401 .38602 L

.92473 .38234 L

.92545 .37824 L

.92618 .37354 L

.9269 .36774 L

.92763 .35916 L

.92727 .34569 L

.9269 .33223 L

Mfstroke

.85805 .10907 m

.85877 .1098 L

.8595 .11055 L

.86022 .1113 L

.86095 .11205 L

.86167 .11282 L

.8624 .11359 L

.86312 .11437 L

.86385 .11515 L

.86457 .11594 L

.8653 .11674 L

.86602 .11755 L

.86675 .11837 L

.86747 .11919 L

.8682 .12002 L

.86892 .12086 L

.86965 .1217 L

.87037 .12256 L

.8711 .12343 L

.87182 .1243 L

.87254 .12518 L

.87327 .12607 L

.87399 .12696 L

.87472 .12787 L

.87544 .12879 L

.87617 .12971 L

.87689 .13065 L

.87762 .1316 L

.87834 .13255 L

.87907 .13352 L

.87979 .13449 L

.88052 .13547 L

.88124 .13647 L

.88197 .13747 L

.88269 .13849 L

.88342 .13952 L

.88414 .14056 L

.88487 .14161 L

.88559 .14267 L

.88632 .14374 L

.88704 .14482 L

.88777 .14592 L

.88849 .14703 L

.88922 .14815 L

.88994 .14929 L

.89066 .15044 L

.89139 .1516 L

.89211 .15278 L

.89284 .15397 L

.89356 .15517 L

Mistroke

.89429 .1564 L

.89501 .15764 L

.89574 .15889 L

.89646 .16016 L

.89719 .16144 L

.89791 .16274 L

.89864 .16406 L

.89936 .1654 L

.90009 .16676 L

.90081 .16813 L

.90154 .16953 L

.90226 .17095 L

.90299 .17238 L

.90371 .17385 L

.90444 .17533 L

.90516 .17684 L

.90589 .17837 L

.90661 .17993 L

.90733 .18152 L

.90806 .18313 L

.90878 .18477 L

.90951 .18645 L

.91023 .18816 L

.91096 .1899 L

.91168 .19168 L

.91241 .1935 L

.91313 .19536 L

.91386 .19726 L

.91458 .19922 L

.91531 .20123 L

.91603 .20329 L

.91676 .2054 L

.91748 .20759 L

.91821 .20985 L

.91893 .21219 L

.91966 .21462 L

.92038 .21715 L

.92111 .2198 L

.92183 .22258 L

.92256 .22552 L

.92328 .22864 L

.92401 .23201 L

.92473 .2357 L

.92545 .23979 L

.92618 .24449 L

.9269 .25029 L

.92763 .25888 L

.92727 .27234 L

.9269 .2858 L

Mfstroke

.97619 .40035 m

.97474 .4006 L

.97329 .40086 L

.97184 .40112 L

.97039 .40137 L

.96894 .40163 L

.96749 .40188 L

.96604 .40214 L

.96459 .40239 L

.96314 .40264 L

.96169 .4029 L

.96024 .40315 L

.9588 .4034 L

.95735 .40365 L

.9559 .4039 L

.95445 .40415 L

.953 .4044 L

.95155 .40465 L

.9501 .4049 L

.94865 .40515 L

.9472 .40539 L

.94575 .40564 L

.9443 .40589 L

.94285 .40613 L

.9414 .40637 L

.93995 .40662 L

.9385 .40686 L

.93705 .4071 L

.9356 .40734 L

.93415 .40758 L

.9327 .40782 L

.93125 .40805 L

.9298 .40829 L

.92835 .40852 L

.9269 .40875 L

.92545 .40898 L

.92401 .40921 L

.92256 .40944 L

.92111 .40967 L

.91966 .40989 L

.91821 .41012 L

.91676 .41034 L

.91531 .41056 L

.91386 .41078 L

.91241 .41099 L

.91096 .4112 L

.90951 .41141 L

.90806 .41162 L

.90661 .41182 L

.90516 .41203 L

Mistroke

.90371 .41222 L

.90226 .41242 L

.90081 .41261 L

.89936 .4128 L

.89791 .41298 L

.89646 .41316 L

.89501 .41334 L

.89356 .41351 L

.89211 .41367 L

.89066 .41383 L

.88922 .41399 L

.88777 .41413 L

.88632 .41427 L

.88487 .4144 L

.88342 .41453 L

.88197 .41464 L

.88052 .41474 L

.87907 .41483 L

.87762 .41491 L

.87617 .41498 L

.87472 .41502 L

.87327 .41505 L

.87182 .41506 L

.87037 .41504 L

.86892 .41499 L

.86747 .41491 L

.86602 .41479 L

.86457 .41461 L

.86312 .41437 L

.86167 .41402 L

.86022 .41354 L

.85877 .41285 L

.85732 .41166 L

Mfstroke

.97619 .21769 m

.97474 .21743 L

.97329 .21717 L

.97184 .21692 L

.97039 .21666 L

.96894 .21641 L

.96749 .21615 L

.96604 .2159 L

.96459 .21564 L

.96314 .21539 L

.96169 .21514 L

.96024 .21488 L

.9588 .21463 L

.95735 .21438 L

.9559 .21413 L

.95445 .21388 L

.953 .21363 L

.95155 .21338 L

.9501 .21313 L

.94865 .21289 L

.9472 .21264 L

.94575 .21239 L

.9443 .21215 L

.94285 .2119 L

.9414 .21166 L

.93995 .21142 L

.9385 .21118 L

.93705 .21093 L

.9356 .21069 L

.93415 .21046 L

.9327 .21022 L

.93125 .20998 L

.9298 .20975 L

.92835 .20951 L

.9269 .20928 L

.92545 .20905 L

.92401 .20882 L

.92256 .20859 L

.92111 .20836 L

.91966 .20814 L

.91821 .20792 L

.91676 .2077 L

.91531 .20748 L

.91386 .20726 L

.91241 .20704 L

.91096 .20683 L

.90951 .20662 L

.90806 .20641 L

.90661 .20621 L

.90516 .20601 L

Mistroke

.90371 .20581 L

.90226 .20561 L

.90081 .20542 L

.89936 .20523 L

.89791 .20505 L

.89646 .20487 L

.89501 .20469 L

.89356 .20452 L

.89211 .20436 L

.89066 .2042 L

.88922 .20405 L

.88777 .2039 L

.88632 .20376 L

.88487 .20363 L

.88342 .20351 L

.88197 .20339 L

.88052 .20329 L

.87907 .2032 L

.87762 .20312 L

.87617 .20306 L

.87472 .20301 L

.87327 .20298 L

.87182 .20298 L

.87037 .20299 L

.86892 .20304 L

.86747 .20312 L

.86602 .20325 L

.86457 .20342 L

.86312 .20367 L

.86167 .20401 L

.86022 .20449 L

.85877 .20519 L

.85732 .20638 L

Mfstroke

.85863 .41275 m

.85848 .41266 L

.85834 .41256 L

.85819 .41246 L

.85805 .41235 L

.8579 .41223 L

.85776 .4121 L

.85761 .41197 L

.85747 .41182 L

.85732 .41166 L

.85718 .41147 L

.85703 .41128 L

.85689 .41106 L

.85674 .4108 L

.8566 .41051 L

.85645 .41013 L

.85631 .40955 L

s

.85863 .20528 m

.85848 .20537 L

.85834 .20547 L

.85819 .20557 L

.85805 .20569 L

.8579 .20581 L

.85776 .20593 L

.85761 .20607 L

.85747 .20622 L

.85732 .20638 L

.85718 .20656 L

.85703 .20676 L

.85689 .20698 L

.85674 .20723 L

.8566 .20752 L

.85645 .20791 L

.85631 .20848 L

s

.9269 .33223 m

.92618 .32702 L

.92545 .32287 L

.92473 .31934 L

.92401 .31623 L

.92328 .31341 L

.92256 .31082 L

.92183 .30842 L

.92111 .30617 L

.92038 .30406 L

.91966 .30205 L

.91893 .30014 L

.91821 .29831 L

.91748 .29656 L

.91676 .29487 L

.91603 .29325 L

.91531 .29167 L

.91458 .29015 L

.91386 .28867 L

.91313 .28724 L

.91241 .28584 L

.91168 .28448 L

.91096 .28316 L

.91023 .28186 L

.90951 .28059 L

.90878 .27935 L

.90806 .27813 L

.90733 .27694 L

.90661 .27577 L

.90589 .27463 L

.90516 .2735 L

.90444 .27239 L

.90371 .2713 L

.90299 .27022 L

.90226 .26917 L

.90154 .26813 L

.90081 .2671 L

.90009 .26608 L

.89936 .26508 L

.89864 .2641 L

.89791 .26312 L

.89719 .26215 L

.89646 .2612 L

.89574 .26026 L

.89501 .25933 L

.89429 .2584 L

.89356 .25749 L

.89284 .25658 L

.89211 .25568 L

.89139 .25479 L

Mistroke

.89066 .25391 L

.88994 .25303 L

.88922 .25217 L

.88849 .2513 L

.88777 .25044 L

.88704 .2496 L

.88632 .24875 L

.88559 .24791 L

.88487 .24707 L

.88414 .24624 L

.88342 .24541 L

.88269 .24459 L

.88197 .24377 L

.88124 .24296 L

.88052 .24214 L

.87979 .24133 L

.87907 .24052 L

.87834 .23972 L

.87762 .23891 L

.87689 .23811 L

.87617 .23731 L

.87544 .2365 L

.87472 .2357 L

.87399 .2349 L

.87327 .23409 L

.87254 .23329 L

.87182 .23248 L

.8711 .23168 L

.87037 .23087 L

.86965 .23005 L

.86892 .22923 L

.8682 .22841 L

.86747 .22758 L

.86675 .22674 L

.86602 .22589 L

.8653 .22503 L

.86457 .22416 L

.86385 .22328 L

.86312 .22238 L

.8624 .22146 L

.86167 .22052 L

.86095 .21954 L

.86022 .21853 L

.8595 .21745 L

.85877 .21632 L

.85805 .21506 L

.85732 .21364 L

.8566 .21175 L

Mfstroke

.9269 .2858 m

.92618 .29102 L

.92545 .29516 L

.92473 .29869 L

.92401 .30181 L

.92328 .30463 L

.92256 .30721 L

.92183 .30961 L

.92111 .31186 L

.92038 .31398 L

.91966 .31598 L

.91893 .31789 L

.91821 .31972 L

.91748 .32147 L

.91676 .32316 L

.91603 .32479 L

.91531 .32636 L

.91458 .32788 L

.91386 .32936 L

.91313 .3308 L

.91241 .33219 L

.91168 .33355 L

.91096 .33488 L

.91023 .33618 L

.90951 .33745 L

.90878 .33868 L

.90806 .3399 L

.90733 .34109 L

.90661 .34226 L

.90589 .34341 L

.90516 .34453 L

.90444 .34565 L

.90371 .34674 L

.90299 .34781 L

.90226 .34887 L

.90154 .34991 L

.90081 .35094 L

.90009 .35195 L

.89936 .35295 L

.89864 .35394 L

.89791 .35491 L

.89719 .35588 L

.89646 .35683 L

.89574 .35778 L

.89501 .35871 L

.89429 .35963 L

.89356 .36055 L

.89284 .36146 L

.89211 .36235 L

.89139 .36324 L

Mistroke

.89066 .36412 L

.88994 .365 L

.88922 .36587 L

.88849 .36673 L

.88777 .36759 L

.88704 .36844 L

.88632 .36929 L

.88559 .37013 L

.88487 .37096 L

.88414 .37179 L

.88342 .37262 L

.88269 .37344 L

.88197 .37426 L

.88124 .37508 L

.88052 .37589 L

.87979 .3767 L

.87907 .37751 L

.87834 .37832 L

.87762 .37912 L

.87689 .37993 L

.87617 .38073 L

.87544 .38153 L

.87472 .38233 L

.87399 .38313 L

.87327 .38394 L

.87254 .38474 L

.87182 .38555 L

.8711 .38636 L

.87037 .38717 L

.86965 .38799 L

.86892 .38881 L

.8682 .38963 L

.86747 .39046 L

.86675 .3913 L

.86602 .39214 L

.8653 .393 L

.86457 .39387 L

.86385 .39475 L

.86312 .39565 L

.8624 .39657 L

.86167 .39752 L

.86095 .39849 L

.86022 .39951 L

.8595 .40058 L

.85877 .40172 L

.85805 .40297 L

.85732 .4044 L

.8566 .40629 L

Mfstroke

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{567, 350.313},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.776525,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008g0001GPP10`40000100000800002008200000

P800P020P<30`<3L`:K:l00003<006H009T00<`00?l0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV

09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<003o03?o06Ko09Wo0<co

0?oo0000<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I

<c>I<fJI<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0

IYT0I/`0I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bI

I_nIIP3<IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0c

VC<cVFHcVITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<

VIW<VLc<VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`c

c?lcc01Vc3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03o

c3?oc6Koc9Woc<coc?ooc000oc<0ofH0oiT0ol`0ool0o`0coc<cofHcoiTcol`coolco`1Voc=VofIV

oiUVolaVoomVo`2Ioc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<o`3ooc?oofKooiWoolco

ooooo`0000410@820P<30`@410D51@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C

4a@D5?okl:2PY820P?l0003o0?oo0000ool0o`3oooooodCQ00<0hN40on7ah@00A>400`3Qh@3ohO7Q

0014h@030>7Q0?oQlN4004CQ00<0hN40on7ah@00A>400`3Qh@3ohO7Q0014h@030>7Q0?oQlN4004CQ

00<0hN40on7ah@00A>400`3Qh@3ohO7Q0014h@030>7Q0>3Q7[kbh@00A>430=WQ1khMh@^nj>4004CQ

00<0hN40e>46_RgQ2;kQh@00A>400`3Qh@3@h@Bn>n47_][Q0014h@030>7Q0<gQ1;i5h@Jne>4004CQ

00<0hN40b^44_TkQ1Kk?h@00A>400`3Qh@38h@>nE^45_/[Q0014h@030>7Q0<KQ0[iNh@FnaN4004CQ

00<0hN40a>42_VGQ1;k1h@00A>400`3Qh@31h@>nJn45_[cQ0014h@030>7Q0<3Q0[ibh@Bn^>4004CQ

00<0hN40_^42_WOQ1;jeh@00A>430;gQ0[ilh@Bn/N4004CQ00<0hN40^n42_X;Q1;j]h@00A>400`3Q

h@2jh@:nQn43_Z[Q0014h@030>7Q0;SQ0[j<h@>nYn4004CQ00<0hN40]n42_Y3Q0kjTh@00A>400`3Q

h@2fh@03_^7Q09?Q0kjQh@00A>400`3Qh@2eh@03_^7Q09OQ0kjNh@00A>400`3Qh@2dh@03_^7Q09[Q

1;jKh@00A>400`3Qh@2bh@:nX>43_YWQ0014h@030>7Q0;;Q00>nhN40X^43_YKQ0014h@030>7Q0;3Q

0[jWh@>nU>4004CQ00<0hN40=N4>3fcQ00>nhN40ZN43_Y;Q0014h@<0:N4<3`kQ3`mMh@03_^7Q0:cQ

0[j@h@00A>400`3Qh@0Qh@P?:N493e?Q00>nhN40[n42_XkQ0014h@030>7Q01gQ10ljh@P?B^400kkQ

h@2bh@:nS>4004CQ00<0hN406^433dKQ1Pm3h@03_^7Q0;GQ0[j:h@00A>400`3Qh@0Eh@D?Cn463ccQ

0[jih@:nR>4004CQ00<0hN404^433e[Q1Pleh@03_^7Q0;[Q0kj6h@00A>400`3Qh@0Ah@033n7Q067Q

1Pl^h@03_^7Q0;gQ0[j5h@00A>400`3Qh@0>h@<?J^453bWQ00>nhN40_n42_X?Q0014h@030>7Q00_Q

0`mbh@H?8^400kkQh@32h@:nPN4004CQ00<0hN402N423g_Q10lMh@03_^7Q0<CQ0[j0h@00=>4500;Q

00<0hN401^400`3Qh@08h@033n7Q07oQ1@lGh@03_^7Q0<OQ0[inh@00=^401`3QhN40h@001n400`3Q

h@06h@8?Qn443a?Q00>nhN40b>42_WgQ000`h@<00n401`3QhN40h@001n450004h@l?3hkQ1@l=h@03

_^7Q0<[Q0[ikh@00=^401`3QhN40h@001n400`3Qh@02h@033n7Q09CQ1@l7h@03_^7Q0<cQ0[ijh@00

=^401`3QhN40h@001n400`3Qh@023i_Q1@l2h@03_^7Q0<kQ0[iih@00=N4200CQ00<0hN401^400`3Q

3`2Rh@D?d>42_WOQ0014h@8?Y>400kkQh@053lgQ0[ifh@00@n400`l0h@2Th@03_^7Q00GQ1@o9h@:n

MN4004?Q00<?0>40Xn400kkQh@0:h@@?b>400kkQh@1bh@00@N423`03h@3Q0:;Q00>nhN403n453lCQ

00>nhN40LN40043Q00D?hN7Q002Rh@03_^7Q01GQ10o1h@:nLN4003kQ0Pl4h@030>7Q0:3Q00>nhN40

6N453kgQ0[i`h@00?N400`oQh@04h@030>7Q0:3Q00>nhN407^443k[Q00>nhN40K^4003gQ00<?hN40

1>4309oQ00>nhN408n443kOQ0[i^h@00>n423`OQ00<0hN40Wn400kkQh@0Wh@D?/n42_VgQ000jh@03

3n7Q00OQ00<0hN40W^400kkQh@0/h@D?/>42_VcQ000jh@033n7Q00OQ00<0hN40WN400kkQh@0bh@D?

[>42_P?Q4PmFh@00>>423`[Q00<0hN40WN400kkQh@0fh@@?Wn4;3`:n0PlBhA@?@^4003OQ00<?hN40

2^400`3Qh@2Mh@03_^7Q03[Q1@nCh@L?3>400kkQh@0Vh@h?=>4003OQ00<?hN402^400`3Qh@2Lh@03

_^7Q043Q10n9h@H?5>400kkQh@0ch@@?<>4003KQ00<?hN402n400`3Qh@2Lh@03_^7Q04CQ1@n0h@@?

6n400kkQh@1Vh@00=N400`oQh@0<h@030>7Q09_Q00>nhN40B^443gSQ10lPh@03_^7Q06GQ000dh@03

3n7Q00gQ00<0hN40Vn400kkQh@1>h@D?L>443bCQ00>nhN40I>4003CQ00<?hN403N400`3Qh@2Jh@03

_^7Q05CQ10mZh@<?9n42_VGQ000ch@033n7Q00kQ00<0hN40V^400kkQh@1Hh@@?I>423b_Q0[iTh@00

<^400`oQh@0?h@<0V^400kkQh@1Lh@D?GN423bkQ0[iSh@00<N400`oQh@0@h@030>7Q09WQ00>nhN40

H^453eKQ0`l`h@03_^7Q067Q000ah@033n7Q013Q00<0hN40VN400kkQh@1Wh@D?D>400`oQh@0bh@03

_^7Q063Q000`h@033n7Q017Q00<0hN40V>400kkQh@1/h@D?B^423cGQ0[iQh@00;n400`oQh@0Bh@03

0>7Q09SQ00>nhN40LN453dCQ00<?hN40=^42_V3Q000_h@033n7Q01;Q00<0hN40V>400kkQh@1eh@H?

?^423cWQ00>nhN40G^4002kQ00<?hN404n400`3Qh@2Gh@03_^7Q07cQ10lhh@8?>n42_UoQ000^h@03

3n7Q01?Q00<0hN40Un400kkQh@20h@H?<^400`oQh@0kh@03_^7Q05gQ000]h@033n7Q01CQ00<0hN40

Un400kkQh@25h@H?:n423coQ00>nhN40G>4002cQ00<?hN405N400`3Qh@2Gh@03_^7Q08_Q1@lUh@03

3n7Q043Q00>nhN40Fn4002cQ00<?hN405N400`3Qh@2Fh@03_^7Q097Q1PlMh@8?@n400kkQh@1Kh@00

:n400`oQh@0Fh@030>7Q09KQ00>nhN40Un483a;Q0`m6h@03_^7Q05[Q000[h@033n7Q01KQ0`2Fh@03

_^7Q09kQ4`m9h@:nFn4002[Q00<?hN405n400`3Qh@2Eh@03_^7Q0?cQ00>nhN40FN4002[Q00<?hN40

5n400`3Qh@2Eh@03_^7Q0?gQ00>nhN40F>4002WQ00<?hN406>400`3Qh@2Dh@03_^7Q0?kQ00>nhN40

F>4002WQ00<?hN406>400`3Qh@2Dh@03_^7Q0?oQ00>nhN40En4002SQ00<?hN406N400`3Qh@2Dh@03

_^7Q0?oQ00>nhN40En4002SQ00<?hN406N400`3Qh@2Dh@03_^7Q0?oQ0N400kkQh@1Fh@009n400`oQ

h@0Jh@030>7Q09CQ00>nhN40on42h@03_^7Q05GQ000Wh@033n7Q01[Q00<0hN40U>400kkQh@3oh@;Q

00>nhN40EN4002KQ00<?hN406n400`3Qh@2Ch@03_^7Q0?oQ1>400kkQh@1Dh@009^400`oQh@0Kh@03

0>7Q09?Q00>nhN40on44h@03_^7Q05CQ000Uh@033n7Q01cQ0`2Ch@03_^7Q0?oQ1>42_UGQ000Uh@03

3n7Q01cQ00<0hN40T^400kkQh@3oh@KQ00>nhN40Dn4002GQ00<?hN407>400`3Qh@2Bh@03_^7Q0?oQ

1n400kkQh@1Bh@009>400`oQh@0Mh@030>7Q09;Q00>nhN40on47h@03_^7Q05;Q000Th@033n7Q01gQ

00<0hN40TN400kkQh@3oh@WQ00>nhN40DN4002?Q00<?hN407^400`3Qh@2Ah@03_^7Q0?oQ2N400kkQ

h@1Ah@008n400`oQh@0Nh@030>7Q097Q00>nhN40on49h@03_^7Q057Q000Sh@033n7Q01kQ00<0hN40

TN400kkQh@3oh@[Q00>nhN40D>4002;Q00<?hN407n400`3Qh@2Ah@03_^7Q0?oQ2^400kkQh@1@h@00

8^400`oQh@0Oh@030>7Q097Q00>nhN40on4;h@03_^7Q04oQ000Rh@033n7Q01KQ00<0hN401^400`3Q

h@2@h@03_^7Q0?oQ3>400kkQh@1?h@008^400`oQh@0Eh@030>4000OQ00<0hN40T>400kkQh@3oh@gQ

00>nhN40C^40027Q00<?hN404N4300CQ00<0hN401N4508kQ00>nhN40on4=h@03_^7Q04kQ000Qh@03

3n7Q01KQ0P08h@030>7Q093Q00>nhN40on4=h@03_^7Q04kQ000Ph@033n7Q01OQ00<0hN401n400`3Q

h@2?h@03_^7Q0?oQ3n400kkQh@1=h@008>400`oQh@0Gh@<01n400`3Qh@2?h@03_^7Q0?GQ1[hCh@03

_^7Q04gQ000Ph@033n7Q027Q00<0hN40Sn400kkQh@3ah@Bn1^4;_PSQ00>nhN40CN40023Q00<?hN40

8N400`3Qh@2?h@03_^7Q0?3Q00>nhN404n47_P;Q00>nhN40C>4001oQ00<?hN408^400`3Qh@2>h@03

_^7Q0?3Q00>nhN406^47_T_Q000Oh@033n7Q02;Q00<0hN40S^400kkQh@3ohA7Q00BnhN7Q1[i5h@00

7n400`oQh@0Rh@030>7Q08kQ00>nhN40l>400kkQh@0Nh@03_^7Q00KQ1[hoh@007n400`oQh@0Rh@03

0>7Q08kQ00>nhN40lN400kkQh@0Mh@03_^7Q00cQ1[hih@007n400`oQh@0Rh@030>7Q08kQ00>nhN40

lN400kkQh@0Mh@03_^7Q01;Q1[hch@007^400`oQh@0Sh@030>7Q08kQ00>nhN40l^400kkQh@0Lh@03

_^7Q01SQ0kh`h@007^400`oQh@0Sh@<0S^400kkQh@3ch@03_^7Q01cQ00>nhN40B^4001kQ00<?hN40

8n400`3Qh@2>h@03_^7Q0??Q0[hMh@03_^7Q04[Q000Mh@033n7Q02CQ00<0hN40S^400kkQh@3dh@03

_^7Q01_Q00>nhN40B^4001gQ00<?hN409>400`3Qh@2>h@03_^7Q0?GQ00>nhN406n400kkQh@19h@00

7N400`oQh@0Th@030>7Q08gQ00>nhN40mn400kkQh@0Jh@03_^7Q04WQ000Mh@033n7Q02CQ00<0hN40

SN400kkQh@3gh@:n6n400kkQh@19h@007N400`oQh@0Th@030>7Q08gQ00>nhN40nN400kkQh@0Hh@03

_^7Q04WQ000Lh@033n7Q02GQ00<0hN40SN400kkQh@3ih@:n6N400kkQh@19h@007>400`oQh@0Uh@03

0>7Q08gQ00>nhN40n^42_QWQ00>nhN40B>4001cQ00<?hN409N400`3Qh@2=h@03_^7Q0?_Q0[hHh@03

_^7Q04SQ000Lh@033n7Q02GQ00<0hN40SN400kkQh@3lh@:n5n400kkQh@18h@007>400`oQh@0Uh@<0

SN400kkQh@3mh@03_^7Q01GQ00>nhN40B>4001cQ00<?hN409N400`3Qh@2=h@03_^7Q0?kQ00>nhN40

5>400kkQh@18h@007>400`oQh@0Uh@030>7Q08gQ00>nhN40on400kkQh@0Ch@03_^7Q04SQ000Kh@03

3n7Q02KQ00<0hN40S>400kkQh@3oh@;Q00>nhN404^400kkQh@18h@006n400`oQh@0Vh@030>7Q08cQ

00>nhN40on42h@:n5>400kkQh@17h@006n400`oQh@0Vh@030>7Q08cQ00>nhN40on43h@:n4n400kkQ

h@17h@006n400`oQh@0Vh@030>7Q08cQ00>nhN40on44h@:n4^400kkQh@17h@006n400`oQh@0Vh@03

0>7Q08cQ00>nhN40on45h@03_^7Q013Q00>nhN40An4001_Q00<?hN409^400`3Qh@2<h@03_^7Q0?oQ

1^400kkQh@0?h@03_^7Q04OQ000Jh@033n7Q02OQ00<0hN40S>400kkQh@3oh@OQ00>nhN403^400kkQ

h@17h@006^400`oQh@0Wh@030>7Q08cQ00>nhN40on47h@:n3n400kkQh@17h@006^400`oQh@0Wh@03

0>7Q08cQ00>nhN40on48h@03_^7Q00gQ00>nhN40An4001[Q00<?hN409n4308cQ00>nhN40on49h@03

_^7Q00cQ00>nhN40An4001[Q00<?hN409n400`3Qh@2<h@03_^7Q0?oQ2^400kkQh@0;h@03_^7Q04OQ

000Jh@033n7Q02OQ00<0hN40S>400kkQh@3oh@[Q0[h<h@03_^7Q04OQ000Jh@033n7Q02OQ00<0hN40

S>400kkQh@3oh@_Q00>nhN402^400kkQh@17h@006^400`oQh@0Wh@030>7Q08_Q00>nhN40on4=h@03

_^7Q00WQ00>nhN40An4001[Q00<?hN409n400`3Qh@2;h@03_^7Q0?oQ3^400kkQh@08h@03_^7Q04OQ

000Jh@033n7Q02OQ00<0hN40Rn400kkQh@3oh@kQ00>nhN402>400kkQh@17h@006^400`oQh@0Wh@03

0>7Q08_Q00>nhN40on4?h@03_^7Q00OQ00>nhN40An4001[Q00<?hN409n400`3Qh@2;h@03_^7Q0?oQ

3n400kkQh@07h@03_^7Q04OQ000Jh@033n7Q02OQ00<0hN40@n4500;Q00<0hN40?^401;kQhN450003

h@0004?Q1@02h@030>7Q047Q1@02h@030>7Q047Q1@000n40000Uh@03_^7Q00KQ00>nhN404n4300?Q

00<0hN40:n4001[Q00<?hN409n400`3Qh@15h@070>7Qh@3Q000oh@03_^7Q00?Q00L0hN7Q0>4004CQ

00<0hN400^400`3Qh@13h@070>7Qh@3Q0014h@030>7Q00?Q00<0hN408n400kkQh@05h@03_^7Q01?Q

00<0hN400^400`3Q000/h@006N400`oQh@0Xh@030>7Q04GQ00<0hN400n400`3Qh@0mh@03_^7Q00?Q

00L0hN7Q0>4004CQ00<0hN400^400`3Qh@13h@070>7Qh@3Q0014h@030>7Q00;Q0P0Uh@03_^7Q00GQ

00>nhN405>401`3QhN40h@00;>4001WQ00<?hN40:>4304GQ00@0hN7Q0P10h@03_^7Q00?Q00@0hN7Q

0P15h@030>7Q00?Q00<0hN40@^400`3Qh@02h@030>7Q04?Q00L0hN7Q0>4002KQ00>nhN401>400kkQ

h@0Dh@070>7Qh@3Q000/h@006N400`oQh@0Xh@030>7Q04GQ00D0hN7Q0011h@03_^7Q00?Q00D0hN7Q

0016h@070>7Qh@3Q0014h@070>7Qh@3Q0014h@070>7Qh@3Q000Vh@03_^7Q00?Q00>nhN405>400`3Q

0002h@030>4002cQ000Ih@033n7Q02SQ00<0hN40A>4200?Q0`0oh@03_^7Q00;Q0P04h@80@n4200?Q

0`13h@801>400`3Qh@12h@801>4202KQ0[h4h@03_^7Q01GQ00<0hN400^400`3Qh@0[h@006N400`oQ

h@0Xh@030>7Q08_Q00>nhN40on4Ch@03_^7Q00;Q00>nhN40B>4001WQ00<?hN40:>400`3Qh@2;h@03

_^7Q0?oQ5>401KkQhN6n04[Q000Ih@033n7Q02SQ00<0hN40R^400kkQh@3ohAGQ00FnhN7Q_P1:h@00

6N400`oQh@0Xh@030>7Q08[Q00>nhN40on4Eh@05_^7QhKh0B^4001WQ00<?hN40:>400`3Qh@2:h@03

_^7Q0?oQ5^400kkQ_P1;h@006N400`oQh@0Xh@030>7Q08[Q00>nhN40on4Fh@03_^6n04_Q000Ih@03

3n7Q02SQ00<0hN40R^400kkQh@3ohAKQ00>nhKh0=n44013Q000Ih@033n7Q02SQ00<0hN40R^400kkQ

h@3ohAOQ0[hgh@<04N4000cQ3@000`l0002e0003_P000?l05`000kh0000W017Q00<0hN403n4001OQ

00<0h@l03>400`3Qh@0<h@030>7Q00cQ00<0hN403>400`3Qh@0<h@030>7Q00cQ00<0hN403>400`3Q

h@0<h@030>7Q00cQ00<0hN403>400`3Qh@0<h@030>7Q00gQ00<0hN400^400kkQh@07h@030>7Q00cQ

00<0hN403>400`3Qh@0<h@030>7Q00cQ00<0hN403>400`3Qh@0<h@030>7Q00cQ00<0hN403>400`3Q

h@0<h@030>7Q00cQ00<0hN403>400`3Qh@0<h@030>7Q00cQ00<0hN403>400`3Qh@0<h@030>7Q00cQ

00<0hN403>400`3Qh@0<h@030;jn00cQ00<0hN403>400`3Qh@0Jh@804N4001OQ00<0h@l03>400`3Q

h@0<h@030>7Q00cQ00<0hN403>400`3Qh@0<h@030>7Q00cQ00<0hN403>400`3Qh@0<h@030>7Q00cQ

00<0hN403>400`3Qh@0<h@030>7Q00gQ00<0hN400^400kkQh@07h@030>7Q00cQ00<0hN403>400`3Q

h@0<h@030>7Q00cQ00<0hN403>400`3Qh@0<h@030>7Q00cQ00<0hN403>400`3Qh@0<h@030>7Q00cQ

00<0hN403>400`3Qh@0<h@030>7Q00cQ00<0hN403>400`3Qh@0<h@030>7Q00cQ00<0hN403>400`3Q

h@0<h@030;jn00cQ00<0hN403>400`3Qh@0]h@006N400`oQh@0Xh@030>7Q04SQ00<0hN40?n400kkQ

h@07h@030>7Q04SQ00<0hN40B>400`3Qh@18h@030>7Q02[Q00>nhKh06n400`3Qh@0]h@006N400`oQ

h@0Xh@030>7Q04SQ00<0hN40?n400kkQh@07h@030>7Q04SQ00<0hN40B>400`3Qh@18h@030>7Q02[Q

00>nhKh06n400`3Qh@0]h@006N400`oQh@0Xh@030>7Q08[Q00>nhN40on4Fh@03_^6n04_Q000Ih@03

3n7Q02SQ00<0hN40R^400kkQh@3ohAGQ00FnhN7Q_P1:h@006N400`oQh@0Xh@030>7Q08[Q00>nhN40

on4Eh@05_^7QhKh0B^4001WQ00<?hN40:>400`3Qh@2;h@03_^7Q0?oQ5>401KkQhN6n04[Q000Ih@03

3n7Q02SQ00<0hN40Rn400kkQh@3ohA?Q00>nhN400^400kkQh@18h@006N400`oQh@0Xh@030>7Q08_Q

00>nhN40on4Bh@03_^7Q00?Q00>nhN40B>4001WQ00<?hN40:>400`3Qh@2;h@03_^7Q0?oQ4^400kkQ

h@03h@03_^7Q04SQ000Ih@033n7Q02SQ0`2;h@03_^7Q0?oQ4N42_PKQ00>nhN40An4001[Q00<?hN40

9n400`3Qh@2;h@03_^7Q0?oQ4N400kkQh@05h@03_^7Q04OQ000Jh@033n7Q02OQ00<0hN40Rn400kkQ

h@3ohA3Q0[h7h@03_^7Q04OQ000Jh@033n7Q02OQ00<0hN40Rn400kkQh@3ohA3Q00>nhN401^400kkQ

h@17h@006^400`oQh@0Wh@030>7Q08_Q00>nhN40on4?h@03_^7Q00OQ00>nhN40An4001[Q00<?hN40

9n400`3Qh@2;h@03_^7Q0?oQ3n400kkQh@07h@03_^7Q04OQ000Jh@033n7Q02OQ00<0hN40Rn400kkQ

h@3oh@kQ00>nhN402>400kkQh@17h@006^400`oQh@0Wh@030>7Q08_Q00>nhN40on4=h@:n2^400kkQ

h@17h@006^400`oQh@0Wh@030>7Q08_Q00>nhN40on4<h@:n2n400kkQh@17h@006^400`oQh@0Wh@03

0>7Q08cQ00>nhN40on4;h@03_^7Q00[Q00>nhN40An4001[Q00<?hN409n400`3Qh@2<h@03_^7Q0?oQ

2^42_PcQ00>nhN40An4001[Q00<?hN409n400`3Qh@2<h@03_^7Q0?oQ2^400kkQh@0;h@03_^7Q04OQ

000Jh@033n7Q02OQ0`2<h@03_^7Q0?oQ2N400kkQh@0<h@03_^7Q04OQ000Jh@033n7Q02OQ00<0hN40

S>400kkQh@3oh@SQ00>nhN403N400kkQh@17h@006^400`oQh@0Wh@030>7Q08cQ00>nhN40on47h@:n

3n400kkQh@17h@006^400`oQh@0Wh@030>7Q08cQ00>nhN40on47h@03_^7Q00kQ00>nhN40An4001_Q

00<?hN409^400`3Qh@2<h@03_^7Q0?oQ1N42_Q7Q00>nhN40An4001_Q00<?hN409^400`3Qh@2<h@03

_^7Q0?oQ1N400kkQh@0@h@03_^7Q04OQ000Kh@033n7Q02KQ00<0hN40S>400kkQh@3oh@CQ00>nhN40

4N400kkQh@17h@006n400`oQh@0Vh@030>7Q08cQ00>nhN40on43h@:n4n400kkQh@17h@006n400`oQ

h@0Vh@030>7Q08cQ00>nhN40on42h@:n5>400kkQh@17h@006n400`oQh@0Vh@030>7Q08cQ00>nhN40

on41h@:n5>400kkQh@18h@007>400`oQh@0Uh@030>7Q08gQ00>nhN40on400kkQh@0Ch@03_^7Q04SQ

000Lh@033n7Q02GQ0`2=h@03_^7Q0?gQ0[hFh@03_^7Q04SQ000Lh@033n7Q02GQ00<0hN40SN400kkQ

h@3mh@03_^7Q01GQ00>nhN40B>4001cQ00<?hN409N400`3Qh@2=h@03_^7Q0?cQ00>nhN405^400kkQ

h@18h@007>400`oQh@0Uh@030>7Q08gQ00>nhN40nn42_QSQ00>nhN40B>4001cQ00<?hN409N400`3Q

h@2=h@03_^7Q0?[Q00>nhN405n400kkQh@19h@007>400`oQh@0Uh@030>7Q08gQ00>nhN40nN42_QWQ

00>nhN40BN4001gQ00<?hN409>400`3Qh@2=h@03_^7Q0?SQ0[hJh@03_^7Q04WQ000Mh@033n7Q02CQ

00<0hN40SN400kkQh@3gh@:n6n400kkQh@19h@007N400`oQh@0Th@030>7Q08gQ00>nhN40m^42_QcQ

00>nhN40BN4001gQ00<?hN409>400`3Qh@2>h@03_^7Q0?CQ0[hMh@03_^7Q04WQ000Mh@033n7Q02CQ

00<0hN40S^400kkQh@3dh@03_^7Q01_Q00>nhN40B^4001kQ00<?hN408n400`3Qh@2>h@03_^7Q0??Q

00>nhN407>400kkQh@1:h@007^400`oQh@0Sh@<0S^400kkQh@3bh@:n7^400kkQh@1:h@007^400`oQ

h@0Sh@030>7Q08kQ00>nhN40lN42_QkQ00>nhN405^45_S3Q000Oh@033n7Q02;Q00<0hN40S^400kkQ

h@3ah@03_^7Q01gQ00>nhN404N45_SGQ000Oh@033n7Q02;Q00<0hN40S^400kkQh@3ah@03_^7Q01gQ

00>nhN402n46_S[Q000Oh@033n7Q02;Q00<0hN40S^400kkQh@3`h@03_^7Q01kQ00>nhN401N46_T3Q

000Oh@033n7Q02;Q00<0hN40S^400kkQh@3`h@03_^7Q01gQ00>nhN401[i6h@007n400`oQh@0Rh@03

0>7Q08kQ00>nhN40l>42_Q[Q1ki<h@008>400`oQh@0Qh@030>7Q08oQ00>nhN40l>400kkQh@0@h@Rn

1>400kkQh@1<h@008>400`oQh@0Qh@030>7Q08oQ00>nhN40lN4C_P[Q00>nhN40CN40023Q00<?hN40

8N400`3Qh@2?h@03_^7Q0?oQ3n400kkQh@1=h@008>400`oQh@0Hh@030>7Q00KQ00<0hN40Sn400kkQ

h@3oh@kQ00>nhN40C^40027Q00<?hN405^400`3Q0007h@030>7Q093Q00>nhN40on4=h@03_^7Q04kQ

000Qh@033n7Q01SQ00<0hN401N4508kQ00>nhN40on4=h@03_^7Q04kQ000Rh@033n7Q01GQ0P08h@03

0>7Q093Q00>nhN40on4<h@03_^7Q04oQ000Rh@033n7Q01GQ00<0hN401n400`3Qh@2@h@03_^7Q0?oQ

3>400kkQh@1?h@008^400`oQh@0Eh@<01n400`3Qh@2Ah@03_^7Q0?oQ2n400kkQh@1?h@008n400`oQ

h@0Nh@030>7Q097Q00>nhN40on4:h@03_^7Q053Q000Sh@033n7Q01kQ00<0hN40TN400kkQh@3oh@[Q

00>nhN40D>4002?Q00<?hN407^400`3Qh@2Ah@03_^7Q0?oQ2N400kkQh@1Ah@008n400`oQh@0Nh@03

0>7Q097Q00>nhN40on49h@03_^7Q057Q000Th@033n7Q01gQ00<0hN40TN400kkQh@3oh@SQ00>nhN40

D^4002CQ00<?hN407N400`3Qh@2Bh@03_^7Q0?oQ1n400kkQh@1Bh@009N400`oQh@0Lh@030>7Q09;Q

00>nhN40on47h@03_^7Q05;Q000Uh@033n7Q01cQ0`2Bh@03_^7Q0?oQ1^400kkQh@1Ch@009^400`oQ

h@0Kh@030>7Q09?Q00>nhN40on44h@03_^7Q05CQ000Vh@033n7Q01_Q00<0hN40Tn400kkQh@3oh@CQ

00>nhN40E>4002KQ00<?hN406n400`3Qh@2Ch@03_^7Q0?oQ0n42_UKQ000Wh@033n7Q01[Q00<0hN40

U>400kkQh@3oh@;Q00>nhN40EN4002OQ00<?hN406^400`3Qh@2Dh@03_^7Q0?oQ0N42_UOQ000Xh@03

3n7Q01WQ00<0hN40U>400kkQh@3oh@7Q00>nhN40E^4002SQ00<?hN406N400`3Qh@2Dh@03_^7Q0?oQ

00>nhN40En4002WQ00<?hN406>400`3Qh@2Dh@03_^7Q0?oQ00>nhN40En4002WQ00<?hN406>400`3Q

h@2Dh@03_^7Q0?kQ00>nhN40F>4002[Q00<?hN405n400`3Qh@2Eh@03_^7Q0?gQ00>nhN40F>4002[Q

00<?hN405n400`3Qh@2Eh@03_^7Q0:OQ1`m>h@03_^7Q05WQ000[h@033n7Q01KQ0`2Fh@03_^7Q09cQ

2Pl7h@D?B>400kkQh@1Jh@00:n400`oQh@0Fh@030>7Q09KQ00>nhN40UN473aKQ0Pm6h@03_^7Q05[Q

000/h@033n7Q01GQ00<0hN40U^400kkQh@2?h@L?7^433d;Q00>nhN40Fn4002cQ00<?hN405N400`3Q

h@2Gh@03_^7Q08WQ1PlVh@033n7Q03oQ0[iMh@00;N400`oQh@0Dh@030>7Q09OQ00>nhN40Q>453bgQ

0Ploh@03_^7Q05cQ000^h@033n7Q01?Q00<0hN40Un400kkQh@1oh@D?=>400`oQh@0kh@03_^7Q05gQ

000^h@033n7Q01?Q00<0hN40Un400kkQh@1jh@D?>^400`oQh@0ih@:nGn4002oQ00<?hN404^400`3Q

h@2Hh@03_^7Q07CQ1@m0h@8?>N400kkQh@1Nh@00;n400`oQh@0Bh@030>7Q09SQ00>nhN40Kn453dKQ

0Plgh@03_^7Q05oQ000`h@033n7Q017Q00<0hN40VN400kkQh@1Zh@D?C>423cCQ00>nhN40H>40037Q

00<?hN404>400`3Qh@2Ih@03_^7Q06GQ1@mBh@8?<^42_V;Q000ah@033n7Q013Q00<0hN40V^400kkQ

h@1Ph@@?FN423c3Q00>nhN40HN4003;Q00<?hN403n4309[Q00>nhN40Fn453ekQ0`l]h@03_^7Q06;Q

000ch@033n7Q00kQ00<0hN40V^400kkQh@1Gh@@?I^423b[Q00>nhN40Hn4003CQ00<?hN403N400`3Q

h@2Jh@03_^7Q05;Q1@m/h@8?9n42_VGQ000dh@033n7Q00gQ00<0hN40Vn400kkQh@1=h@@?Ln433b?Q

0[iVh@00=N400`oQh@0<h@030>7Q09_Q00>nhN40B>453g[Q10lNh@:nIn4003KQ00<?hN402n400`3Q

h@2Lh@03_^7Q04?Q10n3h@D?6N400kkQh@1Vh@00=n400`oQh@0:h@030>7Q09gQ00>nhN40?^443h_Q

1`lAh@:n<N483c3Q000hh@033n7Q00WQ00<0hN40WN400kkQh@0ih@D?UN493`WQ00>nhN408^4>3cSQ

000ih@033n7Q00SQ00<0hN40WN400kkQh@0eh@D?X^483`03_Pl?02@?AN4003[Q00<?hN401n400`3Q

h@2Mh@03_^7Q033Q1@n^h@03_^7Q06[Q000jh@033n7Q00OQ00<0hN40W^400kkQh@0/h@@?/N400kkQ

h@1[h@00>n400`oQh@06h@<0Wn400kkQh@0Vh@D?]>400kkQh@1/h@00?>423`KQ00<0hN40Wn400kkQ

h@0Rh@@?^>400kkQh@1]h@00?^400`oQh@03h@030>7Q0:3Q00>nhN407>453k_Q00>nhN40K^4003oQ

00<?hN400^400`3Qh@2Ph@03_^7Q01SQ10noh@03_^7Q06oQ0010h@053n7Qh@00X^400kkQh@0Dh@D?

`>42_W;Q0011h@043n7Q0:?Q00>nhN403^453lCQ0[ich@00@^423`030>7Q0:;Q00>nhN402N453lOQ

0[idh@00A>400`oQh@2Sh@03_^7Q00?Q1@o;h@:nMN4004CQ00<03`l0Xn400kkQ3`043lkQ0[ifh@00

A>40103Qh@nOh@D?dN42_WSQ000dh@D00^400`3Qh@06h@040>7Qh@8?VN453`?Q00>nhN40c^42_WWQ

000fh@070>7Qh@3Q0007h@030>7Q00?Q00<?hN40TN453`WQ00>nhN40c>42_W[Q000fh@070>7Qh@3Q

0007h@D00^423hkQ10l>h@03_^7Q0<WQ0[ilh@00=^401`3QhN40h@001n400`3Qh@06h@033n7Q08GQ

1@lCh@03_^7Q0<SQ0[imh@00=^401`3QhN40h@001n400`3Qh@07h@8?P>453aWQ00>nhN40aN42_WoQ

000eh@801>400`3Qh@06h@030>7Q00WQ0`mih@@?7n400kkQh@33h@:nP>4004CQ00<0hN403>400`oQ

h@1`h@H?9>400kkQh@30h@:nP^4004CQ00<0hN403N433f[Q1@lZh@03_^7Q0;kQ0kj3h@00A>400`3Q

h@0@h@<?HN463c3Q00>nhN40_>42_XGQ0014h@030>7Q01?Q0`mHh@H?=n400kkQh@2ih@>nQ^4004CQ

00<0hN405^433doQ1Plnh@03_^7Q0;KQ0kj8h@00A>400`3Qh@0Ih@D?@^483dCQ00>nhN40]>43_X[Q

0014h@030>7Q01kQ10lgh@L?CN400kkQh@2ah@>nS>4004CQ00<0hN408^483bKQ2@mEh@03_^7Q0:kQ

0kj>h@00A>4302[Q9PmOh@03_^7Q0:_Q0kj@h@00A>400`3Qh@2`h@03_^7Q0:SQ0kjBh@00A>400`3Q

h@2ah@03_^7Q0:CQ0kjEh@00A>400`3Qh@2bh@03_^7Q0:7Q0kjGh@00A>400`3Qh@2ch@03_^7Q09gQ

0kjJh@00A>400`3Qh@2dh@:nVn43_YcQ0014h@030>7Q0;GQ00>nhN40U^43_YoQ0014h@030>7Q0;KQ

0[jCh@>nX^4004CQ00<0hN40^>400kkQh@2=h@>nYN4004CQ00<0hN40^>42_X_Q0kjXh@00A>400`3Q

h@2jh@:nQN44_Z_Q0014h@<0^n42_X7Q0kj_h@00A>400`3Qh@2mh@:nNn44_[;Q0014h@030>7Q0;kQ

0[ifh@Fn]N4004CQ00<0hN40`>42_W3Q1;jjh@00A>400`3Qh@32h@:nJ^44_[kQ0014h@030>7Q0<CQ

0[iSh@Fn`^4004CQ00<0hN40a^42_UgQ1;k7h@00A>400`3Qh@38h@>nE>46_/_Q0014h@030>7Q0<_Q

0ki<h@Jnd>4004CQ00<0hN40c^43_T?Q1[kFh@00A>400`3Qh@3Ah@Fn=n47_]cQ0014h@030>7Q0=KQ

1KhZh@Vnh^4004CQ0`3Kh@Rn5n4;_^_Q0014h@030>7Q0>?Q5kkfh@00A>400`3Qh@3ohO7Q0014h@03

0>7Q0?oQlN4004CQ00<0hN40on7ah@00A>400`3Qh@3ohO7Q0014h@030>7Q0?oQlN4004CQ00<0hN40

on7ah@00A>400`3Qh@3ohO7Q0014h@030>7Q0?oQlN400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQ

on4ih@00on7ohCWQ003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQon4ih@00on7ohCWQ

003oh@OQ0P001>400>4400;Q0`02h@030>7Q0?oQ7^400?oQ2>400`3Q0009h@060>7Q0>40on4Oh@00

on48h@<00^440003h@00008000CQ0>40on4Oh@00on48h@040>4000KQ00<0h@000^400`3Q003ohAoQ

0012h@80`n400`3Qh@08h@800^400`3Q003ohAoQ0013h@030>7Q0<3Q0P0;h@050>7Qh@00on4Ph@00

@N4300;Q00<0hN40on7_h@00@>40203Qh@3Q0>40on7`h@00@>40203Qh@3Q0>40on7`h@00@N430004

h@3Q0?oQl>4004GQ00<0h@00on7`h@00A^400`3Qh@3ohNoQ003ohOoQ>N400?oQon4ih@00on7ohCWQ

003ohOoQ>N400?oQon4ih@00\

\>"],

  ImageRangeCache->{{{0, 566}, {349.313, 0}} -> {13.0847, -13.7348, 0.0133088,

   0.085747}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-1.36252 0.0935486 0.309017 0.0207805 [

[.32135 .29652 -6 -9 ]

[.32135 .29652 6 0 ]

[.50845 .29652 -6 -9 ]

[.50845 .29652 6 0 ]

[.69554 .29652 -6 -9 ]

[.69554 .29652 6 0 ]

[.88264 .29652 -6 -9 ]

[.88264 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12175 .10121 -18 -4.5 ]

[.12175 .10121 0 4.5 ]

[.12175 .20511 -12 -4.5 ]

[.12175 .20511 0 4.5 ]

[.12175 .41292 -6 -4.5 ]

[.12175 .41292 0 4.5 ]

[.12175 .51682 -12 -4.5 ]

[.12175 .51682 0 4.5 ]

[.13425 .64303 -7 0 ]

[.13425 .64303 7 16 ]

[.5 .63053 -17 0 ]

[.5 .63053 17 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.32135 .30902 m

.32135 .31527 L

s

[(18)] .32135 .29652 0 1 Mshowa

.50845 .30902 m

.50845 .31527 L

s

[(20)] .50845 .29652 0 1 Mshowa

.69554 .30902 m

.69554 .31527 L

s

[(22)] .69554 .29652 0 1 Mshowa

.88264 .30902 m

.88264 .31527 L

s

[(24)] .88264 .29652 0 1 Mshowa

.125 Mabswid

.18103 .30902 m

.18103 .31277 L

s

.2278 .30902 m

.2278 .31277 L

s

.27458 .30902 m

.27458 .31277 L

s

.36812 .30902 m

.36812 .31277 L

s

.4149 .30902 m

.4149 .31277 L

s

.46167 .30902 m

.46167 .31277 L

s

.55522 .30902 m

.55522 .31277 L

s

.602 .30902 m

.602 .31277 L

s

.64877 .30902 m

.64877 .31277 L

s

.74232 .30902 m

.74232 .31277 L

s

.78909 .30902 m

.78909 .31277 L

s

.83587 .30902 m

.83587 .31277 L

s

.08748 .30902 m

.08748 .31277 L

s

.0407 .30902 m

.0407 .31277 L

s

.92942 .30902 m

.92942 .31277 L

s

.97619 .30902 m

.97619 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13425 .10121 m

.1405 .10121 L

s

[(-10)] .12175 .10121 1 0 Mshowa

.13425 .20511 m

.1405 .20511 L

s

[(-5)] .12175 .20511 1 0 Mshowa

.13425 .41292 m

.1405 .41292 L

s

[(5)] .12175 .41292 1 0 Mshowa

.13425 .51682 m

.1405 .51682 L

s

[(10)] .12175 .51682 1 0 Mshowa

.125 Mabswid

.13425 .01809 m

.138 .01809 L

s

.13425 .03887 m

.138 .03887 L

s

.13425 .05965 m

.138 .05965 L

s

.13425 .08043 m

.138 .08043 L

s

.13425 .12199 m

.138 .12199 L

s

.13425 .14277 m

.138 .14277 L

s

.13425 .16355 m

.138 .16355 L

s

.13425 .18433 m

.138 .18433 L

s

.13425 .22589 m

.138 .22589 L

s

.13425 .24668 m

.138 .24668 L

s

.13425 .26746 m

.138 .26746 L

s

.13425 .28824 m

.138 .28824 L

s

.13425 .3298 m

.138 .3298 L

s

.13425 .35058 m

.138 .35058 L

s

.13425 .37136 m

.138 .37136 L

s

.13425 .39214 m

.138 .39214 L

s

.13425 .4337 m

.138 .4337 L

s

.13425 .45448 m

.138 .45448 L

s

.13425 .47526 m

.138 .47526 L

s

.13425 .49604 m

.138 .49604 L

s

.13425 .5376 m

.138 .5376 L

s

.13425 .55838 m

.138 .55838 L

s

.13425 .57916 m

.138 .57916 L

s

.13425 .59994 m

.138 .59994 L

s

.25 Mabswid

.13425 0 m

.13425 .61803 L

s

gsave

.13425 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -78 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(k) show

73.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

83.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(70) show

93.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 .4 1 r

.5 Mabswid

.4149 .59567 m

.41481 .59569 L

.41387 .59597 L

.41293 .59624 L

.412 .59651 L

.41106 .59677 L

.41013 .59703 L

.40919 .59728 L

.40826 .59753 L

.40732 .59778 L

.40639 .59802 L

.40545 .59826 L

.40451 .59849 L

.40358 .59872 L

.40264 .59895 L

.40171 .59917 L

.40077 .59938 L

.39984 .59959 L

.3989 .5998 L

.39797 .6 L

.39703 .60019 L

.3961 .60038 L

.39516 .60057 L

.39422 .60075 L

.39329 .60092 L

.39235 .60109 L

.39142 .60126 L

.39048 .60142 L

.38955 .60157 L

.38861 .60172 L

.38768 .60186 L

.38674 .60199 L

.38581 .60212 L

.38487 .60224 L

.38393 .60236 L

.383 .60247 L

.38206 .60258 L

.38113 .60267 L

.38019 .60277 L

.37926 .60285 L

.37832 .60293 L

.37739 .603 L

.37645 .60307 L

.37551 .60312 L

.37458 .60317 L

.37364 .60322 L

.37271 .60325 L

.37177 .60328 L

.37084 .6033 L

.3699 .60331 L

Mistroke

.36897 .60332 L

.36803 .60332 L

.3671 .60331 L

.36616 .60329 L

.36522 .60326 L

.36429 .60323 L

.36335 .60318 L

.36242 .60313 L

.36148 .60307 L

.36055 .603 L

.35961 .60292 L

.35868 .60283 L

.35774 .60273 L

.35681 .60263 L

.35587 .60251 L

.35493 .60239 L

.354 .60225 L

.35306 .60211 L

.35213 .60195 L

.35119 .60179 L

.35026 .60161 L

.34932 .60142 L

.34839 .60123 L

.34745 .60102 L

.34651 .6008 L

.34558 .60057 L

.34464 .60033 L

.34371 .60008 L

.34277 .59981 L

.34184 .59954 L

.3409 .59925 L

.33997 .59895 L

.33903 .59863 L

.3381 .59831 L

.33716 .59797 L

.33622 .59762 L

.33529 .59726 L

.33435 .59688 L

.33342 .59649 L

.33248 .59609 L

.33155 .59567 L

.33061 .59524 L

.32968 .59479 L

.32874 .59433 L

.32781 .59385 L

.32687 .59336 L

.32593 .59285 L

.325 .59233 L

.32406 .59179 L

.32313 .59124 L

Mistroke

.32219 .59067 L

.32126 .59008 L

.32032 .58948 L

.31939 .58886 L

.31845 .58822 L

.31751 .58756 L

.31658 .58689 L

.31564 .5862 L

.31471 .58548 L

.31377 .58475 L

.31284 .584 L

.3119 .58323 L

.31097 .58244 L

.31003 .58164 L

.3091 .58081 L

.30816 .57996 L

.30722 .57908 L

.30629 .57819 L

.30535 .57727 L

.30442 .57633 L

.30348 .57536 L

.30255 .57438 L

.30161 .57337 L

.30068 .57233 L

.29974 .57127 L

.29881 .57018 L

.29787 .56907 L

.29693 .56793 L

.296 .56676 L

.29506 .56557 L

.29413 .56435 L

.29319 .56309 L

.29226 .56181 L

.29132 .5605 L

.29039 .55915 L

.28945 .55778 L

.28851 .55637 L

.28758 .55492 L

.28664 .55345 L

.28571 .55193 L

.28477 .55038 L

.28384 .5488 L

.2829 .54717 L

.28197 .54551 L

.28103 .54381 L

.2801 .54206 L

.27916 .54027 L

.27822 .53844 L

.27729 .53656 L

.27635 .53464 L

Mistroke

.27542 .53266 L

.27448 .53064 L

.27355 .52857 L

.27261 .52644 L

.27168 .52426 L

.27074 .52202 L

.2698 .51971 L

.26887 .51735 L

.26793 .51493 L

.267 .51243 L

.26606 .50987 L

.26513 .50724 L

.26419 .50453 L

.26326 .50173 L

.26232 .49886 L

.26139 .4959 L

.26045 .49284 L

.25951 .48969 L

.25858 .48643 L

.25764 .48307 L

.25671 .47959 L

.25577 .47598 L

.25484 .47225 L

.2539 .46837 L

.25297 .46433 L

.25203 .46013 L

.2511 .45575 L

.25016 .45117 L

.24922 .44637 L

.24829 .44133 L

.24735 .43601 L

.24642 .43038 L

.24548 .4244 L

.24455 .41801 L

.24361 .41112 L

.24268 .40362 L

.24174 .39537 L

.2408 .38611 L

.23987 .37542 L

.23893 .36248 L

.238 .34483 L

.23724 .30902 L

Mfstroke

.4149 .02237 m

.41481 .02234 L

.41387 .02207 L

.41293 .0218 L

.412 .02153 L

.41106 .02127 L

.41013 .02101 L

.40919 .02075 L

.40826 .0205 L

.40732 .02025 L

.40639 .02001 L

.40545 .01977 L

.40451 .01954 L

.40358 .01931 L

.40264 .01909 L

.40171 .01887 L

.40077 .01865 L

.39984 .01844 L

.3989 .01824 L

.39797 .01804 L

.39703 .01784 L

.3961 .01765 L

.39516 .01746 L

.39422 .01728 L

.39329 .01711 L

.39235 .01694 L

.39142 .01678 L

.39048 .01662 L

.38955 .01646 L

.38861 .01632 L

.38768 .01618 L

.38674 .01604 L

.38581 .01591 L

.38487 .01579 L

.38393 .01567 L

.383 .01556 L

.38206 .01546 L

.38113 .01536 L

.38019 .01527 L

.37926 .01518 L

.37832 .0151 L

.37739 .01503 L

.37645 .01497 L

.37551 .01491 L

.37458 .01486 L

.37364 .01482 L

.37271 .01478 L

.37177 .01475 L

.37084 .01473 L

.3699 .01472 L

Mistroke

.36897 .01472 L

.36803 .01472 L

.3671 .01473 L

.36616 .01475 L

.36522 .01477 L

.36429 .01481 L

.36335 .01485 L

.36242 .0149 L

.36148 .01496 L

.36055 .01504 L

.35961 .01511 L

.35868 .0152 L

.35774 .0153 L

.35681 .01541 L

.35587 .01552 L

.35493 .01565 L

.354 .01578 L

.35306 .01593 L

.35213 .01608 L

.35119 .01625 L

.35026 .01642 L

.34932 .01661 L

.34839 .01681 L

.34745 .01702 L

.34651 .01723 L

.34558 .01746 L

.34464 .01771 L

.34371 .01796 L

.34277 .01822 L

.34184 .0185 L

.3409 .01879 L

.33997 .01909 L

.33903 .0194 L

.3381 .01972 L

.33716 .02006 L

.33622 .02041 L

.33529 .02078 L

.33435 .02115 L

.33342 .02154 L

.33248 .02195 L

.33155 .02237 L

.33061 .0228 L

.32968 .02325 L

.32874 .02371 L

.32781 .02418 L

.32687 .02468 L

.32593 .02518 L

.325 .0257 L

.32406 .02624 L

.32313 .0268 L

Mistroke

.32219 .02737 L

.32126 .02795 L

.32032 .02856 L

.31939 .02918 L

.31845 .02982 L

.31751 .03047 L

.31658 .03115 L

.31564 .03184 L

.31471 .03255 L

.31377 .03328 L

.31284 .03403 L

.3119 .0348 L

.31097 .03559 L

.31003 .0364 L

.3091 .03723 L

.30816 .03808 L

.30722 .03895 L

.30629 .03985 L

.30535 .04077 L

.30442 .0417 L

.30348 .04267 L

.30255 .04366 L

.30161 .04467 L

.30068 .0457 L

.29974 .04676 L

.29881 .04785 L

.29787 .04896 L

.29693 .0501 L

.296 .05127 L

.29506 .05246 L

.29413 .05369 L

.29319 .05494 L

.29226 .05622 L

.29132 .05754 L

.29039 .05888 L

.28945 .06026 L

.28851 .06167 L

.28758 .06311 L

.28664 .06459 L

.28571 .0661 L

.28477 .06765 L

.28384 .06923 L

.2829 .07086 L

.28197 .07252 L

.28103 .07423 L

.2801 .07597 L

.27916 .07776 L

.27822 .0796 L

.27729 .08147 L

.27635 .0834 L

Mistroke

.27542 .08537 L

.27448 .08739 L

.27355 .08947 L

.27261 .0916 L

.27168 .09378 L

.27074 .09602 L

.2698 .09832 L

.26887 .10068 L

.26793 .10311 L

.267 .1056 L

.26606 .10816 L

.26513 .1108 L

.26419 .11351 L

.26326 .1163 L

.26232 .11917 L

.26139 .12214 L

.26045 .12519 L

.25951 .12834 L

.25858 .1316 L

.25764 .13496 L

.25671 .13845 L

.25577 .14205 L

.25484 .14579 L

.2539 .14967 L

.25297 .1537 L

.25203 .1579 L

.2511 .16228 L

.25016 .16686 L

.24922 .17166 L

.24829 .17671 L

.24735 .18202 L

.24642 .18765 L

.24548 .19363 L

.24455 .20003 L

.24361 .20692 L

.24268 .21441 L

.24174 .22267 L

.2408 .23193 L

.23987 .24261 L

.23893 .25555 L

.238 .27321 L

.23724 .30902 L

Mfstroke

.4149 .59567 m

.41864 .59453 L

.42238 .59334 L

.42612 .59209 L

.42987 .59079 L

.43361 .58945 L

.43735 .58807 L

.44109 .58665 L

.44483 .58519 L

.44858 .58369 L

.45232 .58217 L

.45606 .58061 L

.4598 .57903 L

.46354 .57742 L

.46729 .5758 L

.47103 .57415 L

.47477 .57248 L

.47851 .5708 L

.48225 .5691 L

.486 .56739 L

.48974 .56566 L

.49348 .56393 L

.49722 .56219 L

.50096 .56044 L

.50471 .55868 L

.50845 .55692 L

.51219 .55516 L

.51593 .55339 L

.51967 .55162 L

.52342 .54985 L

.52716 .54808 L

.5309 .54631 L

.53464 .54454 L

.53838 .54278 L

.54212 .54101 L

.54587 .53925 L

.54961 .5375 L

.55335 .53575 L

.55709 .53401 L

.56083 .53227 L

.56458 .53054 L

.56832 .52881 L

.57206 .5271 L

.5758 .52539 L

.57954 .52369 L

.58329 .52199 L

.58703 .52031 L

.59077 .51863 L

.59451 .51697 L

.59825 .51531 L

Mistroke

.602 .51366 L

.60574 .51203 L

.60948 .5104 L

.61322 .50879 L

.61696 .50718 L

.62071 .50559 L

.62445 .504 L

.62819 .50243 L

.63193 .50087 L

.63567 .49932 L

.63942 .49778 L

.64316 .49626 L

.6469 .49474 L

.65064 .49324 L

.65438 .49175 L

.65813 .49027 L

.66187 .48881 L

.66561 .48735 L

.66935 .48591 L

.67309 .48448 L

.67683 .48306 L

.68058 .48165 L

.68432 .48026 L

.68806 .47888 L

.6918 .47751 L

.69554 .47615 L

.69929 .47481 L

.70303 .47347 L

.70677 .47215 L

.71051 .47085 L

.71425 .46955 L

.718 .46827 L

.72174 .467 L

.72548 .46574 L

.72922 .46449 L

.73296 .46326 L

.73671 .46204 L

.74045 .46083 L

.74419 .45963 L

.74793 .45844 L

.75167 .45727 L

.75542 .45611 L

.75916 .45496 L

.7629 .45382 L

.76664 .4527 L

.77038 .45158 L

.77413 .45048 L

.77787 .44939 L

.78161 .44831 L

.78535 .44725 L

Mistroke

.78909 .44619 L

.79284 .44515 L

.79658 .44412 L

.80032 .4431 L

.80406 .44209 L

.8078 .44109 L

.81154 .44011 L

.81529 .43913 L

.81903 .43817 L

.82277 .43722 L

.82651 .43628 L

.83025 .43535 L

.834 .43443 L

.83774 .43352 L

.84148 .43263 L

.84522 .43174 L

.84896 .43086 L

.85271 .43 L

.85645 .42915 L

.86019 .4283 L

.86393 .42747 L

.86767 .42665 L

.87142 .42584 L

.87516 .42504 L

.8789 .42424 L

.88264 .42346 L

.88638 .42269 L

.89013 .42193 L

.89387 .42118 L

.89761 .42044 L

.90135 .41971 L

.90509 .41898 L

.90884 .41827 L

.91258 .41757 L

.91632 .41688 L

.92006 .41619 L

.9238 .41552 L

.92755 .41485 L

.93129 .4142 L

.93503 .41355 L

.93877 .41291 L

.94251 .41228 L

.94625 .41166 L

.95 .41105 L

.95374 .41044 L

.95748 .40985 L

.96122 .40926 L

.96496 .40868 L

.96871 .40811 L

.97245 .40755 L

Mistroke

.97619 .407 L

Mfstroke

.4149 .02237 m

.41864 .02351 L

.42238 .0247 L

.42612 .02594 L

.42987 .02724 L

.43361 .02858 L

.43735 .02996 L

.44109 .03139 L

.44483 .03285 L

.44858 .03434 L

.45232 .03587 L

.45606 .03742 L

.4598 .03901 L

.46354 .04061 L

.46729 .04224 L

.47103 .04389 L

.47477 .04556 L

.47851 .04724 L

.48225 .04894 L

.486 .05065 L

.48974 .05237 L

.49348 .0541 L

.49722 .05585 L

.50096 .0576 L

.50471 .05935 L

.50845 .06111 L

.51219 .06288 L

.51593 .06465 L

.51967 .06641 L

.52342 .06819 L

.52716 .06996 L

.5309 .07172 L

.53464 .07349 L

.53838 .07526 L

.54212 .07702 L

.54587 .07878 L

.54961 .08053 L

.55335 .08228 L

.55709 .08403 L

.56083 .08576 L

.56458 .0875 L

.56832 .08922 L

.57206 .09094 L

.5758 .09265 L

.57954 .09435 L

.58329 .09604 L

.58703 .09773 L

.59077 .0994 L

.59451 .10107 L

.59825 .10272 L

Mistroke

.602 .10437 L

.60574 .10601 L

.60948 .10763 L

.61322 .10925 L

.61696 .11085 L

.62071 .11245 L

.62445 .11403 L

.62819 .1156 L

.63193 .11716 L

.63567 .11871 L

.63942 .12025 L

.64316 .12178 L

.6469 .12329 L

.65064 .12479 L

.65438 .12628 L

.65813 .12776 L

.66187 .12923 L

.66561 .13068 L

.66935 .13213 L

.67309 .13356 L

.67683 .13497 L

.68058 .13638 L

.68432 .13777 L

.68806 .13916 L

.6918 .14053 L

.69554 .14188 L

.69929 .14323 L

.70303 .14456 L

.70677 .14588 L

.71051 .14719 L

.71425 .14848 L

.718 .14977 L

.72174 .15104 L

.72548 .1523 L

.72922 .15354 L

.73296 .15478 L

.73671 .156 L

.74045 .15721 L

.74419 .15841 L

.74793 .15959 L

.75167 .16076 L

.75542 .16193 L

.75916 .16308 L

.7629 .16421 L

.76664 .16534 L

.77038 .16645 L

.77413 .16755 L

.77787 .16864 L

.78161 .16972 L

.78535 .17079 L

Mistroke

.78909 .17184 L

.79284 .17289 L

.79658 .17392 L

.80032 .17494 L

.80406 .17594 L

.8078 .17694 L

.81154 .17793 L

.81529 .1789 L

.81903 .17986 L

.82277 .18082 L

.82651 .18176 L

.83025 .18269 L

.834 .1836 L

.83774 .18451 L

.84148 .18541 L

.84522 .18629 L

.84896 .18717 L

.85271 .18803 L

.85645 .18889 L

.86019 .18973 L

.86393 .19056 L

.86767 .19139 L

.87142 .1922 L

.87516 .193 L

.8789 .19379 L

.88264 .19457 L

.88638 .19534 L

.89013 .1961 L

.89387 .19685 L

.89761 .1976 L

.90135 .19833 L

.90509 .19905 L

.90884 .19976 L

.91258 .20046 L

.91632 .20116 L

.92006 .20184 L

.9238 .20252 L

.92755 .20318 L

.93129 .20384 L

.93503 .20449 L

.93877 .20512 L

.94251 .20575 L

.94625 .20638 L

.95 .20699 L

.95374 .20759 L

.95748 .20819 L

.96122 .20877 L

.96496 .20935 L

.96871 .20992 L

.97245 .21048 L

Mistroke

.97619 .21104 L

Mfstroke

1 0 0 r

.50845 .39176 m

.50658 .39252 L

.50471 .39328 L

.50283 .39404 L

.50096 .39481 L

.49909 .39557 L

.49722 .39634 L

.49535 .3971 L

.49348 .39787 L

.49161 .39864 L

.48974 .3994 L

.48787 .40017 L

.486 .40094 L

.48412 .40171 L

.48225 .40248 L

.48038 .40325 L

.47851 .40402 L

.47664 .4048 L

.47477 .40557 L

.4729 .40634 L

.47103 .40712 L

.46916 .40789 L

.46729 .40866 L

.46542 .40944 L

.46354 .41022 L

.46167 .41099 L

.4598 .41177 L

.45793 .41255 L

.45606 .41332 L

.45419 .4141 L

.45232 .41488 L

.45045 .41566 L

.44858 .41644 L

.44671 .41721 L

.44483 .41799 L

.44296 .41877 L

.44109 .41955 L

.43922 .42033 L

.43735 .42111 L

.43548 .4219 L

.43361 .42268 L

.43174 .42346 L

.42987 .42424 L

.428 .42502 L

.42612 .4258 L

.42425 .42658 L

.42238 .42736 L

.42051 .42814 L

.41864 .42893 L

.41677 .42971 L

Mistroke

.4149 .43049 L

.41303 .43127 L

.41116 .43205 L

.40929 .43283 L

.40741 .43362 L

.40554 .4344 L

.40367 .43518 L

.4018 .43596 L

.39993 .43674 L

.39806 .43752 L

.39619 .4383 L

.39432 .43908 L

.39245 .43986 L

.39058 .44064 L

.38871 .44142 L

.38683 .4422 L

.38496 .44298 L

.38309 .44375 L

.38122 .44453 L

.37935 .44531 L

.37748 .44608 L

.37561 .44686 L

.37374 .44764 L

.37187 .44841 L

.37 .44919 L

.36812 .44996 L

.36625 .45073 L

.36438 .4515 L

.36251 .45228 L

.36064 .45305 L

.35877 .45382 L

.3569 .45459 L

.35503 .45535 L

.35316 .45612 L

.35129 .45689 L

.34941 .45765 L

.34754 .45842 L

.34567 .45918 L

.3438 .45994 L

.34193 .4607 L

.34006 .46146 L

.33819 .46222 L

.33632 .46298 L

.33445 .46374 L

.33258 .46449 L

.33071 .46525 L

.32883 .466 L

.32696 .46675 L

.32509 .4675 L

.32322 .46825 L

Mistroke

.32135 .46899 L

.31948 .46974 L

.31761 .47048 L

.31574 .47122 L

.31387 .47196 L

.312 .4727 L

.31012 .47343 L

.30825 .47417 L

.30638 .4749 L

.30451 .47563 L

.30264 .47636 L

.30077 .47708 L

.2989 .47781 L

.29703 .47853 L

.29516 .47925 L

.29329 .47996 L

.29141 .48068 L

.28954 .48139 L

.28767 .4821 L

.2858 .4828 L

.28393 .4835 L

.28206 .48421 L

.28019 .4849 L

.27832 .4856 L

.27645 .48629 L

.27458 .48698 L

.2727 .48766 L

.27083 .48834 L

.26896 .48902 L

.26709 .4897 L

.26522 .49037 L

.26335 .49104 L

.26148 .4917 L

.25961 .49236 L

.25774 .49302 L

.25587 .49367 L

.254 .49432 L

.25212 .49497 L

.25025 .49561 L

.24838 .49624 L

.24651 .49687 L

.24464 .4975 L

.24277 .49812 L

.2409 .49874 L

.23903 .49935 L

.23716 .49996 L

.23529 .50056 L

.23341 .50116 L

.23154 .50175 L

.22967 .50233 L

Mistroke

.2278 .50291 L

.22593 .50349 L

.22406 .50406 L

.22219 .50462 L

.22032 .50517 L

.21845 .50572 L

.21658 .50626 L

.2147 .5068 L

.21283 .50733 L

.21096 .50785 L

.20909 .50836 L

.20722 .50886 L

.20535 .50936 L

.20348 .50985 L

.20161 .51033 L

.19974 .51081 L

.19787 .51127 L

.196 .51172 L

.19412 .51217 L

.19225 .51261 L

.19038 .51303 L

.18851 .51345 L

.18664 .51386 L

.18477 .51425 L

.1829 .51464 L

.18103 .51501 L

.17916 .51537 L

.17729 .51572 L

.17541 .51606 L

.17354 .51639 L

.17167 .5167 L

.1698 .517 L

.16793 .51728 L

.16606 .51755 L

.16419 .51781 L

.16232 .51805 L

.16045 .51828 L

.15858 .51849 L

.1567 .51868 L

.15483 .51885 L

.15296 .51901 L

.15109 .51915 L

.14922 .51928 L

.14735 .51938 L

.14548 .51946 L

.14361 .51952 L

.14174 .51956 L

.13987 .51958 L

.13799 .51957 L

.13612 .51954 L

Mistroke

.13425 .51949 L

.13238 .51941 L

.13051 .5193 L

.12864 .51917 L

.12677 .51901 L

.1249 .51881 L

.12303 .51859 L

.12116 .51834 L

.11929 .51805 L

.11741 .51773 L

.11554 .51737 L

.11367 .51698 L

.1118 .51654 L

.10993 .51607 L

.10806 .51555 L

.10619 .51499 L

.10432 .51438 L

.10245 .51373 L

.10058 .51303 L

.0987 .51227 L

.09683 .51146 L

.09496 .51059 L

.09309 .50966 L

.09122 .50867 L

.08935 .50761 L

.08748 .50649 L

.08561 .50529 L

.08374 .50401 L

.08187 .50265 L

.07999 .50121 L

.07812 .49968 L

.07625 .49806 L

.07438 .49633 L

.07251 .4945 L

.07064 .49256 L

.06877 .49049 L

.0669 .4883 L

.06503 .48597 L

.06316 .4835 L

.06129 .48087 L

.05941 .47807 L

.05754 .4751 L

.05567 .47193 L

.0538 .46854 L

.05193 .46493 L

.05006 .46106 L

.04819 .45692 L

.04632 .45246 L

.04445 .44766 L

.04258 .44247 L

Mistroke

.0407 .43684 L

.03883 .43069 L

.03696 .42394 L

.03509 .41645 L

.03322 .40807 L

.03135 .39851 L

.02948 .38735 L

.02761 .37374 L

.02574 .35553 L

.02381 .30902 L

Mfstroke

.50845 .22628 m

.50658 .22552 L

.50471 .22475 L

.50283 .22399 L

.50096 .22323 L

.49909 .22246 L

.49722 .2217 L

.49535 .22093 L

.49348 .22017 L

.49161 .2194 L

.48974 .21863 L

.48787 .21786 L

.486 .21709 L

.48412 .21632 L

.48225 .21555 L

.48038 .21478 L

.47851 .21401 L

.47664 .21324 L

.47477 .21247 L

.4729 .21169 L

.47103 .21092 L

.46916 .21014 L

.46729 .20937 L

.46542 .20859 L

.46354 .20782 L

.46167 .20704 L

.4598 .20627 L

.45793 .20549 L

.45606 .20471 L

.45419 .20393 L

.45232 .20316 L

.45045 .20238 L

.44858 .2016 L

.44671 .20082 L

.44483 .20004 L

.44296 .19926 L

.44109 .19848 L

.43922 .1977 L

.43735 .19692 L

.43548 .19614 L

.43361 .19536 L

.43174 .19458 L

.42987 .1938 L

.428 .19302 L

.42612 .19223 L

.42425 .19145 L

.42238 .19067 L

.42051 .18989 L

.41864 .18911 L

.41677 .18833 L

Mistroke

.4149 .18754 L

.41303 .18676 L

.41116 .18598 L

.40929 .1852 L

.40741 .18442 L

.40554 .18364 L

.40367 .18286 L

.4018 .18208 L

.39993 .18129 L

.39806 .18051 L

.39619 .17973 L

.39432 .17895 L

.39245 .17817 L

.39058 .17739 L

.38871 .17662 L

.38683 .17584 L

.38496 .17506 L

.38309 .17428 L

.38122 .1735 L

.37935 .17273 L

.37748 .17195 L

.37561 .17117 L

.37374 .1704 L

.37187 .16962 L

.37 .16885 L

.36812 .16808 L

.36625 .1673 L

.36438 .16653 L

.36251 .16576 L

.36064 .16499 L

.35877 .16422 L

.3569 .16345 L

.35503 .16268 L

.35316 .16191 L

.35129 .16115 L

.34941 .16038 L

.34754 .15962 L

.34567 .15885 L

.3438 .15809 L

.34193 .15733 L

.34006 .15657 L

.33819 .15581 L

.33632 .15505 L

.33445 .1543 L

.33258 .15354 L

.33071 .15279 L

.32883 .15204 L

.32696 .15128 L

.32509 .15054 L

.32322 .14979 L

Mistroke

.32135 .14904 L

.31948 .1483 L

.31761 .14755 L

.31574 .14681 L

.31387 .14607 L

.312 .14534 L

.31012 .1446 L

.30825 .14387 L

.30638 .14313 L

.30451 .1424 L

.30264 .14168 L

.30077 .14095 L

.2989 .14023 L

.29703 .13951 L

.29516 .13879 L

.29329 .13807 L

.29141 .13736 L

.28954 .13665 L

.28767 .13594 L

.2858 .13523 L

.28393 .13453 L

.28206 .13383 L

.28019 .13313 L

.27832 .13244 L

.27645 .13175 L

.27458 .13106 L

.2727 .13037 L

.27083 .12969 L

.26896 .12901 L

.26709 .12834 L

.26522 .12766 L

.26335 .127 L

.26148 .12633 L

.25961 .12567 L

.25774 .12501 L

.25587 .12436 L

.254 .12371 L

.25212 .12307 L

.25025 .12243 L

.24838 .12179 L

.24651 .12116 L

.24464 .12053 L

.24277 .11991 L

.2409 .11929 L

.23903 .11868 L

.23716 .11807 L

.23529 .11747 L

.23341 .11688 L

.23154 .11629 L

.22967 .1157 L

Mistroke

.2278 .11512 L

.22593 .11455 L

.22406 .11398 L

.22219 .11342 L

.22032 .11286 L

.21845 .11231 L

.21658 .11177 L

.2147 .11124 L

.21283 .11071 L

.21096 .11019 L

.20909 .10968 L

.20722 .10917 L

.20535 .10867 L

.20348 .10818 L

.20161 .1077 L

.19974 .10723 L

.19787 .10676 L

.196 .10631 L

.19412 .10586 L

.19225 .10543 L

.19038 .105 L

.18851 .10458 L

.18664 .10418 L

.18477 .10378 L

.1829 .1034 L

.18103 .10302 L

.17916 .10266 L

.17729 .10231 L

.17541 .10197 L

.17354 .10165 L

.17167 .10134 L

.1698 .10104 L

.16793 .10075 L

.16606 .10048 L

.16419 .10022 L

.16232 .09998 L

.16045 .09976 L

.15858 .09955 L

.1567 .09935 L

.15483 .09918 L

.15296 .09902 L

.15109 .09888 L

.14922 .09876 L

.14735 .09866 L

.14548 .09857 L

.14361 .09851 L

.14174 .09847 L

.13987 .09846 L

.13799 .09846 L

.13612 .09849 L

Mistroke

.13425 .09855 L

.13238 .09862 L

.13051 .09873 L

.12864 .09886 L

.12677 .09903 L

.1249 .09922 L

.12303 .09944 L

.12116 .09969 L

.11929 .09998 L

.11741 .10031 L

.11554 .10066 L

.11367 .10106 L

.1118 .10149 L

.10993 .10197 L

.10806 .10248 L

.10619 .10304 L

.10432 .10365 L

.10245 .1043 L

.10058 .10501 L

.0987 .10576 L

.09683 .10658 L

.09496 .10745 L

.09309 .10837 L

.09122 .10936 L

.08935 .11042 L

.08748 .11155 L

.08561 .11275 L

.08374 .11402 L

.08187 .11538 L

.07999 .11682 L

.07812 .11835 L

.07625 .11998 L

.07438 .1217 L

.07251 .12353 L

.07064 .12548 L

.06877 .12754 L

.0669 .12973 L

.06503 .13206 L

.06316 .13454 L

.06129 .13716 L

.05941 .13996 L

.05754 .14294 L

.05567 .14611 L

.0538 .14949 L

.05193 .15311 L

.05006 .15697 L

.04819 .16112 L

.04632 .16557 L

.04445 .17037 L

.04258 .17556 L

Mistroke

.0407 .1812 L

.03883 .18735 L

.03696 .1941 L

.03509 .20158 L

.03322 .20997 L

.03135 .21952 L

.02948 .23069 L

.02761 .2443 L

.02574 .2625 L

.02381 .30902 L

Mfstroke

.50845 .39176 m

.51312 .38986 L

.5178 .38796 L

.52248 .38608 L

.52716 .38419 L

.53183 .38232 L

.53651 .38045 L

.54119 .37858 L

.54587 .37673 L

.55054 .37488 L

.55522 .37304 L

.5599 .3712 L

.56458 .36938 L

.56925 .36756 L

.57393 .36575 L

.57861 .36395 L

.58329 .36216 L

.58796 .36038 L

.59264 .3586 L

.59732 .35684 L

.602 .35509 L

.60667 .35335 L

.61135 .35162 L

.61603 .34991 L

.62071 .3482 L

.62538 .34651 L

.63006 .34483 L

.63474 .34317 L

.63942 .34152 L

.64409 .33988 L

.64877 .33826 L

.65345 .33665 L

.65813 .33506 L

.6628 .33348 L

.66748 .33192 L

.67216 .33038 L

.67683 .32886 L

.68151 .32736 L

.68619 .32587 L

.69087 .3244 L

.69554 .32296 L

.70022 .32153 L

.7049 .32012 L

.70958 .31874 L

.71425 .31738 L

.71893 .31604 L

.72361 .31472 L

.72829 .31343 L

.73296 .31216 L

.73764 .31092 L

Mistroke

.74232 .3097 L

.747 .3085 L

.75167 .30734 L

.75635 .30619 L

.76103 .30508 L

.76571 .30399 L

.77038 .30293 L

.77506 .3019 L

.77974 .30089 L

.78442 .29991 L

.78909 .29897 L

.79377 .29805 L

.79845 .29716 L

.80313 .2963 L

.8078 .29547 L

.81248 .29466 L

.81716 .29389 L

.82184 .29315 L

.82651 .29244 L

.83119 .29176 L

.83587 .2911 L

.84054 .29048 L

.84522 .28989 L

.8499 .28932 L

.85458 .28879 L

.85925 .28828 L

.86393 .28781 L

.86861 .28736 L

.87329 .28694 L

.87796 .28655 L

.88264 .28618 L

.88732 .28585 L

.892 .28554 L

.89667 .28526 L

.90135 .285 L

.90603 .28477 L

.91071 .28457 L

.91538 .28439 L

.92006 .28424 L

.92474 .28411 L

.92942 .284 L

.93409 .28392 L

.93877 .28386 L

.94345 .28382 L

.94813 .2838 L

.9528 .28381 L

.95748 .28384 L

.96216 .28388 L

.96684 .28395 L

.97151 .28403 L

Mistroke

.97619 .28413 L

Mfstroke

.50845 .22628 m

.51312 .22818 L

.5178 .23007 L

.52248 .23196 L

.52716 .23384 L

.53183 .23572 L

.53651 .23759 L

.54119 .23945 L

.54587 .24131 L

.55054 .24316 L

.55522 .245 L

.5599 .24683 L

.56458 .24866 L

.56925 .25048 L

.57393 .25228 L

.57861 .25409 L

.58329 .25588 L

.58796 .25766 L

.59264 .25943 L

.59732 .26119 L

.602 .26294 L

.60667 .26468 L

.61135 .26641 L

.61603 .26813 L

.62071 .26983 L

.62538 .27152 L

.63006 .2732 L

.63474 .27487 L

.63942 .27652 L

.64409 .27816 L

.64877 .27978 L

.65345 .28139 L

.65813 .28298 L

.6628 .28455 L

.66748 .28611 L

.67216 .28765 L

.67683 .28917 L

.68151 .29068 L

.68619 .29216 L

.69087 .29363 L

.69554 .29508 L

.70022 .2965 L

.7049 .29791 L

.70958 .29929 L

.71425 .30065 L

.71893 .30199 L

.72361 .30331 L

.72829 .3046 L

.73296 .30587 L

.73764 .30712 L

Mistroke

.74232 .30834 L

.747 .30953 L

.75167 .3107 L

.75635 .31184 L

.76103 .31296 L

.76571 .31404 L

.77038 .31511 L

.77506 .31614 L

.77974 .31714 L

.78442 .31812 L

.78909 .31907 L

.79377 .31999 L

.79845 .32088 L

.80313 .32174 L

.8078 .32257 L

.81248 .32337 L

.81716 .32414 L

.82184 .32488 L

.82651 .3256 L

.83119 .32628 L

.83587 .32693 L

.84054 .32755 L

.84522 .32815 L

.8499 .32871 L

.85458 .32925 L

.85925 .32975 L

.86393 .33023 L

.86861 .33068 L

.87329 .3311 L

.87796 .33149 L

.88264 .33185 L

.88732 .33219 L

.892 .33249 L

.89667 .33278 L

.90135 .33303 L

.90603 .33326 L

.91071 .33347 L

.91538 .33364 L

.92006 .3338 L

.92474 .33393 L

.92942 .33403 L

.93409 .33412 L

.93877 .33418 L

.94345 .33421 L

.94813 .33423 L

.9528 .33422 L

.95748 .3342 L

.96216 .33415 L

.96684 .33409 L

.97151 .334 L

Mistroke

.97619 .3339 L

Mfstroke

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{567, 350.313},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.776525,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008g0001GPP10`40000100000800002008200000

P800P020P<30`<3L`:K:l00003<006H009T00<`00?l0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV

09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<003o03?o06Ko09Wo0<co

0?oo0000<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I

<c>I<fJI<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0

IYT0I/`0I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bI

I_nIIP3<IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0c

VC<cVFHcVITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<

VIW<VLc<VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`c

c?lcc01Vc3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03o

c3?oc6Koc9Woc<coc?ooc000oc<0ofH0oiT0ol`0ool0o`0coc<cofHcoiTcol`coolco`1Voc=VofIV

oiUVolaVoomVo`2Ioc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<o`3ooc?oofKooiWoolco

ooooo`0000410@820P<30`@410D51@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C

4a@D5?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooe;Q00<0hN40on7Sh@00D^400`3Qh@3ohN?Q

001Bh@030>7Q0?oQhn4005;Q00<0hN40on7Sh@00D^400`3Qh@3ohN?Q001Bh@030>7Q0?oQhn4005;Q

00<0hN40on7Sh@00D^400`3Qh@3ohN?Q001Bh@030>7Q06kQ4[kohF?Q001Bh@030>7Q06[Q1KhAh@Jn

on5Mh@00D^4306OQ0khLh@Fnon5Hh@00D^400`3Qh@1Th@>n8n44__oQEN4005;Q00<0hN40H^43_RWQ

0kkohE;Q001Bh@030>7Q063Q0[h_h@:non5@h@00D^400`3Qh@1Nh@>n<^44__oQC>4005;Q00<0hN40

GN42_SSQ0[kohD[Q001Bh@030>7Q05_Q0[hlh@Bnon56h@00D^400`3Qh@1Jh@:n@N42__oQA>4005;Q

00<0hN40FN42_TCQ0[kohD;Q001Bh@030>7Q05SQ0[i7h@:non50h@00D^4305OQ00>nhN40BN44__oQ

?>4005;Q00<0hN40E^400kkQh@1>h@:non4jh@00D^400`3Qh@1Eh@03_^7Q057Q0[kohCSQ001Bh@03

0>7Q05CQ00>nhN40E>42__oQ=^4005;Q00<0hN40Dn400kkQh@1Gh@03_^7Q0?oQ<n4005;Q00<0hN40

D^400kkQh@1Ih@:non4ch@00D^400`3Qh@1Ah@:nGN44__oQ;n4005;Q00<0hN40D>42_V;Q0[kohBgQ

001Bh@030>7Q053Q00>nhN40Hn42__oQ:n4005;Q00<0hN40Cn400kkQh@1Vh@:non4Yh@00D^400`3Q

h@1>h@03_^7Q06WQ0[kohBOQ001Bh@<0CN42_VgQ0[kohBGQ001Bh@030>7Q04gQ00>nhN40K^42__oQ

8n4005;Q00<0hN40C>400kkQh@1ah@:non4Qh@00D^400`3Qh@1;h@:nMN42__oQ7n4005;Q00<0hN40

Bn400kkQh@1fh@:non4Mh@00D^400`3Qh@1:h@03_^7Q07WQ1;kohAWQ001Bh@030>7Q04[Q00>nhN40

ON42__oQ5n4005;Q00<0hN40B^400kkQh@1oh@03_^7Q0?oQ5>4005;Q00<0hN40BN400kkQh@21h@:n

on4Dh@00D^400`3Qh@18h@:nQN42__oQ4^4005;Q00<0hN40B>400kkQh@26h@:non4@h@00D^4304OQ

00>nhN40RN42__oQ3^4005;Q00<0hN40An400kkQh@2;h@:non4<h@00D^400`3Qh@16h@03_^7Q08kQ

0[koh@[Q001Bh@030>7Q04KQ00>nhN40T>42__oQ2>4005;Q00<0hN40AN400kkQh@2Ch@Bnon44h@00

D^400`3Qh@15h@03_^7Q09OQ0[koh@;Q001Bh@030>7Q04GQ00>nhN40VN42__oQ001Bh@030>7Q04CQ

00>nhN40W>42__gQ001Bh@030>7Q04CQ00>nhN40W^42___Q0011h@D00^400`3Qh@04h@d??>400kkQ

h@2Qh@:nnN4004?Q00D0hN7Q00073`?Q00<0hN401n483cCQ00>nhN40Xn42__OQ000mh@<00n400`0?

3`023`03h@3Q00OQ100>h@H?;N400kkQh@2Vh@>nm>40047Q0`l3h@030>4000SQ00<0hN405N453bSQ

00>nhN40ZN42__;Q000oh@8?0^401`3QhN40h@002>400`3Qh@0Jh@@?9>400kkQh@2[h@:nl>4003gQ

0Pl3h@801>400`3Qh@07h@030>7Q01kQ10lOh@03_^7Q0:kQ0[k^h@00>n423aGQ00<0hN408^443a_Q

00>nhN40/>42_^cQ000jh@033n7Q01GQ00<0hN409^443aOQ00>nhN40/^44_^SQ000hh@8?6>400`3Q

h@0Zh@8?5>400kkQh@2gh@:ni^4003OQ00<?hN406>400`3Qh@0/h@@?4>400kkQh@2ih@:ni>4003KQ

00<?hN406N400`3Qh@0`h@<?3>400kkQh@2lh@:nh^4003CQ0PlLh@030>7Q03?Q0`l9h@03_^7Q0;kQ

0[kPh@00<n400`oQh@0Lh@<0=^433`KQ00>nhN40`>44_]cQ000bh@033n7Q01gQ00<0hN40>N433`;Q

00>nhN40aN42_][Q000ah@033n7Q01kQ00<0hN40?>433lWQ0[kHh@00<>400`oQh@0Oh@030>7Q03kQ

00Bn3`l?b>43_]GQ000_h@033n7Q023Q00<0hN40?^401;kQhN433lSQ0[kCh@00;^400`oQh@0Qh@03

0>7Q03gQ00>nhN401N433lOQ0[kAh@00;^400`oQh@0Qh@030>7Q03gQ00>nhN402>423lOQ1;k=h@00

;N400`oQh@0Rh@030>7Q03gQ00>nhN402^423lWQ0[k;h@00;>400`oQh@0Sh@030>7Q03cQ00>nhN40

3N433lSQ0[k9h@00:n400`oQh@0Th@030>7Q03cQ00>nhN404>423lSQ1;k5h@00:n400`oQh@0Th@03

0>7Q03cQ00>nhN404^433lWQ0[k3h@00:^400`oQh@0Uh@<0?>400kkQh@0Eh@<?b>44_[oQ000Yh@03

3n7Q02KQ00<0hN40>n400kkQh@0Ih@8?b^42_[gQ000Yh@033n7Q02KQ00<0hN40>n400kkQh@0Kh@<?

bN44_[WQ000Xh@033n7Q02OQ00<0hN40>n400kkQh@0Nh@<?b^42_[OQ000Xh@033n7Q02OQ00<0hN40

>n400kkQh@0Qh@8?b^43_[CQ000Wh@033n7Q02SQ00<0hN40>^400kkQh@0Th@<?b^42_[;Q000Wh@03

3n7Q02SQ00<0hN40>^400kkQh@0Wh@8?b^44_ZkQ000Vh@033n7Q02WQ00<0hN40>^400kkQh@0Yh@<?

bn42_ZcQ000Vh@033n7Q02WQ00<0hN40>^400kkQh@0/h@8?bn44_ZSQ000Uh@033n7Q02[Q00<0hN40

>^400kkQh@0^h@8?cN42_ZKQ000Uh@033n7Q02[Q00<0hN40>^400kkQh@0`h@8?cN44_Z;Q000Th@03

3n7Q02_Q0`0jh@03_^7Q03;Q0`o>h@BnW^4002CQ00<?hN40:n400`3Qh@0ih@03_^7Q03KQ0Po@h@Bn

V^4002?Q00<?hN40;>400`3Qh@0ih@03_^7Q03SQ0`oAh@:nV>4002?Q00<?hN40;>400`3Qh@0ih@03

_^7Q03_Q0PoAh@>nUN4002?Q00<?hN40;>400`3Qh@0ih@03_^7Q03gQ0`oAh@BnTN4002;Q00<?hN40

;N400`3Qh@0ih@03_^7Q043Q0PoCh@BnSN4002;Q00<?hN40;N400`3Qh@0hh@03_^7Q04?Q0`oDh@Bn

RN4002;Q00<?hN40;N400`3Qh@0hh@03_^7Q04KQ0PoFh@BnQN40027Q00<?hN40;^400`3Qh@0hh@03

_^7Q04SQ0`oGh@BnPN40027Q00<?hN40;^400`3Qh@0hh@03_^7Q04_Q0PoIh@BnON40027Q00<?hN40

;^400`3Qh@0hh@03_^7Q04gQ0`oJh@BnNN40023Q00<?hN40;n4303OQ00>nhN40DN423mcQ1;ieh@00

8>400`oQh@0_h@030>7Q03OQ00>nhN40D^433mkQ0kibh@008>400`oQh@0_h@030>7Q03OQ00>nhN40

EN423moQ1;i^h@008>400`oQh@0_h@030>7Q03OQ00>nhN40En433n3Q1[iXh@008>400`oQh@0_h@03

0>7Q03OQ00>nhN40F^423nCQ1;iTh@008>400`oQh@0_h@030>7Q03OQ00>nhN40G>433nGQ1[iNh@00

8>400`oQh@0_h@030>7Q03OQ00>nhN40Gn423nWQ1;iJh@007n400`oQh@0`h@030>7Q03KQ00>nhN40

H^433n[Q1KiEh@007n400`oQh@0`h@030>7Q03KQ00>nhN40IN423ngQ1[i?h@007n400`oQh@0Vh@03

0>7Q00OQ00<0hN40=^400kkQh@1Wh@<?l>44_T_Q000Oh@033n7Q02GQ00<0h@002>400`3Qh@0fh@03

_^7Q06[Q0Pobh@JnAN4001kQ00<?hN408N4300CQ00<0hN401^4403GQ00>nhN40K>423oKQ2;hmh@00

7^400`oQh@0Vh@802N400`3Qh@0fh@03_^7Q06kQ0`okh@Jn=n4001kQ00<?hN409^400`3Qh@08h@03

0>7Q03GQ00>nhN40L^423ooQ1Khbh@007^400`oQh@0Vh@<02>400`3Qh@0eh@03_^7Q07CQ0Pooh@?Q

0[h`h@007^400`oQh@0ah@030>7Q03GQ00>nhN40M^423ooQ<n4001gQ00<?hN40<^400`3Qh@0eh@03

_^7Q07SQ0`oohC3Q000Mh@033n7Q03;Q00<0hN40=N400kkQh@1kh@8?on4^h@007N400`oQh@0bh@03

0>7Q03GQ00>nhN40ON433ooQ:n4001gQ00<?hN40<^400`3Qh@0eh@03_^7Q083Q0`oohBSQ000Mh@03

3n7Q03;Q00<0hN40=N400kkQh@23h@8?on4Vh@007>400`oQh@0ch@<0=N400kkQh@25h@<?on4Sh@00

7>400`oQh@0ch@030>7Q03CQ00>nhN40RN433ooQ8>4001cQ00<?hN40<n400`3Qh@0dh@03_^7Q08cQ

0PoohAkQ000Lh@033n7Q03?Q00<0hN40=>400kkQh@2>h@<?on4Kh@007>400`oQh@0ch@030>7Q03CQ

00>nhN40TN423ooQ6N4001cQ00<?hN40<n400`3Qh@0dh@03_^7Q09?Q0PoohAOQ000Lh@033n7Q03?Q

00<0hN40=>400kkQh@2Eh@<?on4Dh@006n400`oQh@0dh@030>7Q03CQ00>nhN40V>423ooQ4^4001_Q

00<?hN40=>400`3Qh@0dh@03_^7Q09[Q0`ooh@oQ000Kh@033n7Q03CQ00<0hN40=>400kkQh@2Mh@8?

on4=h@006n400`oQh@0dh@030>7Q03CQ00>nhN40Wn433ooQ2^4001_Q00<?hN40=>4303CQ00>nhN40

X^423ooQ2>4001_Q00<?hN40=>400`3Qh@0dh@03_^7Q0:CQ0Pooh@KQ000Kh@033n7Q03CQ00<0hN40

<n400kkQh@2Wh@<?on43h@006n400`oQh@0dh@030>7Q03?Q00>nhN40Z^423ooQ0N4001[Q00<?hN40

=N400`3Qh@0ch@03_^7Q0:cQ0`omh@006^400`oQh@0eh@030>7Q03?Q00>nhN40[n423o_Q000Jh@03

3n7Q03GQ00<0hN40<n400kkQh@2ah@<?n>4001[Q00<?hN40=N400`3Qh@0ch@03_^7Q0;CQ0Pofh@00

6^400`oQh@0eh@030>7Q03?Q00>nhN40]^453o7Q000Jh@033n7Q03GQ00<0hN40<n400kkQh@2kh@8?

kn4001[Q00<?hN40=N400`3Qh@0ch@03_^7Q0;gQ0`o/h@006^400`oQh@0eh@<0<n400kkQh@30h@8?

j^4001[Q00<?hN40=N400`3Qh@0ch@03_^7Q0<;Q0`oWh@006^400`oQh@0eh@030>7Q03?Q00>nhN40

aN423nGQ000Jh@033n7Q03GQ00<0hN40<n400kkQh@37h@8?hn4001[Q00<?hN40=N400`3Qh@0ch@03

_^7Q0<WQ0`oPh@006^400`oQh@0eh@030>7Q03?Q00>nhN40c>453m_Q000Jh@033n7Q03GQ00<0hN40

<n400kkQh@3Ah@8?fN4001[Q00<?hN40=N400`3Qh@0ch@03_^7Q02?Q1@02h@030>7Q05SQ0`03h@03

0>7Q04GQ0PlAh@<00^4305WQ0`03h@<0G>4001[Q00<?hN40=N400`3Qh@0ch@03_^7Q02GQ00L0hN7Q

0>4005WQ00<0hN400^400`3Q0018h@<?3^400`3Qh@02h@030>7Q05WQ00<0hN401>400`3Qh@0?hA`?

<>4001WQ00<?hN40=^400`3Qh@0ch@03_^7Q02GQ00L0hN7Q0>4005[Q00L0hN7Q0>4004_Q1@l:h@03

0>7Q00;Q00<0hN40FN401@3QhN4001<?C>4001WQ00<?hN40=^400`3Qh@0ch@03_^7Q02GQ00<0hN40

0^400`3Qh@1Ih@070>7Qh@3Q001@h@8?2>400`3Qh@02h@030>7Q05;Q30l00n40h@1Lh@006N400`oQ

h@0fh@<0<n400kkQh@0Uh@070>7Qh@3Q001Ih@030>4000;Q00<0h@00D^433`CQ00<0h@000^400`3Q

0019h@X?1^400`3Q0003h@80GN4001WQ00<?hN40=^400`3Qh@0bh@03_^7Q02GQ0P04h@030>7Q05WQ

00<0hN400^400`3Qh@1Dh@8?0n400`3Qh@02h@030>7Q047Q1`lAh@030>7Q00?Q00<0hN40Fn4001WQ

00<?hN40=^400`3Qh@0bh@03_^7Q0>GQ1@m2h@D?O>4001WQ00<?hN40=^400`3Qh@0bh@03_^7Q0>[Q

0Plih@L?PN4001WQ00<?hN40=^400`3Qh@0bh@03_^7Q0>cQ0`lah@D?R>4001WQ00<?hN40=^400`3Q

h@0bh@03_^7Q0>oQ1@lWh@D?SN4001WQ00<?hN40=^400`3Qh@0bh@03_^7Q0?CQ0PlPh@D?T^4001WQ

00<?hN40=^400`3Qh@0bh@03_^7Q0?KQ1@lFh@D?Un4001WQ00<?hN40=^400`3Qh@0bh@03_^7Q0?_Q

0Pl?h@D?R>44013Q000Ih@033n7Q03KQ00<0hN40<^400kkQh@3mh@D?1^443hgQ0`0Ah@003>4=0003

3`0006/000>n0000o`0300H?PP0Ah@030>7Q00oQ000Ih@033n7Q00GQ00<0hN405^400`3Qh@0Eh@03

0>7Q01GQ00<0hN405N400`3Qh@02h@03_^7Q017Q00<0hN405N400`3Qh@0Eh@030>7Q01GQ00<0hN40

5^400`3Qh@0Eh@030>7Q01GQ00<0hN405N400`3Qh@0Fh@030>7Q01GQ00<0hN404^493a;Q00<0hN40

5^400`3Qh@0Eh@030>7Q01GQ00<0hN405N400`3Qh@0Kh@804N4001WQ00<?hN401N400`3Qh@0Fh@03

0>7Q01GQ00<0hN405N400`3Qh@0Eh@030>7Q00;Q00>nhN404N400`3Qh@0Eh@030>7Q01GQ00<0hN40

5N400`3Qh@0Fh@030>7Q01GQ00<0hN405N400`3Qh@0Eh@030>7Q01KQ00<0hN405N400`3Qh@0@h@8?

0n400`3Qh@03h@D?3N400`3Qh@0Fh@030>7Q01GQ00<0hN405N400`3Qh@0Eh@030>7Q02kQ000Ih@03

3n7Q03KQ00<0hN40<^400kkQh@0Yh@030>7Q05kQ00<0hN40G^400`3Qh@0;h@D?4>433c_Q00<0hN40

G^4001WQ00<?hN40=^400`3Qh@0bh@03_^7Q02WQ00<0hN40G^400`3Qh@1Nh@030>7Q00WQ0PlHh@D?

=^400`3Qh@1Nh@006N400`oQh@0fh@030>7Q03;Q00>nhN40l^453aoQ10nCh@006N400`oQh@0fh@03

0>7Q03;Q00>nhN40kn433bSQ1@n>h@006N400`oQh@0fh@030>7Q03;Q00>nhN40kN423c3Q1`n7h@00

6N400`oQh@0fh@030>7Q03;Q00>nhN40j>453cWQ1@n2h@006N400`oQh@0fh@030>7Q03;Q00>nhN40

i^423d?Q20mjh@006N400`oQh@0fh@030>7Q03?Q00>nhN40h^433dgQ1`mch@006N400`oQh@0fh@<0

<n400kkQh@3Mh@D?En4:3fWQ000Ih@033n7Q03KQ00<0hN40<n400kkQh@3Kh@8?I^4<3egQ000Jh@03

3n7Q03GQ00<0hN40<n400kkQh@3Hh@<?M>4]3c3Q000Jh@033n7Q03GQ00<0hN40<n400kkQh@3Fh@8?

e>4001[Q00<?hN40=N400`3Qh@0ch@03_^7Q0=CQ0PoFh@006^400`oQh@0eh@030>7Q03?Q00>nhN40

cn453mSQ000Jh@033n7Q03GQ00<0hN40<n400kkQh@3<h@<?gN4001[Q00<?hN40=N400`3Qh@0ch@03

_^7Q0<[Q0PoPh@006^400`oQh@0eh@030>7Q03?Q00>nhN40b>423n;Q000Jh@033n7Q03GQ00<0hN40

<n400kkQh@35h@<?i>4001[Q00<?hN40=N400`3Qh@0ch@03_^7Q0<?Q0PoWh@006^400`oQh@0eh@<0

<n400kkQh@2nh@D?jN4001[Q00<?hN40=N400`3Qh@0ch@03_^7Q0;_Q0`o^h@006^400`oQh@0eh@03

0>7Q03?Q00>nhN40^N423o7Q000Jh@033n7Q03GQ00<0hN40<n400kkQh@2gh@8?ln4001[Q00<?hN40

=N400`3Qh@0ch@03_^7Q0;CQ0`oeh@006^400`oQh@0eh@030>7Q03?Q00>nhN40/^423oSQ000Jh@03

3n7Q03GQ00<0hN40<n400kkQh@2_h@<?n^4001[Q00<?hN40=N400`3Qh@0ch@03_^7Q0:gQ0Pomh@00

6n400`oQh@0dh@030>7Q03?Q00>nhN40Z^433ooQ000Kh@033n7Q03CQ00<0hN40<n400kkQh@2Xh@8?

on43h@006n400`oQh@0dh@030>7Q03CQ00>nhN40YN423ooQ1N4001_Q00<?hN40=>4303CQ00>nhN40

X^433ooQ1n4001_Q00<?hN40=>400`3Qh@0dh@03_^7Q0:3Q0Pooh@[Q000Kh@033n7Q03CQ00<0hN40

=>400kkQh@2Kh@D?on4<h@006n400`oQh@0dh@030>7Q03CQ00>nhN40V>433ooQ4N4001_Q00<?hN40

=>400`3Qh@0dh@03_^7Q09KQ0PoohACQ000Lh@033n7Q03?Q00<0hN40=>400kkQh@2Dh@8?on4Fh@00

7>400`oQh@0ch@030>7Q03CQ00>nhN40TN433ooQ6>4001cQ00<?hN40<n400`3Qh@0dh@03_^7Q08oQ

0PoohA_Q000Lh@033n7Q03?Q00<0hN40=>400kkQh@2<h@<?on4Mh@007>400`oQh@0ch@030>7Q03CQ

00>nhN40R^423ooQ8>4001cQ00<?hN40<n4303GQ00>nhN40Qn423ooQ8^4001cQ00<?hN40<n400`3Q

h@0eh@03_^7Q08CQ0`oohBCQ000Mh@033n7Q03;Q00<0hN40=N400kkQh@22h@8?on4Wh@007N400`oQ

h@0bh@030>7Q03GQ00>nhN40On433ooQ:N4001gQ00<?hN40<^400`3Qh@0eh@03_^7Q07gQ0PoohBcQ

000Mh@033n7Q03;Q00<0hN40=N400kkQh@1jh@<?on4^h@007N400`oQh@0bh@030>7Q03GQ00>nhN40

N>423ooQ<N4001kQ00<?hN40<N400`3Qh@0eh@03_^7Q07GQ0`oohC?Q000Nh@033n7Q037Q00<0hN40

=N400kkQh@1dh@033n7Q0?oQ0N43_S3Q000Nh@033n7Q02OQ00<0hN401n400`3Qh@0fh@03_^7Q073Q

0`onh@Fn<n4001kQ00<?hN409^400`3Q0008h@030>7Q03KQ00>nhN40K^423o_Q1[hhh@007^400`oQ

h@0Xh@030>7Q00KQ100eh@03_^7Q06_Q0`ogh@Jn?^4001oQ00<?hN409N4200WQ00<0hN40=^400kkQ

h@1Yh@8?m>46_TCQ000Oh@033n7Q02GQ00<0hN402>400`3Qh@0fh@03_^7Q06KQ0`o`h@JnB^4001oQ

00<?hN409N4300SQ00<0hN40=^400kkQh@1Th@8?kN46_U3Q000Oh@033n7Q033Q00<0hN40=^400kkQ

h@1Qh@<?k>43_UKQ000Ph@033n7Q02oQ00<0hN40=n400kkQh@1Nh@8?jN46_UWQ000Ph@033n7Q02oQ

00<0hN40=n400kkQh@1Kh@<?in44_UoQ000Ph@033n7Q02oQ00<0hN40=n400kkQh@1Ih@8?i>46_V?Q

000Ph@033n7Q02oQ00<0hN40=n400kkQh@1Gh@8?h^44_VWQ000Ph@033n7Q02oQ00<0hN40=n400kkQ

h@1Dh@<?h>44_VgQ000Ph@033n7Q02oQ00<0hN40=n400kkQh@1Bh@8?g^45_W7Q000Ph@033n7Q02oQ

0`0hh@03_^7Q04oQ0`oKh@BnM^40027Q00<?hN40;^400`3Qh@0hh@03_^7Q04gQ0PoJh@BnN^40027Q

00<?hN40;^400`3Qh@0hh@03_^7Q04[Q0`oHh@BnO^40027Q00<?hN40;^400`3Qh@0hh@03_^7Q04SQ

0PoGh@BnP^4002;Q00<?hN40;N400`3Qh@0hh@03_^7Q04GQ0`oEh@BnQ^4002;Q00<?hN40;N400`3Q

h@0hh@03_^7Q04?Q0PoDh@BnR^4002;Q00<?hN40;N400`3Qh@0ih@03_^7Q03oQ0`oBh@BnS^4002?Q

00<?hN40;>400`3Qh@0ih@03_^7Q03gQ0PoCh@:nT^4002?Q00<?hN40;>400`3Qh@0ih@03_^7Q03[Q

0`oBh@>nU>4002CQ00<?hN40:n400`3Qh@0ih@03_^7Q03SQ0PoAh@BnUn4002CQ00<?hN40:n400`3Q

h@0ih@03_^7Q03GQ0`o?h@BnVn4002CQ00<?hN40:n4303[Q00>nhN40<^423m3Q0[jOh@009N400`oQ

h@0Zh@030>7Q03[Q00>nhN40;n433lkQ1;jQh@009N400`oQh@0Zh@030>7Q03[Q00>nhN40;^400`oQ

h@3;h@BnYN4002KQ00<?hN40:N400`3Qh@0jh@03_^7Q02_Q0`o<h@:nZN4002KQ00<?hN40:N400`3Q

h@0jh@03_^7Q02WQ0Po;h@BnZn4002OQ00<?hN40:>400`3Qh@0jh@03_^7Q02KQ0`o;h@:n[n4002OQ

00<?hN40:>400`3Qh@0jh@03_^7Q02CQ0Po:h@Bn/N4002SQ00<?hN409n400`3Qh@0kh@03_^7Q023Q

0`o;h@03_^7Q0;?Q000Xh@033n7Q02OQ00<0hN40>n400kkQh@0Mh@<?b^44_[KQ000Yh@033n7Q02KQ

00<0hN40>n400kkQh@0Kh@8?bn42_[[Q000Zh@033n7Q02GQ00<0hN40>n400kkQh@0Hh@<?bN44_[cQ

000Zh@033n7Q02GQ0`0lh@03_^7Q01CQ0`o:h@:n`>4002_Q00<?hN409>400`3Qh@0lh@03_^7Q01;Q

0Po9h@Bn`^4002cQ00<?hN408n400`3Qh@0lh@03_^7Q00oQ0`o9h@:na^4002cQ00<?hN408n400`3Q

h@0lh@03_^7Q00cQ0`o:h@:nb>4002gQ00<?hN408^400`3Qh@0mh@03_^7Q00[Q0Po8h@Bnb^4002kQ

00<?hN408N400`3Qh@0mh@03_^7Q00OQ0`o8h@:nc^4002oQ00<?hN408>400`3Qh@0mh@03_^7Q00CQ

0`o9h@:nd>40033Q00<?hN407n400`3Qh@0nh@03_^7Q00<?b>44_];Q000`h@033n7Q01oQ00<0hN40

?^433l[Q00>nhN40e>40037Q00<?hN407^400`3Qh@0kh@<?00>nhN40b>42_]OQ000bh@8?7^4303SQ

0`l4h@03_^7Q0<?Q1;kIh@00=>400`oQh@0Kh@030>7Q03GQ0`l7h@03_^7Q0<7Q0[kMh@00=N400`oQ

h@0Jh@030>7Q03;Q0`l:h@03_^7Q0;oQ0[kOh@00=^400`oQh@0Ih@030>7Q02oQ0`l>h@03_^7Q0;cQ

0[kQh@00=n423aWQ00<0hN40:n443a7Q00>nhN40^>44_^?Q000ih@033n7Q01KQ00<0hN40:N433aCQ

00>nhN40]^42_^OQ000jh@8?5^400`3Qh@0Uh@@?6>400kkQh@2ch@:njN4003cQ0PlDh@030>7Q027Q

10lLh@03_^7Q0;7Q0[k[h@00?^423a;Q00<0hN407N443b3Q00>nhN40[n42_^gQ0010h@8?1002h@03

0>7Q00OQ00<0hN406N443bGQ00>nhN40Z^44_^oQ0012h@<?0^400`3Q0008h@030>7Q01CQ1@lYh@03

_^7Q0:SQ0[kch@00@n400`3Q3`033`030>7Q00KQ100<h@L?;n400kkQh@2Vh@03_^7Q0??Q0013h@06

0>7Qh@3Q2`l2h@`?=^400kkQh@2Th@:nm^4004?Q00L0hN7Q0>4000SQ00@0h@l?@^400kkQh@2Rh@:n

n>4004;Q0P04h@030>7Q00OQ00<0hN40A>400kkQh@2Oh@:nn^4005;Q00<0hN40A>400kkQh@2Mh@:n

o>4005;Q00<0hN40AN400kkQh@2Hh@Bno^4005;Q00<0hN40AN400kkQh@2Fh@:non43h@00D^400`3Q

h@16h@03_^7Q09?Q0[koh@GQ001Bh@030>7Q04KQ00>nhN40TN42__oQ1n4005;Q00<0hN40An400kkQ

h@2>h@:non49h@00D^400`3Qh@17h@03_^7Q08cQ0[koh@_Q001Bh@<0B>400kkQh@29h@:non4=h@00

D^400`3Qh@18h@03_^7Q08OQ0[koh@oQ001Bh@030>7Q04WQ00>nhN40Q>42__oQ4N4005;Q00<0hN40

BN400kkQh@20h@Bnon4Ch@00D^400`3Qh@1:h@03_^7Q07kQ00>nhN40on4Eh@00D^400`3Qh@1:h@03

_^7Q07cQ0[kohASQ001Bh@030>7Q04[Q0[ikh@:non4Jh@00D^400`3Qh@1;h@03_^7Q07OQ0[kohAcQ

001Bh@030>7Q04cQ00>nhN40M>42__oQ7^4005;Q00<0hN40C>400kkQh@1bh@:non4Ph@00D^400`3Q

h@1=h@03_^7Q06oQ0[kohB;Q001Bh@<0C^400kkQh@1/h@:non4Th@00D^400`3Qh@1>h@:nJn42__oQ

9^4005;Q00<0hN40Cn400kkQh@1Uh@Bnon4Xh@00D^400`3Qh@1@h@03_^7Q06;Q0[kohBcQ001Bh@03

0>7Q057Q00>nhN40Gn42__oQ;^4005;Q00<0hN40DN42_UkQ0[kohC3Q001Bh@030>7Q05;Q0[iKh@:n

on4bh@00D^400`3Qh@1Ch@:nF>42__oQ=>4005;Q00<0hN40E>42_UKQ00>nhN40on4dh@00D^400`3Q

h@1Eh@:nDN44__oQ=n4005;Q0`1Fh@:nC^42__oQ>n4005;Q00<0hN40En42_T_Q0[kohCgQ001Bh@03

0>7Q05SQ0[i8h@:non4oh@00D^400`3Qh@1Jh@03_^7Q04?Q0[kohD7Q001Bh@030>7Q05[Q0[i0h@Bn

on53h@00D^400`3Qh@1Lh@:n?>42__oQAn4005;Q00<0hN40GN42_SOQ1;kohDWQ001Bh@030>7Q05oQ

0[hch@:non5=h@00D^400`3Qh@1Qh@:n;N44__oQCn4005;Q00<0hN40Hn42_RSQ0kkohE?Q001Bh@03

0>7Q06GQ0khQh@Bnon5Fh@00D^4306SQ0khIh@Jnon5Ih@00D^400`3Qh@1[h@Jn3N47__oQG^4005;Q

00<0hN40L>4>__oQIN4005;Q00<0hN40on7Sh@00D^400`3Qh@3ohN?Q001Bh@030>7Q0?oQhn4005;Q

00<0hN40on7Sh@00D^400`3Qh@3ohN?Q001Bh@030>7Q0?oQhn4005;Q00<0hN40on7Sh@00D^400`3Q

h@3ohN?Q003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ

>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQon4ih@00on42h@8000?Q00001^4400OQ00<0hN40

0^400`3Qh@3ohAWQ003oh@?Q00<0h@004^401`3QhN40h@00on4Jh@00on43h@<01n4400OQ00L0hN7Q

0>400?oQ6^400?oQ0n40103Q000Bh@060>7Q0>40on4Jh@00D>420;3Q00<0hN404N400`3Q0002h@03

0>400?oQ6^40057Q00<0hN40[N4201?Q0`03h@030>7Q0?oQ6N4004oQ0`02h@030>7Q0?oQhN4004kQ

00P0hN40h@3Q0?oQh^4004kQ00P0hN40h@3Q0?oQh^4004oQ0`001>40h@3ohN;Q001Ch@030>400?oQ

h^4005CQ00<0hN40on7Qh@00on7ohCWQ003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400001

\

\>"],

  ImageRangeCache->{{{0, 566}, {349.313, 0}} -> {14.2998, -14.8707, 0.0206228,

   0.0928385}}]

}, Open  ]]

}, Open  ]],



Cell[TextData[{

  "\nAt any point on a branch of solutions defined by (q0,p0,w0)  we may \n\

calculate the deflection of the plate",

  StyleBox[" w",

    FontSlant->"Italic"],

  "(r). This is done by using (2.5), \nfrom which we get   ",

  StyleBox["w",

    FontSlant->"Italic"],

  "(",

  StyleBox["r",

    FontSlant->"Italic"],

  ") = -",

  StyleBox["r ",

    FontSlant->"Italic"],

  StyleBox["W1(",

    FontSize->16],

  StyleBox["r",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[") -2 W(",

    FontSize->16],

  StyleBox["r",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[

  "). \nWe can plot a sequence of deflection curves along a branch of \

solutions \nby using the following code.    ",

    FontSize->16]

}], "Input",

  FormatType->TextForm,

  FontSize->16],



Cell[CellGroupData[{



Cell[BoxData[

    \(Length[k38loopf]\)], "Input"],



Cell[BoxData[

    \(1990\)], "Output"]

}, Open  ]],



Cell[BoxData[

    \("\<k38loopf is in k38loopf\>"\)], "Input"],



Cell[CellGroupData[{



Cell[BoxData[

    \(loop = \n\ \ \ \ \ 

      Show[Graphics[{

            Line[Table[{k38loopf[\([i, 2]\)], k38loopf[\([i, 3, 1]\)]}, {i, 

                  1990}]]}\ ], \n\ \ \ \ \ \ \ \ \ \ Axes -> Automatic, 

        AxesLabel -> {a, q0}, \ PlotRange -> All\ ]\)], "Input"],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{288, 177.938},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l00003<006H009T00<`00?l0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV

09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<003o03?o06Ko09Wo0<co

0?oo0000<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I

<c>I<fJI<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0

IYT0I/`0I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bI

I_nIIP3<IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0c

VC<cVFHcVITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<

VIW<VLc<VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`c

c?lcc01Vc3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03o

c3?oc6Koc9Woc<coc?ooc000oc<0ofH0oiT0ol`0ool0o`0coc<cofHcoiTcol`coolco`1Voc=VofIV

oiUVolaVoomVo`2Ioc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<o`3ooc?oofKooiWoolco

ooooo`0000410@820P<30`@410D51@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C

4a@D5?okl:2PY820P?l0003o0?oo0000ool0o`3oooooobcQ00<0hN40lN4002cQ00<0hN40lN4002cQ

0P3bh@00;>400`3Qh@1[h@l0Mn4002cQ00<0hN40I>4700oQ2`1/h@00;>400`3Qh@1Ph@@08>4906CQ

000/h@030>7Q05cQ100/h@L0G^4002cQ0P1Kh@<0=N4705SQ000/h@030>7Q05SQ0P0oh@H0D^4002cQ

00<0hN40E^4204KQ1P1=h@00;>400`3Qh@1Eh@80CN4504SQ000/h@030>7Q05?Q0P1Ch@D0A>4002cQ

00<0hN40D^4205SQ1011h@00;>42057Q0P1Mh@@0?^4002cQ00<0hN403>4K02SQ0P1Qh@<0?>4002cQ

00<0hN402>4401[Q2@0Oh@80I>4303[Q000/h@030>7Q00CQ100Vh@L06N400`3Qh@1Uh@<0>>4001oQ

1@02h@030>7Q00?Q00@0hN7Q0`0`h@H04^4206[Q0P0gh@008N401`3QhN40h@001>40103Q000ih@D0

3N400`3Qh@1[h@80=N4001_Q0`03h@070>7Qh@3Q0004h@<0?n4500OQ00<0hN40KN4203CQ000Qh@07

0>7Qh@3Q0002h@<0AN460003h@3Q077Q0P0bh@008N401P3QhN40h@<00^400`3Qh@18h@D0LN42037Q

000Ph@801>4200CQ00<0hN40BN400`3Qh@0506kQ0P0`h@009^400`3Qh@03h@030>7Q04SQ00<0hN40

1^4406_Q0P0_h@009N400`3Qh@04h@030>7Q04SQ00<0hN402^4406SQ0P0^h@008n4200OQ0P18h@03

0>7Q00kQ1@1Uh@80;N4002;Q00<0hN401n400`3Qh@16h@805>4506;Q00<0hN40:n40027Q00<0hN40

2>400`3Qh@16h@030>7Q01OQ101Ph@030>7Q02[Q000Ph@030>7Q00WQ00<0hN40A^400`3Qh@0Kh@@0

G>4202_Q000Oh@030>7Q00[Q00<0hN40AN400`3Qh@0Oh@D0FN4202[Q000Nh@030>7Q00_Q00<0hN40

AN400`3Qh@0Sh@@0En400`3Qh@0Xh@007N400`3Qh@0<h@80AN400`3Qh@0Xh@@0E>400`3Qh@0Wh@00

7N400`3Qh@0<h@030>7Q04CQ00<0hN40:n44057Q0P0Xh@007>400`3Qh@0=h@030>7Q04?Q00<0hN40

;n4404oQ00<0hN409^4001cQ00<0hN403N400`3Qh@13h@030>7Q03;Q101<h@809n4001_Q00<0hN40

3^400`3Qh@13h@030>7Q03KQ0`1:h@030>7Q02GQ000Jh@030>7Q00oQ0P13h@030>7Q03[Q0`18h@03

0>7Q02CQ000Ih@030>7Q013Q00<0hN40@^400`3Qh@0lh@@0AN400`3Qh@0Th@006N400`3Qh@0@h@03

0>7Q047Q00<0hN40@N4204CQ00<0hN408n4001SQ00<0hN404N400`3Qh@11h@030>7Q04?Q1010h@03

0>7Q02?Q000Hh@030>7Q017Q00<0hN40@N400`3Qh@16h@<0?n400`3Qh@0Rh@006>400`3Qh@0Ah@03

0>7Q047Q00<0hN40BN4203gQ00<0hN408^4001OQ00<0hN404^42047Q00<0hN40C>4303[Q0P0Sh@00

5n400`3Qh@0Bh@030>7Q043Q00<0hN40Cn4203WQ00<0hN408N4001KQ00<0hN404n400`3Qh@0oh@03

0>7Q05;Q0`0fh@030>7Q027Q000Fh@030>7Q01?Q00<0hN40?n400`3Qh@1Eh@80=>4202;Q000Eh@03

0>7Q00kQ00<0hN400n400`3Qh@0oh@030>7Q05OQ0`0bh@030>7Q023Q000Eh@030>7Q00gQ00<0h@00

1>400`3Qh@0oh@030>7Q05WQ0`0`h@030>7Q023Q000Dh@030>7Q00WQ0`04h@030>7Q00;Q0`0oh@03

0>7Q05cQ0P0^h@030>7Q023Q000Dh@030>7Q00kQ0P05h@030>7Q03oQ00<0hN40GN4302cQ0P0Qh@00

5>400`3Qh@0>h@030>7Q00CQ00<0hN40?^400`3Qh@1Qh@<0:^400`3Qh@0Oh@005>400`3Qh@0>h@<0

1>400`3Qh@0nh@030>7Q06?Q0P0Yh@030>7Q01oQ000Ch@030>7Q01KQ00<0hN40?^400`3Qh@1Uh@<0

9^400`3Qh@0Oh@004n400`3Qh@0Fh@030>7Q03kQ00<0hN40In4202GQ00<0hN407n4001?Q00<0hN40

5^4203kQ00<0hN40J^4302;Q00<0hN407n4001?Q00<0hN405^400`3Qh@0mh@030>7Q06cQ0P0Qh@03

0>7Q01oQ000Bh@030>7Q01OQ00<0hN40?N400`3Qh@1^h@808>400`3Qh@0Nh@004^400`3Qh@0Gh@03

0>7Q03gQ00<0hN40L>4201kQ00<0hN407^4001;Q00<0hN405n400`3Qh@0mh@030>7Q077Q0`0Lh@03

0>7Q01kQ000Bh@030>7Q01OQ00<0hN40?N400`3Qh@1dh@806^400`3Qh@0Nh@004N400`3Qh@0Hh@80

?^400`3Qh@1eh@806>400`3Qh@0Oh@004N400`3Qh@0Hh@030>7Q03gQ00<0hN40Mn4201KQ00<0hN40

7n40017Q00<0hN406>400`3Qh@0mh@030>7Q07WQ00<0hN404n400`3Qh@0Oh@004N400`3Qh@0Hh@03

0>7Q03gQ00<0hN40NN4201CQ00<0hN407n40017Q00<0hN406>400`3Qh@0lh@030>7Q07cQ0P0Bh@03

0>7Q01oQ000Ah@030>7Q01SQ0P0mh@030>7Q07kQ0P0@h@030>7Q01oQ000Ah@030>7Q01SQ00<0hN40

8N4500;Q00<0hN404N400`3Qh@0:h@D000?Q00008N4500;Q00<0hN407^4500;Q00<0hN406^400`3Q

h@02h@D000?Q00000n400`3Qh@0Ph@004N400`3Qh@0Hh@030>7Q02?Q00L0hN7Q0>4001;Q00<0hN40

3>401`3QhN40h@008^400`3Qh@02h@030>7Q023Q00L0hN7Q0>4001cQ0P04h@030>7Q00?Q00@0hN40

8^40017Q00<0hN406>400`3Qh@0Sh@030>7Q00?Q00<0hN404>400`3Qh@0<h@070>7Qh@3Q000Rh@03

0>7Q00;Q00<0hN408>401`3QhN40h@007^401@3QhN4000CQ0P02h@030>7Q023Q000Ah@030>7Q01SQ

00<0hN408n40103QhN4201?Q00<0hN403>40103QhN4202?Q00<0hN400n400`3Qh@0Oh@030>7Q00;Q

00<0hN407^40103Qh@03h@030>4000;Q00<0hN408>40013Q00<0hN406N400`3Qh@0Sh@050>7Qh@00

5>400`3Qh@0<h@050>7Qh@009>401`3QhN40h@008N401`3QhN40h@008>400`3Q0003h@050>40h@00

8n40013Q00<0hN406N4202?Q0P03h@<04^400`3Qh@0;h@801>42027Q0P03h@<08>4200CQ00<0hN40

8>4200CQ0P000n40h@0Rh@004>400`3Qh@0Ih@030>7Q03cQ00<0hN40Q^4200GQ00<0hN408^40013Q

00<0hN406N400`3Qh@0lh@030>7Q08OQ00<0hN400^400`3Qh@0Sh@004>400`3Qh@0Ih@030>7Q03cQ

00<0hN40R>401@3QhN4002GQ000@h@030>7Q01WQ00<0hN40?>400`3Qh@29h@040>7Q01?Q100>h@00

4>400`3Qh@0Ih@030>7Q03cQ00<0hN40R^4201CQ0`0?h@002^7l00[Q00<0hN403N4000cQ00D0hN7Q

0003h@030>7Q00GQ00<0hN401N400`3Qh@05h@030>7Q00GQ00<0hN401N400`3Qh@05h@030>7Q00KQ

00<0hN401N400`3Qh@05h@030>7Q00GQ00<0hN400n400`3Q0007h@030>7Q00GQ00<0hN401N400`3Q

h@06h@030>7Q00GQ00<0hN401N400`3Qh@05h@030>7Q00GQ00<0hN401N400`3Qh@05h@030>7Q00GQ

00<0hN401N400`3Qh@06h@030>7Q00GQ00<0hN401N400`3Qh@05h@030>7Q00GQ0`05h@030>7Q00gQ

0P0?h@004>400`3Qh@0Ih@030>7Q03cQ00<0hN40RN40103Qh@0Uh@004>400`3Qh@0Ih@030>7Q03cQ

00<0hN40R>401@3QhN4002GQ000@h@030>7Q01WQ00<0hN40?>400`3Qh@27h@030>7Q00?Q00<0hN40

8^40013Q00<0hN406N400`3Qh@0lh@030>7Q08KQ00<0hN401>400`3Qh@0Rh@004>400`3Qh@0Ih@80

?N400`3Qh@25h@030>7Q00KQ00<0hN408N40013Q00<0hN406N400`3Qh@0lh@030>7Q08CQ00<0hN40

1n400`3Qh@0Qh@004N400`3Qh@0Hh@030>7Q03cQ00<0hN40Pn400`3Qh@09h@030>7Q023Q000Ah@03

0>7Q01SQ00<0hN40?>400`3Qh@22h@030>7Q00[Q00<0hN408>40017Q00<0hN406>400`3Qh@0lh@03

0>7Q083Q0P0=h@030>7Q023Q000Ah@030>7Q01SQ0P0mh@030>7Q07oQ00<0hN403N400`3Qh@0Ph@00

4N400`3Qh@0Hh@030>7Q03cQ00<0hN40O^400`3Qh@0?h@030>7Q01oQ000Ah@030>7Q01SQ00<0hN40

?>400`3Qh@1lh@804^400`3Qh@0Oh@004N400`3Qh@0Hh@030>7Q03gQ00<0hN40NN4201CQ00<0hN40

7n40017Q00<0hN406>400`3Qh@0mh@030>7Q07SQ0P0Eh@030>7Q01oQ000Ah@030>7Q01SQ00<0hN40

?N400`3Qh@1fh@805n400`3Qh@0Oh@004^400`3Qh@0Gh@80?^400`3Qh@1eh@030>7Q01OQ00<0hN40

7n4001;Q00<0hN405n400`3Qh@0mh@030>7Q07?Q0P0Kh@030>7Q01kQ000Bh@030>7Q01OQ00<0hN40

?N400`3Qh@1ah@807N400`3Qh@0Nh@004^400`3Qh@0Gh@030>7Q03gQ00<0hN40L>4201kQ00<0hN40

7^4001?Q00<0hN405^400`3Qh@0mh@030>7Q06gQ0`0Ph@030>7Q01kQ000Ch@030>7Q01KQ00<0hN40

?N400`3Qh@1/h@030>7Q023Q00<0hN407n4001?Q00<0hN405^4203kQ00<0hN40J^4202?Q00<0hN40

7n4001?Q00<0hN405^400`3Qh@0nh@030>7Q06OQ0P0Uh@030>7Q01oQ000Ch@030>7Q01KQ00<0hN40

?^400`3Qh@1Uh@809n400`3Qh@0Oh@005>400`3Qh@0Eh@030>7Q03kQ00<0hN40Hn4202WQ00<0hN40

7n4001CQ00<0hN403n400`3Qh@03h@030>7Q03kQ00<0hN40HN4202_Q00<0hN407n4001CQ00<0hN40

3^400`3Q0004h@030>7Q03oQ00<0hN40GN4302cQ0P0Qh@005>400`3Qh@0@h@030>7Q00;Q0`0oh@03

0>7Q05_Q0`0^h@030>7Q023Q000Eh@030>7Q00gQ0P05h@030>7Q03oQ00<0hN40FN42037Q00<0hN40

8>4001GQ00<0hN403N400`3Qh@04h@030>7Q03oQ00<0hN40En4203?Q00<0hN408>4001KQ00<0hN40

3>4300CQ00<0hN40?n400`3Qh@1Eh@80=>4202;Q000Fh@030>7Q01?Q00<0hN40@>400`3Qh@1Ah@<0

=^400`3Qh@0Qh@005n400`3Qh@0Bh@030>7Q043Q00<0hN40Cn4203WQ00<0hN408N4001OQ00<0hN40

4^42047Q00<0hN40C>4303[Q0P0Sh@006>400`3Qh@0Ah@030>7Q047Q00<0hN40B>4303gQ00<0hN40

8^4001SQ00<0hN404N400`3Qh@11h@030>7Q04KQ0P10h@030>7Q02;Q000Ih@030>7Q013Q00<0hN40

@N400`3Qh@13h@<0@N400`3Qh@0Sh@006N400`3Qh@0@h@030>7Q047Q00<0hN40@>4304CQ00<0hN40

8n4001[Q00<0hN403n4204?Q00<0hN40?>4304KQ00<0hN409>4001[Q00<0hN403n400`3Qh@12h@03

0>7Q03WQ1018h@030>7Q02CQ000Kh@030>7Q00kQ00<0hN40@n400`3Qh@0eh@<0Bn400`3Qh@0Uh@00

7>400`3Qh@0=h@030>7Q04?Q00<0hN40<^4304gQ0P0Wh@007N400`3Qh@0<h@030>7Q04CQ00<0hN40

;N44053Q00<0hN409^4001gQ00<0hN403>400`3Qh@14h@030>7Q02[Q101Bh@030>7Q02OQ000Nh@03

0>7Q00_Q0P15h@030>7Q02OQ101Dh@80:N4001kQ00<0hN402n400`3Qh@15h@030>7Q02;Q1@1Gh@03

0>7Q02SQ000Oh@802n400`3Qh@15h@030>7Q01oQ101Jh@030>7Q02WQ000Ph@030>7Q00WQ00<0hN40

A^400`3Qh@0Jh@D0G>4202_Q000Qh@030>7Q00SQ00<0hN40A^400`3Qh@0Gh@@0Gn4202cQ000Rh@03

0>7Q00OQ00<0hN40An400`3Qh@0Bh@@0Hn400`3Qh@0[h@008n400`3Qh@06h@80B>400`3Qh@0>h@@0

I^400`3Qh@0/h@009>4200KQ00<0hN40B>400`3Qh@09h@D0J>400`3Qh@0]h@009^400`3Qh@03h@03

0>7Q04SQ0P06h@D0Jn4202oQ000Wh@800n400`3Qh@19h@030>4000@0Kn42033Q000Oh@D00^400`3Q

h@020003h@3Q04SQ1@1bh@030>7Q033Q000Qh@070>7Qh@3Q0003h@80A>4600;Q0P1`h@80<n40027Q

00L0hN7Q0>4000CQ0`0nh@D02>4206kQ0P0dh@008N401`3QhN40h@001>400`3Q000203OQ1@0>h@03

0>7Q06[Q0`0eh@008N401`3QhN40h@001>400`3Qh@02h@80;n4601CQ00<0hN40J>4203OQ000Ph@80

1>400`3Qh@03h@030>7Q00CQ1@0Th@L06^400`3Qh@1Uh@<0>>4002cQ00<0hN402N4401OQ2@0Qh@80

I>4303[Q000/h@030>7Q00gQ600[h@030>7Q05oQ0`0lh@00;>4205;Q0P1Lh@<0?n4002cQ00<0hN40

D^4205OQ1012h@00;>400`3Qh@1Ch@<0DN4504GQ000/h@030>7Q05GQ0P1<h@D0BN4002cQ00<0hN40

En4204CQ1P1>h@00;>4205WQ0`0lh@L0Dn4002cQ00<0hN40F^4303CQ1`1Ih@00;>400`3Qh@1Mh@@0

:N4805oQ000/h@030>7Q063Q1@0Mh@T0I^4002cQ00<0hN40I>4;00KQ3P1^h@00;>400`3Qh@1^h@P0

Nn4002cQ0P3bh@00;>400`3Qh@3ah@00;>400`3Qh@3ah@00on4Qh@00on4Qh@00on4Qh@00on4Qh@00

on4Qh@00on4Qh@00on4Qh@00on4Qh@00on4Qh@00:^420?CQ000[h@030>7Q0?;Q000Yh@<00^400`3Q

h@3_h@00:>40203Qh@3Q0>40l>4002SQ00P0hN40h@3Q0?3Q000Yh@<000CQ0>40l>4002gQ00<0h@00

l>4002kQ00<0hN40kn400?oQ8N400?oQ8N400?oQ8N400?oQ8N400?oQ8N400001\

\>"],

  ImageRangeCache->{{{73.4375, 302.813}, {246.625, 105.313}} -> {10.6353, 

  9.41776, 0.0246723, 0.172985}}],



Cell[BoxData[

    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),

      False,

      Editable->False]], "Output"]

}, Open  ]],



Cell[BoxData[{

    \(\neqnsmall[q0_, p0_, w0_, a_, k_]\  := \n

      \ \ \ \ \ \ {\(q'\)[r]\  == \ q1[r], \ \(p'\)[r]\  == \ p1[r], \ 

        \(w'\)[r]\  == \ w1[r], \n\ \ \ \ \ \ \ \ \ \ \ \ 

        \(q1'\)[r] + 3/r\ q1[r] + a^2\ p[r]\ q[r] == k^2\ w[r], \n

        \ \ \ \ \ \ \ \ \ \ \ \ \(p1'\)[r] + 3/r\ p1[r]\  == \ .5\ q[r]^2, \n

        \ \ \ \ \ \ \ \ \ \ \ \ \(w1'\)[r] + 3/r\ w1[r] + q[r]\  == 0, \n

        \ \ \ \ \ \ \ \ \ \ \ \ q1[10^\(-6\)] == 0, p1[10^\(-6\)] == 0, 

        w1[10^\(-6\)] == 0, \n\ \ \ \ \ \ \ \ \ \ \ \ q[10^\(-6\)] == q0, 

        p[10^\(-6\)] == p0, w[10^\(-6\)] == w0}\n\ \ \ \ \ \ \ \ \ \ \ \), 

    \(ivpsmall[{q0_, p0_, w0_}, a_, k_]\  := \n\ \ \ \ \ 

      NDSolve[eqnsmall[q0, p0, w0, a, k], {q, p, w, q1, p1, w1}, {r, 1}\ , 

        MaxSteps -> 5000\ ]\)}], "Input"],



Cell["\<\





deflection[{q0_,p0_,w0_},a_,k_,r_]:= 

     (-r*w1[r] - 2*w[r])/.Flatten[ivpsmall[{q0,p0,w0},a,k]]





\

\>", "Input",

  PageWidth->Infinity,

  InitializationCell->True,

  ShowSpecialCharacters->False,

  FormatType->InputForm],



Cell[BoxData[

    \(plotdeflection := \n

      Plot[deflection[k38loopf[\([i, 3]\)], k38loopf[\([i, 2]\)], 

          k38loopf[\([i, 1]\)], r], {r, 10^\(-6\), 1}, \n\ Axes -> Automatic, 

        AxesLabel -> {r, DEFLECTION}, PlotRange -> {\(-1.\), 1.}, \n\t\t

        PlotStyle -> Hue[1], \n\ 

        PlotLabel -> StringForm["\<a=``\>", k38loopf[\([i, 2]\)]], 

        DisplayFunction -> Identity]\)], "Input"],



Cell[BoxData[

    \(plotloop := \n

      Show[{loop, 

          Graphics[{Hue[1], PointSize[.05], 

              Point[{k38loopf[\([i, 2]\)], k38loopf[\([i, 3, 1]\)]}]}]}, \n

        \t\tDisplayFunction -> Identity]\)], "Input"],



Cell[BoxData[

    \(deflectionloop[imin_, imax_, di_] := \n

      Table[Show[GraphicsArray[{plotdeflection, plotloop}]], {i, imin, imax, 

          di}]\)], "Input"],



Cell[CellGroupData[{



Cell[BoxData[

    \(deflectionloop[2, 1989, 56]\)], "Input"],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238085 0.952382 0.0757894 9.83045 [

[.21428 .06329 -9 -9 ]

[.21428 .06329 9 0 ]

[.40476 .06329 -9 -9 ]

[.40476 .06329 9 0 ]

[.59524 .06329 -9 -9 ]

[.59524 .06329 9 0 ]

[.78571 .06329 -9 -9 ]

[.78571 .06329 9 0 ]

[.97619 .06329 -3 -9 ]

[.97619 .06329 3 0 ]

[1.025 .07579 0 -8 ]

[1.025 .07579 9 8 ]

[.01131 .17409 -24 -4.5 ]

[.01131 .17409 0 4.5 ]

[.01131 .2724 -24 -4.5 ]

[.01131 .2724 0 4.5 ]

[.01131 .3707 -24 -4.5 ]

[.01131 .3707 0 4.5 ]

[.01131 .46901 -24 -4.5 ]

[.01131 .46901 0 4.5 ]

[.01131 .56731 -24 -4.5 ]

[.01131 .56731 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -57 0 ]

[.5 .63053 57 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21428 .07579 m

.21428 .08204 L

s

[(0.2)] .21428 .06329 0 1 Mshowa

.40476 .07579 m

.40476 .08204 L

s

[(0.4)] .40476 .06329 0 1 Mshowa

.59524 .07579 m

.59524 .08204 L

s

[(0.6)] .59524 .06329 0 1 Mshowa

.78571 .07579 m

.78571 .08204 L

s

[(0.8)] .78571 .06329 0 1 Mshowa

.97619 .07579 m

.97619 .08204 L

s

[(1)] .97619 .06329 0 1 Mshowa

.125 Mabswid

.07143 .07579 m

.07143 .07954 L

s

.11905 .07579 m

.11905 .07954 L

s

.16667 .07579 m

.16667 .07954 L

s

.2619 .07579 m

.2619 .07954 L

s

.30952 .07579 m

.30952 .07954 L

s

.35714 .07579 m

.35714 .07954 L

s

.45238 .07579 m

.45238 .07954 L

s

.5 .07579 m

.5 .07954 L

s

.54762 .07579 m

.54762 .07954 L

s

.64286 .07579 m

.64286 .07954 L

s

.69048 .07579 m

.69048 .07954 L

s

.7381 .07579 m

.7381 .07954 L

s

.83333 .07579 m

.83333 .07954 L

s

.88095 .07579 m

.88095 .07954 L

s

.92857 .07579 m

.92857 .07954 L

s

.25 Mabswid

0 .07579 m

1 .07579 L

s

gsave

1.025 .07579 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 .17409 m

.03006 .17409 L

s

[(0.01)] .01131 .17409 1 0 Mshowa

.02381 .2724 m

.03006 .2724 L

s

[(0.02)] .01131 .2724 1 0 Mshowa

.02381 .3707 m

.03006 .3707 L

s

[(0.03)] .01131 .3707 1 0 Mshowa

.02381 .46901 m

.03006 .46901 L

s

[(0.04)] .01131 .46901 1 0 Mshowa

.02381 .56731 m

.03006 .56731 L

s

[(0.05)] .01131 .56731 1 0 Mshowa

.125 Mabswid

.02381 .09545 m

.02756 .09545 L

s

.02381 .11511 m

.02756 .11511 L

s

.02381 .13477 m

.02756 .13477 L

s

.02381 .15443 m

.02756 .15443 L

s

.02381 .19375 m

.02756 .19375 L

s

.02381 .21342 m

.02756 .21342 L

s

.02381 .23308 m

.02756 .23308 L

s

.02381 .25274 m

.02756 .25274 L

s

.02381 .29206 m

.02756 .29206 L

s

.02381 .31172 m

.02756 .31172 L

s

.02381 .33138 m

.02756 .33138 L

s

.02381 .35104 m

.02756 .35104 L

s

.02381 .39036 m

.02756 .39036 L

s

.02381 .41002 m

.02756 .41002 L

s

.02381 .42969 m

.02756 .42969 L

s

.02381 .44935 m

.02756 .44935 L

s

.02381 .48867 m

.02756 .48867 L

s

.02381 .50833 m

.02756 .50833 L

s

.02381 .52799 m

.02756 .52799 L

s

.02381 .54765 m

.02756 .54765 L

s

.02381 .05613 m

.02756 .05613 L

s

.02381 .03647 m

.02756 .03647 L

s

.02381 .01681 m

.02756 .01681 L

s

.02381 .58697 m

.02756 .58697 L

s

.02381 .60663 m

.02756 .60663 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -118 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(13.3400000000000007`) show

173.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

1 0 0 r

.5 Mabswid

.02381 .60332 m

.02499 .6033 L

.02605 .60325 L

.02729 .60316 L

.02846 .60303 L

.03053 .60271 L

.03279 .60223 L

.03527 .60155 L

.0379 .60065 L

.04262 .59857 L

.05205 .59266 L

.06244 .58353 L

.07293 .57166 L

.0842 .5561 L

.10458 .52149 L

.1458 .43318 L

.18551 .33979 L

.22371 .25871 L

.24502 .22217 L

.26435 .19619 L

.27403 .18598 L

.2845 .17712 L

.28931 .17381 L

.29439 .17084 L

.29906 .16858 L

.30348 .16685 L

.30586 .16609 L

.30844 .16538 L

.31059 .1649 L

.31296 .16447 L

.31552 .16413 L

.31692 .16399 L

.31824 .1639 L

.31946 .16385 L

.32059 .16382 L

.32182 .16382 L

.32312 .16385 L

.32427 .1639 L

.32531 .16397 L

.32652 .16407 L

.32765 .16419 L

.32968 .16446 L

.33187 .16483 L

.33686 .16599 L

.34145 .16741 L

.35115 .17149 L

.36022 .17648 L

.38086 .19132 L

.41968 .22638 L

.43943 .24421 L

Mistroke

.46096 .26101 L

.47095 .26734 L

.48159 .2728 L

.48676 .27492 L

.49163 .27659 L

.49633 .27788 L

.50072 .27879 L

.50297 .27915 L

.50539 .27944 L

.50676 .27957 L

.50807 .27967 L

.50924 .27973 L

.51051 .27977 L

.51175 .27979 L

.51245 .27979 L

.51311 .27979 L

.51381 .27977 L

.51444 .27975 L

.51514 .27972 L

.51587 .27968 L

.5171 .27959 L

.51825 .27949 L

.52084 .27919 L

.52325 .27881 L

.52552 .27836 L

.52978 .27731 L

.53436 .27585 L

.53932 .27389 L

.54881 .26907 L

.55923 .26218 L

.58029 .24354 L

.62068 .19381 L

.65956 .13721 L

.70089 .08021 L

.72156 .05662 L

.7407 .03904 L

.75926 .02643 L

.76864 .0218 L

.77368 .0198 L

.779 .01806 L

.78381 .0168 L

.78635 .01626 L

.78908 .01577 L

.79158 .01541 L

.79386 .01514 L

.79496 .01504 L

.79616 .01494 L

.7972 .01487 L

.79832 .01481 L

.79962 .01476 L

Mistroke

.80083 .01473 L

.80157 .01472 L

.80227 .01472 L

.80359 .01472 L

.80426 .01474 L

.80497 .01476 L

.80625 .01481 L

.80778 .01489 L

.80916 .01499 L

.81164 .01521 L

.81432 .01554 L

.81917 .01631 L

.82409 .01734 L

.82868 .0185 L

.83912 .02183 L

.86019 .03084 L

.89912 .05133 L

.91895 .06121 L

.9294 .06571 L

.9405 .06974 L

.94932 .07229 L

.954 .07338 L

.95904 .07433 L

.96366 .075 L

.96568 .07524 L

.96789 .07544 L

.96999 .07559 L

.97193 .0757 L

.97301 .07574 L

.97399 .07576 L

.97512 .07578 L

.97619 .07579 L

Mfstroke

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.02803 .25147 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{697.625, 205.25},

  ImageMargins->{{13, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:i0000c@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l00003<006H009T00<`00?l0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV

09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<003o03?o06Ko09Wo0<co

0?oo0000<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I

<c>I<fJI<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0

IYT0I/`0I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bI

I_nIIP3<IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0c

VC<cVFHcVITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<

VIW<VLc<VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`c

c?lcc01Vc3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03o

c3?oc6Koc9Woc<coc?ooc000oc<0ofH0oiT0ol`0ool0o`0coc<cofHcoiTcol`coolco`1Voc=VofIV

oiUVolaVoomVo`2Ioc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<o`3ooc?oofKooiWoolco

ooooo`0000410@820P<30`@410D51@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C

4a@D5?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooooQon6kh@00on7ohK_Q003ohOoQ^n400?oQ

on6kh@00on7ohK_Q000]h@030>7Q0?oQKN400`3Qh@3ohA_Q000]h@030>7Q0?oQKN400`3Qh@3ohA_Q

000]h@030>7Q0?oQKN420?oQ7>4002gQ00<0hN40on5]h@030>7Q0?oQ6n4002gQ00<0hN40d^473i?Q

00<0hN40M^4A09?Q000]h@80d>433`OQ1@n>h@030>7Q06oQ200@h@/0R>4002gQ00<0hN40bn443`oQ

0Pn<h@030>7Q06[Q1@0Rh@T0P>4002gQ00<0hN40bN423aGQ0Pn:h@030>7Q06OQ100^h@P0NN4002gQ

00<0hN40b>400`oQh@0Gh@8?R>400`3Qh@1Th@@0>>4707?Q000]h@030>7Q0<KQ0PlLh@<?QN4206?Q

0`12h@H0KN4002gQ0P0]h@030>7Q00;Q00@0hN7Q0`0Yh@030>7Q00;Q00<0hN400^4302SQ00<0hN40

0^40103QhN4202CQ00<?hN400n400`3Qh@02h@030>7Q00;Q00<0hN403n423a[Q1@1Th@030>7Q063Q

0`1:h@H0In4002gQ00<0hN40:n400`3Q0007h@030>7Q02SQ00<0h@002N400`3Qh@0Vh@030>4000OQ

00<0h@008^400`oQh@03h@030>4000OQ00<0h@004^423a[Q00<0hN40I>400`3Qh@1Oh@80DN4606;Q

000]h@030>7Q02_Q00<0h@002>400`3Qh@0Wh@030>4000OQ100Wh@030>4000OQ00<0h@008N400`oQ

h@04h@030>4000OQ00<0h@005>423aSQ00<0hN40I>400`3Qh@1Mh@80F>4505kQ000]h@030>7Q02_Q

00<0h@002>400`3Qh@0Wh@030>4000OQ00<0h@00:>400`3Q0007h@808N400`oQh@05h@030>4000SQ

00<0hN405N423aKQ00<0hN40I>400`3Qh@1Lh@80GN4505[Q000]h@030>7Q02_Q00<0h@001n400`3Q

000Xh@030>4000SQ0P0Xh@030>4000OQ00<0hN407n400`oQh@06h@030>4000OQ00<0h@006>423aCQ

00<0hN40I>400`3Qh@1Kh@030>7Q067Q101Gh@00;N400`3Qh@0/h@030>7Q00OQ00<0hN40:>400`3Q

h@08h@030>7Q02OQ00<0hN401n4201kQ00<?hN402>400`3Qh@07h@030>7Q01WQ0PlAh@80I^4205[Q

0P1Wh@@0E>4002gQ0P30h@033n7Q037Q0Pmgh@030>7Q013Q6@0_h@80Jn4305;Q000]h@030>7Q0;kQ

00<?hN40=>423gGQ00<0hN402^4601SQ2@0Vh@80Kn42053Q000]h@030>7Q0;gQ00<?hN40=n433g;Q

00<0hN401^4402OQ1`0Nh@80L^4204kQ000]h@030>7Q0;cQ00<?hN40>n433aWQ0`1Ch@030>7Q00?Q

0`0ah@L05n4207CQ0`1<h@00;N400`3Qh@2kh@033n7Q03oQ0PlHh@030>7Q04CQ1@02h@030>7Q00CQ

00@0hN7Q0P0jh@H04^400`3Qh@1eh@80Bn4002KQa0000`l0001200L?1`0:h@030>7Q04KQ00L0hN7Q

0>4000GQ1011h@H03>400`3Qh@1hh@80BN4002gQ00<0hN402^400`3Qh@0:h@030>7Q00_Q00<0hN40

2^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Qh@0;h@030>7Q00[Q00<0hN402^400`3Qh@0:h@03

0>7Q00_Q00<0hN402^400`3Qh@0:h@040>7Q3`WQ00<0hN402^400`3Qh@0;h@030>7Q00[Q00<0hN40

2^400`3Qh@0:h@030>7Q00kQ1010h@<00n401`3QhN40h@001>4304SQ1@07h@030>7Q07[Q0P18h@00

;N400`3Qh@0bh@030>7Q03;Q00<0hN40<^400`3Qh@0Ih@033n7Q01GQ00<0hN40<^400`3Qh@1Hh@07

0>7Qh@3Q0002h@8000?Q0>40CN450003h@3Q07gQ0P17h@00;N400`3Qh@2gh@033n7Q0:KQ00H0hN7Q

0>4300?Q00<0hN40D>4507kQ00<0hN40A>4002gQ00<0hN40]n400`oQh@2Uh@801>4200GQ00<0hN40

DN40103QhN4407_Q00<0hN40@n4002gQ00<0hN40]^400`oQh@2/h@030>7Q00CQ00<0hN40D>400`3Q

h@06h@D0Mn4204?Q000]h@80]^400`oQh@2[h@801n400`3Qh@1@h@030>7Q00[Q1@1dh@030>7Q047Q

000]h@030>7Q0;CQ00<?hN40Zn400`3Qh@07h@80D>400`3Qh@0?h@D0LN400`3Qh@10h@00;N400`3Q

h@2dh@033n7Q0:[Q00<0hN402>400`3Qh@1>h@030>7Q01CQ101_h@030>7Q03oQ000]h@030>7Q0;?Q

00<?hN40Z^400`3Qh@09h@030>7Q04kQ00<0hN406>4406_Q0P10h@00;N400`3Qh@2bh@033n7Q0:[Q

00<0hN402^400`3Qh@1=h@030>7Q01cQ1@1Xh@80?n4002gQ0P2bh@033n7Q0:[Q00<0hN402n400`3Q

h@1=h@030>7Q023Q1@1Uh@030>7Q03gQ000]h@030>7Q0;7Q00<?hN40ZN400`3Qh@0<h@030>7Q04gQ

00<0hN409>4406?Q00<0hN40?>4002gQ00<0hN40/>400`oQh@2Yh@030>7Q00gQ00<0hN40C>400`3Q

h@0Xh@@0HN400`3Qh@0kh@00;N400`3Qh@2_h@033n7Q0:WQ00<0hN403^4204gQ00<0hN40;>4305kQ

0P0lh@00;N400`3Qh@2^h@033n7Q0:WQ00<0hN403n400`3Qh@1;h@030>7Q033Q101Kh@030>7Q03[Q

000]h@030>7Q0:kQ00<?hN40ZN400`3Qh@0?h@030>7Q04_Q00<0hN40<n4305WQ0P0kh@00;N420:kQ

00<?hN40ZN400`3Qh@0@h@030>7Q04[Q00<0hN40=n4405KQ0P0jh@00;N400`3Qh@2/h@033n7Q0:[Q

00<0hN404>400`3Qh@1:h@030>7Q03_Q0`1Dh@030>7Q03SQ000]h@030>7Q0:cQ00<?hN40ZN400`3Q

h@0Ah@030>7Q04WQ00<0hN40?n43057Q0P0ih@00;N400`3Qh@2[h@033n7Q0:[Q00<0hN404N4204[Q

00<0hN40@^4304oQ00<0hN40=n4002gQ00<0hN40Z^400`oQh@2Zh@030>7Q01;Q00<0hN40B>400`3Q

h@16h@<0C>4203SQ000]h@80Zn400`oQh@2Yh@030>7Q01?Q00<0hN40B>400`3Qh@19h@<0B^400`3Q

h@0fh@00;N400`3Qh@2Yh@033n7Q0:[Q00<0hN404n400`3Qh@18h@030>7Q04cQ0P18h@030>7Q03KQ

000]h@030>7Q0:WQ00<?hN40ZN400`3Qh@0Dh@030>7Q04SQ00<0hN40C^4304KQ00<0hN40=N4001OQ

00<0hN400^400`3Qh@02h@030>7Q00D01>400`3Qh@1;h@X?Dn400`oQh@2Zh@030>7Q01CQ00<0hN40

B>400`3Qh@1Ah@<0@n400`3Qh@0eh@005^400`3Q0007h@030>4000?Q00<0hN401>400`3Qh@19h@8?

2^423e3Q00<?hN40Z^400`3Qh@0Eh@80B>400`3Qh@1Eh@<0@N400`3Qh@0dh@005^400`3Q0007h@03

0>4000?Q00<0hN401>4304OQ0Pl>h@8?C^400`oQh@2Zh@030>7Q01GQ00<0hN40An400`3Qh@1Gh@80

@>400`3Qh@0dh@005^400`3Q0007h@030>4000?Q00<0hN401>400`3Qh@15h@8?4^423d_Q00<?hN40

Z^400`3Qh@0Fh@030>7Q04OQ00<0hN40FN4303gQ00<0hN40=>4001KQ00<0h@001n400`3Q0003h@03

0>7Q00CQ00<0hN40A>400`oQh@0Dh@8?B>400`oQh@2[h@030>7Q01KQ00<0hN40A^400`3Qh@1Mh@<0

>n400`3Qh@0ch@005n400`3Qh@07h@040>7Qh@801^400`3Qh@13h@033n7Q01OQ00<?hN40AN400`oQ

h@2[h@030>7Q01KQ00<0hN40A^400`3Qh@1Ph@80>N400`3Qh@0ch@00;N400`3Qh@12h@033n7Q01WQ

0Pm4h@033n7Q0:_Q00<0hN404>400`3Qh@04h@030>7Q04KQ00<0hN40HN4303OQ00<0hN40<n4002gQ

00<0hN40@N400`oQh@0Lh@033n7Q047Q00<?hN40Zn400`3Qh@0?h@030>4000GQ00<0hN40A^400`3Q

h@1Th@80=N4203CQ000]h@80@^400`oQh@0Mh@033n7Q03oQ00<?hN40Zn400`3Qh@0;h@<01>400`3Q

h@03h@80A^400`3Qh@1Wh@<0<n400`3Qh@0bh@00;N400`3Qh@10h@033n7Q01oQ00<?hN40?N400`oQ

h@2/h@030>7Q013Q0P06h@030>7Q04GQ00<0hN40J^42037Q00<0hN40<^4002gQ00<0hN40?n400`oQ

h@0Qh@033n7Q03_Q00<?hN40[N400`3Qh@0@h@030>7Q00GQ00<0hN40AN400`3Qh@1[h@80<>400`3Q

h@0bh@00;N400`3Qh@0nh@033n7Q02?Q00<?hN40>N400`oQh@2^h@030>7Q013Q0`05h@030>7Q04GQ

00<0hN40KN4302gQ0P0ch@00;N400`3Qh@0mh@033n7Q02GQ0Plih@033n7Q0:gQ00<0hN406N400`3Q

h@14h@030>7Q077Q0P0/h@030>7Q037Q000]h@80?^400`oQh@0Wh@033n7Q03GQ00<?hN40[^400`3Q

h@0Ih@030>7Q04CQ00<0hN40Ln4202[Q00<0hN40<N4002gQ00<0hN40?>400`oQh@0Yh@033n7Q03?Q

00<?hN40[n400`3Qh@0Ih@80AN400`3Qh@1eh@80:>400`3Qh@0ah@00;N400`3Qh@0kh@033n7Q02_Q

00<?hN40<N400`oQh@2`h@030>7Q01WQ00<0hN40A>400`3Qh@1fh@809n400`3Qh@0ah@00;N400`3Q

h@0jh@033n7Q02gQ00<?hN40;n400`oQh@2ah@030>7Q01WQ00<0hN40A>400`3Qh@1hh@<09>400`3Q

h@0ah@00;N400`3Qh@0ih@033n7Q02oQ00<?hN40;N400`oQh@2bh@030>7Q01WQ00<0hN40A>400`3Q

h@1kh@808^400`3Qh@0ah@00;N400`3Qh@0ih@033n7Q033Q00<?hN40:n400`oQh@2bh@030>7Q01[Q

00<0hN40A>400`3Qh@1mh@808>400`3Qh@0ah@00;N4203WQ00<?hN40<^400`oQh@0Zh@033n7Q0:oQ

0Pl00n40h@0Kh@030>7Q04CQ00<0hN40On400`3Qh@0Mh@030>7Q037Q000]h@030>7Q03SQ00<?hN40

<n400`oQh@0Xh@033n7Q0:kQ1PlLh@030>7Q04CQ00<0hN40On4201kQ00<0hN40<N4002gQ00<0hN40

=n400`oQh@0eh@033n7Q02KQ00<?hN40[^483a_Q0P14h@030>7Q08;Q0P0Kh@030>7Q03;Q000]h@03

0>7Q03KQ00<?hN40=n400`oQh@0Th@033n7Q0:kQ2PlJh@030>7Q04?Q00<0hN40Q>4201WQ00<0hN40

<^4002gQ00<0hN40=^400`oQh@0hh@033n7Q02;Q00<?hN40[n4:3a[Q00<0hN40@n400`3Qh@26h@80

5n400`3Qh@0bh@00;N4203KQ00<?hN40>^400`oQh@0Ph@033n7Q0:oQ30lIh@030>7Q04?Q00<0hN40

R>400`3Qh@0Dh@030>7Q03;Q000]h@030>7Q03GQ00<?hN40>n423aoQ00<?hN40/>4<3aWQ00<0hN40

@n400`3Qh@29h@030>7Q01?Q00<0hN40<^4002gQ00<0hN40=>400`oQh@0nh@033n7Q01_Q00<?hN40

/^4:3a[Q00<0hN40@n400`3Qh@2:h@804n400`3Qh@0bh@00;N400`3Qh@0dh@033n7Q03oQ0PlJh@03

3n7Q0;?Q2PlJh@80A>400`3Qh@2<h@030>7Q013Q00<0hN40<^4001OQ00<0hN400^400`3Qh@02h@04

0>7Qh@<01N400`3Qh@0ch@033n7Q04;Q0PlFh@8?]n483a_Q00<0hN409N4500;Q00<0hN405>400`3Q

h@0<h@D000?Q00009N4500;Q00<0hN408n4500;Q00<0hN407N4200CQ1@000n400003h@030>7Q03?Q

000Fh@030>4000OQ00<0h@000^400`3Qh@05h@030>7Q03?Q00<?hN40A>423a;Q0Pnjh@H?7>400`3Q

h@0Wh@070>7Qh@3Q000Eh@030>7Q00kQ00L0hN7Q0>4002KQ00<0hN400^400`3Qh@0Uh@070>7Qh@3Q

000Ph@030>7Q00?Q00<0hN400n40103Qh@0eh@005^400`3Q0007h@030>4000?Q00<0hN401>4303;Q

00<?hN40An423`kQ0Pnnh@8?00<0hN406n400`3Qh@0Wh@030>7Q00?Q00<0hN404n400`3Qh@0>h@07

0>7Qh@3Q000Vh@030>7Q00;Q00<0hN409N401`3QhN40h@008N400`3Qh@02h@030>7Q00;Q0P02h@03

0>7Q03?Q000Fh@030>4000OQ00<0h@000n400`3Qh@04h@030>7Q03;Q00<?hN40BN433`OQ10o2h@03

0>7Q01_Q00<0hN409n40103QhN4201KQ00<0hN403^40103QhN4202OQ00<0hN400n400`3Qh@0Th@03

0>7Q00;Q00<0hN408N4200;Q00L0hN7Q0>4000;Q00<0hN40<n4001KQ00<0h@001n400`3Q0002h@03

0>4000GQ00<0hN40<N400`oQh@1=h@P?a>400`3Qh@0Lh@030>7Q02OQ00D0hN7Q000Gh@030>7Q00kQ

00D0hN7Q000Xh@070>7Qh@3Q000Vh@070>7Qh@3Q000Sh@040>7Q00?Q00D0h@3Q000fh@005n400`3Q

h@07h@030>7Q00;Q00<0hN401>400`3Qh@0ah@033n7Q0?oQ6^400`3Qh@0Lh@030>7Q02KQ0P03h@<0

5N400`3Qh@0=h@801>4202GQ0P03h@<09N4200CQ00<0hN408n4300CQ0P000n40h@0eh@00;N400`3Q

h@0`h@033n7Q0?oQ6n400`3Qh@0Lh@80A>400`3Qh@2Dh@030>7Q00GQ00<0hN40=N4002gQ0P0ah@03

3n7Q0?oQ6n400`3Qh@0Lh@030>7Q04?Q00<0hN40UN400`3Qh@04h@030>7Q03GQ000]h@030>7Q02oQ

00<?hN40on4Lh@030>7Q01cQ00<0hN40@n400`3Qh@2Fh@030>7Q00;Q00<0hN40=^4002gQ00<0hN40

;n400`oQh@3ohAcQ00<0hN407>400`3Qh@13h@030>7Q09OQ00D0hN7Q000hh@00;N400`3Qh@0_h@03

3n7Q0?oQ7>400`3Qh@0Lh@030>7Q04?Q00<0hN40V>40103Qh@0Eh@@07n4002gQ00<0hN40;^400`oQ

h@3ohAgQ00<0hN407>400`3Qh@13h@030>7Q09WQ0P0Fh@<08>4002gQ00<0hN40;^400`oQh@3ohAKQ

o`0H00_Q00<0hN407^4002gQ0P0^h@033n7Q0?oQ6N400`3Qh@02h@050>7Qh@002>400`3Qh@06h@03

0>7Q00KQ00<0hN401^400`3Qh@06h@030>7Q00KQ00<0hN401^400`3Qh@06h@030>7Q00KQ00<0hN40

1^400`3Qh@04h@030>4000SQ00<0hN401^400`3Qh@06h@030>7Q00KQ00<0hN401^400`3Qh@06h@03

0>7Q00KQ00<0hN401^400`3Qh@06h@030>7Q00KQ00<0hN401^400`3Qh@06h@030>7Q00KQ00<0hN40

1^400`3Qh@06h@030>7Q00KQ00<0hN401^4300KQ00<0hN403^42023Q000]h@030>7Q02gQ00<?hN40

on4Nh@030>7Q01cQ00<0hN40:^400`3Qh@0Fh@030>7Q017Q00<0hN40:^400`3Qh@0Zh@030>7Q02[Q

00@0hN40>>4002gQ00<0hN40;>400`oQh@3ohAoQ00<0hN407>400`3Qh@13h@030>7Q09OQ00D0hN7Q

000hh@00;N400`3Qh@0/h@033n7Q0?oQ7n400`3Qh@0Lh@030>7Q04?Q00<0hN40U^400`3Qh@02h@03

0>7Q03KQ000]h@030>7Q02_Q00<?hN40on4Ph@030>7Q01cQ00<0hN40@n400`3Qh@2Eh@030>7Q00CQ

00<0hN40=N4002gQ0P0/h@033n7Q0?oQ8>400`3Qh@0Lh@80A>400`3Qh@2Dh@030>7Q00GQ00<0hN40

=N4002gQ00<0hN40:^400`oQh@3ohB7Q00<0hN407>400`3Qh@13h@030>7Q09?Q00<0hN401n400`3Q

h@0dh@00;N400`3Qh@0Zh@033n7Q0?oQ8N400`3Qh@0Lh@030>7Q04?Q00<0hN40T^400`3Qh@08h@03

0>7Q03CQ000]h@030>7Q02[Q00<?hN40on4Rh@030>7Q01_Q00<0hN40@n400`3Qh@2Ah@030>7Q00[Q

00<0hN40<n4002gQ00<0hN40:N400`oQh@3ohB?Q00<0hN406n400`3Qh@13h@030>7Q093Q00<0hN40

2n400`3Qh@0ch@00;N400`3Qh@0Yh@033n7Q0?oQ8n400`3Qh@0Kh@030>7Q04?Q00<0hN40S^4200kQ

00<0hN40<n4002gQ0P0Yh@033n7Q0?oQ9>400`3Qh@0Kh@030>7Q04?Q00<0hN40SN400`3Qh@0>h@03

0>7Q03?Q000]h@030>7Q02SQ00<?hN40on4Th@030>7Q01_Q0P14h@030>7Q08_Q0P0Bh@030>7Q03;Q

000]h@030>7Q02OQ00<?hN40on4Uh@030>7Q01_Q00<0hN40@n400`3Qh@2:h@030>7Q01;Q00<0hN40

<^4001OQ00<0hN400^400`3Qh@02h@040>7Qh@801^400`3Qh@0Wh@033n7Q0?oQ9N400`3Qh@0Kh@03

0>7Q04?Q00<0hN40RN400`3Qh@0Ch@030>7Q03;Q000Fh@030>4000OQ00<0h@001>400`3Qh@03h@03

0>7Q02OQ00<?hN40on4Uh@030>7Q01_Q00<0hN40@n400`3Qh@27h@805^400`3Qh@0bh@005^400`3Q

0007h@030>4000?Q00<0hN401>4302KQ00<?hN40on4Vh@030>7Q01_Q00<0hN40@n400`3Qh@26h@03

0>7Q01KQ00<0hN40<^4001KQ00<0h@001n400`3Q0004h@030>7Q00?Q00<0hN409^400`oQh@3ohBKQ

00<0hN406n400`3Qh@13h@030>7Q08CQ0P0Ih@030>7Q03;Q000Fh@030>4000OQ00<0h@000^400`3Q

0005h@030>7Q02GQ00<?hN40on4Xh@030>7Q01[Q0P14h@030>7Q08;Q0P0Kh@030>7Q03;Q000Gh@03

0>7Q00OQ00<0hN400^400`3Qh@04h@030>7Q02GQ00<?hN40on4Xh@030>7Q01[Q00<0hN40A>400`3Q

h@1oh@807^400`3Qh@0ah@00;N400`3Qh@0Th@033n7Q0?oQ:N400`3Qh@0Jh@030>7Q04CQ00<0hN40

O^4201oQ00<0hN40<N4002gQ00<0hN409>400`oQh@3ohBWQ00<0hN406^400`3Qh@14h@030>7Q07cQ

0P0Qh@030>7Q037Q000]h@809N400`oQh@3ohB[Q00<0hN406N400`3Qh@14h@030>7Q07[Q0P0Sh@03

0>7Q037Q000]h@030>7Q02?Q00<?hN40on4[h@030>7Q01WQ00<0hN40A>400`3Qh@1hh@809N400`3Q

h@0ah@00;N400`3Qh@0Sh@033n7Q0?oQ:n400`3Qh@0Ih@030>7Q04CQ00<0hN40M^4202OQ00<0hN40

<N4002gQ00<0hN408^400`oQh@3ohBcQ00<0hN406N4204GQ00<0hN40MN4202SQ00<0hN40<N4002gQ

00<0hN408^400`oQh@3ohBcQ00<0hN406N400`3Qh@14h@030>7Q07?Q0P0Zh@030>7Q037Q000]h@80

8n400`oQh@3ohBcQ00<0hN406N400`3Qh@14h@030>7Q073Q0`0/h@030>7Q037Q000]h@030>7Q027Q

00<?hN40on4^h@030>7Q01SQ00<0hN40AN400`3Qh@1]h@80;^4203?Q000]h@030>7Q027Q00<?hN40

on4^h@030>7Q017Q00<0hN401>400`3Qh@15h@030>7Q06_Q0P0`h@030>7Q03;Q000]h@030>7Q023Q

00<?hN40on4_h@030>7Q013Q00<0h@001N400`3Qh@15h@030>7Q06WQ0`0ah@030>7Q03;Q000]h@03

0>7Q023Q00<?hN40on4_h@030>7Q01;Q00<0hN400n4204KQ00<0hN40In4203CQ00<0hN40<^4002gQ

0P0Ph@033n7Q0?oQ<N400`3Qh@0?h@801^400`3Qh@16h@030>7Q06?Q0`0eh@80=>4002gQ00<0hN40

7n400`oQh@3ohC7Q00<0hN403n400`3Qh@05h@030>7Q04KQ00<0hN40HN4203SQ00<0hN40<n4002gQ

00<0hN407n400`oQh@3ohC;Q00<0hN403^4300GQ00<0hN40A^400`3Qh@1Oh@<0>N400`3Qh@0ch@00

;N400`3Qh@0Nh@033n7Q0?oQ<n400`3Qh@0Fh@030>7Q04KQ00<0hN40GN4203_Q0P0eh@00;N400`3Q

h@0Nh@033n7Q0?oQ<n400`3Qh@0Fh@030>7Q04OQ00<0hN40FN4303gQ00<0hN40=>4002gQ00<0hN40

7N400`oQh@3ohCGQ00<0hN405N4204SQ00<0hN40En42043Q00<0hN40=>4002gQ0P0Nh@033n7Q0?oQ

=N400`3Qh@0Eh@030>7Q04OQ00<0hN40E>4304;Q00<0hN40=>4002gQ00<0hN407>400`oQh@3ohCOQ

00<0hN405>400`3Qh@18h@030>7Q053Q0`14h@030>7Q03GQ000]h@030>7Q01cQ00<?hN40on4gh@03

0>7Q01CQ00<0hN40B>400`3Qh@1>h@80An400`3Qh@0eh@005n400`3Qh@02h@030>7Q00;Q00<0hN40

0^4300CQ00<0hN406n400`oQh@3ohCWQ00<0hN404n400`3Qh@18h@030>7Q04cQ0P18h@030>7Q03KQ

000Fh@030>4000OQ00<0h@001>400`3Qh@03h@030>7Q01_Q00<?hN40on4ih@030>7Q01?Q00<0hN40

B>400`3Qh@18h@@0B^400`3Qh@0fh@005^400`3Q0007h@030>4000;Q1004h@<06^400`oQh@3ohC_Q

00<0hN404^400`3Qh@19h@030>7Q04CQ0`1=h@80>>4001KQ00<0h@001n400`3Q0002h@030>4000GQ

00<0hN406^400`oQh@3ohCcQ00<0hN404N4204[Q00<0hN40@^42053Q00<0hN40=n4001KQ00<0h@00

1n400`3Q0003h@801N400`3Qh@0Ih@033n7Q0?oQ?N400`3Qh@0Ah@030>7Q04WQ00<0hN40?n43057Q

00<0hN40>>4001OQ00<0hN401n400`3Qh@03h@030>7Q00?Q00<0hN406N400`oQh@3ohCkQ00<0hN40

4>400`3Qh@1:h@030>7Q03[Q101Dh@030>7Q03SQ000]h@030>7Q01SQ00<?hN40on4oh@030>7Q013Q

00<0hN40B^400`3Qh@0hh@80En400`3Qh@0ih@00;N400`3Qh@0Hh@033n7Q0?oQ@>400`3Qh@0?h@03

0>7Q04_Q00<0hN40<n4405SQ0P0kh@00;N4201SQ00<?hN40on52h@030>7Q00kQ00<0hN40Bn400`3Q

h@0`h@@0Fn400`3Qh@0jh@00;N400`3Qh@0Gh@033n7Q0?oQ@^400`3Qh@0>h@80CN400`3Qh@0[h@@0

G^400`3Qh@0kh@00;N400`3Qh@0Fh@033n7Q0?oQA>400`3Qh@0=h@030>7Q04cQ00<0hN40:>44063Q

0P0mh@00;N400`3Qh@0Fh@033n7Q0?oQAN400`3Qh@0<h@030>7Q04gQ00<0hN408n4406CQ00<0hN40

?>4002gQ00<0hN405N400`oQh@3ohDOQ00<0hN402n400`3Qh@1=h@030>7Q01oQ1@1Vh@030>7Q03gQ

000]h@805^400`oQh@3ohDSQ00<0hN402^400`3Qh@1=h@030>7Q01cQ101Yh@80?n4002gQ00<0hN40

5>400`oQh@3ohD[Q00<0hN402N400`3Qh@1>h@030>7Q01OQ101/h@80@>4002gQ00<0hN405>400`oQ

h@3ohD_Q0P09h@030>7Q04kQ00<0hN404n4506oQ00<0hN40?n4002gQ00<0hN404n400`oQh@3ohDgQ

00<0hN401n42053Q00<0hN403n4407;Q00<0hN40@>4002gQ00<0hN404n400`oQh@3ohDkQ00<0hN40

1^400`3Qh@1@h@030>7Q00[Q101eh@030>7Q047Q000]h@030>7Q01;Q00<?hN40on5@h@801^400`3Q

h@1@h@801^4507SQ00<0hN40@^4002gQ0P0Ch@033n7Q0?oQD^4200CQ00<0hN40DN400`3Qh@0507[Q

0P15h@00;N400`3Qh@0Ah@033n7Q0?oQBn4500;Q00@0hN400n400`3Qh@1@h@D0ON4204KQ000]h@03

0>7Q017Q00<?hN40on5=h@070>7Qh@3Q0002h@040>7Q04gQ1@02h@030>7Q07cQ0P17h@00;N400`3Q

h@0@h@033n7Q0?oQC^401`3QhN40h@000n4404OQ1P07h@030>7Q07[Q0P18h@00;N400`3Qh@0@h@03

3n7Q0?oQC^401`3QhN40h@001N4304;Q1@0=h@030>7Q07OQ0`19h@00;N42013Q00<?hN40on5?h@07

0>7Qh@3Q0005h@030>7Q0080>n4501?Q00<0hN40MN4204_Q000]h@030>7Q00oQ00<?hN40on5>h@80

1>400`3Qh@04h@030>7Q00;Q100ah@H06N400`3Qh@1bh@<0C>4002gQ00<0hN403^400`oQh@3ohEcQ

00<0hN401^4302OQ1`0Oh@80LN4304kQ000]h@030>7Q00kQ00<?hN40on5Lh@030>7Q00WQ200Fh@T0

9n4206kQ0`1@h@005n400`3Qh@02h@030>7Q00;Q00<0hN400^400`3Qh@04h@030>7Q00gQ00<?hN40

on5Mh@030>7Q017Q5P0ah@80Jn4305;Q000Fh@030>4000OQ00<0h@000^400`3Q0005h@030>7Q00cQ

00<?hN40on5Nh@80Fn400`3Qh@1Uh@@0E>4001KQ00<0h@001n400`3Q0004h@030>7Q00?Q0`0<h@03

3n7Q0?oQG^400`3Qh@1Kh@030>7Q067Q101Gh@005^400`3Q0007h@030>4000;Q0P06h@030>7Q00_Q

00<?hN40on5Oh@030>7Q05cQ0P1Mh@D0F^4001KQ00<0h@001n400`3Q0002h@030>7Q00GQ00<0hN40

2^400`oQh@3ohF3Q00<0hN40GN4305KQ1P1Nh@005n400`3Qh@07h@040>7Qh@<01N400`3Qh@09h@03

3n7Q0?oQHN400`3Qh@1Oh@80D>4606?Q000]h@030>7Q00SQ00<?hN40on5Rh@030>7Q067Q0P19h@H0

J>4002gQ0P08h@033n7Q0?oQHn4206CQ0P11h@H0K^4002gQ00<0hN401^400`oQh@3ohFCQ00<0hN40

IN4303OQ201ch@00;N400`3Qh@04h@8?on5Wh@030>7Q06SQ0`0]h@P0N^4002gQ00<0hN400^423ooQ

JN400`3Qh@1[h@D08>49087Q000]h@030>4?008?on5[h@030>7Q06oQ2P0;h@d0RN4002gQ0PoohFkQ

00<0hN40N>4=09GQ000]h@80on5^h@80on4Lh@00;N400`3Qh@3ohFgQ00<0hN40on4Kh@00;N400`3Q

h@3ohFgQ00<0hN40on4Kh@00;N400`3Qh@3ohFgQ00<0hN40on4Kh@00on7ohK_Q003ohOoQ^n400?oQ

on6kh@00on7ohK_Q003ohOoQ^n400?oQon6kh@00on7ohK_Q003ohOoQ^n4007_Q10000n4000070003

h@0000CQ00@0hN7Q0P04h@<00^400`3Qh@02h@030>7Q00;Q00<0hN400^400`3Qh@02h@030>7Q00;Q

00<0hN400^400`3Qh@02h@030>7Q00;Q00<0hN400^400`3Qh@02h@030>7Q00;Q00<0hN400^400`3Q

h@02h@030>7Q0?oQen4007_Q0`08h@030>7Q00?Q00<0hN401n400`3Qh@02h@060>7Q0>400^400`3Q

0002h@030>4000;Q00<0h@000^400`3Q0002h@030>4000;Q00<0h@000^400`3Q0002h@030>4000;Q

00<0h@000^400`3Q0002h@030>4000;Q00<0h@000n400`3Qh@3ohMOQ001mh@030>7Q00@00^400`3Q

h@02h@030>7Q00OQ00@0hN7Q10001>40h@02h@030>4000;Q00<0h@000^400`3Q0002h@030>4000;Q

00<0h@000^400`3Q0002h@030>4000;Q00<0h@000^400`3Q0002h@030>4000;Q00<0h@000^400`3Q

0003h@030>7Q0;OQ0P3ohAkQ001lh@802>400`3Qh@03h@030>7Q00OQ00H0hN40h@02h@030>4000;Q

00<0h@000^400`3Q0002h@030>4000;Q00<0h@000^400`3Q0002h@030>4000;Q00<0h@000^400`3Q

0002h@030>4000;Q00<0h@000^400`3Q0002h@030>4000CQ00<0hN40]n400`3Qh@3ohAcQ000Dh@@0

00?Q00001P02h@X00^4200;Q0`02h@<00n420006h@000>40@>401`3QhN40h@001n400`3Q0003h@80

0^400`3Q0002h@030>4000;Q00<0h@000^400`3Q0002h@030>4000;Q00<0h@000^400`3Q0002h@03

0>4000;Q00<0h@000^400`3Q0002h@030>4000;Q00<0h@000^400`3Q0002h@030>4000CQ00<0hN40

/>4300;Q00<0hN40on4Ih@005N401P3Qh@3Q00;Q00<0h@001>401P3Qh@3Q00;Q00<0h@001N400`3Q

h@02h@050>7Qh@000^40103Q0>4203oQ0P04h@030>7Q00OQ00<0hN400n401@3QhN4000CQ00<0hN40

0^400`3Qh@02h@030>7Q00;Q00<0hN400^400`3Qh@02h@030>7Q00;Q00<0hN400^400`3Qh@02h@03

0>7Q00;Q00<0hN400^400`3Qh@02h@040>7Qh@<00n400`3Qh@2`h@080>7Q0>40h@3ohA[Q000Eh@06

0>7Q0>401>400`3Qh@02h@030>7Q00;Q00<0hN400^400`3Qh@03h@030>7Q00;Q00D0hN7Q0002h@04

0>40h@80on5Ch@080>7Q0>40h@3ohA[Q000Eh@050>7Q0>400P03h@800n400`3Qh@02h@800n400`3Q

h@03h@030>7Q00;Q00D0hN7Q0002h@060>400>40on5Dh@<000CQ0>40on4Jh@005N401P3Qh@3Q00;Q

00<0h@000^400`3Q0004h@0>0>7Q0>40h@3Q0>40h@02h@050>7Qh@000^401P3Q003Q0?oQF>400`3Q

003ohA[Q000Dh@@000?Q00002`02h@D000GQ0000h@050004h@0000?Q0P001>400>420?oQFN400`3Q

h@3ohAWQ003ohOoQ^n400?oQon6kh@00on7ohK_Q003ohOoQ^n400?oQon6kh@00on7ohK_Q003ohOoQ

^n400?oQon6kh@00on7ohK_Q0000\

\>"],

  ImageRangeCache->{{{49.4375, 606.5}, {242.625, 79.4375}} -> {-0.242109, 

  0.286134, 0.00302982, 0.00302982}, {{63.875, 315.375}, {238.688, 

  83.3125}} -> {-0.443313, 0.0277434, 0.00390259, 0.000378086}, {{340.5, 

  592}, {238.688, 83.3125}} -> {3.19546, 1.69899, 0.0227494, 0.159503}}]

}, Open  ]]

}, Open  ]],



Cell[CellGroupData[{



Cell["3 The Cubic Polynomial Problem", "Subsection",

  FontSize->18],



Cell[CellGroupData[{



Cell[BoxData[{

    \(We\ now\ try\ to\ understand\ the\ global\ structure\ of\ the\ surface\ 

      \(q\_0\) \((a, k)\) . \nThe\ above\ bifurcation\ diagrams\ are\ just\ 

      sections\ of\ this\ surface\ at\ various\), 

    \(values\ of\ k . \ In\ this\ section\ we\ investigate\ the\ one - 

      dimensional\ \ algebraic\), 

    \(problem, \n

    \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ 

    c\  + \ d\ x\  - \ x\^3\  = \ 

      0. \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \

\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \((3.1)\)\), 

    \(This\ equation\ \ has\ a\ cubic\ nonlinearity\ and\ two\ parameters\ 

      "\<c\>"\ and\ "\<d\>" . \ Our\), 

    \(buckling\ problem\ also\ has\ a\ cubic\ nonlinearity\ and\ two\ 

      parameters\ "\<a\>"\ and\ "\<k\>", \n

    but\ is\ much\ more\ complicated\ since\ it\ is\ infinite\ dimensional\ 

      problem . \ The\ \), 

    \(surface\ x \((c, d)\)\ defined\ by\ \((3.1)\)\ is\ shown\ below\ 

      together\ with\ the\ graph\ of\), 

    \(the\ equation\ \), 

    \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ 

    d\  = \ 3\ 

        \((c\/2)\)\^\(2\/3

              \)\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \

\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ 

        \((3.2)\)\), 

    \(called\ a\ cusp, \ 

    which\ is\ the\ set\ of\ points\ in\ the\ \((c, d)\) - 

      plane\ for\ which\ the\), 

    \(folding\ surface\ below\ has\ vertical\ tangency . \ Over\ a\ point\ in

      \ the\ interior\ of\), 

    \(the\ cusp, \ the\ surface\ has\ multiple\ \(solutions . \)\ \t\n\t\t\t\n

    \)}], "Input",

  FontFamily->"Times New Roman",

  FontSize->16],



Cell[GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000@0000300P10`400001

00000800002008200000P800P020P<30`<3L`:K:l03o0?oo0000ool0o`3o

ooooo`000800002008200000P800P020P820P<30`?l0003o0?oo0000ool0

o`3oooooo`000800002008200000P800P020P820P<30`?l0003o0?oo0000

ool0o`3oooooo`000800002008200000P800P020P820P<30`?l0003o0?oo

0000ool0o`3oooooo`000800002008200000P800P020P820P<30`?l0003o

0?oo0000ool0o`3oooooo`000800002008200000P800P020P820P<30`?l0

003o0?oo0000ool0o`3oooooo`000800002008200000P800P020P820P<30

`?l0003o0?oo0000ool0o`3oooooo`000800002008200000P800P020P820

P<30`?l0003o0?oo0000ool0o`3oooooo`000800002008200000P800P020

P820P<30`?l0003o0?oo0000ool0o`3oooooo`000800002008200000P800

P020P820P<30`?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P820P<30`?l0003o0?oo0000ool0o`3oooooo`00080000200820

0000P800P020P820P<30`?l0003o0?oo0000ool0o`3oooooo`0008000020

08200000P800P020P820P<30`?l0003o0?oo0000ool0o`3oooooo`000800

002008200000P800P020P820P<30`?l0003o0?oo0000ool0o`3oooooo`00

0800002008200000P800P020P820P<30`?l0003o0?oo0000ool0o`3ooooo

o`000800002008200000P800P?okl:2PY820P?l0003o0?oo0000ool0o`3o

ooooool?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo

3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?

o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l0

0?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?

10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo

3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?

o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l0

0?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?

10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo

3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?

o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l0

0?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?

10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo

3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?

o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l0

0?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?

10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo

3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?

o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l0

0?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?

10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo

3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?

o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l0

0?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?

10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo

3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?

o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l0

0?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?

10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo

3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?

o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l0

0?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?

10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo

3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?

o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l0

0?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?

10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo

3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?

o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l0

0?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?

10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo

3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?

o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l0

0?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?

10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo

3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?

o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l0

0?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?

10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo

3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?

o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l0

0?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?

10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo

3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?

o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l0

0?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?

10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo

3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?

o`oo3ol?10l00?l?o`oo3ol?10l00?l?f@l00aT?3`0I3`036@l?0?l?o`l;

3`00o`oG3`8I7@l26Ol?o`l;3`00o`oF3`8I7`l26Ol?o`l:3`00o`oF3`8I

7`l26Ol?o`l:3`00o`nU3`<I00<?6AT06Pl56@/?0QT63`DI0Pl00aT?3`03

3`TI1@l26@h?2AT23`036@l?00D?1AWo3n8?003o3j@?0aT00`lI6@036AL?

0aT23`8I2Pl26@D?0aT33`046@l?6@D?21T53`8I3`l86@<?00<I3`l00`l3

6@8?0QWo3n4?003o3j<?0aT33`<I60l26@@?0QT83`<I10l36@L?00<I3`l0

10l86@@?0aT?3`PI0Pl00aT?3`033`8I10l26Ol?h0l00?l?X`l36@<?0aTN

3`<I1`l36@@?0aT73`036@l?00D?00<I3`l00`l00aT?3`023`<I40l00aT?

3`033`046@l?6@/?0aWo3ml?003o3j<?0aT33`<I7Pl36@L?0aT43`<I20l0

0aT?3`053`036@l?00L?0aTA3`036@l?00H?00<I3`l020l36Ol?g`l00?l?

X`l36@<?0aT73`XI30l46@L?0aT43`<I20l00aT?3`053`8I20l36A4?0QT7

3`036@l?00L?11Wo3ml?003o3j<?0aT33`<I70l56@L?0aT43`<I20l00aT?

3`063`8I1`l36A8?0QT63`036@l?00H?1AWo3ml?003o3j<?0aT33`<I6`l5

6@P?0aT53`8I0Pl36@@?00<I3`l01Pl26@H?0aT23`036@l?00D?00<I3`l0

1Pl26@H?00<I3`l010l56Ol?h0l00?l?Y0l36@033aTI008I1`l:6@/?0QT;

3`8I1@l36@043aTI6@@?00<I3`l01Pl26@H?0QT43`036@l?00<?00<I3`l0

1`l26@H?00<I3`l01@l26Ol?hPl00?l?Y@l36@043aTI6Ad?0QT:3`8I1`l4

6@D?00<I3`l01Pl36@D?0QT43`036@l?00<?00<I3`l01`l36@D?00<I3`l0

1Pl26Ol?h@l00?l?Z@l36Ad?0aT:3`8I40l00aT?6@053`<I10l26@H?00DI

3`l?6@043`036@l?00<?0aT63`036@l?00D?0aWo3n0?003o3jT?0aTH3`8I

0Pl46@X?0QT@3`046@l?6@<?11T43`8I1`l00aT?6@063`046@l?3`@I1Pl0

0aT?3`026@8?11Wo3n0?003o3jT?0aTI3`LI2`l26@l?00<I3`l01aT43`8I

20l00aT?6@063`LI1`l011T?3`l76Ol?h0l00?l?Z0l46AX?1AT>3`036@l?

00d?00@I3`l?11T43`036@l?00T?00<I3`l01`l46@T?00@I3`l?1AWo3n4?

003o3ol?o`oo3`@?003o3ol?o`oo3`@?003o3ol?o`oo3`@?003o3ol?o`oo

3`@?003o3ol?o`oo3`@?003o3ol?o`oo3`@?003o3ol?o`oo3`@?003o3ol?

o`oo3`@?003o3ol?o`oo3`@?003o3ol?o`oo3`@?003o3ol?o`oo3`@?003o

3ol?o`oo3`@?003o3ol?o`oo3`@?003o3ol?o`oo3`@?003o3ol?o`oo3`@?

003o3ol?o`oo3`@?003o3ol?o`oo3`@?003o3ol?o`oo3`@?003o3ol?o`oo

3`@?003Y3`80o`oo3ol?60l00>T?@`3o3ol?ePl00>T?P`3o3ol?UPl00>P?

0P123h00o`oo3eH?003X3`80PPn00?l?o`lF3`00i`l20<<?P@3o3m@?003W

3`80o`l43h40P@l30?l?40l00>H?0P3o3dH?P0113`<0o`l@3`00iPl20?l?

QPn20?l?4Pl00>H?0P3o3lH?@P3o3a8?003U3`80o`l?3`H0l@l20?l?4`l0

0>D?0P3o3`h?0P023`<0l@l20?l?4`l00>@?0P3o3`h?0P043`80l0l20?l?

50l00>@?0P3o3`h?0P043`80k`l20?l?5@l00><?0P3o3`l?0P043`80k`l2

0?l?5@l00><?0P3o3`l?0P043`80kPl20?l?5Pl00><?0P3o3`l?0P043`80

kPl20?l?5Pl00>8?0P3o3a4?0P023`<0k@l20?l?5`l00>8?0P3o3a8?1P3/

3`80o`lH3`00h@l20?l?5`l20>`?0P3o3aP?003Q3`80o`lG3`80j`l20?l?

6@l00>0?0P3o3aP?0P3[3`80o`lI3`00h0l20?l?o`l53`80o`lJ3`00h0l2

0?l?o`l43`80o`lK3`00g`l20?l?o`l53`80o`lK3`00g`l20?l?o`l43`80

o`lL3`00gPl20?l?o`l53`80o`lL3`00gPl20?l?o`l43`80o`lM3`00g@l2

0?l?5`l20>X?0P3o3ah?003M3`80o`lG3`<0j@l20?l?7Pl00=d?0P2Y3`@I

J@l30>P?0P3o3al?003L3`80Z@l00`0I6@056FH?103W3`80o`lO3`00g0l2

0:T?10076F0?10000`l0003V3`80o`lP3`00f`l20:d?10076Ed?1P000`l0

3`3S3`80o`lQ3`00f`l20;0?10076EP?10000`l000040><?0P3o3b4?003J

3`80]0l400LIE@l00`0?000803X?0aVU3`80o`lR3`00fPl20;L?10076E4?

3@0g3`DIY@l20?l?8Pl00=X?0P2j3`@01QU>3`X000@?0000=0l66@0300l?

0:<?0P3o3b<?003I3`80_Pl400HICPl300033`0000D0<Pl66@0300l?0:@?

0P3o3b@?003I3`80`@l300LIC0l503D?1AT00`0?3`2W3`80o`lT3`00f0l2

0<D?0`066Dh?00<03`l0<@l56@0300l?0:P?0P3o3bD?003H3`80b0l300HI

BPl00`0?3`0`3`DI00<03`l0ZPl20?l?9@l00=L?0P3<3`801QU83`0300l?

02h?1AT00`0?3`2[3`80o`lV3`00e`l20<l?0P066DD?00<03`l0:`l66Jl?

0P3o3bL?003G3`80d@l200HI@Pl00`0?3`0Z3`HI/@l20?l?9`l00=H?0P3E

3`801AU03`0300l?02P?1AT00`0?3`2`3`80o`lX3`00ePl20=L?0P056Cd?

00<03`l09`l56@0300l?0;8?0P3o3bP?003E3`80fPl200DI>`l00`0?3`0U

3`DI]Pl20?l?:@l00=D?0P3L3`8011Tj3`0300l?02<?1AVg3`80o`lZ3`00

e0l20=l?0P046CL?00<03`l08Pl56KT?0P3o3bX?003D3`80h@l00`0I6@02

6CH?00<03`l080l56KX?0P3o3b/?003D3`80h`l0100I6ATe3`0300l?01d?

00<06AT00aVl3`80o`l[3`00d`l20>D?00@06ATI<`l00`0?3`0L3`0301TI

00<I_@l20?l?;0l00=<?0P3W3`@I<@l00`0?3`0J3`0301TI00<I_Pl20?l?

;@l00=8?0P3Y3`@I;`l00`0?3`0I3`0301TI00<I`0l20?l?;@l00=8?0P3Z

3`0401TI6Bh?00<03`l05`l00`0I6@036L4?0P3o3bh?003A3`80k0l0100I

6AT]3`0300l?01D?00<06AT00aW33`80o`l^3`00d@l20>d?00@06ATI:`l0

0`0?3`0D3`0301TI00<Ia0l20?l?;`l00=4?0P3^3`0401TI6BX?00<03`l0

4`l56LD?0P3o3c0?003@3`80l0l00`0I6@0Y3`0300l?018?1AW73`80o`l`

3`00d0l20?4?00<06AT0:0l00`0?3`0@3`0301TI008Ib0l20?l?<@l00<l?

0P3c3`<I9`l00`0?3`0>3`0301TI008IbPl20?l?<@l00<l?0P3d3`8I9Pl0

0`0?3`0>3`0301TI008IbPl20?l?<Pl00<h?0P3e3`0301TI02D?00<03`l0

30l00`0I6@026L/?0P3o3c<?003>3`80mPl26BD?00<03`l02`l00`0I6@02

6L`?0P3o3c<?003>3`80m`l26B<?00<03`l02Pl00`0I6@026Ld?0P3o3c@?

003=3`80n0l36B8?00<03`l02@l00`0I6@026Lh?0P3o3c@?003=3`80n@l2

6B4?00<03`l02@l0100I6AW?3`80o`le3`00c0l20?X?00<06AT080l00`0?

3`083`@Ic`l20?l?=Pl00<`?0P3k3`8I80l00`0?3`063`0301TI008Id0l2

0?l?=Pl00</?0P3l3`0301TI01h?00<03`l01Pl0100I6AWA3`80o`lg3`00

b`l20?d?0QTN3`0300l?00D?00@06ATIdPl20?l?=`l00</?0P3m3`8I7Pl0

0`0?3`043`0401TI6M8?0P3o3cP?003:3`80o`l26A`?00<03`l010l0100I

6AWB3`80o`li3`00bPl20?l?0QTL3`0300l?00<?00@06ATId`l20?l?>@l0

0<T?0P3o3`4?00<06AT06Pl00`0?3`033`0401TI6M<?0P3o3cX?00393`80

o`l23`8I6Pl00`0?3`023`0401TI6M@?0P3o3cX?00383`80o`l33`8I6Pl0

1@0?3`l000<Ie0l20?l?>`l00<P?0P3o3`<?0QTI3`0500l?3`000aWD3`80

o`ll3`00b0l20?l?0`l00`0I6@0H3`0400l?3`<Ie@l20?l??0l00<L?0P3o

3`D?0QTH3`0400l?008Ie@l20?l??@l00<L?0P3o3`D?0QTG3`0400l?008I

ePl20?l??@l00<H?0P3o3`H?00<06AT05Pl0100?00026MD?0P3o3ch?0036

3`80o`l63`0301TI01D?00@03`l00QWE3`80o`lo3`00a@l20?l?20l26AD?

00<03`000aWE3`80o`lo3`00a@l20?l?20l26AD?00<03`000QWE3`80o`m0

3`00a@l20?l?20l00`0I6@0C3`0300l0008IePl20?l?@0l00<@?0P3o3`T?

00<06AT04`l00`0?00026MD?0P3o3d4?00343`80o`l:3`8I4`l2008IePl2

0?l?@@l00<<?0P3o3`/?0QTB3`800aWE3`80o`m23`00``l20?l?2`l00`0I

6@0A3`800QWE3`80o`m33`00`Pl20?l?30l00`0I6@0@3`0400lI6MH?0P3o

3d<?00323`80o`l<3`0301TI010?0P026MD?0P3o3d@?00323`80o`l<3`03

01TI010?00<06AT0ePl20?l?A0l00<4?0P3o3`h?0QT?3`0400lI6MD?0P3o

3dD?00313`80o`l>3`0301TI00h?0P026M@?0P3o3dH?00303`80o`l?3`03

01TI00d?0P026MD?0P3o3dH?00303`80o`l?3`0301TI00d?0P026M@?0P3o

3dL?002o3`80o`l@3`0301TI00d?00<06AT0e@l20?l?A`l00;l?0P3o3a0?

00<06AT030l0100?6AWD3`80o`m83`00_`l20?l?4@l00`0I6@0;3`0301TI

0=@?0P3o3dT?002n3`80o`lB3`0301TI00/?00<06AT0e0l20?l?B@l00;h?

0P3o3a8?00<06AT02Pl00`0I6@3D3`80o`m:3`00_@l20?l?4`l00`0I6@0:

3`0301TI0=@?0P3o3dX?002m3`80o`lC3`0301TI00T?00@03aTId`l20?l?

B`l00;`?0P3o3a@?00<06AT02@l00`0I6@3C3`80o`m<3`00_0l20?l?5@l0

0`0I6@083`0301TI0=<?0P3o3d`?002l3`80o`lE3`0301TI00L?00<06AT0

d`l20?l?C@l00;/?0P3o3aH?00<06AT01`l00`0I6@3C3`80o`m=3`00^`l2

0?l?5Pl00`0I6@073`0301TI0=8?0P3o3dh?002j3`80o`lG3`0301TI00H?

00<06AT0dPl20?l?C`l00;X?0P3o3aL?00<06AT01Pl00`0I6@3B3`80o`m?

3`00^@l20?l?60l2008I0`l2008IdPl20?l?D0l00;T?0P3o3aT?00<06AT0

0Pl3008IdPl20?l?D0l00;T?0P3o3aT?00<06AT00Pl3008Id@l20?l?D@l0

0;P?0P3o3aX?00@06AT?0`026M4?0P3o3e8?002h3`80o`lJ3`0401TI3`<0

0QWA3`80o`mB3`00]`l20?l?6`l0100I6@l2008Id@l20?l?D`l00;L?0P3o

3a/?0P026@800QU>3`80P@l20?l?D`l00;H?0P3o3a`?0P026@800QU=3`80

00<?00l0OPl20?l?E0l00;H?0P3o3a`?0P026@0301TI04h?200;3`@0J`l2

0?l?E@l00;H?0P3o3ad?00@06AT00QU>3`X000<?00l01@l2008?0P1Z3`80

o`mE3`00]@l20?l?7Pl00`0I6@026B@0:Pl=00D?0P043`80J0l20?l?EPl0

0;D?0P3o3ah?00@06AT09@lZ00033`0000@02`l206h?0P3o3eH?002d3`80

o`lO3`<0D@l400d?0P1]3`80o`mG3`00]0l20?l?7`l3054?0`0>3`80K0l2

0?l?F0l00;<?0P3o3b8?00<03`l0C`l200l?0P043`80IPl20?l?F0l00;<?

0P3o3b8?00<03`l0H@l2008?0P1V3`80o`mI3`00/`l20?l?8Pl00`0?3`1R

3`@0I`l20?l?F@l00;8?0P3o3b<?00<03`l0c0l20?l?FPl00;8?0P3o3b<?

00<03`l0b`l20?l?F`l00;4?0P3o3b@?00<03`l0b`l20?l?F`l00;4?0P3o

3b@?00<03`l0bPl20?l?G0l00;0?0P3o3bD?00<03`l0bPl20?l?G0l00;0?

0P3o3bD?00<03`l0b@l20?l?G@l00;0?0P3o3bD?00<03`l0b0l20?l?GPl0

0:l?0P3o3bH?00<03`l0b0l20?l?GPl00:l?0P3o3bH?00<03`l0a`l20?l?

G`l00:h?0P3o3bL?00<03`l0a`l20?l?G`l00:h?0P3o3bL?00<03`l0aPl2

0?l?H0l00:d?0P3o3bP?00<03`l0a@l20?l?H@l00:d?0P3o3bP?00<03`l0

a@l20?l?H@l00:d?0P3o3bL?00<03`l0a@l20?l?HPl00:`?0P3o3bP?00<0

3`l0a@l20?l?HPl00:`?0P3o3bP?00<03`l0a0l20?l?H`l00:/?0P3o3bT?

00<03`l0``l20?l?I0l00:/?0P3o3bT?00<03`l0``l20?l?I0l00:X?0P3o

3bX?00<03`l0`Pl20?l?I@l00:X?0P3o3bX?00<03`l0`Pl20?l?I@l00:X?

0P3o3bX?00<03`l0`@l20?l?IPl00:T?0P3o3b/?00<03`l0`0l20?l?I`l0

0:T?0P3o3b/?00<03`l0`0l20?l?I`l00:P?0P3o3b`?00<03`l0_`l20?l?

J0l00:P?0P3o3b`?00<03`l0_`l20?l?J0l00:L?0P3o3bd?00<03`l0_Pl2

0?l?J@l00:L?O@2a3`0300l?0;d?0P3o3fX?002V3oT0=Pl00`0?3`023b<0

V0l20?l?JPl00:H?0P1l3jl00Pl0100?3`m707@?0P3o3f/?003o3j0?=002

3`0400l?3kd0o`m[3`00o`oF3`0300l?02@?VP3o3f/?003o3mH?00<03`l0

APl00`0?3`1a3`@0o`m[3`00o`oF3`0300l?0;X?0`3o3f`?003o3mH?00<0

3`l0o`oo3bX?003o3mH?00<03`l0o`oo3bX?003o3mH?00<03`l0o`oo3bX?

003o3mH?00<03`l0o`oo3bX?003o3mH?00<03`l0o`oo3bX?003o3mH?00<0

3`l0o`oo3bX?003o3mH?00<03`l0o`oo3bX?003o3mH?00<03`l0o`oo3bX?

003o3mH?00<03`l0o`oo3bX?003o3mH?00<03`l0o`oo3bX?003o3mH?00<0

3`l0o`oo3bX?003o3mH?103o3ol?:@l00?l?d@l;0?l?o`lW3`00o`oB3`X0

o`oo3bL?003o3m8?0P000`l000040?l?o`lX3`00o`oC3`L0o`oo3bT?003o

3mD?1@3o3ol?:@l00?l?e0l50?l?o`lZ3`00o`oE3`80o`oo3b`?003o3ol?

o`oo3`@?003o3ol?o`oo3`@?003o3ol?o`oo3`@?003o3ol?o`oo3`@?003o

3ol?o`oo3`@?003o3ol?o`oo3`@?003o3ol?o`oo3`@?003o3ol?o`oo3`@?

003o3ol?o`oo3`@?003o3ol?o`oo3`@?003o3ol?o`oo3`@?003o3ol?o`oo

3`@?003o3m8?00<03`l0o`oo3bh?003o3m<?0P023`80o`oo3bX?003o3m<?

0P023`80o`oo3bX?003o3m@?103o3ol?:`l00?l?e@l20?l?o`l/3`00o`oD

3`@0o`oo3b/?003o3m<?0P023`80o`oo3bX?003o3m<?0P023`80o`oo3bX?

003o3m8?0P043`80o`oo3bT?003o3ol?o`oo3`@?003o3ol?o`oo3`@?003o

3ol?o`oo3`@?003o3ol?30l7024?2@093`<00`l301L?0`033`<04@l7024?

1`3o3e@?003o3ol?30l7024?2@093`<00`l301L?0`033`<04@l7024?1`3o

3e@?003o3ol?2Pl300D?0`0=3`<03@l300D?0`093`<00`l301L?0`033`<0

3`l300D?0`0M3`<01@l30?l?DPl00?l?o`l:3`<01@l300d?0`0=3`<01@l3

00T?0`033`<05`l300<?0`0?3`<01@l301d?0`053`<0o`mB3`00o`oo3`X?

0`0E3`<03@l300D?0`0;3`D06`l501T?0`093`/02@l300D?0`3o3e8?003o

3ol?2Pl301D?0`0=3`<01@l300/?1@0K3`D06@l300T?2`093`<01@l30?l?

DPl00?l?o`l:3`<04@l;00T?0`053`<02`l500/?1@0;3`D06@l301d?0`05

3`<0o`mB3`00o`oo3`X?0`0A3`/02@l300D?0`0;3`D02`l500/?1@0I3`<0

7@l300D?0`3o3e8?003o3ol?2Pl300D?0`0=3`<03@l300D?0`093`<00`l3

01L?0`033`<04`l500/?2`093`<01@l30?l?DPl00?l?o`l:3`<01@l300d?

0`0=3`<01@l300T?0`033`<05`l300<?0`0C3`D02`l;00T?0`053`<0o`mB

3`00o`oo3``?1`0?3`<03`l900T?0`033`<05`l300<?0`0G3`<07@l300D?

0`3o3e8?003o3ol?30l700l?0`0?3`T02@l300<?0`0G3`<00`l301L?0`0M

3`<01@l30?l?DPl00?l?o`lj3`<0B@l301d?0`053`<0o`mB3`00o`oo3cX?

0`193`<07@l300D?0`3o3e8?003o3ol?>Pl303@?0`053`<00Pl300D?0`0M

3`<01@l30?l?DPl00?l?o`lj3`<0=0l300D?0`023`<01@l301d?0`053`<0

o`mB3`00o`oo3cX?0`0f3`<000@?00001Pl7024?1`3o3e@?003o3ol?>Pl3

03H?0`0010l000063`L08@l70?l?E0l00?l?o`me3`<0o`n;3`00o`oo3gD?

0`3o3h/?003o3ol?o`oo3`@?003o3ol?o`oo3`@?003o3ol?o`oo3`@?003o

3ol?o`oo3`@?003o3ol?o`oo3`@?003o3ol?o`oo3`@?003o3ol?o`oo3`@?

003o3ol?o`oo3`@?003o3ol?o`lA3`0300l?0>l?003o3ol?o`l83``0k`l0

0?l?o`ol3aL0k`l00?l?o`oc3aD01`l20?4?003o3ol?j@lD018?0P3a3`00

o`oo3n4?4`0J3`80lPl00?l?o`oI3a4090l20?8?003o3ol?dPl@02/?0P3c

3`00o`oo3l/?3`0c3`80l`l00?l?o`o53`h0>@l20?@?003o3ol?`0l<040?

0P3d3`00o`oo3k/?2`163`80m0l00?l?o`ng3`X0BPl20?D?003o3ol?/Pl:

04l?0P3e3`00o`oo3jh?2P1B3`80mPl00?l?_Pl20>X?201G3`80mPl00?l?

_@l70>8?201J3`80m`l00?l?XPl`0=4?201M3`80m`l00?l?U`m<0;d?1`1Q

3`80m`l00?l?S`lD020?20063a@0^0l706<?0P3h3`00o`n93`l0<@l00`0?

3`0D3`P0/`l606H?0P3h3`00o`n23`h0E0l80:`?1P1X3`80n@l00?l?O@l=

05d?202W3`H0JPl20?T?003o3gP?2`1X3`L0XPl506d?0P3i3`00o`mc3`/0

L0l709d?1@1^3`80nPl00?l?KPl;07P?1@2J3`D0L0l20?X?003o3fX?2P20

3`<0U`l5074?0P3k3`00o`mU3`X0QPl309@?1@1c3`80n`l00?l?H@l:08/?

0`2A3`D0M0l20?`?003o3ed?2@2A3`<0SPl507H?0P3l3`00o`mH3`X0UPl2

08`?1@1h3`80o0l00?l?E0l:09/?0P293`D0N@l20?d?003o3e0?2@2P3`80

Q`l507/?0P3m3`00o`m<3`T0Y0l208H?101l3`80oPl00?l?A`l:0:T?0P23

3`@0OPl20?h?003o3d<?2P2]3`80P@l507h?0P3o3`00o`lo3`T0/Pl2080?

10203`80o`l00?l?>`l90;D?0`1n3`@0PPl20?l?003o3cL?2@2i3`<0O@l4

088?0P3o3`4?003o3c<?2@2m3`80O0l408@?0P3o3`4?003o3bl?2@313`80

N`l408@?0P3o3`8?003o3b/?2@353`80N@l408H?0P3o3`8?003o3bL?2@39

3`80M`l508L?0P3o3`8?003o3b<?2@3=3`80MPl408P?0P3o3`<?003o3al?

2@3@3`80M@l408X?0P3o3`<?003o3a/?2@3D3`80M0l408X?0P3o3`@?003o

3aL?2@3H3`80L`l308`?0P3o3`@?003o3a<?2@3K3`80LPl408`?0P3o3`D?

003o3`l?2@3O3`80L@l408d?0P3o3`D?003o3`/?2@3S3`80K`l408l?0P3o

3`D?003o3`L?2@3V3`80K`l408l?0P3o3`H?003o3`<?2@3Z3`80K@l4094?

0P3o3`H?003n3`T0k@l306`?102A3`80o`l73`00nPl90?0?0`1/3`<0T`l2

0?l?1`l00?H?2@3c3`<0J`l409<?0P3o3`P?003b3`T0mPl406X?102D3`80

o`l83`00kPl90?T?101Z3`<0UPl20?l?20l00>X?2@3l3`<0JPl409H?0P3o

3`T?003V3`T0o`l406T?102G3`80o`l93`00hPl90?l?0`l406P?102H3`80

o`l:3`00gPl90?l?1Pl200033`0006L?102I3`80o`l:3`00d`l200D?2@3o

3`T?00<03`l00P1W3`<0V`l20?l?2Pl00=<?0P000`l000070?l?30l2008?

0P1U3`@0V`l20?l?2`l00=8?2@3o3`l?0P023`80I@l409`?0P3o3`/?003B

3`D0o`lA3`@00Pl206@?0`2M3`80o`l<3`00dPl20?l?4`l4008?0P1S3`@0

WPl20?l?30l00=4?0P3o3a8?10043`80HPl409h?0P3o3`d?003A3`80o`lA

3`@010l2064?102P3`80o`l=3`00d0l20?l?40l400H?0P1P3`@0X@l20?l?

3@l00=0?0P3o3`h?1@063`80H0l30:8?0P3o3`h?003@3`80o`l<3`D020l2

05h?102S3`80o`l>3`00c`l20?l?2Pl600T?0P1N3`@0X`l20?l?3`l00<l?

0P3o3`P?1P0;3`80G@l30:D?0P3o3`l?003>3`80o`l63`H03@l205`?102U

3`80o`l@3`00cPl20?l?0`l700h?0P1L3`@0YPl20?l?40l00<d?0P3o3`8?

1P0A3`80FPl40:P?0P3o3a0?003=3`80oPl601<?0P1J3`@0Z0l20?l?4@l0

0<d?0P3k3`L05@l205P?102Z3`80o`lA3`00c0l20?P?200G3`80F0l40:X?

0P3o3a8?003<3`80m@l801X?0P1G3`<0[0l20?l?4Pl00</?0P3c3`L07@l2

05H?102]3`80o`lB3`00b`l20?0?1`0P3`80E@l40:d?0P3o3a<?003;3`80

k@l7028?0P1E3`<0[`l20?l?4`l00<X?0P3[3`L09@l205<?102_3`80o`lD

3`00bPl20>L?200W3`80D`l40;0?0P3o3a@?00393`80i@l802X?0P1B3`<0

/@l20?l?5@l00<T?0P3R3`L0;@l2054?102b3`80o`lE3`00b0l20>4?1P0`

3`80D0l40;<?0P3o3aD?00383`80gPl6038?0P1@3`<0]0l20?l?5Pl00<P?

0P3L3`H0=0l204h?102e3`80o`lF3`00a`l20=/?1@0f3`80CPl40;D?0P3o

3aL?00373`80f0l603L?0P1>3`<0]`l20?l?5`l00<H?0P3G3`H0>@l204`?

102g3`80o`lH3`00aPl20=D?1@0k3`80C0l40;P?0P3o3aP?00363`80dPl6

03d?0P1:3`@0^Pl20?l?60l00<D?0P3A3`H0?Pl204X?102j3`80o`lI3`00

a@l20<l?1@113`80B@l30;`?0P3o3aT?00343`80cPl5048?0P183`@0_0l2

0?l?6Pl00<@?0P3<3`D0A0l204L?102m3`80o`lJ3`00``l20<`?10153`80

A`l30;l?0P3o3aX?00333`80bPl404L?0P153`@0_`l20?l?6`l00<<?0P38

3`D0A`l204D?10303`80o`lK3`00`Pl20<P?10193`80A0l30<4?0P3o3a`?

00323`80a`l304X?0P133`@0`Pl20?l?70l00<4?0P373`<0B`l2048?1032

3`80o`lM3`00`@l20<H?0`1;3`80@Pl30<@?0P3o3ad?00313`80a@l304`?

0P103`@0a@l20?l?7@l00<0?0P353`<0C0l2040?10353`80o`lN3`00`0l2

0<@?0`1<3`80?`l40<L?0P3o3ah?002o3`80a@l204d?0P0n3`@0a`l20?l?

7`l00;l?0P343`80C@l203h?0`393`80o`lO3`00_Pl20<@?0`1=3`80?0l4

0<T?0P3o3b0?002n3`80a0l204d?0P0l3`@0bPl20?l?80l00;h?0P333`80

CPl203X?103<3`80o`lP3`00_@l20<@?0P1=3`80>Pl40<`?0P3o3b4?002m

3`80``l204h?0P0i3`<0cPl20?l?8@l00;`?0P343`80C@l203P?103>3`80

o`lR3`00_0l20<<?0P1>3`80=`l40<l?0P3o3b8?002l3`80``l204d?0P0f

3`@0d@l20?l?8Pl00;/?0P333`80CPl203D?103A3`80o`lS3`00^`l20<<?

0P1=3`80=@l30=<?0P3o3b<?002j3`80``l204h?0P0c3`@0d`l20?l?90l0

0;X?0P333`80C@l203<?103D3`80o`lT3`00^@l20<<?0P1>3`80<@l40=D?

0P3o3bD?002i3`80``l204d?0P0a3`@0ePl20?l?9@l00;T?0P323`80C@l2

030?103H3`80o`lU3`00^0l20<8?0P1>3`80;`l40=P?0P3o3bH?002h3`80

`Pl204d?0P0_3`<0fPl20?l?9Pl00;L?0P333`80C@l202d?103J3`80o`lW

3`00]`l20<<?0P1<3`80;@l40=/?0P3o3bL?002g3`80``l204`?0P0[3`@0

g0l20?l?:0l00;H?0P343`80B`l202/?103M3`80o`lX3`00]Pl20<@?0P1;

3`80:@l40=l?0P3o3bP?002e3`80a@l204X?0P0Y3`@0g`l20?l?:@l00;D?

0P353`80BPl202L?103Q3`80o`lY3`00]0l20<L?0P183`809Pl50>4?0P3o

3bX?002d3`80a`l204P?0P0U3`@0h`l20?l?:Pl00;@?0P373`80A`l202@?

103U3`80o`lZ3`00/`l20<T?0P163`808Pl50>D?0P3o3b/?002c3`80b@l2

04D?0P0R3`@0i`l20?l?:`l00;8?0P3:3`80A@l2020?103X3`80o`l/3`00

/Pl20</?0P133`807`l50>T?0P3o3b`?002b3`80b`l2048?0P0O3`@0jPl2

0?l?;@l00;4?0P3=3`80@@l201d?103/3`80o`l]3`00/@l20<d?0`0o3`80

70l50>d?0P3o3bd?002`3`80c`l203l?0P0J3`D0kPl20?l?;Pl00;0?0P3@

3`80?@l201T?1@3`3`80o`l^3`00[`l20=4?0P0m3`805`l50?4?0P3o3bl?

002_3`80dPl203/?0P0F3`D0l`l20?l?;`l00:l?0P3B3`80>`l201<?1P3d

3`80o`l`3`00[Pl20=@?0P0i3`804Pl60?H?0P3o3c0?002^3`80e0l203T?

0P0@3`L0m`l20?l?<0l00:d?0P3F3`<0=Pl200d?1`3j3`80o`la3`00[@l2

0=L?0`0e3`802`l70?`?0P3o3c4?002]3`80e`l5038?0P083`L0o`l20?l?

<Pl00:`?0P3J3`D0<0l200D?1`3o3`<?0P3o3c8?002/3`80f`l702`?0P04

3`H0o`l63`80o`lb3`00Z`l20=d?200Z3`8000<?0000103o3`P?0P3o3c<?

002[3`80gPl902L?203o3`X?0P3o3c<?002Z3`80h0l400033`0000<08`l7

0?l?30l20?l?=0l00:X?0P3R3`<00Pl601d?1`3o3`l?0P3o3c@?002Z3`80

h`l300<?1`0F3`P0o`lA3`80o`le3`00Z@l20>D?0`053`P03Pl90?l?50l2

0?l?=@l00:T?0P3V3`<01`lH0?l?60l20?l?=@l00:P?0P3X3`<02Pl@0?l?

6`l20?l?=Pl00:P?0P3Y3`<040l00`0?3`3o3b4?0P3o3cH?002X3`80jPl3

0?l?<Pl20?l?=`l00:L?0P3/3`<0o`la3`80o`lg3`00Y`l20>d?0`3o3bl?

0P3o3cP?002V3`80k`l30?l?;Pl20?l?>0l00:H?0P3`3`<0o`l]3`80o`lh

3`00Y@l20?8?0`3o3b/?0P3o3cT?002U3`80l`l30?l?:Pl20?l?>@l00:D?

0P3d3`<0o`lX3`80o`lj3`00Y0l20?H?0`3o3bL?0P3o3cX?002T3`80m`l3

0?l?9Pl20?l?>Pl00:<?0P3i3`<0o`lT3`80o`lk3`00X`l20?X?0`3o3b<?

0P3o3c/?002S3`80n`l30?l?8@l20?l??0l00:8?0P3m3`<0o`lP3`80o`ll

3`00XPl20?h?0`3o3ah?0P3o3cd?002Q3`80o`l13`<0o`lM3`80o`lm3`00

X@l20?l?0Pl20?l?7@l20?l??@l00:0?0P3o3`@?0P3o3a/?0P3o3ch?002P

3`80o`l43`<0o`lJ3`80o`ln3`00X0l20?l?1@l30?l?60l20?l??`l009l?

0P3o3`L?0`3o3aL?0P3o3cl?002O3`80o`l83`80o`lF3`80o`m03`00WPl2

0?l?2Pl20?l?5@l20?l?@0l009h?0P3o3`X?0P3o3aD?0P3o3d0?002N3`80

o`l;3`80o`lC3`80o`m13`00W@l20?l?30l20?l?4`l20?l?@@l009d?0P3o

3``?0P3o3a8?0P3o3d8?002L3`80o`l>3`80o`lA3`80o`m23`00W0l20?l?

3Pl20?l?4@l20?l?@Pl009/?0P3o3`l?0P3o3a0?0P3o3d<?002K3`80o`l@

3`80o`l?3`80o`m33`00V`l20?l?3`l20?l?3`l20?l?A0l009X?0P3o3a0?

0P3o3`l?0P3o3d@?002J3`80o`l@3`80o`l>3`80o`m53`00V@l20?l?4@l2

0?l?3Pl20?l?A@l009T?0P3o3a0?0P3o3`l?0P3o3dD?002I3`80o`l@3`80

o`l>3`80o`m63`00V0l20?l?40l20?l?3`l20?l?APl009P?0P3o3`l?0`3o

3`h?0P3o3dL?002G3`80o`l?3`<0o`l?3`80o`m73`00U`l20?l?3`l20?l?

3`l20?l?B0l009H?0P3o3`l?0P3o3a0?0P3o3dP?002F3`80o`l>3`<0o`l@

3`80o`m83`00UPl20?l?3@l30?l?40l20?l?B@l009D?0P3o3`d?0`3o3a4?

0P3o3dT?002E3`80o`l<3`<0o`lA3`80o`m:3`00U0l20?l?30l30?l?4Pl2

0?l?BPl009@?0P3o3`/?0`3o3a<?0P3o3dX?002D3`80o`l;3`80o`lC3`80

o`m;3`00T`l20?l?o`lQ3`80o`m;3`00T`l20?l?o`lP3`80o`m<3`00TPl2

0?l?o`lQ3`80o`m<3`00TPl20?l?o`lP3`80o`m=3`00T@m@0?l?dPl20?l?

C@l0094?W@3o3hD?0P3o3dd?003Q3i/0o`lf3`80o`m>3`00o`l_3i/0j0l2

0?l?CPl00?l?O@nK09T?0P3o3dl?003o3lX?V`1<3`80o`m?3`00o`oo3aT?

VP3o3e0?003o3ol?IPm>0?l?C`l00?l?o`nb3`80o`m?3`00o`oo3ol?o`l4

3`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?

o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo

3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00

o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l4

3`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?

o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo

3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00

o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l4

3`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?

o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo

3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00

o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l4

3`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?

o`l43`00o`oo3ol?o`l43`00\

\>"], "Graphics",

  ImageSize->{759, 569.25},

  ImageMargins->{{12, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}}]

}, Open  ]],



Cell[BoxData[{

    \(By\ cutting\ the\ surface\ defined\ by\ \((3.1)\)\ with\ planes\ 

      perpendicular\ to\ the\ \), 

    \(\((c, d)\) - plane, \ 

    we\ obtain\ curves\ which\ have\ the\ same\ characteristics\ as\), 

    \(th\ above\ bifurcation\ diagrams\ for\ thebuckling\ problem.\ \nWe\ do\ 

      this\ by\ letting\), 

    \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \

\ \ \ \ \ \ \ 

    d\  = \ m\ c\  + \ 

        \(1\/2\)\ .\nThis\ is\ a\ plane\ in\ \((x, c, d)\)\ space.\ We\ fix\ m

          \ \((the\ slope\ in\ the\ \((c, d)\) - plane)\)\ \), 

    \(and\ vary\ c\ which\ is\ analogous\ to\ fixing\ "\<k\>"\ and\ varying\ 

      "\<a\>"\ \ as\ was\ done\), 

    \(for\ the\ buckling\ problem.\ We\ do\ this\ with\ the\ following\ 

      \(commands.\)\ \t\t\t\)}], "Input",

  FontFamily->"Times New Roman",

  FontSize->16],



Cell["\<\



<<Graphics`ImplicitPlot`\

\>", "Input",

  PageWidth->Infinity,

  ShowSpecialCharacters->False,

  FormatType->InputForm],



Cell["\<\





cusp[c1_,m_] :=  Plot[{3/4^(1/3) (Abs[c])^(2/3),m c + .5},{c,-c1,c1},

               AspectRatio->Automatic, AxesLabel->{\"C\",\"d\"}, 

               PlotRange->{-1,3/4^(1/3) (c1)^(2/3)},

               PlotStyle->{{Hue[.6]},{Hue[1]}},DisplayFunction->Identity,

         PlotLabel->StringForm[\"d=``,           d=``\",3 (C/2)^(2/3), m \

C+.5]] 



cubic[c1_,m_]:=

                    ImplicitPlot[c+(m c +.5) x-x^3==0,{c,-c1,c1},

                      AspectRatio->Automatic, AxesLabel->{C,X},

                      PlotStyle->Hue[1],DisplayFunction->Identity,

    PlotLabel->StringForm[\"                               0=``\",C+(m \

C+.5)X-X^3]]\

\>", "Input",

  PageWidth->Infinity,

  ShowSpecialCharacters->False,

  FormatType->InputForm],



Cell[BoxData[

    \(\(\ncubicbifurcation[c1_, mmin_, mmax_, dm_] := \n

      Table[Show[GraphicsArray[{cusp[c1, m], cubic[c1, m]}]], {m, mmin, mmax, 

          dm}]\)\)], "Input"],



Cell[BoxData[

    \(\(\nUsing\ these\ commands\ we\ get\ the\ following\ \(diagrams.\)\)\)],

   "Input",

  FontFamily->"Times New Roman",

  FontSize->16],



Cell[CellGroupData[{



Cell[BoxData[

    \(cubicbifurcation[2, 1.65, 1.32, \(-.005\)]\)], "Input"],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -82 0 ]

[.5 .96488 82 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -143 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.65) show

217.250000 19.500000 moveto

(C) show

222.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.28355 0 m

.30316 .03235 L

.34309 .09823 L

.3815 .16162 L

.42237 .22905 L

.46172 .29398 L

.49955 .3564 L

.53984 .42288 L

.57861 .48685 L

.61984 .55487 L

.65954 .62039 L

.69774 .68341 L

.73838 .75047 L

.77751 .81504 L

.81909 .88365 L

.85916 .94976 L

s

.85916 .94976 m

.86075 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.402397 0.238095 [

[.02381 .3899 -6 -9 ]

[.02381 .3899 6 0 ]

[.2619 .3899 -6 -9 ]

[.2619 .3899 6 0 ]

[.7381 .3899 -3 -9 ]

[.7381 .3899 3 0 ]

[.97619 .3899 -3 -9 ]

[.97619 .3899 3 0 ]

[1.025 .4024 0 -8 ]

[1.025 .4024 9 8 ]

[.4875 .04525 -24 -4.5 ]

[.4875 .04525 0 4.5 ]

[.4875 .1643 -12 -4.5 ]

[.4875 .1643 0 4.5 ]

[.4875 .28335 -24 -4.5 ]

[.4875 .28335 0 4.5 ]

[.4875 .52144 -18 -4.5 ]

[.4875 .52144 0 4.5 ]

[.4875 .64049 -6 -4.5 ]

[.4875 .64049 0 4.5 ]

[.4875 .75954 -18 -4.5 ]

[.4875 .75954 0 4.5 ]

[.4875 .87859 -6 -4.5 ]

[.4875 .87859 0 4.5 ]

[.5 .96713 -4.5 0 ]

[.5 .96713 4.5 16 ]

[.5 .95463 -134.5 0 ]

[.5 .95463 134.5 16 ]

[ 0 0 0 0 ]

[ 1 .94213 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .4024 m

.02381 .40865 L

s

[(-2)] .02381 .3899 0 1 Mshowa

.2619 .4024 m

.2619 .40865 L

s

[(-1)] .2619 .3899 0 1 Mshowa

.7381 .4024 m

.7381 .40865 L

s

[(1)] .7381 .3899 0 1 Mshowa

.97619 .4024 m

.97619 .40865 L

s

[(2)] .97619 .3899 0 1 Mshowa

.125 Mabswid

.07143 .4024 m

.07143 .40615 L

s

.11905 .4024 m

.11905 .40615 L

s

.16667 .4024 m

.16667 .40615 L

s

.21429 .4024 m

.21429 .40615 L

s

.30952 .4024 m

.30952 .40615 L

s

.35714 .4024 m

.35714 .40615 L

s

.40476 .4024 m

.40476 .40615 L

s

.45238 .4024 m

.45238 .40615 L

s

.54762 .4024 m

.54762 .40615 L

s

.59524 .4024 m

.59524 .40615 L

s

.64286 .4024 m

.64286 .40615 L

s

.69048 .4024 m

.69048 .40615 L

s

.78571 .4024 m

.78571 .40615 L

s

.83333 .4024 m

.83333 .40615 L

s

.88095 .4024 m

.88095 .40615 L

s

.92857 .4024 m

.92857 .40615 L

s

.25 Mabswid

0 .4024 m

1 .4024 L

s

gsave

1.025 .4024 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .04525 m

.50625 .04525 L

s

[(-1.5)] .4875 .04525 1 0 Mshowa

.5 .1643 m

.50625 .1643 L

s

[(-1)] .4875 .1643 1 0 Mshowa

.5 .28335 m

.50625 .28335 L

s

[(-0.5)] .4875 .28335 1 0 Mshowa

.5 .52144 m

.50625 .52144 L

s

[(0.5)] .4875 .52144 1 0 Mshowa

.5 .64049 m

.50625 .64049 L

s

[(1)] .4875 .64049 1 0 Mshowa

.5 .75954 m

.50625 .75954 L

s

[(1.5)] .4875 .75954 1 0 Mshowa

.5 .87859 m

.50625 .87859 L

s

[(2)] .4875 .87859 1 0 Mshowa

.125 Mabswid

.5 .06906 m

.50375 .06906 L

s

.5 .09287 m

.50375 .09287 L

s

.5 .11668 m

.50375 .11668 L

s

.5 .14049 m

.50375 .14049 L

s

.5 .18811 m

.50375 .18811 L

s

.5 .21192 m

.50375 .21192 L

s

.5 .23573 m

.50375 .23573 L

s

.5 .25954 m

.50375 .25954 L

s

.5 .30716 m

.50375 .30716 L

s

.5 .33097 m

.50375 .33097 L

s

.5 .35478 m

.50375 .35478 L

s

.5 .37859 m

.50375 .37859 L

s

.5 .42621 m

.50375 .42621 L

s

.5 .45002 m

.50375 .45002 L

s

.5 .47383 m

.50375 .47383 L

s

.5 .49764 m

.50375 .49764 L

s

.5 .54525 m

.50375 .54525 L

s

.5 .56906 m

.50375 .56906 L

s

.5 .59287 m

.50375 .59287 L

s

.5 .61668 m

.50375 .61668 L

s

.5 .6643 m

.50375 .6643 L

s

.5 .68811 m

.50375 .68811 L

s

.5 .71192 m

.50375 .71192 L

s

.5 .73573 m

.50375 .73573 L

s

.5 .78335 m

.50375 .78335 L

s

.5 .80716 m

.50375 .80716 L

s

.5 .83097 m

.50375 .83097 L

s

.5 .85478 m

.50375 .85478 L

s

.5 .02144 m

.50375 .02144 L

s

.5 .9024 m

.50375 .9024 L

s

.5 .92621 m

.50375 .92621 L

s

.25 Mabswid

.5 0 m

.5 .94213 L

s

gsave

.5 .96713 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .95463 -195.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.65) show

293.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

298.000000 15.000000 moveto

(L) show

305.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

312.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

319.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

324.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

328.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .94213 L

0 .94213 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .25324 m

.02576 .25322 L

.03158 .25317 L

.04117 .25309 L

.05437 .25296 L

.07095 .2528 L

.09063 .2526 L

.11306 .25234 L

.13787 .25203 L

.16463 .25166 L

.19289 .25122 L

.22216 .25069 L

.25193 .25006 L

.28171 .24933 L

.31098 .24846 L

.33923 .24746 L

.366 .2463 L

.39081 .245 L

.41324 .24357 L

.43292 .24206 L

.44949 .24055 L

.46269 .23917 L

.47228 .23803 L

.47811 .23729 L

.48006 .23703 L

s

.48006 .23703 m

.48218 .23674 L

.48851 .23584 L

.49894 .23421 L

.51329 .23165 L

.53132 .22782 L

.55271 .2222 L

.57711 .21423 L

.60409 .20346 L

.63319 .18997 L

.66392 .17439 L

.69574 .15764 L

.72812 .14051 L

.7605 .12363 L

.79233 .10743 L

.82305 .09221 L

.85216 .07818 L

.87914 .06551 L

.90353 .05433 L

.92493 .04472 L

.94296 .03677 L

.95731 .03053 L

.96774 .02604 L

.97407 .02334 L

.97619 .02243 L

s

.48006 .48502 m

.48218 .45762 L

.48851 .43068 L

.49894 .40455 L

.51329 .3796 L

.53132 .35631 L

.55271 .33533 L

.57711 .31736 L

.60409 .30298 L

.63319 .29222 L

.66392 .28455 L

.69574 .27919 L

.72812 .27541 L

.7605 .2727 L

.79233 .27072 L

.82305 .26923 L

.85216 .26811 L

.87914 .26724 L

.90353 .26658 L

.92493 .26607 L

.94296 .26568 L

.95731 .2654 L

.96774 .26521 L

.97407 .2651 L

.97619 .26506 L

s

.48006 .48514 m

.48218 .51283 L

.48851 .54067 L

.49894 .56843 L

.51329 .59594 L

.53132 .62307 L

.55271 .64966 L

.57711 .6756 L

.60409 .70075 L

.63319 .725 L

.66392 .74824 L

.69574 .77037 L

.72812 .79127 L

.7605 .81086 L

.79233 .82905 L

.82305 .84575 L

.85216 .86091 L

.87914 .87444 L

.90353 .88629 L

.92493 .8964 L

.94296 .90474 L

.95731 .91127 L

.96774 .91594 L

.97407 .91876 L

.97619 .9197 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->1,

  AnimationCycleRepetitions->Infinity,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l00003<006H009T00<`00?l0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV

09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<003o03?o06Ko09Wo0<co

0?oo0000<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I

<c>I<fJI<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0

IYT0I/`0I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bI

I_nIIP3<IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0c

VC<cVFHcVITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<

VIW<VLc<VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`c

c?lcc01Vc3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03o

c3?oc6Koc9Woc<coc?ooc000oc<0ofH0oiT0ol`0ool0o`0coc<cofHcoiTcol`coolco`1Voc=VofIV

oiUVolaVoomVo`2Ioc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<o`3ooc?oofKooiWoolco

ooooo`0000410@820P<30`@410D51@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C

4a@D5?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooooQaN400?oQaN400?oQaN400?oQaN400?oQ

aN400?oQD^400`3Qh@1`h@00on5Bh@030>7Q073Q001Th@D0j>400`3Qh@1`h@00I^400`3Qh@3Xh@03

0>7Q073Q0016h@033n7Q01OQ0`03h@030>7Q00;Q0P3Th@80E>433a[Q0016h@033n7Q01gQ00<0hN40

0^400`3Qh@3Sh@030>7Q057Q0PlMh@00An400`oQh@0Lh@030>7Q00;Q00<0hN40d^4500;Q00<0hN40

0^400`3Qh@02h@030>7Q04oQ0PlOh@00An400`oQh@0Kh@801>400`3Qh@3Dh@030>7Q00KQ00<0h@00

0n400`3Qh@1=h@8?8N4004SQ00<?hN408>420<oQ0`03h@030>7Q00SQ00@0hN7Q0P1<h@8?8n4004SQ

00<?hN408>400`3Qh@3Dh@030>7Q00KQ0P04h@030>7Q04WQ0PlUh@00BN400`oQh@0Oh@030>7Q0=CQ

00<0hN401^400`3Qh@03h@030>7Q04OQ0PlWh@00B^400`oQh@0Nh@030>7Q0=?Q0P08h@<00n400`3Q

h@15h@8?:N4004[Q00<?hN407^420>CQ0P13h@<?:n4004_Q00<?hN407N400`3Qh@3Sh@030>7Q043Q

0Pl^h@00C>400`oQh@0Lh@030>7Q0>?Q00<0hN40?^423c3Q001<h@033n7Q01cQ00<0hN40hn400`3Q

h@0lh@8?<^4004gQ00<?hN406n420>CQ00<0hN40>^423cCQ001=h@033n7Q01_Q00<0hN40hn4203WQ

0Plfh@00C^400`oQh@0Jh@030>7Q0>?Q00<0hN40=N433cSQ001?h@033n7Q01WQ00<0hN40hn400`3Q

h@0ch@8?>n4004oQ00<?hN406N420>CQ00<0hN40<N423cgQ001@h@033n7Q01SQ00<0hN40hn42033Q

0Ploh@00DN400`oQh@08h@030>7Q00;Q00<0hN400^400`3Qh@02h@030>7Q0>?Q00<0hN40;N423d7Q

001Ah@033n7Q00OQ00<0h@001n400`3Q0003h@030>7Q0>?Q00<0hN40:n423d?Q001Bh@043n7Qh@<0

0^400`3Q0009h@040>7Qh@80i>400`3Qh@0Yh@8?AN4005?Q00<?hN401N400`3Q0007h@801>400`3Q

h@3Sh@80:>423dOQ001Ch@033n7Q00GQ00<0h@001n400`3Qh@03h@030>7Q0>?Q00<0hN409N423dWQ

001Dh@033n7Q00GQ00<0hN401^4300?Q00<0hN40hn400`3Qh@0Th@033n7Q04WQ001Dh@033n7Q01CQ

00<0hN40g>4500;Q00<0hN408^423dcQ001Eh@033n7Q01?Q0P3Oh@030>7Q00;Q00<0hN408N400`oQ

h@1<h@00E^400`oQh@0Bh@030>7Q0=SQ0`03h@030>7Q00;Q0P0Ph@8?Cn4005KQ00<?hN404^400`3Q

h@3Nh@030>7Q00;Q00<0hN407N423e7Q001Gh@033n7Q017Q00<0hN40g^400`3Qh@02h@030>7Q01_Q

0PmCh@00F>400`oQh@0@h@80g^4200CQ00<0hN406N423eGQ001Hh@033n7Q013Q00<0hN40hn4201SQ

0PmGh@006^4302GQ1@0Bh@033n7Q00oQ00<0hN409>4502CQ0`2Ch@030>7Q01GQ0PmIh@006^400`3Q

h@0Wh@030>7Q01?Q00<?hN403^400`3Qh@0Vh@030>7Q02CQ00<0hN40Tn400`3Qh@0Bh@<?Fn4001GQ

0`03h@030>7Q023Q0`03h@030>7Q01?Q00<?hN403^4202OQ00<0hN409N400`3Qh@2Bh@030>7Q00oQ

0`mNh@006n400`3Qh@0Vh@030>7Q01CQ00<?hN403N400`3Qh@0Vh@030>7Q02GQ00<0hN40T^400`3Q

h@0=h@8?HN4001[Q00<0h@009n400`3Qh@0Dh@033n7Q00gQ00<0hN409^400`3Qh@0Th@030>4009?Q

0P0;h@<?Hn4001_Q00<0hN409N4201OQ00<?hN403>400`3Qh@0Uh@809n400`3Qh@2Bh@030>7Q00OQ

0`mVh@00GN400`oQh@0;h@80i>400`3Qh@05h@8?JN4005gQ00<?hN402n400`3Qh@3Sh@030>4?00D?

Jn4005kQ00<?hN402^400`3Qh@1Kh@80PN473g7Q001Oh@033n7Q00WQ00<0hN40F^400`3Qh@1eh@`?

1N400`3Qh@1`h@005N5:00033`0006001^400`3Qh@1LhAT?4N400`3Qh@1`h@006N400`3Qh@06h@03

0>7Q00GQ00<0hN401N400`3Qh@05h@030>7Q00GQ00<0hN401N400`3Qh@06h@030>7Q00GQ00<0hN40

0^4010oQh@07h@03_^7Q00GQ00<0hN401^400`3Qh@05h@030>7Q00GQ00<0hN401N400`3Qh@05h@03

0>7Q00GQ00<0hN401^400`3Qh@05h@030>7Q00GQ00<0hN402>400`3Qh@0^hBh?:^400`3Qh@1`h@00

H>400`oQh@08h@03_^7Q05[Q00<0h@00Q^42077Q001Qh@033n7Q00OQ0[iKh@<0Q^400`3Qh@1>h@P?

6^40067Q00<?hN401n42_^CQ00<0hN40<N4M3b;Q001Rh@033n7Q00GQ00>n0;h0eN400`3Qh@02h@03

0>7Q00;Q00<0hN400^400`3Qh@0Uh@`??n4006?Q00<?hN401>400kh0_P3Dh@030>4000OQ00<0h@00

0n400`3Qh@0Oh@H?Bn4006?Q00<?hN401>400kh0_P3?h@<00^400`3Q0009h@040>7Qh@806^463e7Q

001Th@033n7Q00;Q00Fnh@00_P3Ch@030>4000OQ0P04h@030>7Q01GQ10mGh@00I>400`oQh@02h@05

_^40hKh0dn400`3Q0007h@030>7Q00?Q00<0hN404^433e_Q001Uh@093n7QhKkQ0>6n0=CQ00<0hN40

1^4300?Q00<0hN404>423ekQ001Vh@063n7Q_^400^400kkQh@3Ph@803n423f3Q001Vh@053n7Q_^40

0P000n6nh@3Qh@030>7Q00cQ0PmRh@00In401@oQ_^4000;Q00>nhN40h>400`3Qh@0;h@033n7Q06;Q

001Wh@053kkQh@000n400kkQh@3Oh@030>7Q00[Q00<?hN40Hn4006SQ00@?hN400n400kkQh@3Oh@03

0>7Q00SQ0PmVh@00J>400kh?h@0200;Q00>nhN40gn4200SQ00<?hN40I^4006OQ00Fnh@oQ0004h@03

_^7Q0=kQ00<0hN401^400`oQh@1Wh@00G>400`3Qh@02h@030>7Q00;Q00H0_^7Q3`04h@03_^7Q08OQ

0`0Xh@D09n400`3Qh@05h@033n7Q01kQ1@0Xh@<06^4005_Q00<0h@001n400`2n0002h@033`3Q00?Q

00>nhN40Qn400`3Qh@0Zh@030>7Q02OQ00<0hN401>400`oQh@0Qh@030>7Q02SQ00<0hN406^4005_Q

00<0h@002>400kh0h@02h@033`3Q00?Q00>nhN40PN4300?Q00<0hN408n4300?Q00<0hN409n4200CQ

00<?hN408^400`3Qh@0Yh@030>7Q01WQ001Kh@030>4000OQ00<0_^400n400`0?h@03h@03_^7Q08OQ

00<0hN40:N400`3Qh@0Wh@030>7Q00;Q00<?hN408n400`3Qh@0Yh@030>7Q01WQ001Kh@030>4000OQ

00>nhN400n400`0?h@04h@03_^7Q08GQ00<0h@00:^400`3Qh@0Wh@050>7Qh@l09^400`3Qh@0Xh@03

0>4001[Q001Lh@030>7Q00KQ00>n00000n400`3Q3`04h@03_^7Q08KQ00<0hN40:>4202WQ00D0hN7Q

3`0Uh@80:n400`3Qh@0Ih@00I>400kkQh@04h@8000<?hN400^400kkQh@3Lh@8000?Q3n40K^4006CQ

00>nhN401>40103Qh@l4h@03_^7Q0=_Q00<0h@l0L>4006?Q00>nhN401N40103Qh@l4h@03_^7Q0=_Q

00<0h@l0L>4006?Q00>nhN401N401@3QhN4?00CQ00>nhN40f^400`0?h@1Rh@803>4006;Q00>nhN40

1^400`3Qh@02h@053n7QhKh0g>400`0?h@1Qh@030>7Q00cQ001Rh@03_^7Q00KQ0P03h@033n7Q00;Q

00>nhN40ON5L00033`0005X01n400`3Qh@0<h@00HN400kkQh@07h@030>7Q00?Q00D?hN7Q_P23h@03

0>7Q02WQ00<0hN40:N400`oQh@0Yh@030>7Q02WQ00<0hN402N400`3Qh@0<h@00HN400kkQh@07h@03

0>7Q00?Q00D?hN7Q_P3Jh@033`3Q06;Q00<0h@003>40063Q00>nhN402>400`3Qh@04h@053n7QhKh0

fN400`l0h@1Rh@<03>40063Q00>nhN402>4200KQ00@?hN6nf>4010oQ001ah@00Gn400kkQh@09h@03

0>7Q00GQ00D?hN7Q_P3Gh@033n4007;Q001Oh@03_^7Q00WQ00<0hN401^4010oQhKkGh@033n4007;Q

001Nh@03_^7Q00[Q00<0hN401n4010oQhKkFh@033n4007;Q001Nh@03_^7Q00[Q0P08h@043n7Q_]GQ

00<?hN400P1ah@00GN400kkQh@0;h@030>7Q00SQ00@?hN6ne>4010oQh@1bh@00GN400kkQh@04h@D0

0^400`3Qh@08h@043n7Q_]CQ00@?hN40L^4005cQ00>nhN401n400`3Qh@02h@030>7Q00WQ00@?hN6n

dn4010oQh@1bh@00Fn400kkQh@08h@030>7Q00;Q0P0;h@043n7Q_];Q00@?hN40L^4005_Q00>nhN40

2>400`3Qh@02h@030>7Q00[Q00@?hN6ndN4010oQhN42077Q001Jh@03_^7Q00WQ00<0hN400^400`3Q

h@0;h@043n7Q_]3Q00D?hN7Q001bh@00F^400kkQh@08h@801>400`3Qh@0<h@043n7Q_/oQ00D?hN7Q

001bh@00FN400kkQh@0?h@803N4010oQhKk?h@053n7Qh@00L^4005SQ00>nhN404>400`3Qh@0=h@04

3n7Q_/kQ00@?hN7Q0P1ah@00F>400kkQh@0@h@030>7Q00kQ00@?hN6nc^4010oQh@1bh@00En400kkQ

h@0Ah@030>7Q00kQ00@?hN6nc^4010oQh@1bh@00E^400kkQh@0Bh@804>4010oQhKk1h@030>7Q00;Q

00<0hN400^400`3Q3`02h@030>7Q073Q001Fh@03_^7Q01;Q00<0hN403n401@oQhN6n0;oQ00<0h@00

1n40103Q00l2h@030>7Q073Q001Eh@03_^7Q01?Q00<0hN404>4010oQhKjoh@030>4000WQ00@03n7Q

0P1ah@00E>400kkQh@0Dh@030>7Q017Q00@?hN6n_^400`3Q0007h@800^400`oQ001bh@00Dn400kkQ

h@0Eh@804^4010oQhKjnh@030>4000OQ00L0hN7Q3n4007;Q001Ch@03_^7Q01GQ00<0hN404^4010oQ

hKjnh@030>7Q00KQ0`001>4?h@1bh@00D^400kkQh@0Fh@030>7Q01?Q00@?hN6nb^4010oQ001ah@00

DN400kkQh@0Gh@030>7Q01?Q00@?hN6nbn400`l0h@1ah@00DN400kkQh@0Gh@805N4010oQhKk:h@03

3`3Q077Q001@h@03_^7Q01SQ00<0hN405>4010oQhKk;h@033n7Q073Q001?h@03_^7Q00SQ1@02h@03

0>7Q00;Q00<0hN400^400`3Qh@0Eh@043n7Q_/[Q00<?0>40L>4004oQ00>nhN402^400`3Qh@06h@03

0>4000?Q00<0hN405N401@oQhN6n0<WQ00<03n40L>4004kQ00>nhN402n400`3Qh@08h@040>7Qh@80

5n401@oQhN6n0<SQ00<03n40L>4004gQ00>nhN403>400`3Qh@06h@801>400`3Qh@0Gh@043n7Q_/SQ

00<0h@l0L>4004cQ00>nhN403N400`3Qh@06h@030>7Q00?Q00<0hN405n401@oQhN6n0<OQ00<0h@l0

L>4004cQ00>nhN403>4200SQ0`03h@030>7Q01SQ00D?hN7Q_P36h@8000?Q3n40K^4004_Q00>nhN40

7N4201WQ00<?hN400^400kkQh@33h@050>7Qh@l0K^4004[Q00>nhN407^400`3Qh@0Ih@053n7QhKh0

aN401@3QhN4?06kQ001:h@03_^7Q01kQ00<0hN406^401@oQhN6n0<CQ00<0hN400^400`oQh@1[h@00

BN400kkQh@0Oh@030>7Q01[Q00<?hN400^400kkQh@31h@800n400`oQh@1[h@00B>400kkQh@0Ph@80

7>400`oQh@02h@03_^7Q0<3Q00<0hN400n400`oQh@1Zh@00An400kkQh@0Qh@030>7Q01_Q00<?hN40

0n400kkQh@2oh@030>7Q00CQ00<?hN40JN4004OQ00>nhN408N400`3Qh@0Lh@033n7Q00;Q00>nhN40

^>4500;Q00<0hN401N400`oQh@1Xh@00A^400kkQh@0Rh@030>7Q01gQ00<?hN400^400kkQh@2ih@03

0>7Q00;Q00<0hN401N400`oQh@1Xh@00AN400kkQh@0Sh@807^400`oQh@03h@03_^7Q0;SQ00<0hN40

0^4200OQ00<?hN40In4004CQ00>nhN409>400`3Qh@0Nh@033n7Q00?Q00>nhN40]n400`3Qh@02h@03

0>7Q00OQ00<?hN40I^4004CQ00>nhN409>400`3Qh@0Nh@033n7Q00?Q00>nhN40]n400`3Qh@02h@03

0>7Q00SQ00<?hN40IN4004?Q00>nhN409N400`3Qh@0Oh@033n7Q00?Q00>nhN40]N4200CQ00<0hN40

2N400`oQh@1Th@00@^400kkQh@0Vh@030>7Q023Q00<?hN400n400kkQh@2jh@802^400`oQh@1Th@00

@N400kkQh@0Wh@808N400`oQh@04h@03_^7Q0;WQ00<0hN402^400`oQh@1Sh@00@>400kkQh@0Xh@03

0>7Q027Q00<?hN401>400kkQh@2hh@030>7Q00_Q00<?hN40H^40043Q00>nhN408^4300?Q00<0hN40

8N400`oQh@05h@03_^7Q0;OQ00<0hN403>400`oQh@1Qh@00?n400kkQh@0Sh@030>7Q00?Q00<0hN40

8^400`oQh@04h@03_^7Q0;OQ0P0>h@033n7Q063Q000nh@03_^7Q02GQ00<0hN400^4202?Q00<?hN40

1N400kkQh@2fh@030>7Q00kQ00<?hN40Gn4003gQ00>nhN409^400`3Qh@02h@030>7Q02?Q00<?hN40

1N400kkQh@2eh@030>7Q00oQ00<?hN40G^4003gQ00>nhN409N400`3Q0003h@030>7Q02CQ00<?hN40

1N400kkQh@2dh@030>7Q013Q00<?hN40GN4003cQ00>nhN409n400`3Qh@02h@030>7Q02CQ00<?hN40

1^400kkQh@2ch@030>7Q017Q0PmMh@00>n400kkQh@0]h@809^400`oQh@06h@03_^7Q0;;Q0P0Dh@03

3n7Q05[Q000jh@03_^7Q02kQ00<0hN409N400`oQh@06h@03_^7Q0;;Q00<0hN405>423e[Q000jh@03

_^7Q02kQ00<0hN409^400`oQh@06h@03_^7Q0;7Q00<0hN405^400`oQh@1Gh@00>N400kkQh@0_h@03

0>7Q02OQ00<?hN401^400kkQh@2`h@030>7Q01OQ00<?hN40E^4003SQ00>nhN40<>4202SQ00<?hN40

1n400kkQh@2_h@806N423eKQ000gh@03_^7Q037Q00<0hN40:>400`oQh@06h@03_^7Q0:oQ00<0hN40

6^400`oQh@1Ch@00=n400kkQh@0ah@030>7Q02WQ00<?hN401^400kkQh@2Mh@D00^400`3Qh@02h@03

0>7Q00;Q00<0hN406n400`oQh@1Bh@00=^400kkQh@0bh@030>7Q02WQ00<?hN401n400kkQh@2Nh@03

0>7Q00KQ00<0h@000n400`3Qh@0Lh@8?D^4003GQ00>nhN40<n4202_Q00<?hN401n400kkQh@2Mh@03

0>7Q00SQ00@0hN7Q0P0Oh@033n7Q04oQ000dh@03_^7Q03CQ00<0hN40:^400`oQh@08h@03_^7Q09cQ

00<0hN401^4200CQ00<0hN407n423doQ000ch@03_^7Q03GQ00<0hN40:n400`oQh@08h@03_^7Q09_Q

00<0hN401^400`3Qh@03h@030>7Q027Q00<?hN40C>4003;Q00>nhN40=^400`3Qh@0/h@033n7Q00OQ

00>nhN40V^4200SQ0`03h@030>7Q02;Q0Pm<h@00<N400kkQh@0gh@80;N400`oQh@08h@03_^7Q0:WQ

00<0hN409>400`oQh@19h@00<>400kkQh@0hh@030>7Q02gQ00<?hN402>400kkQh@2Xh@809^423dWQ

000_h@03_^7Q02WQ0`03h@030>7Q00;Q00<0hN400^400`3Qh@0^h@033n7Q00SQ00>nhN40Yn400`3Q

h@0Wh@033n7Q04KQ000^h@03_^7Q02[Q00<0hN401n400`3Q0003h@030>7Q02kQ00<?hN402N400kkQ

h@2Vh@030>7Q02SQ0Pm6h@00;N400kkQh@0/h@030>7Q00SQ00@0hN7Q0P0`h@033n7Q00WQ00>nhN40

YN400`3Qh@0Zh@033n7Q04?Q000/h@03_^7Q02gQ00<0hN401^4200CQ00<0hN40;n400`oQh@0:h@03

_^7Q0:CQ0P0/h@8?@n4002_Q00>nhN40;N400`3Q0007h@030>7Q00?Q00<0hN40<>400`oQh@0:h@03

_^7Q0:?Q00<0hN40;N400`oQh@10h@00:^400kkQh@0_h@030>7Q00KQ0`03h@030>7Q033Q00<?hN40

2n400kkQh@2Rh@030>7Q02kQ0Pm0h@00:N400kkQh@0oh@80<^400`oQh@0;h@03_^7Q0:7Q00<0hN40

<>423ckQ000Xh@03_^7Q043Q00<0hN40<^400`oQh@0;h@03_^7Q0:3Q00<0hN40<^423ccQ000Wh@03

_^7Q047Q00<0hN40<^400`oQh@0<h@03_^7Q09oQ0P0eh@8?>^4002KQ00>nhN40@^400`3Qh@0ch@03

3n7Q00cQ00>nhN40W^400`3Qh@0fh@8?>>4002GQ00>nhN40@n4203CQ00<?hN403N400kkQh@2Mh@03

0>7Q03SQ0Plfh@009>400kkQh@14h@030>7Q03CQ00<?hN403N400kkQh@2Lh@030>7Q03[Q0Pldh@00

8n400kkQh@15h@030>7Q03GQ00<?hN403N400kkQh@2Kh@80?N423c;Q000Sh@03_^7Q04GQ00<0hN40

=N400`oQh@0>h@03_^7Q09[Q00<0hN40?^400`oQh@0_h@008^400kkQh@16h@80=n400`oQh@0>h@03

_^7Q09?Q0`03h@030>7Q03oQ0Pl_h@008N400kkQh@17h@030>7Q03OQ00<?hN403^400kkQh@2Bh@03

0>7Q00?Q00<0hN40@N423bgQ000Ph@03_^7Q04SQ00<0hN40=n400`oQh@0?h@03_^7Q09;Q00<0hN40

0^4204CQ00<?hN40:^4001oQ00>nhN40BN400`3Qh@0hh@033n7Q00oQ00>nhN40TN400`3Qh@02h@03

0>7Q04CQ0PlZh@007^400kkQh@1:h@80>N400`oQh@0@h@03_^7Q08oQ00<0h@000n400`3Qh@16h@8?

:>4001gQ00>nhN40Bn400`3Qh@0ih@033n7Q013Q00>nhN40Sn400`3Qh@02h@030>7Q04SQ0PlVh@00

7>400kkQh@1<h@030>7Q03[Q00<?hN404>400kkQh@2Ch@030>7Q04[Q0`lSh@006n400kkQh@17h@80

1>400`3Qh@0jh@033n7Q017Q00>nhN40T^4204kQ0`lPh@006^400kkQh@1:h@050>7Qh@00?N400`oQ

h@0Ah@03_^7Q097Q00<0hN40D>423akQ000Ih@03_^7Q04[Q00<0hN400^4203cQ00<?hN404N400kkQ

h@2Ah@030>7Q05;Q0PlLh@00In400`3Qh@3Wh@030>7Q05CQ0PlJh@00IN400`3Q003Yh@80LN4006KQ

00<0hN40j>400`3Qh@1`h@00;>430?oQ8n400`3Qh@1`h@00;>400`3Qh@3ohB?Q00<0hN40L>4002gQ

00<0hN401N400`3Qh@3ohHgQ000]h@040>7Qh@<000CQ0>7Q0`3ohH[Q000/h@030>4000;Q0P02h@03

0>7Q00;Q00<0hN40on68h@00;N400`3Qh@03h@040>7Q00;Q00<0hN40on69h@00<n40103Qh@03h@03

0>7Q00KQ00<0hN409N4302gQ00<0hN40on4Wh@007N430003h@0000803>4300CQ0`08h@030>7Q02CQ

00@0hN404N430003h@0000800^400`3Qh@02h@030>7Q00;Q00<0hN401N40103QhN4500;Q00@0hN7Q

0P04h@030>7Q00CQ0P3;h@030>7Q03;Q00<0hN402>4001cQ00@0hN409>400`3Qh@0Sh@040>7Q013Q

00@0hN401^400`3Q0007h@030>4000CQ1@03h@030>7Q00KQ00<0h@000^400`3Q0004h@030>7Q0<?Q

00<0hN401>400`3Qh@0Ch@030>7Q01kQ00<0hN401n4001cQ00D0hN40h@040003h@0001P0:n43013Q

00D0hN40h@040004h@3Q00WQ00<0hN401>400`3Qh@03h@030>7Q00KQ00<0h@001>400`3Qh@02h@03

0>7Q0;7Q00@0hN7Q1002h@801^400`3Qh@03h@030>7Q00;Q00<0hN400^400`3Qh@02h@030>7Q00GQ

00@0hN7Q1@02h@040>7Qh@801>400`3Qh@04h@801>40103QhN42007Q0@0100007N4304gQ00<0hN40

3n4300KQ00<0h@001n4200OQ00<0hN400n400`3Qh@06h@800n4200GQ00<0hN40/>400`3Q0007h@03

0>7Q00CQ1@03h@070>7Qh@3Q0007h@030>4000CQ1@03h@030>7Q00KQ00<0h@000^400`3Q0004h@03

0>7Q00CQ00<0hN400^400`3Q0001h@007n400`3Qh@1:h@804n400`3Qh@04h@030>4000OQ00<0hN40

3>400`3Qh@06h@030>7Q00;Q00<0hN401>400`3Q002`h@030>4000;Q10000n40h@07h@030>7Q00?Q

00L0hN7Q0>4000WQ00<0hN401>400`3Qh@03h@030>7Q00KQ00<0h@001>400`3Qh@02h@030>7Q00CQ

00<0hN400n41007Q0N4001kQ0P1Ph@801n400`3Qh@06h@<02n4200WQ0P02h@<01>4309KQ0P000n40

000Eh@030>4000OQ00<0hN401^400`3Qh@03h@070>7Qh@3Q0007h@801n400`3Qh@03h@030>7Q00KQ

0P03h@801N400`3Qh@04h@030>7Q00?Q0@01h@7Q003ohE7Q00<0h@005^400`3Q0007h@030>4000gQ

00H0hN40h@07h@030>7Q00cQ00<0hN401^400`3Qh@02h@030>7Q00CQ00<0h@000n400`3Qh@03h@03

0>40007Q000Yh@801^420?oQ7n400`3Qh@0Fh@030>7Q00KQ0`0>h@040>7Q00SQ0`0;h@802N4200;Q

0`04h@<00^400`3Qh@03h@800N410040000[h@030>7Q00;Q00<0hN40on4Oh@030>7Q073Q000Zh@03

0>7Q00?Q00<0hN401N400`3Qh@3ohAKQ00<0h@00LN4002_Q00<0hN400^400`3Qh@02h@@00n430?oQ

4N420003h@00073Q000Yh@030>4000CQ00<0h@000^420003h@3Q00CQ00<0hN40on64h@00:^400`3Q

h@03h@<01>400`3Q0003h@030>7Q0?oQQN4003OQ00<0h@001>400`3Qh@3ohHCQ000eh@<01>430?oQ

Q^400?oQaN400?oQaN400?oQaN400?oQaN400?oQaN400001\

\>"],

  ImageRangeCache->{{{39.0625, 399.625}, {242.25, 79.4375}} -> {-0.283063, 

  0.441994, 0.00467965, 0.00467965}, {{48.375, 211.188}, {238.313, 

  83.3125}} -> {-4.15766, 1.27453, 0.0256287, 0.0256287}, {{227.438, 

  390.25}, {238.313, 83.3125}} -> {-9.02533, 0.516244, 0.0233784, 0.0233784}}]

}, Open  ]]

}, Open  ]]

}, Open  ]],



Cell[CellGroupData[{



Cell[TextData[StyleBox["4  References", "Section",

  FontFamily->"Times New Roman",

  FontSize->18]], "Section",

  FontFamily->"Times New Roman",

  FontSize->18],



Cell[BoxData[{

    RowBox[{

      RowBox[{

        StyleBox[\(1.  Chow\),

          FontFamily->"Times New Roman",

          FontSize->16], 

        StyleBox[",",

          FontFamily->"Times New Roman",

          FontSize->16], 

        StyleBox[\(S . C . \),

          FontFamily->"Times New Roman",

          FontSize->16], 

        StyleBox[",",

          FontFamily->"Times New Roman",

          FontSize->16], 

        StyleBox[" ",

          FontFamily->"Times New Roman"], 

        StyleBox["Hale",

          FontFamily->"Times New Roman"], 

        StyleBox[",",

          FontFamily->"Times New Roman"], 

        StyleBox[" ",

          FontFamily->"Times New Roman"], 

        StyleBox[\(J . K . \ Chapter\ 5\),

          FontFamily->"Times New Roman"], 

        StyleBox[",",

          FontFamily->"Times New Roman"], 

        StyleBox[" ",

          FontFamily->"Times New Roman",

          FontSlant->"Italic"], 

        StyleBox[\(Methods\ of\ Bifurcation\ Theory\),

          FontFamily->"Times New Roman",

          FontSlant->"Italic"], 

        StyleBox[",",

          FontFamily->"Times New Roman",

          FontSlant->"Italic"], "\n", 

        StyleBox[

          RowBox[{"   ", 

            StyleBox[" ",

              FontFamily->"Times New Roman"]}]], 

        StyleBox[\(Springer - Verlag\),

          FontFamily->"Times New Roman"], 

        StyleBox[",",

          FontFamily->"Times New Roman"], 

        StyleBox[" ",

          FontFamily->"Times New Roman"], 

        StyleBox[\(Berlin\ and\ New\ York\),

          FontFamily->"Times New Roman"], 

        StyleBox[",",

          FontFamily->"Times New Roman"], 

        StyleBox[" ",

          FontFamily->"Times New Roman"], 

        StyleBox["1982.",

          FontFamily->"Times New Roman"]}], "\n"}], 

    StyleBox[\(2. \  Wolkowisky, J . H . , \ 

      Buckling\ of\ the\ Circular\ Plate\ Embedded\ in\ Elastic\),

      FontFamily->"Times New Roman"], 

    RowBox[{"    ", 

      RowBox[{

        StyleBox["Springs",

          FontFamily->"Times New Roman"], 

        StyleBox[",",

          FontFamily->"Times New Roman"], 

        StyleBox[" ",

          FontFamily->"Times New Roman"], 

        StyleBox[\(An\ Application\ to\ Geophysics\),

          FontFamily->"Times New Roman"], 

        StyleBox[",",

          FontFamily->"Times New Roman"], 

        StyleBox[" ",

          FontFamily->"Times New Roman"], 

        StyleBox[\(Communications\ on\ Pure\ and\),

          FontFamily->"Times New Roman",

          FontSlant->"Italic"]}], 

      StyleBox[" ",

        FontFamily->"Times New Roman",

        FontSlant->"Italic"]}], 

    RowBox[{

      StyleBox[

        StyleBox[

          RowBox[{"   ", 

            StyleBox[" ",

              FontFamily->"Times New Roman"]}]],

        FontSlant->"Italic"], 

      RowBox[{

        StyleBox[\(Applied\ Mathematics\),

          FontFamily->"Times New Roman",

          FontSlant->"Italic"], 

        StyleBox[",",

          FontFamily->"Times New Roman"], 

        StyleBox["1969",

          FontFamily->"Times New Roman"], 

        StyleBox[",",

          FontFamily->"Times New Roman"], 

        StyleBox[" ",

          FontFamily->"Times New Roman"], 

        StyleBox["22",

          FontFamily->"Times New Roman"], 

        StyleBox[",",

          FontFamily->"Times New Roman"], 

        StyleBox[" ",

          FontFamily->"Times New Roman"], 

        StyleBox[\(639 - 667. \),

          FontFamily->"Times New Roman"]}]}]}], "Input",

  FontSize->16]

}, Open  ]]

}, Open  ]]

},

FrontEndVersion->"Microsoft Windows 3.0",

ScreenRectangle->{{0, 1024}, {0, 687}},

AutoGeneratedPackage->None,

WindowSize->{715, 530},

WindowMargins->{{Automatic, 116}, {24, Automatic}},

PrintingCopies->1,

PrintingPageRange->{Automatic, Automatic}

]





(***********************************************************************

Cached data follows.  If you edit this Notebook file directly, not using

Mathematica, you must remove the line containing CacheID at the top of 

the file.  The cache data will then be recreated when you save this file 

from within Mathematica.

***********************************************************************)



(*CellTagsOutline

CellTagsIndex->{}

*)



(*CellTagsIndex

CellTagsIndex->{}

*)



(*NotebookFileOutline

Notebook[{



Cell[CellGroupData[{

Cell[1731, 51, 217, 7, 150, "Title"],

Cell[1951, 60, 204, 8, 180, "Subtitle"],



Cell[CellGroupData[{

Cell[2180, 72, 123, 5, 55, "Section"],



Cell[CellGroupData[{

Cell[2328, 81, 7063, 243, 1035, "Input"],

Cell[9394, 326, 48987, 806, 608, 48864, 802, "GraphicsData", 

"Bitmap", "Graphics"]

}, Open  ]],

Cell[58396, 1135, 685, 11, 180, "Input"]

}, Open  ]],



Cell[CellGroupData[{

Cell[59118, 1151, 132, 2, 54, "Section"],

Cell[59253, 1155, 37888, 623, 460, 37794, 620, "GraphicsData", 

"Bitmap", "Graphics"],



Cell[CellGroupData[{

Cell[97166, 1782, 86, 1, 50, "Subsection"],

Cell[97255, 1785, 4205, 142, 552, "Input"]

}, Open  ]],



Cell[CellGroupData[{

Cell[101497, 1932, 85, 1, 50, "Subsection"],

Cell[101585, 1935, 1257, 37, 327, "Input"],

Cell[102845, 1974, 1759, 49, 58, "Input"],

Cell[104607, 2025, 2153, 59, 80, "Input"],

Cell[106763, 2086, 344, 14, 33, "Input"],

Cell[107110, 2102, 1062, 27, 94, "Input"],

Cell[108175, 2131, 594, 26, 54, "Input"],

Cell[108772, 2159, 910, 31, 55, "Input"],

Cell[109685, 2192, 1610, 67, 96, "Input"],

Cell[111298, 2261, 914, 20, 320, "Input"],

Cell[112215, 2283, 359, 14, 75, "Input"],

Cell[112577, 2299, 78, 2, 30, "Input"],

Cell[112658, 2303, 331, 9, 51, "Input"],

Cell[112992, 2314, 699, 24, 159, "Input"],

Cell[113694, 2340, 227, 7, 30, "Input"],



Cell[CellGroupData[{

Cell[113946, 2351, 85, 2, 33, "Input"],

Cell[114034, 2355, 102, 3, 31, "Output"]

}, Open  ]],

Cell[114151, 2361, 351, 14, 96, "Input"],

Cell[114505, 2377, 305, 6, 90, "Input"],

Cell[114813, 2385, 482, 19, 75, "Input"],



Cell[CellGroupData[{

Cell[115320, 2408, 80, 2, 30, "Input"],

Cell[115403, 2412, 27285, 1037, 380, 14443, 873, "GraphicsData", 

"PostScript", "Graphics"]

}, Open  ]]

}, Open  ]],



Cell[CellGroupData[{

Cell[142737, 3455, 119, 2, 50, "Subsection"],

Cell[142859, 3459, 16474, 488, 756, "Input"],

Cell[159336, 3949, 2272, 49, 190, "Input"],

Cell[161611, 4000, 225, 8, 96, "Input"],

Cell[161839, 4010, 101, 2, 30, "Input"],

Cell[161943, 4014, 2102, 47, 150, "Input"],

Cell[164048, 4063, 180, 4, 70, "Input"],

Cell[164231, 4069, 200, 5, 54, "Input"],

Cell[164434, 4076, 1084, 28, 408, "Input",

  InitializationCell->True],

Cell[165521, 4106, 294, 8, 117, "Input"],

Cell[165818, 4116, 323, 10, 102, "Input",

  InitializationCell->True],

Cell[166144, 4128, 125, 7, 96, "Input"],

Cell[166272, 4137, 542, 12, 56, "Input"],

Cell[166817, 4151, 301, 8, 56, "Input"],

Cell[167121, 4161, 72, 1, 50, "Input"],

Cell[167196, 4164, 131, 2, 50, "Input"],

Cell[167330, 4168, 682, 16, 156, "Input",

  InitializationCell->True],

Cell[168015, 4186, 260, 8, 30, "Input",

  InitializationCell->True],

Cell[168278, 4196, 502, 19, 56, "Input"],

Cell[168783, 4217, 2371, 51, 210, "Input"]

}, Open  ]],



Cell[CellGroupData[{

Cell[171191, 4273, 59, 1, 50, "Subsection"],

Cell[171253, 4276, 360, 9, 76, "Input"],



Cell[CellGroupData[{

Cell[171638, 4289, 1168, 26, 130, "Input"],



Cell[CellGroupData[{

Cell[172831, 4319, 40080, 1691, 359, 23877, 1486, "GraphicsData", 

"PostScript", "Graphics"],

Cell[212914, 6012, 39067, 1597, 359, 22142, 1383, "GraphicsData", 

"PostScript", "Graphics"],

Cell[251984, 7611, 44958, 1825, 359, 25167, 1576, "GraphicsData", 

"PostScript", "Graphics"],

Cell[296945, 9438, 39566, 1510, 359, 20286, 1267, "GraphicsData", 

"PostScript", "Graphics"],

Cell[336514, 10950, 55772, 2514, 359, 35742, 2262, "GraphicsData", 

"PostScript", "Graphics"],

Cell[392289, 13466, 65875, 3161, 359, 45719, 2907, "GraphicsData", 

"PostScript", "Graphics"],

Cell[458167, 16629, 78028, 3937, 359, 57953, 3684, "GraphicsData", 

"PostScript", "Graphics"],

Cell[536198, 20568, 78848, 3973, 359, 58494, 3717, "GraphicsData", 

"PostScript", "Graphics"],

Cell[615049, 24543, 75737, 3777, 359, 55309, 3520, "GraphicsData", 

"PostScript", "Graphics"],

Cell[690789, 28322, 63933, 3085, 359, 44923, 2845, "GraphicsData", 

"PostScript", "Graphics"],

Cell[754725, 31409, 44130, 1955, 359, 27735, 1747, "GraphicsData", 

"PostScript", "Graphics"]

}, Open  ]]

}, Open  ]],

Cell[798882, 33368, 782, 30, 138, "Input"],



Cell[CellGroupData[{

Cell[799689, 33402, 49, 1, 30, "Input"],

Cell[799741, 33405, 38, 1, 29, "Output"]

}, Open  ]],

Cell[799794, 33409, 62, 1, 30, "Input"],



Cell[CellGroupData[{

Cell[799881, 33414, 276, 5, 70, "Input"],

Cell[800160, 33421, 45597, 2433, 186, 35962, 2310, "GraphicsData", 

"PostScript", "Graphics"],

Cell[845760, 35856, 130, 3, 29, "Output"]

}, Open  ]],

Cell[845905, 35862, 812, 12, 230, "Input"],

Cell[846720, 35876, 235, 12, 138, "Input",

  InitializationCell->True],

Cell[846958, 35890, 411, 7, 110, "Input"],

Cell[847372, 35899, 228, 5, 90, "Input"],

Cell[847603, 35906, 165, 3, 50, "Input"],



Cell[CellGroupData[{

Cell[847793, 35913, 60, 1, 30, "Input"],

Cell[847856, 35916, 62576, 3013, 214, 43883, 2778, "GraphicsData", 

"PostScript", "Graphics"]

}, Open  ]]

}, Open  ]],



Cell[CellGroupData[{

Cell[910481, 38935, 68, 1, 50, "Subsection"],



Cell[CellGroupData[{

Cell[910574, 38940, 1713, 34, 423, "Input"],

Cell[912290, 38976, 23108, 381, 578, 23012, 378, "GraphicsData", 

"Bitmap", "Graphics"]

}, Open  ]],

Cell[935413, 39360, 868, 17, 228, "Input"],

Cell[936284, 39379, 130, 6, 48, "Input"],

Cell[936417, 39387, 752, 19, 246, "Input"],

Cell[937172, 39408, 179, 3, 70, "Input"],

Cell[937354, 39413, 153, 4, 57, "Input"],



Cell[CellGroupData[{

Cell[937532, 39421, 75, 1, 30, "Input"],

Cell[937610, 39424, 34866, 1270, 213, 20267, 1084, "GraphicsData", 

"PostScript", "Graphics"]

}, Open  ]]

}, Open  ]]

}, Open  ]],



Cell[CellGroupData[{

Cell[972537, 40701, 161, 4, 54, "Section"],

Cell[972701, 40707, 3500, 104, 147, "Input"]

}, Open  ]]

}, Open  ]]

}

]

*)









(***********************************************************************

End of Mathematica Notebook file.

***********************************************************************)



