(***********************************************************************



                    Mathematica-Compatible Notebook



This notebook can be used on any computer system with Mathematica 3.0,

MathReader 3.0, or any compatible application. The data for the notebook 

starts with the line of stars above.



To get the notebook into a Mathematica-compatible application, do one of 

the following:



* Save the data starting with the line of stars above into a file

  with a name ending in .nb, then open the file inside the application;



* Copy the data starting with the line of stars above to the

  clipboard, then use the Paste menu command inside the application.



Data for notebooks contains only printable 7-bit ASCII and can be

sent directly in email or through ftp in text mode.  Newlines can be

CR, LF or CRLF (Unix, Macintosh or MS-DOS style).



NOTE: If you modify the data for this notebook not in a Mathematica-

compatible application, you must delete the line below containing the 

word CacheID, otherwise Mathematica-compatible applications may try to 

use invalid cache data.



For more information on notebooks and Mathematica-compatible 

applications, contact Wolfram Research:

  web: http://www.wolfram.com

  email: info@wolfram.com

  phone: +1-217-398-0700 (U.S.)



Notebook reader applications are available free of charge from 

Wolfram Research.

***********************************************************************)



(*CacheID: 232*)





(*NotebookFileLineBreakTest

NotebookFileLineBreakTest*)

(*NotebookOptionsPosition[   5703309,     246948]*)

(*NotebookOutlinePosition[   5704051,     246974]*)

(*  CellTagsIndexPosition[   5704007,     246970]*)

(*WindowFrame->Normal*)







Notebook[{



Cell[CellGroupData[{

Cell[TextData[{

  "   \"Shooting\" and \"Bifurcating\" with\n    ",

  StyleBox["Mathematica",

    FontFamily->"Times New Roman",

    FontSlant->"Italic"]

}], "Title",

  PageWidth->WindowWidth,

  TextAlignment->Center],



Cell["\<\

Jay H. Wolkowisky

Department of Mathematics 

University of Colorado

Boulder, Colorado 80309, USA

wolkowis@euclid.colorado.edu\

\>", "Subtitle",

  PageWidth->WindowWidth,

  TextAlignment->Center],



Cell[CellGroupData[{



Cell[TextData[{

  "1 ",

  StyleBox["The Shooting Method",

    FontFamily->"Times New Roman"]

}], "Section",

  FontSize->18],



Cell[CellGroupData[{



Cell[TextData[{

  StyleBox[

  "As a simple example, we will consider the boundary value \nproblem (BVP):",

    

    FontSize->14],

  "\n",

  StyleBox[

  "y'' =f(x,y,y',\[Lambda]),\ny(0)=0,                                         \

                                        (1.1)\ny(1)=0.\n\nAssociated with \

this boundary value problem is the initial\n value problem (IVP):\ny'' \

=f(x,y,y',\[Lambda]), \ny(0)=0,                                               \

                                  (1.2)\ny'(0)=\[Alpha].\n\nLet \n\

y(x,\[Alpha],\[Lambda]) \nbe a solution of (1.2) for a fixed value of \

\[Lambda]. Solutions of (1.1) (if any) \nwill be determined by the condition:\

\n\ny(1,\[Alpha],\[Lambda])=0.                                                \

                            (1.3)\n\nSo for each value of  \[Alpha] that \

satisfies (1.3) there will exist a \nsolution of (1.1). We use Newton's \

method to find the roots of (1.3).\nThis takes the form of:\n\n",

    FontSize->14],

  Cell[BoxData[

      FormBox[

        StyleBox[

          RowBox[{\(\[Alpha]\_\(n + 1\)\), "=", 

            RowBox[{

              FormBox[\(\[Alpha]\_n - \),

                "TraditionalForm"], 

              FormBox[

                RowBox[{

                  FormBox["",

                    "TraditionalForm"], 

                  SuperscriptBox[

                    RowBox[{\(y\_\[Alpha]\), "(", 

                      RowBox[{"1", ",", 

                        FormBox[\(\[Alpha]\_n\),

                          "TraditionalForm"], ",", "\[Lambda]"}], ")"}], 

                    \(-1\)]}],

                "TraditionalForm"], "y", 

              RowBox[{"(", 

                RowBox[{"1", ",", 

                  FormBox[\(\[Alpha]\_n\),

                    "TraditionalForm"], ",", "\[Lambda]"}], ")"}]}]}],

          FontSize->16], TraditionalForm]],

    FontSize->16],

  StyleBox[" ,     ",

    FontSize->16],

  StyleBox["n ",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[

  " =0,1,2,...  (1.4)\n\nIn order to calculate the partial derivative in \

(1.4) we differentiate\nthe IVP (1.2) with respect to \[Alpha] and obtain the \

fourth\norder IVP:\n\n",

    FontSize->16],

  StyleBox["y",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox["''=f(x,",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`y\)],

    FontSize->16],

  StyleBox[",",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`y\)],

    FontSize->16],

  StyleBox["',\[Lambda]),\n",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`\(y\_\[Alpha]'\)'\)],

    FontSize->16],

  StyleBox["=",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`f\_y\)],

    FontSize->16],

  StyleBox["(x,",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`y\)],

    FontSize->16],

  StyleBox[",",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`y\)],

    FontSize->16],

  StyleBox["',\[Lambda])",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`y\_\(\[Alpha]\n\t\)\)],

    FontSize->16],

  StyleBox[" + ",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`f\_\(y'\)\)],

    FontSize->16],

  StyleBox["(x,",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`y\)],

    FontSize->16],

  StyleBox[",",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`y\)],

    FontSize->16],

  StyleBox["',\[Lambda])",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`y\_\[Alpha]\)],

    FontSize->16],

  StyleBox["',\n",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`y\)],

    FontSize->16],

  StyleBox[

  "(0)=0,                                                                     \

              (1.5)\n",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`y\_\[Alpha]\)],

    FontSize->16],

  StyleBox["(0)=0,\n",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`y\)],

    FontSize->16],

  StyleBox["'(0)=\[Alpha],\n",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`y\_\[Alpha]\)],

    FontSize->16],

  StyleBox["'(0)=1.\n\nWe solve this IVP for ",

    FontSize->16],

  StyleBox["y",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox["(1,",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`\[Alpha]\_n\)],

    FontSize->16],

  StyleBox[",\[Lambda]) and ",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`y\_\[Alpha]\)],

    FontSize->16],

  StyleBox["(1,",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`\[Alpha]\_n\)],

    FontSize->16],

  StyleBox[",\[Lambda]),",

    FontSize->16],

  StyleBox[" n",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[

  "=1,2,... , at\neach stage of the iteration scheme (1.4).\n\nOnce we have a \

solution, \[Alpha](",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`\(\[Lambda]\_0)\)\)],

    FontSize->16],

  StyleBox[", of (1.3) at \[Lambda] = ",

    FontSize->16],

  Cell[BoxData[

      FormBox[

        StyleBox[\(\[Lambda]\_0\),

          FontSize->16], TraditionalForm]]],

  " ",

  StyleBox["we can get a solution\nfor \[Lambda] = ",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`\[Lambda]\_0\  + \ \ \[CapitalDelta]\[Lambda]\)],

    FontSize->16],

  " ",

  StyleBox["by using \[Alpha]=\[Alpha](",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`\[Lambda]\_0\)],

    FontSize->16],

  StyleBox[

  ") as our first iterate to start the \niteration scheme (1.4). After two \

points \[Alpha](",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`\(\[Lambda]\_o)\)\)],

    FontSize->16],

  StyleBox[" and \[Alpha](",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`\[Lambda]\_0\)],

    FontSize->16],

  StyleBox[" + \[CapitalDelta]\[Lambda])",

    FontSize->16],

  " ",

  StyleBox[

  " are \nfound on the graph of \[Alpha](\[Lambda]), instead of using \

\[Alpha](",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`\[Lambda]\_0\)],

    FontSize->16],

  StyleBox[

  " + \[CapitalDelta]\[Lambda]) as our initial\niterate to find the next \

point \[Alpha](",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`\[Lambda]\_0\)],

    FontSize->16],

  StyleBox[

  " + 2 \[CapitalDelta]\[Lambda]), it is easy to see \n(by the following \

figure)  that by using\n\n       \[Alpha](",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`\[Lambda]\_0\)],

    FontSize->16],

  StyleBox[" + \[CapitalDelta]\[Lambda]) + (\[Alpha](",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`\[Lambda]\_0\)],

    FontSize->16],

  StyleBox[" + \[CapitalDelta]\[Lambda]) - \[Alpha](",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`\[Lambda]\_0\)],

    FontSize->16],

  StyleBox[")) = 2 \[Alpha](",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`\[Lambda]\_0\)],

    FontSize->16],

  StyleBox[" + \[CapitalDelta]\[Lambda]) - \[Alpha](",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`\[Lambda]\_0\)],

    FontSize->16],

  StyleBox[

  ") \n       \nas the initial iterate, the convergence will be faster. \n",

    FontSize->16]

}], "Input",

  FormatType->TextForm],



Cell[GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000<P0002F1000`40O003

h00Oogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00

ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogoo

ogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogoo

ogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo

8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo

003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003o

OoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOooo

OoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOooo

OolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolS

Ool00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol0

0?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mo

oomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomo

oomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomo

ob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=o

o`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00

ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogoo

ogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogoo

ogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo

8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo

003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003o

OoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOooo

OoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOooo

OolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolS

Ool00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol0

0?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mo

oomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomo

oomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomo

ob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=o

o`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00

ogooVgoo0g`0CWoo0g`0ogoo<goo002]Ool3O00jOol00g`0Oomoo`1cOol0

0g`0Oomoo`0fOol017`0Oomoog`0CGoo00Al07ooOoml0?mooc=oo`00WWoo

0W`037oo00Al07ooOoml02Eoo`03O01oogoo019oo`03O01oogoo00Uoo`9l

00aoo`=l025oo`03O01oogoo01Uoo`9l00eoo`=l00Moo`03O01oogoo009l

02]oo`9l00Yoo`03O01oogoo009l02Aoo`03O01oogoo01Yoo`9l00Uoo`03

O01oogoo009l00Qoo`03O01oogoo0?moobMoo`00WWoo00=l07ooOol02goo

00=l07ooOol00W`097oo00=l07ooOol04Goo00=l07ooOol02Woo00=l07oo

Ool02Woo00Al07ooOoml025oo`03O01oogoo01Uoo`03O01oogoo00]oo`04

O01oogooO007Ool017`0Oomoogoo0W`0:Woo00=l07ooOol02Goo00=l07oo

Ool00W`097oo00=l07ooOol06Woo00=l07ooOol027oo00=l07ooOol00W`0

27oo00=l07ooOol0ogoo9goo001YOol3O002Ool017`0Oomoogoo0g`00goo

0W`00Woo0g`00Woo00=l07ooOol04Goo17`000=oog`0O0000Woo00Al07oo

Oomoo`9l00=oo`9l0005Ooml07ooO01oo`03O0000gooO01oo`04Ool00g`0

Oomoo`02Ool017`0Oomoogoo27`000=oog`0O0000goo0W`017oo00Al07oo

Ooml00Eoo`03O01oogoo009oo`03O01oogoo009oo`03O01oogoo009oo`Al

0003Ooml07`0009oo`04O01oogooOol2O003Ool2O0000gooO01l0002Ool2

O004Ool00g`0Oomoo`02Ool017`0Oomoogoo27`000=oog`0O0000goo0W`0

0goo00Al07ooOoml00Yoo`03O01oogoo009oo`Al0003Ooml07`0009oo`04

O01oogooOol2O003Ool2O0001GooO01oog`0Ool017`01Goo00=l07ooOol0

0Woo00Al07ooOoml009oo`03O01oogoo00Uoo`05O01oogooOoml0002Ool6

O003Ool4O0000gooO01l0002Ool017`0Oomoogoo0W`00goo0W`000Aoog`0

Oomoo`9l009oo`03O01oogoo00Aoo`03O01oogoo009oo`03O01oogoo00Ql

0003Ooml07`000=oo`9l00=oo`04O01oogooO00;Ool017`0Oomoogoo17`0

00=oog`0O0000goo00=l07ooOol00W`00goo0W`000Aoog`0Oomoo`9l00=o

o`03O01oogoo009oo`03O01oogoo0?moobMoo`00JWoo00El07ooOomoog`0

009oo`05O01oogooOoml0002Ool017`0Oomoog`067oo0W`00Woo0g`00goo

00=l07ooOol00Woo00=l07ooOol017`00Woo00=l07ooOol00W`01goo00=l

07ooOol01Woo00=l07ooOol00goo0W`00Woo00=l07ooOol017`00goo00=l

07ooOol01Woo00=l07ooOol01goo00Al07ooOomoo`9l009oo`=l00=oo`03

O01oogoo009oo`03O01oogoo00Al0004Ooml07ooOol2O004Ool00g`0Oomo

o`06Ool00g`0Oomoo`03Ool2O002Ool00g`0Oomoo`04O002Ool00g`0Oomo

o`0?Ool2O002Ool3O003Ool00g`0Oomoo`02Ool00g`0Oomoo`04O002Ool0

0g`0Oomoo`02O006Ool00g`0Oomoo`02Ool00g`0Oomoo`0GOol01G`0Oomo

ogooO0000Woo0W`00Woo0g`00goo00=l07ooOol00Woo00=l07ooOol01G`0

0Woo00=l07ooOol027oo00=l07ooOol01Goo00=l07ooOol00goo0W`00Woo

00=l07ooOol017`00Woo00=l07ooOol03goo0W`00Woo0g`017oo00El07oo

Oomoog`0009oo`El009oo`03O01oogoo00Moo`03O01oogoo0?moobMoo`00

JWoo00=l07ooOol00W`00Woo00El07ooOomoog`0009oo`03O01oogoo00Al

01Eoo`9l00=oo`9l00=oo`03O01oogoo009oo`04O01oogooO002Ool017`0

Oomoog`00Woo00=l07ooOol01Woo00=l07ooOol01goo00Al07ooOomoo`9l

00=oo`04O01oogooO002Ool01G`0OomoogooO00027oo00=l07ooOol01goo

00Al07ooOomoo`9l00=oo`9l00=oo`03O01oogoo009oo`04O01oogooO002

Ool00g`0Ooml0002Ool2O004Ool00g`0Oomoo`07Ool017`0Oomoogoo0W`0

0goo00Al07ooOoml009oo`04O01oogooO00AOol2O003Ool2O003Ool00g`0

Oomoo`02Ool017`0Oomoog`00Woo00Al07ooOoml009oo`9l00Ioo`03O01o

ogoo009oo`9l00Qoo`Ml00Yoo`03O01oogoo00=oo`9l00=oo`9l00=oo`03

O01oogoo009oo`04O01oogooO002Ool00g`0Ooml0002O00:Ool00g`0Oomo

o`06Ool017`0Oomoogoo0W`00goo00Al07ooOoml009oo`04O01oogooO00A

Ool2O003Ool2O004Ool01G`0OomoogooO0000Woo00El07ooOoml07oo00=l

00Uoo`03O01oogoo0?moobMoo`00JWoo00El07ooO01oog`0009oo`05O01o

ogooOoml0002Ool017`0Oomoog`00Woo00=l07ooOol04goo0W`00goo0W`0

0goo00=l07ooOol00Woo0W`000=oog`0Ool01Goo0g`01Goo1g`01Woo00Al

07ooOomoo`9l00=oo`9l0003Ooml07oo00Eoo`03O01oogoo00=oo`Ml00Io

o`04O01oogooOol2O003Ool2O003Ool00g`0Oomoo`02Ool2O0000gooO01o

o`03Ool017`0Oomoog`00Woo1g`01Woo00Al07ooOomoo`9l00=oo`9l0003

Ooml07oo00Aoo`03O01oogoo00=oo`Ml00Eoo`9l00=oo`9l00=oo`03O01o

ogoo009oo`9l0003Ooml07oo00Aoo`04O01oogooO007Ool00g`0Oomoo`02

Ool2O00JOol00g`0Oomoo`02Ool2O003Ool2O003Ool00g`0Oomoo`02Ool2

O0000gooO01oo`0=Ool7O005Ool017`0Oomoogoo0W`00goo0W`000=oog`0

Ool017oo00=l07ooOol017oo1g`017oo0W`00goo0W`017oo00Al07ooOomo

o`9l0003Ooml07oo00moo`03O01oogoo0?moobMoo`00JWoo00El07ooO01o

og`000=oo`=l009oo`=l009oo`9l00=oo`03O01oogoo011oo`9l00=oo`9l

00=oo`03O01oogoo00=oo`=l015oo`03O01oogoo00Moo`05O01oogooOoml

0005Ool3O006Ool00g`0Oomoo`06Ool00g`0Oomoo`07Ool017`0Oomoogoo

0W`00goo0W`00goo00=l07ooOol00goo0g`01Goo0g`01Goo00=l07ooOol0

1goo00El07ooOomoog`000Eoo`=l00Eoo`03O01oogoo00moo`9l00=oo`9l

00=oo`03O01oogoo00=oo`=l00Ioo`=l00Moo`03O01oogoo009oo`9l01]o

o`04O01oogooOol2O003Ool2O003Ool00g`0Oomoo`03Ool3O00AOol00g`0

Oomoo`06Ool01G`0OomoogooO0001Goo0g`01Goo00=l07ooOol03goo0W`0

0goo0W`017oo00=l07ooOol00Woo0g`047oo00=l07ooOol0ogoo9goo001Z

Ool2O002Ool00g`0Oomoo`07Ool00g`0Oomoo`0IOol2O003Ool3O002Ool0

0g`0Oomoo`03Ool3O00AOol00g`0Oomoo`08Ool017`0Ooml07`01Goo0g`0

1Woo00=l07ooOol01Woo00=l07ooOol01goo00Al07ooOomoo`9l00=oo`=l

009oo`03O01oogoo00=oo`=l00eoo`03O01oogoo00Qoo`04O01oog`0O005

Ool3O005Ool00g`0Oomoo`0?Ool2O003Ool3O002Ool00g`0Oomoo`03Ool3

O00@Ool00g`0Oomoo`02Ool00g`0Oomoo`07Ool7O00<Ool017`0Oomoogoo

0W`00goo0g`00Woo00=l07ooOol00goo0g`04Goo00=l07ooOol01goo00Al

07ooO01l00Eoo`=l00Eoo`03O01oogoo00moo`9l00=oo`=l00=oo`03O01o

ogoo009oo`=l011oo`03O01oogoo0?moobMoo`00JWoo00El07ooOomoog`0

00Uoo`03O01oogoo01Yoo`Al0003Ooml07`0009oo`03O01oogoo00Aoo`03

O01oogoo011oo`03O01oogoo00Qoo`04O01oog`0O006Ool00g`0Oomoo`05

Ool00g`0Oomoo`06Ool00g`0Oomoo`07Ool00g`0Oomoo`02Ool4O0000goo

O01l0002Ool00g`0Oomoo`04Ool00g`0Oomoo`0<Ool00g`0Oomoo`08Ool0

17`0Ooml07`01Woo00=l07ooOol017oo00=l07ooOol047oo17`000=oog`0

O0000Woo00=l07ooOol017oo00=l07ooOol03goo00=l07ooOol00Woo00=l

07ooOol06Woo00=l07ooOol00Woo17`000=oog`0O0000Woo00=l07ooOol0

17oo00=l07ooOol047oo00=l07ooOol01goo00Al07ooO01l00Ioo`03O01o

ogoo00Aoo`03O01oogoo011oo`Al0003Ooml07`000=oo`03O01oogoo00=o

o`03O01oogoo00moo`03O01oogoo0?moobMoo`00JGoo0W`00Woo0g`0;Woo

00=l07ooOol017oo00=l07ooOol047oo00=l07ooOol02Goo0W`01goo00=l

07ooOol01Goo00=l07ooOol01Woo00=l07ooOol01goo00=l07ooOol02goo

00=l07ooOol017oo00=l07ooOol037oo00=l07ooOol02Goo0W`01goo00=l

07ooOol017oo00=l07ooOol06Goo00=l07ooOol017oo00=l07ooOol03goo

00=l07ooOol00Woo00=l07ooOol05Woo00El07ooOomoog`000eoo`03O01o

ogoo00Aoo`03O01oogoo011oo`03O01oogoo00Qoo`9l00Moo`03O01oogoo

00Aoo`03O01oogoo01Yoo`03O01oogoo00=oo`03O01oogoo00moo`03O01o

ogoo0?moobMoo`00WWoo00El07ooOomoog`0009oo`03O01oogoo01aoo`9l

00Aoo`04O01oogooO007Ool00g`0Oomoo`0AOol00g`0Oomoo`0:Ool01G`0

OomoogooO0000Woo00=l07ooOol067oo0W`017oo00Al07ooOoml00Ioo`03

O01oogoo01Uoo`05O01oogooOoml0002Ool00g`0Oomoo`0?Ool01G`0Oomo

ogooO0006Woo17`03Goo00El07ooOomoog`0009oo`03O01oogoo01]oo`9l

00Aoo`04O01oogooO006Ool00g`0Oomoo`0JOol017`0Oomoog`00Woo00=l

07ooOol03goo00=l07ooOol0ogoo9goo002NOol3O00017ooO01l07`087oo

00=l07ooOol00Woo0g`01Woo0g`057oo00=l07ooOol02Goo0g`000Aoog`0

O01l01aoo`03O01oogoo009oo`=l00Eoo`=l01]oo`=l0004Ooml07`0O00@

Ool3O002Ool00g`0Oomoo`0JOol2O00>Ool3O00017ooO01l07`07goo00=l

07ooOol00Woo0g`01Goo0g`077oo1W`047oo0g`0ogoo:Goo002SOol2O00V

Ool2O00^Ool2O00ROol2O00XOol2O017Ool2O00UOol2O00XOol2O03oOoll

Ool00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol0

0?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mo

oomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomo

oomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomo

ob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=o

o`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00

ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogoo

ogooogoo8goo003oOoooOoooOolSOol00?mooleoo`<00?mooe9oo`00ogoo

O7oo0`00CGoo00@007ooOol00?mooe9oo`00ogooNgoo00@007ooOol004eo

o`03001oogoo0080055oo`<00?aoo`00ogooNgoo00<007ooOol00P00C7oo

00<007ooOol00P00D7oo00@007ooOol00?aoo`00ogoo<7oo0`00B7oo00<0

07ooOol00P00@Goo0P0017oo0P000goo00<007ooOol00P0000=oo`00Ool0

1Woo00<007ooOol00goo00@007ooOomoo`L00003Ool007oo00=oo`T00003

Ool0000000Aoo`8001ioo`03001oogoo00800?]oo`00ogoo97oo0P0017oo

0P0000Eoo`00Ool007oo008003ioo`8000Aoo`80009oo`03001oogoo0080

00Uoo`03001oogoo009oo`04001oogooOol90002Ool20004Ool2000LOol2

0003Ool40002Ool01000Oomoo`002Woo00<007ooOol027oo00<007ooOol0

0Woo00<007ooOol017oo00<007ooOol017oo0P0000=oo`0000000goo1000

4Woo0P0017oo0P000Woo0P000Woo0P001Woo00<007ooOol00goo00<007oo

Ool00Woo100017oo2@0000=oo`00000017oo0P00d7oo003oOolTOol20003

Ool40002Ool00`00Oomoo`02000mOol20003Ool400001Goo001oogoo0000

2Woo00<007ooOol01Woo00<007ooOol017oo0P000Woo0P000goo100077oo

0P000Woo00@007ooOol000=oo`<000Yoo`03001oogoo00Uoo`03001oogoo

00Uoo`03001oogoo00=oo`80009oo`80009oo`04001oogoo000BOol20003

Ool40002Ool00`00Oomoo`020006Ool00`00Oomoo`08Ool01@00Oomoogoo

00000goo00<007ooOol017oo0P0000=oo`0000000goo1000cgoo003oOolU

Ool20002Ool01000Oomoo`000Woo00<007ooOol00P00?Woo0P000Woo00@0

07ooOol0009oo`<000Yoo`03001oogoo00Moo`03001oogoo00=oo`8000=o

o`80009oo`04001oogoo000LOol20002Ool00`00Oomoo`0AOol00`00Oomo

o`0:Ool00`00Oomoo`08Ool00`00Oomoo`02Ool20003Ool20002Ool00`00

Oomoo`0DOol20002Ool01000Oomoo`000Woo00@007ooOol000Moo`03001o

ogoo00aoo`8000=oo`03001oogoo00=oo`80009oo`80009oo`04001oogoo

003?Ool00?moobEoo`80009oo`03001oogoo00=oo`03001oogoo008003io

o`80009oo`03001oogoo011oo`03001oogoo00Moo`03001oogoo009oo`80

00Aoo`80009oo`03001oogoo01ioo`800003Ool007oo00ioo`P000Uoo`80

00Yoo`04001oogooOol20004Ool200000goo001oo`0EOol20002Ool00`00

Oomoo`04Ool30007Ool00`00Oomoo`0<Ool20003Ool00`00Oomoo`02Ool2

0003Ool20002Ool00`00Oomoo`3@Ool00?moobIoo`800003Ool007oo00Ao

o`04001oogoo0010Ool200000goo001oo`0=Ool80007Ool01000Oomoogoo

0P001Goo0P0000=oo`00Ool07goo0`004goo0P003Goo00<007ooOol027oo

00<007ooOol00P001Goo0`0067oo0P0000=oo`00Ool02goo20002goo0P00

17oo00@007ooOomoo`8000Aoo`800003Ool007oo0=5oo`00ogoo9Woo0`00

1goo0`00@7oo0`004Woo0P002Woo00<007ooOol00P001Woo0`008Woo0P00

57oo00<007ooOol037oo00<007ooOol01goo00<007ooOol00P001Woo0P00

67oo0`0047oo0P002goo10001Goo00<007ooOol00P001Goo0`00dgoo003o

OolWOol2001;Ool2000COol00`00Oomoo`08Ool00`00Oomoo`020007Ool2

000ROol2000DOol00`00Oomoo`0<Ool00`00Oomoo`08Ool01000Ool00000

1Woo0P006Goo0P004Goo00<007ooOol02Woo0P001Woo00<007ooOol00P00

1Woo0P00dgoo003oOolWOol2001;Ool2000COol00`00Oomoo`09Ool01000

Ool000001goo0P008goo00<007ooOol04Woo00<007ooOol01goo00<007oo

Ool00Woo00<007ooOol027oo0`0027oo00<007ooOol05goo0P004Goo00<0

07ooOol02goo00<007ooOol01Goo00@007oo000000Ioo`800==oo`00ogoo

:7oo00<007ooOol0BWoo00<007ooOol04Goo00<007ooOol02Goo0`002Goo

00<007ooOol07Goo00@007ooOol001moo`80009oo`8000]oo`8000Aoo`04

001oogoo000KOol00`00Oomoo`0?Ool00`00Oomoo`07Ool00`00Oomoo`02

Ool00`00Oomoo`04Ool30008Ool00`00Oomoo`16Ool20005Ool30021Ool0

0?moobAoo`04001oogoo0019Ool01000Oomoo`008Goo0P001Goo00@007oo

Ool0021oo`04001oogoo000POol5000;Ool00`00Oomoo`03Ool01000Oomo

o`005goo00@007ooOol001aoo`04001oogooOol20007Ool20004Ool01000

Oomoo`00BGoo0P0017oo1@00P7oo003oOolTOol01000Oomoo`00BGoo00@0

07ooOol0025oo`03001oogoo00Aoo`04001oogoo000QOol3000QOol3000C

Ool3000GOol01000Oomoo`007Goo1@001goo00<007ooOol00goo00@007oo

Ool004Yoo`8000=oo`<00003Ool007oo07moo`00ogoo9Goo0`00BWoo0`00

:Goo0`008Goo0P00>7oo0P006Goo0`007Woo0`003goo0`00BWoo0`000Woo

00D007ooOomoo`00081oo`00ogoo9Goo0P00Bgoo0P00:Woo0P00Mgoo0P00

<Goo0P00<7oo00<007ooOol06Goo0P000Woo00<007ooOol0PWoo003oOooo

OomnOol5000FOol300000goo001oo`23Ool00?mooomooaEoo`03001oogoo

06]oo`@0019oo`D008Aoo`00l7oo00<007ooOol0=Goo00<007ooOol0DGoo

00<007ooOol0C7oo00<007ooOol0AGoo00<007ooOol0J7oo2P0047oo1000

Q7oo003oOolZOol00`00Oomoo`1@Ool00`00Oomoo`1<Ool00`00Oomoo`15

Ool00`00Oomoo`09OomO0006Ool4000@Ool30025Ool00?moobYoo`03001o

ogoo051oo`03001oogoo045ooel0065oo`@001Eoo`8008Eoo`00ogoo:Woo

00<007ooOol0=GooG`002goo00<007ooOol0AGoo00<007ooOol0Igoo0`00

6Woo00<007ooOol0Pgoo003oOol3OomO000KOol00`00Oomoo`1<Ool00`00

Oomoo`15Ool00`00Oomoo`1UOol2002SOol00?1ooa8002Moo`03001oogoo

051oo`03001oogoo04aoo`03001oogoo04Eoo`03001oogoo07moo`05001o

ogooOol00026Ool00?1oo`03001oogoo03Ioo`03001oogoo051oo`03001o

ogoo04aoo`03001oogoo04Eoo`03001oogoo07moo`800003Ool0000008Io

o`00l7oo00<007ooOol0=Woo00<007ooOol0D7oo00<007ooOol0C7oo00<0

07ooOol0AGoo00<007ooOol0P7oo1000QWoo003`Ool00`00Oomoo`0fOol0

0`00Oomoo`1@Ool00`00Oomoo`1<Ool00`00Oomoo`15Ool00`00Oomoo`20

Ool30027Ool00?1oo`03001oogoo03Ioo`03001oogoo051oo`03001oogoo

04aoo`03001oogoo04Eoo`03001oogoo0?moo`]oo`00l7oo00<007ooOol0

=Woo00<007ooOol0D7oo00<007ooOol0C7oo00<007ooOol0AGoo00<007oo

Ool0ogoo2goo003`Ool00`00Oomoo`0fOol00`00Oomoo`1@Ool00`00Oomo

o`1<Ool00`00Oomoo`15Ool00`00Oomoo`3oOol;Ool00?1oo`03001oogoo

03Ioo`03001oogoo051oo`03001oogoo04aoo`03001oogoo04Eoo`03001o

ogoo0?moo`]oo`00l7oo00<007ooOol0=Woo00<007ooOol0D7oo00<007oo

Ool0C7oo00<007ooOol0AGoo00<007ooOol0ogoo2goo003`Ool00`00Oomo

o`0fOol00`00Oomoo`1@Ool00`00Oomoo`1<Ool00`00Oomoo`15Ool00`00

Oomoo`3oOol;Ool00?1oo`03001oogoo03Ioo`03001oogoo051oo`03001o

ogoo04aoo`03001oogoo04Eoo`03001oogoo0?moo`]oo`00l7oo00<007oo

Ool0=Woo00<007ooOol0D7oo00<007ooOol0C7oo00<007ooOol0AGoo00<0

07ooOol0ogoo2goo003`Ool00`00Oomoo`0fOol00`00Oomoo`1@Ool00`00

Oomoo`1<Ool00`00Oomoo`15Ool00`00Oomoo`3oOol;Ool00?1oo`03001o

ogoo03Ioo`03001oogoo051oo`03001oogoo04aoo`03001oogoo04Eoo`03

001oogoo0?moo`]oo`00l7oo00<007ooOol0=Woo00<007ooOol0D7oo00<0

07ooOol0C7oo00<007ooOol0AGoo00<007ooOol0ogoo2goo003`Ool00`00

Oomoo`0fOol00`00Oomoo`1@Ool00`00Oomoo`1<Ool00`00Oomoo`15Ool0

0`00Oomoo`3oOol;Ool00?1oo`03001oogoo03Ioo`03001oogoo051oo`03

001oogoo04aoo`03001oogoo04Eoo`03001oogoo0?moo`]oo`00l7oo00<0

07ooOol0=Woo00<007ooOol0D7oo00<007ooOol0C7oo00<007ooOol0ogoo

Dgoo003`Ool00`00Oomoo`0fOol00`00Oomoo`1@Ool00`00Oomoo`1<Ool0

0`00Oomoo`3oOomCOol00?1oo`03001oogoo03Ioo`03001oogoo051oo`03

001oogoo04aoo`03001oogoo04Eoo`03001oogoo0?moo`]oo`00l7oo00<0

07ooOol0=Woo00<007ooOol0D7oo00<007ooOol0C7oo00<007ooOol0ogoo

Dgoo003`Ool00`00Oomoo`0fOol00`00Oomoo`1@Ool00`00Oomoo`1<Ool0

0`00Oomoo`3oOomCOol00?1oo`03001oogoo03Ioo`03001oogoo051oo`03

001oogoo04aoo`03001oogoo04Eoo`03001oogoo0?moo`]oo`00l7oo00<0

07ooOol0=Woo00<007ooOol0D7oo00<007ooOol0C7oo00<007ooOol0AGoo

00<007ooOol0ogoo2goo003`Ool00`00Oomoo`0fOol00`00Oomoo`1@Ool0

0`00Oomoo`1<Ool00`00Oomoo`3oOomCOol00?1oo`03001oogoo03Ioo`03

001oogoo051oo`03001oogoo04aoo`03001oogoo0?mooe=oo`00l7oo00<0

07ooOol0=Woo00<007ooOol0D7oo00<007ooOol0C7oo00<007ooOol0A7oo

00<007ooOol0ogoo37oo003`Ool00`00Oomoo`0fOol00`00Oomoo`1@Ool0

0`00Oomoo`1<Ool00`00Oomoo`3oOomCOol00?1oo`03001oogoo03Ioo`03

001oogoo051oo`03001oogoo04aoo`03001oogoo0?mooe=oo`00l7oo00<0

07ooOol0=Woo00<007ooOol0Wgoo00<007ooOol0A7oo00<007ooOol0ogoo

37oo003`Ool00`00Oomoo`0fOol00`00Oomoo`1@Ool00`00Oomoo`1<Ool0

0`00Oomoo`14Ool00`00Oomoo`3oOol<Ool00?1oo`03001oogoo03Ioo`03

001oogoo051oo`03001oogoo0?mooj9oo`00l7oo00<007ooOol0=Woo00<0

07ooOol0Wgoo00<007ooOol0A7oo00<007ooOol0ogoo37oo003`Ool00`00

Oomoo`0fOol00`00Oomoo`1@Ool00`00Oomoo`1<Ool00`00Oomoo`14Ool0

0`00Oomoo`3oOol<Ool00?1oo`03001oogoo03Ioo`03001oogoo051oo`03

001oogoo0?mooj9oo`00l7oo00<007ooOol0=Woo00<007ooOol0ogoomGoo

003`Ool00`00Oomoo`0fOol00`00Oomoo`2OOol00`00Oomoo`14Ool00`00

Oomoo`3oOol<Ool00?1oo`03001oogoo03Ioo`03001oogoo051oo`03001o

ogoo04aoo`03001oogoo04Aoo`03001oogoo0?moo`aoo`00l7oo00<007oo

Ool0=Woo00<007ooOol0iWoo00<007ooOol0ogoo37oo003`Ool00`00Oomo

o`0fOol00`00Oomoo`2OOol00`00Oomoo`14Ool00`00Oomoo`3oOol<Ool0

0?1oo`03001oogoo03Ioo`03001oogoo051oo`03001oogoo04aoo`03001o

ogoo04Aoo`03001oogoo0?moo`aoo`00l7oo00<007ooOol0=Woo00<007oo

Ool0D7oo00<007ooOol0Tgoo00<007ooOol0ogoo37oo003`Ool00`00Oomo

o`0fOol00`00Oomoo`3VOol00`00Oomoo`3oOol<Ool00?1oo`03001oogoo

03Ioo`03001oogoo051oo`03001oogoo04aoo`03001oogoo04Aoo`03001o

ogoo0?moo`aoo`00l7oo00<007ooOol0=Woo00<007ooOol0D7oo00<007oo

Ool0Tgoo00<007ooOol0ogoo37oo003`Ool00`00Oomoo`0fOol00`00Oomo

o`3VOol00`00Oomoo`3oOol<Ool00?1oo`03001oogoo03Ioo`03001oogoo

09moo`03001oogoo04Aoo`03001oogoo0?moo`aoo`00l7oo00<007ooOol0

=Woo00<007ooOol0Cgoo00<007ooOol0CGoo00<007ooOol0A7oo00<007oo

Ool0ogoo37oo003`Ool00`00Oomoo`0fOol00`00Oomoo`1?Ool00`00Oomo

o`2DOol00`00Oomoo`3oOol<Ool00=ioo`<000moo`03001oogoo03Ioo`03

001oogoo09ioo`03001oogoo04Eoo`03001oogoo0?moo`aoo`00cWoo1000

2goo00@007ooOol000=oo`@000Qoo`03001oogoo03Ioo`03001oogoo04mo

o`03001oogoo04aoo`03001oogoo04Eoo`03001oogoo0?moo`aoo`00cWoo

0P003Goo00<007ooOol00P0017oo0P0027oo00<007ooOol0=Woo00<007oo

Ool0Cgoo00<007ooOol0U7oo00<007ooOol0ogoo37oo003>Ool00`00Oomo

o`0<Ool00`00Oomoo`020005Ool00`00Oomoo`06Ool00`00Oomoo`0fOol0

0`00Oomoo`3VOol00`00Oomoo`3oOol<Ool00<=oo`D0009oo`05001oogoo

Ool00003Ool20004Ool20002Ool20002Ool20005Ool00`00Oomoo`06Ool0

0`00Oomoo`0fOol00`00Oomoo`1?Ool2O01=Ool00`00Oomoo`15Ool00`00

Oomoo`3oOol<Ool00<=oo`80009oo`D0009oo`04001oogooOol20003Ool4

0002Ool01000Oomoo`001Woo00<007ooOol01Woo00<007ooOol0=Goo0`00

CWoo1W`0Bgoo00<007ooOol0AGoo00<007ooOol0ogoo37oo0032Ool20004

Ool200001Goo001oogoo000017oo0P000Woo00@007ooOol000=oo`<000Io

o`03001oogoo00Ioo`03001oogoo00800003Ool00000009oo`800003Ool0

0000009oo`800003Ool00000009oo`03001oogoo00800003Ool00000009o

o`800003Ool00000009oo`800003Ool00000009oo`03001oogoo00800003

Ool0000000@004Ioo`03O01oogoo00Aoo`Il09=oo`03001oogoo0?moo`ao

o`00`Woo0P0017oo0P0017oo00<007ooOol00Woo0P000Woo00<007ooOol0

3Goo00<007ooOol01Woo00<007ooOol0<goo1`00AWoo17`000=oog`0O000

1G`0Bgoo00<007ooOol0AGoo00<007ooOol0ogoo37oo0032Ool20004Ool2

0004Ool00`00Oomoo`03Ool200000goo001oo`0>Ool00`00Oomoo`06Ool0

0`00Oomoo`0cOol700000gooO01l0002Ool00g`0Oomoo`02O0000gooO01l

0002Ool2O0000gooO01l0002Ool2O0000gooO01l0002Ool00g`0Oomoo`02

O0000gooO01l0002Ool2O0000gooO01l0002Ool2O0000gooO01l0002Ool2

O0000gooO01l0002Ool00g`0Oomoo`02O0000gooO01l0002Ool2O0000goo

O01l0007O01;Ool00`00Oomoo`15Ool00`00Oomoo`3oOol<Ool00<9oo`80

00Aoo`8000Aoo`03001oogoo00=oo`<0011oo`03001oogoo00Ioo`03001o

ogoo03=oo`L004Moo`Al0003Ooml07`000Al09=oo`03001oogoo0?moo`ao

o`00`goo00<007ooOol00goo0P000goo00<007ooOol017oo0P0047oo00<0

07ooOol01Woo00<007ooOol0<goo1P0000=l07ooOol0@goo0W`01Woo1G`0

Tgoo00<007ooOol0ogoo37oo0033Ool2000017oo000007oo0P000goo00<0

07ooOol017oo0P0047oo00<007ooOol01Woo00<007ooOol0=Goo100000=l

07ooOol0C7oo00=l07ooOol0C7oo00<007ooOol0AGoo00<007ooOol0ogoo

37oo0034Ool30003Ool01@00Oomoogoo00001goo00<007ooOol03Woo00<0

07ooOol01Woo00<007ooOol0?7oo00=l07ooOol0BWoo00=l07ooOol0Bgoo

00<007ooOol0AGoo00<007ooOol0ogoo37oo003>Ool01@00Oomoogoo0000

0Woo00<007ooOol03goo00<007ooOol01Woo00<007ooOol0?goo00=l07oo

Ool0Agoo00=l07ooOol0ogooXWoo003>Ool20002Ool01000Oomoo`0047oo

0P0027oo00<007ooOol0?goo00=l07ooO000UGoo00<007ooOol0AGoo00<0

07ooOol0ogoo37oo003>Ool4000017oo000000003Woo100027oo00<007oo

Ool0@Woo0W`0Tgoo00<007ooOol0AGoo00<007ooOol0ogoo37oo003COol2

000KOol00`00Oomoo`15Ool00g`0Oomoo`11Ool00g`0Oomoo`3oOonROol0

0?1oo`03001oogoo04Moo`03O01oogoo03moo`03O01oogoo0?mooj9oo`00

l7oo00<007ooOol0B7oo0W`0SGoo00<007ooOol0AGoo00<007ooOol0ogoo

37oo003`Ool00`00Oomoo`1;Ool2O00lOol00g`0Oomoo`2COol00`00Oomo

o`3oOol<Ool00?1oo`03001oogoo08Uoo`03O01oogoo0?mooj9oo`00l7oo

00<007ooOol0CWoo0W`0Qgoo00<007ooOol0ogooE7oo003`Ool00`00Oomo

o`1AOol2O024Ool00`00Oomoo`3oOomDOol00?1oo`03001oogoo08Uoo`03

O01oogoo04]oo`03001oogoo0?mooeAoo`00l7oo00<007ooOol0E7oo0g`0

<Woo00=l07ooOol0Bgoo00<007ooOol0ogooE7oo003`Ool00`00Oomoo`1H

Ool00g`0Oomoo`1lOol00`00Oomoo`14Ool00`00Oomoo`3oOol=Ool00?1o

o`03001oogoo05Yoo`9l02eoo`03O01oogoo04]oo`03001oogoo0?mooeAo

o`00l7oo00<007ooOol0Fgoo0W`0;7oo00=l07ooOol0Bgoo00<007ooOol0

ogooE7oo003`Ool00`00Oomoo`1NOol00g`0Oomoo`1fOol00`00Oomoo`14

Ool00`00Oomoo`3oOol=Ool00?1oo`03001oogoo061oo`9l07Eoo`03001o

ogoo04Aoo`03001oogoo0?moo`eoo`00l7oo00<007ooOol0RGoo00=l07oo

Ool0Bgoo00<007ooOol0ogooE7oo003`Ool00`00Oomoo`1TOol2O01aOol0

0`00Oomoo`14Ool00`00Oomoo`3oOol=Ool00?1oo`03001oogoo0=Moo`03

001oogoo04Aoo`03001oogoo0?moo`eoo`00l7oo00<007ooOol0RGoo00=l

07ooOol0Bgoo00<007ooOol0ogooE7oo003`Ool00`00Oomoo`1ZOol2O00M

Ool00g`0Oomoo`1;Ool00`00Oomoo`14Ool00`00Oomoo`3oOol=Ool00?1o

o`03001oogoo06eoo`03O01oogoo06Moo`03001oogoo04Aoo`03001oogoo

0?moo`eoo`00l7oo00<007ooOol0Kgoo00=l07ooOol05goo00=l07ooOol0

Bgoo00<007ooOol0A7oo00<007ooOol0ogoo3Goo003`Ool00`00Oomoo`1`

Ool2O00FOol2O0000gooO01oo`1:Ool00`00Oomoo`14Ool00`00Oomoo`3o

Ool=Ool00?1oo`03001oogoo07=oo`03O01oogoo019oo`03O01oog`004ao

o`03001oogoo04Aoo`03001oogoo0?moo`eoo`00l7oo00<007ooOol0M7oo

0W`04Woo00=l07ooO000C7oo00<007ooOol0A7oo00<007ooOol0ogoo3Goo

003`Ool00`00Oomoo`1gOol00g`0Oomoo`0>Ool3O01<Ool00`00Oomoo`14

Ool00`00Oomoo`3oOol=Ool00?1oo`03001oogoo07Yoo`03O01oogoo00ao

o`9l04aoo`03001oogoo04Aoo`03001oogoo0?moo`eoo`00l7oo00<007oo

Ool0NWoo00=l07ooOol037oo0W`0C7oo00<007ooOol0A7oo00<007ooOol0

ogoo3Goo002cOol4000=Ool3000POol40005Ool00`00Oomoo`1mOol00g`0

Oomoo`09Ool00g`0Oomoo`1;Ool00`00Oomoo`14Ool00`00Oomoo`3oOol=

Ool00;=oo`8000ioo`04001oogoo000ROol20005Ool00`00Oomoo`20Ool2

O007Ool00`00Oomoo`1;Ool00`00Oomoo`14Ool00`00Oomoo`3oOol=Ool0

0;=oo`03001oogoo00eoo`03001oogoo0080029oo`03001oogoo00=oo`03

001oogoo08Moo`D004]oo`03001oo`0O04Aoo`03001oogoo0?moo`eoo`00

Z7oo1@000Woo00D007ooOomoo`0000Aoo`8000Aoo`800005Ool007oo001o

o`030006Ool00`00Oomoo`02Ool90002Ool20004Ool20004Ool00`00Oomo

o`03Ool00`00Oomoo`23Ool2O002Ool2000017`000000000BWoo00<0000O

01l00P0O@Woo00<007ooOol0ogoo3Goo002XOol20002Ool50002Ool00`00

Oomoo`02Ool20003Ool40002Ool00`00Oomoo`020006Ool00`00Oomoo`02

Ool00`00Oomoo`04Ool20002Ool20003Ool40003Ool00`00Oomoo`03Ool0

0`00Oomoo`26Ool2O00200001G`000007`0OOol00P0O0Woo0P0O00=oo`0O

01l00Woo00<07gooOol00P0O00=oo`0O01l00Woo0P0O00=oo`0O01l00Woo

00<07gooOol097oo0`0O00=oo`0O00001@0O@Goo00<007ooOol0ogoo3Goo

002WOol20004Ool200001Goo001oogoo00001Goo0P000Woo00@007ooOol0

009oo`04001oogoo0007Ool00`00Oomoo`03Ool00`00Oomoo`03Ool20003

Ool20002Ool01000Oomoo`000goo00<007ooOol00goo00<007ooOol0QWoo

0P0000El0000001l0000025oo`807`9oo`0301moogoo00807`03Ool07`0O

009oo`D07`9oo`807`03Ool07`0O009oo`0301moogoo00807`03Ool07`0O

009oo`X07d1oo`03001oogoo0?moo`eoo`00Ygoo0P0017oo0P0017oo00<0

07ooOol00goo0P000Woo00<007ooOol017oo0`001goo00<007ooOol00goo

00<007ooOol00Woo0P0017oo0P000Woo00<007ooOol017oo00<007ooOol0

0Woo0P0000=oo`0000000Woo00<007ooOol00P0000=oo`0000000Woo0P00

00=oo`0000000Woo0P0000=oo`0000000Woo00<007ooOol00P0000=oo`00

00000Woo0P0000=oo`0000000Woo0P0000=oo`0000000Woo00<007ooOol0

0P0000=oo`0000000Woo0P0000=oo`0000000Woo0P0000=oo`0000000Woo

00<007ooOol00P0000=oo`0000000Woo0P0000=oo`0000000Woo0P0000=o

o`0000000Woo0P0000=oo`0000000Woo00<007ooOol00P0000=oo`000000

0Woo0P0000=oo`0000000Woo0P0000=oo`0000000Woo00<007ooOol01000

0W`000<007`0Ool0AWoo2P0O@7oo00<007ooOol0ogoo3Goo002WOol20004

Ool20004Ool00`00Oomoo`04Ool200000goo001oo`0;Ool80003Ool01000

Oomoogoo0P001Goo0P0000=oo`00Ool01Goo00<007ooOol00goo00<007oo

Ool0Qgoo1@000W`0A7oo0P0O00Aoo`0O01l000H07d1oo`03001oogoo0?mo

o`eoo`00Ygoo0P0017oo0P0017oo00<007ooOol017oo0`0047oo0P001Woo

00<007ooOol00P001Woo0`001goo00<007ooOol00goo00<007ooOol0R7oo

0`000goo00=l07ooOol0A7oo0P0O00<0000O01l0100O@7oo00<007ooOol0

ogoo3Goo002XOol00`00Oomoo`03Ool20003Ool00`00Oomoo`05Ool2000A

Ool00`00Oomoo`04Ool00`00Oomoo`020007Ool20007Ool00`00Oomoo`03

Ool00`00Oomoo`2@Ool00g`0Oomoo`13Ool00`0O00007`0401m1Ool00`00

Oomoo`3oOol=Ool00:Qoo`800004Ool00000Ool20003Ool00`00Oomoo`05

Ool2000AOol00`00Oomoo`05Ool01000Ool000001goo0P001goo00<007oo

Ool00goo00<007ooOol0TGoo0g`0@goo00<0000O01l00P0O@Woo00<007oo

Ool0ogoo3Goo002YOol30003Ool01@00Oomoogoo000027oo00<007ooOol0

3goo00<007ooOol01Goo0`002Goo00<007ooOol01Goo00<007ooOol00goo

00<007ooOol0TGoo00=l07ooOol00Woo00=l07ooOol0?Woo00<007ooOol0

A7oo00<007ooOol0ogoo3Goo002cOol00`00Oomoo`02Ool01000Oomoo`00

6goo0P001Goo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo09=o

o`04O01oogooO010Ool00`00Oomoo`14Ool00`00Oomoo`3oOol=Ool00;=o

o`8000=oo`04001oogoo000KOol00`00Oomoo`04Ool01000Oomoo`001goo

0P001Goo00<007ooOol0Tgoo0W`017oo00=l07ooOol0>goo00<007ooOol0

A7oo00<007ooOol0ogoo3Goo002cOol40002Ool3000SOol30005Ool40005

Ool00`00Oomoo`2EOol00g`0Oomoo`03Ool2O00jOol00`00Oomoo`3oOomD

Ool00;Uoo`8002Aoo`8000moo`03001oogoo09Ioo`03O01oogoo00=oo`9l

03Uoo`03001oogoo0?mooeAoo`00l7oo00<007ooOol0Wgoo0W`0=Woo00<0

07ooOol0A7oo00<007ooOol0ogoo3Goo003`Ool00`00Oomoo`2QOol2O00d

Ool00`00Oomoo`14Ool00`00Oomoo`3oOol=Ool00?1oo`03001oogoo09Uo

o`03O01oogoo00Moo`03O01oogoo0?moohQoo`00l7oo00<007ooOol0YGoo

0W`0<7oo00<007ooOol0A7oo00<007ooOol0ogoo3Goo003`Ool00`00Oomo

o`2KOol2O00jOol00`00Oomoo`14Ool00`00Oomoo`3oOol=Ool00?1oo`03

001oogoo09eoo`03O01oogoo0?moohioo`00l7oo00<007ooOol0WWoo00=l

07ooOol02Woo0W`0ogooPGoo003`Ool00`00Oomoo`2OOol00g`0Oomoo`0e

Ool00`00Oomoo`14Ool00`00Oomoo`3oOol=Ool00?1oo`03001oogoo0:1o

o`03O01oogoo00aoo`03O01oogoo02Eoo`03001oogoo04Aoo`03001oogoo

0?moo`eoo`00l7oo00<007ooOol0/Goo0W`0ogooNgoo003`Ool00`00Oomo

o`2SOol00g`0Oomoo`0>Ool2O00QOol00`00Oomoo`13Ool00`00Oomoo`3o

Ool>Ool00?1oo`03001oogoo0:=oo`03O01oogoo00moo`9l021oo`03001o

ogoo04=oo`03001oogoo0?moo`ioo`00l7oo00<007ooOol0^7oo00=l07oo

Ool0ogooLgoo003`Ool00`00Oomoo`2UOol2O00COol2O03oOombOol00?1o

o`03001oogoo0:Moo`03O01oogoo019oo`03O01oogoo01Qoo`03001oogoo

04=oo`03001oogoo0?moo`ioo`00l7oo00<007ooOol0Z7oo00=l07ooOol0

4goo0W`0ogooKWoo003`Ool00`00Oomoo`2YOol00g`0Oomoo`0EOol2O03o

Oom[Ool00>5oo`=l00aoo`03001oogoo0=Moo`03001oogoo04=oo`03001o

ogoo0?moo`ioo`00UGoo0g`0B7oo00Al07ooOoml00aoo`03001oogoo0<Ao

o`9l015oo`03001oogoo04=oo`03001oogoo0?moo`ioo`00U7oo00Al07oo

Ooml04Qoo`03O01oogoo009l00]oo`03001oogoo0<Moo`9l0?moofEoo`00

Qgoo0W`02goo00=l07ooOol00W`087oo00=l07ooOol06Goo0W`02Goo00=l

07ooOol00W`01Goo00=l07ooOol00goo00<007ooOol0[Goo00=l07ooOol0

9Woo00<007ooOol0A7oo00<007ooOol0ogoo3Woo0027Ool00g`0Oomoo`0:

Ool00g`0Oomoo`02O00POol00g`0Oomoo`0IOol00g`0Oomoo`08Ool00g`0

Oomoo`02O005Ool00g`0Oomoo`03Ool00`00Oomoo`3;Ool00g`0Oomoo`02

O006Ool00`00Oomoo`14Ool00`00Oomoo`3oOol>Ool007Eoo`Il00=oo`Al

0003Ooml07`0009oo`04O01oogooOol2O003Ool2O00017ooO01l07oo0g`0

17oo00=l07ooOol00Woo00Al07ooOomoo`Ql0003Ooml07`000=oo`9l00=o

o`03O01oog`000]oo`03O01oogoo009oo`Al0003Ooml07`0009oo`04O01o

ogooOol2O003Ool4O0000gooO01l0005Ool00g`0Oomoo`03Ool00`00Oomo

o`2_Ool2O00LOol2O0000gooO01oo`1;Ool00`00Oomoo`3oOol>Ool007Io

o`05O01oogooOoml0002Ool2O002Ool3O003Ool00g`0Oomoo`02Ool00g`0

Oomoo`04O0001GooO01oogooO0001Goo00=l07ooOol01Woo00=l07ooOol0

0goo0W`00Woo00=l07ooOol017`00Woo00=l07ooOol03goo0W`00Woo0g`0

0goo00=l07ooOol00Woo00=l07ooOol01g`01Woo00=l07ooOol00goo00<0

07ooOol0/Goo00=l07ooOol06Goo00El07ooO01oog`000Aoo`9l04Eoo`03

001oogoo0?moo`ioo`00Mgoo00=l07ooOol00goo0W`00goo0W`00goo00=l

07ooOol00Woo00Al07ooOoml009oo`03O01oogoo00=l00Eoo`03O01oogoo

00Moo`04O01oogooOol2O003Ool017`0Oomoog`00Woo00Al07ooOoml015o

o`9l00=oo`9l00=oo`03O01oogoo009oo`04O01oogooO002Ool00g`0Oomo

o`07Ool00g`0Oomoo`03Ool00`00Oomoo`2bOol00g`0Oomoo`0IOol5O000

0gooO01l0004O013Ool00`00Oomoo`3oOol>Ool007Qoo`03O01oogoo009o

o`9l00=oo`9l00=oo`03O01oogoo009oo`9l0003Ooml07oo00Uoo`Ml00Io

o`04O01oogooOol2O003Ool2O0000gooO01oo`04Ool00g`0Oomoo`03Ool7

O005Ool2O003Ool2O003Ool00g`0Oomoo`02Ool2O0000gooO01oo`0;Ool0

0g`0Oomoo`03Ool00`00Oomoo`2cOol00g`0Oomoo`0MOol7O013Ool00`00

Oomoo`3oOol>Ool007Uoo`04O01oogooOol2O003Ool2O003Ool00g`0Oomo

o`03Ool3O00=Ool00g`0Oomoo`07Ool01G`0OomoogooO0001Goo0g`01Goo

00=l07ooOol03goo0W`00goo0W`00goo00=l07ooOol00goo0g`037oo00=l

07ooOol00goo00<007ooOol00W`000=oog`0O0000Woo0W`000=oog`0O000

0Woo0W`000=oog`0O0000Woo00=l07ooOol00W`000=oog`0O0000Woo0W`0

00=oog`0O0000Woo0W`000=oog`0O0000Woo00=l07ooOol00W`000=oog`0

O0000Woo0W`000=oog`0O0000Woo0W`000=oog`0O0000Woo00=l07ooOol0

0W`000=oog`0O0000Woo0W`000=oog`0O0000Woo0W`000=oog`0O0000Woo

0W`000=oog`0O0000Woo00=l07ooOol00W`000=oog`0O0000Woo0W`000=o

og`0O0000Woo0W`000=oog`0O0000Woo00=l07ooOol00W`000=oog`0O000

0Woo0W`000=oog`0O0000Woo0W`000=oog`0O0000Woo00=l07ooOol00W`0

00=oog`0O0000Woo0W`000=oog`0O0000Woo0W`000=oog`0O0000Woo00=l

07ooOol00W`000Aoog`0O01oo`=l0003Ooml07`0009oo`9l0003Ooml07`0

009oo`03O01oogoo009l0003Ooml07`0009oo`9l0004Ooml07`0Ool6O013

Ool00`00Oomoo`3oOol>Ool007Uoo`04O01oogooOol2O003Ool3O002Ool0

0g`0Oomoo`03Ool3O00=Ool00g`0Oomoo`08Ool017`0Ooml07`01Goo0g`0

1Goo00=l07ooOol03goo0W`00goo0g`00Woo00=l07ooOol00goo0g`037oo

00=l07ooOol00goo00<007ooOol0]Goo00=l07ooOol06goo1g`0@goo00<0

07ooOol0ogoo3Woo001iOol00g`0Oomoo`02Ool4O0000gooO01l0002Ool0

0g`0Oomoo`04Ool00g`0Oomoo`0<Ool00g`0Oomoo`08Ool017`0Ooml07`0

1Woo00=l07ooOol017oo00=l07ooOol047oo17`000=oog`0O0000Woo00=l

07ooOol017oo00=l07ooOol02goo00=l07ooOol00goo00<007ooOol0e7oo

1W`0@goo00<007ooOol0ogoo3Woo001eOol01G`0OomoogooO0003Goo00=l

07ooOol017oo00=l07ooOol037oo00=l07ooOol02Goo0W`01goo00=l07oo

Ool017oo00=l07ooOol06Goo00=l07ooOol017oo00=l07ooOol02goo00=l

07ooOol00goo00<007ooOol0]goo0W`06goo1W`0@goo00<007ooOol0ogoo

3Woo001fOol4O00=Ool01G`0OomoogooO0000Woo00=l07ooOol067oo0W`0

17oo00Al07ooOoml00Ioo`03O01oogoo01Uoo`05O01oogooOoml0002Ool0

0g`0Oomoo`0;Ool00g`0Oomoo`03Ool00`00Oomoo`2iOol00g`0Oomoo`0J

Ool00g`0Oomoo`14Ool00`00Oomoo`3oOol>Ool007Moo`9l00ioo`=l0004

Ooml07`0O00LOol00g`0Oomoo`02Ool3O005Ool3O00KOol3O00017ooO01l

07`037oo0g`01Goo00<007ooOol0^Woo00=l07ooOol0H7oo00<007ooOol0

ogoo3Woo002<Ool2O00ROol2O00XOol2O00DOol00`00Oomoo`2kOol00g`0

Oomoo`0HOol00g`0Oomoo`14Ool00`00Oomoo`3oOol>Ool00?1oo`03001o

ogoo0;aoo`03O01oogoo05ioo`03001oogoo0?moo`ioo`00l7oo00<007oo

Ool0ogoo7Woo00<007ooOol0ogoo3Woo003`Ool00`00Oomoo`2oOol00g`0

Oomoo`0DOol00g`0Oomoo`14Ool00`00Oomoo`3oOol>Ool00?1oo`03001o

ogoo0;moo`03O01oogoo01Aoo`03O01oogoo04Aoo`03001oogoo0?moo`io

o`00l7oo00<007ooOol0ogoo7Woo00<007ooOol0ogoo3Woo003`Ool00`00

Oomoo`31Ool2O00COol00g`0Oomoo`14Ool00`00Oomoo`3oOol>Ool00?1o

o`03001oogoo0<=oo`03O01oogoo011oo`03O01oogoo04Aoo`03001oogoo

0?moo`ioo`00l7oo00<007ooOol0a7oo00=l07ooOol0EWoo00<007ooOol0

ogoo3Woo003`Ool00`00Oomoo`35Ool00g`0Oomoo`1EOol00`00Oomoo`3o

Ool>Ool00?1oo`03001oogoo0<Ioo`9l00ioo`03O01oogoo04Aoo`03001o

ogoo0?moo`ioo`00l7oo00<007ooOol0agoo00=l07ooOol037oo00=l07oo

Ool0ogooEGoo003`Ool00`00Oomoo`3oOolNOol00`00Oomoo`3oOol>Ool0

0?1oo`03001oogoo0<Uoo`9l00]oo`03O01oogoo04Aoo`03001oogoo0?mo

o`ioo`00l7oo00<007ooOol0eWoo00=l07ooOol0ogooEGoo003`Ool00`00

Oomoo`3<Ool00g`0Oomoo`05Ool017`0Oomoog`0ogooEWoo003`Ool00`00

Oomoo`3=Ool00g`0Oomoo`04Ool017`0Oomoog`0AGoo00<007ooOol0ogoo

3Woo003`Ool00`00Oomoo`3>Ool00g`0Oomoo`03Ool017`0Ooml07`0AGoo

00<007ooOol0ogoo3Woo003`Ool00`00Oomoo`3?Ool00g`0Oomoo`03Ool3

O03oOomFOol00;9oo`<003]oo`03001oogoo0=5oo`04O01oogooOol2O016

Ool00`00Oomoo`3oOol>Ool00:=oo`@000Yoo`04001oogoo000[Ool4000<

Ool00`00Oomoo`3AOol017`0Oomoogoo0W`0AWoo00<007ooOol0ogoo3Woo

002SOol2000<Ool00`00Oomoo`02000/Ool2000<Ool00`00Oomoo`3EOol2

O03oOomGOol00:=oo`03001oogoo00]oo`03001oogoo008002eoo`03001o

ogoo00Yoo`03001oogoo0==oo`9l00800?mooeMoo`00V7oo1@000Woo00D0

07ooOomoo`0000=oo`8000Aoo`80009oo`03001oogoo008000Moo`03001o

ogoo00=oo`04001oogooOol70002Ool900000goo00000004Ool200000goo

001oo`0;Ool00`00Oomoo`3BOol60014Ool00`00Oomoo`3oOol?Ool009Qo

o`80009oo`D0009oo`04001oogooOol20003Ool400001Goo001oogoo0000

27oo00<007ooOol027oo00<007ooOol00Woo00@007ooOol000Ioo`800003

Ool0000000=oo`D000aoo`03001oogoo0=9oo`@00003O000000004=oo`03

001oogoo0?moo`moo`00Ugoo0P0017oo0P0000Eoo`00Oomoo`0000Aoo`80

009oo`04001oogoo0002Ool30008Ool00`00Oomoo`09Ool00`00Oomoo`05

Ool00`00Oomoo`03Ool20002Ool20002Ool00`00Oomoo`02000<Ool00`00

Oomoo`3BOol500000g`0001oo`3oOomDOol009Moo`8000Aoo`8000Aoo`03

001oogoo009oo`80009oo`03001oogoo00ioo`03001oogoo00Yoo`03001o

ogoo00Aoo`03001oogoo009oo`8000=oo`80009oo`05001oogooOol0000<

Ool00`00Oomoo`3BOol600000g`0Oomoo`11Ool00`00Oomoo`3oOol?Ool0

09Moo`8000Aoo`8000Aoo`03001oogoo00=oo`800003Ool007oo00]oo`P0

00Uoo`8000Ioo`04001oogooOol20004Ool200000goo001oo`02Ool00`00

Oomoo`0:Ool20002Ool200000goo00000002Ool200000goo00000002Ool0

0`00Oomoo`0200000goo00000002Ool200000goo00000002Ool200000goo

00000002Ool00`00Oomoo`0200000goo00000002Ool200000goo00000002

Ool200000goo00000002Ool00`00Oomoo`0200000goo00000002Ool20000

0goo00000002Ool200000goo00000002Ool00`00Oomoo`020002Ool00`00

Oomoo`0200000goo00000002Ool200000goo00000002Ool200000goo0000

0002Ool00`00Oomoo`0200000goo00000002Ool200000goo00000002Ool2

00000goo00000002Ool00`00Oomoo`0200000goo00000002Ool200000goo

00000002Ool200000goo00000002Ool00`00Oomoo`0200000goo00000002

Ool200000goo00000002Ool200000goo00000002Ool00`00Oomoo`020000

0goo00000002Ool200000goo00000002Ool200000goo0000000400000goo

O01oo`11Ool00`00Oomoo`3oOol?Ool009Moo`8000Aoo`8000Aoo`03001o

ogoo00=oo`<0011oo`8000eoo`03001oogoo00Aoo`03001oogoo008000Eo

o`<000Aoo`03001oogoo00Yoo`03001oogoo0==oo`D00?mooeIoo`00V7oo

00<007ooOol00goo0P000goo00<007ooOol017oo0P004Goo00<007ooOol0

37oo00<007ooOol00goo00<007ooOol00P001Woo0P0017oo00<007ooOol0

2Woo00<007ooOol0e7oo00<007ooOol017oo0W`0ogooDGoo002HOol20000

17oo000007oo0P000goo00<007ooOol017oo0P004Goo00<007ooOol037oo

00<007ooOol017oo00@007oo000000Ioo`8000Aoo`03001oogoo00Yoo`03

001oogoo0?mooaeoo`03001oogoo0?moo`moo`00VGoo0`000goo00D007oo

Oomoo`0000Moo`03001oogoo00moo`03001oogoo00Moo`03001oogoo009o

o`03001oogoo00Aoo`<000Qoo`03001oogoo009oo`03001oogoo00Yoo`03

001oogoo0=ioo`03O01oogoo0?moodeoo`00Xgoo00D007ooOomoo`00009o

o`03001oogoo01Yoo`80009oo`8000Moo`8000Aoo`04001oogoo0005Ool0

0`00Oomoo`0:Ool00`00Oomoo`3OOol00g`0Oomoo`3oOom<Ool00:=oo`80

009oo`04001oogoo000MOol50007Ool00`00Oomoo`03Ool01000Oomoo`00

17oo0P0037oo00<007ooOol0h7oo00=l07ooOol0>Goo00<007ooOol0ogoo

3goo002SOol4000017oo000000007Woo0`003goo0`000Woo100037oo00<0

07ooOol0hGoo00=l07ooOol0>7oo00<007ooOol0ogoo3goo002XOol2000a

Ool2000COol00`00Oomoo`3ROol2O00hOol00`00Oomoo`3oOol?Ool00?1o

o`03001oogoo0>=oo`03O01oogoo03Ioo`03001oogoo0?moo`moo`00l7oo

00<007ooOol0ogoo7Goo00<007ooOol0ogoo3goo003`Ool00`00Oomoo`3U

Ool2O00eOol00`00Oomoo`3oOol?Ool00?1oo`03001oogoo0?mooaeoo`03

001oogoo0?moo`moo`00l7oo00<007ooOol0j7oo00=l07ooOol0<Goo00<0

07ooOol0ogoo3goo003`Ool00`00Oomoo`3XOol2O00bOol00`00Oomoo`3o

Ool?Ool00?1oo`03001oogoo0>Yoo`03O01oogoo02moo`03001oogoo0?mo

o`moo`00l7oo00<007ooOol0jgoo00=l07ooOol0;Woo00<007ooOol0ogoo

3goo003`Ool00`00Oomoo`3/Ool00g`0Oomoo`0]Ool00`00Oomoo`3oOol?

Ool00?1oo`03001oogoo0>eoo`9l02eoo`03001oogoo0?moo`moo`00l7oo

00<007ooOol0ogoo7Goo00<007ooOol0ogoo3goo003`Ool00`00Oomoo`3_

Ool2O00[Ool00`00Oomoo`3oOol?Ool00?1oo`03001oogoo0?mooaeoo`03

001oogoo0?moo`moo`00l7oo00<007ooOol0lWoo00=l07ooOol09goo00<0

07ooOol0ogoo3goo003`Ool00`00Oomoo`3cOol00g`0Oomoo`0VOol00`00

Oomoo`3oOol?Ool00?1oo`03001oogoo0?Aoo`9l02Ioo`03001oogoo0?mo

o`moo`00l7oo00<007ooOol0mGoo00=l07ooOol097oo00<007ooOol0ogoo

3goo003`Ool00`00Oomoo`3oOolMOol00`00Oomoo`3oOol?Ool00?1oo`03

001oogoo0?Moo`9l02=oo`03001oogoo0?moo`moo`00l7oo00<007ooOol0

ogooogoo;goo003`Ool00`00Oomoo`3jOol00g`0Oomoo`3oOolaOol00?1o

o`03001oogoo0?Yoo`03O01oogoo01moo`03001oogoo0?moo`moo`00l7oo

00<007ooOol0o7oo00=l07ooOol07Goo00<007ooOol0ogoo3goo003`Ool0

0`00Oomoo`3mOol00g`0Oomoo`3oOol^Ool00?1oo`03001oogoo0?ioo`03

O01oogoo01]oo`03001oogoo0?moo`moo`00l7oo00<007ooOol0ogoo0W`0

6goo00<007ooOol0ogoo3goo003`Ool00`00Oomoo`3oOoooOol_Ool00?1o

o`03001oogoo0?moo`9oo`9l0?moob]oo`00l7oo00<007ooOol0ogoo7Goo

00<007ooOol0ogoo3goo003`Ool00`00Oomoo`3oOol5Ool00g`0Oomoo`0E

Ool00`00Oomoo`3oOol?Ool00?1oo`03001oogoo0?moo`Ioo`03O01oogoo

0?moobIoo`00l7oo00<007ooOol0ogoo1goo0W`04goo00<007ooOol0ogoo

47oo003`Ool00`00Oomoo`3oOol8Ool00g`0Oomoo`0AOol00`00Oomoo`3o

Ool@Ool00?1oo`03001oogoo0?moo`Uoo`03O01oogoo0?moob=oo`00l7oo

00<007ooOol0ogoo2Woo0W`0ogoo8goo003`Ool00`00Oomoo`3oOolLOol0

0`00Oomoo`3oOol@Ool00?1oo`03001oogoo0?moo`eoo`03O01oogoo00ao

o`03001oogoo0?mooa1oo`00l7oo00<007ooOol0ogoo3Goo00=l07ooOol0

ogoo7goo003`Ool00`00Oomoo`3oOolLOol00`00Oomoo`3oOol@Ool00?1o

o`03001oogoo0?mooa1oo`03O01oogoo00Uoo`03001oogoo0?mooa1oo`00

l7oo00<007ooOol0ogoo4Goo00=l07ooOol0ogoo6goo003`Ool00`00Oomo

o`3oOolBOol00g`0Ooml003oOolJOol00?1oo`03001oogoo0?mooa=oo`03

O01oog`000Ioo`03001oogoo0?mooa1oo`00l7oo00<007ooOol0ogoo4Woo

1G`01Goo00<007ooOol0ogoo47oo001]Ool2O00gOol00g`0Oomoo`0@Ool2

O009Ool3O00TOol00g`0Oomoo`02Ool00`00Oomoo`3oOolDOol2O0000goo

O01oo`03Ool00`00Oomoo`3oOol@Ool006eoo`03O01oogoo00aoo`=l02Mo

o`03O01oogoo011oo`03O01oogoo00Moo`04O01oogooO00TOol00g`0Oomo

o`02Ool00`00Oomoo`3oOolFOol2O004Ool00`00Oomoo`3oOol@Ool005ao

o`Il009oo`Al0003Ooml07`0009oo`04O01oogooOol2O003Ool2O0001Goo

O01oog`0Ool00W`017oo00=l07ooOol00Woo00Al07ooOomoo`Il0003Ooml

07`000Il0003Ooml07`000=oo`9l00=oo`04O01oogooO00;Ool01G`0Oomo

ogooO0000goo0W`00goo0W`000Ioog`0O01l07ooO005Ool00g`0Oomoo`02

Ool017`0Oomoogoo27`000=oog`0O0000goo0W`00goo00=l07ooOol00Woo

00<007ooOol0ogoo6goo00=l0000O000ogoo4Goo001MOol01W`0Oomoogoo

O01oo`9l009oo`=l00=oo`03O01oogoo009oo`03O01oogoo00Al009oo`03

O01oogoo009l00=oo`03O01oogoo00Moo`07O01oogooOoml07ooO0001Goo

0W`00Woo00=l07ooOol017`00Woo00=l07ooOol047oo00=l07ooOol00Woo

00=l07ooOol017`000=oog`0O0001goo00=l07ooOol01Woo00=l07ooOol0

0goo0W`00Woo00=l07ooOol017`00Woo00=l07ooOol00Woo00<007ooOol0

ogoo6Woo0W`000@007`0O01l0?moo`moo`00GWoo00=l07ooOol00Woo0W`0

0goo0W`00goo00=l07ooOol00Woo00Al07ooOoml009oo`04O01oogooO002

Ool2O003Ool00g`0Oomoo`08Ool00g`0Oomoo`03Ool017`0Oomoogoo0W`0

0goo00Al07ooOoml009oo`04O01oogooO00BOol00g`0Oomoo`02Ool01G`0

Oomoog`0Ool00W`000=oog`0O0001goo00=l07ooOol01goo00Al07ooOomo

o`9l00=oo`04O01oogooO002Ool017`0Oomoog`017oo00<007ooOol0ogoo

6Goo1g`0ogoo3goo001OOol017`0Oomoogoo0W`00goo0W`00goo00=l07oo

Ool00Woo0W`000=oog`0Ool017oo00=l07ooOol02G`027oo00=l07ooOol0

0Woo00Al07ooOomoo`9l00=oo`9l0003Ooml07oo00Aoo`03O01oogoo00Ao

o`Ml00Eoo`03O01oogoo009oo`9l0004Ooml07ooO002Ool00g`0Oomoo`03

Ool7O006Ool017`0Oomoogoo0W`00goo0W`000=oog`0Ool017oo00=l07oo

Ool00Woo00<007ooOol0ogoo6Goo1g`0ogoo3goo001POol00g`0Oomoo`02

O003Ool2O003Ool00g`0Oomoo`03Ool3O005Ool017`0Oomoog`017oo00=l

07ooOol02Woo00El07ooOomoog`000=oo`03O01oogoo00=oo`=l00Eoo`03

O01oogoo011oo`03O01oogoo00=oo`=l009oo`=l00Qoo`03O01oogoo00Mo

o`05O01oogooOoml0005Ool3O005Ool00g`0Oomoo`02Ool00`00Oomoo`2b

Ool2O002Ool2O0000gooO01l0002Ool2O0000gooO01l0002Ool00g`0Oomo

o`02O0000gooO01l0002Ool2O0000gooO01l0002Ool2O0000gooO01l0002

Ool00g`0Oomoo`02O0000gooO01l0002Ool2O0000gooO01l0002Ool2O000

0gooO01l0002Ool2O0000gooO01l0002Ool00g`0Oomoo`02O0000gooO01l

0002Ool2O0000gooO01l0002Ool2O0000gooO01l0002Ool00g`0Oomoo`09

O03oOol?Ool0061oo`03O01oogoo009l00=oo`=l009oo`03O01oogoo00=o

o`=l00Ioo`=l00Aoo`03O01oogoo00Yoo`03O01oogoo009oo`04O01oog`0

O005Ool3O005Ool00g`0Oomoo`0@Ool00g`0Oomoo`03Ool3O00=Ool00g`0

Oomoo`08Ool017`0Ooml07`01Goo0g`01Goo00=l07ooOol00Woo00=l07oo

Ool00W`000=oog`0O0000Woo0W`000=oog`0O0000Woo0W`000=oog`0O000

0Woo00=l07ooOol00W`000=oog`0O0000Woo0W`000=oog`0O0000Woo0W`0

00=oog`0O0000Woo00=l07ooOol00W`000=oog`0O0000Woo0W`000=oog`0

O0000Woo0W`000=oog`0O0000Woo00=l07ooOol00W`000=oog`0O0000Woo

0W`000=oog`0O0000Woo0W`000=oog`0O0000Woo0W`000=oog`0O0000Woo

00=l07ooOol00W`000=oog`0O0000Woo0W`000=oog`0O0000Woo0W`000=o

og`0O0000Woo00=l07ooOol00W`000=oog`0O0000Woo0W`000=oog`0O000

0Woo0W`000=oog`0O0000Woo00=l07ooOol00W`000=oog`0O0000Woo0W`0

00=oog`0O0000Woo0W`000=oog`0O0000Woo00=l07ooOol0JGoo1g`0ogoo

3goo001POol017`0Oomoogoo17`000=oog`0O0000Woo00=l07ooOol017oo

00=l07ooOol037oo00=l07ooOol02Woo00=l07ooOol00Woo00Al07ooO01l

00Ioo`03O01oogoo00Aoo`03O01oogoo011oo`03O01oogoo00Aoo`03O01o

ogoo00aoo`03O01oogoo00Qoo`04O01oog`0O006Ool00g`0Oomoo`04Ool0

0g`0Oomoo`02Ool01000Ooml07`0ogoo6Goo1G`0ogoo47oo001LOol01G`0

OomoogooO00037oo00=l07ooOol017oo00=l07ooOol037oo00=l07ooOol0

1Woo00El07ooOomoog`000Eoo`9l00Moo`03O01oogoo00Aoo`03O01oogoo

011oo`03O01oogoo00Aoo`03O01oogoo00aoo`03O01oogoo00Uoo`9l00Mo

o`03O01oogoo00Aoo`03O01oogoo009oo`03001oogoo0?mooaaoo`03O01o

ogoo0?mooa1oo`00GGoo17`037oo00El07ooOomoog`0009oo`03O01oogoo

01Ioo`Al00Eoo`9l00Aoo`04O01oogooO006Ool00g`0Oomoo`0@Ool01G`0

OomoogooO0000Woo00=l07ooOol067oo0W`017oo00Al07ooOoml00Ioo`03

O01oogoo009oo`03001oogoo0?mooaaoo`03O01oogoo0?mooa1oo`00GWoo

0W`03Goo0g`000Aoog`0O01l01Yoo`9l00Moo`03O01oogoo009oo`=l00Eo

o`=l019oo`=l0004Ooml07`0O00LOol00g`0Oomoo`02Ool3O005Ool3O004

Ool00`00Oomoo`3oOolLOol00g`0Oomoo`3oOol@Ool0079oo`9l02Uoo`9l

01moo`9l029oo`9l00aoo`03001oogoo0?mooaaoo`03O01oogoo0?mooa1o

o`00l7oo00<007ooOol0ogoo77oo00=l07ooOol0ogoo47oo003`Ool00`00

Oomoo`3oOolLOol00g`0Oomoo`3oOol@Ool00?1oo`03001oogoo0?mooaao

o`03O01oogoo0?mooa1oo`00l7oo00<007ooOol0ogoo77oo00=l07ooOol0

ogoo47oo003`Ool00`00Oomoo`3oOolLOol00g`0Oomoo`3oOol@Ool00?1o

o`03001oogoo0?mooaaoo`03O01oogoo0?mooa1oo`00l7oo00<007ooOol0

ogoo77oo00=l07ooOol0ogoo47oo003`Ool00`00Oomoo`3oOolLOol00g`0

Oomoo`3oOol@Ool00?1oo`03001oogoo0?mooaaoo`03O01oogoo0?mooa1o

o`00l7oo00<007ooOol0ogoo77oo00=l07ooOol0ogoo47oo003`Ool00`00

Oomoo`3oOolLOol00g`0Oomoo`3oOol@Ool00?1oo`03001oogoo0?mooaao

o`03O01oogoo0?mooa1oo`00l7oo00<007ooOol0ogoo77oo00=l07ooOol0

ogoo47oo003`Ool00`00Oomoo`3oOolLOol00g`0Oomoo`3oOol@Ool00?1o

o`03001oogoo0?mooaaoo`03O01oogoo0?mooa1oo`00l7oo00<007ooOol0

ogoo77oo00=l07ooOol0ogoo47oo003`Ool00`00Oomoo`3oOolLOol00g`0

Oomoo`3oOol@Ool00?1oo`03001oogoo0?mooaaoo`03O01oogoo0?mooa1o

o`00l7oo00<007ooOol0ogoo77oo00=l07ooOol0ogoo47oo003`Ool00`00

Oomoo`3oOolLOol00g`0Oomoo`3oOol@Ool00?1oo`03001oogoo0?mooaao

o`03O01oogoo0?mooa1oo`00l7oo00<007ooOol0ogoo77oo00=l07ooOol0

ogoo47oo003`Ool00`00Oomoo`3oOolLOol00g`0Oomoo`3oOol@Ool00?1o

o`03001oogoo0?mooaaoo`03O01oogoo0?mooa1oo`00l7oo00<007ooOol0

ogoo77oo00=l07ooOol0ogoo47oo003`Ool00`00Oomoo`3oOolLOol00g`0

Oomoo`3oOol@Ool00?1oo`03001oogoo0?mooaaoo`03O01oogoo0?mooa1o

o`00l7oo00<007ooOol0ogoo77oo00=l07ooOol0ogoo47oo003`Ool00`00

Oomoo`3oOolLOol00g`0Oomoo`3oOol@Ool00?1oo`03001oogoo0?mooaao

o`03O01oogoo0?mooa1oo`00l7oo00<007ooOol0ogoo77oo00=l07ooOol0

ogoo47oo003`Ool00`00Oomoo`3oOolLOol00g`0Oomoo`3oOol@Ool00?1o

o`03001oogoo0?mooaYoo`05O01oog`0Ooml003oOol@Ool00?1oo`03001o

ogoo0?mooa]oo`9l0003Ooml07oo0?moo`moo`00Ygoo1000?Goo100017oo

00<007ooOol0ogoo6goo0g`0ogoo4Goo002WOol20011Ool20004Ool00`00

Oomoo`3oOolKOol3O03oOolAOol00:Moo`03001oogoo00aoo`<0039oo`03

001oogoo009oo`03001oogoo0?mooa]oo`=l0?mooa5oo`00W7oo1@000Woo

00D007ooOomoo`0000Aoo`8000Aoo`800004Ool007ooOol20008Ool00`00

Oomoo`02Ool00`00Oomoo`02Ool40004Ool900000goo00000004Ool20005

Ool00`00Oomoo`02Ool00`00Oomoo`3oOolLOol2O03oOolAOol009aoo`80

009oo`D0009oo`03001oogoo009oo`8000=oo`D0009oo`8000Qoo`03001o

ogoo00Moo`05001oogooOol00003Ool00`00Oomoo`04Ool200000goo0000

0003Ool40004Ool00`00Oomoo`02Ool00`00Oomoo`3oOolKOol00`00O000

003oOolAOol009]oo`8000Aoo`800005Ool007ooOol00005Ool20002Ool0

0`00Oomoo`020002Ool20008Ool00`00Oomoo`0;Ool20003Ool00`00Oomo

o`03Ool20002Ool20002Ool01000Oomoo`0017oo00<007ooOol00Woo00<0

07ooOol0ogoo6Goo0`0000Al000000000?moo`moo`00Vgoo0P0017oo0P00

17oo00<007ooOol00goo0P000Woo00D007ooOomoo`00009oo`8000Qoo`03

001oogoo00]oo`8000=oo`03001oogoo009oo`8000=oo`80009oo`03001o

ogoo00Eoo`03001oogoo009oo`03001oogoo0?mooaUoo`L00?moo`moo`00

Vgoo0P0017oo0P0017oo00<007ooOol017oo0P0000=oo`00Ool00Woo00@0

07ooOol000Eoo`P000Yoo`8000Aoo`04001oogooOol20004Ool200000goo

001oo`06Ool00`00Oomoo`02Ool20002Ool200000goo00000002Ool20000

0goo00000002Ool00`00Oomoo`0200000goo00000002Ool200000goo0000

0002Ool200000goo00000002Ool00`00Oomoo`0200000goo00000002Ool2

00000goo00000002Ool200000goo00000002Ool00`00Oomoo`0200000goo

00000002Ool200000goo00000002Ool200000goo00000002Ool00`00Oomo

o`020002Ool00`00Oomoo`0200000goo00000002Ool200000goo00000002

Ool200000goo00000002Ool00`00Oomoo`0200000goo00000002Ool20000

0goo00000002Ool200000goo00000002Ool00`00Oomoo`0200000goo0000

0002Ool200000goo00000002Ool200000goo00000002Ool00`00Oomoo`02

00000goo00000002Ool200000goo00000002Ool200000goo00000002Ool0

0`00Oomoo`0200000goo00000002Ool200000goo00000002Ool200000goo

00000002Ool00`00Oomoo`0200000goo00000002Ool200000goo00000002

Ool200000goo00000002Ool200000goo00000002Ool00`00Oomoo`020000

0goo00000002Ool200000goo00000002Ool200000goo00000002Ool00`00

Oomoo`0200000goo00000002Ool9003oOol>Ool009]oo`8000Aoo`8000Ao

o`03001oogoo00Aoo`<000Eoo`<000Qoo`8000Yoo`@000Eoo`03001oogoo

008000Eoo`<000Qoo`03001oogoo009oo`03001oogoo0?mooaQoo`T00?mo

o`ioo`00W7oo00<007ooOol00goo0P000goo00<007ooOol01Goo0P004Goo

00<007ooOol02Goo0P001Woo00<007ooOol00P001Woo0P0027oo00<007oo

Ool00Woo00<007ooOol0ogoo67oo2@00ogoo3Woo002LOol2000017oo0000

07oo0P000goo00<007ooOol01Goo0P004Goo00<007ooOol02Woo00<007oo

Ool01Goo00@007oo000000Ioo`8000Qoo`03001oogoo009oo`03001oogoo

0?mooaUoo`L00?moo`moo`00WGoo0`000goo00D007ooOomoo`0000Qoo`03

001oogoo00moo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo00Ao

o`<000Qoo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo0?mooaUo

o`L00?moo`moo`00Ygoo00<007ooOol00Woo00@007ooOol001]oo`04001o

ogooOol20007Ool20004Ool01000Oomoo`002Goo00<007ooOol00Woo00<0

07ooOol0ogoo6goo1000ogoo47oo002WOol20003Ool01000Oomoo`0077oo

1@001goo00<007ooOol00goo00@007ooOol000Qoo`8000Aoo`03001oogoo

0?mooomoobmoo`00Ygoo10000Woo0`007Goo0`003goo0`001Woo100017oo

00<007ooOol0ogooogoo;goo002]Ool2000`Ool2000?Ool00`00Oomoo`3o

OoooOol_Ool00?1oo`03001oogoo0?mooomoobmoo`00l7oo00<007ooOol0

ogooogoo;goo003`Ool00`00Oomoo`3oOoooOol_Ool00?1oo`03001oogoo

0?mooomoobmoo`00l7oo00<007ooOol0ogooogoo;goo003`Ool00`00Oomo

o`3oOoooOol_Ool00?1oo`03001oogoo0?mooomoobmoo`00l7oo00<007oo

Ool0ogooogoo;goo003`Ool00`00Oomoo`3oOoooOol_Ool00?1oo`03001o

ogoo0?mooomoobmoo`00l7oo00<007ooOol0ogooogoo;goo003`Ool00`00

Oomoo`3oOoooOol_Ool00?1oo`03001oogoo0?mooomoobmoo`00l7oo00<0

07ooOol0ogooogoo;goo003`Ool00`00Oomoo`3oOoooOol_Ool00?1oo`03

001oogoo0?mooomoobmoo`00l7oo00<007ooOol0ogooogoo;goo003`Ool0

0`00Oomoo`3oOoooOol_Ool00?1oo`03001oogoo0?mooomoobmoo`00l7oo

00<007ooOol0ogooogoo;goo003`Ool00`00Oomoo`3oOoooOol_Ool00?1o

o`03001oogoo0?mooomoobmoo`00l7oo00<007ooOol0ogooogoo;goo003`

Ool00`00Oomoo`3oOoooOol_Ool00?1oo`03001oogoo0?mooomoobmoo`00

l7oo00<007ooOol0ogooogoo;goo003`Ool00`00Oomoo`3oOoooOol_Ool0

0?1oo`03001oogoo0?mooomoobmoo`00l7oo00<007ooOol0ogooogoo;goo

003]Ool01000Oomoo`000goo00<007ooOol0ogooogoo:goo003]Ool01000

Oomoo`000goo00<007ooOol0ogooogoo:goo003]Ool01000Oomoo`000Woo

00<007ooOol0ogooogoo;7oo003^Ool00`00Ool00002Ool00`00Oomoo`3o

OoooOol/Ool00>ioo`03001oo`00009oo`03001oogoo0?mooomoobaoo`00

kWoo00<007oo00000Woo00<007ooOol0ogooogoo;7oo003^Ool01@00Ool0

07oo0000ogooogoo;goo003_Ool200000goo001oo`3oOoooOol^Ool00>mo

o`800003Ool007oo0?mooomoobioo`00kgoo0P0000=oo`00Ool0ogooogoo

;Woo003_Ool3003oOoooOol`Ool00?1oo`800?mooomooc1oo`00l7oo0P00

ogooogoo<7oo003`Ool2003oOoooOol`Ool00?1oo`03001oogoo0?mooomo

obmoo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=o

o`00ogooogooogoo8goo003_Ool50003Ool2003oOoooOolYOol00>ioo`<0

009oo`800004Ool00000003oOoooOolYOol00>eoo`<000Aoo`<00?mooomo

ob]oo`00kGoo0`0017oo0`00ogooogoo:goo003]Ool20005Ool3003oOooo

Ool[Ool00>eoo`8000Ioo`800?mooomoob]oo`00kGoo0P001Woo0`00ogoo

ogoo:Woo003]Ool30004Ool4003oOoooOolZOol00>ioo`8000Aoo`04001o

o`00003oOoooOolZOol00>moo`800005Ool00000001oo`02003oOoooOolZ

Ool00?1oo`@000=oo`03001oogoo0?mooomoobQoo`00ogooogooogoo8goo

003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003o

OoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOooo

OoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOooo

OolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolS

Ool00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol0

0?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mo

oomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomo

oomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomo

ob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=o

o`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00

ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogoo

ogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogoo

ogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo

8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo

003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003o

OoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOooo

OoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOooo

OolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolS

Ool00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol0

0?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mo

oomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomo

oomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomo

ob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=o

o`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00

ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogoo

ogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogoo

ogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo

8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo

003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003o

OoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOooo

OoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOooo

OolSOol00001\

\>"], "Graphics",

  ImageSize->{800, 600},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  ImageCacheContents->"Empty"]

}, Open  ]],



Cell[TextData[StyleBox[

"We \"march\" along in this way, obtaining a branch of solutions \[Alpha](\

\[Lambda]).\n\nNow we come back to the question of how  one calculates the \

initial iterate to \nget the first point on a branch of solutions? This is \

done by looking for a solution\nnear an eigenvalue of the \"linearized\" \

problem, since it is well known [1] that\nif a branch of solutions exist for \

the nonlinear problem, it must bifurcate from\nthe \"trival\" solution at a \

value of \[Lambda] near an eigenvalue of the \"linearized problem.\nThis idea \

will be illustrated in the next section.",

  FontSize->16]], "Input",

  PageWidth->WindowWidth,

  FormatType->TextForm]

}, Open  ]],



Cell[CellGroupData[{



Cell[TextData[StyleBox["2 The Buckled Plate on an Elastic Foundation",

  FontSize->18]], "Section",

  FontFamily->"Times New Roman"],



Cell[GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000<P0002F1000`40O003

h00Oogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00

ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogoo

ogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogoo

ogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo

8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo

003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003o

OoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOooo

OoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOooo

OolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolS

Ool00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol0

0?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mo

oomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomo

oomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomo

ob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=o

o`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00

ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogoo

ogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogoo

ogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo

8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo

003oOoooOoooOolSOol00?moofQoo`8001=oo`03001oogoo0?mooj9oo`00

ogoo8Woo00<007ooOol05Goo00<007ooOol04goo0P005Goo0P004goo0P00

4goo0P003goo0P004Woo0P00ogooJWoo003oOolQOol2000FOol2000DOol2

000EOol2000COol2000COol2000?Ool2000BOol2000AOol2000AOol00`00

Oomoo`0>Ool2000>Ool00`00Oomoo`0=Ool00`00Oomoo`3oOolCOol00?mo

ob1oo`8001Ioo`8001Aoo`8001Eoo`8001=oo`8001=oo`8000moo`80019o

o`80015oo`80015oo`8000moo`8000ioo`8000ioo`800?mooaEoo`00ogoo

7goo0P005Woo0P0057oo0P005Goo0P004goo0P004goo0P003goo0P004Woo

0P004Goo0P004Goo0P003goo0P003Woo0P003Woo0P00ogoo5Woo003oOolN

Ool2000FOol2000DOol2000EOol2000COol2000COol2000?Ool2000BOol2

000AOol2000AOol2000?Ool2000>Ool2000>Ool2003oOolGOol00?mooaeo

o`8001Ioo`8001Aoo`8001Eoo`8001=oo`8001=oo`8000moo`80019oo`80

015oo`80015oo`8000moo`8000ioo`8000ioo`800?mooaQoo`00ogoo77oo

0P005Woo0P0057oo0P005Goo0P004goo0P004goo0P003goo0P004Woo0P00

4Goo0P004Goo0P003goo0P003Woo0P003Woo0P00ogoo6Goo003oOolKOol2

000FOol2000DOol2000EOol2000COol2000COol2000?Ool2000BOol2000A

Ool2000AOol2000?Ool2000>Ool2000>Ool2003oOolJOol00?mooaYoo`80

01Ioo`8001Aoo`8001Eoo`8001=oo`8001=oo`8000moo`80019oo`80015o

o`80015oo`8000moo`8000ioo`8000ioo`800?mooa]oo`00ogoo6Goo0P00

5Woo0P0057oo0P005Goo0P004goo0P004goo0P003goo0P004Woo0P004Goo

0P004Goo0P003goo0P003Woo0P003Woo0P00ogoo77oo003oOolHOol2000F

Ool2000DOol2000EOol2000COol2000COol2000?Ool2000BOol2000AOol2

000AOol2000?Ool2000>Ool2000>Ool2003oOolMOol00?mooaMoo`8001Io

o`8001Aoo`8001Eoo`8001=oo`8001=oo`8000moo`80019oo`80015oo`80

015oo`8000moo`8000ioo`8000ioo`800?mooaioo`00ogoo5Woo0P005Woo

0P0057oo0P005Goo0P004goo0P004goo0P003goo0P004Woo0P004Goo0P00

4Goo0P003goo0P003Woo0P003Woo0P00ogoo7goo003oOolEOol2000FOol2

000DOol2000EOol2000COol2000COol2000?Ool2000BOol2000AOol2000A

Ool2000?Ool2000>Ool2000>Ool2003oOolPOol00?mooaAoo`8001Ioo`80

01Aoo`8001Eoo`8001=oo`8001=oo`8000moo`80019oo`80015oo`80015o

o`8000moo`8000ioo`8000ioo`800?moob5oo`00ogoo4goo0P005Woo0P00

57oo0P005Goo0P004goo0P004goo0P003goo0P004Woo0P004Goo0P004Goo

0P003goo0P003Woo0P003Woo0P00ogoo8Woo003oOolBOol2000FOol2000D

Ool2000EOol2000COol2000COol2000?Ool2000BOol2000AOol2000AOol2

000?Ool2000>Ool2000>Ool2003oOolSOol00?mooa5oo`8001Ioo`8001Ao

o`8001Eoo`8001=oo`8001=oo`8000moo`80019oo`80015oo`80015oo`80

00moo`8000ioo`8000ioo`800?moobAoo`00ogoo47oo0P005Woo0P0057oo

0P005Goo0P004goo0P004goo0P003goo0P004Woo0P004Goo0P004Goo0P00

3goo0P003Woo0P003Woo0P00ogoo9Goo003oOol?Ool2000FOol2000DOol2

000EOol2000COol2000COol2000?Ool2000BOol2000AOol2000AOol2000?

Ool2000>Ool2000>Ool2003oOolVOol00?moo`ioo`8001Ioo`8001Aoo`80

01Eoo`8001=oo`8001=oo`8000moo`80019oo`80015oo`80015oo`8000mo

o`8000ioo`8000ioo`800?moobMoo`00ogoo3Goo0P005Woo0P0057oo0P00

5Goo0P004goo0P004goo0P003goo0P004Woo0P004Goo0P004Goo0P003goo

0P003Woo0P003Woo0P00ogoo:7oo003oOol<Ool2000FOol2000DOol2000E

Ool2000COol2000COol2000?Ool2000BOol2000AOol2000AOol2000?Ool2

000>Ool2000>Ool2003oOolYOol00?moo`]oo`8001Ioo`8001Aoo`8001Eo

o`8001=oo`8001=oo`8000moo`80019oo`80015oo`80015oo`8000moo`80

00ioo`8000ioo`800?moobYoo`00ogoo2Woo0P005Woo0P0057oo0P005Goo

0P004goo0P004goo0P003goo0P004Woo0P004Goo0P004Goo0P003goo0P00

3Woo0P003Woo0P00ogoo:goo003nOol_000:Ool00`00Oomoo`0YOol00`00

Oomoo`0BOol00`00Oomoo`0>Ool00`00Oomoo`0AOol00`00Oomoo`0?Ool2

000AOol2000?Ool2000>Ool2000>Ool2003oOol/Ool00?moo`Uoo`03001o

ogoo01Eoo`03001oogoo00Yooa<0000301l0000002P0000301l0000002<0

000301l007oo01]oo`05001oogooOol07`0=Ool2000@Ool00`00Oomoo`0<

Ool2000>Ool2003oOol]Ool00?mood5oo`0301moogoo02Qoo`0301moogoo

02=oo`0301moo`0001l0000301l0000004@00?moobMoo`00ogoo@Goo00<0

7gooOol0:7oo00<07gooOol08goo00<07gooOol07goo00<07gooOol08Goo

00<07gooOol087oo3000ogoo6goo003oOom1Ool00`0OOomoo`0XOol00`0O

Oomoo`0SOol00`0OOomoo`0OOol00`0OOomoo`0QOol00`0OOomoo`3oOom7

Ool00?mood5oo`0301moogoo02Qoo`0301moogoo02=oo`0301moogoo01mo

o`0301moogoo025oo`0301moogoo0?moodMoo`00ogoo@Goo00<07gooOol0

:7oo00<07gooOol08goo00<07gooOol07goo00<07gooOol08Goo00<07goo

Ool0ogooAgoo003oOom1Ool00`0OOomoo`0XOol00`0OOomoo`0SOol00`0O

Oomoo`0OOol00`0OOomoo`0QOol00`0OOomoo`3oOom7Ool00?mood5oo`03

01moogoo02Qoo`0301moogoo02=oo`0301moogoo01moo`0301moogoo025o

o`0301moogoo0?moodMoo`00ogoo@Goo00<07gooOol0:7oo0`0O97oo00<0

7gooOol07Woo00<07gooOol08Goo00<07gooOol0ogooAgoo003oOom1Ool0

0`0OOomoo`0WOol00`0OOomoo`0201lSOol00`0OOomoo`0NOol00`0OOomo

o`0QOol00`0OOomoo`3oOom7Ool00?mood5oo`0301moogoo02Yoo`0401mo

o`0O01lQOol00`0OOomoo`0NOol00`0OOomoo`0QOol00`0OOomoo`3oOom7

Ool00?mood9oo`0301moogoo02eoo`807amoo`0301moogoo01ioo`0301mo

ogoo025oo`0301moogoo0?moodMoo`00ogoo@goo0P0O;goo0`0O77oo00<0

7gooOol07Woo00<07gooOol0ogooJgoo003oOom5Ool201l`Ool201lJOol0

0`0OOomoo`0NOol00`0OOomoo`0POol201ooOom9Ool00?moodMoo`0301mo

ogoo02moo`807aQoo`807amoo`0301moogoo01eoo`<07omood]oo`00ogoo

B7oo0P0O<Goo0`0O5goo100O6goo00<07goo01l01@0O5Goo0`0OogooCWoo

003oOom9Ool201l/Ool601lLOol301lPOol501l=Ool301ooOomAOol00?mo

od5oo`P07bQoo`H07bEoo`@07b1oo`807`Moo`807`03Ool07`0O0?mooeAo

o`00ogoo>Woo1`0O:Woo1P0O;goo0P0O77oo0P0O2Woo1P0OogooDWoo003o

OolhOol201l[Ool601l`Ool501lKOol301lBOol501ooOom=Ool00?moocYo

o`<07bMoo`@07bmoo`@07aeoo`<07aYoo`D07omoodQoo`00ogoo?Goo0P0O

:Goo100O9goo100O7Woo0`0O8Woo100OogooA7oo003oOoloOol301lZOol4

01lOOol401lOOol301lYOol201ooOom2Ool00?mood9oo`807baoo`@07aUo

o`807b1oo`<07bMoo`D07omoodAoo`00ogooA7oo0P0O;Woo100O5goo0`0O

77oo0`0O8goo1@0OogooBGoo003oOom6Ool301l_Ool401lFOol301lLOol6

01lHOol501ooOom>Ool00?moodUoo`807bioo`@07aQoo`<07amoo`D07`io

o`D07omooe=oo`00ogooAWoo1@0O:Woo100O7goo0`0O8Goo1@0O2Goo00<0

7gooOol0ogooEGoo003oOom0Ool601lZOol501lVOol301l2Ool00`0OOomo

o`0NOol201l8Ool401ooOomCOol00?mooc]oo`D07baoo`@07b]oo`D07aeo

o`@07`ioo`@07omoodmoo`00ogoo>7oo0`0O;7oo1@0O:Woo1@0O7Woo100O

5Woo1@0OogooBWoo003oOolhOol301l[Ool301lXOol501lOOol401lOOol4

01ooOom6Ool00?mooc]oo`<07b]oo`@07b1oo`@07b1oo`@07omoofeoo`00

ogoo?Woo100O:goo100O77oo100O7Goo0`0O:7oo1@0OogooA7oo003oOom2

Ool301l/Ool401lLOol501lHOol401lSOol401ooOom9Ool00?moodEoo`@0

7baoo`D07aaoo`D07aMoo`<07a]oo`D07omoodeoo`00ogooBGoo00<07goo

Ool0;Woo0P0O7goo1@0O5Goo0`0O57oo100OogooDWoo003oOom8Ool201l]

Ool301lVOol00`0OOomoo`0EOol301l?Ool201ooOomFOol00?mood=oo`D0

7baoo`<07bMoo`<07aYoo`<07`aoo`@07omooeAoo`00ogoo?goo100O;Woo

0`0O9Woo100O87oo0`0O3Goo0`0OogooDGoo003oOolhOol201l00goo01l0

7`0201l^Ool401lUOol401lROol401lAOol401ooOom=Ool00?moocQoo`<0

7bmoo`<07bEoo`@07b9oo`@07aUoo`@07omoodUoo`00ogoo>goo0P0O:Woo

0`0O97oo100O8Woo100O8Goo1`0Oogoo@Woo003oOolmOol201lWOol0100O

Ool07`0O8goo00<07gooOol087oo100O9Goo1@0OogooA7oo003oOoloOol0

100OOomoo`0O9goo0P0O8Woo0P0O7goo00<07gooOol08Woo1@0OogooBGoo

003oOom0Ool301lYOol201l3Ool00`0OOomoo`0LOol201lNOol201lKOol7

01ooOom>Ool00?mood9oo`0301moogoo02Uoo`@07b1oo`807aioo`807aQo

o`<07`03Ool07`0O0?mooe1oo`00ogoo@Woo00<07gooOol0;7oo00<07goo

Ool087oo0`0O7Goo00<07gooOol06goo0`0OogooCGoo003oOom2Ool00`0O

Oomoo`0/Ool00`0OOomoo`0ROol00`0OOomoo`0LOol201l00goo01moo`0K

Ool00`0OOol07`3oOom:Ool00?mood9oo`0301moogoo02aoo`0301moogoo

029oo`0301moogoo01moo`0301moogoo01aoo`0301moogoo0?moodQoo`00

ogoo@Woo00<07gooOol0;7oo00<07gooOol08Woo00<07gooOol07goo00<0

7gooOol077oo00<07gooOol0ogooB7oo003oOom2Ool00`0OOomoo`0/Ool0

0`0OOomoo`0ROol00`0OOomoo`0OOol00`0OOomoo`0LOol00`0OOomoo`3o

Oom8Ool00?mood9oo`0301moogoo02aoo`0301moogoo029oo`0301moogoo

01moo`0301moogoo01aoo`0301moogoo0?moodQoo`00ogoo@Woo00<07goo

Ool0;7oo00<07gooOol08Woo00<07gooOol07Woo00<07gooOol07Goo00<0

7gooOol0ogooB7oo003oOom2Ool00`0OOomoo`0/Ool00`0OOomoo`0ROol0

0`0OOomoo`0NOol00`0OOomoo`0MOol00`0OOomoo`3oOom8Ool00?mood9o

o`0301moogoo02aoo`0301moogoo029oo`0301moogoo01ioo`0301moogoo

01eoo`0301moogoo0?moodQoo`00ogoo@Woo00<07gooOol0;7oo00<07goo

Ool08Woo00<07gooOol07Woo00<07gooOol07Goo00<07gooOol0ogooB7oo

003oOom1Ool00`0OOomoo`0]Ool00`0OOomoo`0ROol00`0OOomoo`0NOol0

0`0OOomoo`0MOol00`0OOomoo`3oOom8Ool00?mood5oo`0301moogoo02eo

o`0301moogoo029oo`0301moogoo01ioo`0301moogoo01eoo`0301moogoo

0?moodQoo`00ogoo;7oo7000:Goo00<07gooOol08Woo00<07gooOol07Woo

00<07gooOol07Goo00<07gooOol0ogooB7oo003oOol]Ool00`00Oomoo`0H

OolY00000`0O0000000M0005Ool00`0OOomoo`0NOol00`0OOomoo`0MOol0

0`0OOomoo`0:Ool00`00Oomoo`3oOolkOol00?mooamoo`9l00]oo`03001o

ogoo069oobH0000301l0000001d0000301l0000000Yoo`03001oogoo0?mo

oc]oo`00ogoo8Goo17`01goo00<007ooOol0Zgoo3@00ogoo>goo003oOolU

Ool4O003Ool00`00Oomoo`2eOol00`00Oomoo`08Ool3O03oOol`Ool00=Ao

oeQl0;Moo`03001oogoo00Aoo`Al0?mooc=oo`00ogoo9goo17`000=oo`00

Ool0]Woo00<007ooO00017`0ogoo=goo003oOolSOol4O005Ool00`00Oomo

o`2eOolEO03oOolYOol00?mooamoo`Al00Uoo`03001oogoo0;Eoo`03001o

og`000=l00moobQl0?moo`5oo`00ogoo:goo00<007ooOol0]Woo00<007oo

Ool00goo0g`0=7oo27`0n7oo003oOol[Oom5001dOol00`00Oomoo`06Ool4

O03oOolaOol00?moob]oo`03001oogoo049oodP002aoo`03001oogoo00Yo

o`03O01oogoo0?moobioo`00ogoo^7oo;@00ogoo?Goo003oOoooOoooOolS

Ool00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol0

0?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mo

oomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomo

oomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomo

ob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=o

o`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00

ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogoo

ogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogoo

ogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo

8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo

003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003o

OoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOooo

OoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOooo

OolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolS

Ool00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol0

0?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mo

oomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomo

oomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomo

ob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=o

o`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00

ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogoo

ogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogoo

ogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo

8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo

003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003o

OoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOooo

OoooOolSOol00?moofeoo`03O01oogoo02moo`03O01oogoo0?mooh1oo`00

ogooKGoo00=l07ooOol0;goo00=l07ooOol0ogooP7oo003oOom^Ool00g`0

Oomoo`0]Ool00g`0Oomoo`3oOon1Ool00?moofioo`03O01oogoo02eoo`03

O01oogoo0?mooh5oo`00ogooKWoo00=l07ooOol0;Goo00=l07ooOol0ogoo

PGoo003oOom^Ool00g`0Oomoo`0]Ool00g`0Oomoo`3oOon1Ool00?moofio

o`03O01oogoo02eoo`03O01oogoo0?mooh5oo`00ogooKWoo00=l07ooOol0

;Goo00=l07ooOol0ogooPGoo003oOom_Ool00g`0Oomoo`0[Ool00g`0Oomo

o`3oOon2Ool00?moofmoo`03O01oogoo02]oo`03O01oogoo0?mooh9oo`00

ogooKgoo00=l07ooOol0:goo00=l07ooOol0ogooPWoo003oOom_Ool00g`0

Oomoo`0[Ool00g`0Oomoo`0]Ool00g`0Oomoo`3oOomBOol00?mood=oo`03

O01oogoo02Uoo`03O01oogoo02]oo`03O01oogoo02aoo`03O01oogoo0?mo

oe=oo`00ogooA7oo00=l07ooOol0:Goo00=l07ooOol0:Goo00=l07ooOol0

;Goo00=l07ooOol0ogooDgoo003oOom4Ool00g`0Oomoo`0YOol00g`0Oomo

o`0YOol00g`0Oomoo`0/Ool00g`0Oomoo`3oOomDOol00?moodEoo`03O01o

ogoo02Qoo`03O01oogoo02Uoo`03O01oogoo02]oo`03O01oogoo0?mooeEo

o`00ogooAGoo00=l07ooOol0:7oo00=l07ooOol0:Goo00=l07ooOol0:goo

00=l07ooOol0ogooEGoo003oOom6Ool00g`0Oomoo`0WOol00g`0Oomoo`0Y

Ool00g`0Oomoo`0ZOol00g`0Oomoo`3oOomFOol00?moodIoo`03O01oogoo

02Qoo`03O01oogoo02Qoo`03O01oogoo02Yoo`03O01oogoo0?mooeIoo`00

ogooAWoo00=l07ooOol0:7oo00=l07ooOol09goo00=l07ooOol0:Woo00=l

07ooOol0ogooEgoo003oOom7Ool00g`0Oomoo`0WOol00g`0Oomoo`0WOol0

0g`0Oomoo`0YOol00g`0Oomoo`3oOomHOol00?moodMoo`03O01oogoo02Mo

o`03O01oogoo02Moo`03O01oogoo02Uoo`03O01oogoo0?mooeQoo`00ogoo

B7oo00=l07ooOol09Woo00=l07ooOol09goo00=l07ooOol0:7oo00=l07oo

Ool0ogooFGoo003oOom8Ool00g`0Oomoo`0VOol00g`0Oomoo`0WOol00g`0

Oomoo`0XOol00g`0Oomoo`3oOomIOol00?moodUoo`03O01oogoo02Ioo`03

O01oogoo02Ioo`03O01oogoo02Moo`03O01oogoo01ioo`03O01oogoo0?mo

ocUoo`00ogooBGoo00=l07ooOol09Woo00=l07ooOol09Goo00=l07ooOol0

9goo00=l07ooOol07Woo00=l07ooOol0ogoo>Woo003oOom:Ool00g`0Oomo

o`0UOol00g`0Oomoo`0UOol00g`0Oomoo`0WOol00g`0Oomoo`0MOol00g`0

Oomoo`3oOolkOol00?moodYoo`03O01oogoo02Eoo`03O01oogoo02Eoo`03

O01oogoo02Ioo`03O01oogoo01ioo`03O01oogoo0?mooc]oo`00ogooBgoo

00=l07ooOol097oo00=l07ooOol09Goo00=l07ooOol09Woo00=l07ooOol0

7Goo00=l07ooOol0ogoo?7oo003oOom;Ool00g`0Oomoo`0UOol00g`0Oomo

o`0TOol00g`0Oomoo`0UOol00g`0Oomoo`0MOol00g`0Oomoo`3oOolmOol0

0?moob9oo`03O01oogoo02Moo`03O01oogoo02Aoo`03O01oogoo02Aoo`03

O01oogoo02Aoo`03O01oogoo01eoo`03O01oogoo0?moocioo`00ogoo8goo

00=l07ooOol09Woo00=l07ooOol097oo00=l07ooOol08goo00=l07ooOol0

9Goo00=l07ooOol077oo00=l07ooOol0ogoo?goo003oOolTOol00g`0Oomo

o`0VOol00g`0Oomoo`0SOol00g`0Oomoo`0SOol00g`0Oomoo`0TOol00g`0

Oomoo`0MOol00g`0Oomoo`3oOoloOol00?moobAoo`03O01oogoo02Ioo`03

O01oogoo02=oo`03O01oogoo02=oo`03O01oogoo02Aoo`03O01oogoo01ao

o`03O01oogoo0?mood1oo`00ogoo9Goo00=l07ooOol09Woo00=l07ooOol0

8goo00=l07ooOol08Woo00=l07ooOol08goo00=l07ooOol077oo00=l07oo

Ool0ogoo@Goo003oOolVOol00g`0Oomoo`0UOol00g`0Oomoo`0SOol00g`0

Oomoo`0ROol00g`0Oomoo`0SOol00g`0Oomoo`0KOol00g`0Oomoo`3oOom2

Ool00?moobMoo`03O01oogoo02Eoo`03O01oogoo029oo`03O01oogoo029o

o`03O01oogoo029oo`03O01oogoo01]oo`03O01oogoo0?mood=oo`00ogoo

9goo00=l07ooOol09Goo00=l07ooOol08Woo00=l07ooOol08Goo00=l07oo

Ool08Woo00=l07ooOol077oo00=l07ooOol0ogoo@goo003oOolXOol00g`0

Oomoo`0UOol00g`0Oomoo`0QOol00g`0Oomoo`0QOol00g`0Oomoo`0ROol0

0g`0Oomoo`0KOol00g`0Oomoo`3oOom4Ool00?moobUoo`03O01oogoo02Ao

o`03O01oogoo025oo`03O01oogoo025oo`03O01oogoo025oo`03O01oogoo

01]oo`03O01oogoo0?moodEoo`00ogoo:Woo00=l07ooOol097oo00=l07oo

Ool08Goo00=l07ooOol087oo00=l07ooOol08Goo00=l07ooOol06Woo00=l

07ooOol0ogooAWoo003oOolZOol00g`0Oomoo`0TOol00g`0Oomoo`0QOol0

0g`0Oomoo`0POol00g`0Oomoo`0POol00g`0Oomoo`0JOol00g`0Oomoo`3o

Oom7Ool00?moob]oo`03O01oogoo02=oo`03O01oogoo025oo`03O01oogoo

01moo`03O01oogoo021oo`03O01oogoo01Yoo`03O01oogoo0?moodQoo`00

ogoo;7oo00=l07ooOol08goo00=l07ooOol087oo00=l07ooOol07goo00=l

07ooOol087oo00=l07ooOol06Woo00=l07ooOol0ogooB7oo003oOol/Ool0

0g`0Oomoo`0SOol00g`0Oomoo`0POol00g`0Oomoo`0OOol00g`0Oomoo`0O

Ool00g`0Oomoo`0JOol00g`0Oomoo`3oOom9Ool00?moobeoo`03O01oogoo

02=oo`03O01oogoo021oo`03O01oogoo01ioo`03O01oogoo01moo`03O01o

ogoo01Uoo`03O01oogoo0?moodYoo`00ogoo;Woo00=l07ooOol08Woo00=l

07ooOol087oo00=l07ooOol07Woo00=l07ooOol07Woo00=l07ooOol06Goo

00=l07ooOol0ogooBgoo003oOol_Ool00g`0Oomoo`0ROol00g`0Oomoo`0O

Ool00g`0Oomoo`0NOol00g`0Oomoo`0MOol00g`0Oomoo`0IOol00g`0Oomo

o`3oOom<Ool00?moobmoo`03O01oogoo029oo`03O01oogoo01moo`03O01o

ogoo01eoo`03O01oogoo01ioo`03O01oogoo01Uoo`03O01oogoo0?moodao

o`00ogoo<7oo00=l07ooOol08Woo00=l07ooOol07Woo00=l07ooOol07Goo

00=l07ooOol07Goo00=l07ooOol06Goo00=l07ooOol0ogooCGoo003oOola

Ool00g`0Oomoo`0QOol00g`0Oomoo`0NOol00g`0Oomoo`0JOol017`0Oomo

og`07goo00=l07ooOol067oo00=l07ooOol0ogooCWoo003oOolaOol00g`0

Oomoo`0ROol00g`0Oomoo`0NOol017`0Oomoog`067oo00Al07ooOoml009o

o`03O01oogoo01Uoo`03O01oogoo01Qoo`03O01oogoo0?moodmoo`00ogoo

<Woo00=l07ooOol08Goo00=l07ooOol06goo00Al07ooOoml009oo`03O01o

ogoo01Ioo`04O01oogooO002Ool00g`0Oomoo`0HOol00g`0Oomoo`0HOol0

0g`0Oomoo`0_Ool2O03oOolOOol00?mooc=oo`03O01oogoo025oo`03O01o

ogoo01Yoo`04O01oogooO002Ool00g`0Oomoo`0FOol01W`0Oomoog`0Ooml

01]oo`03O01oogoo01Qoo`03O01oogoo02ioo`03O01oogoo0?mooamoo`00

ogoo=7oo00=l07ooOol087oo00=l07ooOol06Woo00Al07ooOoml009oo`03

O01oogoo01Ioo`03O01oog`0009oo`03O01oogoo01Qoo`03O01oogoo01Qo

o`03O01oogoo02eoo`9l0?moob9oo`00ogoo=7oo00=l07ooOol08Goo00=l

07ooOol06Woo00=l07ooO0000Woo00=l07ooOol05Woo00El07ooO01oog`0

01]oo`03O01oogoo01Moo`03O01oogoo02eoo`03O01oogoo0?moob9oo`00

ogoo=Goo00=l07ooOol087oo00=l07ooOol06Woo00Il07ooOoml07ooO00H

Ool01G`0Ooml07ooO0005Woo00El07ooOomoog`001Uoo`03O01oogoo02eo

o`03O01oogoo0?moob=oo`00ogoo=Woo00=l07ooOol087oo00=l07ooOol0

6Woo00El07ooO01oog`001Qoo`05O01oog`0Ooml000FOol017`0Oomoog`0

6Goo00=l07ooOol0;7oo0W`0ogoo9Woo003oOolgOol00g`0Oomoo`0OOol0

1G`0OomoogooO00067oo00El07ooO01oog`001Qoo`04O01oog`0O00FOol0

1G`0OomoogooO00067oo00=l07ooOol0;7oo00=l07ooOol0ogoo9Woo003o

OolgOol00g`0Oomoo`0POol017`0Oomoog`06Goo0g`06Goo00Al07ooO01l

01Ioo`04O01oogooO00IOol00g`0Oomoo`0ZOol2O03oOolYOol00?moo`]o

o`03O01oogoo02Yoo`03O01oogoo01moo`04O01oogooO00IOol3O00JOol2

O00GOol017`0Oomoog`00Woo00=l07ooOol04goo00=l07ooOol0:Woo00=l

07ooOol0ogoo:Goo003oOol<Ool00g`0Oomoo`0ZOol00g`0Oomoo`0KOol0

1g`0OomoogooO01oog`001Yoo`9l01Yoo`9l01Moo`03O01oog`0009oo`03

O01oogoo01=oo`03O01oogoo02Uoo`9l0?moobaoo`00ogoo3Goo00=l07oo

Ool0:Goo00=l07ooOol077oo00Al07ooOoml009oo`03O01oogoo01Moo`9l

01Yoo`03O01oogoo01Eoo`03O01oog`0009oo`03O01oogoo01=oo`03O01o

ogoo02Uoo`03O01oogoo0?moobaoo`00ogoo3Woo00=l07ooOol0:Goo00=l

07ooOol077oo00Il07ooOoml07ooO00JOol00g`0Oomoo`0C0005Ool00g`0

Oomoo`0EOol01G`0Ooml07ooO0005Goo00=l07ooOol0:7oo0W`0ogoo;goo

003oOol?Ool00g`0Oomoo`0YOol00g`0Oomoo`0LOol01G`0Ooml07ooO000

57oo2@004goo2@0057oo0W`000=oog`0Ool05Goo00=l07ooOol09goo00=l

07ooOol0ogoo;goo003oOol@Ool00g`0Oomoo`0YOol00g`0Oomoo`0KOol0

1G`0Ooml07ooO0004Goo0`009Goo0`0047oo00Al07ooO01l01Ioo`03O01o

ogoo02Moo`03O01oogoo0?mooc1oo`00ogoo4Goo00=l07ooOol0:7oo00=l

07ooOol077oo00Al07ooO01l00ioo`<002]oo`<000eoo`=l01Ioo`03O01o

ogoo02Ioo`9l0?mooc=oo`00ogoo4Woo0W`0:Goo00=l07ooOol077oo0W`0

00=oog`0Ool02Goo0`00<Goo10002Goo0W`04Woo00El07ooOomoog`002Qo

o`03O01oogoo0?mooc=oo`00ogoo57oo00=l07ooOol09goo00=l07ooOol0

77oo0g`01Woo1000>7oo0`001Goo0W`04goo00Al07ooOoml02Moo`9l0?mo

ocIoo`00ogoo5Goo00=l07ooOol09Woo00=l07ooOol07Goo0W`00goo0`00

?goo0`000Woo00=l07ooOol04Goo00El07ooOomoog`002Ioo`03O01oogoo

0?moocIoo`00ogoo5Woo00=l07ooOol09Woo00=l07ooOol077oo0W`000=o

o`000000AGoo0P0057oo00Al07ooOoml02Eoo`9l0?moocUoo`00ogoo5goo

00=l07ooOol09Woo00=l07ooOol077oo00=l0000Ool0B7oo0P004Goo00Al

07ooOoml00=oo`03O01oogoo01moo`03O01oogoo0?moocUoo`00ogoo67oo

00=l07ooOol09Woo00El07ooOomoog`001Qoo`8004aoo`8000moo`03O01o

og`0009oo`9l021oo`9l0?moocaoo`00ogoo6Goo00=l07ooOol09Goo00El

07ooOomoog`001Ioo`80051oo`03001oogoo00]oo`03O01oog`0009oo`03

O01oogoo01moo`03O01oogoo0?moocaoo`00ogoo6Woo00=l07ooOol09Goo

00El07ooOomoog`001=oo`8005=oo`8000]oo`9l009oo`03O01oogoo01mo

o`03O01oogoo0?mooceoo`00ogoo6goo00=l07ooOol09Goo00Al07ooOoml

015oo`8005Moo`8000Qoo`03O01oog`0009l021oo`9l0?mood1oo`00ogoo

77oo00=l07ooOol08Goo00Ml07ooOomoog`0Ooml000?Ool2001KOol20006

Ool3O00QOol00g`0Oomoo`3oOom0Ool00?mooaeoo`03O01oogoo025oo`04

O01oogooO002Ool00g`0Oomoo`0;Ool00`00Oomoo`1MOol20003Ool3O00P

Ool2O03oOom3Ool00?mooaioo`03O01oogoo025oo`06O01oogooO01oog`0

2goo0P00HWoo00<007ooOol00W`087oo00=l07ooOol0ogoo@goo003oOolO

Ool00g`0Oomoo`0QOol01W`0Oomoog`0Ooml00Uoo`03001oogoo06=oo`03

001oogoo01moo`9l0?moodIoo`00ogoo87oo00=l07ooOol08Goo00El07oo

O01oog`000Qoo`03001oogoo06Eoo`8001ioo`03O01oogoo031oo`03O01o

ogoo0?mooa=oo`00ogoo8Goo00=l07ooOol08Goo00Al07ooO01l00Moo`03

001oogoo06Qoo`03001oogoo01Uoo`9l035oo`9l0?mooaIoo`00ogoo8Woo

00=l07ooOol08Goo17`017oo0P00K7oo00<007ooOol04Woo00=l07ooOol0

0Woo00=l07ooOol0;goo0W`0ogoo67oo003oOolSOol00g`0Oomoo`0ROol2

O003Ool00`00Oomoo`1]Ool00`00Oomoo`0@Ool017`0Oomoogoo0W`0<7oo

0W`0ogoo6Woo003oOolTOol00g`0Oomoo`0ROol2O0000goo001oo`1`Ool0

0`00Oomoo`0>Ool01G`0OomoogooO000<7oo0W`0ogoo77oo003oOolUOol0

0g`0Oomoo`0SOol00`00Oomoo`1aOol2000=Ool01G`0OomoogooO000;Woo

0g`0ogoo7Woo003oOolVOol00g`0Oomoo`0QOol00`00Oomoo`1dOol00`00

Oomoo`09Ool00g`0Oomoo`02O00]Ool2O03oOolQOol00?moobMoo`03O01o

ogoo01ioo`8007Qoo`03001oogoo00Moo`04O01oogooO004Ool2O00WOol2

O03oOolSOol00?moobQoo`03O01oogoo01aoo`03001oogoo07Uoo`03001o

ogoo00Eoo`04O01oog`0O002Ool3O00WOol2O03oOolUOol00?moobUoo`03

O01oogoo01Yoo`03001oogoo07]oo`03001oogoo00=oo`03O01oog`0009o

o`9l02Qoo`9l0?moobMoo`00ogoo:Woo00=l07ooOol067oo00<007ooOol0

OGoo00<007ooOol00Woo1G`0:7oo0W`0ogoo:Goo003oOol[Ool00g`0Oomo

o`0GOol00`00Oomoo`1nOol00`00Oomoo`03O00YOol2O03oOol[Ool00?mo

obaoo`03O01oogoo01Eoo`03001oogoo081oo`03001oogoo02Uoo`9l0?mo

obeoo`00ogoo;Goo00=l07ooOol04goo00<007ooOol0PGoo00<007ooOol0

9goo0W`0ogoo;goo003oOol^Ool00g`0Oomoo`02Ool00g`0Oomoo`0<Ool0

0`00Oomoo`23Ool00`00Oomoo`0TOol2O03oOolaOol00?moobmoo`05O01o

ogooOoml000=Ool00`00Oomoo`25Ool00`00Oomoo`0QOol2O03oOolcOol0

0?mooc1oo`05O01oogooOoml000;Ool00`00Oomoo`27Ool00`00Oomoo`0N

Ool2O03oOoleOol00?mooc5oo`04O01oogooO00;Ool00`00Oomoo`28Ool0

0`00Oomoo`0KOol2O03oOolgOol00?mooc9oo`04O01oogooO009Ool00`00

Oomoo`2:Ool00`00Oomoo`0HOol2O03oOoliOol00?Eoo`9l03Ioo`9l00=o

o`04O01oogooO007Ool00`00Oomoo`2;Ool00`00Oomoo`0?Ool00g`0Oomo

o`04Ool2O03oOolkOol00?Moo`=l03Eoo`9l009oo`03O01oog`000Ioo`03

001oogoo08eoo`03001oogoo00eoo`03O01oogoo00=oo`9l0?mooceoo`00

nWoo0W`0=Goo00Il07ooOoml07ooO004Ool00`00Oomoo`2?Ool00`00Oomo

o`0:Ool2O004Ool2O03oOoloOol00?aoo`9l03Aoo`9l0004Ooml07ooO003

Ool00`00Oomoo`2@Ool00`00Oomoo`08Ool00g`0Oomoo`02Ool2O03oOom1

Ool00?ioo`9l03Aoo`Al009oo`03001oogoo095oo`03001oogoo00Moo`04

O01oogooOol2O03oOom3Ool00?moo`5oo`9l03Aoo`=l0003Ool007oo09=o

o`03001oogoo00Eoo`03O01oogoo009l0?moodEoo`00ogoo0goo0g`0<goo

00=l0000Ool0U7oo00<007ooOol017oo00Al07ooO01l00Aoo`=l0?mood1o

o`00ogoo1Woo0W`0<Goo00<007ooOol0UGoo00<007ooOol00Woo0g`00Woo

17`0ogoo@goo003oOol8Ool2O00_Ool00`00Oomoo`2EOol00`00Oomoo`07

O03oOom7Ool00?moo`Yoo`9l02aoo`03001oogoo09Moo`04001oog`0O03o

Oom<Ool00?moo`aoo`9l02Yoo`03001oogoo09Qoo`03001oogoo0?moodao

o`00ogoo3Woo0W`09goo00<007ooOol0VGoo00<007ooOol0ogooC7oo003o

Ool@Ool3O00TOol00`00Oomoo`2JOol00`00Oomoo`3oOom;Ool00?mooa=o

o`9l025oo`03001oogoo09]oo`03001oogoo0?mood]oo`00ogoo5Goo0W`0

7goo00<007ooOol0W7oo00<007ooOol0ogooBWoo003oOolGOol2O00LOol0

0`00Oomoo`2MOol00`00Oomoo`3oOom:Ool00?mooaUoo`9l01Yoo`03001o

ogoo09ioo`03001oogoo03ioo`=l0?moo`Qoo`00ogoo6goo0g`05Woo00<0

07ooOol0Wgoo00<007ooOol0>Woo17`0ogoo2goo003oOolNOol2O007Ool0

0g`0Oomoo`0:Ool00`00Oomoo`2POol00`00Oomoo`0dOol5O03oOol?Ool0

0?moob1oo`9l00Ioo`03O01oogoo00Qoo`03001oogoo0:5oo`03001oogoo

031oo`Al0?mooaAoo`00ogoo8Woo0W`01Goo00=l07ooOol01goo00<007oo

Ool0XGoo00<007ooOol0:goo1G`0ogoo67oo003oOolTOol2O004Ool00g`0

Oomoo`06Ool00`00Oomoo`2ROol00`00Oomoo`0VOol4O03oOolMOol00?mo

obIoo`=l009oo`9l00Eoo`03001oogoo0:=oo`03001oogoo025oo`El0?mo

ob5oo`00ogoo:Goo0W`00Woo00=l07ooOol00Woo00<007ooOol0Xgoo00<0

07ooOol077oo1G`0ogoo9Woo003oOol[Ool2O0000gooO01oo`02Ool00`00

Oomoo`2TOol00`00Oomoo`0:Ool2O00;Ool4O03oOol[Ool00?moobEoo`El

00=oo`Al0003001oogoo0:Eoo`03001oogoo00Qoo`9l00Qoo`El0?moobmo

o`00ogoo:Woo1g`000<007ooOol0YGoo00<007ooOol01Woo0W`01Woo17`0

ogoo=7oo003oOol`Ool00g`0001oo`2WOol00`00Oomoo`03Ool2O003Ool5

O03oOolhOol00?mooc1oo`03001oogoo0:Moo`04001oogooOol2O0000goo

O01l0002O03oOolmOol00?mooc1oo`03001oogoo0:Moo`03001oog`000Al

0?mood5oo`00ogoo<7oo00<007ooOol0Ygoo00<007`0O0003G`0ogoo>7oo

003oOol`Ool00`00Oomoo`2XOol00`00Oomoo`3oOom4Ool00?moobmoo`03

001oogoo0:Uoo`03001oogoo0?moodAoo`00ogoo;goo00<007ooOol0ZGoo

00<007ooOol0ogooA7oo003oOol_Ool00`00Oomoo`2ZOol00`00Oomoo`3o

Oom3Ool00?moobmoo`03001oogoo0:Yoo`03001oogoo0?mood=oo`00ogoo

;Woo00<007ooOol0Zgoo00<007ooOol0ogoo@goo003oOol^Ool00`00Oomo

o`2[Ool00`00Oomoo`3oOom3Ool00?moobioo`03001oogoo0:]oo`03001o

ogoo0?mood=oo`00ogoo;Woo00<007ooOol0Zgoo00<007ooOol0ogoo@goo

003oOol^Ool00`00Oomoo`2[Ool00`00Oomoo`3oOom3Ool00?moobioo`03

001oogoo0:]oo`03001oogoo0?mood=oo`00ogoo;Woo00<007ooOol0[7oo

00<007ooOol0ogoo@Woo003oOol^Ool00`00Oomoo`2/Ool00`00Oomoo`3o

Oom2Ool00?moobioo`03001oogoo0:aoo`03001oogoo00Uoo`=l0?moocIo

o`00ogoo;Goo00<007ooOol0[Goo00<007ooOol017oo1G`0ogoo>Goo003o

Ool]Ool00`00Oomoo`2]Ool00`00Ooml0004O03oOolnOol00?moobeoo`03

001oogoo0:eoo`03001l07`0011l0?mooc9oo`00ogoo;Goo00<007ooOol0

[Goo00@007ooOomoo`=l00aooaQl0?mooaYoo`00ogoo7Woo0W`03Goo00<0

07ooOol0[Goo00<007ooOol017oo0g`08Goo5G`0ogoo1Goo003[Ool7O00]

Ool4O009Ool00`00Oomoo`2]Ool00`00Oomoo`07Ool4O03oOolgOol00?9o

oaUl01Qoo`=l00Ioo`03001oogoo0:eoo`03001oogoo00]oo`03O01oogoo

0?moocAoo`00ogoo37oo6G`00Woo17`00Woo00<007ooOol0[Woo00<007oo

Ool0ogoo@Goo003oOolUOol7O0000goo001oo`2^Ool00`00Oomoo`3oOom2

Ool00?moob=oo`El00Eoo`03001oogoo0:eoo`03001oogoo0?mood9oo`00

ogoo7Woo1G`02Woo00<007ooOol0[Goo00<007ooOol0ogoo@Woo003oOol]

Ool00`00Oomoo`2]Ool00`00Oomoo`3oOom2Ool00?moobeoo`03001oogoo

0:eoo`03001oogoo0?mood9oo`00ogoo;Goo00<007ooOol0[Goo00<007oo

Ool0ogoo@Woo003oOol^Ool00`00Oomoo`2/Ool00`00Oomoo`3oOom2Ool0

0?moobioo`03001oogoo0:aoo`03001oogoo0?mood9oo`00ogoo;Woo00<0

07ooOol0[7oo00<007ooOol0ogoo@Woo003oOol^Ool00`00Oomoo`2/Ool0

0`00Oomoo`3oOom2Ool00?moobioo`03001oogoo0:]oo`03001oogoo0?mo

od=oo`00ogoo;Woo00<007ooOol0Zgoo00<007ooOol0ogoo@goo003oOol^

Ool00`00Oomoo`2[Ool00`00Oomoo`3oOom3Ool00?moobioo`03001oogoo

0:]oo`03001oogoo0?mood=oo`00ogoo;Woo00<007ooOol0Zgoo00<007oo

Ool0ogoo@goo003oOol^Ool00`00Oomoo`2[Ool00`00Oomoo`05Ool6O03o

OolhOol00?moobmoo`03001oogoo0:Yoo`03001l07`000El0?moocioo`00

ogoo;goo00<007ooOol0ZWoo00<007`0O0001G`0ogoo?Woo003oOol_Ool0

0`00Oomoo`2YOol00`00Oomoo`02Ool2O002Ool6O03oOolhOol00?moobmo

o`03001oogoo0:Uoo`03001oogoo00Aoo`9l00Ioo`Il0?mooc9oo`00ogoo

<7oo00<007ooOol0Z7oo00<007ooOol01Woo0W`02Woo1W`0ogoo;7oo003o

Ool`Ool00`00Oomoo`2WOol00`00Oomoo`09Ool3O00=Ool5O03oOolWOol0

0?mooc1oo`03001oogoo0:Moo`03001oogoo01ioo`Il0?moob5oo`00ogoo

<Goo00<007ooOol0YWoo00<007ooOol097oo1W`0ogoo6goo003oOolaOol0

0`00Oomoo`2UOol00`00Oomoo`0[Ool6O03oOolEOol00?mooc5oo`03001o

ogoo0:Eoo`03001oogoo035oo`El0?mooa1oo`00ogoo<Goo00<007ooOol0

YGoo00<007ooOol0=Woo1W`0ogoo2Woo003oOolbOol00`00Oomoo`2TOol0

0`00Oomoo`3oOom6Ool00?mooc9oo`03001oogoo0:=oo`03001oogoo0?mo

odMoo`00ogoo<Woo00<007ooOol0Xgoo00<007ooOol0ogooAgoo003oOol/

Ool6O0000goo001oo`2SOol00`00Oomoo`3oOom7Ool00?moobAoo`Ql009o

o`=l009oo`03001oogoo0:5oo`03001oogoo0?moodQoo`00ogoo:goo1G`0

0goo00<007ooOol0XGoo00<007ooOol0ogooB7oo003oOolXOol3O002Ool0

0g`0Oomoo`04Ool00`00Oomoo`2POol00`00Oomoo`3oOom8Ool00?moobEo

o`=l00=oo`9l00Moo`03001oogoo09moo`03001oogoo0?moodUoo`00ogoo

8goo0W`01Goo00=l07ooOol027oo00<007ooOol0WWoo00<007ooOol0ogoo

BGoo003oOolPOol3O005Ool2O00;Ool00`00Oomoo`2MOol00`00Oomoo`02

Ool3O03oOom5Ool00?mooaeoo`=l00Moo`03O01oogoo00aoo`03001oogoo

09aoo`03001oogoo00=oo`Il0?mood5oo`00ogoo6Woo0g`06Goo00<007oo

Ool0Vgoo00<007ooOol01Goo0g`00Woo17`0ogoo?Goo003oOolHOol2O00M

Ool00`00Oomoo`2JOol00`00Oomoo`06Ool017`0Ooml07`017oo0g`0ogoo

>Woo003oOolEOol3O00OOol00`00Oomoo`2IOol00`00Oomoo`08Ool00g`0

Oomoo`02O03oOoloOol00?mooa9oo`=l02=oo`03001oogoo09Moo`03001o

ogoo00Yoo`04O01oogooOol2O03oOolmOol00?moo`moo`=l02Ioo`03001o

ogoo09Moo`03001oogoo00]oo`03O01oogoo009oo`9l0?mooc]oo`00ogoo

3Goo0W`0:Woo00<007ooOol0UGoo00<007ooOol03Goo0W`017oo0W`0ogoo

>Goo003oOol:Ool3O00]Ool00`00Oomoo`2DOol00`00Oomoo`0?Ool00g`0

Oomoo`03Ool2O03oOolgOol00?moo`Moo`=l031oo`03001oogoo09=oo`03

001oogoo01Qoo`9l0?moocEoo`00ogoo17oo0g`0=7oo00<007ooOol0TWoo

00<007ooOol06Woo0W`0ogoo<goo003oOol1Ool3O00gOol00`00Oomoo`2A

Ool00`00Oomoo`0MOol2O03oOolaOol00?ioo`9l03]oo`03001oogoo091o

o`03001oogoo01moo`9l0?moobmoo`00ngoo0g`0?Goo00<007ooOol0Sgoo

00<007ooOol08Woo0W`0ogoo;Goo003hOol3O011Ool00`00Oomoo`2=Ool0

0`00Oomoo`0UOol2O03oOol[Ool00?Eoo`=l04Eoo`03001oogoo08]oo`03

001oogoo02Qoo`9l0?moobUoo`00m7oo00=l07ooOol0Agoo00<007ooOol0

RGoo00@007ooOomoo`=l02Moo`9l0?moobMoo`00ogoo?Goo0g`000<007oo

Ool0R7oo00<007ooOol00Woo1G`09Woo00=l07ooOol0ogoo97oo003oOolk

Ool4O002Ool00`00Oomoo`26Ool00`00Oomoo`04Ool3O00017ooO01l07`0

97oo0W`0ogoo97oo003oOoliOol2O00017ooO01oog`00Woo00<007ooOol0

QGoo00<007ooOol01Woo00=l07ooO0000goo0g`08goo0W`0ogoo8Woo003o

OolgOol2O002Ool00g`0Ooml0004Ool00`00Oomoo`23Ool00`00Oomoo`07

Ool00g`0Oomoo`02O004Ool00g`0Oomoo`0ROol2O03oOolPOol00?moocEo

o`9l00=oo`03O01oog`000Ioo`03001oogoo085oo`03001oogoo00Uoo`05

O01oogooOoml000ZOol2O03oOolNOol00?moocAoo`03O01oogoo009oo`03

O01oog`000Qoo`03001oogoo07moo`03001oogoo00]oo`04O01oogooOol2

O00ZOol2O03oOolLOol00?moocQoo`04O01oogooO009Ool00`00Oomoo`1n

Ool00`00Oomoo`0<Ool00g`0Oomoo`02Ool00g`0Oomoo`0YOol2O03oOolJ

Ool00?moocIoo`9l009oo`03O01oogoo00Uoo`03001oogoo07aoo`03001o

ogoo00ioo`03O01oogoo009oo`9l02]oo`03O01oogoo0?mooaMoo`00ogoo

=Goo00El07ooOomoog`000aoo`03001oogoo07]oo`03001oogoo011oo`03

O01oogoo00=oo`03O01oogoo0?mood9oo`00ogoo=7oo00=l07ooOol00Woo

00=l07ooOol02goo00<007ooOol0NGoo00<007ooOol067oo0W`0ogoo@Woo

003oOolcOol00g`0Oomoo`02Ool00g`0Oomoo`0=Ool2001hOol00`00Oomo

o`0KOol00g`0Oomoo`3oOoloOol00?mooc9oo`03O01oogoo01Eoo`03001o

ogoo07=oo`800003Ooml07oo01aoo`9l0?moocmoo`00ogoo<Goo00=l07oo

Ool05goo00<007ooOol0LGoo00<007ooOol00Woo0W`07Goo00=l07ooOol0

ogoo?7oo003oOol_Ool2O00KOol00`00Oomoo`1_Ool00`00Oomoo`03Ool4

O00LOol2O03oOollOol00?moobioo`03O01oogoo01aoo`8006ioo`03001o

ogoo00Eoo`9l0003Ooml07`001aoo`03O01oogoo0?moocUoo`00ogoo;Goo

00=l07ooOol07goo00<007ooOol0JWoo00<007ooOol01goo0g`000=oog`0

O0006goo0W`0ogoo>Goo003oOol/Ool00g`0Oomoo`0QOol00`00Oomoo`1W

Ool2000:Ool017`0Oomoog`00Woo0W`06goo00=l07ooOol0ogoo=Woo003o

Ool[Ool00g`0Oomoo`0SOol00`00Oomoo`1UOol00`00Oomoo`0;Ool017`0

Oomoog`00goo0W`06Woo0W`0ogoo=Woo003oOolYOol2O00WOol00`00Oomo

o`1SOol00`00Oomoo`0=Ool017`0Oomoog`087oo00=l07ooOol0ogoo<goo

003oOolXOol00g`0Oomoo`0XOol2001ROol00`00Oomoo`0?Ool017`0Oomo

og`087oo0W`0ogoo<goo003oOolWOol00g`0Oomoo`0[Ool2001NOol2000B

Ool017`0Oomoogoo0W`087oo00=l07ooOol0ogoo<7oo003oOolVOol00g`0

Oomoo`0ZOol3O0000goo001oo`1JOol2000EOol00g`0Oomoo`02Ool00g`0

Oomoo`0NOol2O03oOol`Ool00?moobEoo`03O01oogoo02Yoo`=l00=oo`80

05Moo`8001Qoo`03O01oogoo009oo`03O01oogoo01moo`03O01oogoo0?mo

obeoo`00ogoo97oo00=l07ooOol0:Woo00Al07ooO01l00Eoo`8005=oo`80

0003Ooml07`001eoo`03O01oogoo01moo`9l0?moobeoo`00ogoo8Woo0W`0

;7oo00Al07ooO01l00Qoo`8004moo`8000=oo`=l01eoo`03O01oogoo021o

o`03O01oogoo0?moobYoo`00ogoo8Goo00=l07ooOol0:Woo0W`000Aoog`0

Ooml00Yoo`8004]oo`8000Ioo`=l01eoo`9l025oo`9l0?moobYoo`00ogoo

87oo00=l07ooOol0:Woo00Il07ooOoml07ooO00=Ool20018Ool00`00Oomo

o`06Ool2O0000gooO01oo`0MOol00g`0Oomoo`0POol00g`0Oomoo`3oOolW

Ool00?mooamoo`03O01oogoo02Yoo`07O01oogooOoml07ooO0003goo0P00

A7oo0P002Woo0W`000=oog`0Ool07Goo00=l07ooOol087oo0W`0ogoo9goo

003oOolNOol00g`0Oomoo`0ZOol01G`0OomoogooO0000Woo00=l07ooOol0

3goo0`00?Goo100037oo00El07ooO01oog`001ioo`03O01oogoo025oo`03

O01oogoo0?moobAoo`00ogoo7Goo00=l07ooOol0;Woo00Al07ooOoml01Eo

o`<003Moo`<0011oo`03O01oog`0009oo`03O01oogoo01aoo`03O01oogoo

0?moodMoo`00ogoo6goo0W`0<7oo00El07ooOomoog`001Qoo`<0035oo`<0

01Aoo`03O01oog`0009oo`9l01eoo`9l0?moodMoo`00ogoo6Woo00=l07oo

Ool0<7oo00Al07ooOoml01aoo`@002Yoo`<001Moo`04O01oogooO003Ool0

0g`0Oomoo`0LOol00g`0Oomoo`3oOom4Ool00?mooaUoo`03O01oogoo031o

o`05O01oogooOoml000LOol017`0Oomoogoo0`008goo100027oo00=l07oo

Ool03goo00Al07ooOoml02=oo`03O01oogoo0?mood=oo`00ogoo67oo00=l

07ooOol0<7oo00=l07ooOol07Woo0W`01Woo2P0047oo2@0037oo0W`04Goo

00Al07ooOoml02=oo`03O01oogoo0?mood9oo`00ogoo5goo00=l07ooOol0

<7oo00=l07ooOol07Woo0g`047oo40001Goo00=l07ooOol03Goo0W`04Goo

00El07ooOomoog`002=oo`03O01oogoo0?mood5oo`00ogoo5Woo00=l07oo

Ool0<Goo00=l07ooOol07Woo0g`09Goo00=l07ooOol03Goo0g`04Goo00El

07ooOomoog`002=oo`03O01oogoo0?mood1oo`00ogoo57oo0W`0<goo00=l

07ooOol07Woo00Al07ooO01l01=oo`03O01oogoo00ioo`=l00ioo`=l01Eo

o`03O01oogoo029oo`9l0?mood1oo`00ogoo4goo00=l07ooOol0<Woo00=l

07ooOol07goo00Al07ooO01l01=oo`03O01oogoo00ioo`=l00ioo`9l0003

Ooml07oo01Aoo`03O01oogoo02=oo`03O01oogoo0?mooceoo`00ogoo4Woo

00=l07ooOol0<Woo00=l07ooOol07goo00El07ooO01oog`0019oo`9l011o

o`=l00ioo`04O01oog`0O00FOol00g`0Oomoo`0SOol00g`0Oomoo`3oOoll

Ool00?mooa5oo`03O01oogoo039oo`03O01oogoo021oo`05O01oog`0Ooml

000BOol3O00?Ool2O0000gooO01oo`0<Ool01G`0Ooml07ooO0005Goo00=l

07ooOol097oo00=l07ooOol0ogoo>goo003oOom6Ool00g`0Oomoo`0OOol0

1W`0Oomoog`0Ooml019oo`=l00moo`9l0003Ooml07oo00aoo`05O01oog`0

Ooml000FOol00g`0Oomoo`0TOol00g`0Oomoo`3oOoljOol00?moodEoo`03

O01oogoo021oo`06O01oogooO01oog`04Woo0g`03goo0W`000=oog`0Ool0

37oo00=l07ooO0000Woo00=l07ooOol057oo00=l07ooOol097oo0W`0ogoo

>Woo003oOom4Ool00g`0Oomoo`0POol017`0Oomoog`00Woo00=l07ooOol0

3goo00Al07ooO01l00ioo`06O01oogooO01oog`037oo00=l07ooO0000Woo

00=l07ooOol057oo00=l07ooOol09Woo00=l07ooOol0ogoo=goo003oOom3

Ool00g`0Oomoo`0QOol017`0Oomoog`00Woo00=l07ooOol03goo00El07oo

O01oog`000eoo`06O01oogooO01oog`037oo00Al07ooOoml009oo`03O01o

ogoo01Aoo`03O01oogoo02Ioo`03O01oogoo0?moocIoo`00ogoo@goo00=l

07ooOol097oo00Al07ooOoml015oo`05O01oog`0Ooml000=Ool01W`0Oomo

og`0Ooml00aoo`04O01oogooO002Ool00g`0Oomoo`0EOol00g`0Oomoo`0V

Ool00g`0Oomoo`3oOoleOol00?mood9oo`03O01oogoo02Eoo`04O01oogoo

O00AOol01G`0Ooml07ooO0003Goo00Al07ooOoml009oo`03O01oogoo00Uo

o`04O01oogooO00JOol00g`0Oomoo`0WOol00g`0Oomoo`3oOoldOol00?mo

od5oo`03O01oogoo02Eoo`03O01oogoo019oo`06O01oogooO01oog`03Goo

00Al07ooOoml009oo`03O01oogoo00Uoo`04O01oogooO00KOol00g`0Oomo

o`0WOol2O03oOoldOol00?mood1oo`03O01oogoo02Ioo`03O01oogoo019o

o`04O01oogooO002Ool00g`0Oomoo`0:Ool017`0Oomoog`04Goo00=l07oo

Ool06Woo00=l07ooOol0ogooG7oo003oOom0Ool00g`0Oomoo`0VOol00g`0

Oomoo`0BOol017`0Oomoog`00Woo00=l07ooOol03Goo00=l07ooOol047oo

00=l07ooOol06Goo00=l07ooOol0ogooG7oo003oOoloOol00g`0Oomoo`0W

Ool00g`0Oomoo`0BOol017`0Oomoog`00Woo00=l07ooOol03Goo00=l07oo

Ool047oo00=l07ooOol06Woo00=l07ooOol0ogooFgoo003oOolnOol00g`0

Oomoo`0WOol00g`0Oomoo`0FOol00g`0Oomoo`0@Ool00g`0Oomoo`0@Ool0

0g`0Oomoo`0KOol00g`0Oomoo`3oOomJOol00?mooceoo`03O01oogoo02Qo

o`03O01oogoo01Ioo`03O01oogoo011oo`03O01oogoo011oo`03O01oogoo

01]oo`03O01oogoo0?mooeYoo`00ogoo?Goo00=l07ooOol0:7oo00=l07oo

Ool05Woo00=l07ooOol047oo00=l07ooOol047oo00=l07ooOol077oo00=l

07ooOol0ogooFGoo003oOollOol00g`0Oomoo`0YOol00g`0Oomoo`0FOol0

0g`0Oomoo`0@Ool00g`0Oomoo`0AOol00g`0Oomoo`0LOol00g`0Oomoo`3o

OomHOol00?mooc]oo`03O01oogoo02Uoo`03O01oogoo01Moo`03O01oogoo

011oo`03O01oogoo015oo`03O01oogoo01eoo`03O01oogoo0?mooeMoo`00

ogoo>Woo00=l07ooOol0:Woo00=l07ooOol05goo00=l07ooOol047oo00=l

07ooOol04Goo00=l07ooOol07Goo00=l07ooOol0ogooEgoo003oOoljOol0

0g`0Oomoo`0ZOol00g`0Oomoo`0GOol00g`0Oomoo`0AOol00g`0Oomoo`0@

Ool00g`0Oomoo`0NOol00g`0Oomoo`3oOomFOol00?moocUoo`03O01oogoo

02]oo`03O01oogoo01Moo`03O01oogoo015oo`03O01oogoo011oo`03O01o

ogoo01moo`03O01oogoo0?mooeEoo`00ogoo>7oo00=l07ooOol0:goo00=l

07ooOol067oo00=l07ooOol04Goo00=l07ooOol04Goo00=l07ooOol07Woo

00=l07ooOol0ogooEGoo003oOolgOol00g`0Oomoo`0/Ool00g`0Oomoo`0H

Ool00g`0Oomoo`0AOol00g`0Oomoo`0AOol00g`0Oomoo`0OOol00g`0Oomo

o`3oOomDOol00?moocMoo`03O01oogoo02aoo`03O01oogoo01Qoo`03O01o

ogoo015oo`03O01oogoo015oo`03O01oogoo021oo`03O01oogoo0?mooe=o

o`00ogoo=Woo00=l07ooOol0;Goo00=l07ooOol067oo00=l07ooOol04Goo

00=l07ooOol04Goo00=l07ooOol087oo00=l07ooOol0ogooDgoo003oOole

Ool00g`0Oomoo`0]Ool00g`0Oomoo`0IOol00g`0Oomoo`0AOol00g`0Oomo

o`0AOol00g`0Oomoo`0QOol00g`0Oomoo`3oOomBOol00?moofEoo`03O01o

ogoo01Uoo`03O01oogoo015oo`03O01oogoo019oo`03O01oogoo025oo`03

O01oogoo0?mooe5oo`00ogooIGoo00=l07ooOol06Goo00=l07ooOol04Goo

00=l07ooOol04Woo00=l07ooOol08Goo00=l07ooOol0ogooDGoo003oOomU

Ool00g`0Oomoo`0IOol00g`0Oomoo`0AOol00g`0Oomoo`0BOol00g`0Oomo

o`0ROol00g`0Oomoo`3oOom@Ool00?moofAoo`03O01oogoo01Yoo`03O01o

ogoo015oo`03O01oogoo019oo`03O01oogoo02=oo`03O01oogoo0?moodmo

o`00ogooI7oo00=l07ooOol06Woo00=l07ooOol04Goo00=l07ooOol04goo

00=l07ooOol0ogooM7oo003oOomTOol00g`0Oomoo`0JOol00g`0Oomoo`0A

Ool00g`0Oomoo`0COol00g`0Oomoo`3oOomdOol00?moofAoo`03O01oogoo

01Yoo`03O01oogoo015oo`03O01oogoo01=oo`03O01oogoo0?moogAoo`00

ogooHgoo00=l07ooOol06goo00=l07ooOol04Woo00=l07ooOol04Woo00=l

07ooOol0ogooM7oo003oOomSOol00g`0Oomoo`0KOol00g`0Oomoo`0BOol0

0g`0Oomoo`0BOol00g`0Oomoo`3oOomdOol00?moof=oo`03O01oogoo01]o

o`03O01oogoo019oo`03O01oogoo01=oo`03O01oogoo0?moog=oo`00ogoo

Hgoo00=l07ooOol06goo00=l07ooOol04Woo00=l07ooOol04goo00=l07oo

Ool0ogooLgoo003oOomROol00g`0Oomoo`0LOol00g`0Oomoo`0BOol00g`0

Oomoo`0COol00g`0Oomoo`3oOomcOol00?moof9oo`03O01oogoo01aoo`03

O01oogoo019oo`03O01oogoo01=oo`03O01oogoo0?moog=oo`00ogooHWoo

00=l07ooOol077oo00=l07ooOol04Woo00=l07ooOol04goo00=l07ooOol0

ogooLgoo003oOomROol00g`0Oomoo`0LOol00g`0Oomoo`0BOol00g`0Oomo

o`0DOol00g`0Oomoo`3oOombOol00?moof5oo`03O01oogoo01eoo`03O01o

ogoo019oo`03O01oogoo0?moohUoo`00ogooHGoo00=l07ooOol07Goo00=l

07ooOol04Woo00=l07ooOol0ogooRGoo003oOomQOol00g`0Oomoo`0MOol0

0g`0Oomoo`0BOol00g`0Oomoo`3oOon9Ool00?moof5oo`03O01oogoo01eo

o`03O01oogoo0?mooiioo`00ogooH7oo00=l07ooOol07Woo00=l07ooOol0

ogooWWoo003oOon1Ool00g`0Oomoo`3oOonNOol00?mooh5oo`03O01oogoo

0?mooiioo`00ogooPGoo00=l07ooOol0ogooWWoo003oOon1Ool00g`0Oomo

o`3oOonNOol00?mooh5oo`03O01oogoo0?mooiioo`00ogooogooogoo8goo

003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003o

OoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOooo

OoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOooo

OolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolS

Ool00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol0

0?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mo

oomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomo

oomoob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomo

ob=oo`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=o

o`00ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00

ogooogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogoo

ogooogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogoo

ogoo8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo

8goo003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo

003oOoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003o

OoooOoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOooo

OoooOolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOooo

OolSOol00?mooomooomoob=oo`00ogooogooogoo8goo003oOoooOoooOolS

Ool00?mooomooomoob=oo`00ogooogooogoo8goo0000\

\>"], "Graphics",

  ImageSize->{602, 451.5},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}}],



Cell[CellGroupData[{



Cell[TextData[StyleBox["2.1 Mathematical Formulation",

  FontSize->18]], "Subsection"],



Cell[TextData[{

  StyleBox[

  "We investigate the radially symmetric deflections so that the variables \

are \nonly a function of the radius r. This problem is formulated in terms of \

the\nfollowing system of three second order nonlinear ordinary differential\n\

equations which we derived in an earlier paper [2].\n\nGq + ",

    FontSize->16],

  StyleBox[Cell[BoxData[

      \(TraditionalForm\`a\^2\)],

    FontSize->16]],

  StyleBox[" pq = ",

    FontSize->16],

  StyleBox[Cell[BoxData[

      \(TraditionalForm\`k\^2\)],

    FontSize->16]],

  StyleBox["W,\nGp = ",

    FontSize->16],

  StyleBox[Cell[BoxData[

      \(TraditionalForm\`1\/2\)],

    FontSize->16]],

  StyleBox[Cell[BoxData[

      FormBox[

        SuperscriptBox[

          StyleBox["q",

            FontSlant->"Plain"], "2"], TraditionalForm]],

    FontSize->16]],

  StyleBox[

  ",\nGW + q = 0,                                                             \

                                     (2.1)\nwhere  G\[FilledSmallCircle]=",

    FontSize->16],

  StyleBox[Cell[BoxData[

      FormBox[

        FractionBox["1", 

          StyleBox[\(r\^3\),

            FontSize->16]], TraditionalForm]],

    FontSize->16]],

  StyleBox[Cell[BoxData[

      FormBox[

        RowBox[{

          SubscriptBox["\[PartialD]", 

            StyleBox["r",

              FontSize->14]], " ", 

          RowBox[{"(", 

            RowBox[{\(r\^3\), 

              RowBox[{

                SubscriptBox["\[PartialD]", 

                  StyleBox["r",

                    FontSize->14]], " ", "\[FilledSmallCircle]"}]}]}]}], 

        TraditionalForm]],

    FontSize->16]],

  StyleBox[")  \nand 0 \[LessEqual] ",

    FontSize->16],

  StyleBox["r",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[

  " \[LessEqual] 1.\n\nThe boundary conditions are:\n\nq'(0) = 0,  p'(0) = 0, \

 W'(0) = 0,                                                                   \

  (2.2)\nq(1) = 0,   p(1) = 1,   W'(1) + 2 W(1) = 0.                          \

                            (2.3)\n\nThe variables q(",

    FontSize->16],

  StyleBox["r",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[") and W(",

    FontSize->16],

  StyleBox["r",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[") are defined in terms of the vertical deflection ",

    FontSize->16],

  StyleBox["w(r) ",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox["\nas follows:\n\nq(",

    FontSize->16],

  StyleBox["r",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[") = ",

    FontSize->16],

  StyleBox[Cell[BoxData[

      FormBox[

        StyleBox[

          FractionBox["1", 

            StyleBox["r",

              FontSize->16]],

          FontSize->16], TraditionalForm]],

    FontSize->16]],

  StyleBox[Cell[BoxData[

      FormBox[

        RowBox[{

          RowBox[{

            RowBox[{

              SubscriptBox["\[PartialD]", 

                StyleBox["r",

                  FontSize->14]], \(w(r)\)}], ","}], "\n"}], 

        TraditionalForm]],

    FontSize->16]],

  StyleBox[

  "                                                                           \

                                               "],

  StyleBox["(2.4)",

    FontSize->16],

  StyleBox["\n"],

  StyleBox["W(",

    FontSize->16],

  StyleBox["r",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[") = - ",

    FontSize->16],

  StyleBox[Cell[BoxData[

      FormBox[

        FractionBox["1", 

          StyleBox[\(r\ \),

            FontSize->16]], TraditionalForm]],

    FontSize->16]],

  StyleBox[Cell[BoxData[

      FormBox[

        RowBox[{

          SubsuperscriptBox[

            StyleBox["\[Integral]",

              FontSize->18], "0", 

            StyleBox["r",

              FontSize->16]], \(s\ \(w(s)\) \[DifferentialD]s\)}], 

        TraditionalForm]],

    FontSize->16]],

  StyleBox[

  ".                                                                          \

                                 "],

  StyleBox["(2.5)   ",

    FontSize->16],

  StyleBox["  \n\n"],

  StyleBox["The variable p(",

    FontSize->16],

  StyleBox["r",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[") represents the radial stress.\n",

    FontSize->16]

}], "Input",

  FormatType->TextForm]

}, Open  ]],



Cell[CellGroupData[{



Cell[TextData[StyleBox["2.2  The Linearized Problem",

  FontSize->18]], "Subsection"],



Cell[TextData[{

  StyleBox[

  "As was mentioned in Section 1,  we need to solve the linearized problem\n\

and find its eigenvalues in order to start the shooting method.\n \nThe \

boundary value problem defined by (2.1), (2.2), (2.3), has the obvious\n\

solution: \nq \[Congruent] 0, p \[Congruent] 1, W \[Congruent] 0 \nfor any ",

    FontSize->16],

  StyleBox["a",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[" and ",

    FontSize->16],

  StyleBox["k . ",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[

  "This solution represents the unbuckled state.\nThe BVP  problem linearized \

about this unbuckled solution is:\n\nGq + ",

    FontSize->16],

  Cell[BoxData[

      FormBox[

        SuperscriptBox[

          StyleBox["a",

            FontSlant->"Italic"], "2"], TraditionalForm]],

    FontSize->16],

  StyleBox["q = ",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`k\^2\)],

    FontSize->16],

  StyleBox[

  "W,\nGp = 0,                                                                \

                                            (2.6)\nGW + q = 0,\ntogether with \

the boundary conditions (2.2) and (2.3).\nThis BVP has been solved in [2]. \

The solution is:\n",

    FontSize->16]

}], "Input",

  FormatType->TextForm],



Cell[BoxData[

    FormBox[

      RowBox[{

        RowBox[{

          StyleBox[

            FormBox[

              SubscriptBox[

                StyleBox["q",

                  FontSlant->"Plain"], "n"],

              "TraditionalForm"],

            FontSize->16], 

          StyleBox["=",

            FontSize->16], 

          RowBox[{

            StyleBox[

              FormBox[

                FractionBox["1", 

                  StyleBox["r",

                    FontSize->16]],

                "TraditionalForm"],

              FontSize->16], 

            StyleBox[

              FormBox[

                RowBox[{"(", 

                  RowBox[{

                    RowBox[{

                      FormBox[\(\(\[Lambda]\_n\)(k)\),

                        "TraditionalForm"], 

                      FormBox[\(\ \(J\_0\)(k\/\(\(\[Lambda]\_n\)(k)\))\),

                        "TraditionalForm"], 

                      FormBox[\(\(J\_1\)(\(\(\[Lambda]\_n\)(k)\)\ r)\),

                        "TraditionalForm"]}], "-", 

                    RowBox[{

                      FormBox[\(k\/\(\(\[Lambda]\_n\)(k)\)\),

                        "TraditionalForm"], 

                      

                      FormBox[

                        \(\(\(J\_0\)(\(\[Lambda]\_n\)(k)\ )\) 

                          \(\(J\_1\)(\(\(k\ \)\/\(\(\[Lambda]\_n\)(k)\)\) r)

                            \)\),

                        "TraditionalForm"]}]}], ")"}],

                "TraditionalForm"],

              FontSize->16], 

            FormBox[

              RowBox[{

                FormBox["",

                  "TraditionalForm"], 

                FormBox["",

                  "TraditionalForm"]}],

              "TraditionalForm"]}]}], ","}], TraditionalForm]], "Input"],



Cell[BoxData[

    FormBox[

      RowBox[{

        RowBox[{

          StyleBox[

            RowBox[{

              RowBox[{

                SubscriptBox[

                  StyleBox["W",

                    FontSlant->"Plain"], "n"], 

                FormBox[

                  RowBox[{

                    FormBox["",

                      "TraditionalForm"], 

                    FormBox["",

                      "TraditionalForm"]}],

                  "TraditionalForm"]}], "=", 

              RowBox[{

                FormBox[

                  FractionBox["1", 

                    StyleBox["r",

                      FontSize->16]],

                  "TraditionalForm"], 

                FormBox[

                  RowBox[{"(", 

                    RowBox[{

                      RowBox[{

                        FormBox[\(k\/\(\(\[Lambda]\_n\)(k)\)\),

                          "TraditionalForm"], " ", 

                        FormBox[\(\ \(J\_0\)(k\/\(\(\[Lambda]\_n\)(k)\))\),

                          "TraditionalForm"], 

                        FormBox[\(\(J\_1\)(\(\(\[Lambda]\_n\)(k)\)\ r)\),

                          "TraditionalForm"]}], "-", 

                      RowBox[{

                        FormBox[\(\(\[Lambda]\_n\)(k)\),

                          "TraditionalForm"], 

                        

                        FormBox[

                          \(\(\(J\_0\)(\(\[Lambda]\_n\)(k))\)\ 

                            \(\(J\_1\)(\(\(k\ \)\/\(\(\[Lambda]\_n\)(k)\)\) r)

                              \)\),

                          "TraditionalForm"]}]}], ")"}],

                  "TraditionalForm"]}]}],

            FontSize->16], 

          StyleBox[" ",

            FontSize->16], 

          StyleBox[",",

            FontSize->16], "\n", 

          RowBox[{

            StyleBox["p",

              FontSize->16,

              FontSlant->"Plain"], 

            StyleBox[" ",

              FontSize->16], 

            StyleBox["\[Congruent]",

              FontSize->16], 

            StyleBox[" ",

              FontSize->16], 

            StyleBox["1.",

              FontSize->16]}]}], "\t"}], TraditionalForm]], "Input"],



Cell[TextData[{

  StyleBox["Where the ",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`\(\[Lambda]\_n\)(k)\)],

    FontSize->16],

  StyleBox[" are, for a fixed value of ",

    FontSize->16],

  StyleBox["k",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[", roots of",

    FontSize->16]

}], "Input",

  FormatType->TextForm],



Cell[BoxData[

    FormBox[

      RowBox[{

      \(\(\(\[Lambda]\_n\)(k)\) 

          \(\(J\_1\) \((\(\[Lambda]\_n\)(k)\ )\)\)\/\(\(J\_0\) 

              \((\(\[Lambda]\_n\)(k)\ )\)\)\), " ", "=", " ", 

        RowBox[{\(k\/\(\(\[Lambda]\_n\)(k)\)\), 

          RowBox[{

            FractionBox[

              RowBox[{\(J\_1\), 

                RowBox[{"(", 

                  FractionBox[

                    RowBox[{

                      StyleBox["k",

                        FontSize->16], " "}], 

                    StyleBox[\(\(\[Lambda]\_n\) \((k)\)\),

                      FontSize->16]], ")"}]}], 

              RowBox[{\(J\_0\), 

                RowBox[{"(", 

                  FractionBox[

                    StyleBox["k",

                      FontSize->16], 

                    StyleBox[\(\(\[Lambda]\_n\) \((k)\)\),

                      FontSize->16]], ")"}]}]], ".", 

            "                                                                 \

    ", \((2.7)\)}]}]}], TraditionalForm]], "Input",

  FormatType->StandardForm,

  FontSize->16],



Cell[TextData[{

  StyleBox["Here ",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`J\_0\)],

    FontSize->16],

  StyleBox[" and ",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`J\_1\)],

    FontSize->16],

  " ",

  StyleBox[

  "are the Bessel functions of the first kind. \nFinally, the eigenvalues ",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`a\_n\)],

    FontSize->16],

  StyleBox["(",

    FontSize->16],

  StyleBox["k",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[") are given by",

    FontSize->16]

}], "Input",

  FormatType->TextForm],



Cell[TextData[{

  StyleBox[" ",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`a\_n\)],

    FontSize->16],

  StyleBox["(",

    FontSize->16],

  StyleBox["k",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[") = ",

    FontSize->16],

  Cell[BoxData[

      FormBox[

        SuperscriptBox[

          RowBox[{"(", 

            StyleBox[

              RowBox[{\(\(\[Lambda]\_n\%2\)(k)\), " ", "+", " ", 

                FractionBox[

                  StyleBox[\(k\^2\),

                    FontSize->16], 

                  RowBox[{

                    StyleBox[\(\(\[Lambda]\_n\%2\)(k)\),

                      FontSize->16], " "}]]}],

              FontSize->16], " ", ")"}], \(1\/2\)], TraditionalForm]]],

  ".                                                                          \

                          ",

  StyleBox["  (2.8)",

    FontSize->16]

}], "Input",

  FormatType->TextForm],



Cell[TextData[{

  StyleBox[

  "We see from (2.7), which we call the eigenvalue equation, that for ",

    FontSize->16],

  StyleBox["k",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[" =0,\n",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`\(\(\[Lambda]\_n\)(0)\ \)\)],

    FontSize->16],

  StyleBox["=",

    FontSize->16],

  StyleBox[" ",

    FontSize->16,

    FontSlant->"Italic"],

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox[

            RowBox[{

              StyleBox["j",

                FontSlant->"Italic"], "1"}]], \(n\ \)], TraditionalForm]],

    FontSize->16,

    FontSlant->"Italic"],

  ", ",

  StyleBox[" where ",

    FontSize->16],

  Cell[BoxData[

      FormBox[

        StyleBox[

          SubscriptBox[

            StyleBox[

              RowBox[{

                StyleBox["j",

                  FontSlant->"Italic"], "1"}]], \(n\ \)],

          FontSize->16], TraditionalForm]]],

  " ",

  StyleBox["is the nth zero of  ",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`\(J\_1\)(\[Lambda])\)],

    FontSize->16],

  ". ",

  StyleBox["We find the  ",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`a\_n\)],

    FontSize->16],

  StyleBox["(",

    FontSize->16],

  StyleBox["k",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[") using\nthe following ",

    FontSize->16],

  StyleBox["Mathematica",

    FontFamily->"Times New Roman",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[" ",

    FontFamily->"System",

    FontSize->16],

  StyleBox["code. \n",

    FontSize->16]

}], "Input",

  FormatType->TextForm],



Cell[BoxData[{

    RowBox[{

      RowBox[{\(f1[lam_]\), " ", ":=", " ", 

        RowBox[{"lam", "*", 

          FormBox[\(\(\(J\_1\)(lam)\)\/\(\(J\_0\)(lam)\)\),

            "TraditionalForm"]}]}], "\n"}], 

    RowBox[{

      \(findroot[lam0_, k0_] := 

        lam /. FindRoot[f1[lam] == f1[k0/lam], {lam, lam0}]\), "\n"}], 

  \(eigenbranch[lam0_, \ k0_, \ dk_, \ jm_]\  := \ \n\ \ 

      Module[{Lam, a}, \ \n\ \ \ Lam[0] := findroot[lam0, k0 + 10^\(-100\)]; 

        \ \n\ \ \ Lam[1] := findroot[Lam[0], k0 + dk]; \ \n\ \ \ 

        Lam[i_] := 

          \((Lam[i] = findroot[2*Lam[i - 1] - Lam[i - 2], k0 + i*dk])\) /; 

            i >= 2; \n\ \ \ \ 

        a[i_] := \(a[i] = \@\(Lam[i]\^2 + \((k0 + i\ dk)\)\^2\/Lam[i]\^2\)\); 

        \ \n\ \ \ \ Table[{k0\  + \ j*dk, a[j]}, {j, 0, jm}]\n

        \t\ \ \ \ \ \ \ \ \ \ \ ]\)}], "Input",

  PageWidth->Infinity,

  ShowSpecialCharacters->False,

  FontSize->14],



Cell[TextData[{

  StyleBox["\nIn order to calculate the value of a particular  ",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`a\_n\)],

    FontSize->16],

  StyleBox["(",

    FontSize->16],

  StyleBox["k",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[") we use the following:\n",

    FontSize->16]

}], "Input",

  FormatType->TextForm],



Cell[BoxData[

    \(<< NumericalMath`BesselZeros`\)], "Input",

  FontSize->14],



Cell[BoxData[{\(j1[n_] := BesselJZeros[1, {n, n}]\), 

    RowBox[{

      RowBox[{

        SubscriptBox["a", 

          StyleBox[

            RowBox[{

              StyleBox["n",

                FontSize->11], "_"}]]], "[", "k_", "]"}], ":=", 

      \(\(eigenbranch[j1[n], 0, 1., k]\)[\([k + 1, 2]\)]\)}]}], "Input",

  FontSize->14],



Cell[TextData[{

  StyleBox["In this command we start at k = 0 with lam0 = j1[n]",

    FontSize->16],

  " . ",

  StyleBox[

  "We then march along \nincreasing k in steps of 1, until we reach the \

desired value of k. This is \nsimilar to the idea used in the shooting method \

to march along to ",

    FontSize->16],

  "get ",

  StyleBox["\na branch of solutions.\n\nFor example to calculate  ",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`a\_3\)],

    FontSize->16],

  StyleBox["(38) and ",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`a\_4\)],

    FontSize->16],

  StyleBox["(38) we would use\n",

    FontSize->16]

}], "Input",

  FormatType->TextForm,

  FontSize->16],



Cell[BoxData[

    RowBox[{"{", 

      RowBox[{\(a\_3[38]\), ",", 

        RowBox[{

          SubscriptBox["a", 

            StyleBox["4",

              FontWeight->"Plain"]], "[", "38", "]"}]}], "}"}]], "Input",

  FontSize->14],



Cell[CellGroupData[{



Cell[TextData[StyleBox["and get,",

  FontSize->16]], "Input",

  FormatType->TextForm],



Cell["{13.314,15.5456}", "Output",

  GeneratedCell->False,

  CellAutoOverwrite->False,

  FontSize->14]

}, Open  ]],



Cell[TextData[{

  StyleBox["\n\nWe could plot the graphs of the  ",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`a\_n\)],

    FontSize->16],

  StyleBox["(",

    FontSize->16],

  StyleBox["k",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[") with the following command.\n",

    FontSize->16]

}], "Input",

  FormatType->TextForm],



Cell[BoxData[

    \(eigenbranchgraph[k0_, dk_, jm_, mm_] := \n\t

      Show[Table[Graphics[{Line[eigenbranch[j1[m], k0, dk, jm]]}], {m, mm}], 

        \n\t\tAxes -> Automatic, AxesOrigin -> {0, 0}, \n\t\t

        AxesLabel -> {k, a}, PlotLabel -> \*"\"\<\!\(a\_n\)(k)\>\""]\)], 

  "Input",

  FontSize->14],



Cell[TextData[{

  StyleBox["\nFor example to plot the first five  ",

    FontSize->16],

  Cell[BoxData[

      \(TraditionalForm\`a\_n\)],

    FontSize->16],

  StyleBox["(",

    FontSize->16],

  StyleBox["k",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox["), for  0 \[LessSlantEqual] ",

    FontSize->16],

  StyleBox["k",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[" \[LessSlantEqual] 100, we would use:\n",

    FontSize->16]

}], "Input",

  FormatType->TextForm],



Cell[CellGroupData[{



Cell[BoxData[

    \(eigenbranchgraph[0, 1., 100, 5]\)], "Input",

  FontSize->14],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.00952381 -0.119356 0.03499 [

[.21429 -0.13186 -6 -9 ]

[.21429 -0.13186 6 0 ]

[.40476 -0.13186 -6 -9 ]

[.40476 -0.13186 6 0 ]

[.59524 -0.13186 -6 -9 ]

[.59524 -0.13186 6 0 ]

[.78571 -0.13186 -6 -9 ]

[.78571 -0.13186 6 0 ]

[.97619 -0.13186 -9 -9 ]

[.97619 -0.13186 9 0 ]

[1.025 -0.11936 0 -8 ]

[1.025 -0.11936 9 8 ]

[.01131 .05559 -6 -4.5 ]

[.01131 .05559 0 4.5 ]

[.01131 .14307 -18 -4.5 ]

[.01131 .14307 0 4.5 ]

[.01131 .23054 -12 -4.5 ]

[.01131 .23054 0 4.5 ]

[.01131 .31802 -24 -4.5 ]

[.01131 .31802 0 4.5 ]

[.01131 .40549 -12 -4.5 ]

[.01131 .40549 0 4.5 ]

[.01131 .49297 -24 -4.5 ]

[.01131 .49297 0 4.5 ]

[.01131 .58044 -12 -4.5 ]

[.01131 .58044 0 4.5 ]

[.02381 .64303 -4.5 0 ]

[.02381 .64303 4.5 16 ]

[.5 .63053 -14 0 ]

[.5 .63053 14 16 ]

[ 0 -0.11936 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 -0.11936 m

.21429 -0.11311 L

s

[(20)] .21429 -0.13186 0 1 Mshowa

.40476 -0.11936 m

.40476 -0.11311 L

s

[(40)] .40476 -0.13186 0 1 Mshowa

.59524 -0.11936 m

.59524 -0.11311 L

s

[(60)] .59524 -0.13186 0 1 Mshowa

.78571 -0.11936 m

.78571 -0.11311 L

s

[(80)] .78571 -0.13186 0 1 Mshowa

.97619 -0.11936 m

.97619 -0.11311 L

s

[(100)] .97619 -0.13186 0 1 Mshowa

.125 Mabswid

.07143 -0.11936 m

.07143 -0.11561 L

s

.11905 -0.11936 m

.11905 -0.11561 L

s

.16667 -0.11936 m

.16667 -0.11561 L

s

.2619 -0.11936 m

.2619 -0.11561 L

s

.30952 -0.11936 m

.30952 -0.11561 L

s

.35714 -0.11936 m

.35714 -0.11561 L

s

.45238 -0.11936 m

.45238 -0.11561 L

s

.5 -0.11936 m

.5 -0.11561 L

s

.54762 -0.11936 m

.54762 -0.11561 L

s

.64286 -0.11936 m

.64286 -0.11561 L

s

.69048 -0.11936 m

.69048 -0.11561 L

s

.7381 -0.11936 m

.7381 -0.11561 L

s

.83333 -0.11936 m

.83333 -0.11561 L

s

.88095 -0.11936 m

.88095 -0.11561 L

s

.92857 -0.11936 m

.92857 -0.11561 L

s

.25 Mabswid

0 -0.11936 m

1 -0.11936 L

s

gsave

1.025 -0.11936 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(k) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 .05559 m

.03006 .05559 L

s

[(5)] .01131 .05559 1 0 Mshowa

.02381 .14307 m

.03006 .14307 L

s

[(7.5)] .01131 .14307 1 0 Mshowa

.02381 .23054 m

.03006 .23054 L

s

[(10)] .01131 .23054 1 0 Mshowa

.02381 .31802 m

.03006 .31802 L

s

[(12.5)] .01131 .31802 1 0 Mshowa

.02381 .40549 m

.03006 .40549 L

s

[(15)] .01131 .40549 1 0 Mshowa

.02381 .49297 m

.03006 .49297 L

s

[(17.5)] .01131 .49297 1 0 Mshowa

.02381 .58044 m

.03006 .58044 L

s

[(20)] .01131 .58044 1 0 Mshowa

.125 Mabswid

.02381 .07309 m

.02756 .07309 L

s

.02381 .09058 m

.02756 .09058 L

s

.02381 .10808 m

.02756 .10808 L

s

.02381 .12557 m

.02756 .12557 L

s

.02381 .16056 m

.02756 .16056 L

s

.02381 .17806 m

.02756 .17806 L

s

.02381 .19555 m

.02756 .19555 L

s

.02381 .21305 m

.02756 .21305 L

s

.02381 .24804 m

.02756 .24804 L

s

.02381 .26553 m

.02756 .26553 L

s

.02381 .28303 m

.02756 .28303 L

s

.02381 .30052 m

.02756 .30052 L

s

.02381 .33551 m

.02756 .33551 L

s

.02381 .35301 m

.02756 .35301 L

s

.02381 .3705 m

.02756 .3705 L

s

.02381 .388 m

.02756 .388 L

s

.02381 .42299 m

.02756 .42299 L

s

.02381 .44048 m

.02756 .44048 L

s

.02381 .45798 m

.02756 .45798 L

s

.02381 .47547 m

.02756 .47547 L

s

.02381 .51046 m

.02756 .51046 L

s

.02381 .52796 m

.02756 .52796 L

s

.02381 .54545 m

.02756 .54545 L

s

.02381 .56295 m

.02756 .56295 L

s

.02381 .0381 m

.02756 .0381 L

s

.02381 .0206 m

.02756 .0206 L

s

.02381 .00311 m

.02756 .00311 L

s

.02381 .59794 m

.02756 .59794 L

s

.02381 .61543 m

.02756 .61543 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -75 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 16.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(n) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

72.000000 15.000000 moveto

(H) show

77.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(k) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

82.000000 15.000000 moveto

(L) show

87.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

.5 Mabswid

.02381 .01472 m

.03333 .01534 L

.04286 .01718 L

.05238 .02018 L

.0619 .02426 L

.07143 .02931 L

.08095 .03521 L

.09048 .04182 L

.1 .04901 L

.10952 .05667 L

.11905 .06464 L

.12857 .07281 L

.1381 .08102 L

.14762 .08913 L

.15714 .09699 L

.16667 .10444 L

.17619 .11136 L

.18571 .11769 L

.19524 .12341 L

.20476 .12859 L

.21429 .13332 L

.22381 .1377 L

.23333 .14184 L

.24286 .14579 L

.25238 .14963 L

.2619 .15338 L

.27143 .15709 L

.28095 .16078 L

.29048 .16446 L

.3 .16815 L

.30952 .17184 L

.31905 .17556 L

.32857 .17929 L

.3381 .18305 L

.34762 .18683 L

.35714 .19063 L

.36667 .19445 L

.37619 .19829 L

.38571 .20214 L

.39524 .20601 L

.40476 .20989 L

.41429 .21377 L

.42381 .21766 L

.43333 .22154 L

.44286 .2254 L

.45238 .22926 L

.4619 .23309 L

.47143 .23689 L

.48095 .24066 L

.49048 .24439 L

Mistroke

.5 .24807 L

.50952 .2517 L

.51905 .25527 L

.52857 .25878 L

.5381 .26222 L

.54762 .26559 L

.55714 .26889 L

.56667 .27212 L

.57619 .27528 L

.58571 .27838 L

.59524 .28141 L

.60476 .28439 L

.61429 .28732 L

.62381 .29019 L

.63333 .29303 L

.64286 .29583 L

.65238 .29859 L

.6619 .30133 L

.67143 .30404 L

.68095 .30673 L

.69048 .3094 L

.7 .31206 L

.70952 .3147 L

.71905 .31734 L

.72857 .31997 L

.7381 .32259 L

.74762 .3252 L

.75714 .32781 L

.76667 .33042 L

.77619 .33302 L

.78571 .33563 L

.79524 .33823 L

.80476 .34083 L

.81429 .34343 L

.82381 .34603 L

.83333 .34863 L

.84286 .35122 L

.85238 .35382 L

.8619 .35642 L

.87143 .35901 L

.88095 .3616 L

.89048 .36419 L

.9 .36678 L

.90952 .36936 L

.91905 .37194 L

.92857 .37451 L

.9381 .37708 L

.94762 .37964 L

.95714 .38219 L

.96667 .38474 L

Mistroke

.97619 .38727 L

Mfstroke

.02381 .12612 m

.03333 .12622 L

.04286 .12653 L

.05238 .12704 L

.0619 .12776 L

.07143 .1287 L

.08095 .12986 L

.09048 .13127 L

.1 .13293 L

.10952 .13488 L

.11905 .13715 L

.12857 .13978 L

.1381 .14283 L

.14762 .14638 L

.15714 .15051 L

.16667 .15531 L

.17619 .16082 L

.18571 .16703 L

.19524 .17388 L

.20476 .18119 L

.21429 .18875 L

.22381 .19634 L

.23333 .2037 L

.24286 .2106 L

.25238 .21687 L

.2619 .22241 L

.27143 .22722 L

.28095 .23135 L

.29048 .23494 L

.3 .2381 L

.30952 .24093 L

.31905 .24352 L

.32857 .24594 L

.3381 .24824 L

.34762 .25045 L

.35714 .25261 L

.36667 .25473 L

.37619 .25684 L

.38571 .25895 L

.39524 .26106 L

.40476 .2632 L

.41429 .26536 L

.42381 .26756 L

.43333 .26979 L

.44286 .27208 L

.45238 .27442 L

.4619 .27681 L

.47143 .27927 L

.48095 .2818 L

.49048 .2844 L

Mistroke

.5 .28709 L

.50952 .28985 L

.51905 .29269 L

.52857 .29563 L

.5381 .29864 L

.54762 .30175 L

.55714 .30493 L

.56667 .30819 L

.57619 .31151 L

.58571 .3149 L

.59524 .31834 L

.60476 .32182 L

.61429 .32533 L

.62381 .32885 L

.63333 .33237 L

.64286 .33589 L

.65238 .33937 L

.6619 .34282 L

.67143 .34622 L

.68095 .34955 L

.69048 .3528 L

.7 .35597 L

.70952 .35905 L

.71905 .36203 L

.72857 .3649 L

.7381 .36768 L

.74762 .37036 L

.75714 .37294 L

.76667 .37543 L

.77619 .37784 L

.78571 .38017 L

.79524 .38244 L

.80476 .38464 L

.81429 .38679 L

.82381 .38889 L

.83333 .39095 L

.84286 .39297 L

.85238 .39497 L

.8619 .39695 L

.87143 .3989 L

.88095 .40084 L

.89048 .40277 L

.9 .40469 L

.90952 .40661 L

.91905 .40853 L

.92857 .41044 L

.9381 .41236 L

.94762 .41429 L

.95714 .41622 L

.96667 .41816 L

Mistroke

.97619 .42012 L

Mfstroke

.02381 .23661 m

.03333 .23665 L

.04286 .23675 L

.05238 .23691 L

.0619 .23715 L

.07143 .23745 L

.08095 .23783 L

.09048 .23828 L

.1 .23881 L

.10952 .23942 L

.11905 .24012 L

.12857 .24091 L

.1381 .2418 L

.14762 .24281 L

.15714 .24395 L

.16667 .24523 L

.17619 .2467 L

.18571 .24837 L

.19524 .25029 L

.20476 .25254 L

.21429 .25518 L

.22381 .25831 L

.23333 .26205 L

.24286 .26651 L

.25238 .27175 L

.2619 .27777 L

.27143 .28446 L

.28095 .29165 L

.29048 .29907 L

.3 .30646 L

.30952 .31355 L

.31905 .32009 L

.32857 .32592 L

.3381 .33094 L

.34762 .33518 L

.35714 .33873 L

.36667 .34172 L

.37619 .34428 L

.38571 .3465 L

.39524 .34847 L

.40476 .35026 L

.41429 .35191 L

.42381 .35345 L

.43333 .35492 L

.44286 .35633 L

.45238 .3577 L

.4619 .35904 L

.47143 .36037 L

.48095 .36169 L

.49048 .36301 L

Mistroke

.5 .36433 L

.50952 .36566 L

.51905 .36701 L

.52857 .36838 L

.5381 .36977 L

.54762 .37119 L

.55714 .37264 L

.56667 .37413 L

.57619 .37566 L

.58571 .37723 L

.59524 .37885 L

.60476 .38053 L

.61429 .38227 L

.62381 .38408 L

.63333 .38596 L

.64286 .38792 L

.65238 .38997 L

.6619 .39212 L

.67143 .39436 L

.68095 .39671 L

.69048 .39917 L

.7 .40175 L

.70952 .40444 L

.71905 .40725 L

.72857 .41016 L

.7381 .41318 L

.74762 .41629 L

.75714 .41949 L

.76667 .42276 L

.77619 .42608 L

.78571 .42944 L

.79524 .43283 L

.80476 .43622 L

.81429 .43959 L

.82381 .44294 L

.83333 .44624 L

.84286 .44947 L

.85238 .45262 L

.8619 .45568 L

.87143 .45864 L

.88095 .46148 L

.89048 .4642 L

.9 .4668 L

.90952 .46928 L

.91905 .47164 L

.92857 .47389 L

.9381 .47603 L

.94762 .47807 L

.95714 .48002 L

.96667 .48189 L

Mistroke

.97619 .48368 L

Mfstroke

.02381 .34684 m

.03333 .34685 L

.04286 .3469 L

.05238 .34697 L

.0619 .34708 L

.07143 .34721 L

.08095 .34738 L

.09048 .34758 L

.1 .34781 L

.10952 .34807 L

.11905 .34837 L

.12857 .3487 L

.1381 .34908 L

.14762 .34949 L

.15714 .34995 L

.16667 .35045 L

.17619 .35101 L

.18571 .35162 L

.19524 .35229 L

.20476 .35304 L

.21429 .35386 L

.22381 .35478 L

.23333 .35582 L

.24286 .35699 L

.25238 .35832 L

.2619 .35986 L

.27143 .36165 L

.28095 .36378 L

.29048 .36633 L

.3 .36941 L

.30952 .37315 L

.31905 .37766 L

.32857 .383 L

.3381 .38913 L

.34762 .39591 L

.35714 .40313 L

.36667 .4105 L

.37619 .41774 L

.38571 .42458 L

.39524 .43079 L

.40476 .4362 L

.41429 .44078 L

.42381 .44457 L

.43333 .44771 L

.44286 .4503 L

.45238 .45248 L

.4619 .45435 L

.47143 .45597 L

.48095 .45742 L

.49048 .45872 L

Mistroke

.5 .45992 L

.50952 .46104 L

.51905 .4621 L

.52857 .4631 L

.5381 .46407 L

.54762 .46502 L

.55714 .46594 L

.56667 .46685 L

.57619 .46775 L

.58571 .46864 L

.59524 .46954 L

.60476 .47043 L

.61429 .47133 L

.62381 .47224 L

.63333 .47316 L

.64286 .47409 L

.65238 .47503 L

.6619 .47599 L

.67143 .47697 L

.68095 .47798 L

.69048 .479 L

.7 .48006 L

.70952 .48114 L

.71905 .48226 L

.72857 .48342 L

.7381 .48462 L

.74762 .48586 L

.75714 .48715 L

.76667 .4885 L

.77619 .48991 L

.78571 .49139 L

.79524 .49295 L

.80476 .49459 L

.81429 .49632 L

.82381 .49815 L

.83333 .50008 L

.84286 .50213 L

.85238 .50431 L

.8619 .50661 L

.87143 .50904 L

.88095 .5116 L

.89048 .51429 L

.9 .51711 L

.90952 .52004 L

.91905 .52308 L

.92857 .52621 L

.9381 .52941 L

.94762 .53267 L

.95714 .53597 L

.96667 .53929 L

Mistroke

.97619 .54261 L

Mfstroke

.02381 .45695 m

.03333 .45696 L

.04286 .45698 L

.05238 .45702 L

.0619 .45708 L

.07143 .45715 L

.08095 .45723 L

.09048 .45734 L

.1 .45746 L

.10952 .4576 L

.11905 .45775 L

.12857 .45792 L

.1381 .45812 L

.14762 .45833 L

.15714 .45856 L

.16667 .45881 L

.17619 .45908 L

.18571 .45938 L

.19524 .4597 L

.20476 .46005 L

.21429 .46043 L

.22381 .46084 L

.23333 .46128 L

.24286 .46176 L

.25238 .46229 L

.2619 .46286 L

.27143 .46349 L

.28095 .46419 L

.29048 .46496 L

.3 .46582 L

.30952 .4668 L

.31905 .46791 L

.32857 .4692 L

.3381 .4707 L

.34762 .47248 L

.35714 .47463 L

.36667 .47723 L

.37619 .48043 L

.38571 .48433 L

.39524 .48905 L

.40476 .49462 L

.41429 .50096 L

.42381 .50789 L

.43333 .51516 L

.44286 .52248 L

.45238 .52956 L

.4619 .53613 L

.47143 .54198 L

.48095 .54699 L

.49048 .55116 L

Mistroke

.5 .55458 L

.50952 .55737 L

.51905 .55966 L

.52857 .56157 L

.5381 .56319 L

.54762 .56459 L

.55714 .56581 L

.56667 .56691 L

.57619 .5679 L

.58571 .56882 L

.59524 .56967 L

.60476 .57047 L

.61429 .57123 L

.62381 .57196 L

.63333 .57267 L

.64286 .57336 L

.65238 .57403 L

.6619 .57469 L

.67143 .57534 L

.68095 .57599 L

.69048 .57663 L

.7 .57728 L

.70952 .57792 L

.71905 .57856 L

.72857 .57921 L

.7381 .57987 L

.74762 .58053 L

.75714 .5812 L

.76667 .58188 L

.77619 .58257 L

.78571 .58327 L

.79524 .58398 L

.80476 .58471 L

.81429 .58546 L

.82381 .58622 L

.83333 .58701 L

.84286 .58782 L

.85238 .58865 L

.8619 .58951 L

.87143 .59039 L

.88095 .59131 L

.89048 .59227 L

.9 .59327 L

.90952 .59431 L

.91905 .5954 L

.92857 .59654 L

.9381 .59775 L

.94762 .59902 L

.95714 .60037 L

.96667 .6018 L

Mistroke

.97619 .60332 L

Mfstroke

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{602, 371.875},

  ImageMargins->{{44, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  FontSize->14,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009J0001L`P10`40000100000800002008200000

P800P020P<30`<3L`:K:l00003<006H009T00<`00?l0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV

09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<003o03?o06Ko09Wo0<co

0?oo0000<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I

<c>I<fJI<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0

IYT0I/`0I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bI

I_nIIP3<IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0c

VC<cVFHcVITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<

VIW<VLc<VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`c

c?lcc01Vc3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03o

c3?oc6Koc9Woc<coc?ooc000oc<0ofH0oiT0ol`0ool0o`0coc<cofHcoiTcol`coolco`1Voc=VofIV

oiUVolaVoomVo`2Ioc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<o`3ooc?oofKooiWoolco

ooooo`0000410@820P<30`@410D51@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C

4a@D5?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooooQon5Lh@00Z>4300?Q00<0hN40CN4300;Q

00<0hN40C>4200CQ00<0hN40CN400`3Qh@02h@030>7Q04SQ1@02h@030>7Q00;Q00<0hN40Dn400:SQ

00<0hN400^400`3Q001?h@060>7Q0>40CN400`3Q0002h@030>4004gQ00<0h@000^400`3Q001;h@07

0>7Qh@3Q0002h@030>4005CQ002Yh@070>7Qh@3Q001=h@@000CQ0>40CN400`3Q0002h@030>4004gQ

00<0h@000^400`3Q001;h@070>7Qh@3Q0002h@030>4005CQ002Yh@070>7Qh@3Q001=h@030>4000;Q

00<0h@00CN4200?Q00<0h@00C^401`3QhN40h@00Bn401`3QhN40h@000^400`3Q001Dh@00Z>400`3Q

0002h@030>4004kQ0P02h@030>4004gQ00<0hN400^400`3Q001=h@030>4000;Q00<0h@00Bn401`3Q

hN40h@000^400`3Q001Dh@00ZN400`3Qh@02h@030>7Q04kQ00D0hN7Q001?h@800n400`3Qh@1=h@03

0>7Q00;Q00<0hN40BN4200CQ00<0hN400^400`3Qh@1Ch@00on7ohEcQ003ohOoQG>400?oQon5Lh@00

on7ohEcQ003ohOoQG>400?oQon4Jh@8000?Q0000?N400?oQon4Kh@030>4003kQ001<hOl0`@0=h@<0

?^4006cQ00<0hN404^400`3Qh@0Ch@030>7Q01;Q00<0hN404^400`3Qh@0Bh@030>7Q01?Q00<0hN40

4^400`3Qh@0Bh@030>7Q01;Q00<0hN404n400`3Qh@0Bh@030>7Q01;Q00<0hN404^400`3Qh@0Ch@03

0>7Q01;Q00<0hN404^400`3Qh@0Bh@030>7Q01?Q00<0hN404^400`3Qh@0Fh@040>4003gQ001/h@03

0>7Q01;Q00<0hN404n400`3Qh@0Bh@030>7Q01;Q00<0hN404^400`3Qh@0Ch@030>7Q01;Q00<0hN40

4^400`3Qh@0Bh@030>7Q01?Q00<0hN404^400`3Qh@0Bh@030>7Q01;Q00<0hN404n400`3Qh@0Bh@03

0>7Q01;Q00<0hN404^400`3Qh@0Ch@030>7Q01;Q00<0hN405^400`3Qh@0nh@00[>400`3Qh@1Bh@03

0>7Q05;Q00<0hN40D^400`3Qh@1Bh@030>7Q01GQ0P10h@00on7ohEcQ003ohOoQG>400?oQon5Lh@00

on7ohEcQ003ohOoQG>400?oQon5Lh@00on7ohEcQ003ohOoQG>400?oQon5Lh@00on7ohEcQ003ohOoQ

G>400?oQon5Lh@00on7ohEcQ003ohOoQG>400?oQon5Lh@00on7ohEcQ003ohOoQG>400?oQon5Lh@00

on7ohEcQ003ohOoQG>400?oQon5Lh@00on7ohEcQ003ohOoQG>400?oQon5Lh@00on7ohEcQ003ohOoQ

G>400?oQon5Lh@00on7ohEcQ003ohOoQG>400?oQon5Lh@00on7ohEcQ003ohOoQG>400?oQon5Lh@00

on7ohEcQ003ohOoQG>400?oQon5Lh@00on7ohEcQ003ohOoQG>400?oQon5Lh@00on7ohEcQ003ohOoQ

G>400?oQon5Lh@00on7ohEcQ003ohOoQG>400?oQon5Lh@00on7ohEcQ003ohOoQG>400?oQon5Lh@00

on7ohEcQ001Gh@030>7Q0?oQon42h@00En400`3Qh@3ohOoQ0^4005OQ0`3ohOoQ0^4005OQ00<0hN40

on7oh@;Q001Gh@030>7Q0?oQon42h@00En400`3Qh@3ohOoQ0^4005OQ00<0hN40on7oh@;Q001Gh@H0

on7nh@00En400`3Qh@03h@D0on7ih@00En400`3Qh@08h@<0on7fh@00En4300_Q0P3ohOCQ001Gh@03

0>7Q00gQ0P3ohO;Q001Gh@030>7Q00oQ00<0hN40on7_h@00En400`3Qh@0@h@80on7_h@00En400`3Q

h@0Bh@030>7Q0?oQk>4005OQ00<0hN404n420?oQk>4005OQ00<0hN405N420?oQj^4005OQ0`0Gh@80

on7Xh@00En400`3Qh@0Ih@80on7Vh@00En400`3Qh@0Kh@030>7Q0?oQhn4005OQ00<0hN407>400`3Q

h@3ohN;Q001Gh@030>7Q01gQ0P3ohN;Q001Gh@030>7Q01oQ00<0hN40on7Oh@00C^400`3Qh@06h@03

0>7Q023Q00<0hN40on7Nh@00CN400`3Q0007h@030>7Q027Q00<0hN40on7Mh@00Cn400`3Qh@05h@@0

8N400`3Qh@3ohMcQ001=h@802>400`3Qh@0Sh@030>7Q0?oQfn4004gQ00<0hN401n400`3Qh@0Th@03

0>7Q0?oQf^4004gQ0`07h@030>7Q02GQ0P3ohM[Q001Gh@030>7Q02OQ00<0hN40on7Gh@00En400`3Q

h@0Xh@030>7Q0?oQe^4005OQ00<0hN40:N420?oQe^4005OQ00<0hN40:n400`3Qh@3ohM?Q001Gh@<0

;>400`3Qh@3ohM;Q001Gh@030>7Q02gQ00<0hN40on7Ah@00En400`3Qh@0^h@030>7Q0?oQd>4005OQ

00<0hN40;n400`3Qh@3ohLoQ001Gh@030>7Q033Q00<0hN40on7>h@00En400`3Qh@0ah@030>7Q0?oQ

cN4005OQ00<0hN40<^420?oQcN4005OQ00<0hN40=>400`3Qh@3ohL[Q001Gh@<0=N400`3Qh@3ohLWQ

001Gh@030>7Q03KQ00<0hN40on78h@00En400`3Qh@0gh@030>7Q0?oQan4005OQ00<0hN40>>400`3Q

h@3ohLKQ001Gh@030>7Q03WQ0P3ohLKQ001Gh@030>7Q03_Q0P3ohLCQ001Gh@030>7Q03gQ00<0hN40

on71h@00En400`3Qh@0nh@030>7Q0?oQ`>4005OQ0`0oh@80on70h@00En400`3Qh@11h@030>7Q0?oQ

_N4005OQ00<0hN40@^400`3Qh@3ohKcQ001Gh@030>7Q04?Q0P3ohKcQ001Gh@030>7Q04GQ00<0hN40

on6ih@00En400`3Qh@16h@030>7Q0?oQ^>4005OQ00<0hN40An420?oQ^>4005OQ00<0hN40BN420?oQ

]^4005OQ3`0oh@80on6dh@00En400`3Qh@0<h@d0=>420?oQ/^4005OQ00<0hN406N4403;Q0P3ohK3Q

001Gh@030>7Q01gQ100`h@80on6^h@00En400`3Qh@0Qh@@0;^420?oQ[>4004CQ00<0hN400^400`3Q

h@02h@030>7Q00KQ00<0hN409N4502_Q0P3ohJ[Q0014h@030>7Q00KQ00<0h@001n400`3Qh@0Zh@@0

:N420?oQZ>4004CQ00<0hN402>400`3Qh@05h@@0;N4302SQ0`3ohJGQ0015h@030>7Q00GQ0P08h@03

0>7Q037Q0P0Yh@80on6Sh@00@n400`3Q0007h@030>7Q00OQ00<0hN40<n4202WQ0`3ohJ3Q0013h@<0

1n4300OQ00<0hN40=N4202[Q0`3ohIgQ001Gh@030>7Q03OQ0`0Zh@80on6Kh@00En400`3Qh@0jh@80

:^420?oQVN4005OQ00<0hN40?>4202[Q0P3ohIOQ001Gh@030>7Q03kQ0P0Zh@@0on6Ch@00En43043Q

0P0/h@<0on6@h@00En400`3Qh@12h@030>7Q02cQ0P3ohHkQ001Gh@030>7Q04?Q0P0^h@80on6<h@00

En400`3Qh@15h@030>7Q02gQ0P3ohH[Q001Gh@030>7Q04KQ00<0hN40;^430?oQQn4005OQ00<0hN40

An42037Q103ohH?Q001Gh@030>7Q04WQ00<0hN40<^420?oQPN4005OQ00<0hN40B^4203CQ0P3ohGoQ

001Gh@<0C>4203CQ0P3ohGgQ001Gh@030>7Q04kQ00<0hN40<n430?oQN^4005OQ00<0hN40Cn400`3Q

h@0eh@<0on5gh@00En400`3Qh@1@h@030>7Q03OQ0P3ohGGQ001Gh@030>7Q057Q00<0hN40>>430?oQ

L^4005OQ00<0hN40D^400`3Qh@0jh@80on5`h@00En400`3Qh@1Ch@030>7Q03_Q0`3ohFgQ001Gh@03

0>7Q05CQ0P0nh@<0on5Zh@00En4305KQ00<0hN40?^420?oQJ>4005OQ00<0hN40En400`3Qh@0oh@80

on5Vh@00En400`3Qh@1Hh@80@N420?oQI>4005OQ00<0hN40F^400`3Qh@10h@@0on5Ph@00En400`3Q

h@1Kh@80A>430?oQGN4005OQ00<0hN40GN4204GQ0P3ohE_Q001Gh@030>7Q05oQ00<0hN40A>420?oQ

FN4005OQ00<0hN40H>400`3Qh@15h@80on5Gh@00En43067Q0P17h@80on5Eh@00En400`3Qh@1Sh@03

0>7Q04KQ0P3ohE?Q001Gh@030>7Q06CQ00<0hN40An440?oQCn4005OQ00<0hN40IN4204_Q0`3ohDcQ

001Gh@030>7Q06OQ00<0hN40Bn420?oQB^4004OQ1@02h@030>7Q00KQ00<0hN40J>4204gQ0P3ohDSQ

0019h@070>7Qh@3Q0007h@030>7Q06[Q0`1<h@80on56h@00BN401`3QhN40h@001n4406cQ0P1<h@80

on54h@00BN401`3QhN40h@001n400`3Qh@1_h@<0Bn420?oQ@^4004WQ00L0hN7Q0>4000OQ00<0hN40

L^4304[Q103ohCkQ0018h@801>400`3Qh@06hAL0HN4204cQ0`3ohC_Q001Gh@030>7Q01CQ4@1Bh@<0

C>420?oQ>N4005OQ00<0hN409N4=04SQ1@19h@80on4gh@00En400`3Qh@0bh@T0A>4404OQ0P3ohCGQ

001Gh@030>7Q03_Q1014h@@0AN430?oQ<^4005OQ0`0oh@P0@>4404CQ103ohBkQ001Gh@030>7Q04OQ

1@0oh@D0@n420?oQ;>4005OQ00<0hN40C>44043Q1011h@<0on4Yh@00En400`3Qh@1@h@<0@N44043Q

0`3ohBKQ001Gh@030>7Q05?Q0P13h@@0?n420?oQ9>4005OQ00<0hN40EN4304CQ1@0lh@80on4Rh@00

En400`3Qh@1Hh@@0AN4403[Q0P3ohB3Q001Gh@030>7Q05cQ0P17h@@0>>440?oQ7>4005OQ0`1Nh@80

BN4403SQ103ohASQ001Gh@030>7Q063Q00<0hN40B^4503OQ0`3ohAGQ001Gh@030>7Q067Q0P1?h@@0

=^420?oQ4n4005OQ00<0hN40Hn400`3Qh@1@h@@0=>430?oQ4>4005OQ00<0hN40I>4205CQ100ch@@0

on4<h@00En400`3Qh@1Vh@80E^4503;Q0P3oh@[Q001Gh@030>7Q06SQ00<0hN40F>44033Q0`3oh@OQ

001Gh@030>7Q06WQ0P1Lh@@0;n440?oQ0n4005OQ0`1[h@030>7Q05gQ0`0`h@<0on4005OQ00<0hN40

K>400`3Qh@1Oh@80<N420?gQ001Gh@030>7Q06gQ0P1Qh@@0;n440?WQ001Gh@030>7Q06oQ00<0hN40

H^4402oQ103eh@00En400`3Qh@1`h@030>7Q06GQ100_h@<0l^4005OQ00<0hN40LN400`3Qh@1Xh@<0

;n420?3Q001Gh@030>7Q07;Q0P1[h@80;n430>gQ001Gh@030>7Q07CQ00<0hN40J^4402kQ1@3Xh@00

En4307GQ00<0hN40KN43033Q103Th@00En400`3Qh@1fh@80L>4203;Q103Ph@00En400`3Qh@1hh@03

0>7Q06oQ0`0ch@<0gN4005OQ00<0hN40NN400`3Qh@1ah@<0<n420=_Q001Gh@030>7Q07[Q0P1dh@80

<n440=OQ000mh@D000CQ00000n400`3Qh@02h@030>7Q00KQ00<0hN40O>400`3Qh@1ch@@0<n440=?Q

000oh@050>7Qh@002N400`3Q0007h@030>7Q07gQ0P1gh@<0=>440<oQ000oh@030>7Q00;Q00<0hN40

2>400`3Qh@05h@@0O^4207SQ0P0fh@@0bn4003oQ00<0hN400^400`3Qh@06h@802>400`3Qh@21h@03

0>7Q07OQ0`0gh@D0a^4003oQ00L0hN7Q0>4000OQ00<0hN401n400`3Qh@22h@030>7Q07WQ0`0ih@<0

`n4003kQ0P04h@030>7Q00KQ0`07h@030>7Q08?Q0P1lh@80>^420<7Q001Gh@030>7Q08GQ00<0hN40

Nn4403SQ0`2nh@00En400`3Qh@26h@80On4303SQ102jh@00En400`3Qh@28h@80P>4203[Q1@2eh@00

En400`3Qh@2:h@80P>4303cQ102ah@00En4308cQ0`20h@<0?N440:gQ001Gh@030>7Q08oQ0P21h@80

?n430:[Q001Gh@030>7Q097Q0`20h@@0?^420:SQ001Gh@030>7Q09CQ1020h@<0?N440:CQ001Gh@03

0>7Q09SQ101oh@80?n440:3Q001GhAL0R>4507cQ0P11h@@0W>4005OQ00<0hN405>4R06_Q101jh@80

@n4409SQ001Gh@030>7Q03KQ4@1Nh@@0N>4304CQ1@2Ch@00En4304OQ3@1Eh@T0L^4504CQ0`2@h@00

En400`3Qh@1Dh@T0EN4407?Q0`14h@80S^4005OQ00<0hN40GN48057Q201^h@80A>4308_Q001Gh@03

0>7Q06GQ101Eh@T0In4304CQ1027h@00En400`3Qh@1Yh@D0FN4406KQ1014h@D0P^4005OQ00<0hN40

K^4405WQ2@1Qh@@0AN4407kQ001Gh@030>7Q07;Q101Nh@P0GN4204OQ101jh@00En400`3Qh@1fh@<0

Hn4405_Q0`18h@@0M^4005OQ0`1ih@80IN4905GQ1018h@@0L^4005OQ00<0hN40Nn4306_Q201Ah@@0

B>42073Q001Gh@030>7Q07kQ0P1ah@D0D>4504GQ0`1]h@00En400`3Qh@20h@80M>44057Q1014h@@0

JN4005OQ00<0hN40P^4207KQ201=h@@0A>4406GQ001Gh@030>7Q08CQ0P1lh@D0C>4404CQ1@1Ph@00

En400`3Qh@26h@030>7Q07kQ101<h@D0A>4405cQ001Gh@030>7Q08OQ0P22h@@0CN4404CQ0`1Ih@00

En4308WQ00<0hN40Pn4404gQ102Lh@00En400`3Qh@2:h@030>7Q08KQ1@1<h@@0V>4005OQ00<0hN40

Rn4208_Q101<h@D0Tn4005OQ00<0hN40SN400`3Qh@2<h@@0CN4408oQ001Gh@030>7Q08kQ0P2@h@@0

CN4408_Q0017h@D00^400`3Qh@06h@030>7Q093Q0P2Bh@D0C>4908;Q0019h@070>7Qh@3Q0007h@03

0>7Q09;Q00<0hN40U>44057Q101nh@00BN400`3Qh@03h@030>7Q00GQ102Bh@030>7Q09OQ101Ah@@0

N^4004WQ00@0hN7Q0P08h@030>7Q09CQ00<0hN40V^4305;Q101fh@00BN401@3QhN4000WQ00<0hN40

UN400`3Qh@2Lh@80E>45077Q0018h@800n4300OQ00<0hN40U^400`3Qh@2Mh@@0EN4406gQ001Gh@03

0>7Q09OQ00<0hN40X>4405GQ201Uh@00En400`3Qh@2Hh@80Y>4305[Q1@1Ph@00En400`3Qh@2Jh@03

0>7Q0:CQ0P1Mh@@0G>4005OQ00<0hN40Vn400`3Qh@2Uh@<0G^4305WQ001Gh@<0W>420:SQ102fh@00

En400`3Qh@2Nh@030>7Q0:WQ0P2dh@00En400`3Qh@2Oh@80Zn430;7Q001Gh@030>7Q0:7Q0P2/h@<0

[^4005OQ00<0hN40Xn400`3Qh@2/h@80[>4005OQ00<0hN40Y>420:kQ0`2Yh@00En400`3Qh@2Vh@80

[n440:GQ001Gh@030>7Q0:SQ0P2ah@80Xn4005OQ0`2Zh@80/N430:3Q001Gh@030>7Q0:cQ0P2bh@<0

WN4005OQ00<0hN40[^440;7Q0P2Kh@00En400`3Qh@2bh@@0[n4309SQ001Gh@030>7Q0;KQ102^h@@0

U>4005OQ00<0hN40^^440:kQ0P2Bh@00En400`3Qh@2nh@D0Zn4308oQ001GhA<0/n440:[Q102;h@00

En43013Q<`24h@P0Y^4408OQ001Gh@030>7Q04?Q6P1bh@T0XN4408?Q001Gh@030>7Q05gQ4@1Zh@P0

WN42087Q001Gh@030>7Q06kQ301Vh@d0T^4307kQ001Gh@030>7Q07[Q2@1Zh@T0S>4407[Q001Gh@03

0>7Q08?Q101_h@`0Q>4407KQ001Gh@030>7Q08OQ2@1bh@T0On45077Q001Gh@030>7Q093Q101gh@P0

O>4406gQ001Gh@<0U>4307cQ3@1ch@@0JN4005OQ00<0hN40Un4208OQ2@1^h@@0IN4005OQ00<0hN40

VN4208kQ201Zh@D0H>4005OQ00<0hN40Vn4209CQ2@1Vh@L0FN4005OQ00<0hN40WN4309[Q202nh@00

En400`3Qh@2Ph@80X>440;[Q000mh@D00^400`3Qh@02h@030>7Q00;Q00<0hN401^400`3Qh@2Rh@80

X^490;7Q000oh@030>7Q00;Q00<0hN401^400`3Q0007h@030>7Q0:CQ0P2Yh@@0[N4003oQ00<0hN40

0^400`3Qh@08h@030>7Q00GQ102Uh@80Zn490:CQ000oh@030>7Q00?Q00<0hN401N4200SQ00<0hN40

Z>400`3Qh@2ah@@0X>4003oQ00L0hN7Q0>4000OQ00<0hN401n400`3Qh@2Yh@80]N4409cQ000nh@80

0n4300OQ0`07h@030>7Q0:_Q00<0hN40]^4409SQ001Gh@030>7Q0:cQ00<0hN40^N4509?Q001Gh@03

0>7Q0:gQ0P2nh@@0Sn4005OQ00<0hN40[n400`3Qh@2oh@@0Rn4005OQ0`2`h@80`n4408OQ001Gh@03

0>7Q0;;Q0P35h@D0P^4005OQ00<0hN40]>400`3Qh@37h@@0O^4005OQ00<0hN40]N400`3Qh@3:h@<0

Nn4005OQ00<0hN40]^400`3Qh@3<h@80NN4005OQ00<0hN40]n400`3Qh@3=h@<0M^4005OQ00<0hN40

^>400`3Qh@3?h@D0LN4005OQ00<0hN40^N400`3Qh@3Ch@<0K^4005OQ0`2jh@80e^4206cQ001Gh@03

0>7Q0;cQ00<0hN40eN4306WQ001Gh@030>7Q0;gQ00<0hN40en4306KQ001Gh@030>7Q0;kQ0P3Jh@80

I>4005OQ00<0hN40`>420=[Q101Ph@00En400`3Qh@32h@80g>4305gQ001Gh@030>7Q0<CQ0P3Mh@80

Fn4005OQ00<0hN40a^400`3Qh@3Lh@80FN4005OQ0`37h@80on4hh@00En400`3Qh@39h@80on4fh@00

En400`3Qh@3;h@<0on4ch@00En400`3Qh@3>h@80on4ah@00En400`3Qh@3@h@@0on4]h@00En400`3Q

h@3Dh@@0on4Yh@00En400`3Qh@3Hh@@0on4Uh@00En400`3Qh@3Lh@@0on4Qh@00En430>3Q2@3ohASQ

001Gh@030>7Q0>WQ103ohACQ001Gh@030>7Q0>gQ3@3oh@OQ001Gh@030>7Q0?[Q3@3ih@00En400`3Q

h@3oh@SQ303]h@00En400`3Qh@3ohACQ3@3Ph@00B>4300?Q00<0hN401^400`3Qh@3ohB7Q4@3?h@00

B>400`3Qh@02h@030>4000OQ00<0hN40on4bh@d0`^4004WQ00L0hN7Q0>4000OQ103ohCkQ3@2eh@00

BN401`3QhN40h@001n400`3Qh@3ohDcQ4@2Th@00B>400`3Q0002h@030>4000OQ00<0hN40on5Mh@`0

V>4004WQ00<0hN400^400`3Qh@06h@030>7Q0?oQJN4908oQ001Gh@030>7Q0?oQL^4=08;Q001Gh@03

0>7Q0?oQOn4807[Q001Gh@030>7Q0?oQQn49077Q001Gh@<0on6@h@P0JN4005OQ00<0hN40on6Hh@T0

H>4005OQ00<0hN40on6Qh@@0G>4005OQ00<0hN40on6Uh@<0FN4005OQ00<0hN40on7oh@;Q001Gh@03

0>7Q0?oQon42h@00En400`3Qh@3ohOoQ0^4005OQ00<0hN40on7oh@;Q001Gh@<0on7oh@;Q001Gh@03

0>7Q0?oQon42h@00on7ohEcQ003ohOoQG>400?oQon5Lh@00on7ohEcQ003ohOoQG>400?oQon5Lh@00

on7ohEcQ003ohOoQG>400?oQon5Lh@00on4Uh@8000?Q0>400n400`3Qh@04h@030>7Q0?oQ9N400?oQ

9^400`3Q0003h@030>7Q00KQ00<0hN40on4Th@00on4Qh@@000CQ0>400^400`3Qh@020003h@0000?Q

00<0hN40on4Sh@00on4Qh@<00n401@3QhN4000?Q00<0h@001>400`3Qh@3ohB?Q003ohB?Q00<0hN40

1N40103QhN4300CQ00<0hN40on4Sh@00on4Rh@801n401P3QhN40h@800n400`3Qh@3ohB?Q003ohBcQ

00@0hN401N400`3Qh@3ohBCQ001Eh@@0dn4300CQ00<0hN40on4Uh@00EN430?oQon44h@00En400`3Q

h@3ohOoQ0^4005KQ0P3ohOoQ1>400?oQon5Lh@00on7ohEcQ003ohOoQG>400?oQon5Lh@00on7ohEcQ

003ohOoQG>400?oQon5Lh@00\

\>"],

  ImageRangeCache->{{{74.25, 554.813}, {381, 84.5}} -> {-42.4148, 5.83387, 

  0.235412, 0.064076}}]

}, Open  ]]

}, Open  ]],



Cell[CellGroupData[{



Cell[TextData[StyleBox["2.3 The Shooting Method for the Buckled Plate",

  FontSize->18]], "Subsection",

  FontSize->18],



Cell[TextData[{

  "Associated with the BVP (2.1)-(2.3) is the following IVP in the form of \

six first \norder differential equations and six initial conditions,\n\nq' = \

q1,\np' = p1,\nW' = W1,\nq1' + ",

  Cell[BoxData[

      FormBox[

        FractionBox["3", 

          StyleBox["r",

            FontSize->16]], TraditionalForm]]],

  "q1 + ",

  Cell[BoxData[

      \(TraditionalForm\`a\^2\)]],

  "pq = ",

  Cell[BoxData[

      \(TraditionalForm\`k\^2\)]],

  "W,\n\np1' +  ",

  Cell[BoxData[

      FormBox[

        FractionBox["3", 

          StyleBox["r",

            FontSize->16]], TraditionalForm]]],

  "p1 = ",

  Cell[BoxData[

      \(TraditionalForm\`1\/2\)]],

  Cell[BoxData[

      FormBox[

        SuperscriptBox[

          StyleBox["q",

            FontSlant->"Plain"], "2"], TraditionalForm]]],

  ",                                                                          \

        (2.9)\n\nW1' + ",

  Cell[BoxData[

      FormBox[

        FractionBox["3", 

          StyleBox["r",

            FontSize->16]], TraditionalForm]]],

  "W1 + q = 0,\nq1(0) = 0,  p1(0) = 0,  W1(0) = 0,\nq(0) = ",

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox["q",

            FontSlant->"Plain"], "0"], TraditionalForm]]],

  ",  p(0) = ",

  Cell[BoxData[

      FormBox[

        RowBox[{

          SubscriptBox[

            StyleBox["p",

              FontSlant->"Plain"], 

            StyleBox["0",

              FontSize->12]], ","}], TraditionalForm]]],

  "  W(0) = ",

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox["W",

            FontSlant->"Plain"], "0"], TraditionalForm]]],

  ".\n\nA solution {q(",

  StyleBox["r",

    FontSlant->"Italic"],

  ",",

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox["q",

            FontSlant->"Plain"], "0"], TraditionalForm]]],

  ",",

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox["p",

            FontSlant->"Plain"], 

          StyleBox["0",

            FontSize->12]], TraditionalForm]]],

  ",",

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox["W",

            FontSlant->"Plain"], "0"], TraditionalForm]]],

  "), p(",

  StyleBox["r",

    FontSlant->"Italic"],

  ",",

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox["q",

            FontSlant->"Plain"], "0"], TraditionalForm]]],

  ",",

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox["p",

            FontSlant->"Plain"], 

          StyleBox["0",

            FontSize->12]], TraditionalForm]]],

  ",",

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox["W",

            FontSlant->"Plain"], "0"], TraditionalForm]]],

  "), W(",

  StyleBox["r",

    FontSlant->"Italic"],

  ",",

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox["q",

            FontSlant->"Plain"], "0"], TraditionalForm]]],

  ",",

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox["p",

            FontSlant->"Plain"], 

          StyleBox["0",

            FontSize->12]], TraditionalForm]]],

  ",",

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox["W",

            FontSlant->"Plain"], "0"], TraditionalForm]]],

  ")} of this IVP will be a\nsolution of the BVP if ",

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox["q",

            FontSlant->"Plain"], "0"], TraditionalForm]]],

  ", ",

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox["p",

            FontSlant->"Plain"], 

          StyleBox["0",

            FontSize->12]], TraditionalForm]]],

  ", and ",

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox["W",

            FontSlant->"Plain"], "0"], TraditionalForm]]],

  " satisfy (2.3). That is, if\n\nF(",

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox["q",

            FontSlant->"Plain"], "0"], TraditionalForm]]],

  ",",

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox["p",

            FontSlant->"Plain"], 

          StyleBox["0",

            FontSize->12]], TraditionalForm]]],

  ",",

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox["W",

            FontSlant->"Plain"], "0"], TraditionalForm]]],

  ") = ",

  Cell[BoxData[

      FormBox[

        RowBox[{"(", GridBox[{

              {

                RowBox[{

                  StyleBox["q",

                    FontSlant->"Plain"], "(", 

                  RowBox[{"1", ",", 

                    FormBox[

                      SubscriptBox[

                        StyleBox["q",

                          FontSlant->"Plain"], "0"],

                      "TraditionalForm"], ",", 

                    FormBox[

                      SubscriptBox[

                        StyleBox["p",

                          FontSlant->"Plain"], 

                        StyleBox["0",

                          FontSize->12]],

                      "TraditionalForm"], ",", 

                    FormBox[

                      SubscriptBox[

                        StyleBox["W",

                          FontSlant->"Plain"], "0"],

                      "TraditionalForm"]}], ")"}]},

              {

                RowBox[{"                         ", 

                  RowBox[{

                    RowBox[{

                      RowBox[{

                        StyleBox["p",

                          FontSlant->"Plain"], "(", 

                        RowBox[{"1", ",", 

                          FormBox[

                            SubscriptBox[

                              StyleBox["q",

                                FontSlant->"Plain"], "0"],

                            "TraditionalForm"], ",", 

                          FormBox[

                            SubscriptBox[

                              StyleBox["p",

                                FontSlant->"Plain"], 

                              StyleBox["0",

                                FontSize->12]],

                            "TraditionalForm"], ",", 

                          FormBox[

                            SubscriptBox[

                              StyleBox["W",

                                FontSlant->"Plain"], "0"],

                            "TraditionalForm"]}], ")"}], "-", "1"}], "\n", 

                    RowBox[{

                      RowBox[{"W1", "(", 

                        RowBox[{"1", ",", 

                          FormBox[

                            SubscriptBox[

                              StyleBox["q",

                                FontSlant->"Plain"], "0"],

                            "TraditionalForm"], ",", 

                          FormBox[

                            SubscriptBox[

                              StyleBox["p",

                                FontSlant->"Plain"], 

                              StyleBox["0",

                                FontSize->12]],

                            "TraditionalForm"], ",", 

                          FormBox[

                            SubscriptBox[

                              StyleBox["W",

                                FontSlant->"Plain"], "0"],

                            "TraditionalForm"]}], ")"}], "+", 

                      RowBox[{"2", 

                        RowBox[{

                          StyleBox["W",

                            FontSlant->"Plain"], "(", 

                          RowBox[{"1", ",", 

                            FormBox[

                              SubscriptBox[

                                StyleBox["q",

                                  FontSlant->"Plain"], "0"],

                              "TraditionalForm"], ",", 

                            FormBox[

                              SubscriptBox[

                                StyleBox["p",

                                  FontSlant->"Plain"], 

                                StyleBox["0",

                                  FontSize->12]],

                              "TraditionalForm"], ",", 

                            FormBox[

                              SubscriptBox[

                                StyleBox["W",

                                  FontSlant->"Plain"], "0"],

                              "TraditionalForm"]}], ")"}]}]}]}], "\t"}]}

              }], "\[NegativeThinSpace]", ")"}], TraditionalForm]]],

  "  = 0.        (2.10)\n\nWe wish to solve F(",

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox["q",

            FontSlant->"Plain"], "0"], TraditionalForm]]],

  ",",

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox["p",

            FontSlant->"Plain"], 

          StyleBox["0",

            FontSize->12]], TraditionalForm]]],

  ",",

  Cell[BoxData[

      FormBox[

        SubscriptBox[

          StyleBox["W",

            FontSlant->"Plain"], "0"], TraditionalForm]]],

  ") = 0 for (",

  Cell[BoxData[

      FormBox[

        RowBox[{

          RowBox[{

            FormBox[

              SubscriptBox[

                StyleBox["q",

                  FontSlant->"Plain"], "0"],

              "TraditionalForm"], ",", 

            FormBox[

              SubscriptBox[

                StyleBox["p",

                  FontSlant->"Plain"], 

                StyleBox["0",

                  FontSize->12]],

              "TraditionalForm"], ",", 

            FormBox[

              SubscriptBox[

                StyleBox["W",

                  FontSlant->"Plain"], "0"],

              "TraditionalForm"]}], ")"}], TraditionalForm]]],

  " using Newton's method.\nThis iteration scheme takes the form\n\n",

  Cell[BoxData[

      FormBox[

        SubscriptBox["Q", 

          RowBox[{

            StyleBox["n",

              FontSlant->"Plain"], "+", "1"}]], TraditionalForm]]],

  " = ",

  Cell[BoxData[

      FormBox[

        SubscriptBox["Q", 

          StyleBox["n",

            FontSlant->"Plain"]], TraditionalForm]]],

  " - ",

  Cell[BoxData[

      FormBox[

        SuperscriptBox[

          RowBox[{"(", 

            RowBox[{

              SubscriptBox["\[PartialD]", 

                StyleBox["Q",

                  FontSize->14,

                  FontSlant->"Italic"]], 

              RowBox[{"F", "(", 

                SubscriptBox["Q", 

                  StyleBox["n",

                    FontSlant->"Plain"]], ")"}]}], ")"}], \(-1\)], 

        TraditionalForm]]],

  "F(",

  Cell[BoxData[

      FormBox[

        RowBox[{

          SubscriptBox["Q", 

            StyleBox["n",

              FontSlant->"Plain"]], ")"}], TraditionalForm]]],

  ",\n\nwhere ",

  StyleBox["Q = ",

    FontSlant->"Italic"],

  Cell[BoxData[

      FormBox[

        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{

              {

                RowBox[{

                  SubscriptBox[

                    StyleBox["q",

                      FontSlant->"Plain"], "0"], "\n", 

                  SubscriptBox[

                    StyleBox["p",

                      FontSlant->"Plain"], "0"]}]},

              {

                SubscriptBox[

                  StyleBox["W",

                    FontSlant->"Plain"], "0"]}

              }], "\[NegativeThinSpace]", ")"}], TraditionalForm]]],

  " and  ",

  Cell[BoxData[

      FormBox[

        RowBox[{

          SubscriptBox["\[PartialD]", 

            StyleBox["Q",

              FontSize->14,

              FontSlant->"Italic"]], \(F(Q)\)}], TraditionalForm]]],

  " = ",

  Cell[BoxData[

      FormBox[

        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{

              {GridBox[{

                    {

                      RowBox[{

                        RowBox[{

                          SubscriptBox["\[PartialD]", 

                            SubscriptBox[

                              StyleBox["q",

                                FontSlant->"Plain"], "0"]], 

                          StyleBox["q",

                            FontSlant->"Plain"]}], 

                        StyleBox[

                          RowBox[{

                            StyleBox[" ",

                              FontSlant->"Plain"], 

                            "                      "}]]}], 

                      RowBox[{

                        SubscriptBox["\[PartialD]", 

                          SubscriptBox[

                            StyleBox["p",

                              FontSlant->"Plain"], "0"]], 

                        StyleBox["q",

                          FontSlant->"Plain"]}]}

                    }], 

                RowBox[{

                  SubscriptBox["\[PartialD]", 

                    SubscriptBox[

                      StyleBox["W",

                        FontSlant->"Plain"], "0"]], 

                  StyleBox["q",

                    FontSlant->"Plain"]}]},

              {GridBox[{

                    {GridBox[{

                          {

                            RowBox[{

                              SubscriptBox["\[PartialD]", 

                                SubscriptBox[

                                  StyleBox["q",

                                    FontSlant->"Plain"], "0"]], 

                              StyleBox["p",

                                FontSlant->"Plain"]}]},

                          {

                            RowBox[{

                              SubscriptBox["\[PartialD]", 

                                SubscriptBox[

                                  StyleBox["q",

                                    FontSlant->"Plain"], "0"]], 

                              RowBox[{"(", 

                                RowBox[{"W1", "+", 

                                  RowBox[{"2", 

                                    StyleBox["W",

                                      FontSlant->"Plain"]}]}], ")"}]}]}

                          }], GridBox[{

                          {

                            RowBox[{

                              SubscriptBox["\[PartialD]", 

                                SubscriptBox[

                                  StyleBox["p",

                                    FontSlant->"Plain"], "0"]], 

                              StyleBox["p",

                                FontSlant->"Plain"]}]},

                          {

                            RowBox[{

                              SubscriptBox["\[PartialD]", 

                                SubscriptBox[

                                  StyleBox["p",

                                    FontSlant->"Plain"], "0"]], 

                              RowBox[{"(", 

                                RowBox[{"W1", "+", 

                                  RowBox[{"2", 

                                    StyleBox["W",

                                      FontSlant->"Plain"]}]}], ")"}]}]}

                          }]}

                    }], GridBox[{

                    {

                      RowBox[{

                        SubscriptBox["\[PartialD]", 

                          SubscriptBox[

                            StyleBox["W",

                              FontSlant->"Plain"], "0"]], 

                        StyleBox["p",

                          FontSlant->"Plain"]}]},

                    {

                      RowBox[{

                        SubscriptBox["\[PartialD]", 

                          SubscriptBox[

                            StyleBox["W",

                              FontSlant->"Plain"], "0"]], 

                        RowBox[{"(", 

                          RowBox[{"W1", "+", 

                            RowBox[{"2", 

                              StyleBox["W",

                                FontSlant->"Plain"]}]}], ")"}]}]}

                    }]}

              }], "\[NegativeThinSpace]", ")"}], TraditionalForm]]],

  " \n\nis the Jacobian matrix. In order to obtain the partial derivatives \

needed in\nthe above Jacobian matrix, we first differentiate each of the \

equations in  the\nfollowing IVP with respect to ",

  Cell[BoxData[

      FormBox[

        RowBox[{

          FormBox[

            SubscriptBox[

              StyleBox["q",

                FontSlant->"Plain"], "0"],

            "TraditionalForm"], ",", 

          FormBox[

            SubscriptBox[

              StyleBox["p",

                FontSlant->"Plain"], 

              StyleBox["0",

                FontSize->12]],

            "TraditionalForm"], ",", 

          FormBox[

            SubscriptBox[

              StyleBox["W",

                FontSlant->"Plain"], "0"],

            "TraditionalForm"]}], TraditionalForm]]],

  ", respectively.\n"

}], "Input",

  FormatType->TextForm,

  FontSize->16],



Cell[BoxData[

    RowBox[{

      RowBox[{"eqs", "=", 

        RowBox[{"{", 

          RowBox[{

            RowBox[{

              RowBox[{

                SuperscriptBox["q", "\[Prime]",

                  MultilineFunction->None], "[", \(r, q0, p0, w0\), "]"}], 

              "==", \(q1[r, q0, p0, w0]\)}], ",", "\n", "\t\t         ", 

            RowBox[{

              RowBox[{

                SuperscriptBox["p", "\[Prime]",

                  MultilineFunction->None], "[", \(r, q0, p0, w0\), "]"}], 

              "==", \(p1[r, q0, p0, w0]\)}], ",", "\n", "\t\t         ", 

            RowBox[{

              RowBox[{

                SuperscriptBox["w", "\[Prime]",

                  MultilineFunction->None], "[", \(r, q0, p0, w0\), "]"}], 

              "==", \(w1[r, q0, p0, w0]\)}], ",", "\n", "\t\t       ", 

            RowBox[{

              RowBox[{

                RowBox[{

                  SuperscriptBox["q1", "\[Prime]",

                    MultilineFunction->None], "[", \(r, q0, p0, w0\), "]"}], 

                "+", \(\((3*q1[r, \ q0, \ p0, \ w0])\)/r\), "+", "\n", 

                "\t\t\t                      ", 

                \(a\^2\ p[r, q0, p0, w0]\ q[r, q0, p0, w0]\)}], "==", 

              \(k\^2\ w[r, q0, p0, w0]\)}], ",", "       ", 

            RowBox[{

              RowBox[{

                RowBox[{

                  SuperscriptBox["p1", "\[Prime]",

                    MultilineFunction->None], "[", \(r, q0, p0, w0\), "]"}], 

                "+", \(\((3*p1[r, \ q0, \ p0, \ w0])\)/r\)}], "==", 

              \(0.5\ q[r, q0, p0, w0]^2\)}], ",", 

            RowBox[{

              RowBox[{

                RowBox[{

                  SuperscriptBox["w1", "\[Prime]",

                    MultilineFunction->None], "[", \(r, q0, p0, w0\), "]"}], 

                "+", \(\((3*w1[r, \ q0, \ p0, \ w0])\)/r\), "+", 

                \(q[r, q0, p0, w0]\)}], "==", "0"}], ",", 

            \(q1[10^\(-6\), q0, p0, w0] == 0\), ",", 

            \(p1[10^\(-6\), q0, p0, w0] == 0\), ",", 

            \(w1[10^\(-6\), q0, p0, w0] == 0\), ",", 

            \(q[10^\(-6\), q0, p0, w0] == q0\), ",", 

            \(p[10^\(-6\), q0, p0, w0] == p0\), ",", 

            \(w[10^\(-6\), q0, p0, w0] == w0\)}], "}"}]}], ";"}]], "Input",

  FontSize->14],



Cell[TextData[{

  "\nWe also simplify the notation. These steps are accomplished using the \n\

following ",

  StyleBox["Mathematica",

    FontSlant->"Italic"],

  " code.\n"

}], "Input",

  FormatType->TextForm,

  FontSize->16],



Cell[BoxData[

    \(cat[x_, y_] := ToExpression[StringJoin[ToString[x], ToString[y]]]\)], 

  "Input"],



Cell[BoxData[

    RowBox[{

      RowBox[{"newnames", "=", 

        RowBox[{"{", 

          RowBox[{

            RowBox[{

              RowBox[{

                SubscriptBox["\[PartialD]", 

                  StyleBox["q0",

                    FontSize->10]], 

                RowBox[{

                  SuperscriptBox["q_", "\[Prime]",

                    MultilineFunction->None], "[", \(r, q0, p0, w0\), "]"}]}],

               "\[RuleDelayed]", 

              RowBox[{

                SuperscriptBox[\(\(cat[q, d]\)[1]\), "\[Prime]",

                  MultilineFunction->None], "[", "r", "]"}]}], ",", "\n", 

            "\t\t                ", 

            RowBox[{

              RowBox[{\(\[PartialD]\_p0\), 

                RowBox[{

                  SuperscriptBox["q_", "\[Prime]",

                    MultilineFunction->None], "[", \(r, q0, p0, w0\), "]"}]}],

               "\[RuleDelayed]", 

              RowBox[{

                SuperscriptBox[\(\(cat[q, d]\)[2]\), "\[Prime]",

                  MultilineFunction->None], "[", "r", "]"}]}], ",", "\n", 

            "\t\t                ", 

            RowBox[{

              RowBox[{\(\[PartialD]\_w0\), 

                RowBox[{

                  SuperscriptBox["q_", "\[Prime]",

                    MultilineFunction->None], "[", \(r, q0, p0, w0\), "]"}]}],

               "\[RuleDelayed]", 

              RowBox[{

                SuperscriptBox[\(\(cat[q, d]\)[3]\), "\[Prime]",

                  MultilineFunction->None], "[", "r", "]"}]}], ",", "\n", 

            "\t\t                ", 

            \(\[PartialD]\_q0 q_[r_, q0, p0, w0] \[RuleDelayed] 

              \(\(cat[q, d]\)[1]\)[r]\), ",", "\n", "\t\t                ", 

            \(\[PartialD]\_p0 q_[r_, q0, p0, w0] \[RuleDelayed] 

              \(\(cat[q, d]\)[2]\)[r]\), ",", "\n", "\t\t                ", 

            \(\[PartialD]\_w0 q_[r_, q0, p0, w0] \[RuleDelayed] 

              \(\(cat[q, d]\)[3]\)[r]\), ",", "\n", 

            "\t\t                     ", 

            \(q_[r_, q0, p0, w0] \[RuleDelayed] q[r]\)}], "}"}]}], ";"}]], 

  "Input",

  FontSize->14],



Cell[BoxData[

    \(\(\n\ \ \ \ \ \ \ \ \ \ \ \ \ \ {eqs, \[PartialD]\_q0\ eqs, 

        \[PartialD]\_p0\ eqs, \[PartialD]\_w0\ eqs} /. newnames\n\)\)], 

  "Input",

  FontSize->14],



Cell["\<\

Then after some rearrangement we obtain the following IVP, consisting 

24 first order differential equations and 24 initial conditions.\

\>", "Input",

  FormatType->TextForm,

  FontSize->16],



Cell["\<\

eqns[q0_,p0_,w0_,a_,k_] :=

    Flatten[Join[{q'[r] == q1[r], p'[r] == p1[r], w'[r] == w1[r],

        q1'[r]+3/r q1[r]+a^2 p[r] q[r]==k^2 w[r],

        p1'[r]+3/r p1[r] == .5 q[r]^2,

        w1'[r]+3/r w1[r]+q[r] ==0,

      Table[{qd[i]'[r] == q1d[i][r],

         pd[i]'[r] == p1d[i][r],

         wd[i]'[r] == w1d[i][r],

        q1d[i]'[r]+3/r q1d[i][r]+a^2 pd[i][r] q[r]+a^2 p[r] qd[i][r]

                           ==k^2 wd[i][r],

        p1d[i]'[r]+3/r p1d[i][r] == q[r] qd[i][r],

        w1d[i]'[r]+3/r w1d[i][r]+qd[i][r] == 0,

        q1d[i][10^-6]==0,p1d[i][10^-6]==0,w1d[i][10^-6]==0},{i,3}

            ],

        q1[10^-6]==0, p1[10^-6]==0, w1[10^-6]==0,

         q[10^-6]==q0, p[10^-6]==p0, w[10^-6]==w0,

        qd[1][10^-6] ==1, qd[2][10^-6]==0, qd[3][10^-6]==0,

        pd[1][10^-6] ==0, pd[2][10^-6]==1, pd[3][10^-6]==0,

        wd[1][10^-6] ==0, wd[2][10^-6]==0, wd[3][10^-6]==1 }

                 ]

            ]

        \

\>", "Input",

  PageWidth->Infinity,

  InitializationCell->True,

  ShowSpecialCharacters->False,

  FormatType->InputForm,

  FontSize->14],



Cell[TextData[{

  "\nWe note that in this IVP, we have used r = ",

  Cell[BoxData[

      \(TraditionalForm\`10\^\(-6\)\)]],

  " because r = 0 is a \nsingular point of the differential equations. \n\n\

This IVP is solved using the following."

}], "Input",

  FormatType->TextForm,

  FontSize->16],



Cell["\<\

    

ivp[q0_,p0_,w0_,a_,k_] :=

     NDSolve[eqns[q0,p0,w0,a,k],Flatten[Join[{q,p,w,q1,p1,w1,

\t  Table[{qd[i],pd[i],wd[i], q1d[i],p1d[i],w1d[i]},{i,3}]}] ],

\t\t\t\t {r,1} ,MaxSteps->3000 ] \

\>", "Input",

  PageWidth->Infinity,

  InitializationCell->True,

  ShowSpecialCharacters->False,

  FormatType->InputForm],



Cell["\<\



Newton's method takes the form of the following commands.



\

\>", "Input",

  FormatType->TextForm,

  FontSize->16],



Cell[BoxData[

    FormBox[

      StyleBox[

        RowBox[{"jacobian", ":=", 

          RowBox[{"(", GridBox[{

                {\(\(qd[1]\)[1]\), \(\(qd[2]\)[1]\), \(\(qd[3]\)[1]\)},

                {\(\(pd[1]\)[1]\), \(\(pd[2]\)[1]\), \(\(pd[3]\)[1]\)},

               

                 {\(\(w1d[1]\)[1] + 2 \(wd[1]\)[1]\ \), \(\ 

                  \(w1d[2]\)[1] + 2\ \(wd[2]\)[1]\ \ \), 

                  \(\(w1d[3]\)[1] + 2\ \(wd[3]\)[1]\)}

                }], " ", ")"}]}],

        FontFamily->"Courier New"], TraditionalForm]], "Input"],



Cell[BoxData[

    RowBox[{"y1", ":=", 

      RowBox[{"(", "\[NegativeThinSpace]", GridBox[{

            {\(q[1]\)},

            {GridBox[{

                  {\(p[1]\  - \ 1\)},

                  {\(2\ w[1]\  + \ w1[1]\)}

                  }]}

            }], "\[NegativeThinSpace]", ")"}]}]], "Input"],



Cell[BoxData[

    \(\(\ndy0n := \(-Inverse[jacobian].y1\)\)\)], "Input"],



Cell[BoxData[

    \(\(\nf[{q0_, p0_, w0_}, a_, k_] := {q0, p0, w0} + dy0n /. 

        Flatten[ivp[q0, p0, w0, a, k]]\)\)], "Input"],



Cell[TextData[{

  "\nid[{q0_,p0_,w0_},a_,k_,e_] :=(",

  StyleBox["l=0",

    FontColor->RGBColor[1, 0, 0]],

  ";\n                                  FixedPoint[(",

  StyleBox["l++",

    FontColor->RGBColor[1, 0, 0]],

  ";f[#,a,k])&,{q0,p0,w0},\n                                    SameTest-> ( \

(Abs[ #1[[1]]-#2[[1]] ]+\n                                                  \

Abs[ #1[[2]]-#2[[2]] ]+\n                                                  \

Abs[ #1[[3]]-#2[[3]] ])<e &) \n                                            ]\n\

                              )"

}], "Input",

  PageWidth->Infinity,

  InitializationCell->True,

  ShowSpecialCharacters->False,

  FormatType->InputForm],



Cell[TextData[{

  StyleBox["jd",

    FontColor->RGBColor[1, 0, 0]],

  "[{q0_,p0_,w0_},a_,k_] := Det[jacobian/.Flatten[ivp[q0,p0,w0,a,k]] ]"

}], "Input",

  PageWidth->Infinity,

  InitializationCell->True,

  ShowSpecialCharacters->False,

  FormatType->InputForm],



Cell[TextData[{

  "Next, in order to follow a branch of solutions as",

  StyleBox[" \"",

    FontFamily->"Times New Roman"],

  StyleBox["a",

    FontFamily->"Courier New"],

  "\" and/or \"",

  StyleBox["k",

    FontFamily->"Courier New"],

  "\" is incremented\nby ",

  StyleBox["da",

    FontFamily->"Courier New"],

  " and ",

  StyleBox["dk",

    FontFamily->"Courier New"],

  " respectively, we use the following."

}], "Input",

  FormatType->TextForm,

  FontFamily->"Times New Roman",

  FontSize->16],



Cell[BoxData[

    RowBox[{"\n", 

      RowBox[{

      \(idbranch[q0_, p0_, w0_, a0_, k0_, da_, dk_, jm_, e_]\), " ", ":=", 

        "\n", "    ", 

        RowBox[{"Module", "[", 

          RowBox[{\({idb, jbd}\), ",", "\n", "          ", 

            RowBox[{

            \(idb[0]\  := \ {q0, p0, w0}\), ";", "\n", "          ", 

              \(idb[1]\  := \ id[idb[0], a0, k0, e]\), ";", "\n", 

              "          ", 

              RowBox[{\(idb[i_]\), " ", ":=", " ", 

                RowBox[{

                  RowBox[{"(", 

                    RowBox[{\(idb[i]\), " ", "=", " ", 

                      RowBox[{"id", "[", 

                        RowBox[{

                          RowBox[{"(", 

                            StyleBox[\(2\ idb[i - 1]\  - \ idb[i - 2]\),

                              CellFrame->True,

                              Background->RGBColor[0, 1, 0]], ")"}], ",", 

                          "\n", "                                  ", 

                          \(a0 + \((i - 1)\)\ da\), ",", 

                          \(k0 + \((i - 1)\)\ dk\), ",", "e"}], "]"}]}], 

                    ")"}], "/;", 

                  StyleBox[\(i >= 2\),

                    Background->RGBColor[0, 1, 0]]}]}], " ", ";", "\n", 

              "          ", 

              RowBox[{

                RowBox[{

                  StyleBox["jbd",

                    FontColor->RGBColor[1, 0, 0]], "[", "i_", "]"}], " ", 

                ":=", " ", 

                RowBox[{\(jbd[i]\), " ", "=", " ", 

                  RowBox[{

                    StyleBox["jd",

                      FontColor->RGBColor[1, 0, 0]], "[", \(idb[i], 

                    a0 + \((i - 1)\)\ da, k0 + \((i - 1)\)\ dk\), "]"}]}]}], 

              ";", "\n", "          ", 

              RowBox[{"Table", "[", 

                RowBox[{

                  RowBox[{"{", 

                    RowBox[{

                    \(k0 + \((j - 1)\)\ dk\), ",", " ", 

                      \(a0 + \((j - 1)\)\ da\), ",", \(idb[j]\), ",", 

                      RowBox[{

                        StyleBox["jbd",

                          FontColor->RGBColor[1, 0, 0]], "[", "j", "]"}], ",",

                       

                      StyleBox["l",

                        FontColor->RGBColor[1, 0, 0]]}], "}"}], ",", 

                  \({j, jm}\)}], "]"}]}]}], " ", "]"}]}], "\n"}]], "Input"]

}, Open  ]],



Cell[CellGroupData[{



Cell["2.4 Graphical Results", "Subsection",

  FontSize->18],



Cell[TextData[{

  "We illustrate the numerical results obtained using the previous commands\n\

by plotting either q0,p0, or w0 on the vertical axis versus \"",

  StyleBox["a",

    FontFamily->"Courier New"],

  "\" on the \nhorizontal axis. This is done using the following."

}], "Input",

  FormatType->TextForm,

  FontFamily->"Times New Roman",

  FontSize->16],



Cell[CellGroupData[{



Cell[BoxData[

    RowBox[{"\n", 

      RowBox[{

        RowBox[{"plota", "[", 

          RowBox[{

            StyleBox[

              RowBox[{

                StyleBox["c",

                  FontColor->RGBColor[1, 0, 0]], "_"}]], ",", "m_", ",", 

            "k_"}], "]"}], ":=", "   ", "\n", "        ", 

        RowBox[{"ListPlot", "[", 

          RowBox[{

            RowBox[{"Table", "[", 

              RowBox[{

                RowBox[{"{", 

                  RowBox[{\(idbranch[\([i, 2]\)]\), ",", 

                    RowBox[{"idbranch", "[", 

                      RowBox[{"[", 

                        RowBox[{"i", ",", "3", ",", 

                          StyleBox["c",

                            FontColor->RGBColor[1, 0, 0]]}], "]"}], "]"}]}], 

                  "}"}], ",", \({i, m}\)}], "\n", 

              "\t\t                                    ", "]"}], ",", "\n", 

            "              ", \(Axes -> Automatic\), ",", 

            \(AxesLabel -> {a, q0}\), ",", \(PlotJoined -> True\), ",", "\n", 

            "\t\t        ", \(PlotLabel -> StringForm["\<k=``\>", k]\), ",", 

            " ", \(PlotRange -> All\)}], " ", "]"}]}]}]], "Input"],



Cell[CellGroupData[{



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-0.962104 0.0969147 0.309017 0.0238716 [

[.20087 .29652 -6 -9 ]

[.20087 .29652 6 0 ]

[.3947 .29652 -6 -9 ]

[.3947 .29652 6 0 ]

[.58853 .29652 -6 -9 ]

[.58853 .29652 6 0 ]

[.78236 .29652 -6 -9 ]

[.78236 .29652 6 0 ]

[.97619 .29652 -6 -9 ]

[.97619 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[-0.00546 .0703 -18 -4.5 ]

[-0.00546 .0703 0 4.5 ]

[-0.00546 .18966 -12 -4.5 ]

[-0.00546 .18966 0 4.5 ]

[-0.00546 .42837 -6 -4.5 ]

[-0.00546 .42837 0 4.5 ]

[-0.00546 .54773 -12 -4.5 ]

[-0.00546 .54773 0 4.5 ]

[.00704 .64303 -7 0 ]

[.00704 .64303 7 16 ]

[.5 .63053 -9.5 0 ]

[.5 .63053 9.5 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.20087 .30902 m

.20087 .31527 L

s

[(12)] .20087 .29652 0 1 Mshowa

.3947 .30902 m

.3947 .31527 L

s

[(14)] .3947 .29652 0 1 Mshowa

.58853 .30902 m

.58853 .31527 L

s

[(16)] .58853 .29652 0 1 Mshowa

.78236 .30902 m

.78236 .31527 L

s

[(18)] .78236 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(20)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.0555 .30902 m

.0555 .31277 L

s

.10396 .30902 m

.10396 .31277 L

s

.15242 .30902 m

.15242 .31277 L

s

.24933 .30902 m

.24933 .31277 L

s

.29779 .30902 m

.29779 .31277 L

s

.34624 .30902 m

.34624 .31277 L

s

.44316 .30902 m

.44316 .31277 L

s

.49162 .30902 m

.49162 .31277 L

s

.54007 .30902 m

.54007 .31277 L

s

.63699 .30902 m

.63699 .31277 L

s

.68545 .30902 m

.68545 .31277 L

s

.7339 .30902 m

.7339 .31277 L

s

.83082 .30902 m

.83082 .31277 L

s

.87928 .30902 m

.87928 .31277 L

s

.92773 .30902 m

.92773 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.00704 .0703 m

.01329 .0703 L

s

[(-10)] -0.00546 .0703 1 0 Mshowa

.00704 .18966 m

.01329 .18966 L

s

[(-5)] -0.00546 .18966 1 0 Mshowa

.00704 .42837 m

.01329 .42837 L

s

[(5)] -0.00546 .42837 1 0 Mshowa

.00704 .54773 m

.01329 .54773 L

s

[(10)] -0.00546 .54773 1 0 Mshowa

.125 Mabswid

.00704 .09417 m

.01079 .09417 L

s

.00704 .11804 m

.01079 .11804 L

s

.00704 .14192 m

.01079 .14192 L

s

.00704 .16579 m

.01079 .16579 L

s

.00704 .21353 m

.01079 .21353 L

s

.00704 .2374 m

.01079 .2374 L

s

.00704 .26127 m

.01079 .26127 L

s

.00704 .28515 m

.01079 .28515 L

s

.00704 .33289 m

.01079 .33289 L

s

.00704 .35676 m

.01079 .35676 L

s

.00704 .38063 m

.01079 .38063 L

s

.00704 .4045 m

.01079 .4045 L

s

.00704 .45225 m

.01079 .45225 L

s

.00704 .47612 m

.01079 .47612 L

s

.00704 .49999 m

.01079 .49999 L

s

.00704 .52386 m

.01079 .52386 L

s

.00704 .04643 m

.01079 .04643 L

s

.00704 .02256 m

.01079 .02256 L

s

.00704 .5716 m

.01079 .5716 L

s

.00704 .59548 m

.01079 .59548 L

s

.25 Mabswid

.00704 0 m

.00704 .61803 L

s

gsave

.00704 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -70.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(k) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

78.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 .4 1 r

.5 Mabswid

.97619 .45178 m

.97425 .45227 L

.97231 .45276 L

.97038 .45325 L

.96844 .45374 L

.9665 .45424 L

.96456 .45473 L

.96262 .45523 L

.96068 .45573 L

.95875 .45624 L

.95681 .45674 L

.95487 .45724 L

.95293 .45775 L

.95099 .45826 L

.94905 .45877 L

.94712 .45928 L

.94518 .4598 L

.94324 .46031 L

.9413 .46083 L

.93936 .46135 L

.93742 .46187 L

.93549 .4624 L

.93355 .46292 L

.93161 .46345 L

.92967 .46398 L

.92773 .46451 L

.92579 .46504 L

.92386 .46558 L

.92192 .46611 L

.91998 .46665 L

.91804 .46719 L

.9161 .46773 L

.91417 .46828 L

.91223 .46882 L

.91029 .46937 L

.90835 .46992 L

.90641 .47047 L

.90447 .47102 L

.90254 .47158 L

.9006 .47214 L

.89866 .47269 L

.89672 .47326 L

.89478 .47382 L

.89284 .47438 L

.89091 .47495 L

.88897 .47552 L

.88703 .47609 L

.88509 .47666 L

.88315 .47723 L

.88121 .47781 L

Mistroke

.87928 .47839 L

.87734 .47896 L

.8754 .47955 L

.87346 .48013 L

.87152 .48071 L

.86958 .4813 L

.86765 .48189 L

.86571 .48248 L

.86377 .48307 L

.86183 .48367 L

.85989 .48426 L

.85795 .48486 L

.85602 .48546 L

.85408 .48607 L

.85214 .48667 L

.8502 .48728 L

.84826 .48788 L

.84632 .48849 L

.84439 .4891 L

.84245 .48972 L

.84051 .49033 L

.83857 .49095 L

.83663 .49157 L

.83469 .49219 L

.83276 .49281 L

.83082 .49344 L

.82888 .49406 L

.82694 .49469 L

.825 .49532 L

.82307 .49595 L

.82113 .49659 L

.81919 .49722 L

.81725 .49786 L

.81531 .4985 L

.81337 .49914 L

.81144 .49978 L

.8095 .50043 L

.80756 .50107 L

.80562 .50172 L

.80368 .50237 L

.80174 .50302 L

.79981 .50368 L

.79787 .50433 L

.79593 .50499 L

.79399 .50565 L

.79205 .50631 L

.79011 .50697 L

.78818 .50764 L

.78624 .5083 L

.7843 .50897 L

Mistroke

.78236 .50964 L

.78042 .51031 L

.77848 .51098 L

.77655 .51165 L

.77461 .51233 L

.77267 .51301 L

.77073 .51369 L

.76879 .51437 L

.76685 .51505 L

.76492 .51573 L

.76298 .51642 L

.76104 .5171 L

.7591 .51779 L

.75716 .51848 L

.75522 .51917 L

.75329 .51986 L

.75135 .52056 L

.74941 .52125 L

.74747 .52195 L

.74553 .52265 L

.7436 .52335 L

.74166 .52405 L

.73972 .52475 L

.73778 .52545 L

.73584 .52616 L

.7339 .52686 L

.73197 .52757 L

.73003 .52828 L

.72809 .52899 L

.72615 .5297 L

.72421 .53041 L

.72227 .53112 L

.72034 .53184 L

.7184 .53255 L

.71646 .53327 L

.71452 .53398 L

.71258 .5347 L

.71064 .53542 L

.70871 .53614 L

.70677 .53686 L

.70483 .53758 L

.70289 .5383 L

.70095 .53902 L

.69901 .53975 L

.69708 .54047 L

.69514 .54119 L

.6932 .54192 L

.69126 .54264 L

.68932 .54337 L

.68738 .5441 L

Mistroke

.68545 .54482 L

.68351 .54555 L

.68157 .54628 L

.67963 .547 L

.67769 .54773 L

.67575 .54846 L

.67382 .54919 L

.67188 .54992 L

.66994 .55064 L

.668 .55137 L

.66606 .5521 L

.66413 .55283 L

.66219 .55355 L

.66025 .55428 L

.65831 .55501 L

.65637 .55573 L

.65443 .55646 L

.6525 .55718 L

.65056 .5579 L

.64862 .55863 L

.64668 .55935 L

.64474 .56007 L

.6428 .56079 L

.64087 .56151 L

.63893 .56223 L

.63699 .56295 L

.63505 .56366 L

.63311 .56438 L

.63117 .56509 L

.62924 .5658 L

.6273 .56651 L

.62536 .56722 L

.62342 .56792 L

.62148 .56863 L

.61954 .56933 L

.61761 .57003 L

.61567 .57073 L

.61373 .57142 L

.61179 .57211 L

.60985 .5728 L

.60791 .57349 L

.60598 .57417 L

.60404 .57485 L

.6021 .57553 L

.60016 .57621 L

.59822 .57688 L

.59628 .57755 L

.59435 .57821 L

.59241 .57887 L

.59047 .57953 L

Mistroke

.58853 .58018 L

.58659 .58083 L

.58466 .58147 L

.58272 .58211 L

.58078 .58274 L

.57884 .58337 L

.5769 .584 L

.57496 .58462 L

.57303 .58523 L

.57109 .58584 L

.56915 .58644 L

.56721 .58703 L

.56527 .58762 L

.56333 .58821 L

.5614 .58878 L

.55946 .58935 L

.55752 .58992 L

.55558 .59047 L

.55364 .59102 L

.5517 .59156 L

.54977 .59209 L

.54783 .59262 L

.54589 .59313 L

.54395 .59364 L

.54201 .59414 L

.54007 .59463 L

.53814 .59511 L

.5362 .59558 L

.53426 .59604 L

.53232 .59648 L

.53038 .59692 L

.52844 .59735 L

.52651 .59776 L

.52457 .59817 L

.52263 .59856 L

.52069 .59894 L

.51875 .59931 L

.51681 .59966 L

.51488 .6 L

.51294 .60033 L

.511 .60064 L

.50906 .60094 L

.50712 .60122 L

.50518 .60148 L

.50325 .60174 L

.50131 .60197 L

.49937 .60219 L

.49743 .60239 L

.49549 .60257 L

.49356 .60273 L

Mistroke

.49162 .60288 L

.48968 .603 L

.48774 .60311 L

.4858 .60319 L

.48386 .60326 L

.48193 .6033 L

.47999 .60332 L

.47805 .60332 L

.47611 .60329 L

.47417 .60324 L

.47223 .60316 L

.4703 .60306 L

.46836 .60293 L

.46642 .60278 L

.46448 .60259 L

.46254 .60238 L

.4606 .60214 L

.45867 .60187 L

.45673 .60156 L

.45479 .60123 L

.45285 .60086 L

.45091 .60045 L

.44897 .60001 L

.44704 .59954 L

.4451 .59903 L

.44316 .59847 L

.44122 .59788 L

.43928 .59725 L

.43734 .59658 L

.43541 .59586 L

.43347 .5951 L

.43153 .59429 L

.42959 .59343 L

.42765 .59252 L

.42571 .59156 L

.42378 .59055 L

.42184 .58949 L

.4199 .58836 L

.41796 .58718 L

.41602 .58594 L

.41409 .58464 L

.41215 .58327 L

.41021 .58183 L

.40827 .58033 L

.40633 .57875 L

.40439 .5771 L

.40246 .57537 L

.40052 .57356 L

.39858 .57166 L

.39664 .56968 L

Mistroke

.3947 .5676 L

.39276 .56543 L

.39083 .56316 L

.38889 .56078 L

.38695 .5583 L

.38501 .5557 L

.38307 .55298 L

.38113 .55014 L

.3792 .54716 L

.37726 .54405 L

.37532 .54078 L

.37338 .53736 L

.37144 .53377 L

.3695 .53001 L

.36757 .52606 L

.36563 .52191 L

.36369 .51754 L

.36175 .51294 L

.35981 .50808 L

.35787 .50296 L

.35594 .49753 L

.354 .49178 L

.35206 .48566 L

.35012 .47913 L

.34818 .47214 L

.34624 .46462 L

.34431 .45649 L

.34237 .44764 L

.34043 .43791 L

.33849 .42707 L

.33655 .41479 L

.33462 .40047 L

.33268 .38292 L

.33074 .35885 L

.32916 .30902 L

Mfstroke

.97619 .16625 m

.97425 .16576 L

.97231 .16528 L

.97038 .16478 L

.96844 .16429 L

.9665 .1638 L

.96456 .1633 L

.96262 .1628 L

.96068 .1623 L

.95875 .1618 L

.95681 .1613 L

.95487 .16079 L

.95293 .16028 L

.95099 .15977 L

.94905 .15926 L

.94712 .15875 L

.94518 .15824 L

.94324 .15772 L

.9413 .1572 L

.93936 .15668 L

.93742 .15616 L

.93549 .15564 L

.93355 .15511 L

.93161 .15458 L

.92967 .15405 L

.92773 .15352 L

.92579 .15299 L

.92386 .15246 L

.92192 .15192 L

.91998 .15138 L

.91804 .15084 L

.9161 .1503 L

.91417 .14976 L

.91223 .14921 L

.91029 .14866 L

.90835 .14811 L

.90641 .14756 L

.90447 .14701 L

.90254 .14645 L

.9006 .1459 L

.89866 .14534 L

.89672 .14478 L

.89478 .14422 L

.89284 .14365 L

.89091 .14309 L

.88897 .14252 L

.88703 .14195 L

.88509 .14138 L

.88315 .1408 L

.88121 .14023 L

Mistroke

.87928 .13965 L

.87734 .13907 L

.8754 .13849 L

.87346 .1379 L

.87152 .13732 L

.86958 .13673 L

.86765 .13614 L

.86571 .13555 L

.86377 .13496 L

.86183 .13437 L

.85989 .13377 L

.85795 .13317 L

.85602 .13257 L

.85408 .13197 L

.85214 .13136 L

.8502 .13076 L

.84826 .13015 L

.84632 .12954 L

.84439 .12893 L

.84245 .12832 L

.84051 .1277 L

.83857 .12708 L

.83663 .12647 L

.83469 .12584 L

.83276 .12522 L

.83082 .1246 L

.82888 .12397 L

.82694 .12334 L

.825 .12271 L

.82307 .12208 L

.82113 .12145 L

.81919 .12081 L

.81725 .12017 L

.81531 .11953 L

.81337 .11889 L

.81144 .11825 L

.8095 .11761 L

.80756 .11696 L

.80562 .11631 L

.80368 .11566 L

.80174 .11501 L

.79981 .11436 L

.79787 .1137 L

.79593 .11304 L

.79399 .11239 L

.79205 .11172 L

.79011 .11106 L

.78818 .1104 L

.78624 .10973 L

.7843 .10907 L

Mistroke

.78236 .1084 L

.78042 .10773 L

.77848 .10705 L

.77655 .10638 L

.77461 .1057 L

.77267 .10503 L

.77073 .10435 L

.76879 .10367 L

.76685 .10299 L

.76492 .1023 L

.76298 .10162 L

.76104 .10093 L

.7591 .10024 L

.75716 .09955 L

.75522 .09886 L

.75329 .09817 L

.75135 .09748 L

.74941 .09678 L

.74747 .09608 L

.74553 .09539 L

.7436 .09469 L

.74166 .09399 L

.73972 .09328 L

.73778 .09258 L

.73584 .09188 L

.7339 .09117 L

.73197 .09046 L

.73003 .08976 L

.72809 .08905 L

.72615 .08834 L

.72421 .08762 L

.72227 .08691 L

.72034 .0862 L

.7184 .08548 L

.71646 .08477 L

.71452 .08405 L

.71258 .08333 L

.71064 .08261 L

.70871 .0819 L

.70677 .08118 L

.70483 .08045 L

.70289 .07973 L

.70095 .07901 L

.69901 .07829 L

.69708 .07756 L

.69514 .07684 L

.6932 .07611 L

.69126 .07539 L

.68932 .07466 L

.68738 .07394 L

Mistroke

.68545 .07321 L

.68351 .07248 L

.68157 .07176 L

.67963 .07103 L

.67769 .0703 L

.67575 .06957 L

.67382 .06885 L

.67188 .06812 L

.66994 .06739 L

.668 .06666 L

.66606 .06594 L

.66413 .06521 L

.66219 .06448 L

.66025 .06375 L

.65831 .06303 L

.65637 .0623 L

.65443 .06158 L

.6525 .06085 L

.65056 .06013 L

.64862 .05941 L

.64668 .05868 L

.64474 .05796 L

.6428 .05724 L

.64087 .05652 L

.63893 .0558 L

.63699 .05509 L

.63505 .05437 L

.63311 .05366 L

.63117 .05295 L

.62924 .05223 L

.6273 .05152 L

.62536 .05082 L

.62342 .05011 L

.62148 .04941 L

.61954 .04871 L

.61761 .04801 L

.61567 .04731 L

.61373 .04661 L

.61179 .04592 L

.60985 .04523 L

.60791 .04455 L

.60598 .04386 L

.60404 .04318 L

.6021 .0425 L

.60016 .04183 L

.59822 .04116 L

.59628 .04049 L

.59435 .03982 L

.59241 .03916 L

.59047 .03851 L

Mistroke

.58853 .03786 L

.58659 .03721 L

.58466 .03656 L

.58272 .03593 L

.58078 .03529 L

.57884 .03466 L

.5769 .03404 L

.57496 .03342 L

.57303 .03281 L

.57109 .0322 L

.56915 .0316 L

.56721 .031 L

.56527 .03041 L

.56333 .02983 L

.5614 .02925 L

.55946 .02868 L

.55752 .02812 L

.55558 .02756 L

.55364 .02701 L

.5517 .02647 L

.54977 .02594 L

.54783 .02542 L

.54589 .0249 L

.54395 .02439 L

.54201 .02389 L

.54007 .02341 L

.53814 .02293 L

.5362 .02246 L

.53426 .022 L

.53232 .02155 L

.53038 .02111 L

.52844 .02068 L

.52651 .02027 L

.52457 .01987 L

.52263 .01947 L

.52069 .01909 L

.51875 .01873 L

.51681 .01837 L

.51488 .01803 L

.51294 .01771 L

.511 .0174 L

.50906 .0171 L

.50712 .01682 L

.50518 .01655 L

.50325 .0163 L

.50131 .01606 L

.49937 .01585 L

.49743 .01565 L

.49549 .01547 L

.49356 .0153 L

Mistroke

.49162 .01516 L

.48968 .01503 L

.48774 .01493 L

.4858 .01484 L

.48386 .01478 L

.48193 .01473 L

.47999 .01472 L

.47805 .01472 L

.47611 .01475 L

.47417 .0148 L

.47223 .01487 L

.4703 .01497 L

.46836 .0151 L

.46642 .01526 L

.46448 .01544 L

.46254 .01565 L

.4606 .0159 L

.45867 .01617 L

.45673 .01647 L

.45479 .01681 L

.45285 .01718 L

.45091 .01758 L

.44897 .01802 L

.44704 .0185 L

.4451 .01901 L

.44316 .01956 L

.44122 .02015 L

.43928 .02078 L

.43734 .02146 L

.43541 .02218 L

.43347 .02294 L

.43153 .02375 L

.42959 .02461 L

.42765 .02551 L

.42571 .02647 L

.42378 .02748 L

.42184 .02855 L

.4199 .02967 L

.41796 .03085 L

.41602 .03209 L

.41409 .0334 L

.41215 .03476 L

.41021 .0362 L

.40827 .0377 L

.40633 .03928 L

.40439 .04093 L

.40246 .04267 L

.40052 .04448 L

.39858 .04637 L

.39664 .04836 L

Mistroke

.3947 .05043 L

.39276 .0526 L

.39083 .05487 L

.38889 .05725 L

.38695 .05973 L

.38501 .06233 L

.38307 .06505 L

.38113 .06789 L

.3792 .07087 L

.37726 .07399 L

.37532 .07725 L

.37338 .08067 L

.37144 .08426 L

.3695 .08802 L

.36757 .09198 L

.36563 .09613 L

.36369 .1005 L

.36175 .1051 L

.35981 .10995 L

.35787 .11508 L

.35594 .1205 L

.354 .12626 L

.35206 .13238 L

.35012 .13891 L

.34818 .1459 L

.34624 .15341 L

.34431 .16154 L

.34237 .1704 L

.34043 .18013 L

.33849 .19096 L

.33655 .20325 L

.33462 .21757 L

.33268 .23511 L

.33074 .25919 L

.32916 .30902 L

Mfstroke

1 0 0 r

.97619 .37344 m

.97367 .37372 L

.96979 .37416 L

.96592 .3746 L

.96204 .37504 L

.95816 .37549 L

.95429 .37594 L

.95041 .37639 L

.94653 .37684 L

.94266 .3773 L

.93878 .37776 L

.9349 .37823 L

.93103 .3787 L

.92715 .37917 L

.92328 .37965 L

.9194 .38013 L

.91552 .38061 L

.91165 .3811 L

.90777 .38159 L

.90389 .38208 L

.90002 .38258 L

.89614 .38308 L

.89226 .38359 L

.88839 .3841 L

.88451 .38461 L

.88063 .38512 L

.87676 .38564 L

.87288 .38617 L

.869 .3867 L

.86513 .38723 L

.86125 .38777 L

.85737 .3883 L

.8535 .38885 L

.84962 .3894 L

.84574 .38995 L

.84187 .39051 L

.83799 .39107 L

.83411 .39163 L

.83024 .3922 L

.82636 .39277 L

.82248 .39335 L

.81861 .39393 L

.81473 .39452 L

.81085 .39511 L

.80698 .3957 L

.8031 .3963 L

.79922 .39691 L

.79535 .39752 L

.79147 .39813 L

.78759 .39875 L

Mistroke

.78372 .39937 L

.77984 .4 L

.77596 .40063 L

.77209 .40126 L

.76821 .4019 L

.76433 .40255 L

.76046 .4032 L

.75658 .40386 L

.75271 .40452 L

.74883 .40518 L

.74495 .40585 L

.74108 .40653 L

.7372 .40721 L

.73332 .40789 L

.72945 .40858 L

.72557 .40928 L

.72169 .40998 L

.71782 .41069 L

.71394 .4114 L

.71006 .41212 L

.70619 .41284 L

.70231 .41356 L

.69843 .4143 L

.69456 .41504 L

.69068 .41578 L

.6868 .41653 L

.68293 .41728 L

.67905 .41804 L

.67517 .41881 L

.6713 .41958 L

.66742 .42036 L

.66354 .42114 L

.65967 .42193 L

.65579 .42272 L

.65191 .42352 L

.64804 .42433 L

.64416 .42514 L

.64028 .42596 L

.63641 .42678 L

.63253 .42761 L

.62865 .42844 L

.62478 .42928 L

.6209 .43013 L

.61702 .43098 L

.61315 .43184 L

.60927 .43271 L

.60539 .43358 L

.60152 .43446 L

.59764 .43534 L

.59376 .43623 L

Mistroke

.58989 .43712 L

.58601 .43803 L

.58214 .43893 L

.57826 .43985 L

.57438 .44077 L

.57051 .4417 L

.56663 .44263 L

.56275 .44357 L

.55888 .44451 L

.555 .44546 L

.55112 .44642 L

.54725 .44739 L

.54337 .44836 L

.53949 .44933 L

.53562 .45032 L

.53174 .4513 L

.52786 .4523 L

.52399 .4533 L

.52011 .45431 L

.51623 .45532 L

.51236 .45634 L

.50848 .45737 L

.5046 .4584 L

.50073 .45944 L

.49685 .46048 L

.49297 .46153 L

.4891 .46259 L

.48522 .46365 L

.48134 .46472 L

.47747 .46579 L

.47359 .46687 L

.46971 .46796 L

.46584 .46905 L

.46196 .47014 L

.45808 .47124 L

.45421 .47235 L

.45033 .47346 L

.44645 .47458 L

.44258 .4757 L

.4387 .47683 L

.43482 .47796 L

.43095 .4791 L

.42707 .48024 L

.4232 .48138 L

.41932 .48253 L

.41544 .48369 L

.41157 .48485 L

.40769 .48601 L

.40381 .48717 L

.39994 .48834 L

Mistroke

.39606 .48951 L

.39218 .49069 L

.38831 .49186 L

.38443 .49304 L

.38055 .49422 L

.37668 .49541 L

.3728 .49659 L

.36892 .49778 L

.36505 .49897 L

.36117 .50015 L

.35729 .50134 L

.35342 .50253 L

.34954 .50372 L

.34566 .5049 L

.34179 .50609 L

.33791 .50727 L

.33403 .50845 L

.33016 .50963 L

.32628 .51081 L

.3224 .51198 L

.31853 .51315 L

.31465 .51431 L

.31077 .51546 L

.3069 .51661 L

.30302 .51776 L

.29914 .51889 L

.29527 .52002 L

.29139 .52114 L

.28751 .52224 L

.28364 .52334 L

.27976 .52442 L

.27588 .52549 L

.27201 .52655 L

.26813 .52759 L

.26425 .52862 L

.26038 .52963 L

.2565 .53061 L

.25263 .53158 L

.24875 .53253 L

.24487 .53346 L

.241 .53436 L

.23712 .53523 L

.23324 .53608 L

.22937 .5369 L

.22549 .53769 L

.22161 .53844 L

.21774 .53916 L

.21386 .53984 L

.20998 .54048 L

.20611 .54108 L

Mistroke

.20223 .54164 L

.19835 .54214 L

.19448 .5426 L

.1906 .543 L

.18672 .54335 L

.18285 .54364 L

.17897 .54386 L

.17509 .54402 L

.17122 .54411 L

.16734 .54412 L

.16346 .54405 L

.15959 .54389 L

.15571 .54365 L

.15183 .54331 L

.14796 .54287 L

.14408 .54232 L

.1402 .54166 L

.13633 .54087 L

.13245 .53996 L

.12857 .5389 L

.1247 .5377 L

.12082 .53634 L

.11694 .53482 L

.11307 .53311 L

.10919 .53121 L

.10531 .5291 L

.10144 .52677 L

.09756 .5242 L

.09369 .52137 L

.08981 .51825 L

.08593 .51483 L

.08206 .51107 L

.07818 .50694 L

.0743 .5024 L

.07043 .49741 L

.06655 .49192 L

.06267 .48585 L

.0588 .47913 L

.05492 .47165 L

.05104 .46329 L

.04717 .45387 L

.04329 .44312 L

.03941 .43068 L

.03554 .41591 L

.03166 .39761 L

.02778 .37274 L

.02391 .3162 L

.02381 .30902 L

Mfstroke

.97619 .24459 m

.97367 .24431 L

.96979 .24387 L

.96592 .24343 L

.96204 .24299 L

.95816 .24255 L

.95429 .2421 L

.95041 .24165 L

.94653 .24119 L

.94266 .24073 L

.93878 .24027 L

.9349 .2398 L

.93103 .23933 L

.92715 .23886 L

.92328 .23839 L

.9194 .23791 L

.91552 .23742 L

.91165 .23694 L

.90777 .23645 L

.90389 .23595 L

.90002 .23545 L

.89614 .23495 L

.89226 .23445 L

.88839 .23394 L

.88451 .23343 L

.88063 .23291 L

.87676 .23239 L

.87288 .23187 L

.869 .23134 L

.86513 .2308 L

.86125 .23027 L

.85737 .22973 L

.8535 .22918 L

.84962 .22864 L

.84574 .22808 L

.84187 .22753 L

.83799 .22697 L

.83411 .2264 L

.83024 .22583 L

.82636 .22526 L

.82248 .22468 L

.81861 .2241 L

.81473 .22352 L

.81085 .22292 L

.80698 .22233 L

.8031 .22173 L

.79922 .22113 L

.79535 .22052 L

.79147 .21991 L

.78759 .21929 L

Mistroke

.78372 .21867 L

.77984 .21804 L

.77596 .21741 L

.77209 .21677 L

.76821 .21613 L

.76433 .21548 L

.76046 .21483 L

.75658 .21418 L

.75271 .21352 L

.74883 .21285 L

.74495 .21218 L

.74108 .21151 L

.7372 .21083 L

.73332 .21014 L

.72945 .20945 L

.72557 .20875 L

.72169 .20805 L

.71782 .20735 L

.71394 .20664 L

.71006 .20592 L

.70619 .2052 L

.70231 .20447 L

.69843 .20374 L

.69456 .203 L

.69068 .20225 L

.6868 .20151 L

.68293 .20075 L

.67905 .19999 L

.67517 .19923 L

.6713 .19845 L

.66742 .19768 L

.66354 .19689 L

.65967 .19611 L

.65579 .19531 L

.65191 .19451 L

.64804 .19371 L

.64416 .1929 L

.64028 .19208 L

.63641 .19126 L

.63253 .19043 L

.62865 .18959 L

.62478 .18875 L

.6209 .1879 L

.61702 .18705 L

.61315 .18619 L

.60927 .18533 L

.60539 .18446 L

.60152 .18358 L

.59764 .18269 L

.59376 .18181 L

Mistroke

.58989 .18091 L

.58601 .18001 L

.58214 .1791 L

.57826 .17819 L

.57438 .17727 L

.57051 .17634 L

.56663 .17541 L

.56275 .17447 L

.55888 .17352 L

.555 .17257 L

.55112 .17161 L

.54725 .17065 L

.54337 .16968 L

.53949 .1687 L

.53562 .16772 L

.53174 .16673 L

.52786 .16573 L

.52399 .16473 L

.52011 .16373 L

.51623 .16271 L

.51236 .16169 L

.50848 .16067 L

.5046 .15963 L

.50073 .1586 L

.49685 .15755 L

.49297 .1565 L

.4891 .15545 L

.48522 .15438 L

.48134 .15332 L

.47747 .15224 L

.47359 .15116 L

.46971 .15008 L

.46584 .14899 L

.46196 .14789 L

.45808 .14679 L

.45421 .14568 L

.45033 .14457 L

.44645 .14345 L

.44258 .14233 L

.4387 .1412 L

.43482 .14007 L

.43095 .13894 L

.42707 .1378 L

.4232 .13665 L

.41932 .1355 L

.41544 .13435 L

.41157 .13319 L

.40769 .13203 L

.40381 .13086 L

.39994 .12969 L

Mistroke

.39606 .12852 L

.39218 .12735 L

.38831 .12617 L

.38443 .12499 L

.38055 .12381 L

.37668 .12263 L

.3728 .12144 L

.36892 .12025 L

.36505 .11907 L

.36117 .11788 L

.35729 .11669 L

.35342 .1155 L

.34954 .11432 L

.34566 .11313 L

.34179 .11194 L

.33791 .11076 L

.33403 .10958 L

.33016 .1084 L

.32628 .10723 L

.3224 .10605 L

.31853 .10489 L

.31465 .10373 L

.31077 .10257 L

.3069 .10142 L

.30302 .10028 L

.29914 .09914 L

.29527 .09802 L

.29139 .0969 L

.28751 .09579 L

.28364 .0947 L

.27976 .09361 L

.27588 .09254 L

.27201 .09148 L

.26813 .09044 L

.26425 .08942 L

.26038 .08841 L

.2565 .08742 L

.25263 .08645 L

.24875 .0855 L

.24487 .08458 L

.241 .08368 L

.23712 .0828 L

.23324 .08195 L

.22937 .08113 L

.22549 .08035 L

.22161 .07959 L

.21774 .07887 L

.21386 .07819 L

.20998 .07755 L

.20611 .07695 L

Mistroke

.20223 .0764 L

.19835 .07589 L

.19448 .07543 L

.1906 .07503 L

.18672 .07468 L

.18285 .07439 L

.17897 .07417 L

.17509 .07401 L

.17122 .07393 L

.16734 .07392 L

.16346 .07399 L

.15959 .07414 L

.15571 .07438 L

.15183 .07472 L

.14796 .07517 L

.14408 .07571 L

.1402 .07638 L

.13633 .07716 L

.13245 .07808 L

.12857 .07913 L

.1247 .08033 L

.12082 .08169 L

.11694 .08322 L

.11307 .08492 L

.10919 .08682 L

.10531 .08893 L

.10144 .09126 L

.09756 .09383 L

.09369 .09666 L

.08981 .09978 L

.08593 .1032 L

.08206 .10696 L

.07818 .11109 L

.0743 .11563 L

.07043 .12062 L

.06655 .12612 L

.06267 .13218 L

.0588 .1389 L

.05492 .14638 L

.05104 .15474 L

.04717 .16417 L

.04329 .17491 L

.03941 .18735 L

.03554 .20212 L

.03166 .22042 L

.02778 .2453 L

.02391 .30183 L

.02381 .30902 L

Mfstroke

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{567, 350.313},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.776525,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008g0001GPP10`40000100000800002008200000

P800P020P<30`<3L`:K:l00003<006H009T00<`00?l0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV

09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<003o03?o06Ko09Wo0<co

0?oo0000<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I

<c>I<fJI<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0

IYT0I/`0I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bI

I_nIIP3<IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0c

VC<cVFHcVITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<

VIW<VLc<VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`c

c?lcc01Vc3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03o

c3?oc6Koc9Woc<coc?ooc000oc<0ofH0oiT0ol`0ool0o`0coc<cofHcoiTcol`coolco`1Voc=VofIV

oiUVolaVoomVo`2Ioc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<o`3ooc?oofKooiWoolco

ooooo`0000410@820P<30`@410D51@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C

4a@D5?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooa[Q00<0hN40on7ohAcQ000Jh@030>7Q0?oQ

on4Lh@006^400`3Qh@3ohOoQ7>4001[Q00<0hN40on7ohAcQ000Jh@030>7Q0?oQon4Lh@006^400`3Q

h@3ohOoQ7>4001[Q00<0hN40on7ohAcQ000Jh@030>7Q0?oQon4Lh@006^400`3Qh@3YhAFnon4Mh@00

6^400`3Qh@3Sh@Jn5N47__oQ5^4001[Q00<0hN40gn44_R;Q1[kohA3Q000Jh@030>7Q0=cQ0kh/h@Bn

on4<h@006^430=WQ0khch@Bnon48h@006^400`3Qh@3Gh@:n>^44__oQ1>4001[Q00<0hN40eN42_T3Q

1;koh@006^400`3Qh@3Dh@03_^7Q04CQ0kklh@006^400`3Qh@3Bh@:nB^43__WQ000Jh@030>7Q0=3Q

0[i?h@>nm^4001[Q00<0hN40cn400kkQh@1Bh@Bnl^4001[Q00<0hN40c^400kkQh@1Gh@>nkn4001[Q

00<0hN40cN400kkQh@1Kh@>nk>4001[Q00<0hN40bn42_V7Q0[kZh@006^400`3Qh@3:h@03_^7Q06?Q

0kkWh@006^400`3Qh@39h@03_^7Q06OQ0kkTh@006^430<SQ00>nhN40Jn43_^7Q000Jh@030>7Q0<OQ

00>nhN40Kn43_]kQ000Jh@030>7Q0<KQ00>nhN40Ln42_]cQ000Jh@030>7Q0<GQ00>nhN40M^43_]WQ

000Jh@030>7Q0<CQ00>nhN40N^43_]KQ000Jh@030>7Q0<CQ00>nhN40ON43_]?Q000Jh@030>7Q0<?Q

00>nhN40PN42_]7Q000Jh@030>7Q0<;Q00>nhN40Q>43_/kQ000Jh@030>7Q0<7Q00>nhN40R>43_/_Q

000Jh@030>7Q0<3Q00>nhN40S>42_/WQ000Jh@030>7Q0<3Q00>nhN40S^43_/KQ000:h@D00^400`3Q

h@06h@030>7Q0;oQ00>nhN40T^43_/?Q000<h@070>7Qh@3Q0007h@030>7Q0;kQ00>nhN40U^42_/7Q

0006h@<00n401`3QhN40h@001n450;cQ00>nhN40V>43_[kQ000<h@070>7Qh@3Q0007h@030>7Q0;gQ

00>nhN40W>42_[cQ000<h@070>7Qh@3Q0007h@030>7Q04CQ70mMh@03_^7Q09kQ0kjih@002n4200CQ

00<0hN401^400`3Qh@10h@@?7>483eCQ00>nhN40X^43_[KQ000Jh@030>7Q03cQ10lXh@H?CN400kkQ

h@2Vh@:n]>4001[Q00<0hN40>^423c;Q10m9h@03_^7Q0:SQ0kjah@006^400`3Qh@0fh@@?>>443dCQ

00>nhN40[>43_ZkQ000Jh@030>7Q03CQ0Pm0h@@?@>400kkQh@2_h@>nZn4001[Q00<0hN40<^423dKQ

10lkh@03_^7Q0;?Q0[jYh@006^400`3Qh@0`h@8?C>443cOQ00>nhN40]N43_ZKQ000Jh@030>7Q02kQ

0PmBh@@?<^400kkQh@2ih@>nXn4001[Q00<0hN40;N400`oQh@1Fh@@?;^400kkQh@2lh@:nXN4001[Q

0`0/h@033n7Q05_Q10lYh@03_^7Q0;oQ0kjNh@006^400`3Qh@0Zh@8?H^443bGQ00>nhN40`^43_Y_Q

000Jh@030>7Q02WQ00<?hN40I^423b;Q00>nhN40a^43_YSQ000Jh@030>7Q02SQ00<?hN40JN443akQ

00>nhN40bN42_YKQ000Jh@030>7Q02OQ00<?hN40K^443a[Q00>nhN40bn43_Y?Q000Jh@030>7Q02KQ

00<?hN40Ln423aOQ00>nhN40cn43_Y3Q000Jh@030>7Q02GQ00<?hN40M^443a?Q00>nhN40d^43_XgQ

000Jh@030>7Q02CQ00<?hN40Nn443`kQ00>nhN40e^43_X[Q000Jh@030>7Q02?Q00<?hN40P>423`cQ

00>nhN40fN43_XOQ000Jh@030>7Q02;Q00<?hN40Pn443`SQ00>nhN40g>43_XCQ000Jh@030>7Q027Q

00<?hN40R>443`?Q00>nhN40h>43_X7Q000Jh@030>7Q023Q00<?hN40SN423`03hKkQ0>CQ0kinh@00

6^4301oQ00<?hN40T>443nKQ0kikh@006^400`3Qh@0Oh@033n7Q093Q00BnhN7Q0PoWh@>nN>4001[Q

00<0hN407^400`oQh@2Ah@03_^7Q00?Q10oVh@>nMN4001[Q00<0hN407N400`oQh@2Bh@03_^7Q00OQ

10oUh@>nL^4001[Q00<0hN407N400`oQh@2Ah@03_^7Q00cQ0PoVh@>nKn4001[Q00<0hN407>400`oQ

h@2Bh@03_^7Q00kQ10oUh@>nK>4001[Q00<0hN406n400`oQh@2Ch@03_^7Q01;Q10oTh@>nJN4001[Q

00<0hN406n400`oQh@2Bh@03_^7Q01OQ0PoUh@>nI^4001[Q00<0hN406^400`oQh@2Ch@03_^7Q01WQ

10oTh@>nHn4001[Q00<0hN406N400`oQh@2Dh@03_^7Q01gQ10oSh@FnG^4001[Q00<0hN406N400`oQ

h@2Ch@03_^7Q02;Q0PoVh@>nFn4001[Q00<0hN406>400`oQh@2Dh@03_^7Q02CQ10oUh@>nF>4001[Q

00<0hN405n400`oQh@2Eh@03_^7Q02SQ10oTh@BnE>4001[Q0`0Gh@033n7Q09CQ00>nhN40;N423nKQ

0kiAh@006^400`3Qh@0Fh@033n7Q09GQ00>nhN40;n443nGQ0ki>h@006^400`3Qh@0Fh@033n7Q09GQ

00>nhN40<n443nCQ1;i:h@006^400`3Qh@0Eh@033n7Q09KQ00>nhN40=n443nCQ0ki7h@006^400`3Q

h@0Eh@033n7Q09GQ00>nhN40?>423nGQ1;i3h@006^400`3Qh@0Dh@033n7Q09KQ00>nhN40?^443nGQ

1;hoh@006^400`3Qh@0Dh@033n7Q09KQ00>nhN40@^443nGQ0khlh@006^400`3Qh@0Dh@033n7Q09KQ

00>nhN40A^443nCQ1;hhh@006^400`3Qh@0Ch@033n7Q09KQ00>nhN40Bn443nCQ1;hdh@006^400`3Q

h@0Ch@033n7Q09KQ00>nhN40Cn443nCQ0khah@006^400`3Qh@0Bh@033n7Q09OQ00>nhN40Dn423nGQ

1;h]h@006^400`3Qh@0Bh@033n7Q09OQ00>nhN40EN443nGQ1;hYh@006^4301;Q00<?hN40Un400kkQ

h@1Ih@@?iN44_RGQ000Jh@030>7Q017Q00<?hN40Un400kkQh@1Nh@@?on4;h@006^400`3Qh@0Ah@03

3n7Q09OQ00>nhN40H^443ooQ1n4001[Q00<0hN404N400`oQh@2Gh@03_^7Q06KQ10ooh@?Q000Jh@03

0>7Q013Q00<?hN40V>400kkQh@1Zh@@?o^4001[Q00<0hN404>400`oQh@2Hh@03_^7Q06kQ10ojh@00

6^400`3Qh@0@h@033n7Q09OQ00>nhN40Ln453oGQ000Jh@030>7Q00oQ00<?hN40V>400kkQh@1hh@H?

kn4001[Q00<0hN403n400`oQh@2Hh@03_^7Q07kQ10o[h@006^400`3Qh@0?h@033n7Q09SQ00>nhN40

P^443nOQ000Ah@030>7Q00KQ00<0hN403^400`oQh@2Ih@03_^7Q08KQ10oSh@004>400`3Q0007h@03

0>7Q00kQ00<?hN40V>400kkQh@2;h@@?gn4000_Q0`04h@030>7Q00GQ1@0<h@033n7Q09SQ00>nhN40

Sn463mWQ000@h@802>400`3Qh@0=h@033n7Q09WQ00>nhN40UN443mGQ000@h@030>7Q00OQ00<0hN40

3N400`oQh@2Ih@03_^7Q09WQ10oAh@004>4300OQ00<0hN403N400`oQh@2Ih@03_^7Q09gQ1Po;h@00

6^400`3Qh@0=h@033n7Q09WQ00>nhN40Xn443lOQ000Jh@030>7Q00cQ00<?hN40VN400kkQh@2Xh@H?

`N4001[Q00<0hN403>400`oQh@2Ih@03_^7Q0:kQ10nmh@006^400`3Qh@0<h@033n7Q09WQ00>nhN40

/^463kOQ000Jh@030>7Q00cQ00<?hN40VN400kkQh@2hh@@?/n4001[Q00<0hN403>400`oQh@2Ih@03

_^7Q0;cQ1Pn]h@006^400`3Qh@0;h@033n7Q09[Q00>nhN40`^463jOQ000Jh@030>7Q00_Q00<?hN40

V^400kkQh@38h@H?XN4001[Q00<0hN402n400`oQh@2Ih@03_^7Q0<oQ10nMh@006^4300_Q00<?hN40

VN400kkQh@3Ch@H?Un4001[Q00<0hN402^400`oQh@2Jh@03_^7Q0=WQ1PnAh@006^400`3Qh@0:h@03

3n7Q09[Q00>nhN40gn463h_Q000Jh@030>7Q00[Q00<?hN40V^400kkQh@3Uh@P?Pn4001[Q00<0hN40

2^400`oQh@2Jh@03_^7Q0>gQ1Pmmh@006^400`3Qh@0:h@033n7Q09[Q00>nhN40ln463gOQ000Jh@03

0>7Q00[Q00<?hN40V^400kkQh@3ih@H?LN4001[Q00<0hN402N400`oQh@2Jh@03_^7Q0?oQ0N483fWQ

000Jh@030>7Q00WQ00<?hN40V^400kkQh@3oh@WQ1PmSh@006^400`3Qh@09h@033n7Q09[Q00>nhN40

on4?h@P?Fn4001[Q00<0hN402N400`oQh@2Jh@03_^7Q0?oQ5n483e?Q000Jh@030>7Q00WQ00<?hN40

V^400kkQh@3ohAoQ20m;h@006^4300WQ00<?hN40V^400kkQh@3ohBOQ1Pm5h@006^400`3Qh@08h@03

3n7Q09_Q00>nhN40on4]h@X?>n4001[Q00<0hN402>400`oQh@2Kh@03_^7Q0?oQ=n483c?Q000Jh@03

0>7Q00SQ00<?hN40Vn400kkQh@3ohCoQ20l[h@006^400`3Qh@08h@033n7Q09_Q00>nhN40on57h@H?

9N4001[Q00<0hN402>400`oQh@2Kh@03_^7Q0?oQL^4001[Q00<0hN402>400`oQh@2Jh@03_^7Q0?oQ

Ln4001[Q00<0hN402>400`oQh@2Jh@03_^7Q0?oQLn4001[Q00<0hN402>400`oQh@2Jh@03_^7Q0?oQ

Ln4001[Q00<0hN402>400`oQh@2Jh@03_^7Q0?oQLn4001[Q00<0hN402>400`oQh@2Jh@03_^7Q0?oQ

Ln4001[Q00<0hN402>400`oQh@2Jh@03_^7Q0?oQLn4001[Q00<0hN401n400`oQh@2Kh@03_^7Q0?oQ

Ln4001[Q0`07h@033n7Q09_Q00>nhN40on5ch@006^400`3Qh@07h@033n7Q09_Q00>nhN40on5ch@00

6^400`3Qh@07h@033n7Q09_Q00>nhN40on5ch@006^400`3Qh@07h@033n7Q09_Q00>nhN40on5ch@00

6^400`3Qh@07h@033n7Q09_Q00>nhN40on5ch@006^400`3Qh@07h@033n7Q09_Q00>nhN40on5ch@00

6^400`3Qh@07h@033n7Q09_Q00>nhN40on5ch@006^400`3Qh@07h@033n7Q09_Q00>nhN40on5ch@00

6^400`3Qh@07h@033n7Q09_Q00>nhN40on5ch@006^400`3Qh@07h@033n7Q09_Q00>nhN40on5ch@00

6^400`3Qh@07h@033n7Q05?Q1@001>40000oh@03_^7Q01WQ1@02h@<0Fn450003h@0005cQ1@02h@03

0>7Q05cQ0`03h@030>7Q027Q000Jh@030>7Q00OQ00<?hN40EN401@3QhN40047Q00>nhN406n400`3Q

h@03h@030>7Q05cQ00L0hN7Q0>4005gQ00L0hN7Q0>4005gQ00<0hN400^400`3Q000Rh@006^4300OQ

00<?hN40EN400`3Qh@02h@030>7Q03gQ00>nhN407>40103QhN4405gQ00L0hN7Q0>4005gQ00L0hN7Q

0>4005kQ00L0hN7Q0>4002;Q000Jh@030>7Q00OQ00<?hN40EN400`3Qh@02h@030>7Q03gQ00>nhN40

7>401`3QhN40h@00G^40103QhN4205kQ00<0hN400^400`3Qh@1Mh@070>7Qh@3Q000Rh@006^400`3Q

h@06h@033n7Q05KQ00L0hN7Q0>4003kQ00>nhN407>400`3Qh@02h@80G^401@3QhN4005oQ00L0hN7Q

0>4005gQ00<0h@000^400`3Q000Rh@006^400`3Qh@06h@033n7Q05GQ0P04h@030>7Q03gQ00>nhN40

6n4200GQ00<0hN40Fn4200CQ0P1Lh@801>400`3Qh@1Mh@030>7Q00;Q00<0hN408N4001[Q00<0hN40

1^400`oQh@2Kh@03_^7Q0?oQM>4001[Q00<0hN401^400`oQh@2Kh@03_^7Q0?oQM>4001[Q00<0hN40

1^400`oQh@2Kh@03_^7Q0?oQM>4001[Q00<0hN401^400`oQh@2Kh@03_^7Q0?oQM>4001[Q00<0hN40

1^400`oQh@2Kh@03_^7Q0?oQM>4001[Q00<0hN401^400`oQh@2Kh@03_^7Q0?oQM>4001[Q00<0hN40

1^400`oQh@2Kh@03_^7Q0?oQJ^4400KQ000Jh@030>7Q00KQ00<?hN40Vn400kkQh@3ohF[Q0`07h@00

5n4<00033`0009/000>n0000o`1K017Q00<0hN401N4001[Q00<0hN401^400`oQh@0>h@030>7Q01KQ

00<0hN405^400`3Qh@0Fh@030>7Q01KQ00<0hN405^400`3Qh@0=h@03_^7Q00KQ00<0hN405^400`3Q

h@0Fh@030>7Q01OQ00<0hN405^400`3Qh@0Fh@030>7Q01KQ00<0hN405^400`3Qh@0Fh@030>7Q01KQ

00<0hN405^400`3Qh@0Gh@030>7Q01KQ00<0hN405^400`3Qh@0Jh@801n4001[Q00<0hN401^400`oQ

h@0>h@030>7Q01KQ00<0hN405^400`3Qh@0Fh@030>7Q01KQ00<0hN405^400`3Qh@0=h@03_^7Q00KQ

00<0hN405^400`3Qh@0Fh@030>7Q01OQ00<0hN405^400`3Qh@0Fh@030>7Q01KQ00<0hN405^400`3Q

h@0Fh@030>7Q01KQ00<0hN405^400`3Qh@0Gh@030>7Q01KQ00<0hN405^400`3Qh@0Sh@006^400`3Q

h@06h@033n7Q05WQ00<0hN40?n400kkQh@0Oh@030>7Q06;Q00<0hN40HN400`3Qh@1Rh@030>7Q02?Q

000Jh@030>7Q00KQ00<?hN40FN400`3Qh@0oh@03_^7Q01oQ00<0hN40H^400`3Qh@1Qh@030>7Q06;Q

00<0hN408n4001[Q00<0hN401^400`oQh@2Kh@03_^7Q0?oQM>4001[Q00<0hN401^400`oQh@2Kh@03

_^7Q0?oQM>4001[Q00<0hN401^400`oQh@2Kh@03_^7Q0?oQM>4001[Q00<0hN401^400`oQh@2Kh@03

_^7Q0?oQM>4001[Q00<0hN401^400`oQh@2Kh@03_^7Q0?oQM>4001[Q00<0hN401^400`oQh@2Kh@03

_^7Q0?oQM>4001[Q00<0hN401^400`oQh@2Kh@03_^7Q0?oQM>4001[Q00<0hN401n400`oQh@2Jh@03

_^7Q0?oQM>4001[Q0`07h@033n7Q09[Q00>nhN40on5dh@006^400`3Qh@07h@033n7Q09_Q00>nhN40

on5ch@006^400`3Qh@07h@033n7Q09_Q00>nhN40on5ch@006^400`3Qh@07h@033n7Q09_Q00>nhN40

on5ch@006^400`3Qh@07h@033n7Q09_Q00>nhN40on5ch@006^400`3Qh@07h@033n7Q09_Q00>nhN40

on5ch@006^400`3Qh@07h@033n7Q09_Q00>nhN40on5ch@006^400`3Qh@07h@033n7Q09_Q00>nhN40

on5ch@006^400`3Qh@07h@033n7Q09_Q00>nhN40on5ch@006^400`3Qh@07h@033n7Q09_Q00>nhN40

on5ch@006^400`3Qh@07h@033n7Q09_Q00>nhN40on5ch@006^400`3Qh@07h@033n7Q09_Q00>nhN40

on5ch@006^4300OQ00<?hN40Vn400kkQh@3ohG?Q000Jh@030>7Q00SQ00<?hN40V^400kkQh@3ohG?Q

000Jh@030>7Q00SQ00<?hN40V^400kkQh@3ohG?Q000Jh@030>7Q00SQ00<?hN40V^400kkQh@3ohG?Q

000Jh@030>7Q00SQ00<?hN40V^400kkQh@3ohG?Q000Jh@030>7Q00SQ00<?hN40V^400kkQh@3ohG?Q

000Jh@030>7Q00SQ00<?hN40V^400kkQh@3ohG?Q000Jh@030>7Q00SQ00<?hN40V^400kkQh@3ohG?Q

000Jh@030>7Q00SQ00<?hN40Vn400kkQh@3ohG;Q000Jh@030>7Q00SQ00<?hN40Vn400kkQh@3ohDKQ

1`lUh@006^400`3Qh@08h@033n7Q09_Q00>nhN40on4nh@P?;>4001[Q00<0hN402>400`oQh@2Kh@03

_^7Q0?oQ=>4:3cCQ000Jh@<02N400`oQh@2Jh@03_^7Q0?oQ;>483ckQ000Jh@030>7Q00WQ00<?hN40

V^400kkQh@3ohBCQ20m6h@006^400`3Qh@09h@033n7Q09[Q00>nhN40on4Nh@H?C^4001[Q00<0hN40

2N400`oQh@2Jh@03_^7Q0?oQ5^483eCQ000Jh@030>7Q00WQ00<?hN40V^400kkQh@3oh@kQ20mLh@00

6^400`3Qh@09h@033n7Q09[Q00>nhN40on48h@H?I>4001[Q00<0hN402^400`oQh@2Ih@03_^7Q0?oQ

20mZh@006^400`3Qh@0:h@033n7Q09[Q00>nhN40n>463g;Q000Jh@030>7Q00[Q00<?hN40V^400kkQ

h@3bh@H?N>4001[Q00<0hN402^400`oQh@2Jh@03_^7Q0>cQ1Pmnh@006^400`3Qh@0:h@033n7Q09[Q

00>nhN40i^463hCQ000Jh@030>7Q00[Q00<?hN40V^400kkQh@3Ph@H?R^4001[Q00<0hN402n400`oQ

h@2Ih@03_^7Q0=[Q1Pn@h@006^4300_Q00<?hN40VN400kkQh@3Dh@H?U^4001[Q00<0hN402n400`oQ

h@2Ih@03_^7Q0<kQ1PnLh@006^400`3Qh@0;h@033n7Q09[Q00>nhN40an463j;Q000Jh@030>7Q00_Q

00<?hN40V^400kkQh@31h@H?Z>4001[Q00<0hN403>400`oQh@2Ih@03_^7Q0;gQ10n^h@006^400`3Q

h@0<h@033n7Q09WQ00>nhN40]n463k;Q000Jh@030>7Q00cQ00<?hN40VN400kkQh@2ah@H?^>4001[Q

00<0hN403>400`oQh@2Ih@03_^7Q0:gQ10nnh@006^400`3Qh@0=h@033n7Q09SQ00>nhN40Yn463l;Q

000Jh@030>7Q00gQ00<?hN40VN400kkQh@2Rh@@?b>40017Q00<0hN401^400`3Qh@0=h@033n7Q09WQ

00>nhN40W^443lcQ000@h@030>4000OQ00<0hN403N400`oQh@2Ih@03_^7Q09SQ1Po@h@004^400`3Q

h@05h@D03>400`oQh@2Hh@03_^7Q09CQ10oFh@004>4200SQ00<0hN403^400`oQh@2Hh@03_^7Q093Q

10oJh@004>400`3Qh@07h@030>7Q00kQ00<?hN40V>400kkQh@2:h@H?g^40013Q0`07h@030>7Q00oQ

00<?hN40V>400kkQh@25h@@?i>4001[Q00<0hN403n400`oQh@2Hh@03_^7Q087Q10oXh@006^400`3Q

h@0?h@033n7Q09SQ00>nhN40ON443ncQ000Jh@030>7Q00oQ00<?hN40V>400kkQh@1hh@D?l>4001[Q

00<0hN404>400`oQh@2Gh@03_^7Q07CQ10oeh@006^400`3Qh@0@h@033n7Q09SQ00>nhN40Kn443oWQ

000Jh@030>7Q013Q00<?hN40V>400kkQh@1[h@@?oN4001[Q00<0hN404N400`oQh@2Gh@03_^7Q06OQ

10ooh@;Q000Jh@030>7Q017Q00<?hN40Un400kkQh@1Sh@@?on46h@006^400`3Qh@0Bh@033n7Q09KQ

00>nhN40Gn443n?Q00>nhN408n4001[Q0`0Bh@033n7Q09OQ00>nhN40F^443n?Q1;hVh@006^400`3Q

h@0Bh@033n7Q09OQ00>nhN40E^443n?Q1;hZh@006^400`3Qh@0Ch@033n7Q09KQ00>nhN40D^443n?Q

1;h^h@006^400`3Qh@0Ch@033n7Q09KQ00>nhN40C^443nCQ0khbh@006^400`3Qh@0Dh@033n7Q09GQ

00>nhN40B^443nCQ1;heh@006^400`3Qh@0Dh@033n7Q09KQ00>nhN40An423nCQ1;hih@006^400`3Q

h@0Dh@033n7Q09KQ00>nhN40@n443n?Q0khmh@006^400`3Qh@0Eh@033n7Q09GQ00>nhN40?n443n?Q

1;i0h@006^400`3Qh@0Eh@033n7Q09GQ00>nhN40>n443n?Q1;i4h@006^400`3Qh@0Fh@033n7Q09GQ

00>nhN40=^443nCQ0ki8h@006^400`3Qh@0Fh@033n7Q09GQ00>nhN40=>423nCQ1;i;h@006^400`3Q

h@0Fh@033n7Q09GQ00>nhN40<>443n?Q0ki?h@006^4301OQ00<?hN40U>400kkQh@0/h@@?i>43_U;Q

000Jh@030>7Q01OQ00<?hN40UN400kkQh@0Yh@8?i>44_UGQ000Jh@030>7Q01SQ00<?hN40U>400kkQ

h@0Uh@@?hn43_UWQ000Jh@030>7Q01WQ00<?hN40Tn400kkQh@0Qh@@?i>43_UcQ000Jh@030>7Q01WQ

00<?hN40U>400kkQh@0Nh@8?i>44_UoQ000Jh@030>7Q01[Q00<?hN40Tn400kkQh@0Jh@@?h^44_V?Q

000Jh@030>7Q01_Q00<?hN40T^400kkQh@0Fh@@?hn43_VOQ000Jh@030>7Q01_Q00<?hN40Tn400kkQ

h@0Ch@8?i>43_V[Q000Jh@030>7Q01cQ00<?hN40T^400kkQh@0?h@@?hn43_VgQ000Jh@030>7Q01gQ

00<?hN40TN400kkQh@0;h@@?i>43_W3Q000Jh@030>7Q01gQ00<?hN40T^400kkQh@08h@8?iN43_W?Q

000Jh@030>7Q01kQ00<?hN40TN400kkQh@04h@@?i>43_WKQ000Jh@<07n400`oQh@2@h@03_^7Q00@?

iN43_WWQ000Jh@030>7Q01oQ00<?hN40TN423nKQ0kilh@006^400`3Qh@0Ph@033n7Q08cQ10l00kkQ

h@3Rh@>nOn4001[Q00<0hN408N400`oQh@29h@8?1>400kkQh@3Oh@>nP^4001[Q00<0hN408^400`oQ

h@24h@@?1n400kkQh@3Kh@>nQN4001[Q00<0hN408n400`oQh@1oh@@?2n400kkQh@3Hh@>nR>4001[Q

00<0hN409>400`oQh@1lh@8?3n400kkQh@3Eh@>nRn4001[Q00<0hN409N400`oQh@1gh@@?4^400kkQ

h@3Ah@>nS^4001[Q00<0hN409^400`oQh@1bh@@?5^400kkQh@3?h@:nTN4001[Q00<0hN409n400`oQ

h@1_h@8?6n400kkQh@3;h@>nTn4001[Q00<0hN40:>400`oQh@1Zh@@?7N400kkQh@38h@>nU^4001[Q

00<0hN40:N423fKQ10lRh@03_^7Q0<CQ0kjIh@006^400`3Qh@0[h@033n7Q05oQ10lVh@03_^7Q0<7Q

0kjLh@006^4302cQ00<?hN40G>423b[Q00>nhN40_n42_YoQ000Jh@030>7Q02gQ0PmHh@@?;N400kkQ

h@2kh@>nXN4001[Q00<0hN40;n423e;Q10lah@03_^7Q0;SQ0kjTh@006^400`3Qh@0ah@033n7Q04_Q

10lfh@03_^7Q0;CQ0kjWh@006^400`3Qh@0bh@033n7Q04KQ10ljh@03_^7Q0;;Q0[jZh@006^400`3Q

h@0ch@@?@>443coQ00>nhN40[^43_ZcQ000Jh@030>7Q03OQ0Plhh@H?@n400kkQh@2[h@>n[n4001[Q

00<0hN40>N423c;Q10m:h@03_^7Q0:SQ0[jbh@006^400`3Qh@0kh@@?:>463doQ00>nhN40Y>43_[CQ

000Jh@030>7Q03oQ1PlJh@P?EN400kkQh@2Qh@>n]n4000[Q1@02h@030>7Q00KQ00<0hN40AN4J3ekQ

00>nhN40W^42_[[Q000<h@070>7Qh@3Q0007h@030>7Q0;gQ00>nhN40Vn43_[cQ000<h@070>7Qh@3Q

0007h@D0_>400kkQh@2Gh@>n_n4000cQ00L0hN7Q0>4000OQ00<0hN40_n400kkQh@2Dh@:n`^4000cQ

00L0hN7Q0>4000OQ00<0hN40_n400kkQh@2Ah@>na>4000_Q0P04h@030>7Q00KQ00<0hN40`>400kkQ

h@2=h@>nan4001[Q00<0hN40`N400kkQh@2:h@:nb^4001[Q00<0hN40`N400kkQh@27h@>nc>4001[Q

00<0hN40`^400kkQh@23h@>ncn4001[Q00<0hN40`n400kkQh@20h@:nd^4001[Q00<0hN40a>400kkQ

h@1lh@>ne>4001[Q00<0hN40aN400kkQh@1hh@>nen4001[Q00<0hN40a^400kkQh@1eh@:nf^4001[Q

00<0hN40an400kkQh@1ah@>ng>4001[Q0`37h@03_^7Q06kQ0kkOh@006^400`3Qh@38h@:nJn43_^;Q

000Jh@030>7Q0<[Q00>nhN40I^42_^GQ000Jh@030>7Q0<_Q00>nhN40H^43_^OQ000Jh@030>7Q0<cQ

00>nhN40G^43_^[Q000Jh@030>7Q0<gQ00>nhN40F^43_^gQ000Jh@030>7Q0<kQ00>nhN40E^43__3Q

000Jh@030>7Q0<oQ0[iCh@>nln4001[Q00<0hN40dN400kkQh@1<h@Bnm^4001[Q00<0hN40d^42_TWQ

0kkjh@006^400`3Qh@3Dh@:nA>43__gQ000Jh@030>7Q0=KQ0[hnh@Bnon41h@006^400`3Qh@3Hh@:n

>>44__oQ1N4001[Q0`3Jh@>n<N44__oQ2N4001[Q00<0hN40gN43_RWQ1Kkoh@gQ000Jh@030>7Q0>3Q

1;hPh@Fnon4Bh@006^400`3Qh@3Th@Nn4N48__oQ5n4001[Q00<0hN40jn4A__oQ7n4001[Q00<0hN40

on7ohAcQ000Jh@030>7Q0?oQon4Lh@006^400`3Qh@3ohOoQ7>4001[Q00<0hN40on7ohAcQ000Jh@03

0>7Q0?oQon4Lh@006^400`3Qh@3ohOoQ7>4001[Q00<0hN40on7ohAcQ000Jh@030>7Q0?oQon4Lh@00

on7ohCWQ003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ

>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQ4n420004h@00h@@00^400`3Qh@3ohAOQ003ohACQ

00<0h@001n400`3Q003ohASQ003ohACQ0`02h@@000CQ0>40on4Hh@00on4Dh@040>4000KQ00<0h@00

on4Hh@006>420?WQ00<0hN401n400`3Q003ohASQ000Ih@030>7Q0?KQ0P0:h@030>7Q0?oQ5n4001OQ

0`02h@030>7Q0?oQon4Jh@005^40203Qh@3Q0>40on7ohA_Q000Fh@080>7Q0>40h@3ohOoQ6n4001OQ

0`001>40h@3ohOoQ6n4001_Q00<0h@00on7ohA_Q000Lh@030>7Q0?oQon4Jh@00on7ohCWQ003ohOoQ

>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400001\

\>"],

  ImageRangeCache->{{{73.4375, 526}, {423.375, 144.125}} -> {7.63414, 

  1.62551, 0.0199214, 0.0808776}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-0.849469 0.0730264 0.309017 0.0238087 [

[.1729 .29652 -6 -9 ]

[.1729 .29652 6 0 ]

[.31895 .29652 -6 -9 ]

[.31895 .29652 6 0 ]

[.46501 .29652 -6 -9 ]

[.46501 .29652 6 0 ]

[.61106 .29652 -6 -9 ]

[.61106 .29652 6 0 ]

[.75711 .29652 -6 -9 ]

[.75711 .29652 6 0 ]

[.90316 .29652 -6 -9 ]

[.90316 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01435 .07093 -18 -4.5 ]

[.01435 .07093 0 4.5 ]

[.01435 .18997 -12 -4.5 ]

[.01435 .18997 0 4.5 ]

[.01435 .42806 -6 -4.5 ]

[.01435 .42806 0 4.5 ]

[.01435 .5471 -12 -4.5 ]

[.01435 .5471 0 4.5 ]

[.02685 .64303 -7 0 ]

[.02685 .64303 7 16 ]

[.5 .63053 -12 0 ]

[.5 .63053 12 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.1729 .30902 m

.1729 .31527 L

s

[(14)] .1729 .29652 0 1 Mshowa

.31895 .30902 m

.31895 .31527 L

s

[(16)] .31895 .29652 0 1 Mshowa

.46501 .30902 m

.46501 .31527 L

s

[(18)] .46501 .29652 0 1 Mshowa

.61106 .30902 m

.61106 .31527 L

s

[(20)] .61106 .29652 0 1 Mshowa

.75711 .30902 m

.75711 .31527 L

s

[(22)] .75711 .29652 0 1 Mshowa

.90316 .30902 m

.90316 .31527 L

s

[(24)] .90316 .29652 0 1 Mshowa

.125 Mabswid

.06336 .30902 m

.06336 .31277 L

s

.09987 .30902 m

.09987 .31277 L

s

.13639 .30902 m

.13639 .31277 L

s

.20941 .30902 m

.20941 .31277 L

s

.24593 .30902 m

.24593 .31277 L

s

.28244 .30902 m

.28244 .31277 L

s

.35547 .30902 m

.35547 .31277 L

s

.39198 .30902 m

.39198 .31277 L

s

.42849 .30902 m

.42849 .31277 L

s

.50152 .30902 m

.50152 .31277 L

s

.53803 .30902 m

.53803 .31277 L

s

.57455 .30902 m

.57455 .31277 L

s

.64757 .30902 m

.64757 .31277 L

s

.68408 .30902 m

.68408 .31277 L

s

.7206 .30902 m

.7206 .31277 L

s

.79362 .30902 m

.79362 .31277 L

s

.83014 .30902 m

.83014 .31277 L

s

.86665 .30902 m

.86665 .31277 L

s

.93968 .30902 m

.93968 .31277 L

s

.97619 .30902 m

.97619 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02685 .07093 m

.0331 .07093 L

s

[(-10)] .01435 .07093 1 0 Mshowa

.02685 .18997 m

.0331 .18997 L

s

[(-5)] .01435 .18997 1 0 Mshowa

.02685 .42806 m

.0331 .42806 L

s

[(5)] .01435 .42806 1 0 Mshowa

.02685 .5471 m

.0331 .5471 L

s

[(10)] .01435 .5471 1 0 Mshowa

.125 Mabswid

.02685 .09474 m

.0306 .09474 L

s

.02685 .11855 m

.0306 .11855 L

s

.02685 .14236 m

.0306 .14236 L

s

.02685 .16616 m

.0306 .16616 L

s

.02685 .21378 m

.0306 .21378 L

s

.02685 .23759 m

.0306 .23759 L

s

.02685 .2614 m

.0306 .2614 L

s

.02685 .28521 m

.0306 .28521 L

s

.02685 .33283 m

.0306 .33283 L

s

.02685 .35663 m

.0306 .35663 L

s

.02685 .38044 m

.0306 .38044 L

s

.02685 .40425 m

.0306 .40425 L

s

.02685 .45187 m

.0306 .45187 L

s

.02685 .47568 m

.0306 .47568 L

s

.02685 .49949 m

.0306 .49949 L

s

.02685 .5233 m

.0306 .5233 L

s

.02685 .04712 m

.0306 .04712 L

s

.02685 .02331 m

.0306 .02331 L

s

.02685 .57091 m

.0306 .57091 L

s

.02685 .59472 m

.0306 .59472 L

s

.25 Mabswid

.02685 0 m

.02685 .61803 L

s

gsave

.02685 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -73 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(k) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(28) show

83.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 .4 1 r

.5 Mabswid

.61106 .44096 m

.6082 .44204 L

.60528 .44315 L

.60236 .44427 L

.59944 .4454 L

.59652 .44654 L

.5936 .44768 L

.59068 .44883 L

.58776 .44999 L

.58483 .45116 L

.58191 .45233 L

.57899 .45351 L

.57607 .4547 L

.57315 .4559 L

.57023 .45711 L

.56731 .45833 L

.56439 .45955 L

.56147 .46078 L

.55855 .46202 L

.55562 .46327 L

.5527 .46452 L

.54978 .46579 L

.54686 .46706 L

.54394 .46835 L

.54102 .46964 L

.5381 .47094 L

.53518 .47224 L

.53226 .47356 L

.52933 .47489 L

.52641 .47622 L

.52349 .47756 L

.52057 .47892 L

.51765 .48028 L

.51473 .48165 L

.51181 .48303 L

.50889 .48441 L

.50597 .48581 L

.50305 .48721 L

.50012 .48863 L

.4972 .49005 L

.49428 .49148 L

.49136 .49292 L

.48844 .49437 L

.48552 .49583 L

.4826 .4973 L

.47968 .49877 L

.47676 .50025 L

.47383 .50175 L

.47091 .50325 L

.46799 .50476 L

Mistroke

.46507 .50628 L

.46215 .5078 L

.45923 .50934 L

.45631 .51088 L

.45339 .51243 L

.45047 .51399 L

.44755 .51555 L

.44462 .51713 L

.4417 .51871 L

.43878 .5203 L

.43586 .52189 L

.43294 .5235 L

.43002 .52511 L

.4271 .52672 L

.42418 .52834 L

.42126 .52997 L

.41833 .5316 L

.41541 .53324 L

.41249 .53488 L

.40957 .53653 L

.40665 .53818 L

.40373 .53984 L

.40081 .5415 L

.39789 .54316 L

.39497 .54483 L

.39205 .54649 L

.38912 .54816 L

.3862 .54983 L

.38328 .5515 L

.38036 .55317 L

.37744 .55483 L

.37452 .5565 L

.3716 .55816 L

.36868 .55982 L

.36576 .56147 L

.36283 .56312 L

.35991 .56476 L

.35699 .56639 L

.35407 .56802 L

.35115 .56963 L

.34823 .57124 L

.34531 .57283 L

.34239 .57441 L

.33947 .57597 L

.33655 .57752 L

.33362 .57904 L

.3307 .58055 L

.32778 .58203 L

.32486 .58349 L

.32194 .58492 L

Mistroke

.31902 .58633 L

.3161 .5877 L

.31318 .58904 L

.31026 .59034 L

.30733 .5916 L

.30441 .59282 L

.30149 .594 L

.29857 .59512 L

.29565 .5962 L

.29273 .59721 L

.28981 .59817 L

.28689 .59906 L

.28397 .59989 L

.28104 .60064 L

.27812 .6013 L

.2752 .60189 L

.27228 .60238 L

.26936 .60278 L

.26644 .60307 L

.26352 .60325 L

.2606 .60332 L

.25768 .60326 L

.25476 .60306 L

.25183 .60272 L

.24891 .60222 L

.24599 .60155 L

.24307 .60071 L

.24015 .59968 L

.23723 .59845 L

.23431 .59699 L

.23139 .5953 L

.22847 .59335 L

.22554 .59113 L

.22262 .58862 L

.2197 .58578 L

.21678 .5826 L

.21386 .57904 L

.21094 .57507 L

.20802 .57064 L

.2051 .56572 L

.20218 .56026 L

.19926 .55418 L

.19633 .54741 L

.19341 .53988 L

.19049 .53146 L

.18757 .52203 L

.18465 .5114 L

.18173 .49932 L

.17881 .48547 L

.17589 .46933 L

Mistroke

.17297 .45006 L

.17004 .42603 L

.16712 .39318 L

.1642 .31567 L

.16418 .30902 L

Mfstroke

.61106 .17707 m

.6082 .17599 L

.60528 .17488 L

.60236 .17376 L

.59944 .17263 L

.59652 .1715 L

.5936 .17035 L

.59068 .1692 L

.58776 .16804 L

.58483 .16688 L

.58191 .1657 L

.57899 .16452 L

.57607 .16333 L

.57315 .16213 L

.57023 .16092 L

.56731 .15971 L

.56439 .15849 L

.56147 .15725 L

.55855 .15601 L

.55562 .15477 L

.5527 .15351 L

.54978 .15224 L

.54686 .15097 L

.54394 .14969 L

.54102 .1484 L

.5381 .1471 L

.53518 .14579 L

.53226 .14447 L

.52933 .14315 L

.52641 .14181 L

.52349 .14047 L

.52057 .13912 L

.51765 .13776 L

.51473 .13639 L

.51181 .13501 L

.50889 .13362 L

.50597 .13223 L

.50305 .13082 L

.50012 .12941 L

.4972 .12798 L

.49428 .12655 L

.49136 .12511 L

.48844 .12366 L

.48552 .12221 L

.4826 .12074 L

.47968 .11926 L

.47676 .11778 L

.47383 .11629 L

.47091 .11479 L

.46799 .11328 L

Mistroke

.46507 .11176 L

.46215 .11023 L

.45923 .1087 L

.45631 .10715 L

.45339 .1056 L

.45047 .10405 L

.44755 .10248 L

.44462 .10091 L

.4417 .09932 L

.43878 .09774 L

.43586 .09614 L

.43294 .09454 L

.43002 .09293 L

.4271 .09131 L

.42418 .08969 L

.42126 .08806 L

.41833 .08643 L

.41541 .08479 L

.41249 .08315 L

.40957 .0815 L

.40665 .07985 L

.40373 .07819 L

.40081 .07653 L

.39789 .07487 L

.39497 .07321 L

.39205 .07154 L

.38912 .06988 L

.3862 .06821 L

.38328 .06654 L

.38036 .06487 L

.37744 .0632 L

.37452 .06154 L

.3716 .05988 L

.36868 .05822 L

.36576 .05656 L

.36283 .05492 L

.35991 .05327 L

.35699 .05164 L

.35407 .05001 L

.35115 .0484 L

.34823 .04679 L

.34531 .0452 L

.34239 .04362 L

.33947 .04206 L

.33655 .04052 L

.33362 .03899 L

.3307 .03749 L

.32778 .036 L

.32486 .03454 L

.32194 .03311 L

Mistroke

.31902 .0317 L

.3161 .03033 L

.31318 .029 L

.31026 .02769 L

.30733 .02643 L

.30441 .02521 L

.30149 .02404 L

.29857 .02291 L

.29565 .02184 L

.29273 .02082 L

.28981 .01986 L

.28689 .01897 L

.28397 .01815 L

.28104 .0174 L

.27812 .01673 L

.2752 .01615 L

.27228 .01565 L

.26936 .01525 L

.26644 .01496 L

.26352 .01478 L

.2606 .01472 L

.25768 .01478 L

.25476 .01497 L

.25183 .01532 L

.24891 .01582 L

.24599 .01648 L

.24307 .01732 L

.24015 .01835 L

.23723 .01959 L

.23431 .02104 L

.23139 .02274 L

.22847 .02468 L

.22554 .0269 L

.22262 .02941 L

.2197 .03225 L

.21678 .03543 L

.21386 .03899 L

.21094 .04296 L

.20802 .04739 L

.2051 .05231 L

.20218 .05778 L

.19926 .06386 L

.19633 .07062 L

.19341 .07816 L

.19049 .08657 L

.18757 .09601 L

.18465 .10664 L

.18173 .11871 L

.17881 .13256 L

.17589 .1487 L

Mistroke

.17297 .16797 L

.17004 .192 L

.16712 .22485 L

.1642 .30236 L

.16418 .30902 L

Mfstroke

.61106 .44096 m

.61836 .43823 L

.62566 .43554 L

.63297 .4329 L

.64027 .43031 L

.64757 .42775 L

.65487 .42524 L

.66218 .42277 L

.66948 .42034 L

.67678 .41794 L

.68408 .41559 L

.69139 .41328 L

.69869 .411 L

.70599 .40875 L

.7133 .40654 L

.7206 .40437 L

.7279 .40223 L

.7352 .40012 L

.74251 .39804 L

.74981 .39599 L

.75711 .39398 L

.76441 .39199 L

.77172 .39003 L

.77902 .3881 L

.78632 .3862 L

.79362 .38432 L

.80093 .38247 L

.80823 .38065 L

.81553 .37885 L

.82284 .37707 L

.83014 .37532 L

.83744 .37359 L

.84474 .37189 L

.85205 .3702 L

.85935 .36854 L

.86665 .36689 L

.87395 .36527 L

.88126 .36367 L

.88856 .36208 L

.89586 .36052 L

.90316 .35897 L

.91047 .35744 L

.91777 .35592 L

.92507 .35443 L

.93237 .35295 L

.93968 .35148 L

.94698 .35003 L

.95428 .3486 L

.96159 .34718 L

.96889 .34578 L

Mistroke

.97619 .34438 L

Mfstroke

.61106 .17707 m

.61836 .1798 L

.62566 .18249 L

.63297 .18513 L

.64027 .18773 L

.64757 .19028 L

.65487 .19279 L

.66218 .19527 L

.66948 .1977 L

.67678 .20009 L

.68408 .20244 L

.69139 .20476 L

.69869 .20704 L

.70599 .20928 L

.7133 .21149 L

.7206 .21367 L

.7279 .21581 L

.7352 .21792 L

.74251 .21999 L

.74981 .22204 L

.75711 .22406 L

.76441 .22604 L

.77172 .228 L

.77902 .22993 L

.78632 .23183 L

.79362 .23371 L

.80093 .23556 L

.80823 .23738 L

.81553 .23918 L

.82284 .24096 L

.83014 .24271 L

.83744 .24444 L

.84474 .24615 L

.85205 .24783 L

.85935 .2495 L

.86665 .25114 L

.87395 .25276 L

.88126 .25437 L

.88856 .25595 L

.89586 .25752 L

.90316 .25907 L

.91047 .2606 L

.91777 .26211 L

.92507 .26361 L

.93237 .26509 L

.93968 .26655 L

.94698 .268 L

.95428 .26943 L

.96159 .27085 L

.96889 .27226 L

Mistroke

.97619 .27365 L

Mfstroke

1 0 0 r

.61106 .31335 m

.61471 .31195 L

.61836 .31053 L

.62201 .30912 L

.62566 .30769 L

.62932 .30627 L

.63297 .30484 L

.63662 .3034 L

.64027 .30196 L

.64392 .30051 L

.64757 .29906 L

.65122 .2976 L

.65487 .29614 L

.65853 .29467 L

.66218 .2932 L

.66583 .29172 L

.66948 .29024 L

.67313 .28875 L

.67678 .28725 L

.68043 .28575 L

.68408 .28424 L

.68774 .28273 L

.69139 .28122 L

.69504 .2797 L

.69869 .27817 L

.70234 .27664 L

.70599 .27511 L

.70964 .27358 L

.7133 .27204 L

.71695 .2705 L

.7206 .26896 L

.72425 .26742 L

.7279 .26587 L

.73155 .26433 L

.7352 .26279 L

.73885 .26125 L

.74251 .25971 L

.74616 .25817 L

.74981 .25664 L

.75346 .25512 L

.75711 .2536 L

.76076 .25209 L

.76441 .25058 L

.76807 .24909 L

.77172 .24761 L

.77537 .24614 L

.77902 .24468 L

.78267 .24323 L

.78632 .24181 L

.78997 .24039 L

Mistroke

.79362 .239 L

.79728 .23762 L

.80093 .23627 L

.80458 .23493 L

.80823 .23362 L

.81188 .23233 L

.81553 .23106 L

.81918 .22982 L

.82284 .22861 L

.82649 .22742 L

.83014 .22625 L

.83379 .22512 L

.83744 .22401 L

.84109 .22294 L

.84474 .22189 L

.84839 .22087 L

.85205 .21988 L

.8557 .21892 L

.85935 .21799 L

.863 .21709 L

.86665 .21622 L

.8703 .21538 L

.87395 .21457 L

.8776 .21379 L

.88126 .21304 L

.88491 .21232 L

.88856 .21162 L

.89221 .21096 L

.89586 .21032 L

.89951 .20971 L

.90316 .20913 L

.90682 .20858 L

.91047 .20805 L

.91412 .20754 L

.91777 .20706 L

.92142 .20661 L

.92507 .20618 L

.92872 .20577 L

.93237 .20539 L

.93603 .20503 L

.93968 .20469 L

.94333 .20437 L

.94698 .20407 L

.95063 .20379 L

.95428 .20353 L

.95793 .20329 L

.96159 .20307 L

.96524 .20287 L

.96889 .20268 L

.97254 .20251 L

Mistroke

.97619 .20236 L

Mfstroke

.61106 .30468 m

.61471 .30609 L

.61836 .3075 L

.62201 .30892 L

.62566 .31034 L

.62932 .31177 L

.63297 .3132 L

.63662 .31463 L

.64027 .31607 L

.64392 .31752 L

.64757 .31897 L

.65122 .32043 L

.65487 .32189 L

.65853 .32336 L

.66218 .32483 L

.66583 .32631 L

.66948 .3278 L

.67313 .32929 L

.67678 .33078 L

.68043 .33228 L

.68408 .33379 L

.68774 .3353 L

.69139 .33682 L

.69504 .33834 L

.69869 .33986 L

.70234 .34139 L

.70599 .34292 L

.70964 .34446 L

.7133 .34599 L

.71695 .34753 L

.7206 .34907 L

.72425 .35062 L

.7279 .35216 L

.73155 .3537 L

.7352 .35525 L

.73885 .35679 L

.74251 .35833 L

.74616 .35986 L

.74981 .36139 L

.75346 .36292 L

.75711 .36443 L

.76076 .36595 L

.76441 .36745 L

.76807 .36894 L

.77172 .37043 L

.77537 .3719 L

.77902 .37336 L

.78267 .3748 L

.78632 .37623 L

.78997 .37764 L

Mistroke

.79362 .37904 L

.79728 .38041 L

.80093 .38177 L

.80458 .3831 L

.80823 .38442 L

.81188 .38571 L

.81553 .38697 L

.81918 .38821 L

.82284 .38943 L

.82649 .39062 L

.83014 .39178 L

.83379 .39291 L

.83744 .39402 L

.84109 .3951 L

.84474 .39615 L

.84839 .39717 L

.85205 .39816 L

.8557 .39911 L

.85935 .40004 L

.863 .40094 L

.86665 .40181 L

.8703 .40265 L

.87395 .40346 L

.8776 .40424 L

.88126 .40499 L

.88491 .40572 L

.88856 .40641 L

.89221 .40707 L

.89586 .40771 L

.89951 .40832 L

.90316 .4089 L

.90682 .40946 L

.91047 .40999 L

.91412 .41049 L

.91777 .41097 L

.92142 .41142 L

.92507 .41185 L

.92872 .41226 L

.93237 .41265 L

.93603 .41301 L

.93968 .41335 L

.94333 .41367 L

.94698 .41396 L

.95063 .41424 L

.95428 .4145 L

.95793 .41474 L

.96159 .41496 L

.96524 .41516 L

.96889 .41535 L

.97254 .41552 L

Mistroke

.97619 .41567 L

Mfstroke

.61106 .31335 m

.60814 .31448 L

.60449 .31588 L

.60083 .31727 L

.59718 .31867 L

.59353 .32006 L

.58988 .32144 L

.58623 .32282 L

.58258 .3242 L

.57893 .32558 L

.57528 .32696 L

.57162 .32833 L

.56797 .3297 L

.56432 .33107 L

.56067 .33243 L

.55702 .3338 L

.55337 .33516 L

.54972 .33652 L

.54607 .33788 L

.54241 .33925 L

.53876 .3406 L

.53511 .34196 L

.53146 .34332 L

.52781 .34468 L

.52416 .34604 L

.52051 .3474 L

.51685 .34876 L

.5132 .35012 L

.50955 .35149 L

.5059 .35285 L

.50225 .35421 L

.4986 .35558 L

.49495 .35695 L

.4913 .35832 L

.48764 .35969 L

.48399 .36107 L

.48034 .36244 L

.47669 .36382 L

.47304 .36521 L

.46939 .36659 L

.46574 .36798 L

.46208 .36937 L

.45843 .37077 L

.45478 .37217 L

.45113 .37357 L

.44748 .37498 L

.44383 .3764 L

.44018 .37781 L

.43653 .37923 L

.43287 .38066 L

Mistroke

.42922 .38209 L

.42557 .38353 L

.42192 .38497 L

.41827 .38642 L

.41462 .38787 L

.41097 .38933 L

.40731 .39079 L

.40366 .39227 L

.40001 .39374 L

.39636 .39523 L

.39271 .39672 L

.38906 .39821 L

.38541 .39972 L

.38176 .40123 L

.3781 .40275 L

.37445 .40427 L

.3708 .40581 L

.36715 .40735 L

.3635 .4089 L

.35985 .41045 L

.3562 .41202 L

.35255 .41359 L

.34889 .41517 L

.34524 .41676 L

.34159 .41836 L

.33794 .41996 L

.33429 .42158 L

.33064 .4232 L

.32699 .42483 L

.32333 .42648 L

.31968 .42813 L

.31603 .42979 L

.31238 .43145 L

.30873 .43313 L

.30508 .43482 L

.30143 .43652 L

.29778 .43822 L

.29412 .43994 L

.29047 .44166 L

.28682 .4434 L

.28317 .44514 L

.27952 .4469 L

.27587 .44866 L

.27222 .45043 L

.26856 .45221 L

.26491 .454 L

.26126 .4558 L

.25761 .45761 L

.25396 .45943 L

.25031 .46125 L

Mistroke

.24666 .46309 L

.24301 .46493 L

.23935 .46678 L

.2357 .46864 L

.23205 .4705 L

.2284 .47238 L

.22475 .47425 L

.2211 .47614 L

.21745 .47803 L

.21379 .47992 L

.21014 .48182 L

.20649 .48372 L

.20284 .48562 L

.19919 .48752 L

.19554 .48943 L

.19189 .49133 L

.18824 .49323 L

.18458 .49513 L

.18093 .49702 L

.17728 .49891 L

.17363 .50079 L

.16998 .50265 L

.16633 .5045 L

.16268 .50634 L

.15903 .50815 L

.15537 .50994 L

.15172 .5117 L

.14807 .51344 L

.14442 .51513 L

.14077 .51679 L

.13712 .51839 L

.13347 .51994 L

.12981 .52143 L

.12616 .52284 L

.12251 .52417 L

.11886 .52541 L

.11521 .52655 L

.11156 .52756 L

.10791 .52843 L

.10426 .52915 L

.1006 .52969 L

.09695 .53002 L

.0933 .53013 L

.08965 .52997 L

.086 .52951 L

.08235 .52872 L

.0787 .52753 L

.07504 .52589 L

.07139 .52374 L

.06774 .52101 L

Mistroke

.06409 .51759 L

.06044 .51339 L

.05679 .50827 L

.05314 .50208 L

.04949 .49461 L

.04583 .48559 L

.04218 .47466 L

.03853 .46128 L

.03488 .44457 L

.03123 .42292 L

.02758 .3923 L

.0275 .39153 L

.02743 .39075 L

.02736 .38996 L

.02729 .38917 L

.02721 .38836 L

.02714 .38754 L

.02707 .38672 L

.02699 .38588 L

.02692 .38503 L

.02685 .38417 L

.02677 .3833 L

.0267 .38242 L

.02663 .38152 L

.02656 .38061 L

.02648 .37969 L

.02641 .37875 L

.02634 .3778 L

.02626 .37683 L

.02619 .37585 L

.02612 .37485 L

.02604 .37383 L

.02597 .3728 L

.0259 .37174 L

.02583 .37066 L

.02575 .36957 L

.02568 .36845 L

.02561 .3673 L

.02553 .36613 L

.02546 .36494 L

.02539 .36371 L

.02531 .36246 L

.02524 .36117 L

.02517 .35984 L

.02509 .35848 L

.02502 .35708 L

.02495 .35563 L

.02488 .35413 L

.0248 .35258 L

.02473 .35096 L

Mistroke

.02466 .34928 L

.02458 .34752 L

.02451 .34567 L

.02444 .34372 L

.02436 .34165 L

.02429 .33944 L

.02422 .33704 L

.02415 .33441 L

.02407 .33147 L

.024 .32807 L

.02393 .32392 L

.02381 .30902 L

Mfstroke

.61106 .30468 m

.60814 .30356 L

.60449 .30216 L

.60083 .30076 L

.59718 .29937 L

.59353 .29798 L

.58988 .29659 L

.58623 .29521 L

.58258 .29383 L

.57893 .29245 L

.57528 .29108 L

.57162 .28971 L

.56797 .28834 L

.56432 .28697 L

.56067 .2856 L

.55702 .28424 L

.55337 .28287 L

.54972 .28151 L

.54607 .28015 L

.54241 .27879 L

.53876 .27743 L

.53511 .27607 L

.53146 .27471 L

.52781 .27335 L

.52416 .27199 L

.52051 .27063 L

.51685 .26927 L

.5132 .26791 L

.50955 .26655 L

.5059 .26518 L

.50225 .26382 L

.4986 .26245 L

.49495 .26108 L

.4913 .25971 L

.48764 .25834 L

.48399 .25697 L

.48034 .25559 L

.47669 .25421 L

.47304 .25283 L

.46939 .25144 L

.46574 .25005 L

.46208 .24866 L

.45843 .24726 L

.45478 .24586 L

.45113 .24446 L

.44748 .24305 L

.44383 .24164 L

.44018 .24022 L

.43653 .2388 L

.43287 .23737 L

Mistroke

.42922 .23594 L

.42557 .23451 L

.42192 .23306 L

.41827 .23162 L

.41462 .23016 L

.41097 .2287 L

.40731 .22724 L

.40366 .22577 L

.40001 .22429 L

.39636 .22281 L

.39271 .22132 L

.38906 .21982 L

.38541 .21832 L

.38176 .2168 L

.3781 .21529 L

.37445 .21376 L

.3708 .21223 L

.36715 .21069 L

.3635 .20914 L

.35985 .20758 L

.3562 .20602 L

.35255 .20445 L

.34889 .20286 L

.34524 .20128 L

.34159 .19968 L

.33794 .19807 L

.33429 .19646 L

.33064 .19483 L

.32699 .1932 L

.32333 .19156 L

.31968 .18991 L

.31603 .18825 L

.31238 .18658 L

.30873 .1849 L

.30508 .18321 L

.30143 .18152 L

.29778 .17981 L

.29412 .17809 L

.29047 .17637 L

.28682 .17463 L

.28317 .17289 L

.27952 .17114 L

.27587 .16937 L

.27222 .1676 L

.26856 .16582 L

.26491 .16403 L

.26126 .16223 L

.25761 .16042 L

.25396 .15861 L

.25031 .15678 L

Mistroke

.24666 .15495 L

.24301 .1531 L

.23935 .15125 L

.2357 .1494 L

.23205 .14753 L

.2284 .14566 L

.22475 .14378 L

.2211 .1419 L

.21745 .14001 L

.21379 .13811 L

.21014 .13622 L

.20649 .13432 L

.20284 .13241 L

.19919 .13051 L

.19554 .1286 L

.19189 .1267 L

.18824 .1248 L

.18458 .1229 L

.18093 .12101 L

.17728 .11912 L

.17363 .11725 L

.16998 .11538 L

.16633 .11353 L

.16268 .1117 L

.15903 .10988 L

.15537 .10809 L

.15172 .10633 L

.14807 .1046 L

.14442 .1029 L

.14077 .10125 L

.13712 .09964 L

.13347 .09809 L

.12981 .09661 L

.12616 .09519 L

.12251 .09386 L

.11886 .09262 L

.11521 .09149 L

.11156 .09048 L

.10791 .0896 L

.10426 .08889 L

.1006 .08835 L

.09695 .08801 L

.0933 .08791 L

.08965 .08806 L

.086 .08852 L

.08235 .08932 L

.0787 .09051 L

.07504 .09214 L

.07139 .09429 L

.06774 .09703 L

Mistroke

.06409 .10044 L

.06044 .10465 L

.05679 .10976 L

.05314 .11595 L

.04949 .12342 L

.04583 .13244 L

.04218 .14337 L

.03853 .15675 L

.03488 .17346 L

.03123 .19512 L

.02758 .22573 L

.0275 .22651 L

.02743 .22728 L

.02736 .22807 L

.02729 .22887 L

.02721 .22967 L

.02714 .23049 L

.02707 .23132 L

.02699 .23215 L

.02692 .233 L

.02685 .23386 L

.02677 .23473 L

.0267 .23561 L

.02663 .23651 L

.02656 .23742 L

.02648 .23834 L

.02641 .23928 L

.02634 .24023 L

.02626 .2412 L

.02619 .24218 L

.02612 .24318 L

.02604 .2442 L

.02597 .24524 L

.0259 .2463 L

.02583 .24737 L

.02575 .24847 L

.02568 .24959 L

.02561 .25073 L

.02553 .2519 L

.02546 .2531 L

.02539 .25432 L

.02531 .25558 L

.02524 .25687 L

.02517 .25819 L

.02509 .25955 L

.02502 .26096 L

.02495 .26241 L

.02488 .2639 L

.0248 .26546 L

.02473 .26707 L

Mistroke

.02466 .26875 L

.02458 .27051 L

.02451 .27236 L

.02444 .27431 L

.02436 .27638 L

.02429 .2786 L

.02422 .28099 L

.02415 .28362 L

.02407 .28656 L

.024 .28996 L

.02393 .29412 L

.02381 .30902 L

Mfstroke

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{567, 350.313},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.776525,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008g0001GPP10`40000100000800002008200000

P800P020P<30`<3L`:K:l00003<006H009T00<`00?l0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV

09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<003o03?o06Ko09Wo0<co

0?oo0000<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I

<c>I<fJI<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0

IYT0I/`0I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bI

I_nIIP3<IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0c

VC<cVFHcVITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<

VIW<VLc<VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`c

c?lcc01Vc3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03o

c3?oc6Koc9Woc<coc?ooc000oc<0ofH0oiT0ol`0ool0o`0coc<cofHcoiTcol`coolco`1Voc=VofIV

oiUVolaVoomVo`2Ioc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<o`3ooc?oofKooiWoolco

ooooo`0000410@820P<30`@410D51@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C

4a@D5?okl:2PY820P?l0003o0?oo0000ool0o`3oooooob3Q00<0hN40on7ohAKQ000Ph@030>7Q0?oQ

on4Fh@008>400`3Qh@3ohOoQ5^40023Q00<0hN40on7ohAKQ000Ph@030>7Q0?oQon4Fh@008>400`3Q

h@3ohOoQ5^40023Q00<0hN40on7ohAKQ000Ph@030>7Q0?oQon4Fh@008>400`3Qh@1`h@fnon6Hh@00

8>400`3Qh@1]h@>n3N44__oQU>40023Q00<0hN40J^43_QCQ1KkohHoQ000Ph@030>7Q06SQ0[hLh@03

_^7Q0?oQS>40023Q0P1Xh@03_^7Q01gQ0kkohH_Q000Ph@030>7Q06GQ0[hSh@>non68h@008>400`3Q

h@1Th@03_^7Q02KQ0[kohHKQ000Ph@030>7Q06;Q0[h[h@>non63h@008>400`3Qh@1Qh@03_^7Q02kQ

00>nhN40on60h@008>400`3Qh@1Qh@03_^7Q02oQ1;kohGkQ000Ph@030>7Q063Q00>nhN40=>400kkQ

h@3ohG_Q000Ph@030>7Q05oQ00>nhN40=^42__oQNn40023Q00<0hN40GN42_S_Q0kkohGSQ000Ph@03

0>7Q05cQ00>nhN40?^400kkQh@3ohGGQ000Ph@030>7Q05cQ00>nhN40?n42__oQMN40023Q00<0hN40

Fn400kkQh@12h@03_^7Q0?oQL^40023Q00<0hN40Fn400kkQh@13h@>non5ah@008>4205_Q00>nhN40

An42__oQKn40023Q00<0hN40FN400kkQh@1:h@03_^7Q0?oQK>40023Q00<0hN40FN400kkQh@1;h@:n

on5/h@008>400`3Qh@1Hh@03_^7Q04kQ00>nhN40on5Yh@008>400`3Qh@1Hh@03_^7Q04oQ0[kohFWQ

000Ph@030>7Q05OQ00>nhN40D^43__oQI^40023Q00<0hN40En400kkQh@1Eh@03_^7Q0?oQHn40023Q

00<0hN40E^400kkQh@1Gh@:non5Sh@008>400`3Qh@1Fh@03_^7Q05WQ00>nhN40on5Ph@008>400`3Q

h@1Eh@03_^7Q05_Q0[kohF3Q000?h@D00^400`3Qh@07h@030>7Q05GQ00>nhN40GN400kkQh@3ohEgQ

000Ah@070>7Qh@3Q0008h@030>7Q05CQ00>nhN40Gn43__oQG>4000_Q0`03h@070>7Qh@3Q0008h@@0

Dn400kkQh@1Rh@:non5Jh@004N401`3QhN40h@002>400`3Qh@1Dh@03_^7Q06CQ00>nhN40on5Gh@00

4N401`3QhN40h@002>400`3Qh@1Ch@03_^7Q06KQ0[kohEOQ000@h@801>400`3Qh@07h@030>7Q05?Q

00>nhN40J>400kkQh@3ohECQ000Ph@030>7Q05?Q00>nhN40JN42__oQE>40023Q00<0hN40D^400kkQ

h@1/h@>non5Ah@008>400`3Qh@1Bh@03_^7Q06oQ00>nhN40on5>h@008>400`3Qh@1Ah@03_^7Q077Q

0[kohDkQ000Ph@030>7Q057Q00>nhN40Ln400kkQh@3ohD_Q000Ph@030>7Q01WQ3@l[h@03_^7Q07CQ

0[kohD_Q000Ph@030>7Q01OQ0Pl=h@<?:>400kkQh@1fh@:non59h@008>400`3Qh@0Fh@033n7Q013Q

10lSh@03_^7Q07WQ0kkohDKQ000Ph@805N423aOQ0PlQh@03_^7Q07cQ00>nhN40on53h@008>400`3Q

h@0Bh@8?6n443agQ00>nhN40ON42__oQ@n40023Q00<0hN404N400`oQh@0Oh@8?6n400kkQh@1oh@03

_^7Q0?oQ@>40023Q00<0hN404>400`oQh@0Rh@8?6>400kkQh@21h@>non4oh@008>400`3Qh@0?h@03

3n7Q02GQ0PlFh@03_^7Q08CQ0[kohCgQ000Ph@030>7Q00kQ00<?hN40:>433a;Q00>nhN40Qn400kkQ

h@3ohC[Q000Ph@030>7Q00gQ00<?hN40;>423a3Q00>nhN40R>42__oQ>^40023Q00<0hN403N400`oQ

h@0^h@8?3^400kkQh@2:h@03_^7Q0?oQ=n40023Q00<0hN403>400`oQh@0ah@8?3>400kkQh@2;h@>n

on4fh@008>400`3Qh@0;h@033n7Q03CQ0Pl:h@03_^7Q08kQ0[kohCCQ000Ph@030>7Q00_Q00<?hN40

=^423`OQ00>nhN40TN400kkQh@3ohC7Q000Ph@030>7Q00[Q00<?hN40>N423`GQ00>nhN40T^43__oQ

<>40023Q00<0hN402N400`oQh@0lh@8?0n400kkQh@2Eh@:non4^h@008>4200[Q00<?hN40?^423`03

hKkQ09SQ00>nhN40on4[h@008>400`3Qh@08h@033n7Q047Q00<?_^40VN42__oQ:n40023Q00<0hN40

2>400`oQh@11h@03_Pl?09_Q0kkohBSQ000Ph@030>7Q00SQ00<?hN40@N400kkQh@023icQ00>nhN40

on4Uh@008>400`3Qh@07h@033n7Q04;Q00>nhN400^423i_Q0[kohBGQ000Ph@030>7Q00OQ00<?hN40

@^400kkQh@04h@8?Vn43__oQ8^40023Q00<0hN401^400`oQh@12h@03_^7Q00OQ0PnLh@03_^7Q0?oQ

7n40023Q00<0hN401^400`oQh@12h@03_^7Q00WQ0PnKh@>non4Nh@008>400`3Qh@06h@033n7Q04;Q

00>nhN402n423icQ0[kohAcQ000Ph@030>7Q00GQ00<?hN40@n400kkQh@0=h@8?W>400kkQh@3ohAWQ

000Ph@030>7Q00GQ00<?hN40@n400kkQh@0?h@033n7Q09[Q0kkohASQ000Ph@030>7Q00GQ00<?hN40

@^400kkQh@0Ah@8?WN42__oQ5^40023Q0P05h@033n7Q04?Q00>nhN404n423igQ0kkohA?Q000Ph@03

0>7Q00CQ00<?hN40@n400kkQh@0Eh@8?W^42__oQ4N40023Q00<0hN401>400`oQh@13h@03_^7Q01OQ

0PnNh@>non4>h@008>400`3Qh@04h@033n7Q04?Q00>nhN406N423ioQ00>nhN40on4;h@008>400`3Q

h@03h@033n7Q04CQ00>nhN406n423ikQ0kkoh@[Q000Ph@030>7Q00?Q00<?hN40A>400kkQh@0Mh@8?

Wn42__oQ2>40023Q00<0hN400n400`oQh@13h@03_^7Q023Q0PnOh@>non45h@008>400`3Qh@03h@03

3n7Q04?Q00>nhN408^433ioQ00>nhN40on42h@008>400`3Qh@03h@033n7Q04?Q00>nhN409N423ikQ

0kkoh@7Q000Ph@030>7Q00?Q00<?hN40@n400kkQh@0Wh@8?Wn42__kQ000Ph@030>7Q00;Q00<?hN40

A>400kkQh@0Yh@8?Wn43___Q000Ph@030>7Q00;Q00<?hN40@n400kkQh@0/h@8?X>43__SQ000Ph@80

0n400`oQh@13h@03_^7Q02kQ0PnQh@03_^7Q0?GQ000Ph@030>7Q00;Q00<?hN40@n400kkQh@0`h@8?

X>43__CQ000Ph@050>7Qh@l0A^400kkQh@0bh@8?XN43__7Q000Ph@050>7Qh@l0A^400kkQh@0dh@8?

X^42_^oQ000Ph@050>7Qh@l0A^400kkQh@0fh@033n7Q0:7Q0kk/h@008>401@3QhN4?04KQ00>nhN40

=n423jCQ0kkYh@008>401@3QhN4?04KQ00>nhN40>N443j?Q0[kWh@008>40103Qh@m7h@03_^7Q03gQ

0PnSh@>ni>40023Q00@0hN4?A^400kkQh@10h@8?Y>42_^;Q000Ph@040>7Q3dKQ00>nhN40@^423jCQ

0kkOh@008>40103Qh@m6h@03_^7Q04CQ0PnUh@Bnfn4001KQ00<0hN401n40103Qh@m6h@03_^7Q04KQ

0PnWh@>nf>4001GQ00<0h@002>40103Qh@m6h@03_^7Q04SQ00<?hN40Yn42_]KQ000@h@<01>400`3Q

h@06h@8000<?0>40AN400kkQh@19h@@?Yn42_]CQ000Eh@802N400`3Q3`17h@03_^7Q04gQ0PnWh@Bn

d>4001GQ00<0hN402>400`3Q3`17h@03_^7Q04oQ0PnYh@>ncN4001GQ0`08h@030>4?04OQ00>nhN40

DN423j[Q0[k;h@008>400`3Q3`17h@03_^7Q05?Q0PnZh@>nb>40023Q00<0h@l0An400kkQh@1Eh@8?

Zn43_/GQ000Ph@0300oQ04KQ00>nhN40F>433j_Q1;j>h@T?:^40023Q00<03n40A^400kkQh@1Kh@8?

[N43_WkQ3@lch@008>400`0?h@16h@03_^7Q05gQ0Pn^h@:nM>483d3Q000Ph@0300oQ04KQ00>nhN40

Gn423jkQ0kiZh@L?B>40023Q00<03n40A^400kkQh@1Qh@@?[N44_V3Q1Pm?h@008>400`0?h@16h@03

_^7Q06GQ0Pn_h@>nEn463eGQ000Ph@0300oQ04KQ00>nhN40In423k3Q1;i>h@D?Fn40023Q00<03n40

A^400kkQh@1Yh@8?/^44_TKQ10mPh@008>400`oQh@15h@03_^7Q06cQ0`nch@Bn?^443fCQ000Ph@03

3n7Q04GQ00>nhN40Kn423kGQ1;hfh@@?J>40023Q00<?hN40AN400kkQh@1ah@8?]n43_RoQ10m/h@00

8>400`oQh@15h@03_^7Q07?Q10nfh@Bn:>433g3Q000Ph@033n7Q04GQ00>nhN40Mn423kSQ1;hPh@@?

Ln40023Q00<?hN40AN400kkQh@1ih@8?^^44_Q[Q0Pmgh@008>400`oQh@15h@03_^7Q07_Q10njh@>n

4n443gWQ000Ph@033n7Q04GQ00>nhN40On400`oQh@2jh@Bn3N423ggQ000Ph@033n7Q04GQ00>nhN40

P>423kkQ1;h6h@<?On4001oQ0Pm7h@03_^7Q08;Q10nnh@Bn0Pn2h@007n400`l00016h@03_^7Q08KQ

0Pnlh@@?1;j0h@007n400`l0h@16h@03_^7Q08SQ0Pnhh@8?2>43_WgQ000Oh@033`3Q04KQ00>nhN40

R^443k;Q0Pl=h@BnNN4001oQ00<?0>40A^400kkQh@2>h@8?[>443a?Q1;ieh@007n400`l0h@16h@03

_^7Q093Q00<?hN40Yn423a_Q1;iah@007n400`l0h@16h@03_^7Q097Q10nTh@033n7Q01oQ0ki^h@00

7n400`l0h@16h@03_^7Q09GQ0PnNh@@?9N44_V[Q000Oh@033`3Q04KQ00>nhN40Un423i[Q0Pl]h@Rn

H^4001oQ00<?0>40A^400kkQh@2Ih@@?U>423cOQ1;iNh@007n400`l0h@16h@03_^7Q09gQ0Pn>h@@?

?N43_U_Q000Oh@033`3Q04KQ00>nhN40Wn443hSQ0Pm4h@BnEn4001oQ00<?0>40A^400kkQh@2Sh@03

3n7Q08?Q0Pm:h@RnCn4001oQ00<?0>40A^400kkQh@2Th@8?P^400`oQh@1Bh@BnBn4001oQ00<?0000

A^400kkQh@2Vh@@?N^443eWQ0ki8h@007n400`l0h@15h@03_^7Q0:_Q0Pmfh@8?H>44_TCQ000Nh@03

3n4004KQ00>nhN40[N443g3Q0PmVh@Rn?>4001kQ00<?h@00A^400kkQh@2ah@8?K>423g3Q0khih@00

7^400`oQ0016h@03_^7Q0;?Q0`mUh@@?MN44_SGQ000Nh@033n4004KQ00>nhN40]^423f7Q0Pmmh@Rn

;N4001kQ00<?h@00A^400kkQh@2hh@8?GN423hOQ0khZh@007^400`oQ0016h@03_^7Q0;[Q10mHh@03

3n7Q0;CQ000Nh@033n4004KQ00>nhN40_^423e;Q10ngh@007^400`oQ0016h@03_^7Q0<3Q10m<h@8?

^n4001kQ00<?h@00AN400`2n000200;Q0`12h@D000?Q0000A>4500;Q00<0hN409^423a[Q0`03h@03

0>7Q02GQ0PlLh@<00^4304CQ0`03h@<0C>4001kQ00<?h@00A^400kh0h@04h@030>7Q04?Q00L0hN7Q

0>4004GQ00L0hN7Q0>4002WQ00<?hN405n400`3Qh@02h@030>4002CQ0PlNh@030>7Q00;Q00<0hN40

A>400`3Qh@04h@030>7Q04_Q000Nh@043n4004GQ00>n0>400^4404CQ00L0hN7Q0>4004GQ00L0hN7Q

0>4002[Q10lFh@070>7Qh@3Q000Ph@@?8N400`3Qh@02h@030>7Q04CQ00@0hN7Q101<h@007^400`oQ

0016h@03_P3Q00;Q00<0h@00AN40103QhN4204KQ00<0hN400^400`3Qh@0]h@8?5>401`3QhN40h@00

7^423bGQ00<0hN400^400`3Qh@14h@070>7Qh@3Q001=h@007^400`oQ0016h@03_P3Q00?Q0P15h@05

0>7Qh@00An401`3QhN40h@00<>443`oQ00<0h@000^400`3Q000Mh@033n7Q02CQ00<0h@000^400`3Q

0014h@030>4000?Q0P1=h@007^400`oQ0016h@03_P3Q00CQ00<0hN40@^4200CQ0P14h@801>400`3Q

h@0ch@8?3^400`3Qh@02h@030>7Q01SQ10lXh@030>7Q00;Q00<0hN40A>400`3Qh@03h@030>7Q04_Q

000Nh@033n4004KQ00>nhN40dn443bSQ0Po<h@007^400`oQ0016h@03_^7Q0=OQ0PlTh@8?c^4001kQ

00<?h@00A^400kkQh@3Ih@033n7Q01gQ10o@h@007^400`oQ0016h@03_^7Q0=[Q10lIh@8?e>4001kQ

00<?h@00A^400kkQh@3Nh@8?5N423mKQ000Nh@033n4004KQ00>nhN40h>423a3Q0`oHh@007^400`oQ

0016h@03_^7Q0>;Q0`l;h@8?c>4400_Q000Nh@033n4004KQ00>nhN40iN423`OQ0Po>h@<03>4001;Q

30000`l000160003_P000>L01`o1017Q00<0hN402^4001kQ00<?h@004N400`3Qh@0@h@030>7Q013Q

00<0hN403>401KkQhN4001;Q00<0hN404>400`3Qh@0@h@030>7Q013Q00<0hN404>400`3Qh@0@h@03

0>7Q013Q00<0hN404>400`3Qh@0@h@030>7Q013Q00<0hN403n400`3Qh@0@h@040>7Qh@8?00?Q3`l0

2^400`3Qh@0@h@030>7Q013Q00<0hN404>400`3Qh@0@h@030>7Q013Q00<0hN404>400`3Qh@0@h@03

0>7Q013Q00<0hN404>400`3Qh@0Jh@803>4001kQ00<?h@004N400`3Qh@0@h@030>7Q013Q00<0hN40

3>401KkQhN4001;Q00<0hN404>400`3Qh@0@h@030>7Q013Q00<0hN404>400`3Qh@0@h@030>7Q013Q

00<0hN404>400`3Qh@0@h@030>7Q013Q00<0hN403n400`3Qh@0@h@040>4?3`GQ0Pl8h@030>7Q013Q

00<0hN404>400`3Qh@0@h@030>7Q013Q00<0hN404>400`3Qh@0@h@030>7Q013Q00<0hN404>400`3Q

h@0@h@030>7Q02SQ000Nh@033n4004KQ00FnhN7Q001;h@030>7Q04WQ00<0hN40An433`WQ10lmh@03

0>7Q04WQ00<0hN40C^4001kQ00<?h@00A^401KkQhN4004_Q00<0hN40BN400`3Qh@15h@8?00?Q0>40

3N423c_Q00<0hN40BN400`3Qh@1>h@007^400`oQ0016h@03_^7Q0=gQ10lDh@033n7Q0=GQ000Nh@03

3n4004KQ00>nhN40fn423aWQ10oCh@007^400`oQ0016h@03_^7Q0=WQ0PlOh@8?dN4001kQ00<?h@00

A^400kkQh@3Fh@<?8n423loQ000Nh@033n4004KQ00>nhN40e>423bSQ10o;h@007^400`oQ0016h@03

_^7Q0=3Q10l^h@8?bN4001kQ00<?h@00A^400kkQh@3>h@8?=>423lOQ000Nh@033n4004KQ00>nhN40

b^443cSQ0`o4h@007^4010oQ0015h@03_^7Q0<SQ0Ploh@8?`^4001kQ00<?h@00A^400kkQh@36h@8?

@n423l3Q000Nh@033n4004KQ00>nhN40`n433dOQ0Pnnh@007^400`oQ0016h@03_^7Q0<7Q0Pm<h@@?

^^4001kQ00<?h@00A^400kkQh@2mh@@?D^423kSQ000Nh@033n4004KQ00>nhN40^n423eSQ0Pnfh@00

7^400`oQ0016h@03_^7Q0;WQ0PmLh@033n7Q08?Q1[hZh@007^400`oQ0016h@03_^7Q0;GQ10mOh@@?

ON44_S3Q000Nh@033n4004KQ00>nhN40]>400`oQh@1Uh@8?Mn44_SCQ000Nh@033n4004KQ00>nhN40

/>443f[Q0Pm^h@Nn>>4001kQ00<?h@00A^400kkQh@2^h@8?L>423fSQ1;hoh@007n400`l0h@15h@03

_^7Q0:[Q10mdh@@?H>44_T?Q000Oh@033`0004KQ00>nhN40Yn423gcQ0PmGh@NnAn4001oQ00<?0>40

A^400kkQh@2Uh@8?P>423e7Q1;i>h@007n400`l0h@16h@03_^7Q0:;Q0`n4h@033n7Q04[Q1;iBh@00

7n400`l0h@16h@03_^7Q0:3Q0Pn8h@@?A>44_UKQ000Oh@033`3Q04KQ00>nhN40W>443hkQ0Plnh@Bn

F^4001oQ00<?0>40A^400kkQh@2Jh@8?U>423cGQ1kiNh@007n400`l0h@16h@03_^7Q09SQ0PnHh@@?

;N44_VGQ000Oh@033`3Q04KQ00>nhN40U>443ikQ0PlWh@BnJN4001oQ00<?0>40A^400kkQh@2Bh@8?

Y>423b7Q1;i]h@007n400`l0h@16h@03_^7Q093Q0PnXh@<?6n43_W7Q000Oh@033`3Q04KQ00>nhN40

SN433jgQ0PlEh@BnM>4001oQ00<?0>40A^400kkQh@2;h@8?/^423`oQ1;ihh@007n400`l00016h@03

_^7Q08OQ10nfh@@?1>47_WcQ000Oh@033`3Q04KQ00>nhN40QN423kkQ0Pl2_X?Q000Ph@033n7Q04GQ

00>nhN40Pn423kcQ1;h2h@@?PN40023Q00<?hN40AN400kkQh@1oh@@?^^44_P[Q00<?hN40O^40023Q

00<?hN40AN400kkQh@1nh@033n7Q0;SQ1;h?h@@?O>40023Q00<?hN40AN400kkQh@1lh@8?^>43_QOQ

0Pmjh@008>400`oQh@15h@03_^7Q07[Q0Pnfh@Bn7>443gKQ000Ph@033n7Q04GQ00>nhN40M^443kCQ

1;hTh@@?L^40023Q00<?hN40AN400kkQh@1dh@8?]N43_RcQ0Pm`h@008>400`oQh@15h@03_^7Q07;Q

0Pneh@:n<N433fgQ000Ph@033n7Q04GQ00>nhN40K^443kGQ0[hfh@@?JN40023Q00<03n40AN400kkQ

h@1]h@033n7Q0;?Q1;hlh@H?Hn40023Q00<03n40A^400kkQh@1Zh@8?/^44_TKQ10mOh@008>400`0?

h@16h@03_^7Q06SQ0Pn`h@BnC^453e[Q000Ph@0300oQ04KQ00>nhN40I>443jkQ1;iGh@@?E^40023Q

00<03n40A^400kkQh@1Rh@8?[n43_UoQ20m>h@008>400`0?h@16h@03_^7Q063Q0Pn]h@BnJ^473dOQ

000Ph@0300oQ04KQ00>nhN40G^423jcQ0kieh@X??N40023Q00<03n40A^400kkQh@1Jh@@?[>42_X;Q

3`l^h@008>400`3Q3`16h@03_^7Q05WQ00<?hN40Zn43_Y?Q10lZh@008>400`3Q3`17h@03_^7Q05KQ

0PnZh@Bna>40023Q00<0h@l0An400kkQh@1Dh@8?ZN43_/SQ000Ph@030>4?04OQ00>nhN40D^423jSQ

0kk;h@005^400`3Qh@07h@030>4?04OQ00>nhN40C^443jSQ0[k>h@005N400`3Q0008h@030>4?04OQ

00>nhN40C>423jWQ0kk@h@005n400`3Qh@06h@8000<?0>40AN400kkQh@1:h@8?Yn44_]?Q000Eh@80

2N40103Qh@m6h@03_^7Q04SQ0PnWh@:nen4001GQ00<0hN402>40103Qh@m6h@03_^7Q04OQ00<?hN40

YN42_]WQ000Eh@<02>40103Qh@m6h@03_^7Q04GQ0PnUh@>nfn40023Q00@0hN4?A^400kkQh@11h@@?

Xn44_]kQ000Ph@040>7Q3dKQ00>nhN40?n423jCQ0kkRh@008>40103Qh@m7h@03_^7Q03cQ0PnTh@:n

iN40023Q00D0hN7Q3`16h@03_^7Q03[Q0PnSh@>nin40023Q00D0hN7Q3`16h@03_^7Q03SQ0PnRh@>n

j^40023Q00D0hN7Q3`16h@03_^7Q03KQ0PnRh@:nkN40023Q00D0hN7Q3`16h@03_^7Q03GQ00<?hN40

Wn43_^oQ000Ph@050>7Qh@l0A^400kkQh@0ch@8?Wn43__;Q000Ph@800n400`oQh@13h@03_^7Q037Q

0PnPh@03_^7Q0??Q000Ph@030>7Q00;Q00<?hN40@n400kkQh@0_h@8?Wn43__KQ000Ph@030>7Q00;Q

00<?hN40A>400kkQh@0Zh@@?W^43__WQ000Ph@030>7Q00;Q00<?hN40A>400kkQh@0Xh@8?X>42__cQ

000Ph@030>7Q00?Q00<?hN40@n400kkQh@0Vh@8?Wn43__kQ000Ph@030>7Q00?Q00<?hN40@n400kkQ

h@0Th@8?X>400kkQh@3oh@008>400`3Qh@03h@033n7Q04?Q00>nhN408^423ioQ0kkoh@?Q000Ph@03

0>7Q00?Q00<?hN40A>400kkQh@0Ph@033n7Q09gQ0[koh@KQ000Ph@030>7Q00?Q00<?hN40A>400kkQ

h@0Nh@8?WN43__oQ2>40023Q00<0hN401>400`oQh@13h@03_^7Q01cQ0PnNh@03_^7Q0?oQ2N40023Q

00<0hN401>400`oQh@13h@03_^7Q01[Q0PnMh@>non4<h@008>400`3Qh@04h@033n7Q04?Q00>nhN40

6>423igQ0[koh@oQ000Ph@030>7Q00CQ00<?hN40@n400kkQh@0Fh@8?W>43__oQ4N40023Q0P05h@03

3n7Q04?Q00>nhN405>423icQ0[kohACQ000Ph@030>7Q00GQ00<?hN40@n400kkQh@0Ah@8?Vn43__oQ

5^40023Q00<0hN401N400`oQh@13h@03_^7Q00oQ0PnLh@03_^7Q0?oQ5n40023Q00<0hN401N400`oQ

h@13h@03_^7Q00kQ00<?hN40V^42__oQ6^40023Q00<0hN401^400`oQh@12h@03_^7Q00cQ0PnJh@>n

on4Lh@008>400`3Qh@06h@033n7Q04;Q00>nhN402^423i_Q00>nhN40on4Mh@008>400`3Qh@06h@03

3n7Q04;Q00>nhN402>423i[Q0kkohB3Q000Ph@030>7Q00OQ00<?hN40@^400kkQh@05h@8?V^42__oQ

8n40023Q00<0hN401n400`oQh@12h@03_^7Q00?Q0PnKh@03_^7Q0?oQ8n40023Q00<0hN402>400`oQ

h@11h@04_^7Qh@8?V^43__oQ9^40023Q00<0hN402>400`oQh@11h@04_^4?3i[Q0[kohBWQ000Ph@03

0>7Q00WQ00<?hN40@>423i_Q00>nhN40on4Yh@008>4200[Q00<?hN40?n400`oQ_P2Hh@>non4/h@00

8>400`3Qh@0:h@033n7Q03cQ0Pl2h@03_^7Q09CQ0[kohBoQ000Ph@030>7Q00[Q00<?hN40>^423`CQ

00>nhN40Tn400kkQh@3ohBoQ000Ph@030>7Q00_Q00<?hN40=n423`KQ00>nhN40TN42__oQ<^40023Q

00<0hN402n400`oQh@0eh@8?2N400kkQh@2=h@>non4dh@008>400`3Qh@0<h@033n7Q03;Q0Pl;h@03

_^7Q08cQ00>nhN40on4eh@008>400`3Qh@0=h@033n7Q02gQ10l=h@03_^7Q08[Q0[kohCSQ000Ph@03

0>7Q00kQ00<?hN40:^423a7Q00>nhN40RN400kkQh@3ohCSQ000Ph@030>7Q00oQ00<?hN409n423aCQ

00>nhN40QN43__oQ>n40023Q00<0hN404>400`oQh@0Uh@033n7Q01CQ00>nhN40Pn42__oQ?^40023Q

00<0hN404N400`oQh@0Rh@8?5n400kkQh@22h@03_^7Q0?oQ?^40023Q00<0hN404^400`oQh@0Mh@@?

6^400kkQh@1oh@:non51h@008>4201CQ00<?hN406^423akQ00>nhN40O^400kkQh@3ohD7Q000Ph@03

0>7Q01CQ00<?hN405n423b3Q00>nhN40Nn43__oQA>40023Q00<0hN405N423a?Q10lRh@03_^7Q07WQ

0[kohDOQ000Ph@030>7Q01OQ0`l;h@D?9n400kkQh@1gh@03_^7Q0?oQAn40023Q00<0hN406^4;3bcQ

00>nhN40MN42__oQB^40023Q00<0hN40DN400kkQh@1ch@:non5<h@008>400`3Qh@1Ah@03_^7Q073Q

0kkohDkQ000Ph@030>7Q05;Q00>nhN40K^400kkQh@3ohDoQ000Ph@030>7Q05;Q00>nhN40K>42__oQ

D^40023Q00<0hN40Dn400kkQh@1Zh@03_^7Q0?oQD^40023Q00<0hN40Dn400kkQh@1Xh@:non5Eh@00

3n4500;Q00<0hN401n400`3Qh@1Ch@03_^7Q06OQ00>nhN40on5Eh@004N401`3QhN40h@002>400`3Q

h@1Dh@03_^7Q06?Q0kkohESQ000Ah@070>7Qh@3Q0008h@@0Dn400kkQh@1Qh@:non5Kh@004N401`3Q

hN40h@002>400`3Qh@1Eh@03_^7Q05oQ00>nhN40on5Kh@004N401`3QhN40h@002>400`3Qh@1Eh@03

_^7Q05gQ0[kohEkQ000@h@801>400`3Qh@07h@030>7Q05KQ00>nhN40Fn400kkQh@3ohEkQ000Ph@03

0>7Q05KQ00>nhN40FN42__oQHN40023Q00<0hN40E^400kkQh@1Hh@03_^7Q0?oQHN40023Q00<0hN40

En400kkQh@1Dh@>non5Th@008>400`3Qh@1Gh@03_^7Q05;Q0[kohFOQ000Ph@030>7Q05SQ00>nhN40

D>400kkQh@3ohFOQ000Ph@030>7Q05WQ00>nhN40CN42__oQJ^40023Q00<0hN40FN400kkQh@1<h@03

_^7Q0?oQJ^40023Q00<0hN40F^400kkQh@18h@>non5]h@008>4205_Q00>nhN40A^42__oQL>40023Q

00<0hN40Fn400kkQh@14h@03_^7Q0?oQL>40023Q00<0hN40G>400kkQh@11h@:non5ch@008>400`3Q

h@1Lh@03_^7Q043Q00>nhN40on5ch@008>400`3Qh@1Mh@03_^7Q03cQ0kkohGKQ000Ph@030>7Q05kQ

00>nhN40>N42__oQNN40023Q00<0hN40Gn400kkQh@0gh@03_^7Q0?oQNN40023Q00<0hN40H>400kkQ

h@0ch@>non5lh@008>400`3Qh@1Qh@03_^7Q033Q0[kohGoQ000Ph@030>7Q06;Q00>nhN40;N42__oQ

PN40023Q00<0hN40Hn400kkQh@0Yh@>non63h@008>400`3Qh@1Th@03_^7Q02GQ0kkohHKQ000Ph@80

I^400kkQh@0Sh@03_^7Q0?oQQn40023Q00<0hN40I^42_R3Q0kkohH[Q000Ph@030>7Q06SQ0khJh@>n

on6=h@008>400`3Qh@1[h@03_^7Q01CQ0kkohI3Q000Ph@030>7Q06cQ1Kh;h@Jnon6Ch@008>400`3Q

h@1ah@^non6Ih@008>400`3Qh@3ohOoQ5^40023Q00<0hN40on7ohAKQ000Ph@030>7Q0?oQon4Fh@00

8>400`3Qh@3ohOoQ5^40023Q00<0hN40on7ohAKQ000Ph@030>7Q0?oQon4Fh@008>400`3Qh@3ohOoQ

5^40023Q00<0hN40on7ohAKQ003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQon4ih@00

on7ohCWQ003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQon4ih@00on4<h@8000CQ003Q

10001>400003h@030>7Q0?oQ6N400?oQ3N400`3Q0007h@030>7Q00;Q00<0h@00on4Jh@00on4=h@<0

0^4400;Q00L0hN7Q0>400?oQ6^400?oQ3N40103Q0007h@030>7Q00;Q00<0hN40on4Ih@007^420>cQ

00<0hN401n400`3Q0002h@030>400?oQ6^4001oQ00<0hN40jN4200[Q00<0hN400^400`3Qh@3ohAWQ

000Mh@<00^400`3Qh@3ohOoQ5>4001cQ00P0hN40h@3Q0?oQon4Eh@007>40203Qh@3Q0>40on7ohAGQ

000Mh@<000CQ0>40on7ohAGQ000Qh@030>400?oQon4Eh@008^400`3Qh@3ohOoQ5>400?oQon4ih@00

on7ohCWQ003ohOoQ>N400?oQon4ih@00on7ohCWQ0000\

\>"],

  ImageRangeCache->{{{0, 566}, {349.313, 0}} -> {11.1534, -12.9793, 0.0264183,

   0.0810305}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-0.986672 0.0785145 0.309017 0.0232808 [

[.26956 .29652 -6 -9 ]

[.26956 .29652 6 0 ]

[.42659 .29652 -6 -9 ]

[.42659 .29652 6 0 ]

[.58362 .29652 -6 -9 ]

[.58362 .29652 6 0 ]

[.74065 .29652 -6 -9 ]

[.74065 .29652 6 0 ]

[.89768 .29652 -6 -9 ]

[.89768 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.10003 .07621 -18 -4.5 ]

[.10003 .07621 0 4.5 ]

[.10003 .19261 -12 -4.5 ]

[.10003 .19261 0 4.5 ]

[.10003 .42542 -6 -4.5 ]

[.10003 .42542 0 4.5 ]

[.10003 .54182 -12 -4.5 ]

[.10003 .54182 0 4.5 ]

[.11253 .64303 -7 0 ]

[.11253 .64303 7 16 ]

[.5 .63053 -12 0 ]

[.5 .63053 12 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.26956 .30902 m

.26956 .31527 L

s

[(16)] .26956 .29652 0 1 Mshowa

.42659 .30902 m

.42659 .31527 L

s

[(18)] .42659 .29652 0 1 Mshowa

.58362 .30902 m

.58362 .31527 L

s

[(20)] .58362 .29652 0 1 Mshowa

.74065 .30902 m

.74065 .31527 L

s

[(22)] .74065 .29652 0 1 Mshowa

.89768 .30902 m

.89768 .31527 L

s

[(24)] .89768 .29652 0 1 Mshowa

.125 Mabswid

.15179 .30902 m

.15179 .31277 L

s

.19105 .30902 m

.19105 .31277 L

s

.2303 .30902 m

.2303 .31277 L

s

.30882 .30902 m

.30882 .31277 L

s

.34807 .30902 m

.34807 .31277 L

s

.38733 .30902 m

.38733 .31277 L

s

.46585 .30902 m

.46585 .31277 L

s

.5051 .30902 m

.5051 .31277 L

s

.54436 .30902 m

.54436 .31277 L

s

.62288 .30902 m

.62288 .31277 L

s

.66213 .30902 m

.66213 .31277 L

s

.70139 .30902 m

.70139 .31277 L

s

.7799 .30902 m

.7799 .31277 L

s

.81916 .30902 m

.81916 .31277 L

s

.85842 .30902 m

.85842 .31277 L

s

.07327 .30902 m

.07327 .31277 L

s

.03402 .30902 m

.03402 .31277 L

s

.93693 .30902 m

.93693 .31277 L

s

.97619 .30902 m

.97619 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.11253 .07621 m

.11878 .07621 L

s

[(-10)] .10003 .07621 1 0 Mshowa

.11253 .19261 m

.11878 .19261 L

s

[(-5)] .10003 .19261 1 0 Mshowa

.11253 .42542 m

.11878 .42542 L

s

[(5)] .10003 .42542 1 0 Mshowa

.11253 .54182 m

.11878 .54182 L

s

[(10)] .10003 .54182 1 0 Mshowa

.125 Mabswid

.11253 .09949 m

.11628 .09949 L

s

.11253 .12277 m

.11628 .12277 L

s

.11253 .14605 m

.11628 .14605 L

s

.11253 .16933 m

.11628 .16933 L

s

.11253 .21589 m

.11628 .21589 L

s

.11253 .23917 m

.11628 .23917 L

s

.11253 .26246 m

.11628 .26246 L

s

.11253 .28574 m

.11628 .28574 L

s

.11253 .3323 m

.11628 .3323 L

s

.11253 .35558 m

.11628 .35558 L

s

.11253 .37886 m

.11628 .37886 L

s

.11253 .40214 m

.11628 .40214 L

s

.11253 .4487 m

.11628 .4487 L

s

.11253 .47198 m

.11628 .47198 L

s

.11253 .49526 m

.11628 .49526 L

s

.11253 .51854 m

.11628 .51854 L

s

.11253 .05293 m

.11628 .05293 L

s

.11253 .02965 m

.11628 .02965 L

s

.11253 .00637 m

.11628 .00637 L

s

.11253 .56511 m

.11628 .56511 L

s

.11253 .58839 m

.11628 .58839 L

s

.11253 .61167 m

.11628 .61167 L

s

.25 Mabswid

.11253 0 m

.11253 .61803 L

s

gsave

.11253 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -73 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(k) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(33) show

83.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

1 0 0 r

.5 Mabswid

.57969 .23027 m

.57577 .23493 L

.57184 .23953 L

.56792 .24407 L

.56399 .24851 L

.56006 .25287 L

.55614 .25713 L

.55221 .26129 L

.54829 .26535 L

.54436 .2693 L

.54043 .27316 L

.53651 .27692 L

.53258 .28059 L

.52866 .28417 L

.52473 .28767 L

.52081 .29108 L

.51688 .29441 L

.51295 .29767 L

.50903 .30086 L

.5051 .30399 L

.50118 .30705 L

.49725 .31005 L

.49333 .313 L

.4894 .3159 L

.48547 .31874 L

.48155 .32155 L

.47762 .3243 L

.4737 .32702 L

.46977 .3297 L

.46585 .33235 L

.46192 .33496 L

.45799 .33754 L

.45407 .34009 L

.45014 .34262 L

.44622 .34512 L

.44229 .3476 L

.43837 .35005 L

.43444 .35249 L

.43051 .35491 L

.42659 .35731 L

.42266 .3597 L

.41874 .36208 L

.41481 .36444 L

.41089 .36679 L

.40696 .36913 L

.40303 .37146 L

.39911 .37379 L

.39518 .37611 L

.39126 .37842 L

.38733 .38073 L

Mistroke

.38341 .38304 L

.37948 .38534 L

.37555 .38765 L

.37163 .38995 L

.3677 .39225 L

.36378 .39456 L

.35985 .39687 L

.35593 .39918 L

.352 .40149 L

.34807 .40381 L

.34415 .40613 L

.34022 .40846 L

.3363 .41079 L

.33237 .41314 L

.32845 .41549 L

.32452 .41785 L

.32059 .42021 L

.31667 .42259 L

.31274 .42498 L

.30882 .42738 L

.30489 .42979 L

.30097 .43221 L

.29704 .43464 L

.29311 .43708 L

.28919 .43954 L

.28526 .44201 L

.28134 .44449 L

.27741 .44698 L

.27349 .44949 L

.26956 .45201 L

.26563 .45454 L

.26171 .45709 L

.25778 .45964 L

.25386 .46221 L

.24993 .46479 L

.24601 .46739 L

.24208 .46999 L

.23815 .4726 L

.23423 .47522 L

.2303 .47784 L

.22638 .48047 L

.22245 .48311 L

.21853 .48574 L

.2146 .48838 L

.21067 .49101 L

.20675 .49364 L

.20282 .49626 L

.1989 .49887 L

.19497 .50147 L

.19105 .50404 L

Mistroke

.18712 .5066 L

.18319 .50912 L

.17927 .51162 L

.17534 .51407 L

.17142 .51648 L

.16749 .51884 L

.16357 .52114 L

.15964 .52338 L

.15571 .52554 L

.15179 .52762 L

.14786 .52961 L

.14394 .53149 L

.14001 .53326 L

.13609 .5349 L

.13216 .53641 L

.12823 .53776 L

.12431 .53893 L

.12038 .53993 L

.11646 .54072 L

.11253 .54128 L

.10861 .5416 L

.10468 .54165 L

.10075 .5414 L

.09683 .54083 L

.0929 .5399 L

.08898 .53858 L

.08505 .53683 L

.08113 .5346 L

.0772 .53184 L

.07327 .5285 L

.06935 .5245 L

.06542 .51975 L

.0615 .51416 L

.05757 .50761 L

.05365 .49994 L

.04972 .49095 L

.04579 .48036 L

.04187 .46779 L

.03794 .45261 L

.03402 .4338 L

.02891 .37141 L

.02381 .30902 L

Mfstroke

.57969 .38776 m

.57577 .3831 L

.57184 .3785 L

.56792 .37397 L

.56399 .36952 L

.56006 .36516 L

.55614 .3609 L

.55221 .35675 L

.54829 .35269 L

.54436 .34873 L

.54043 .34487 L

.53651 .34111 L

.53258 .33744 L

.52866 .33386 L

.52473 .33037 L

.52081 .32696 L

.51688 .32362 L

.51295 .32036 L

.50903 .31717 L

.5051 .31405 L

.50118 .31098 L

.49725 .30798 L

.49333 .30503 L

.4894 .30214 L

.48547 .29929 L

.48155 .29649 L

.47762 .29373 L

.4737 .29101 L

.46977 .28833 L

.46585 .28569 L

.46192 .28308 L

.45799 .28049 L

.45407 .27794 L

.45014 .27542 L

.44622 .27292 L

.44229 .27044 L

.43837 .26798 L

.43444 .26554 L

.43051 .26312 L

.42659 .26072 L

.42266 .25833 L

.41874 .25596 L

.41481 .2536 L

.41089 .25124 L

.40696 .2489 L

.40303 .24657 L

.39911 .24424 L

.39518 .24192 L

.39126 .23961 L

.38733 .2373 L

Mistroke

.38341 .23499 L

.37948 .23269 L

.37555 .23039 L

.37163 .22808 L

.3677 .22578 L

.36378 .22347 L

.35985 .22117 L

.35593 .21886 L

.352 .21654 L

.34807 .21423 L

.34415 .2119 L

.34022 .20958 L

.3363 .20724 L

.33237 .2049 L

.32845 .20255 L

.32452 .20019 L

.32059 .19782 L

.31667 .19544 L

.31274 .19305 L

.30882 .19066 L

.30489 .18825 L

.30097 .18583 L

.29704 .1834 L

.29311 .18095 L

.28919 .1785 L

.28526 .17603 L

.28134 .17355 L

.27741 .17105 L

.27349 .16854 L

.26956 .16602 L

.26563 .16349 L

.26171 .16095 L

.25778 .15839 L

.25386 .15582 L

.24993 .15324 L

.24601 .15065 L

.24208 .14805 L

.23815 .14544 L

.23423 .14282 L

.2303 .14019 L

.22638 .13756 L

.22245 .13493 L

.21853 .13229 L

.2146 .12966 L

.21067 .12702 L

.20675 .12439 L

.20282 .12177 L

.1989 .11916 L

.19497 .11657 L

.19105 .11399 L

Mistroke

.18712 .11144 L

.18319 .10891 L

.17927 .10642 L

.17534 .10396 L

.17142 .10155 L

.16749 .09919 L

.16357 .09689 L

.15964 .09465 L

.15571 .09249 L

.15179 .09041 L

.14786 .08842 L

.14394 .08654 L

.14001 .08477 L

.13609 .08313 L

.13216 .08163 L

.12823 .08028 L

.12431 .0791 L

.12038 .07811 L

.11646 .07732 L

.11253 .07675 L

.10861 .07644 L

.10468 .07639 L

.10075 .07663 L

.09683 .07721 L

.0929 .07813 L

.08898 .07945 L

.08505 .0812 L

.08113 .08343 L

.0772 .08619 L

.07327 .08953 L

.06935 .09354 L

.06542 .09828 L

.0615 .10387 L

.05757 .11042 L

.05365 .11809 L

.04972 .12708 L

.04579 .13767 L

.04187 .15025 L

.03794 .16542 L

.03402 .18423 L

.02891 .24662 L

.02381 .30902 L

Mfstroke

0 .4 1 r

.58205 .4328 m

.58048 .43339 L

.57891 .43397 L

.57734 .43455 L

.57577 .43514 L

.5742 .43573 L

.57263 .43632 L

.57106 .43692 L

.56949 .43751 L

.56792 .43811 L

.56634 .43871 L

.56477 .43931 L

.5632 .43991 L

.56163 .44052 L

.56006 .44113 L

.55849 .44174 L

.55692 .44235 L

.55535 .44297 L

.55378 .44358 L

.55221 .4442 L

.55064 .44482 L

.54907 .44545 L

.5475 .44607 L

.54593 .4467 L

.54436 .44733 L

.54279 .44796 L

.54122 .4486 L

.53965 .44924 L

.53808 .44988 L

.53651 .45052 L

.53494 .45116 L

.53337 .45181 L

.5318 .45246 L

.53023 .45311 L

.52866 .45376 L

.52709 .45442 L

.52552 .45508 L

.52395 .45574 L

.52238 .45641 L

.52081 .45707 L

.51924 .45774 L

.51767 .45841 L

.5161 .45909 L

.51453 .45976 L

.51295 .46044 L

.51138 .46112 L

.50981 .46181 L

.50824 .4625 L

.50667 .46319 L

.5051 .46388 L

Mistroke

.50353 .46457 L

.50196 .46527 L

.50039 .46597 L

.49882 .46668 L

.49725 .46738 L

.49568 .46809 L

.49411 .4688 L

.49254 .46952 L

.49097 .47024 L

.4894 .47096 L

.48783 .47168 L

.48626 .47241 L

.48469 .47313 L

.48312 .47387 L

.48155 .4746 L

.47998 .47534 L

.47841 .47608 L

.47684 .47682 L

.47527 .47757 L

.4737 .47832 L

.47213 .47907 L

.47056 .47983 L

.46899 .48059 L

.46742 .48135 L

.46585 .48211 L

.46428 .48288 L

.46271 .48365 L

.46114 .48443 L

.45957 .48521 L

.45799 .48599 L

.45642 .48677 L

.45485 .48756 L

.45328 .48835 L

.45171 .48914 L

.45014 .48994 L

.44857 .49074 L

.447 .49155 L

.44543 .49235 L

.44386 .49316 L

.44229 .49398 L

.44072 .49479 L

.43915 .49562 L

.43758 .49644 L

.43601 .49727 L

.43444 .4981 L

.43287 .49893 L

.4313 .49977 L

.42973 .50061 L

.42816 .50146 L

.42659 .50231 L

Mistroke

.42502 .50316 L

.42345 .50401 L

.42188 .50487 L

.42031 .50574 L

.41874 .5066 L

.41717 .50747 L

.4156 .50835 L

.41403 .50922 L

.41246 .5101 L

.41089 .51099 L

.40932 .51188 L

.40775 .51277 L

.40618 .51366 L

.4046 .51456 L

.40303 .51547 L

.40146 .51637 L

.39989 .51728 L

.39832 .5182 L

.39675 .51911 L

.39518 .52004 L

.39361 .52096 L

.39204 .52189 L

.39047 .52282 L

.3889 .52376 L

.38733 .5247 L

.38576 .52564 L

.38419 .52658 L

.38262 .52754 L

.38105 .52849 L

.37948 .52945 L

.37791 .53041 L

.37634 .53137 L

.37477 .53234 L

.3732 .53331 L

.37163 .53428 L

.37006 .53526 L

.36849 .53624 L

.36692 .53723 L

.36535 .53821 L

.36378 .53921 L

.36221 .5402 L

.36064 .5412 L

.35907 .5422 L

.3575 .5432 L

.35593 .5442 L

.35436 .54521 L

.35279 .54622 L

.35122 .54724 L

.34964 .54825 L

.34807 .54927 L

Mistroke

.3465 .55029 L

.34493 .55131 L

.34336 .55234 L

.34179 .55336 L

.34022 .55439 L

.33865 .55542 L

.33708 .55645 L

.33551 .55748 L

.33394 .55851 L

.33237 .55954 L

.3308 .56058 L

.32923 .56161 L

.32766 .56264 L

.32609 .56367 L

.32452 .56471 L

.32295 .56574 L

.32138 .56677 L

.31981 .5678 L

.31824 .56882 L

.31667 .56985 L

.3151 .57087 L

.31353 .57189 L

.31196 .5729 L

.31039 .57392 L

.30882 .57493 L

.30725 .57593 L

.30568 .57693 L

.30411 .57792 L

.30254 .5789 L

.30097 .57988 L

.2994 .58085 L

.29783 .58181 L

.29625 .58277 L

.29468 .58371 L

.29311 .58465 L

.29154 .58557 L

.28997 .58648 L

.2884 .58738 L

.28683 .58827 L

.28526 .58914 L

.28369 .58999 L

.28212 .59083 L

.28055 .59166 L

.27898 .59246 L

.27741 .59325 L

.27584 .59402 L

.27427 .59476 L

.2727 .59548 L

.27113 .59619 L

.26956 .59686 L

Mistroke

.26799 .59751 L

.26642 .59813 L

.26485 .59873 L

.26328 .5993 L

.26171 .59983 L

.26014 .60033 L

.25857 .6008 L

.257 .60124 L

.25543 .60163 L

.25386 .60199 L

.25229 .60231 L

.25072 .60259 L

.24915 .60283 L

.24758 .60302 L

.24601 .60317 L

.24444 .60327 L

.24286 .60332 L

.24129 .60332 L

.23972 .60326 L

.23815 .60315 L

.23658 .60299 L

.23501 .60276 L

.23344 .60247 L

.23187 .60212 L

.2303 .60171 L

.22873 .60123 L

.22716 .60067 L

.22559 .60005 L

.22402 .59935 L

.22245 .59857 L

.22088 .59771 L

.21931 .59677 L

.21774 .59574 L

.21617 .59463 L

.2146 .59342 L

.21303 .59211 L

.21146 .5907 L

.20989 .58919 L

.20832 .58757 L

.20675 .58584 L

.20518 .58399 L

.20361 .58201 L

.20204 .57991 L

.20047 .57768 L

.1989 .5753 L

.19733 .57278 L

.19576 .5701 L

.19419 .56726 L

.19262 .56425 L

.19105 .56106 L

Mistroke

.18948 .55767 L

.1879 .55409 L

.18633 .55029 L

.18476 .54626 L

.18319 .54198 L

.18162 .53744 L

.18005 .53261 L

.17848 .52748 L

.17691 .52201 L

.17534 .51617 L

.17377 .50993 L

.1722 .50324 L

.17063 .49604 L

.16906 .48827 L

.16749 .47985 L

.16592 .47066 L

.16435 .46056 L

.16278 .44933 L

.16121 .43668 L

.15964 .42211 L

.15807 .40473 L

.1565 .38258 L

.15493 .30902 L

Mfstroke

.58205 .18523 m

.58048 .18465 L

.57891 .18407 L

.57734 .18348 L

.57577 .18289 L

.5742 .1823 L

.57263 .18171 L

.57106 .18112 L

.56949 .18052 L

.56792 .17993 L

.56634 .17933 L

.56477 .17872 L

.5632 .17812 L

.56163 .17751 L

.56006 .17691 L

.55849 .1763 L

.55692 .17568 L

.55535 .17507 L

.55378 .17445 L

.55221 .17383 L

.55064 .17321 L

.54907 .17259 L

.5475 .17196 L

.54593 .17133 L

.54436 .1707 L

.54279 .17007 L

.54122 .16944 L

.53965 .1688 L

.53808 .16816 L

.53651 .16752 L

.53494 .16687 L

.53337 .16622 L

.5318 .16558 L

.53023 .16492 L

.52866 .16427 L

.52709 .16361 L

.52552 .16295 L

.52395 .16229 L

.52238 .16163 L

.52081 .16096 L

.51924 .16029 L

.51767 .15962 L

.5161 .15895 L

.51453 .15827 L

.51295 .15759 L

.51138 .15691 L

.50981 .15622 L

.50824 .15554 L

.50667 .15485 L

.5051 .15415 L

Mistroke

.50353 .15346 L

.50196 .15276 L

.50039 .15206 L

.49882 .15136 L

.49725 .15065 L

.49568 .14994 L

.49411 .14923 L

.49254 .14852 L

.49097 .1478 L

.4894 .14708 L

.48783 .14635 L

.48626 .14563 L

.48469 .1449 L

.48312 .14417 L

.48155 .14343 L

.47998 .1427 L

.47841 .14195 L

.47684 .14121 L

.47527 .14046 L

.4737 .13971 L

.47213 .13896 L

.47056 .13821 L

.46899 .13745 L

.46742 .13668 L

.46585 .13592 L

.46428 .13515 L

.46271 .13438 L

.46114 .13361 L

.45957 .13283 L

.45799 .13205 L

.45642 .13126 L

.45485 .13047 L

.45328 .12968 L

.45171 .12889 L

.45014 .12809 L

.44857 .12729 L

.447 .12649 L

.44543 .12568 L

.44386 .12487 L

.44229 .12406 L

.44072 .12324 L

.43915 .12242 L

.43758 .12159 L

.43601 .12077 L

.43444 .11994 L

.43287 .1191 L

.4313 .11826 L

.42973 .11742 L

.42816 .11658 L

.42659 .11573 L

Mistroke

.42502 .11488 L

.42345 .11402 L

.42188 .11316 L

.42031 .1123 L

.41874 .11143 L

.41717 .11056 L

.4156 .10969 L

.41403 .10881 L

.41246 .10793 L

.41089 .10705 L

.40932 .10616 L

.40775 .10527 L

.40618 .10437 L

.4046 .10347 L

.40303 .10257 L

.40146 .10166 L

.39989 .10075 L

.39832 .09984 L

.39675 .09892 L

.39518 .098 L

.39361 .09707 L

.39204 .09615 L

.39047 .09521 L

.3889 .09428 L

.38733 .09334 L

.38576 .0924 L

.38419 .09145 L

.38262 .0905 L

.38105 .08955 L

.37948 .08859 L

.37791 .08763 L

.37634 .08666 L

.37477 .0857 L

.3732 .08472 L

.37163 .08375 L

.37006 .08277 L

.36849 .08179 L

.36692 .08081 L

.36535 .07982 L

.36378 .07883 L

.36221 .07783 L

.36064 .07684 L

.35907 .07584 L

.3575 .07484 L

.35593 .07383 L

.35436 .07282 L

.35279 .07181 L

.35122 .0708 L

.34964 .06978 L

.34807 .06876 L

Mistroke

.3465 .06774 L

.34493 .06672 L

.34336 .0657 L

.34179 .06467 L

.34022 .06364 L

.33865 .06262 L

.33708 .06159 L

.33551 .06055 L

.33394 .05952 L

.33237 .05849 L

.3308 .05746 L

.32923 .05642 L

.32766 .05539 L

.32609 .05436 L

.32452 .05333 L

.32295 .05229 L

.32138 .05127 L

.31981 .05024 L

.31824 .04921 L

.31667 .04819 L

.3151 .04716 L

.31353 .04614 L

.31196 .04513 L

.31039 .04412 L

.30882 .04311 L

.30725 .04211 L

.30568 .04111 L

.30411 .04012 L

.30254 .03913 L

.30097 .03815 L

.2994 .03718 L

.29783 .03622 L

.29625 .03527 L

.29468 .03432 L

.29311 .03339 L

.29154 .03246 L

.28997 .03155 L

.2884 .03066 L

.28683 .02977 L

.28526 .0289 L

.28369 .02804 L

.28212 .0272 L

.28055 .02638 L

.27898 .02557 L

.27741 .02478 L

.27584 .02402 L

.27427 .02327 L

.2727 .02255 L

.27113 .02185 L

.26956 .02117 L

Mistroke

.26799 .02052 L

.26642 .0199 L

.26485 .0193 L

.26328 .01874 L

.26171 .0182 L

.26014 .0177 L

.25857 .01723 L

.257 .0168 L

.25543 .0164 L

.25386 .01604 L

.25229 .01572 L

.25072 .01544 L

.24915 .0152 L

.24758 .01501 L

.24601 .01486 L

.24444 .01477 L

.24286 .01472 L

.24129 .01472 L

.23972 .01477 L

.23815 .01488 L

.23658 .01505 L

.23501 .01527 L

.23344 .01556 L

.23187 .01591 L

.2303 .01632 L

.22873 .01681 L

.22716 .01736 L

.22559 .01799 L

.22402 .01868 L

.22245 .01946 L

.22088 .02032 L

.21931 .02126 L

.21774 .02229 L

.21617 .02341 L

.2146 .02462 L

.21303 .02592 L

.21146 .02733 L

.20989 .02884 L

.20832 .03046 L

.20675 .0322 L

.20518 .03405 L

.20361 .03602 L

.20204 .03812 L

.20047 .04036 L

.1989 .04273 L

.19733 .04526 L

.19576 .04793 L

.19419 .05077 L

.19262 .05378 L

.19105 .05698 L

Mistroke

.18948 .06036 L

.1879 .06394 L

.18633 .06774 L

.18476 .07178 L

.18319 .07605 L

.18162 .08059 L

.18005 .08542 L

.17848 .09055 L

.17691 .09602 L

.17534 .10186 L

.17377 .1081 L

.1722 .1148 L

.17063 .12199 L

.16906 .12976 L

.16749 .13818 L

.16592 .14737 L

.16435 .15748 L

.16278 .1687 L

.16121 .18136 L

.15964 .19593 L

.15807 .2133 L

.1565 .23545 L

.15493 .30902 L

Mfstroke

1 0 0 r

.58754 .22086 m

.59147 .21616 L

.5954 .2115 L

.59932 .20692 L

.60325 .20244 L

.60717 .1981 L

.6111 .19392 L

.61502 .18992 L

.61895 .18613 L

.62288 .18256 L

.6268 .17921 L

.63073 .17609 L

.63465 .1732 L

.63858 .17052 L

.6425 .16806 L

.64643 .16581 L

.65036 .16374 L

.65428 .16186 L

.65821 .16016 L

.66213 .15861 L

.66606 .15722 L

.66998 .15596 L

.67391 .15483 L

.67784 .15383 L

.68176 .15293 L

.68569 .15214 L

.68961 .15145 L

.69354 .15084 L

.69746 .15032 L

.70139 .14987 L

.70532 .1495 L

.70924 .14919 L

.71317 .14894 L

.71709 .14875 L

.72102 .14861 L

.72494 .14852 L

.72887 .14848 L

.7328 .14847 L

.73672 .14851 L

.74065 .14859 L

.74457 .14869 L

.7485 .14883 L

.75242 .14901 L

.75635 .1492 L

.76028 .14943 L

.7642 .14968 L

.76813 .14995 L

.77205 .15024 L

.77598 .15055 L

.7799 .15088 L

Mistroke

.78383 .15123 L

.78776 .15159 L

.79168 .15197 L

.79561 .15236 L

.79953 .15276 L

.80346 .15318 L

.80738 .15361 L

.81131 .15405 L

.81524 .1545 L

.81916 .15495 L

.82309 .15542 L

.82701 .15589 L

.83094 .15637 L

.83486 .15686 L

.83879 .15735 L

.84272 .15785 L

.84664 .15836 L

.85057 .15887 L

.85449 .15938 L

.85842 .1599 L

.86234 .16042 L

.86627 .16095 L

.8702 .16147 L

.87412 .162 L

.87805 .16254 L

.88197 .16307 L

.8859 .16361 L

.88982 .16415 L

.89375 .16469 L

.89768 .16523 L

.9016 .16577 L

.90553 .16632 L

.90945 .16686 L

.91338 .1674 L

.9173 .16795 L

.92123 .16849 L

.92516 .16904 L

.92908 .16958 L

.93301 .17013 L

.93693 .17067 L

.94086 .17122 L

.94478 .17176 L

.94871 .1723 L

.95264 .17284 L

.95656 .17338 L

.96049 .17392 L

.96441 .17446 L

.96834 .175 L

.97226 .17553 L

.97619 .17607 L

Mistroke

Mfstroke

.58754 .39718 m

.59147 .40187 L

.5954 .40653 L

.59932 .41112 L

.60325 .41559 L

.60717 .41994 L

.6111 .42412 L

.61502 .42811 L

.61895 .4319 L

.62288 .43547 L

.6268 .43882 L

.63073 .44194 L

.63465 .44484 L

.63858 .44751 L

.6425 .44997 L

.64643 .45223 L

.65036 .45429 L

.65428 .45617 L

.65821 .45788 L

.66213 .45942 L

.66606 .46082 L

.66998 .46207 L

.67391 .4632 L

.67784 .46421 L

.68176 .4651 L

.68569 .46589 L

.68961 .46658 L

.69354 .46719 L

.69746 .46771 L

.70139 .46816 L

.70532 .46853 L

.70924 .46884 L

.71317 .46909 L

.71709 .46928 L

.72102 .46942 L

.72494 .46951 L

.72887 .46956 L

.7328 .46956 L

.73672 .46952 L

.74065 .46945 L

.74457 .46934 L

.7485 .4692 L

.75242 .46903 L

.75635 .46883 L

.76028 .46861 L

.7642 .46836 L

.76813 .46809 L

.77205 .4678 L

.77598 .46748 L

.7799 .46715 L

Mistroke

.78383 .46681 L

.78776 .46644 L

.79168 .46607 L

.79561 .46567 L

.79953 .46527 L

.80346 .46485 L

.80738 .46442 L

.81131 .46399 L

.81524 .46354 L

.81916 .46308 L

.82309 .46261 L

.82701 .46214 L

.83094 .46166 L

.83486 .46117 L

.83879 .46068 L

.84272 .46018 L

.84664 .45968 L

.85057 .45917 L

.85449 .45865 L

.85842 .45814 L

.86234 .45761 L

.86627 .45709 L

.8702 .45656 L

.87412 .45603 L

.87805 .4555 L

.88197 .45496 L

.8859 .45442 L

.88982 .45389 L

.89375 .45335 L

.89768 .4528 L

.9016 .45226 L

.90553 .45172 L

.90945 .45117 L

.91338 .45063 L

.9173 .45009 L

.92123 .44954 L

.92516 .449 L

.92908 .44845 L

.93301 .44791 L

.93693 .44736 L

.94086 .44682 L

.94478 .44628 L

.94871 .44573 L

.95264 .44519 L

.95656 .44465 L

.96049 .44411 L

.96441 .44358 L

.96834 .44304 L

.97226 .4425 L

.97619 .44197 L

Mistroke

Mfstroke

0 .4 1 r

.58754 .43079 m

.59147 .42936 L

.5954 .42794 L

.59932 .42654 L

.60325 .42515 L

.60717 .42376 L

.6111 .42239 L

.61502 .42104 L

.61895 .41969 L

.62288 .41835 L

.6268 .41702 L

.63073 .41571 L

.63465 .4144 L

.63858 .4131 L

.6425 .41182 L

.64643 .41054 L

.65036 .40927 L

.65428 .40802 L

.65821 .40677 L

.66213 .40553 L

.66606 .4043 L

.66998 .40307 L

.67391 .40186 L

.67784 .40066 L

.68176 .39946 L

.68569 .39827 L

.68961 .39709 L

.69354 .39592 L

.69746 .39476 L

.70139 .3936 L

.70532 .39245 L

.70924 .39131 L

.71317 .39017 L

.71709 .38905 L

.72102 .38793 L

.72494 .38681 L

.72887 .38571 L

.7328 .38461 L

.73672 .38352 L

.74065 .38243 L

.74457 .38135 L

.7485 .38028 L

.75242 .37921 L

.75635 .37815 L

.76028 .37709 L

.7642 .37604 L

.76813 .375 L

.77205 .37396 L

.77598 .37293 L

.7799 .3719 L

Mistroke

.78383 .37088 L

.78776 .36986 L

.79168 .36885 L

.79561 .36784 L

.79953 .36684 L

.80346 .36584 L

.80738 .36485 L

.81131 .36386 L

.81524 .36288 L

.81916 .3619 L

.82309 .36093 L

.82701 .35996 L

.83094 .35899 L

.83486 .35803 L

.83879 .35707 L

.84272 .35612 L

.84664 .35517 L

.85057 .35422 L

.85449 .35328 L

.85842 .35234 L

.86234 .35141 L

.86627 .35047 L

.8702 .34955 L

.87412 .34862 L

.87805 .3477 L

.88197 .34678 L

.8859 .34586 L

.88982 .34495 L

.89375 .34404 L

.89768 .34313 L

.9016 .34223 L

.90553 .34132 L

.90945 .34042 L

.91338 .33953 L

.9173 .33863 L

.92123 .33774 L

.92516 .33685 L

.92908 .33596 L

.93301 .33508 L

.93693 .33419 L

.94086 .33331 L

.94478 .33243 L

.94871 .33155 L

.95264 .33068 L

.95656 .3298 L

.96049 .32893 L

.96441 .32806 L

.96834 .32719 L

.97226 .32632 L

.97619 .32545 L

Mistroke

Mfstroke

.58754 .18725 m

.59147 .18868 L

.5954 .19009 L

.59932 .1915 L

.60325 .19289 L

.60717 .19427 L

.6111 .19564 L

.61502 .197 L

.61895 .19835 L

.62288 .19968 L

.6268 .20101 L

.63073 .20233 L

.63465 .20363 L

.63858 .20493 L

.6425 .20622 L

.64643 .20749 L

.65036 .20876 L

.65428 .21002 L

.65821 .21127 L

.66213 .21251 L

.66606 .21374 L

.66998 .21496 L

.67391 .21617 L

.67784 .21738 L

.68176 .21857 L

.68569 .21976 L

.68961 .22094 L

.69354 .22211 L

.69746 .22328 L

.70139 .22443 L

.70532 .22558 L

.70924 .22672 L

.71317 .22786 L

.71709 .22899 L

.72102 .23011 L

.72494 .23122 L

.72887 .23233 L

.7328 .23342 L

.73672 .23452 L

.74065 .2356 L

.74457 .23668 L

.7485 .23776 L

.75242 .23882 L

.75635 .23989 L

.76028 .24094 L

.7642 .24199 L

.76813 .24304 L

.77205 .24407 L

.77598 .24511 L

.7799 .24613 L

Mistroke

.78383 .24716 L

.78776 .24817 L

.79168 .24918 L

.79561 .25019 L

.79953 .25119 L

.80346 .25219 L

.80738 .25318 L

.81131 .25417 L

.81524 .25515 L

.81916 .25613 L

.82309 .25711 L

.82701 .25807 L

.83094 .25904 L

.83486 .26 L

.83879 .26096 L

.84272 .26191 L

.84664 .26286 L

.85057 .26381 L

.85449 .26475 L

.85842 .26569 L

.86234 .26663 L

.86627 .26756 L

.8702 .26849 L

.87412 .26941 L

.87805 .27034 L

.88197 .27126 L

.8859 .27217 L

.88982 .27308 L

.89375 .27399 L

.89768 .2749 L

.9016 .27581 L

.90553 .27671 L

.90945 .27761 L

.91338 .27851 L

.9173 .2794 L

.92123 .28029 L

.92516 .28118 L

.92908 .28207 L

.93301 .28296 L

.93693 .28384 L

.94086 .28472 L

.94478 .2856 L

.94871 .28648 L

.95264 .28736 L

.95656 .28823 L

.96049 .2891 L

.96441 .28998 L

.96834 .29085 L

.97226 .29171 L

.97619 .29258 L

Mistroke

Mfstroke

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{567, 350.313},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.776525,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008g0001GPP10`40000100000800002008200000

P800P020P<30`<3L`:K:l00003<006H009T00<`00?l0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV

09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<003o03?o06Ko09Wo0<co

0?oo0000<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I

<c>I<fJI<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0

IYT0I/`0I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bI

I_nIIP3<IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0c

VC<cVFHcVITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<

VIW<VLc<VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`c

c?lcc01Vc3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03o

c3?oc6Koc9Woc<coc?ooc000oc<0ofH0oiT0ol`0ool0o`0coc<cofHcoiTcol`coolco`1Voc=VofIV

oiUVolaVoomVo`2Ioc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<o`3ooc?oofKooiWoolco

ooooo`0000410@820P<30`@410D51@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C

4a@D5?okl:2PY820P?l0003o0?oo0000ool0o`3oooooodOQ00<0hN40on7^h@00An400`3Qh@3ohNkQ

0017h@030>7Q0?oQk^4004OQ0`3ohNkQ0017h@030>7Q0?oQk^4004OQ00<0hN40on7^h@00An400`3Q

h@3ohNkQ0017h@030>7Q0?oQk^4004OQ00<0hN40>n4;__oQZ>4004OQ00<0hN40>>43_P_Q1;kohJCQ

0017h@030>7Q03KQ0[hBh@>non6Qh@00An400`3Qh@0dh@:n5^43__oQWn4004OQ00<0hN40<^42_Q_Q

0kkohIcQ0017h@030>7Q03;Q00>nhN407>43__oQV^4004OQ00<0hN40<>42_R;Q0[kohISQ0017h@03

0>7Q02oQ00>nhN408n42__oQUn4004OQ0`0^h@03_^7Q02KQ0[kohIGQ0017h@030>7Q02kQ00>nhN40

:>42__oQTn4004OQ00<0hN40;N400kkQh@0[h@:non6Ah@00An400`3Qh@0/h@03_^7Q02kQ0[kohHoQ

0017h@030>7Q02_Q00>nhN40<>42__oQS^4004OQ00<0hN40:^400kkQh@0ch@:non6<h@00An400`3Q

h@0Yh@03_^7Q03KQ00>nhN40on69h@00An400`3Qh@0Yh@03_^7Q03KQ0[kohH[Q0017h@030>7Q02WQ

00>nhN40>>42__oQR>4004OQ00<0hN40:>400kkQh@0kh@03_^7Q0?oQQN4004OQ00<0hN409n400kkQ

h@0mh@:non65h@00An400`3Qh@0Wh@03_^7Q03oQ0[kohH?Q0017h@<09^400kkQh@12h@03_^7Q0?oQ

P>4004OQ00<0hN409N400kkQh@14h@:non60h@00An400`3Qh@0Uh@03_^7Q04KQ00>nhN40on5mh@00

An400`3Qh@0Uh@03_^7Q04OQ00>nhN40on5lh@00An400`3Qh@0Th@03_^7Q04WQ0[kohGcQ0017h@03

0>7Q02CQ00>nhN40Bn42__oQN^4004OQ00<0hN408n400kkQh@1>h@03_^7Q0?oQMn4004OQ00<0hN40

8n400kkQh@1?h@:non5gh@00An400`3Qh@0Rh@03_^7Q05;Q0[kohGGQ0017h@030>7Q02;Q00>nhN40

Dn42__oQM>4003KQ1@02h@030>7Q00OQ00<0hN408^400kkQh@1Eh@:non5bh@00>>401`3QhN40h@00

2>400`3Qh@0Qh@03_^7Q05SQ00>nhN40on5_h@00<^4300?Q00L0hN7Q0>4000/?00<0hN407^400kkQ

h@1Ih@03_^7Q0?oQK^4003SQ00<0h@l010l8h@030>7Q00@?7>400kkQh@1Kh@:non5^h@00>>423`;Q

00<0h@002>400`3Qh@04h@@?6>400kkQh@1Mh@:non5/h@00=^423`030>7Q00;Q00<0hN401n400`3Q

h@08h@8?5^400kkQh@1Nh@:non5[h@00=N400`oQh@0?h@030>7Q00[Q0PlDh@03_^7Q063Q0[kohFWQ

000dh@033n7Q013Q00<0hN403>423a;Q00>nhN40H^400kkQh@3ohFKQ000ch@033n7Q017Q00<0hN40

3^423`oQ00>nhN40I>42__oQI^4003;Q00<?hN404^400`3Qh@0@h@8?3N400kkQh@1Vh@:non5Th@00

<N400`oQh@0Ch@030>7Q01;Q0Pl;h@03_^7Q06OQ0[kohF?Q000`h@033n7Q01CQ00<0hN405>423`SQ

00>nhN40J^42__oQHN4002oQ00<?hN405N400`3Qh@0Fh@8?1^400kkQh@1/h@:non5Oh@00;^400`oQ

h@0Fh@030>7Q01SQ00<?hN400n400kkQh@1]h@>non5Mh@00;N400`oQh@0Gh@<06N401@oQhN6n07?Q

0[kohE_Q000]h@033n7Q01OQ00<0hN406^423`03hKkQ07?Q0[kohE[Q000/h@033n7Q01SQ00<0hN40

7>400`nnh@1eh@:non5Hh@00:n400`oQh@0Ih@030>7Q01cQ00Bnh@l?M^42__oQE^4002_Q00<?hN40

6N400`3Qh@0Lh@05_^7Qh@l0M^42__oQEN4002[Q00<?hN406^400`3Qh@0Lh@03_^7Q00;Q00<?hN40

MN43__oQD^4002WQ00<?hN406n400`3Qh@0Lh@03_^7Q00?Q0Pmgh@:non5Ah@00:N400`oQh@0Kh@03

0>7Q01cQ00>nhN401N423gOQ0[kohDoQ000Xh@033n7Q01cQ00<0hN407>400kkQh@07h@033n7Q07KQ

00>nhN40on5<h@00:>400`oQh@0Lh@030>7Q01cQ00>nhN402>400`oQh@1fh@>non5;h@00:>400`oQ

h@0Lh@030>7Q01_Q00>nhN402^423gWQ0[kohDWQ000Wh@033n7Q01gQ00<0hN406n400kkQh@0<h@8?

N>42__oQB>4002OQ00<?hN407N4301_Q00>nhN403^423gSQ0kkohDGQ000Vh@033n7Q01kQ00<0hN40

6^400kkQh@0Ah@033n7Q07OQ0[kohDCQ000Vh@033n7Q01kQ00<0hN406^400kkQh@0Bh@8?NN42__oQ

@^4002KQ00<?hN407^400`3Qh@0Jh@03_^7Q01CQ0Pmih@:non50h@009N400`oQh@0Oh@030>7Q01[Q

00>nhN405^400`oQh@1hh@:non4nh@009N400`oQh@0Oh@030>7Q01[Q00>nhN405n400`oQh@1ih@:n

on4lh@009N400`oQh@0Oh@030>7Q01WQ00>nhN406N423g_Q0[kohC[Q000Th@033n7Q023Q00<0hN40

6N400kkQh@0Kh@8?Nn42__oQ>>4002CQ00<?hN408>400`3Qh@0Ih@03_^7Q01gQ00<?hN40N^42__oQ

=^4002CQ00<?hN408>400`3Qh@0Ih@03_^7Q01kQ00<?hN40Nn43__oQ<n4002?Q00<?hN408N400`3Q

h@0Ih@03_^7Q01oQ0Pmmh@:non4bh@008n400`oQh@0Qh@030>7Q01SQ00>nhN408^400`oQh@1lh@>n

on4_h@008n400`oQh@0Qh@<06>400kkQh@0Sh@033n7Q07gQ0kkohBgQ000Rh@033n7Q02;Q00<0hN40

6>400kkQh@0Th@8?P>42_W7Q5@nTh@008^400`oQh@0Rh@030>7Q01SQ00>nhN409^423goQ0kiUh@X?

5N4?3iGQ000Rh@033n7Q02;Q00<0hN406>400kkQh@0Xh@033n7Q07oQ0kiLh@H?;^4:3h_Q000Qh@03

3n7Q02?Q00<0hN406>400kkQh@0Yh@033n7Q083Q0kiFh@@??^483h?Q000Qh@033n7Q02?Q00<0hN40

6>400kkQh@0Zh@8?Pn42_U;Q0Pm:h@X?NN40027Q00<?hN408n400`3Qh@0Hh@03_^7Q02cQ0Pn2h@>n

C>443eKQ1Pmch@008N400`oQh@0Sh@030>7Q01SQ00>nhN40;^400`oQh@22h@:nAn433f3Q20m[h@00

8>400`oQh@0Th@030>7Q01SQ00>nhN40;n400`oQh@23h@>n@^423f_Q2@mRh@008>400`oQh@0Th@03

0>7Q01OQ00>nhN40<N423hKQ0[hnh@8?M^463ecQ000Ph@033n7Q02CQ00<0hN405n400kkQh@0ch@8?

Q^43_SWQ0Pmnh@P?E>40023Q00<?hN409>400`3Qh@0Gh@03_^7Q03GQ00<?hN40Q^42_SGQ0Pn8h@H?

C^40023Q00<?hN409>4301OQ00>nhN40=^400`oQh@27h@>n<N400`oQh@2>h@P?A^4001oQ00<?hN40

9N400`3Qh@0Gh@03_^7Q03OQ0Pn:h@:n;^400`oQh@2Gh@P??^4001oQ00<?hN409N400`3Qh@0Gh@03

_^7Q03WQ0Pn:h@>n:N423j;Q1Plhh@007n400`oQh@0Uh@030>7Q01KQ00>nhN40?>423h[Q0khUh@8?

Z^483c3Q000Oh@033n7Q02GQ00<0hN405^400kkQh@0nh@033n7Q08[Q0[hRh@033n7Q0>;Q000Oh@03

3n7Q02GQ00<0hN405^400kkQh@0oh@033n7Q08_Q1;hMh@033n7Q0>?Q000Nh@033n7Q02KQ00<0hN40

5^400kkQh@10h@8?Sn42_Q[Q00<?hN40i>4001kQ00<?hN409^400`3Qh@0Fh@03_^7Q04;Q0Pn?h@>n

5^400`oQh@3Uh@007^400`oQh@0Vh@030>7Q01KQ00>nhN40A>400`oQh@2>h@>n4n400`oQh@3Vh@00

7^400`oQh@0Vh@030>7Q01KQ00>nhN40AN400`oQh@2Bh@03_^7Q00gQ00<?hN40in4001kQ00<?hN40

7>400`3Qh@07h@030>7Q01GQ00>nhN40An423i?Q0[h<h@033n7Q0>SQ000Nh@033n7Q01_Q00<0h@00

2>400`3Qh@0Eh@03_^7Q04WQ0PnCh@Bn1n400`oQh@3Yh@007^400`oQh@0Fh@<01>400`3Qh@06h@@0

5>400kkQh@1;h@8?UN42_PCQ00<?hN40j^4001kQ00<?hN406n4200WQ00<0hN405N400kkQh@1=h@8?

UN42_P03h@oQ0>cQ000Mh@033n7Q01cQ00<0hN402>400`3Qh@0Eh@03_^7Q04oQ0PnEh@Bnjn4001gQ

00<?hN407>4300SQ00<0hN405N400kkQh@1Ah@033n7Q097Q00<?hN400^42_^WQ000Mh@033n7Q02OQ

00<0hN405N400kkQh@1Bh@8?T>400`oQh@05h@BniN4001gQ00<?hN409n400`3Qh@0Eh@03_^7Q05CQ

0Pn=h@033n7Q00[Q0[kSh@007N400`oQh@0Wh@030>7Q01GQ00>nhN40E^423h[Q00<?hN403N44_]oQ

000Mh@033n7Q02OQ00<0hN405>400kkQh@1Ih@033n7Q08KQ00<?hN404^42_]gQ000Mh@033n7Q02OQ

00<0hN405>400kkQh@1Jh@033n7Q08CQ00<?hN405N44_]WQ000Mh@033n7Q02OQ00<0hN405>400kkQ

h@1Kh@8?Q>400`oQh@0Ih@>ne^4001gQ00<?hN409n400`3Qh@0Dh@03_^7Q05gQ0Pn1h@033n7Q01gQ

1;kBh@007N400`oQh@0Wh@030>7Q01CQ00>nhN40Gn423gkQ00<?hN408^42_]3Q000Lh@033n7Q02SQ

0`0Dh@03_^7Q067Q0Pmkh@033n7Q02GQ1;k<h@007>400`oQh@0Xh@030>7Q01CQ00>nhN40Hn400`oQ

h@1gh@033n7Q02[Q1;k8h@007>400`oQh@0Xh@030>7Q01CQ00>nhN40I>400`oQh@1fh@033n7Q02kQ

0[k6h@007>400`oQh@0Xh@030>7Q01CQ00>nhN40IN423gGQ00<?hN40<N44_/;Q000Lh@033n7Q02SQ

00<0hN405>400kkQh@1Wh@8?Zn42_/3Q000Lh@033n7Q02SQ00<0hN404n400kkQh@1Zh@8?Zn44_[cQ

000Lh@033n7Q02SQ00<0hN404n400kkQh@1/h@8?[N44_[SQ000Lh@033n7Q02SQ00<0hN404n400kkQ

h@1^h@033n7Q0:kQ1;jdh@007>400`oQh@0Xh@030>7Q01?Q00>nhN40Kn400`oQh@1Wh@033n7Q04OQ

0[jbh@007>400`oQh@0Xh@030>7Q01?Q00>nhN40L>423fKQ00<?hN40B^44_ZkQ000Lh@033n7Q02SQ

00<0hN404n400kkQh@1bh@8?Hn400`oQh@1?h@BnZ^4001_Q00<?hN40:N400`3Qh@0Ch@03_^7Q07CQ

0PmPh@033n7Q05CQ1;jVh@006n400`oQh@0Yh@<04n400kkQh@1fh@8?GN400`oQh@1Ih@:nY>4001_Q

00<?hN40:N400`3Qh@0Ch@03_^7Q07SQ00<?hN40FN400`oQh@1Lh@BnX>4001_Q00<?hN40:N400`3Q

h@0Ch@03_^7Q07WQ00<?hN40F>400`oQh@1Ph@FnVn4001_Q00<?hN40:N400`3Qh@0Ch@03_^7Q07[Q

0PmGh@033n7Q06KQ1;jGh@006n400`oQh@0Yh@030>7Q01?Q00>nhN40O>423eCQ00<?hN40Jn44_Y?Q

000Kh@033n7Q02WQ00<0hN404n400kkQh@1nh@8?DN400`oQh@1`h@BnSn4001_Q00<?hN40:N400`3Q

h@0Ch@03_^7Q083Q0Pm>h@033n7Q07GQ1;j;h@006n400`oQh@0Yh@030>7Q01?Q00>nhN40P^400`oQ

h@1:h@033n7Q07[Q1;j7h@006n400`oQh@0Yh@030>7Q01?Q00>nhN40Pn400`oQh@18h@033n7Q07oQ

1;j3h@006n400`oQh@0Yh@030>7Q01?Q00>nhN40Q>423dOQ00<?hN40Q>44_WoQ000Kh@033n7Q02WQ

00<0hN404n400kkQh@26h@8?A>400`oQh@29h@BnNn4001_Q00<?hN40:N400`3Qh@0Ch@03_^7Q08SQ

0Pm2h@033n7Q08gQ1;igh@006^400`oQh@0Zh@<04n400kkQh@2:h@8??n400`oQh@2Bh@BnLn4001[Q

00<?hN40:^400`3Qh@0Ch@03_^7Q08cQ00<?hN40>n400`oQh@2Gh@BnKn4001[Q00<?hN40:^400`3Q

h@0Ch@03_^7Q08gQ0Pljh@033n7Q09cQ1;i[h@006^400`oQh@0Zh@030>7Q01?Q00>nhN40Sn423cOQ

00<?hN40XN44_VOQ000Jh@033n7Q02[Q00<0hN404n400kkQh@2Ah@8?=>400`oQh@2Vh@FnH^4001[Q

00<?hN40:^400`3Qh@0Ch@03_^7Q09?Q00<?hN40;n423jkQ1;iNh@006^400`oQh@0Zh@030>7Q01?Q

00>nhN40U>400`oQh@0]h@033n7Q0;;Q1;iJh@006^400`oQh@0Zh@030>7Q01?Q00>nhN40UN423bcQ

00<?hN40]n44_UKQ000Jh@033n7Q02[Q00<0hN404n400kkQh@2Gh@8?:N400`oQh@2lh@BnD^4001[Q

00<?hN40:^400`3Qh@0Ch@03_^7Q09WQ00<?hN409N400`oQh@31h@JnC>4001[Q00<?hN40:^400`3Q

h@0Ch@03_^7Q03?Q1@000n400019h@D00^400`3Qh@0<h@033n7Q02?Q00<?hN405>4300?Q00<0hN40

B>4300;Q0`1:h@<00n4300SQ1;i8h@006^400`oQh@0Zh@030>7Q01?Q00>nhN40=N401`3QhN40h@00

B^401`3QhN40h@003^423b7Q0PlGh@030>7Q00;Q00<0h@00BN400`3Qh@02h@030>7Q04[Q00<0hN40

1>400`3Qh@0;h@BnA>4001[Q00<?hN40:^4301?Q00>nhN40=N401`3QhN40h@00B^401`3QhN40h@00

4>423akQ00<?hN406>401`3QhN40h@00B^400`3Qh@02h@030>7Q04[Q00@0hN7Q100@h@Bn@>4001[Q

00<?hN40:^400`3Qh@0Ch@03_^7Q03GQ00@0hN7Q0P1;h@030>7Q00;Q00<0hN404N400`oQh@0Jh@03

3n7Q01WQ00L0hN7Q0>4004[Q00<0hN400^400`3Qh@1:h@070>7Qh@3Q000Eh@Bn?>4001[Q00<?hN40

:^400`3Qh@0Ch@03_^7Q03GQ00D0hN7Q001<h@070>7Qh@3Q000Ch@033n7Q01SQ00<?hN406N400`3Q

0002h@030>4004WQ00<0h@000^400`3Q001:h@030>4000?Q0P0Ih@Jn=^4001[Q00<?hN40:^400`3Q

h@0Ch@03_^7Q03CQ0P04h@80BN4200CQ00<0hN404n423aOQ00<?hN406n400`3Qh@02h@030>7Q04WQ

00<0hN400^400`3Qh@1:h@030>7Q00?Q00<0hN407N44_S;Q000Ih@033n7Q02_Q00<0hN404n400kkQ

h@2Sh@8?5>400`oQh@3Yh@:n<>4001WQ00<?hN40:n400`3Qh@0Ch@03_^7Q0:GQ00<?hN404>400`oQ

h@3ohAgQ000Ih@033n7Q02_Q00<0hN404n400kkQh@2Vh@033n7Q00gQ0PoohB3Q000Ih@033n7Q02_Q

00<0hN404n400kkQh@2Wh@8?3>400`oQh@3ohB3Q000Ih@033n7Q02_Q00<0hN404n400kkQh@2Yh@03

3n7Q00SQ00<?hN40on4Qh@006N400`oQh@0[h@030>7Q01?Q00>nhN40Z^400`oQh@06h@033n7Q0?oQ

8^4001WQ00<?hN40:n400`3Qh@0Ch@03_^7Q0:_Q0Pl5h@033n7Q0?oQ3n44013Q000Ih@033n7Q02_Q

00<0hN404n400kkQh@2]h@033n7Q008?on4Bh@<04N4000cQ3@000`l000110003_P000:h00Poo00D0

4N400`3Qh@0?h@006N400`oQh@02h@030>7Q017Q00<0hN404^400`3Qh@0Ah@030>6n017Q00<0hN40

4^400`3Qh@0Ah@030>7Q017Q00<0hN404^400`3Qh@0Ah@030>7Q017Q00<0hN404^400`3Qh@0=h@<?

00?Q0>404n400`3Qh@0Ah@030>7Q017Q00<0hN404^400`3Qh@0Ah@030>7Q017Q00<0hN404^400`3Q

h@0Ah@030>7Q017Q00<0hN404^400`3Qh@0Ah@030>7Q017Q00<0hN406n42017Q000Ih@033n7Q00;Q

00<0hN404N400`3Qh@0Bh@030>7Q017Q00<0hKh04N400`3Qh@0Bh@030>7Q017Q00<0hN404N400`3Q

h@0Bh@030>7Q017Q00<0hN404N400`3Qh@0Bh@030>7Q00_Q0Pl3h@033`3Q01?Q00<0hN404N400`3Q

h@0Ah@030>7Q01;Q00<0hN404N400`3Qh@0Ah@030>7Q01;Q00<0hN404N400`3Qh@0Ah@030>7Q01;Q

00<0hN404N400`3Qh@0Ah@030>7Q02kQ000Ih@033n7Q02_Q00<0hN404n400kkQh@0hh@030>7Q04kQ

00<0hN407n400`oQh@04h@033n7Q02KQ00<0hN40C^400`3Qh@1?h@030>7Q05KQ000Ih@033n7Q02_Q

00<0hN404n400kkQh@0hh@030>7Q04kQ00<0hN407^400`oQh@06h@033n7Q02GQ00<0hN40C^400`3Q

h@1?h@030>7Q05KQ000Ih@033n7Q02_Q00<0hN404n400kkQh@2Xh@8?2^400`oQh@3ohB7Q000Ih@03

3n7Q02_Q00<0hN404n400kkQh@2Wh@033n7Q00_Q0PoohB7Q000Ih@033n7Q02_Q00<0hN404n400kkQ

h@2Vh@033n7Q00kQ00<?hN40on4Nh@006N400`oQh@0[h@030>7Q01?Q00>nhN40Y>423a;Q00<?hN40

on4Mh@006^400`oQh@0Zh@030>7Q01?Q00>nhN40Xn400`oQh@0Ch@033n7Q0>SQ0kh`h@006^400`oQ

h@0Zh@030>7Q01?Q00>nhN40X^400`oQh@0Eh@033n7Q0>?Q1;hch@006^400`oQh@0Zh@030>7Q01?Q

00>nhN40X>423aWQ0PoOh@Bn=n4001[Q00<?hN40:^4301?Q00>nhN40W^423agQ00<?hN40e^46_S_Q

000Jh@033n7Q02[Q00<0hN404n400kkQh@2Mh@033n7Q01kQ00<?hN40dN44_T7Q000Jh@033n7Q02[Q

00<0hN404n400kkQh@2Lh@033n7Q023Q00<?hN40c>44_TGQ000Jh@033n7Q02[Q00<0hN404n400kkQ

h@2Jh@8?9>400`oQh@37h@BnBN4001[Q00<?hN40:^400`3Qh@0Ch@03_^7Q09SQ0PlWh@033n7Q0<;Q

1;i=h@006^400`oQh@0Zh@030>7Q01?Q00>nhN40Un400`oQh@0Xh@033n7Q0;gQ1;iAh@006^400`oQ

h@0Zh@030>7Q01?Q00>nhN40U^400`oQh@0Zh@033n7Q0;SQ1;iEh@006^400`oQh@0Zh@030>7Q01?Q

00>nhN40U>423bkQ00<?hN40/N46_UWQ000Jh@033n7Q02[Q00<0hN404n400kkQh@2Bh@8?<N423jcQ

1KiOh@006^400`oQh@0Zh@030>7Q01?Q00>nhN40TN400`oQh@0ch@033n7Q0:GQ1;iTh@006^400`oQ

h@0Zh@030>7Q01?Q00>nhN40T>400`oQh@0eh@033n7Q0:3Q1;iXh@006^400`oQh@0Zh@030>7Q01?Q

00>nhN40S^423cWQ00<?hN40Vn44_VcQ000Jh@033n7Q02[Q0`0Ch@03_^7Q08_Q0`llh@033n7Q09KQ

1;i`h@006n400`oQh@0Yh@030>7Q01?Q00>nhN40RN423d3Q00<?hN40TN44_WCQ000Kh@033n7Q02WQ

00<0hN404n400kkQh@28h@033n7Q047Q00<?hN40S>44_WSQ000Kh@033n7Q02WQ00<0hN404n400kkQ

h@27h@033n7Q04?Q00<?hN40Qn44_WcQ000Kh@033n7Q02WQ00<0hN404n400kkQh@25h@8?An400`oQ

h@22h@BnP>4001_Q00<?hN40:N400`3Qh@0Ch@03_^7Q08?Q0Pm:h@033n7Q07gQ1;j4h@006n400`oQ

h@0Yh@030>7Q01?Q00>nhN40PN423dgQ00<?hN40N>44_XSQ000Kh@033n7Q02WQ00<0hN404n400kkQ

h@20h@033n7Q04gQ00<?hN40M>44_XcQ000Kh@033n7Q02WQ00<0hN404n400kkQh@1oh@033n7Q04oQ

00<?hN40Kn44_Y3Q000Kh@033n7Q02WQ00<0hN404n400kkQh@1mh@8?Dn400`oQh@1Zh@BnU>4001_Q

00<?hN40:N400`3Qh@0Ch@03_^7Q07_Q0PmFh@033n7Q06OQ0[jHh@006n400`oQh@0Yh@030>7Q01?Q

00>nhN40NN423eWQ00<?hN40HN45_Y[Q000Kh@033n7Q02WQ00<0hN404n400kkQh@1gh@8?G>400`oQ

h@1Lh@BnWn4001_Q00<?hN40:N4301?Q00>nhN40M^400`oQh@1Mh@033n7Q05OQ1;jSh@006n400`oQ

h@0Yh@030>7Q01?Q00>nhN40MN400`oQh@1Nh@033n7Q05?Q1;jWh@007>400`oQh@0Xh@030>7Q01?Q

00>nhN40Ln423f;Q00<?hN40D>42_Z_Q000Lh@033n7Q02SQ00<0hN404n400kkQh@1ah@8?IN400`oQ

h@1;h@Bn[N4001cQ00<?hN40:>400`3Qh@0Ch@03_^7Q06oQ0PmXh@033n7Q04KQ1;jah@007>400`oQ

h@0Xh@030>7Q01?Q00>nhN40KN423joQ1;jeh@007>400`oQh@0Xh@030>7Q01?Q00>nhN40K>400`oQ

h@2]h@:n^N4001cQ00<?hN40:>400`3Qh@0Ch@03_^7Q06_Q00<?hN40Z^44_[_Q000Lh@033n7Q02SQ

00<0hN405>400kkQh@1Xh@8?ZN44_[oQ000Lh@033n7Q02SQ00<0hN405>400kkQh@1Vh@8?M>400`oQ

h@0bh@:n`n4001cQ00<?hN40:>400`3Qh@0Dh@03_^7Q06CQ0Pmgh@033n7Q02gQ1;k5h@007>400`oQ

h@0Xh@030>7Q01CQ00>nhN40H^423g[Q00<?hN40:>44_/WQ000Lh@033n7Q02SQ0`0Dh@03_^7Q063Q

0Pmmh@033n7Q02GQ0[k=h@007N400`oQh@0Wh@030>7Q01CQ00>nhN40Gn400`oQh@1mh@033n7Q027Q

1;k?h@007N400`oQh@0Wh@030>7Q01CQ00>nhN40G^400`oQh@1oh@033n7Q01gQ0kkCh@007N400`oQ

h@0Wh@030>7Q01CQ00>nhN40G>423h?Q00<?hN406>44_]KQ000Mh@033n7Q02OQ00<0hN405>400kkQ

h@1Jh@8?Q^400`oQh@0Eh@:nf^4001gQ00<?hN409n400`3Qh@0Dh@03_^7Q05SQ0Pn9h@033n7Q013Q

1;kLh@007N400`oQh@0Wh@030>7Q01GQ00>nhN40E^400`oQh@29h@033n7Q00kQ0[kPh@007N400`oQ

h@0Wh@030>7Q01GQ00>nhN40EN400`oQh@2;h@033n7Q00WQ1;kRh@007N400`oQh@0Wh@030>7Q01GQ

00>nhN40Dn423hoQ00<?hN401^42_^KQ000Mh@033n7Q02OQ00<0hN405N400kkQh@1@h@<?T^4010oQ

hN44_^SQ000Mh@033n7Q01gQ00<0hN401n400`3Qh@0Eh@03_^7Q04kQ0PnFh@033kjn0>cQ000Nh@03

3n7Q01_Q00<0h@002>400`3Qh@0Eh@03_^7Q04cQ0PnGh@:n00<?hN40jn4001kQ00<?hN407N400`3Q

h@06h@@05>400kkQh@1;h@033n7Q09?Q1;h3h@033n7Q0>[Q000Nh@033n7Q01_Q0P09h@030>7Q01GQ

00>nhN40B^400`oQh@2Bh@:n2>400`oQh@3Yh@007^400`oQh@0Kh@030>7Q00SQ00<0hN405N400kkQ

h@18h@8?TN44_P_Q00<?hN40j>4001kQ00<?hN406n4300SQ00<0hN405^400kkQh@15h@8?Xn400`oQ

h@3Wh@007^400`oQh@0Vh@030>7Q01KQ00>nhN40@n423i3Q0khCh@033n7Q0>KQ000Nh@033n7Q02KQ

00<0hN405^400kkQh@12h@033n7Q08gQ0khGh@033n7Q0>GQ000Nh@033n7Q02KQ00<0hN405^400kkQ

h@11h@033n7Q08cQ0[hKh@033n7Q0>CQ000Oh@033n7Q02GQ00<0hN405^400kkQh@0oh@8?S>43_QkQ

00<?hN40hn4001oQ00<?hN409N400`3Qh@0Fh@03_^7Q03gQ0Pn;h@>n8^423k;Q00<?hN40;^4001oQ

00<?hN409N400`3Qh@0Fh@03_^7Q03cQ00<?hN40RN42_ROQ00<?hN40Yn483c7Q000Oh@033n7Q02GQ

00<0hN405n400kkQh@0jh@033n7Q08OQ0khZh@033n7Q0:3Q1Plih@007n400`oQh@0Uh@030>7Q01OQ

00>nhN40>>423hSQ0[h^h@8?V>483coQ000Ph@033n7Q02CQ0`0Gh@03_^7Q03KQ0Pn7h@>n<^423hkQ

20m7h@008>400`oQh@0Th@030>7Q01OQ00>nhN40=>423hOQ0[hgh@033n7Q08GQ1Pm?h@008>400`oQ

h@0Th@030>7Q01OQ00>nhN40<n400`oQh@24h@>n>^400`oQh@1lh@P?EN40023Q00<?hN409>400`3Q

h@0Gh@03_^7Q03;Q00<?hN40Pn43_SgQ0Pmeh@L?GN40023Q00<?hN409>400`3Qh@0Hh@03_^7Q02oQ

0Pn3h@>n@^433f[Q20mTh@008N400`oQh@0Sh@030>7Q01SQ00>nhN40;N423h?Q0ki7h@@?G^483fcQ

000Qh@033n7Q02?Q00<0hN406>400kkQh@0/h@033n7Q087Q0[i>h@8?E>483gCQ000Qh@033n7Q02?Q

00<0hN406>400kkQh@0[h@033n7Q083Q0kiAh@@?B>483gcQ000Qh@033n7Q02?Q00<0hN406>400kkQ

h@0Yh@8?PN42_USQ10llh@P?Q>4002;Q00<?hN408^400`3Qh@0Hh@03_^7Q02OQ0Pn0h@>nG^463bcQ

2Pn<h@008^400`oQh@0Rh@030>7Q01SQ00>nhN409^400`oQh@1nh@:nIn4<3`gQ4`nFh@008^400`oQ

h@0Rh@030>7Q01SQ00>nhN409N400`oQh@1mh@>nM>4=3jWQ000Sh@033n7Q027Q0`0Hh@03_^7Q02?Q

0Pmnh@:non4^h@008n400`oQh@0Qh@030>7Q01SQ00>nhN408^400`oQh@1lh@:non4`h@008n400`oQ

h@0Qh@030>7Q01WQ00>nhN408>400`oQh@1kh@:non4bh@009>400`oQh@0Ph@030>7Q01WQ00>nhN40

7^423gcQ0[kohCCQ000Th@033n7Q023Q00<0hN406N400kkQh@0Lh@8?Nn43__oQ=^4002CQ00<?hN40

8>400`3Qh@0Ih@03_^7Q01_Q00<?hN40NN43__oQ>>4002GQ00<?hN407n400`3Qh@0Ih@03_^7Q01[Q

00<?hN40N>42__oQ>n4002GQ00<?hN407n400`3Qh@0Jh@03_^7Q01OQ0Pmjh@:non4lh@009N400`oQ

h@0Oh@030>7Q01[Q00>nhN405N423gWQ0kkohCkQ000Vh@033n7Q01kQ00<0hN406^400kkQh@0Dh@03

3n7Q07SQ00>nhN40on4oh@009^400`oQh@0Nh@030>7Q01[Q00>nhN404n400`oQh@1fh@>non52h@00

9^400`oQh@0Nh@030>7Q01_Q00>nhN403n433gSQ00>nhN40on53h@009n400`oQh@0Mh@<06n400kkQ

h@0=h@8?NN42__oQA^4002OQ00<?hN407N400`3Qh@0Kh@03_^7Q00cQ00<?hN40Mn42__oQB>4002SQ

00<?hN407>400`3Qh@0Kh@03_^7Q00_Q00<?hN40M^42__oQB^4002SQ00<?hN407>400`3Qh@0Lh@03

_^7Q00SQ0Pmgh@:non5<h@00:N400`oQh@0Kh@030>7Q01cQ00>nhN401^423gOQ0[kohDkQ000Yh@03

3n7Q01_Q00<0hN407>400kkQh@05h@033n7Q07GQ0[kohE3Q000Zh@033n7Q01[Q00<0hN407>400kkQ

h@04h@033n7Q07GQ00>nhN40on5@h@00:^400`oQh@0Jh@030>7Q01cQ00>nhN400^423gKQ0[kohE?Q

000[h@033n7Q01WQ00<0hN407>400kkQh@023gKQ0[kohEGQ000[h@033n7Q01WQ00<0hN407>400kkQ

3`1fh@>non5Fh@00;>400`oQh@0Hh@030>7Q01gQ00>nhN40Ln42__oQFN4002gQ00<?hN405n400`3Q

h@0Kh@8?00>nhN40L^400kkQh@3ohEWQ000]h@033n7Q01OQ0`0Ih@8?0^400kkQh@1`h@:non5Lh@00

;^400`oQh@0Fh@030>7Q01OQ0Pl5h@03_^7Q06gQ0[kohEkQ000_h@033n7Q01GQ00<0hN405N423`OQ

00>nhN40K>42__oQGn40033Q00<?hN405>400`3Qh@0Dh@033n7Q00OQ00>nhN40J^42__oQHN40037Q

00<?hN404n400`3Qh@0Ch@033n7Q00WQ00>nhN40In42__oQHn4003;Q00<?hN404^400`3Qh@0Ah@8?

3>400kkQh@1Vh@:non5Th@00<n400`oQh@0Ah@030>7Q00oQ0Pl>h@03_^7Q06CQ0[kohFKQ000dh@03

3n7Q013Q00<0hN403N423a7Q00>nhN40H^400kkQh@3ohFKQ000eh@8?4>400`3Qh@09h@@?4n400kkQ

h@1Ph@:non5Yh@00=n423`kQ00<0hN401n423aOQ00>nhN40G^42__oQJn4003KQ0`033`03h@3Q00SQ

00<0hN401N423aWQ00>nhN40GN42__oQK>4003SQ00@0hN7Q0Pl00`3Qh@06h@030>4?00D?6n400kkQ

h@1Kh@:non5^h@00>>401P3QhN40h@/?0P0Ph@03_^7Q05SQ0[kohG3Q000hh@070>7Qh@3Q0008h@03

0>7Q027Q00>nhN40En42__oQLN4003SQ00L0hN7Q0>4000SQ00<0hN408^400kkQh@1Dh@:non5ch@00

=n4200CQ00<0hN401n400`3Qh@0Rh@03_^7Q05?Q00>nhN40on5ch@00An400`3Qh@0Sh@03_^7Q053Q

0[kohGKQ0017h@030>7Q02?Q00>nhN40C^42__oQN>4004OQ00<0hN409>400kkQh@1=h@03_^7Q0?oQ

Mn4004OQ00<0hN409>400kkQh@1;h@:non5jh@00An400`3Qh@0Uh@03_^7Q04SQ0[kohGcQ0017h@03

0>7Q02GQ00>nhN40An400kkQh@3ohGcQ0017h@030>7Q02GQ00>nhN40AN42__oQOn4004OQ00<0hN40

9N400kkQh@13h@:non61h@00An4302KQ00>nhN40@N42__oQP^4004OQ00<0hN409n400kkQh@0oh@03

_^7Q0?oQP^4004OQ00<0hN409n400kkQh@0mh@:non65h@00An400`3Qh@0Xh@03_^7Q03_Q00>nhN40

on65h@00An400`3Qh@0Yh@03_^7Q03SQ0[kohHSQ0017h@030>7Q02WQ00>nhN40=^42__oQR^4004OQ

00<0hN40:N400kkQh@0eh@:non6;h@00An400`3Qh@0Zh@03_^7Q03;Q0[kohHgQ0017h@030>7Q02_Q

00>nhN40<>400kkQh@3ohHgQ0017h@030>7Q02cQ00>nhN40;N42__oQT>4004OQ00<0hN40;N400kkQ

h@0Zh@:non6Bh@00An400`3Qh@0^h@03_^7Q02SQ00>nhN40on6Bh@00An4302kQ00>nhN409^42__oQ

UN4004OQ00<0hN40;n42_RCQ0[kohIOQ0017h@030>7Q037Q00>nhN407n42__oQVN4004OQ00<0hN40

<^400kkQh@0Lh@:non6Kh@00An400`3Qh@0ch@03_^7Q01WQ0[kohIgQ0017h@030>7Q03CQ0khEh@>n

on6Oh@00An400`3Qh@0fh@:n4N44__oQXN4004OQ00<0hN40>>44_PWQ1;kohJGQ0017h@030>7Q03cQ

2KkohJWQ0017h@030>7Q0?oQk^4004OQ00<0hN40on7^h@00An400`3Qh@3ohNkQ0017h@<0on7^h@00

An400`3Qh@3ohNkQ0017h@030>7Q0?oQk^4004OQ00<0hN40on7^h@00An400`3Qh@3ohNkQ003ohOoQ

>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQon4ih@00

on7ohCWQ003ohOoQ>N400?oQon4ih@00on47h@8000CQ003Q10000n400003h@80on4Ph@00on48h@03

0>4000WQ00<0hN400^400`3Qh@3ohAgQ003oh@SQ0`02h@@00^400`3Qh@02h@030>7Q0?oQ7^400?oQ

2>40103Q0008h@030>7Q00;Q00<0hN40on4Mh@00AN420<3Q00<0hN401n400`3Q0002h@030>400?oQ

7n4004KQ00<0hN40_N4200[Q00<0hN400^400`3Qh@3ohAkQ0014h@<00^400`3Qh@3ohNcQ0013h@08

0>7Q0>40h@3ohNgQ0013h@080>7Q0>40h@3ohNgQ0014h@<000CQ0>40on7]h@00B>400`3Q003ohNgQ

0019h@030>7Q0?oQk>400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQon4ih@00on7ohCWQ0000\

\>"],

  ImageRangeCache->{{{0, 566}, {349.313, 0}} -> {12.251, -13.2736, 0.0245716, 

  0.0828679}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-1.78959 0.138427 0.309017 0.0230521 [

[.14839 .29652 -6 -9 ]

[.14839 .29652 6 0 ]

[.28682 .29652 -6 -9 ]

[.28682 .29652 6 0 ]

[.42525 .29652 -6 -9 ]

[.42525 .29652 6 0 ]

[.56368 .29652 -6 -9 ]

[.56368 .29652 6 0 ]

[.7021 .29652 -6 -9 ]

[.7021 .29652 6 0 ]

[.84053 .29652 -6 -9 ]

[.84053 .29652 6 0 ]

[.97896 .29652 -6 -9 ]

[.97896 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[-0.00253 .0785 -18 -4.5 ]

[-0.00253 .0785 0 4.5 ]

[-0.00253 .19376 -12 -4.5 ]

[-0.00253 .19376 0 4.5 ]

[-0.00253 .42428 -6 -4.5 ]

[-0.00253 .42428 0 4.5 ]

[-0.00253 .53954 -12 -4.5 ]

[-0.00253 .53954 0 4.5 ]

[.00997 .64303 -7 0 ]

[.00997 .64303 7 16 ]

[.5 .63053 -12 0 ]

[.5 .63053 12 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.14839 .30902 m

.14839 .31527 L

s

[(14)] .14839 .29652 0 1 Mshowa

.28682 .30902 m

.28682 .31527 L

s

[(15)] .28682 .29652 0 1 Mshowa

.42525 .30902 m

.42525 .31527 L

s

[(16)] .42525 .29652 0 1 Mshowa

.56368 .30902 m

.56368 .31527 L

s

[(17)] .56368 .29652 0 1 Mshowa

.7021 .30902 m

.7021 .31527 L

s

[(18)] .7021 .29652 0 1 Mshowa

.84053 .30902 m

.84053 .31527 L

s

[(19)] .84053 .29652 0 1 Mshowa

.97896 .30902 m

.97896 .31527 L

s

[(20)] .97896 .29652 0 1 Mshowa

.125 Mabswid

.03765 .30902 m

.03765 .31277 L

s

.06534 .30902 m

.06534 .31277 L

s

.09302 .30902 m

.09302 .31277 L

s

.12071 .30902 m

.12071 .31277 L

s

.17608 .30902 m

.17608 .31277 L

s

.20377 .30902 m

.20377 .31277 L

s

.23145 .30902 m

.23145 .31277 L

s

.25914 .30902 m

.25914 .31277 L

s

.31451 .30902 m

.31451 .31277 L

s

.34219 .30902 m

.34219 .31277 L

s

.36988 .30902 m

.36988 .31277 L

s

.39756 .30902 m

.39756 .31277 L

s

.45293 .30902 m

.45293 .31277 L

s

.48062 .30902 m

.48062 .31277 L

s

.50831 .30902 m

.50831 .31277 L

s

.53599 .30902 m

.53599 .31277 L

s

.59136 .30902 m

.59136 .31277 L

s

.61905 .30902 m

.61905 .31277 L

s

.64673 .30902 m

.64673 .31277 L

s

.67442 .30902 m

.67442 .31277 L

s

.72979 .30902 m

.72979 .31277 L

s

.75748 .30902 m

.75748 .31277 L

s

.78516 .30902 m

.78516 .31277 L

s

.81285 .30902 m

.81285 .31277 L

s

.86822 .30902 m

.86822 .31277 L

s

.8959 .30902 m

.8959 .31277 L

s

.92359 .30902 m

.92359 .31277 L

s

.95127 .30902 m

.95127 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.00997 .0785 m

.01622 .0785 L

s

[(-10)] -0.00253 .0785 1 0 Mshowa

.00997 .19376 m

.01622 .19376 L

s

[(-5)] -0.00253 .19376 1 0 Mshowa

.00997 .42428 m

.01622 .42428 L

s

[(5)] -0.00253 .42428 1 0 Mshowa

.00997 .53954 m

.01622 .53954 L

s

[(10)] -0.00253 .53954 1 0 Mshowa

.125 Mabswid

.00997 .10155 m

.01372 .10155 L

s

.00997 .1246 m

.01372 .1246 L

s

.00997 .14765 m

.01372 .14765 L

s

.00997 .1707 m

.01372 .1707 L

s

.00997 .21681 m

.01372 .21681 L

s

.00997 .23986 m

.01372 .23986 L

s

.00997 .26291 m

.01372 .26291 L

s

.00997 .28596 m

.01372 .28596 L

s

.00997 .33207 m

.01372 .33207 L

s

.00997 .35512 m

.01372 .35512 L

s

.00997 .37817 m

.01372 .37817 L

s

.00997 .40123 m

.01372 .40123 L

s

.00997 .44733 m

.01372 .44733 L

s

.00997 .47038 m

.01372 .47038 L

s

.00997 .49343 m

.01372 .49343 L

s

.00997 .51649 m

.01372 .51649 L

s

.00997 .05544 m

.01372 .05544 L

s

.00997 .03239 m

.01372 .03239 L

s

.00997 .00934 m

.01372 .00934 L

s

.00997 .56259 m

.01372 .56259 L

s

.00997 .58564 m

.01372 .58564 L

s

.00997 .60869 m

.01372 .60869 L

s

.25 Mabswid

.00997 0 m

.00997 .61803 L

s

gsave

.00997 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -73 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(k) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(35) show

83.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

1 0 0 r

.5 Mabswid

.97619 .48931 m

.97342 .48833 L

.97065 .48725 L

.96788 .48609 L

.96512 .48483 L

.96235 .48346 L

.95958 .48197 L

.95681 .48035 L

.95404 .4786 L

.95127 .47669 L

.9485 .47462 L

.94574 .47237 L

.94297 .46993 L

.9402 .46728 L

.93743 .46441 L

.93466 .46131 L

.93189 .45798 L

.92913 .4544 L

.92636 .45058 L

.92359 .44653 L

.92082 .44228 L

.91805 .43784 L

.91528 .43327 L

.91251 .42859 L

.90975 .42386 L

.90698 .41912 L

.90421 .41441 L

.90144 .40976 L

.89867 .40519 L

.8959 .40074 L

.89313 .39641 L

.89037 .3922 L

.8876 .38813 L

.88483 .38419 L

.88206 .38039 L

.87929 .37671 L

.87652 .37315 L

.87375 .36972 L

.87099 .36639 L

.86822 .36317 L

.86545 .36006 L

.86268 .35704 L

.85991 .35411 L

.85714 .35126 L

.85437 .3485 L

.85161 .34581 L

.84884 .3432 L

.84607 .34065 L

.8433 .33817 L

.84053 .33574 L

Mistroke

.83776 .33338 L

.83499 .33107 L

.83223 .32881 L

.82946 .3266 L

.82669 .32444 L

.82392 .32232 L

.82115 .32025 L

.81838 .31821 L

.81561 .31621 L

.81285 .31425 L

.81008 .31232 L

.80731 .31043 L

.80454 .30857 L

.80177 .30673 L

.799 .30493 L

.79623 .30315 L

.79347 .30141 L

.7907 .29968 L

.78793 .29798 L

.78516 .2963 L

.78239 .29465 L

.77962 .29301 L

.77685 .2914 L

.77409 .2898 L

.77132 .28823 L

.76855 .28667 L

.76578 .28513 L

.76301 .2836 L

.76024 .28209 L

.75748 .2806 L

.75471 .27912 L

.75194 .27766 L

.74917 .27621 L

.7464 .27477 L

.74363 .27334 L

.74086 .27193 L

.7381 .27053 L

.73533 .26914 L

.73256 .26776 L

.72979 .26639 L

.72702 .26503 L

.72425 .26368 L

.72148 .26234 L

.71872 .26101 L

.71595 .25968 L

.71318 .25837 L

.71041 .25706 L

.70764 .25576 L

.70487 .25447 L

.7021 .25318 L

Mistroke

.69934 .25191 L

.69657 .25063 L

.6938 .24937 L

.69103 .24811 L

.68826 .24685 L

.68549 .2456 L

.68272 .24436 L

.67996 .24312 L

.67719 .24189 L

.67442 .24066 L

.67165 .23943 L

.66888 .23821 L

.66611 .237 L

.66334 .23578 L

.66058 .23457 L

.65781 .23337 L

.65504 .23217 L

.65227 .23097 L

.6495 .22977 L

.64673 .22858 L

.64396 .22739 L

.6412 .2262 L

.63843 .22502 L

.63566 .22383 L

.63289 .22265 L

.63012 .22147 L

.62735 .2203 L

.62458 .21912 L

.62182 .21795 L

.61905 .21678 L

.61628 .21561 L

.61351 .21444 L

.61074 .21327 L

.60797 .21211 L

.6052 .21094 L

.60244 .20978 L

.59967 .20861 L

.5969 .20745 L

.59413 .20629 L

.59136 .20513 L

.58859 .20397 L

.58583 .20281 L

.58306 .20165 L

.58029 .20049 L

.57752 .19933 L

.57475 .19818 L

.57198 .19702 L

.56921 .19586 L

.56645 .1947 L

.56368 .19355 L

Mistroke

.56091 .19239 L

.55814 .19123 L

.55537 .19007 L

.5526 .18892 L

.54983 .18776 L

.54707 .1866 L

.5443 .18544 L

.54153 .18429 L

.53876 .18313 L

.53599 .18197 L

.53322 .18081 L

.53045 .17965 L

.52769 .17849 L

.52492 .17733 L

.52215 .17617 L

.51938 .17501 L

.51661 .17385 L

.51384 .17269 L

.51107 .17153 L

.50831 .17037 L

.50554 .16921 L

.50277 .16805 L

.5 .16689 L

.49723 .16573 L

.49446 .16457 L

.49169 .16341 L

.48893 .16225 L

.48616 .16109 L

.48339 .15992 L

.48062 .15876 L

.47785 .1576 L

.47508 .15644 L

.47231 .15528 L

.46955 .15413 L

.46678 .15297 L

.46401 .15181 L

.46124 .15065 L

.45847 .14949 L

.4557 .14834 L

.45293 .14718 L

.45017 .14603 L

.4474 .14488 L

.44463 .14373 L

.44186 .14258 L

.43909 .14143 L

.43632 .14028 L

.43355 .13914 L

.43079 .13799 L

.42802 .13685 L

.42525 .13571 L

Mistroke

.42248 .13457 L

.41971 .13344 L

.41694 .13231 L

.41417 .13118 L

.41141 .13005 L

.40864 .12892 L

.40587 .1278 L

.4031 .12668 L

.40033 .12557 L

.39756 .12446 L

.3948 .12335 L

.39203 .12224 L

.38926 .12114 L

.38649 .12005 L

.38372 .11896 L

.38095 .11787 L

.37818 .11678 L

.37542 .11571 L

.37265 .11463 L

.36988 .11356 L

.36711 .1125 L

.36434 .11144 L

.36157 .11039 L

.3588 .10935 L

.35604 .10831 L

.35327 .10727 L

.3505 .10624 L

.34773 .10522 L

.34496 .10421 L

.34219 .1032 L

.33942 .10221 L

.33666 .10121 L

.33389 .10023 L

.33112 .09925 L

.32835 .09829 L

.32558 .09733 L

.32281 .09638 L

.32004 .09544 L

.31728 .09451 L

.31451 .09358 L

.31174 .09267 L

.30897 .09177 L

.3062 .09088 L

.30343 .08999 L

.30066 .08912 L

.2979 .08826 L

.29513 .08742 L

.29236 .08658 L

.28959 .08576 L

.28682 .08494 L

Mistroke

.28405 .08415 L

.28128 .08336 L

.27852 .08259 L

.27575 .08183 L

.27298 .08109 L

.27021 .08036 L

.26744 .07965 L

.26467 .07895 L

.2619 .07827 L

.25914 .0776 L

.25637 .07695 L

.2536 .07632 L

.25083 .0757 L

.24806 .07511 L

.24529 .07453 L

.24252 .07398 L

.23976 .07344 L

.23699 .07292 L

.23422 .07243 L

.23145 .07195 L

.22868 .0715 L

.22591 .07107 L

.22315 .07066 L

.22038 .07028 L

.21761 .06993 L

.21484 .0696 L

.21207 .06929 L

.2093 .06902 L

.20653 .06877 L

.20377 .06855 L

.201 .06836 L

.19823 .0682 L

.19546 .06808 L

.19269 .06798 L

.18992 .06792 L

.18715 .0679 L

.18439 .06791 L

.18162 .06796 L

.17885 .06805 L

.17608 .06817 L

.17331 .06834 L

.17054 .06855 L

.16777 .0688 L

.16501 .0691 L

.16224 .06945 L

.15947 .06984 L

.1567 .07028 L

.15393 .07078 L

.15116 .07133 L

.14839 .07193 L

Mistroke

.14563 .0726 L

.14286 .07332 L

.14009 .0741 L

.13732 .07495 L

.13455 .07587 L

.13178 .07685 L

.12901 .07791 L

.12625 .07904 L

.12348 .08025 L

.12071 .08155 L

.11794 .08292 L

.11517 .08439 L

.1124 .08595 L

.10963 .0876 L

.10687 .08936 L

.1041 .09122 L

.10133 .0932 L

.09856 .09529 L

.09579 .0975 L

.09302 .09985 L

.09025 .10233 L

.08749 .10495 L

.08472 .10773 L

.08195 .11067 L

.07918 .11378 L

.07641 .11708 L

.07364 .12058 L

.07087 .12429 L

.06811 .12822 L

.06534 .13241 L

.06257 .13686 L

.0598 .14161 L

.05703 .14668 L

.05426 .15212 L

.0515 .15796 L

.04873 .16425 L

.04596 .17108 L

.04319 .17852 L

.04042 .18669 L

.03765 .19576 L

.03488 .20597 L

.03212 .21772 L

.02935 .2317 L

.02658 .24948 L

.02381 .30902 L

Mfstroke

.97619 .12872 m

.97342 .12971 L

.97065 .13078 L

.96788 .13194 L

.96512 .13321 L

.96235 .13458 L

.95958 .13607 L

.95681 .13768 L

.95404 .13944 L

.95127 .14134 L

.9485 .14342 L

.94574 .14567 L

.94297 .14811 L

.9402 .15076 L

.93743 .15362 L

.93466 .15672 L

.93189 .16006 L

.92913 .16364 L

.92636 .16746 L

.92359 .1715 L

.92082 .17576 L

.91805 .18019 L

.91528 .18477 L

.91251 .18944 L

.90975 .19417 L

.90698 .19892 L

.90421 .20363 L

.90144 .20828 L

.89867 .21284 L

.8959 .21729 L

.89313 .22163 L

.89037 .22583 L

.8876 .2299 L

.88483 .23384 L

.88206 .23765 L

.87929 .24133 L

.87652 .24488 L

.87375 .24832 L

.87099 .25164 L

.86822 .25486 L

.86545 .25798 L

.86268 .261 L

.85991 .26393 L

.85714 .26677 L

.85437 .26954 L

.85161 .27222 L

.84884 .27484 L

.84607 .27739 L

.8433 .27987 L

.84053 .28229 L

Mistroke

.83776 .28465 L

.83499 .28696 L

.83223 .28922 L

.82946 .29143 L

.82669 .29359 L

.82392 .29571 L

.82115 .29779 L

.81838 .29982 L

.81561 .30182 L

.81285 .30378 L

.81008 .30571 L

.80731 .3076 L

.80454 .30947 L

.80177 .3113 L

.799 .3131 L

.79623 .31488 L

.79347 .31663 L

.7907 .31835 L

.78793 .32005 L

.78516 .32173 L

.78239 .32339 L

.77962 .32502 L

.77685 .32664 L

.77409 .32823 L

.77132 .32981 L

.76855 .33137 L

.76578 .33291 L

.76301 .33443 L

.76024 .33594 L

.75748 .33743 L

.75471 .33891 L

.75194 .34038 L

.74917 .34183 L

.7464 .34326 L

.74363 .34469 L

.74086 .3461 L

.7381 .3475 L

.73533 .3489 L

.73256 .35028 L

.72979 .35164 L

.72702 .353 L

.72425 .35435 L

.72148 .35569 L

.71872 .35703 L

.71595 .35835 L

.71318 .35967 L

.71041 .36097 L

.70764 .36227 L

.70487 .36356 L

.7021 .36485 L

Mistroke

.69934 .36613 L

.69657 .3674 L

.6938 .36867 L

.69103 .36993 L

.68826 .37118 L

.68549 .37243 L

.68272 .37367 L

.67996 .37491 L

.67719 .37615 L

.67442 .37738 L

.67165 .3786 L

.66888 .37982 L

.66611 .38104 L

.66334 .38225 L

.66058 .38346 L

.65781 .38467 L

.65504 .38587 L

.65227 .38707 L

.6495 .38826 L

.64673 .38946 L

.64396 .39065 L

.6412 .39183 L

.63843 .39302 L

.63566 .3942 L

.63289 .39538 L

.63012 .39656 L

.62735 .39774 L

.62458 .39891 L

.62182 .40009 L

.61905 .40126 L

.61628 .40243 L

.61351 .4036 L

.61074 .40476 L

.60797 .40593 L

.6052 .40709 L

.60244 .40826 L

.59967 .40942 L

.5969 .41058 L

.59413 .41174 L

.59136 .4129 L

.58859 .41406 L

.58583 .41522 L

.58306 .41638 L

.58029 .41754 L

.57752 .4187 L

.57475 .41986 L

.57198 .42102 L

.56921 .42217 L

.56645 .42333 L

.56368 .42449 L

Mistroke

.56091 .42564 L

.55814 .4268 L

.55537 .42796 L

.5526 .42912 L

.54983 .43027 L

.54707 .43143 L

.5443 .43259 L

.54153 .43375 L

.53876 .43491 L

.53599 .43606 L

.53322 .43722 L

.53045 .43838 L

.52769 .43954 L

.52492 .4407 L

.52215 .44186 L

.51938 .44302 L

.51661 .44418 L

.51384 .44534 L

.51107 .4465 L

.50831 .44766 L

.50554 .44882 L

.50277 .44998 L

.5 .45114 L

.49723 .4523 L

.49446 .45347 L

.49169 .45463 L

.48893 .45579 L

.48616 .45695 L

.48339 .45811 L

.48062 .45927 L

.47785 .46043 L

.47508 .46159 L

.47231 .46275 L

.46955 .46391 L

.46678 .46507 L

.46401 .46623 L

.46124 .46738 L

.45847 .46854 L

.4557 .46969 L

.45293 .47085 L

.45017 .472 L

.4474 .47316 L

.44463 .47431 L

.44186 .47546 L

.43909 .47661 L

.43632 .47775 L

.43355 .4789 L

.43079 .48004 L

.42802 .48118 L

.42525 .48232 L

Mistroke

.42248 .48346 L

.41971 .48459 L

.41694 .48573 L

.41417 .48686 L

.41141 .48799 L

.40864 .48911 L

.40587 .49023 L

.4031 .49135 L

.40033 .49246 L

.39756 .49358 L

.3948 .49469 L

.39203 .49579 L

.38926 .49689 L

.38649 .49799 L

.38372 .49908 L

.38095 .50017 L

.37818 .50125 L

.37542 .50233 L

.37265 .5034 L

.36988 .50447 L

.36711 .50553 L

.36434 .50659 L

.36157 .50764 L

.3588 .50869 L

.35604 .50973 L

.35327 .51076 L

.3505 .51179 L

.34773 .51281 L

.34496 .51382 L

.34219 .51483 L

.33942 .51583 L

.33666 .51682 L

.33389 .5178 L

.33112 .51878 L

.32835 .51975 L

.32558 .52071 L

.32281 .52166 L

.32004 .5226 L

.31728 .52353 L

.31451 .52445 L

.31174 .52536 L

.30897 .52627 L

.3062 .52716 L

.30343 .52804 L

.30066 .52891 L

.2979 .52977 L

.29513 .53062 L

.29236 .53145 L

.28959 .53228 L

.28682 .53309 L

Mistroke

.28405 .53389 L

.28128 .53467 L

.27852 .53545 L

.27575 .5362 L

.27298 .53695 L

.27021 .53768 L

.26744 .53839 L

.26467 .53909 L

.2619 .53977 L

.25914 .54043 L

.25637 .54109 L

.2536 .54172 L

.25083 .54233 L

.24806 .54292 L

.24529 .5435 L

.24252 .54406 L

.23976 .5446 L

.23699 .54511 L

.23422 .54561 L

.23145 .54608 L

.22868 .54653 L

.22591 .54696 L

.22315 .54737 L

.22038 .54775 L

.21761 .54811 L

.21484 .54844 L

.21207 .54874 L

.2093 .54902 L

.20653 .54926 L

.20377 .54948 L

.201 .54967 L

.19823 .54983 L

.19546 .54996 L

.19269 .55005 L

.18992 .55011 L

.18715 .55014 L

.18439 .55012 L

.18162 .55008 L

.17885 .54999 L

.17608 .54986 L

.17331 .5497 L

.17054 .54949 L

.16777 .54923 L

.16501 .54893 L

.16224 .54859 L

.15947 .54819 L

.1567 .54775 L

.15393 .54725 L

.15116 .54671 L

.14839 .5461 L

Mistroke

.14563 .54544 L

.14286 .54472 L

.14009 .54393 L

.13732 .54308 L

.13455 .54217 L

.13178 .54118 L

.12901 .54012 L

.12625 .53899 L

.12348 .53778 L

.12071 .53649 L

.11794 .53511 L

.11517 .53364 L

.1124 .53209 L

.10963 .53043 L

.10687 .52867 L

.1041 .52681 L

.10133 .52484 L

.09856 .52274 L

.09579 .52053 L

.09302 .51819 L

.09025 .51571 L

.08749 .51308 L

.08472 .5103 L

.08195 .50736 L

.07918 .50425 L

.07641 .50095 L

.07364 .49746 L

.07087 .49375 L

.06811 .48981 L

.06534 .48563 L

.06257 .48117 L

.0598 .47643 L

.05703 .47135 L

.05426 .46592 L

.0515 .46008 L

.04873 .45378 L

.04596 .44695 L

.04319 .43951 L

.04042 .43134 L

.03765 .42227 L

.03488 .41206 L

.03212 .40032 L

.02935 .38634 L

.02658 .36855 L

.02381 .30902 L

Mfstroke

0 .4 1 r

.97204 .42897 m

.96512 .43047 L

.95819 .43199 L

.95127 .43353 L

.94435 .43507 L

.93743 .43664 L

.93051 .43821 L

.92359 .4398 L

.91667 .44141 L

.90975 .44303 L

.90282 .44467 L

.8959 .44633 L

.88898 .44801 L

.88206 .4497 L

.87514 .45141 L

.86822 .45313 L

.8613 .45488 L

.85437 .45665 L

.84745 .45844 L

.84053 .46024 L

.83361 .46207 L

.82669 .46392 L

.81977 .4658 L

.81285 .46769 L

.80592 .46962 L

.799 .47156 L

.79208 .47353 L

.78516 .47553 L

.77824 .47755 L

.77132 .47961 L

.7644 .48169 L

.75748 .4838 L

.75055 .48595 L

.74363 .48812 L

.73671 .49033 L

.72979 .49258 L

.72287 .49486 L

.71595 .49718 L

.70903 .49954 L

.7021 .50193 L

.69518 .50437 L

.68826 .50686 L

.68134 .50939 L

.67442 .51197 L

.6675 .5146 L

.66058 .51728 L

.65365 .52001 L

.64673 .5228 L

.63981 .52565 L

.63289 .52856 L

Mistroke

.62597 .53152 L

.61905 .53456 L

.61213 .53765 L

.6052 .54081 L

.59828 .54404 L

.59136 .54732 L

.58444 .55067 L

.57752 .55407 L

.5706 .55753 L

.56368 .56102 L

.55676 .56454 L

.54983 .56807 L

.54291 .57159 L

.53599 .57508 L

.52907 .57849 L

.52215 .58181 L

.51523 .58499 L

.50831 .588 L

.50138 .5908 L

.49446 .59337 L

.48754 .59567 L

.48062 .5977 L

.4737 .59943 L

.46678 .60086 L

.45986 .60196 L

.45293 .60275 L

.44601 .6032 L

.43909 .60332 L

.43217 .60309 L

.42525 .6025 L

.41833 .60154 L

.41141 .60019 L

.40449 .59843 L

.39756 .59623 L

.39064 .59355 L

.38372 .59036 L

.3768 .58662 L

.36988 .58226 L

.36296 .57722 L

.35604 .57142 L

.34911 .56475 L

.34219 .5571 L

.33527 .54832 L

.32835 .5382 L

.32143 .52649 L

.31451 .51282 L

.30759 .49666 L

.30066 .47717 L

.29374 .45286 L

.28682 .42041 L

Mistroke

.2799 .36895 L

.27741 .30902 L

Mfstroke

.97204 .18907 m

.96512 .18756 L

.95819 .18604 L

.95127 .18451 L

.94435 .18296 L

.93743 .1814 L

.93051 .17982 L

.92359 .17823 L

.91667 .17662 L

.90975 .175 L

.90282 .17336 L

.8959 .1717 L

.88898 .17003 L

.88206 .16834 L

.87514 .16663 L

.86822 .1649 L

.8613 .16315 L

.85437 .16139 L

.84745 .1596 L

.84053 .15779 L

.83361 .15596 L

.82669 .15411 L

.81977 .15224 L

.81285 .15034 L

.80592 .14842 L

.799 .14647 L

.79208 .1445 L

.78516 .1425 L

.77824 .14048 L

.77132 .13843 L

.7644 .13634 L

.75748 .13423 L

.75055 .13209 L

.74363 .12991 L

.73671 .1277 L

.72979 .12546 L

.72287 .12318 L

.71595 .12086 L

.70903 .1185 L

.7021 .1161 L

.69518 .11366 L

.68826 .11117 L

.68134 .10864 L

.67442 .10606 L

.6675 .10344 L

.66058 .10076 L

.65365 .09802 L

.64673 .09523 L

.63981 .09239 L

.63289 .08948 L

Mistroke

.62597 .08651 L

.61905 .08348 L

.61213 .08038 L

.6052 .07722 L

.59828 .074 L

.59136 .07071 L

.58444 .06736 L

.57752 .06396 L

.5706 .06051 L

.56368 .05701 L

.55676 .05349 L

.54983 .04996 L

.54291 .04644 L

.53599 .04296 L

.52907 .03954 L

.52215 .03623 L

.51523 .03305 L

.50831 .03004 L

.50138 .02723 L

.49446 .02467 L

.48754 .02236 L

.48062 .02033 L

.4737 .0186 L

.46678 .01718 L

.45986 .01607 L

.45293 .01529 L

.44601 .01483 L

.43909 .01472 L

.43217 .01495 L

.42525 .01553 L

.41833 .01649 L

.41141 .01784 L

.40449 .0196 L

.39756 .02181 L

.39064 .02448 L

.38372 .02767 L

.3768 .03141 L

.36988 .03577 L

.36296 .04081 L

.35604 .04662 L

.34911 .05328 L

.34219 .06093 L

.33527 .06971 L

.32835 .07983 L

.32143 .09154 L

.31451 .10522 L

.30759 .12138 L

.30066 .14087 L

.29374 .16517 L

.28682 .19762 L

Mistroke

.2799 .24908 L

.27741 .30902 L

Mfstroke

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{567, 350.313},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.776525,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008g0001GPP10`40000100000800002008200000

P800P020P<30`<3L`:K:l00003<006H009T00<`00?l0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV

09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<003o03?o06Ko09Wo0<co

0?oo0000<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I

<c>I<fJI<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0

IYT0I/`0I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bI

I_nIIP3<IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0c

VC<cVFHcVITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<

VIW<VLc<VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`c

c?lcc01Vc3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03o

c3?oc6Koc9Woc<coc?ooc000oc<0ofH0oiT0ol`0ool0o`0coc<cofHcoiTcol`coolco`1Voc=VofIV

oiUVolaVoomVo`2Ioc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<o`3ooc?oofKooiWoolco

ooooo`0000410@820P<30`@410D51@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C

4a@D5?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooa_Q00<0hN40on7ohA_Q000Kh@030>7Q0?oQ

on4Kh@006n400`3Qh@3ohOoQ6n4001_Q00<0hN40on7ohA_Q000Kh@030>7Q0?oQon4Kh@006n430?oQ

on4Kh@006n400`3Qh@3ohOoQ6n4001_Q00<0hN40on7ohA_Q000Kh@030>7Q0=?Q4[kohCGQ000Kh@03

0>7Q0<cQ1khBh@Nnon4^h@006n400`3Qh@39h@>n8>44__oQ:^4001_Q00<0hN40a^43_ROQ0kkohBOQ

000Kh@030>7Q0<CQ0[h]h@Bnon4Sh@006n400`3Qh@32h@:n<n43__oQ8>4001_Q00<0hN40`>42_SSQ

0kkohAgQ000Kh@030>7Q0;kQ0[hmh@:non4Kh@006n400`3Qh@2kh@>n@N42__oQ6N4001_Q0`2jh@03

_^7Q04CQ0kkohAKQ000Kh@030>7Q0;WQ00>nhN40B>42__oQ5>4001_Q00<0hN40^>400kkQh@1;h@:n

on4Bh@006n400`3Qh@2fh@:nD>42__oQ4>4001_Q00<0hN40]>42_UCQ0[koh@kQ000Kh@030>7Q0;?Q

00>nhN40E^43__oQ2n4001_Q00<0hN40/^400kkQh@1Jh@:non49h@006n400`3Qh@2ah@03_^7Q05gQ

00>nhN40on46h@006n400`3Qh@2`h@03_^7Q05oQ0[koh@KQ000Kh@030>7Q0:oQ00>nhN40H^42__oQ

1>4001_Q00<0hN40[^400kkQh@1Uh@:non42h@006n400`3Qh@2]h@03_^7Q06SQ0[koh@006n430:cQ

00>nhN40Jn42__gQ000Kh@030>7Q0:_Q00>nhN40K^400kkQh@3jh@006n400`3Qh@2Zh@03_^7Q073Q

0[kjh@006n400`3Qh@2Yh@03_^7Q07?Q0kkgh@006n400`3Qh@2Xh@03_^7Q07OQ0[keh@006n400`3Q

h@2Wh@03_^7Q07[Q0[kch@006n400`3Qh@1Eh@T?BN400kkQh@1lh@:nlN4001_Q00<0hN40Bn4:3`WQ

30llh@03_^7Q07oQ0[k_h@006n400`3Qh@15h@H?7n473cCQ00>nhN40P^42_^gQ000Kh@030>7Q04;Q

0`l/h@@?<>400kkQh@24h@:njn4000_Q1@02h@030>7Q00KQ00<0hN40?n433c?Q1PlYh@03_^7Q08OQ

0[kYh@003N401`3QhN40h@001n400`3Qh@0lh@<??>443bCQ00>nhN40R^43_^KQ0007h@<00n401`3Q

hN40h@001n4403SQ0`m3h@D?7n400kkQh@2=h@:ni>4000gQ00L0hN7Q0>4000OQ00<0hN40=n423d_Q

0`lKh@03_^7Q093Q0[kRh@003N401`3QhN40h@001n400`3Qh@0eh@8?D>443aKQ00>nhN40Tn43_]oQ

000<h@801>400`3Qh@06h@030>7Q03CQ00<?hN40E>433a?Q00>nhN40U^42_]gQ000Kh@030>7Q03;Q

0PmJh@<?3n400kkQh@2Ih@03_^7Q0=[Q000Kh@030>7Q037Q00<?hN40GN443`_Q00>nhN40V^42_][Q

000Kh@030>7Q02kQ0`mTh@<?1n400kkQh@2Mh@>nen4001_Q00<0hN40;N400`oQh@1Xh@<?1>400kkQ

h@2Ph@>ne>4001_Q00<0hN40;>400`oQh@1/h@8?00?Q_^40YN42_];Q000Kh@030>7Q02_Q00<?hN40

Kn400`nn3`2Wh@:nd>4001_Q00<0hN40:^400`oQh@1`h@03_^7Q00<?Y^44_/cQ000Kh@030>7Q02SQ

0Pmch@03_^7Q00?Q0`nWh@:nb^4001_Q0`0Wh@033n7Q07;Q00>nhN401n433jKQ0[k8h@006n400`3Q

h@0Vh@033n7Q07?Q00>nhN402^433jGQ0kk5h@006n400`3Qh@0Uh@033n7Q07?Q00>nhN403^433jGQ

1;k1h@006n400`3Qh@0Th@033n7Q07?Q00>nhN404^433jKQ0[joh@006n400`3Qh@0Sh@033n7Q07CQ

00>nhN405N423jKQ0[jmh@006n400`3Qh@0Rh@033n7Q07CQ00>nhN406>423jKQ0kjjh@006n400`3Q

h@0Qh@033n7Q07GQ00>nhN406^433jKQ0kjgh@006n400`3Qh@0Ph@033n7Q07GQ00>nhN407^433jKQ

0kjdh@006n400`3Qh@0Ph@033n7Q07GQ00>nhN408N423jOQ0[jbh@006n400`3Qh@0Oh@033n7Q07GQ

00>nhN409>433jKQ0kj_h@006n400`3Qh@0Nh@033n7Q07KQ00>nhN409n423jOQ0kj/h@006n400`3Q

h@0Mh@033n7Q07OQ00>nhN40:N433jOQ1;jXh@006n4301gQ00<?hN40M^400kkQh@0]h@<?Z>43_ZGQ

000Kh@030>7Q01cQ00<?hN40Mn400kkQh@0`h@8?ZN43_Z;Q000Kh@030>7Q01_Q00<?hN40N>400kkQ

h@0bh@8?Z^42_WSQ0PlVh@006n400`3Qh@0Jh@033n7Q07SQ00>nhN40=N433jWQ0[idh@8?:>4001_Q

00<0hN406^400`oQh@1hh@03_^7Q03SQ0`nXh@BnKN433b[Q000Kh@030>7Q01WQ00<?hN40NN400kkQ

h@0kh@033n7Q0:WQ1;iXh@033n7Q02_Q000Kh@030>7Q01SQ00<?hN40N^400kkQh@0lh@<?[>43_V?Q

0Pl^h@006n400`3Qh@0Hh@033n7Q07WQ00>nhN40@>433jcQ1;iMh@8?<>4001_Q00<0hN405n400`oQ

h@1jh@03_^7Q04?Q0`n]h@>nF>423c;Q000Kh@030>7Q01OQ00<?hN40N^400kkQh@16h@033n7Q0:gQ

1;iCh@033n7Q03;Q000Kh@030>7Q01KQ00<?hN40N^400kkQh@18h@<?/>44_ToQ00<?hN40<^4001_Q

00<0hN405^400`oQh@1jh@03_^7Q04_Q0`nah@>nB^423cGQ000Kh@<05N400`oQh@1kh@03_^7Q04kQ

00<?hN40/N44_TGQ00<?hN40=N4001_Q00<0hN405N400`oQh@1jh@03_^7Q053Q0`ndh@>n@>423cSQ

000Kh@030>7Q01CQ00<?hN40Nn400kkQh@1Ch@<?]>44_S_Q00<?hN40>>4001_Q00<0hN405>400`oQ

h@1kh@03_^7Q05KQ00<?hN40]N44_SOQ00<?hN40>>4001_Q00<0hN404n400`oQh@1lh@03_^7Q05OQ

0`nhh@>n<^423c_Q000Kh@030>7Q01?Q00<?hN40Nn400kkQh@1Kh@<?^>44_RgQ00<?hN40>n4001_Q

00<0hN404^400`oQh@1lh@03_^7Q05kQ0Pnjh@>n:^400`oQh@0kh@006n400`3Qh@0Bh@033n7Q07cQ

00>nhN40H>423k_Q1;hUh@033n7Q03cQ000Kh@030>7Q017Q00<?hN40O>400kkQh@1Sh@<?_>43_R;Q

00<?hN40?>4001_Q00<0hN404N400`oQh@1lh@03_^7Q06KQ0Pnmh@Bn7N400`oQh@0mh@006n400`3Q

h@0@h@033n7Q07gQ00>nhN40J>433kkQ1khEh@033n7Q03kQ000Kh@030>7Q013Q00<?hN40ON400kkQ

h@1[h@8?`n44_Q3Q00<?hN40?n4001_Q0`0@h@033n7Q07cQ00>nhN40K^423lGQ0kh=h@033n7Q03oQ

000Kh@030>7Q00oQ00<?hN40ON400kkQh@1`h@<?aN44_PSQ00<?hN40@>4001_Q00<0hN403n400`oQ

h@1mh@03_^7Q07?Q00<?hN40a^44_P?Q00<?hN40@N4001_Q00<0hN403^400`oQh@1nh@03_^7Q07CQ

0`o9h@>n00<?hN40@N4001_Q00<0hN403^400`oQh@1nh@03_^7Q07OQ0`o8h@033kjn00Fn?N4001_Q

00<0hN403^400`oQh@1nh@03_^7Q07[Q00<?hN40aN400`oQh@05h@Bn>N4001_Q00<0hN403N400`oQ

h@1nh@03_^7Q07cQ0`o3h@033n7Q00[Q1;heh@006n400`3Qh@0=h@033n7Q07kQ00>nhN40On433koQ

00<?hN403n43_S;Q000Kh@030>7Q00gQ00<?hN40O^400kkQh@22h@8?_>400`oQh@0Ch@Nn:n4001_Q

00<0hN403N400`oQh@1nh@03_^7Q08CQ0Pnjh@033n7Q01[Q0khXh@004^400`3Qh@06h@030>7Q00gQ

00<?hN40O^400kkQh@26h@<?]n400`oQh@15h@004N400`3Q0007h@030>7Q00cQ00<?hN40On400kkQ

h@29h@8?]>400`oQh@16h@003>4300CQ00<0hN401N4400_Q00<?hN40O^400kkQh@2<h@<?/N400`oQ

h@16h@004N4200SQ00<0hN403>400`oQh@1nh@03_^7Q08oQ0Pn^h@033n7Q04OQ000Ah@030>7Q00OQ

00<0hN403>400`oQh@1nh@03_^7Q097Q0Pn[h@033n7Q04SQ000Ah@<01n400`3Qh@0;h@033n7Q07oQ

00>nhN40Tn433jSQ00<?hN40B>4001_Q00<0hN402n400`oQh@1oh@03_^7Q09KQ0`nTh@033n7Q04WQ

000Kh@030>7Q00[Q00<?hN40P>400kkQh@2Ih@033n7Q0:7Q00<?hN40BN4001_Q00<0hN402^400`oQ

h@1oh@03_^7Q09_Q0`nOh@033n7Q04[Q000Kh@030>7Q00[Q00<?hN40On400kkQh@2Nh@<?Vn400`oQ

h@1;h@006n400`3Qh@0:h@033n7Q07oQ00>nhN40XN400`oQh@2Hh@033n7Q04_Q000Kh@030>7Q00WQ

00<?hN40P>400kkQh@2Rh@<?U^400`oQh@1<h@006n400`3Qh@09h@033n7Q083Q00>nhN40YN433i?Q

00<?hN40C>4001_Q00<0hN402N400`oQh@20h@03_^7Q0:SQ00<?hN40Sn400`oQh@1=h@006n4300WQ

00<?hN40On400kkQh@2Zh@<?SN400`oQh@1>h@006n400`3Qh@09h@033n7Q07oQ00>nhN40[N433hWQ

00<?hN40Cn4001_Q00<0hN402>400`oQh@20h@03_^7Q0;3Q0Pn7h@033n7Q04oQ000Kh@030>7Q00SQ

00<?hN40P>400kkQh@2bh@8?Q>400`oQh@1@h@006n400`3Qh@08h@033n7Q083Q00>nhN40]>433h7Q

00<?hN40D>4001_Q00<0hN402>400`oQh@20h@03_^7Q0;OQ0Pmnh@033n7Q057Q000Kh@030>7Q00OQ

00<?hN40PN400kkQh@2ih@<?N^400`oQh@1Bh@006n400`3Qh@07h@033n7Q083Q00>nhN40_N400`oQ

h@1fh@033n7Q05?Q000Kh@030>7Q00OQ00<?hN40P>400kkQh@2nh@<?MN400`oQh@1Ch@006n400`3Q

h@07h@033n7Q083Q00>nhN40`N433g7Q00<?hN40E>4001_Q00<0hN401n400`oQh@20h@03_^7Q0<CQ

00<?hN40KN400`oQh@1Eh@006n400`3Qh@07h@033n7Q083Q00>nhN40aN433f_Q00<?hN40E^4001_Q

0`06h@033n7Q087Q00>nhN40b>423fWQ00<?hN40E^4001_Q00<0hN401^400`oQh@20h@03_^7Q0<_Q

0PmVh@033n7Q05OQ000Kh@030>7Q00KQ00<?hN40P>400kkQh@3=h@<?H^400`oQh@1Hh@006n400`3Q

h@06h@033n7Q083Q00>nhN40d>423eoQ00<?hN40FN4001_Q00<0hN401^400`oQh@20h@03_^7Q0=;Q

0`mLh@033n7Q05WQ000Kh@030>7Q00KQ00<?hN40P>400kkQh@3Eh@033n7Q05SQ00<?hN40F^4001_Q

00<0hN401^400`oQh@20h@03_^7Q0=KQ0`mFh@033n7Q05_Q000Kh@030>7Q00KQ00<?hN40P>400kkQ

h@3Ih@033n7Q05;Q00<?hN40G>4001_Q00<0hN401^400`oQh@20h@03_^7Q0=[Q0`m@h@033n7Q05gQ

000Kh@030>7Q00KQ00<?hN40P>400kkQh@3Mh@8?C^400`oQh@1Mh@006n400`3Qh@06h@033n7Q083Q

00>nhN40gn433dWQ0PmPh@006n4300KQ00<?hN40P>400kkQh@3Rh@033n7Q04GQ00<?hN40H>4001_Q

00<0hN401^400`oQh@20h@03_^7Q0>?Q00<?hN40A>400`oQh@1Ph@006n400`3Qh@05h@033n7Q087Q

00>nhN40i>433d7Q0PmSh@006n400`3Qh@05h@033n7Q087Q00>nhN40in423ckQ00<?hN40Hn4001_Q

00<0hN401N400`oQh@21h@03_^7Q0>WQ0`lkh@033n7Q06?Q000Kh@030>7Q00GQ00<?hN40PN400kkQ

h@3/h@033n7Q03KQ0PmVh@006n400`3Qh@05h@033n7Q087Q00>nhN40kN400`oQh@0dh@033n7Q06KQ

000Kh@030>7Q00GQ00<?hN40PN400kkQh@3^h@<?<n400`oQh@1Vh@006n400`3Qh@05h@033n7Q087Q

00>nhN40lN423c3Q00<?hN40In4001_Q00<0hN401N400`oQh@20h@03_^7Q0?CQ00<?hN40:n423f[Q

000Kh@030>7Q00GQ00<?hN40>>4500;Q0`0nh@03_P0000800^400`3Qh@0mh@D000?Q0000@>4500;Q

00<0hN40?^4500;Q00<0hN405n433bCQ1@000`l00010h@<00n400`3Qh@0Qh@006n400`3Qh@05h@03

3n7Q03[Q00<0hN400n400`3Qh@0mh@03_^4000?Q00<0h@00@>401`3QhN40h@00@N400`3Qh@02h@03

0>7Q043Q00L0hN7Q0>4001_Q0PlTh@040>7Q3`;Q00<0hN40?N400`3Qh@02h@030>4002;Q000Kh@<0

1N400`oQh@0jh@040>7Qh@@0?^400kkQ0005h@030>7Q03kQ00L0hN7Q0>40047Q00<0hN400^400`3Q

h@10h@070>7Qh@3Q000Mh@033n7Q027Q00<03`l00^42043Q00L0hN7Q0>4002;Q000Kh@030>7Q00GQ

00<?hN40>^401`3QhN40h@00?n400kkQ0003h@80@N40103QhN4204;Q00<0hN400n400`3Qh@0oh@03

0>7Q00;Q00<0hN407N400`oQh@0Ph@073n7Qh@3Q0010h@070>7Qh@3Q000Rh@006n400`3Qh@05h@03

3n7Q03[Q00<0hN400^4203oQ00>nh@000n400`3Qh@10h@050>7Qh@00@n401`3QhN40h@00@N401`3Q

hN40h@007n433agQ0Pl01`3QhN40h@00?n400`3Q0002h@030>4002;Q000Kh@030>7Q00GQ00<?hN40

>N4200GQ00<0hN40?N400kh00003h@<0?n4200CQ0P10h@800n43043Q0P04h@030>7Q027Q0PlJh@04

3n4000CQ0P10h@030>7Q00;Q00<0hN408N4001_Q00<0hN401N400`oQh@20h@03_^7Q0?oQ0^400`oQ

h@0Fh@033n7Q077Q000Kh@030>7Q00CQ00<?hN40PN400kkQh@3oh@?Q0PlDh@8?M>4001_Q00<0hN40

1>400`oQh@21h@03_^7Q0?oQ1N400`oQh@0@h@033n7Q07CQ000Kh@030>7Q00CQ00<?hN40PN400kkQ

h@3oh@KQ00<?hN403n400`oQh@1dh@006n400`3Qh@04h@033n7Q087Q00>nhN40on47h@<?3>423gOQ

000Kh@030>7Q00CQ00<?hN40PN400kkQh@3oh@[Q0Pl9h@033n7Q07OQ000Kh@030>7Q00CQ00<?hN40

PN400kkQh@3oh@cQ00<?hN401>423foQ1007h@006n400`3Qh@04h@033n7Q087Q00>nhN40on4=h@8?

0n400`oQh@1_h@<02>4001KQ30000`l000210003_P000?l03`033f<04N400`3Qh@06h@006n400`3Q

h@04h@033n7Q00GQ00<0hN402n400`3Qh@0;h@030>7Q00cQ00<0hN402n400`3Qh@0;h@030>7Q00cQ

00<0hN402n400`3Qh@0;h@030>7Q00OQ00>nhN400^400`3Qh@0;h@030>7Q00_Q00<0hN403>400`3Q

h@0;h@030>7Q00_Q00<0hN403>400`3Qh@0;h@030>7Q00_Q00<0hN403>400`3Qh@0;h@030>7Q00cQ

00<0hN402n400`3Qh@0;h@030>7Q00cQ00<0hN402n400`3Qh@0;h@030>7Q00cQ00<0hN402n400`3Q

h@07h@8?0^400`3Qh@0<h@030>7Q00_Q00<0hN402n400`3Qh@0<h@030>7Q00_Q00<0hN402n400`3Q

h@0Ih@802>4001_Q00<0hN401>400`oQh@05h@030>7Q00_Q00<0hN402n400`3Qh@0<h@030>7Q00_Q

00<0hN402n400`3Qh@0<h@030>7Q00_Q00<0hN402n400`3Qh@07h@03_^7Q00;Q00<0hN402n400`3Q

h@0;h@030>7Q00cQ00<0hN402n400`3Qh@0;h@030>7Q00cQ00<0hN402n400`3Qh@0;h@030>7Q00cQ

00<0hN402n400`3Qh@0<h@030>7Q00_Q00<0hN402n400`3Qh@0<h@030>7Q00_Q00<0hN402n400`3Q

h@0<h@030>7Q00_Q00<0hN401>433`;Q0Pl00`3Qh@0<h@030>7Q00_Q00<0hN402n400`3Qh@0<h@03

0>7Q00_Q00<0hN402n400`3Qh@0Sh@006n400`3Qh@04h@033n7Q03kQ00<0hN40@>400kkQh@02h@03

0>7Q04CQ00<0hN40AN400`3Qh@15h@030>7Q02kQ00<?hN401N400`oQh@0<h@030>7Q04CQ00<0hN40

8n4001_Q00<0hN401>400`oQh@0nh@030>7Q043Q00>nhN400^400`3Qh@14h@030>7Q04GQ00<0hN40

AN400`3Qh@0/h@8?2N423`cQ00<0hN40A>400`3Qh@0Sh@006n400`3Qh@04h@033n7Q087Q00>nhN40

on48h@033n7Q00_Q00<?hN40M^4001_Q00<0hN401>400`oQh@21h@03_^7Q0?oQ1^423`oQ0Pmfh@00

6n400`3Qh@04h@033n7Q087Q00>nhN40on45h@033n7Q017Q00<?hN40Ln4001_Q00<0hN401N400`oQ

h@20h@03_^7Q0?oQ1>400`oQh@0Ch@8?Ln4001_Q00<0hN401N400`oQh@20h@03_^7Q0?oQ0N433aSQ

00<?hN40L>4001_Q00<0hN401N400`oQh@20h@03_^7Q0?kQ0PlKh@033n7Q073Q000Kh@030>7Q00GQ

00<?hN40P>400kkQh@3mh@033n7Q01cQ00<?hN40Kn4001_Q0`05h@033n7Q083Q00>nhN40nn423b3Q

0Pm_h@006n400`3Qh@05h@033n7Q083Q00>nhN40n^400`oQh@0Rh@033n7Q06cQ000Kh@030>7Q00GQ

00<?hN40P>400kkQh@3gh@<?9^423fcQ000Kh@030>7Q00GQ00<?hN40P>400kkQh@3fh@033n7Q02WQ

00<?hN40JN4001_Q00<0hN401N400`oQh@21h@03_^7Q0??Q0Pl]h@033n7Q06SQ000Kh@030>7Q00GQ

00<?hN40PN400kkQh@3`h@<?<>400`oQh@1Wh@006n400`3Qh@05h@033n7Q087Q00>nhN40kn400`oQ

h@0bh@033n7Q06KQ000Kh@030>7Q00GQ00<?hN40PN400kkQh@3]h@8?=^400`oQh@1Uh@006n400`3Q

h@05h@033n7Q087Q00>nhN40jn423cWQ00<?hN40I>4001_Q00<0hN401N400`oQh@21h@03_^7Q0>WQ

0Pllh@033n7Q06?Q000Kh@030>7Q00GQ00<?hN40PN400kkQh@3Vh@<??n400`oQh@1Rh@006n400`3Q

h@05h@033n7Q087Q00>nhN40iN400`oQh@11h@033n7Q067Q000Kh@<01^400`oQh@20h@03_^7Q0>?Q

0Pm5h@033n7Q063Q000Kh@030>7Q00KQ00<?hN40P>400kkQh@3Qh@8?B>400`oQh@1Oh@006n400`3Q

h@06h@033n7Q083Q00>nhN40gn423d_Q00<?hN40G^4001_Q00<0hN401^400`oQh@20h@03_^7Q0=cQ

0`m>h@033n7Q05gQ000Kh@030>7Q00KQ00<?hN40P>400kkQh@3Kh@033n7Q053Q00<?hN40G>4001_Q

00<0hN401^400`oQh@20h@03_^7Q0=SQ0`mCh@033n7Q05cQ000Kh@030>7Q00KQ00<?hN40P>400kkQ

h@3Gh@033n7Q05GQ00<?hN40Fn4001_Q00<0hN401^400`oQh@20h@03_^7Q0=CQ0`mIh@033n7Q05[Q

000Kh@030>7Q00KQ00<?hN40P>400kkQh@3Bh@8?GN400`oQh@1Ih@006n400`3Qh@06h@033n7Q083Q

00>nhN40cn433eoQ00<?hN40FN4001_Q00<0hN401^400`oQh@20h@03_^7Q0<kQ00<?hN40HN400`oQ

h@1Hh@006n400`3Qh@06h@033n7Q087Q00>nhN40b^433fGQ0PmHh@006n4300OQ00<?hN40P>400kkQ

h@37h@<?JN400`oQh@1Fh@006n400`3Qh@07h@033n7Q083Q00>nhN40a^400`oQh@1[h@033n7Q05GQ

000Kh@030>7Q00OQ00<?hN40P>400kkQh@33h@<?Kn400`oQh@1Dh@006n400`3Qh@07h@033n7Q083Q

00>nhN40`N423g?Q00<?hN40Dn4001_Q00<0hN401n400`oQh@20h@03_^7Q0;oQ0Pmeh@033n7Q05?Q

000Kh@030>7Q00OQ00<?hN40P>400kkQh@2lh@<?N>400`oQh@1Bh@006n400`3Qh@07h@033n7Q087Q

00>nhN40^N423gcQ00<?hN40DN4001_Q00<0hN402>400`oQh@20h@03_^7Q0;KQ0`moh@033n7Q053Q

000Kh@030>7Q00SQ00<?hN40P>400kkQh@2eh@033n7Q083Q00<?hN40D>4001_Q00<0hN402>400`oQ

h@20h@03_^7Q0;;Q0`n4h@033n7Q04oQ000Kh@030>7Q00SQ00<?hN40P>400kkQh@2_h@<?Qn400`oQ

h@1?h@006n400`3Qh@09h@033n7Q07oQ00>nhN40[^400`oQh@28h@033n7Q04oQ000Kh@<02N400`oQ

h@20h@03_^7Q0:[Q0`n<h@033n7Q04kQ000Kh@030>7Q00WQ00<?hN40P>400kkQh@2Wh@<?T>400`oQ

h@1=h@006n400`3Qh@09h@033n7Q083Q00>nhN40Y^400`oQh@2Bh@033n7Q04cQ000Kh@030>7Q00WQ

00<?hN40P>400kkQh@2Sh@<?UN400`oQh@1<h@006n400`3Qh@0:h@033n7Q07oQ00>nhN40X>433iWQ

00<?hN40Bn4001_Q00<0hN402^400`oQh@1oh@03_^7Q09kQ0PnLh@033n7Q04_Q000Kh@030>7Q00[Q

00<?hN40On400kkQh@2Lh@8?Wn400`oQh@1:h@006n400`3Qh@0:h@033n7Q083Q00>nhN40V>433j;Q

00<?hN40BN4001_Q00<0hN402n400`oQh@1oh@03_^7Q09KQ0PnUh@033n7Q04WQ000Kh@030>7Q00_Q

00<?hN40On400kkQh@2Ch@<?Z>400`oQh@18h@004^400`3Qh@06h@030>7Q00cQ00<?hN40O^400kkQ

h@2@h@<?[>400`oQh@17h@004N400`3Q0007h@030>7Q00cQ00<?hN40O^400kkQh@2?h@033n7Q0:gQ

00<?hN40An4001?Q00<0hN401N4400_Q00<?hN40O^400kkQh@2<h@<?/N400`oQh@16h@004N4200SQ

00<0hN403>400`oQh@1oh@03_^7Q08SQ0`ndh@033n7Q04KQ000Ah@030>7Q00OQ00<0hN403N400`oQ

h@1nh@03_^7Q08OQ00<?hN40]^400`oQh@15h@004N4300OQ00<0hN403N400`oQh@1nh@03_^7Q08CQ

0`nih@033n7Q01OQ1[hXh@006n400`3Qh@0=h@033n7Q07kQ00>nhN40PN433kgQ00<?hN404n43_RkQ

000Kh@030>7Q00gQ00<?hN40O^400kkQh@20h@033n7Q0;kQ00<?hN403n44_S7Q000Kh@030>7Q00gQ

00<?hN40O^400kkQh@1mh@<?`^400`oQh@0;h@>n=N4001_Q00<0hN403^400`oQh@1nh@03_^7Q07WQ

0`o6h@033n7Q00;Q2;hhh@006n400`3Qh@0>h@033n7Q07kQ00>nhN40N>400`oQh@37h@033n6n00:n

@>4001_Q00<0hN403^400`oQh@1nh@03_^7Q07GQ0`o8h@Bn@n4001_Q00<0hN403n400`oQh@1mh@03

_^7Q07;Q0`o8h@>n1>400`oQh@10h@006n400`3Qh@0?h@033n7Q07gQ00>nhN40L>423lOQ1;h7h@03

3n7Q043Q000Kh@<04>400`oQh@1lh@03_^7Q06gQ0`o2h@Nn3>400`oQh@0oh@006n400`3Qh@0@h@03

3n7Q07gQ00>nhN40J^423l7Q1;hCh@033n7Q03oQ000Kh@030>7Q017Q00<?hN40O>400kkQh@1Xh@8?

`>43_QSQ00<?hN40?^4001_Q00<0hN404N400`oQh@1lh@03_^7Q06GQ0`nnh@Bn7>400`oQh@0mh@00

6n400`3Qh@0Ah@033n7Q07cQ00>nhN40H^433kgQ1;hQh@033n7Q03cQ000Kh@030>7Q01;Q00<?hN40

O>400kkQh@1Ph@033n7Q0;_Q0khUh@033n7Q03cQ000Kh@030>7Q01;Q00<?hN40O>400kkQh@1Mh@<?

^^44_RWQ00<?hN40>n4001_Q00<0hN404n400`oQh@1kh@03_^7Q05[Q0`njh@>n;^400`oQh@0jh@00

6n400`3Qh@0Ch@033n7Q07cQ00>nhN40F>400`oQh@2gh@Bn<^400`oQh@0ih@006n400`3Qh@0Dh@03

3n7Q07_Q00>nhN40EN433kOQ0khgh@033n7Q03SQ000Kh@030>7Q01CQ00<?hN40Nn400kkQh@1Bh@<?

]^44_S_Q00<?hN40=n4001_Q00<0hN405N400`oQh@1jh@03_^7Q057Q00<?hN40/n44_T3Q00<?hN40

=^4001_Q0`0Eh@033n7Q07_Q00>nhN40CN433k?Q0ki5h@033n7Q03GQ000Kh@030>7Q01KQ00<?hN40

N^400kkQh@1:h@<?/^44_TWQ00<?hN40=>4001_Q00<0hN405^400`oQh@1jh@03_^7Q04SQ0Pnbh@>n

C^423cCQ000Kh@030>7Q01OQ00<?hN40N^400kkQh@15h@8?/>44_U?Q00<?hN40<N4001_Q00<0hN40

5n400`oQh@1jh@03_^7Q04;Q0`n^h@BnF>423c7Q000Kh@030>7Q01SQ00<?hN40NN400kkQh@10h@8?

[^43_UkQ00<?hN40;^4001_Q00<0hN406>400`oQh@1jh@03_^7Q03cQ0`n/h@BnH^400`oQh@0]h@00

6n400`3Qh@0Ih@033n7Q07WQ00>nhN40>^423jcQ0kiWh@<?;>4001_Q00<0hN406^400`oQh@1hh@03

_^7Q03SQ0PnZh@BnKN423b[Q000Kh@030>7Q01[Q00<?hN40N>400kkQh@0eh@<?Z>44_W?Q0`lWh@00

6n400`3Qh@0Kh@033n7Q07SQ00>nhN40<N433jWQ0[ijh@033n7Q02CQ000Kh@030>7Q01cQ00<?hN40

Mn400kkQh@0_h@8?Z^42_Z?Q000Kh@<07N400`oQh@1fh@03_^7Q02gQ0PnYh@>nYN4001_Q00<0hN40

7N400`oQh@1gh@03_^7Q02WQ0`nXh@>nZ>4001_Q00<0hN407^400`oQh@1fh@03_^7Q02KQ0`nWh@Bn

Zn4001_Q00<0hN407n400`oQh@1eh@03_^7Q02?Q0`nWh@>n[n4001_Q00<0hN408>400`oQh@1eh@03

_^7Q027Q00<?hN40YN43_[;Q000Kh@030>7Q023Q00<?hN40MN400kkQh@0Nh@<?Y^42_[GQ000Kh@03

0>7Q027Q00<?hN40MN400kkQh@0Jh@<?Y^43_[OQ000Kh@030>7Q02;Q00<?hN40M>400kkQh@0Gh@<?

Y^43_[[Q000Kh@030>7Q02?Q00<?hN40M>400kkQh@0Dh@8?Y^43_[gQ000Kh@030>7Q02CQ00<?hN40

Ln400kkQh@0Ah@<?Y^42_/3Q000Kh@030>7Q02GQ00<?hN40Ln400kkQh@0>h@8?Yn42_/;Q000Kh@03

0>7Q02KQ00<?hN40Ln400kkQh@0:h@<?YN44_/CQ000Kh@<09n400`oQh@1bh@03_^7Q00SQ0PnUh@>n

b>4001_Q00<0hN40:>400`oQh@1bh@03_^7Q00CQ0`nUh@:nbn4001_Q00<0hN40:N423g;Q00BnhN7Q

0`nVh@:ncN4001_Q00<0hN40:n400`oQh@1`h@03_Pl?0:KQ0kk?h@006n400`3Qh@0/h@8?KN433`03

_^7Q0:CQ0[kBh@006n400`3Qh@0^h@033n7Q06KQ10l4h@03_^7Q0:7Q0[kDh@006n400`3Qh@0_h@03

3n7Q06;Q0`l8h@03_^7Q09kQ0kkFh@006n400`3Qh@0`h@8?Gn433`cQ00>nhN40Vn42_]WQ000Kh@03

0>7Q03;Q00<?hN40FN433`oQ00>nhN40V>43_]_Q000Kh@030>7Q03?Q0PmEh@@?4n400kkQh@2Eh@:n

g^4000_Q1@02h@030>7Q00KQ00<0hN40=N433doQ0`lGh@03_^7Q09?Q0[kPh@003N401`3QhN40h@00

1n400`3Qh@0hh@033n7Q04SQ10lKh@03_^7Q093Q0[kRh@003N401`3QhN40h@001n4403SQ0`m2h@D?

8>400kkQh@2=h@:ni>4000gQ00L0hN7Q0>4000OQ00<0hN40?>433c_Q10lVh@03_^7Q08[Q0[kVh@00

3N401`3QhN40h@001n400`3Qh@0oh@<?<^463b[Q00>nhN40Qn43_^SQ000<h@801>400`3Qh@06h@03

0>7Q04;Q10lYh@D?<N400kkQh@24h@:njn4001_Q00<0hN40A^463a_Q20lgh@03_^7Q08;Q00>nhN40

jn4001_Q00<0hN40C>4K3d3Q00>nhN40On42_^kQ000Kh@030>7Q0:OQ00>nhN40O>43__3Q000Kh@03

0>7Q0:SQ00>nhN40N>43__?Q000Kh@030>7Q0:SQ00>nhN40M^42__KQ000Kh@030>7Q0:WQ00>nhN40

M>400kkQh@3fh@006n400`3Qh@2Zh@03_^7Q077Q0[kih@006n400`3Qh@2[h@03_^7Q06kQ0[kkh@00

6n430:cQ00>nhN40Jn42__gQ000Kh@030>7Q0:gQ00>nhN40JN400kkQh@3mh@006n400`3Qh@2^h@03

_^7Q06KQ0[koh@7Q000Kh@030>7Q0:oQ0[iSh@>non43h@006n400`3Qh@2ah@03_^7Q05gQ0kkoh@KQ

000Kh@030>7Q0;;Q00>nhN40F^42__oQ2N4001_Q00<0hN40/n400kkQh@1Hh@03_^7Q0?oQ2N4001_Q

00<0hN40]>400kkQh@1Eh@:non4<h@006n400`3Qh@2eh@03_^7Q05;Q0[koh@kQ000Kh@030>7Q0;KQ

0[i@h@:non4@h@006n400`3Qh@2hh@03_^7Q04_Q0[kohA;Q000Kh@030>7Q0;WQ0[i8h@>non4Dh@00

6n430;_Q00>nhN40@n42__oQ5n4001_Q00<0hN40_>42_T3Q0kkohAWQ000Kh@030>7Q0;kQ0[hlh@:n

on4Lh@006n400`3Qh@30h@:n>>42__oQ7^4001_Q00<0hN40`^42_S?Q0kkohB3Q000Kh@030>7Q0<CQ

1;h/h@>non4Sh@006n400`3Qh@38h@Bn9>44__oQ9^4001_Q00<0hN40c>43_QkQ0kkohB[Q000Kh@03

0>7Q0<oQ1kh?h@Rnon4]h@006n400`3Qh@3Fh@nnon4eh@006n400`3Qh@3ohOoQ6n4001_Q00<0hN40

on7ohA_Q000Kh@<0on7ohA_Q000Kh@030>7Q0?oQon4Kh@006n400`3Qh@3ohOoQ6n4001_Q00<0hN40

on7ohA_Q000Kh@030>7Q0?oQon4Kh@006n400`3Qh@3ohOoQ6n400?oQon4ih@00on7ohCWQ003ohOoQ

>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQon4ih@00

on7ohCWQ003ohA3Q0P001>400>440003h@0000CQ00<0hN40on4Eh@00on4Ah@030>4000WQ00H0hN40

h@3ohAKQ003ohA7Q0`02h@@00^400`3Qh@03h@030>7Q0?oQ5>400?oQ4N40103Q0008h@030>7Q0080

on4Gh@006N420?GQ00<0hN401n400`3Q0002h@030>7Q0?oQ5^4001[Q00<0hN40l^4200[Q00@0hN7Q

0`3ohAKQ000Hh@<00^400`3Qh@3ohOoQ6N4001OQ00P0hN40h@3Q0?oQon4Jh@005n40203Qh@3Q0>40

on7ohA[Q000Hh@<000CQ0>40on7ohA[Q000Lh@030>400?oQon4Jh@007N400`3Qh@3ohOoQ6N400?oQ

on4ih@00on7ohCWQ003ohOoQ>N400?oQon4ih@00on7ohCWQ0000\

\>"],

  ImageRangeCache->{{{0, 566}, {349.313, 0}} -> {12.6144, -13.4053, 0.0139368,

   0.08369}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-1.84845 0.141303 0.309017 0.0231246 [

[.27109 .29652 -6 -9 ]

[.27109 .29652 6 0 ]

[.41239 .29652 -6 -9 ]

[.41239 .29652 6 0 ]

[.5537 .29652 -6 -9 ]

[.5537 .29652 6 0 ]

[.695 .29652 -6 -9 ]

[.695 .29652 6 0 ]

[.8363 .29652 -6 -9 ]

[.8363 .29652 6 0 ]

[.9776 .29652 -6 -9 ]

[.9776 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.11729 .07777 -18 -4.5 ]

[.11729 .07777 0 4.5 ]

[.11729 .19339 -12 -4.5 ]

[.11729 .19339 0 4.5 ]

[.11729 .42464 -6 -4.5 ]

[.11729 .42464 0 4.5 ]

[.11729 .54026 -12 -4.5 ]

[.11729 .54026 0 4.5 ]

[.12979 .64303 -7 0 ]

[.12979 .64303 7 16 ]

[.5 .63053 -12 0 ]

[.5 .63053 12 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.27109 .30902 m

.27109 .31527 L

s

[(15)] .27109 .29652 0 1 Mshowa

.41239 .30902 m

.41239 .31527 L

s

[(16)] .41239 .29652 0 1 Mshowa

.5537 .30902 m

.5537 .31527 L

s

[(17)] .5537 .29652 0 1 Mshowa

.695 .30902 m

.695 .31527 L

s

[(18)] .695 .29652 0 1 Mshowa

.8363 .30902 m

.8363 .31527 L

s

[(19)] .8363 .29652 0 1 Mshowa

.9776 .30902 m

.9776 .31527 L

s

[(20)] .9776 .29652 0 1 Mshowa

.125 Mabswid

.15805 .30902 m

.15805 .31277 L

s

.18631 .30902 m

.18631 .31277 L

s

.21457 .30902 m

.21457 .31277 L

s

.24283 .30902 m

.24283 .31277 L

s

.29935 .30902 m

.29935 .31277 L

s

.32761 .30902 m

.32761 .31277 L

s

.35587 .30902 m

.35587 .31277 L

s

.38413 .30902 m

.38413 .31277 L

s

.44065 .30902 m

.44065 .31277 L

s

.46891 .30902 m

.46891 .31277 L

s

.49717 .30902 m

.49717 .31277 L

s

.52543 .30902 m

.52543 .31277 L

s

.58196 .30902 m

.58196 .31277 L

s

.61022 .30902 m

.61022 .31277 L

s

.63848 .30902 m

.63848 .31277 L

s

.66674 .30902 m

.66674 .31277 L

s

.72326 .30902 m

.72326 .31277 L

s

.75152 .30902 m

.75152 .31277 L

s

.77978 .30902 m

.77978 .31277 L

s

.80804 .30902 m

.80804 .31277 L

s

.86456 .30902 m

.86456 .31277 L

s

.89282 .30902 m

.89282 .31277 L

s

.92108 .30902 m

.92108 .31277 L

s

.94934 .30902 m

.94934 .31277 L

s

.10153 .30902 m

.10153 .31277 L

s

.07327 .30902 m

.07327 .31277 L

s

.045 .30902 m

.045 .31277 L

s

.01674 .30902 m

.01674 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.12979 .07777 m

.13604 .07777 L

s

[(-10)] .11729 .07777 1 0 Mshowa

.12979 .19339 m

.13604 .19339 L

s

[(-5)] .11729 .19339 1 0 Mshowa

.12979 .42464 m

.13604 .42464 L

s

[(5)] .11729 .42464 1 0 Mshowa

.12979 .54026 m

.13604 .54026 L

s

[(10)] .11729 .54026 1 0 Mshowa

.125 Mabswid

.12979 .1009 m

.13354 .1009 L

s

.12979 .12402 m

.13354 .12402 L

s

.12979 .14714 m

.13354 .14714 L

s

.12979 .17027 m

.13354 .17027 L

s

.12979 .21652 m

.13354 .21652 L

s

.12979 .23964 m

.13354 .23964 L

s

.12979 .26277 m

.13354 .26277 L

s

.12979 .28589 m

.13354 .28589 L

s

.12979 .33214 m

.13354 .33214 L

s

.12979 .35527 m

.13354 .35527 L

s

.12979 .37839 m

.13354 .37839 L

s

.12979 .40152 m

.13354 .40152 L

s

.12979 .44776 m

.13354 .44776 L

s

.12979 .47089 m

.13354 .47089 L

s

.12979 .49401 m

.13354 .49401 L

s

.12979 .51714 m

.13354 .51714 L

s

.12979 .05465 m

.13354 .05465 L

s

.12979 .03152 m

.13354 .03152 L

s

.12979 .0084 m

.13354 .0084 L

s

.12979 .56339 m

.13354 .56339 L

s

.12979 .58651 m

.13354 .58651 L

s

.12979 .60964 m

.13354 .60964 L

s

.25 Mabswid

.12979 0 m

.12979 .61803 L

s

gsave

.12979 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -73 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(k) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(37) show

83.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

1 0 0 r

.5 Mabswid

.97478 .52682 m

.97195 .52728 L

.96913 .52773 L

.9663 .52819 L

.96347 .52864 L

.96065 .5291 L

.95782 .52955 L

.955 .53 L

.95217 .53045 L

.94934 .53091 L

.94652 .53135 L

.94369 .5318 L

.94086 .53225 L

.93804 .53269 L

.93521 .53314 L

.93239 .53357 L

.92956 .53401 L

.92673 .53445 L

.92391 .53488 L

.92108 .53531 L

.91826 .53573 L

.91543 .53615 L

.9126 .53656 L

.90978 .53697 L

.90695 .53737 L

.90413 .53777 L

.9013 .53816 L

.89847 .53854 L

.89565 .53891 L

.89282 .53927 L

.89 .53962 L

.88717 .53995 L

.88434 .54027 L

.88152 .54057 L

.87869 .54085 L

.87587 .54111 L

.87304 .54134 L

.87021 .54154 L

.86739 .5417 L

.86456 .54181 L

.86174 .54187 L

.85891 .54186 L

.85608 .54176 L

.85326 .54155 L

.85043 .54118 L

.8476 .54059 L

.84478 .53966 L

.84195 .53813 L

.83913 .53523 L

.83899 .535 L

Mistroke

.83884 .53476 L

.8387 .53451 L

.83856 .53425 L

.83842 .53395 L

.83828 .53365 L

.83814 .53331 L

.838 .53293 L

.83786 .53252 L

.83771 .53205 L

.83757 .53151 L

.83743 .53087 L

.83729 .53007 L

.83715 .52888 L

Mfstroke

.97478 .09121 m

.97195 .09076 L

.96913 .0903 L

.9663 .08985 L

.96347 .08939 L

.96065 .08894 L

.95782 .08848 L

.955 .08803 L

.95217 .08758 L

.94934 .08713 L

.94652 .08668 L

.94369 .08623 L

.94086 .08579 L

.93804 .08534 L

.93521 .0849 L

.93239 .08446 L

.92956 .08402 L

.92673 .08359 L

.92391 .08316 L

.92108 .08273 L

.91826 .08231 L

.91543 .08189 L

.9126 .08147 L

.90978 .08106 L

.90695 .08066 L

.90413 .08026 L

.9013 .07988 L

.89847 .07949 L

.89565 .07912 L

.89282 .07876 L

.89 .07842 L

.88717 .07808 L

.88434 .07776 L

.88152 .07746 L

.87869 .07718 L

.87587 .07692 L

.87304 .07669 L

.87021 .07649 L

.86739 .07633 L

.86456 .07622 L

.86174 .07616 L

.85891 .07617 L

.85608 .07627 L

.85326 .07649 L

.85043 .07686 L

.8476 .07745 L

.84478 .07838 L

.84195 .0799 L

.83913 .0828 L

.83899 .08303 L

Mistroke

.83884 .08327 L

.8387 .08352 L

.83856 .08378 L

.83842 .08408 L

.83828 .08438 L

.83814 .08472 L

.838 .0851 L

.83786 .08551 L

.83771 .08598 L

.83757 .08652 L

.83743 .08716 L

.83729 .08796 L

.83715 .08915 L

Mfstroke

0 .4 1 r

.97619 .4229 m

.97478 .42321 L

.97336 .42352 L

.97195 .42383 L

.97054 .42414 L

.96913 .42446 L

.96771 .42477 L

.9663 .42508 L

.96489 .4254 L

.96347 .42571 L

.96206 .42603 L

.96065 .42635 L

.95923 .42666 L

.95782 .42698 L

.95641 .4273 L

.955 .42762 L

.95358 .42794 L

.95217 .42826 L

.95076 .42858 L

.94934 .4289 L

.94793 .42922 L

.94652 .42955 L

.9451 .42987 L

.94369 .43019 L

.94228 .43052 L

.94086 .43084 L

.93945 .43117 L

.93804 .4315 L

.93663 .43182 L

.93521 .43215 L

.9338 .43248 L

.93239 .43281 L

.93097 .43314 L

.92956 .43347 L

.92815 .43381 L

.92673 .43414 L

.92532 .43447 L

.92391 .43481 L

.9225 .43514 L

.92108 .43548 L

.91967 .43581 L

.91826 .43615 L

.91684 .43649 L

.91543 .43683 L

.91402 .43717 L

.9126 .43751 L

.91119 .43785 L

.90978 .43819 L

.90837 .43853 L

.90695 .43888 L

Mistroke

.90554 .43922 L

.90413 .43957 L

.90271 .43991 L

.9013 .44026 L

.89989 .44061 L

.89847 .44096 L

.89706 .44131 L

.89565 .44166 L

.89423 .44201 L

.89282 .44236 L

.89141 .44271 L

.89 .44307 L

.88858 .44342 L

.88717 .44378 L

.88576 .44413 L

.88434 .44449 L

.88293 .44485 L

.88152 .44521 L

.8801 .44557 L

.87869 .44593 L

.87728 .4463 L

.87587 .44666 L

.87445 .44702 L

.87304 .44739 L

.87163 .44776 L

.87021 .44812 L

.8688 .44849 L

.86739 .44886 L

.86597 .44923 L

.86456 .44961 L

.86315 .44998 L

.86174 .45035 L

.86032 .45073 L

.85891 .45111 L

.8575 .45148 L

.85608 .45186 L

.85467 .45224 L

.85326 .45262 L

.85184 .45301 L

.85043 .45339 L

.84902 .45378 L

.8476 .45416 L

.84619 .45455 L

.84478 .45494 L

.84337 .45533 L

.84195 .45572 L

.84054 .45611 L

.83913 .45651 L

.83771 .4569 L

.8363 .4573 L

Mistroke

.83489 .4577 L

.83347 .45809 L

.83206 .4585 L

.83065 .4589 L

.82924 .4593 L

.82782 .45971 L

.82641 .46011 L

.825 .46052 L

.82358 .46093 L

.82217 .46134 L

.82076 .46175 L

.81934 .46217 L

.81793 .46258 L

.81652 .463 L

.81511 .46342 L

.81369 .46384 L

.81228 .46426 L

.81087 .46469 L

.80945 .46511 L

.80804 .46554 L

.80663 .46597 L

.80521 .4664 L

.8038 .46683 L

.80239 .46727 L

.80097 .46771 L

.79956 .46814 L

.79815 .46858 L

.79674 .46903 L

.79532 .46947 L

.79391 .46992 L

.7925 .47037 L

.79108 .47082 L

.78967 .47127 L

.78826 .47173 L

.78684 .47218 L

.78543 .47264 L

.78402 .4731 L

.78261 .47357 L

.78119 .47403 L

.77978 .4745 L

.77837 .47497 L

.77695 .47545 L

.77554 .47592 L

.77413 .4764 L

.77271 .47688 L

.7713 .47736 L

.76989 .47785 L

.76848 .47834 L

.76706 .47883 L

.76565 .47933 L

Mistroke

.76424 .47982 L

.76282 .48032 L

.76141 .48083 L

.76 .48133 L

.75858 .48184 L

.75717 .48235 L

.75576 .48287 L

.75435 .48339 L

.75293 .48391 L

.75152 .48444 L

.75011 .48496 L

.74869 .4855 L

.74728 .48603 L

.74587 .48657 L

.74445 .48712 L

.74304 .48766 L

.74163 .48822 L

.74021 .48877 L

.7388 .48933 L

.73739 .48989 L

.73598 .49046 L

.73456 .49103 L

.73315 .49161 L

.73174 .49219 L

.73032 .49278 L

.72891 .49337 L

.7275 .49396 L

.72608 .49456 L

.72467 .49517 L

.72326 .49578 L

.72185 .4964 L

.72043 .49702 L

.71902 .49765 L

.71761 .49828 L

.71619 .49892 L

.71478 .49957 L

.71337 .50022 L

.71195 .50088 L

.71054 .50154 L

.70913 .50222 L

.70772 .5029 L

.7063 .50358 L

.70489 .50428 L

.70348 .50498 L

.70206 .50569 L

.70065 .50641 L

.69924 .50714 L

.69782 .50788 L

.69641 .50862 L

.695 .50938 L

Mistroke

.69358 .51014 L

.69217 .51092 L

.69076 .51171 L

.68935 .5125 L

.68793 .51331 L

.68652 .51413 L

.68511 .51497 L

.68369 .51581 L

.68228 .51668 L

.68087 .51755 L

.67945 .51844 L

.67804 .51934 L

.67663 .52027 L

.67522 .5212 L

.6738 .52216 L

.67239 .52314 L

.67098 .52413 L

.66956 .52515 L

.66815 .52619 L

.66674 .52725 L

.66532 .52833 L

.66391 .52945 L

.6625 .53059 L

.66109 .53176 L

.65967 .53296 L

.65826 .5342 L

.65685 .53548 L

.65543 .53679 L

.65402 .53815 L

.65261 .53955 L

.65119 .54101 L

.64978 .54252 L

.64837 .54408 L

.64695 .54572 L

.64554 .54742 L

.64413 .5492 L

.64272 .55106 L

.6413 .55302 L

.63989 .55506 L

.63848 .5572 L

.63706 .55942 L

.63565 .56171 L

.63424 .56405 L

.63282 .56639 L

.63141 .56867 L

.63 .57085 L

.62859 .57288 L

.62717 .57473 L

.62576 .57641 L

.62435 .57792 L

Mistroke

.62293 .57927 L

.62152 .5805 L

.62011 .58161 L

.61869 .58263 L

.61728 .58356 L

.61587 .58441 L

.61446 .58521 L

.61304 .58595 L

.61163 .58664 L

.61022 .58729 L

.6088 .5879 L

.60739 .58848 L

.60598 .58904 L

.60456 .58956 L

.60315 .59006 L

.60174 .59054 L

.60032 .591 L

.59891 .59144 L

.5975 .59187 L

.59609 .59228 L

.59467 .59268 L

.59326 .59306 L

.59185 .59343 L

.59043 .59379 L

.58902 .59414 L

.58761 .59448 L

.58619 .5948 L

.58478 .59513 L

.58337 .59544 L

.58196 .59574 L

.58054 .59603 L

.57913 .59632 L

.57772 .5966 L

.5763 .59687 L

.57489 .59714 L

.57348 .5974 L

.57206 .59765 L

.57065 .5979 L

.56924 .59814 L

.56783 .59837 L

.56641 .5986 L

.565 .59882 L

.56359 .59904 L

.56217 .59925 L

.56076 .59946 L

.55935 .59966 L

.55793 .59985 L

.55652 .60004 L

.55511 .60023 L

.5537 .60041 L

Mistroke

.55228 .60059 L

.55087 .60075 L

.54946 .60092 L

.54804 .60108 L

.54663 .60123 L

.54522 .60138 L

.5438 .60152 L

.54239 .60166 L

.54098 .60179 L

.53956 .60192 L

.53815 .60204 L

.53674 .60216 L

.53533 .60228 L

.53391 .60238 L

.5325 .60248 L

.53109 .60258 L

.52967 .60267 L

.52826 .60275 L

.52685 .60283 L

.52543 .60291 L

.52402 .60297 L

.52261 .60304 L

.5212 .60309 L

.51978 .60314 L

.51837 .60319 L

.51696 .60322 L

.51554 .60326 L

.51413 .60328 L

.51272 .6033 L

.5113 .60331 L

.50989 .60332 L

.50848 .60332 L

.50707 .60331 L

.50565 .6033 L

.50424 .60327 L

.50283 .60324 L

.50141 .60321 L

.5 .60317 L

.49859 .60312 L

.49717 .60306 L

.49576 .60299 L

.49435 .60292 L

.49293 .60284 L

.49152 .60275 L

.49011 .60265 L

.4887 .60254 L

.48728 .60243 L

.48587 .6023 L

.48446 .60217 L

.48304 .60203 L

Mistroke

.48163 .60188 L

.48022 .60172 L

.4788 .60155 L

.47739 .60137 L

.47598 .60118 L

.47457 .60098 L

.47315 .60077 L

.47174 .60055 L

.47033 .60032 L

.46891 .60007 L

.4675 .59982 L

.46609 .59955 L

.46467 .59928 L

.46326 .59899 L

.46185 .59869 L

.46044 .59837 L

.45902 .59805 L

.45761 .59771 L

.4562 .59736 L

.45478 .59699 L

.45337 .59662 L

.45196 .59622 L

.45054 .59581 L

.44913 .59539 L

.44772 .59496 L

.4463 .59451 L

.44489 .59404 L

.44348 .59356 L

.44207 .59306 L

.44065 .59254 L

.43924 .59201 L

.43783 .59146 L

.43641 .59089 L

.435 .59031 L

.43359 .5897 L

.43217 .58908 L

.43076 .58844 L

.42935 .58778 L

.42794 .58709 L

.42652 .58639 L

.42511 .58567 L

.4237 .58492 L

.42228 .58415 L

.42087 .58336 L

.41946 .58255 L

.41804 .58171 L

.41663 .58085 L

.41522 .57996 L

.41381 .57905 L

.41239 .57811 L

Mistroke

.41098 .57714 L

.40957 .57615 L

.40815 .57513 L

.40674 .57408 L

.40533 .573 L

.40391 .57188 L

.4025 .57074 L

.40109 .56956 L

.39968 .56835 L

.39826 .56711 L

.39685 .56583 L

.39544 .56452 L

.39402 .56317 L

.39261 .56177 L

.3912 .56034 L

.38978 .55887 L

.38837 .55736 L

.38696 .5558 L

.38554 .5542 L

.38413 .55256 L

.38272 .55086 L

.38131 .54912 L

.37989 .54732 L

.37848 .54548 L

.37707 .54357 L

.37565 .54161 L

.37424 .5396 L

.37283 .53752 L

.37141 .53538 L

.37 .53317 L

.36859 .53089 L

.36718 .52855 L

.36576 .52613 L

.36435 .52363 L

.36294 .52105 L

.36152 .51838 L

.36011 .51563 L

.3587 .51278 L

.35728 .50984 L

.35587 .50679 L

.35446 .50363 L

.35305 .50036 L

.35163 .49696 L

.35022 .49343 L

.34881 .48977 L

.34739 .48595 L

.34598 .48198 L

.34457 .47783 L

.34315 .4735 L

.34174 .46897 L

Mistroke

.34033 .46421 L

.33891 .45921 L

.3375 .45394 L

.33609 .44837 L

.33468 .44245 L

.33326 .43615 L

.33185 .42939 L

.33044 .42209 L

.32902 .41414 L

.32761 .40538 L

.3262 .39555 L

.32478 .38423 L

.32337 .37062 L

.32196 .3526 L

.32055 .3148 L

.32055 .30902 L

Mfstroke

.97619 .19514 m

.97478 .19483 L

.97336 .19452 L

.97195 .1942 L

.97054 .19389 L

.96913 .19358 L

.96771 .19327 L

.9663 .19295 L

.96489 .19264 L

.96347 .19232 L

.96206 .19201 L

.96065 .19169 L

.95923 .19137 L

.95782 .19105 L

.95641 .19074 L

.955 .19042 L

.95358 .1901 L

.95217 .18978 L

.95076 .18946 L

.94934 .18913 L

.94793 .18881 L

.94652 .18849 L

.9451 .18817 L

.94369 .18784 L

.94228 .18752 L

.94086 .18719 L

.93945 .18686 L

.93804 .18654 L

.93663 .18621 L

.93521 .18588 L

.9338 .18555 L

.93239 .18522 L

.93097 .18489 L

.92956 .18456 L

.92815 .18423 L

.92673 .1839 L

.92532 .18356 L

.92391 .18323 L

.9225 .18289 L

.92108 .18256 L

.91967 .18222 L

.91826 .18188 L

.91684 .18155 L

.91543 .18121 L

.91402 .18087 L

.9126 .18053 L

.91119 .18019 L

.90978 .17984 L

.90837 .1795 L

.90695 .17916 L

Mistroke

.90554 .17881 L

.90413 .17847 L

.90271 .17812 L

.9013 .17777 L

.89989 .17743 L

.89847 .17708 L

.89706 .17673 L

.89565 .17638 L

.89423 .17603 L

.89282 .17567 L

.89141 .17532 L

.89 .17497 L

.88858 .17461 L

.88717 .17426 L

.88576 .1739 L

.88434 .17354 L

.88293 .17318 L

.88152 .17282 L

.8801 .17246 L

.87869 .1721 L

.87728 .17174 L

.87587 .17137 L

.87445 .17101 L

.87304 .17064 L

.87163 .17028 L

.87021 .16991 L

.8688 .16954 L

.86739 .16917 L

.86597 .1688 L

.86456 .16843 L

.86315 .16805 L

.86174 .16768 L

.86032 .1673 L

.85891 .16693 L

.8575 .16655 L

.85608 .16617 L

.85467 .16579 L

.85326 .16541 L

.85184 .16503 L

.85043 .16464 L

.84902 .16426 L

.8476 .16387 L

.84619 .16348 L

.84478 .1631 L

.84337 .16271 L

.84195 .16231 L

.84054 .16192 L

.83913 .16153 L

.83771 .16113 L

.8363 .16074 L

Mistroke

.83489 .16034 L

.83347 .15994 L

.83206 .15954 L

.83065 .15914 L

.82924 .15873 L

.82782 .15833 L

.82641 .15792 L

.825 .15751 L

.82358 .1571 L

.82217 .15669 L

.82076 .15628 L

.81934 .15587 L

.81793 .15545 L

.81652 .15503 L

.81511 .15461 L

.81369 .15419 L

.81228 .15377 L

.81087 .15335 L

.80945 .15292 L

.80804 .15249 L

.80663 .15206 L

.80521 .15163 L

.8038 .1512 L

.80239 .15076 L

.80097 .15033 L

.79956 .14989 L

.79815 .14945 L

.79674 .14901 L

.79532 .14856 L

.79391 .14812 L

.7925 .14767 L

.79108 .14722 L

.78967 .14676 L

.78826 .14631 L

.78684 .14585 L

.78543 .14539 L

.78402 .14493 L

.78261 .14447 L

.78119 .144 L

.77978 .14353 L

.77837 .14306 L

.77695 .14259 L

.77554 .14211 L

.77413 .14163 L

.77271 .14115 L

.7713 .14067 L

.76989 .14018 L

.76848 .13969 L

.76706 .1392 L

.76565 .13871 L

Mistroke

.76424 .13821 L

.76282 .13771 L

.76141 .13721 L

.76 .1367 L

.75858 .13619 L

.75717 .13568 L

.75576 .13517 L

.75435 .13465 L

.75293 .13412 L

.75152 .1336 L

.75011 .13307 L

.74869 .13254 L

.74728 .132 L

.74587 .13146 L

.74445 .13092 L

.74304 .13037 L

.74163 .12982 L

.74021 .12926 L

.7388 .1287 L

.73739 .12814 L

.73598 .12757 L

.73456 .127 L

.73315 .12642 L

.73174 .12584 L

.73032 .12526 L

.72891 .12467 L

.7275 .12407 L

.72608 .12347 L

.72467 .12286 L

.72326 .12225 L

.72185 .12164 L

.72043 .12102 L

.71902 .12039 L

.71761 .11975 L

.71619 .11911 L

.71478 .11847 L

.71337 .11782 L

.71195 .11716 L

.71054 .11649 L

.70913 .11582 L

.70772 .11514 L

.7063 .11445 L

.70489 .11376 L

.70348 .11305 L

.70206 .11234 L

.70065 .11162 L

.69924 .1109 L

.69782 .11016 L

.69641 .10941 L

.695 .10866 L

Mistroke

.69358 .10789 L

.69217 .10712 L

.69076 .10633 L

.68935 .10553 L

.68793 .10472 L

.68652 .1039 L

.68511 .10307 L

.68369 .10222 L

.68228 .10136 L

.68087 .10048 L

.67945 .09959 L

.67804 .09869 L

.67663 .09777 L

.67522 .09683 L

.6738 .09587 L

.67239 .0949 L

.67098 .0939 L

.66956 .09289 L

.66815 .09185 L

.66674 .09079 L

.66532 .0897 L

.66391 .08859 L

.6625 .08745 L

.66109 .08628 L

.65967 .08507 L

.65826 .08383 L

.65685 .08256 L

.65543 .08124 L

.65402 .07989 L

.65261 .07848 L

.65119 .07703 L

.64978 .07552 L

.64837 .07395 L

.64695 .07232 L

.64554 .07061 L

.64413 .06883 L

.64272 .06697 L

.6413 .06502 L

.63989 .06297 L

.63848 .06084 L

.63706 .05861 L

.63565 .05632 L

.63424 .05398 L

.63282 .05165 L

.63141 .04936 L

.63 .04719 L

.62859 .04516 L

.62717 .0433 L

.62576 .04163 L

.62435 .04012 L

Mistroke

.62293 .03876 L

.62152 .03753 L

.62011 .03642 L

.61869 .03541 L

.61728 .03448 L

.61587 .03362 L

.61446 .03283 L

.61304 .03209 L

.61163 .03139 L

.61022 .03074 L

.6088 .03013 L

.60739 .02955 L

.60598 .029 L

.60456 .02847 L

.60315 .02797 L

.60174 .02749 L

.60032 .02703 L

.59891 .02659 L

.5975 .02616 L

.59609 .02575 L

.59467 .02536 L

.59326 .02497 L

.59185 .0246 L

.59043 .02424 L

.58902 .0239 L

.58761 .02356 L

.58619 .02323 L

.58478 .02291 L

.58337 .0226 L

.58196 .0223 L

.58054 .022 L

.57913 .02171 L

.57772 .02144 L

.5763 .02116 L

.57489 .0209 L

.57348 .02064 L

.57206 .02038 L

.57065 .02014 L

.56924 .0199 L

.56783 .01966 L

.56641 .01943 L

.565 .01921 L

.56359 .01899 L

.56217 .01878 L

.56076 .01857 L

.55935 .01837 L

.55793 .01818 L

.55652 .01799 L

.55511 .0178 L

.5537 .01762 L

Mistroke

.55228 .01745 L

.55087 .01728 L

.54946 .01712 L

.54804 .01696 L

.54663 .0168 L

.54522 .01665 L

.5438 .01651 L

.54239 .01637 L

.54098 .01624 L

.53956 .01611 L

.53815 .01599 L

.53674 .01587 L

.53533 .01576 L

.53391 .01565 L

.5325 .01555 L

.53109 .01546 L

.52967 .01536 L

.52826 .01528 L

.52685 .0152 L

.52543 .01513 L

.52402 .01506 L

.52261 .015 L

.5212 .01494 L

.51978 .01489 L

.51837 .01485 L

.51696 .01481 L

.51554 .01478 L

.51413 .01475 L

.51272 .01473 L

.5113 .01472 L

.50989 .01472 L

.50848 .01472 L

.50707 .01472 L

.50565 .01474 L

.50424 .01476 L

.50283 .01479 L

.50141 .01482 L

.5 .01487 L

.49859 .01492 L

.49717 .01498 L

.49576 .01504 L

.49435 .01512 L

.49293 .0152 L

.49152 .01529 L

.49011 .01539 L

.4887 .01549 L

.48728 .01561 L

.48587 .01573 L

.48446 .01586 L

.48304 .01601 L

Mistroke

.48163 .01616 L

.48022 .01632 L

.4788 .01649 L

.47739 .01667 L

.47598 .01686 L

.47457 .01706 L

.47315 .01727 L

.47174 .01749 L

.47033 .01772 L

.46891 .01796 L

.4675 .01822 L

.46609 .01848 L

.46467 .01876 L

.46326 .01905 L

.46185 .01935 L

.46044 .01966 L

.45902 .01999 L

.45761 .02033 L

.4562 .02068 L

.45478 .02104 L

.45337 .02142 L

.45196 .02181 L

.45054 .02222 L

.44913 .02264 L

.44772 .02308 L

.4463 .02353 L

.44489 .02399 L

.44348 .02448 L

.44207 .02498 L

.44065 .02549 L

.43924 .02603 L

.43783 .02658 L

.43641 .02714 L

.435 .02773 L

.43359 .02833 L

.43217 .02895 L

.43076 .0296 L

.42935 .03026 L

.42794 .03094 L

.42652 .03164 L

.42511 .03237 L

.4237 .03311 L

.42228 .03388 L

.42087 .03467 L

.41946 .03548 L

.41804 .03632 L

.41663 .03718 L

.41522 .03807 L

.41381 .03898 L

.41239 .03992 L

Mistroke

.41098 .04089 L

.40957 .04188 L

.40815 .04291 L

.40674 .04396 L

.40533 .04504 L

.40391 .04615 L

.4025 .04729 L

.40109 .04847 L

.39968 .04968 L

.39826 .05092 L

.39685 .0522 L

.39544 .05352 L

.39402 .05487 L

.39261 .05626 L

.3912 .05769 L

.38978 .05916 L

.38837 .06067 L

.38696 .06223 L

.38554 .06383 L

.38413 .06548 L

.38272 .06717 L

.38131 .06892 L

.37989 .07071 L

.37848 .07256 L

.37707 .07446 L

.37565 .07642 L

.37424 .07844 L

.37283 .08052 L

.37141 .08266 L

.37 .08486 L

.36859 .08714 L

.36718 .08949 L

.36576 .09191 L

.36435 .09441 L

.36294 .09699 L

.36152 .09965 L

.36011 .1024 L

.3587 .10525 L

.35728 .1082 L

.35587 .11125 L

.35446 .1144 L

.35305 .11768 L

.35163 .12107 L

.35022 .1246 L

.34881 .12827 L

.34739 .13208 L

.34598 .13605 L

.34457 .1402 L

.34315 .14453 L

.34174 .14907 L

Mistroke

.34033 .15382 L

.33891 .15882 L

.3375 .16409 L

.33609 .16967 L

.33468 .17558 L

.33326 .18189 L

.33185 .18865 L

.33044 .19594 L

.32902 .20389 L

.32761 .21266 L

.3262 .22249 L

.32478 .2338 L

.32337 .24741 L

.32196 .26543 L

.32055 .30324 L

.32055 .30902 L

Mfstroke

1 0 0 r

.83729 .5225 m

.83743 .52128 L

.83757 .52024 L

.83771 .5193 L

.83786 .51842 L

.838 .51759 L

.83814 .51681 L

.83828 .51606 L

.83842 .51534 L

.83856 .51464 L

.8387 .51395 L

.83884 .51329 L

.83899 .51263 L

.83913 .51198 L

.83927 .51135 L

.83941 .51072 L

.83955 .51011 L

.83969 .5095 L

.83983 .5089 L

.83997 .50829 L

.84012 .50771 L

.84026 .50712 L

.8404 .50653 L

.84054 .50596 L

.84068 .50538 L

.84082 .50481 L

.84096 .50423 L

.8411 .50366 L

.84125 .5031 L

.84139 .50254 L

.84153 .50197 L

.84167 .50141 L

.84181 .50086 L

.84195 .5003 L

.84209 .49973 L

.84224 .49918 L

.84238 .49863 L

.84252 .49807 L

.84266 .49751 L

.8428 .49696 L

.84294 .4964 L

.84308 .49584 L

.84322 .49528 L

.84337 .49473 L

.84351 .49418 L

.84365 .49362 L

.84379 .49307 L

.84393 .4925 L

.84407 .49194 L

.84421 .49138 L

Mistroke

.84435 .49082 L

.8445 .49025 L

.84464 .48969 L

.84478 .48913 L

.84492 .48856 L

.84506 .48798 L

.8452 .48741 L

.84534 .48684 L

.84549 .48627 L

.84563 .48569 L

.84577 .48511 L

.84591 .48453 L

.84605 .48394 L

.84619 .48336 L

.84633 .48277 L

.84647 .48218 L

.84662 .4816 L

.84676 .48099 L

.8469 .4804 L

.84704 .4798 L

.84718 .47918 L

.84732 .47857 L

.84746 .47797 L

.8476 .47734 L

.84775 .47672 L

.84789 .4761 L

.84803 .47547 L

.84817 .47484 L

.84831 .4742 L

.84845 .47356 L

.84859 .47292 L

.84874 .47226 L

.84888 .47161 L

.84902 .47095 L

.84916 .47028 L

.8493 .46961 L

.84944 .46893 L

.84958 .46825 L

.84972 .46755 L

.84987 .46686 L

.85001 .46615 L

.85015 .46544 L

.85029 .46472 L

.85043 .46399 L

.85057 .46327 L

.85071 .46252 L

.85085 .46177 L

.851 .461 L

.85114 .46023 L

.85128 .45945 L

Mistroke

.85184 .45621 L

.85241 .45273 L

.85297 .44898 L

.85354 .44483 L

.8541 .4401 L

.85467 .4344 L

.85524 .42629 L

.85538 .42318 L

.85552 .4173 L

.85524 .40454 L

.85495 .40032 L

.85467 .39712 L

.85184 .3788 L

.84902 .36766 L

.84619 .35905 L

.84337 .35186 L

.84054 .3456 L

.83771 .34001 L

.83489 .33493 L

.83206 .33026 L

.82924 .32592 L

.82641 .32185 L

.82358 .31803 L

.82076 .31441 L

.81793 .31096 L

.81511 .30767 L

.81228 .30452 L

.80945 .30149 L

.80663 .29858 L

.8038 .29576 L

.80097 .29304 L

.79815 .2904 L

.79532 .28784 L

.7925 .28535 L

.78967 .28293 L

.78684 .28056 L

.78402 .27825 L

.78119 .276 L

.77837 .27379 L

.77554 .27163 L

.77271 .26952 L

.76989 .26744 L

.76706 .2654 L

.76424 .2634 L

.76141 .26143 L

.75858 .25949 L

.75576 .25758 L

.75293 .2557 L

.75011 .25385 L

.74728 .25202 L

Mistroke

.74445 .25021 L

.74163 .24843 L

.7388 .24667 L

.73598 .24493 L

.73315 .24321 L

.73032 .24151 L

.7275 .23983 L

.72467 .23817 L

.72185 .23652 L

.71902 .23488 L

.71619 .23326 L

.71337 .23166 L

.71054 .23007 L

.70772 .22849 L

.70489 .22692 L

.70206 .22537 L

.69924 .22383 L

.69641 .2223 L

.69358 .22078 L

.69076 .21927 L

.68793 .21777 L

.68511 .21627 L

.68228 .21479 L

.67945 .21332 L

.67663 .21185 L

.6738 .2104 L

.67098 .20895 L

.66815 .20751 L

.66532 .20607 L

.6625 .20465 L

.65967 .20323 L

.65685 .20182 L

.65402 .20041 L

.65119 .19901 L

.64837 .19762 L

.64554 .19623 L

.64272 .19485 L

.63989 .19347 L

.63706 .1921 L

.63424 .19074 L

.63141 .18938 L

.62859 .18803 L

.62576 .18668 L

.62293 .18534 L

.62011 .18401 L

.61728 .18268 L

.61446 .18135 L

.61163 .18003 L

.6088 .17871 L

.60598 .1774 L

Mistroke

.60315 .1761 L

.60032 .1748 L

.5975 .1735 L

.59467 .17222 L

.59185 .17093 L

.58902 .16965 L

.58619 .16838 L

.58337 .16711 L

.58054 .16585 L

.57772 .16459 L

.57489 .16334 L

.57206 .16209 L

.56924 .16085 L

.56641 .15961 L

.56359 .15838 L

.56076 .15716 L

.55793 .15594 L

.55511 .15472 L

.55228 .15352 L

.54946 .15231 L

.54663 .15112 L

.5438 .14993 L

.54098 .14874 L

.53815 .14756 L

.53533 .14639 L

.5325 .14522 L

.52967 .14406 L

.52685 .1429 L

.52402 .14175 L

.5212 .14061 L

.51837 .13947 L

.51554 .13834 L

.51272 .13721 L

.50989 .13609 L

.50707 .13497 L

.50424 .13387 L

.50141 .13276 L

.49859 .13167 L

.49576 .13058 L

.49293 .12949 L

.49011 .12841 L

.48728 .12734 L

.48446 .12627 L

.48163 .12521 L

.4788 .12416 L

.47598 .12311 L

.47315 .12207 L

.47033 .12103 L

.4675 .12 L

.46467 .11897 L

Mistroke

.46185 .11795 L

.45902 .11694 L

.4562 .11593 L

.45337 .11493 L

.45054 .11394 L

.44772 .11295 L

.44489 .11196 L

.44207 .11098 L

.43924 .11001 L

.43641 .10905 L

.43359 .10808 L

.43076 .10713 L

.42794 .10618 L

.42511 .10524 L

.42228 .1043 L

.41946 .10337 L

.41663 .10245 L

.41381 .10153 L

.41098 .10061 L

.40815 .09971 L

.40533 .09881 L

.4025 .09791 L

.39968 .09702 L

.39685 .09614 L

.39402 .09526 L

.3912 .09439 L

.38837 .09353 L

.38554 .09267 L

.38272 .09182 L

.37989 .09098 L

.37707 .09014 L

.37424 .08931 L

.37141 .08849 L

.36859 .08767 L

.36576 .08686 L

.36294 .08606 L

.36011 .08526 L

.35728 .08447 L

.35446 .08369 L

.35163 .08292 L

.34881 .08215 L

.34598 .0814 L

.34315 .08065 L

.34033 .07991 L

.3375 .07917 L

.33468 .07845 L

.33185 .07773 L

.32902 .07703 L

.3262 .07633 L

.32337 .07564 L

Mistroke

.32055 .07496 L

.31772 .07429 L

.31489 .07363 L

.31207 .07298 L

.30924 .07234 L

.30642 .07171 L

.30359 .0711 L

.30076 .07049 L

.29794 .06989 L

.29511 .06931 L

.29228 .06874 L

.28946 .06818 L

.28663 .06763 L

.28381 .0671 L

.28098 .06658 L

.27815 .06607 L

.27533 .06558 L

.2725 .0651 L

.26968 .06464 L

.26685 .06419 L

.26402 .06376 L

.2612 .06334 L

.25837 .06294 L

.25555 .06256 L

.25272 .06219 L

.24989 .06185 L

.24707 .06152 L

.24424 .06121 L

.24142 .06092 L

.23859 .06065 L

.23576 .0604 L

.23294 .06017 L

.23011 .05996 L

.22729 .05978 L

.22446 .05962 L

.22163 .05948 L

.21881 .05937 L

.21598 .05928 L

.21316 .05922 L

.21033 .05919 L

.2075 .05919 L

.20468 .05921 L

.20185 .05927 L

.19903 .05935 L

.1962 .05947 L

.19337 .05962 L

.19055 .05981 L

.18772 .06002 L

.18489 .06028 L

.18207 .06057 L

Mistroke

.17924 .0609 L

.17642 .06128 L

.17359 .06169 L

.17076 .06214 L

.16794 .06264 L

.16511 .06319 L

.16229 .06378 L

.15946 .06443 L

.15663 .06512 L

.15381 .06586 L

.15098 .06667 L

.14816 .06752 L

.14533 .06844 L

.1425 .06942 L

.13968 .07046 L

.13685 .07157 L

.13403 .07274 L

.1312 .07399 L

.12837 .07532 L

.12555 .07671 L

.12272 .0782 L

.1199 .07976 L

.11707 .08142 L

.11424 .08316 L

.11142 .08501 L

.10859 .08695 L

.10577 .089 L

.10294 .09116 L

.10011 .09344 L

.09729 .09584 L

.09446 .09837 L

.09163 .10104 L

.08881 .10386 L

.08598 .10683 L

.08316 .10997 L

.08033 .11328 L

.0775 .11677 L

.07468 .12047 L

.07185 .12439 L

.06903 .12853 L

.0662 .13294 L

.06337 .13762 L

.06055 .1426 L

.05772 .14792 L

.0549 .15362 L

.05207 .15974 L

.04924 .16635 L

.04642 .17351 L

.04359 .18133 L

.04077 .18995 L

Mistroke

.03794 .19955 L

.03511 .21043 L

.03229 .2231 L

.02946 .2385 L

.02664 .25911 L

.02381 .29745 L

.02381 .30902 L

Mfstroke

.83729 .09553 m

.83743 .09675 L

.83757 .0978 L

.83771 .09874 L

.83786 .09962 L

.838 .10044 L

.83814 .10123 L

.83828 .10197 L

.83842 .10269 L

.83856 .1034 L

.8387 .10408 L

.83884 .10475 L

.83899 .1054 L

.83913 .10605 L

.83927 .10668 L

.83941 .10731 L

.83955 .10792 L

.83969 .10853 L

.83983 .10914 L

.83997 .10974 L

.84012 .11033 L

.84026 .11092 L

.8404 .1115 L

.84054 .11208 L

.84068 .11265 L

.84082 .11323 L

.84096 .11381 L

.8411 .11438 L

.84125 .11493 L

.84139 .1155 L

.84153 .11606 L

.84167 .11662 L

.84181 .11718 L

.84195 .11774 L

.84209 .1183 L

.84224 .11885 L

.84238 .11941 L

.84252 .11996 L

.84266 .12052 L

.8428 .12108 L

.84294 .12163 L

.84308 .1222 L

.84322 .12275 L

.84337 .1233 L

.84351 .12385 L

.84365 .12441 L

.84379 .12497 L

.84393 .12553 L

.84407 .1261 L

.84421 .12665 L

Mistroke

.84435 .12722 L

.8445 .12778 L

.84464 .12835 L

.84478 .1289 L

.84492 .12947 L

.84506 .13005 L

.8452 .13062 L

.84534 .13119 L

.84549 .13177 L

.84563 .13234 L

.84577 .13293 L

.84591 .13351 L

.84605 .13409 L

.84619 .13468 L

.84633 .13526 L

.84647 .13586 L

.84662 .13644 L

.84676 .13705 L

.8469 .13763 L

.84704 .13824 L

.84718 .13885 L

.84732 .13946 L

.84746 .14007 L

.8476 .14069 L

.84775 .14131 L

.84789 .14193 L

.84803 .14256 L

.84817 .1432 L

.84831 .14383 L

.84845 .14447 L

.84859 .14512 L

.84874 .14577 L

.84888 .14643 L

.84902 .14709 L

.84916 .14775 L

.8493 .14843 L

.84944 .1491 L

.84958 .14979 L

.84972 .15048 L

.84987 .15117 L

.85001 .15188 L

.85015 .15259 L

.85029 .15331 L

.85043 .15404 L

.85057 .15477 L

.85071 .15552 L

.85085 .15627 L

.851 .15703 L

.85114 .1578 L

.85128 .15858 L

Mistroke

.85184 .16183 L

.85241 .1653 L

.85297 .16906 L

.85354 .1732 L

.8541 .17794 L

.85467 .18364 L

.85524 .19175 L

.85538 .19486 L

.85552 .20074 L

.85524 .2135 L

.85495 .21771 L

.85467 .22091 L

.85184 .23923 L

.84902 .25037 L

.84619 .25898 L

.84337 .26618 L

.84054 .27244 L

.83771 .27803 L

.83489 .28311 L

.83206 .28778 L

.82924 .29212 L

.82641 .29618 L

.82358 .30001 L

.82076 .30363 L

.81793 .30708 L

.81511 .31036 L

.81228 .31352 L

.80945 .31654 L

.80663 .31946 L

.8038 .32227 L

.80097 .325 L

.79815 .32763 L

.79532 .3302 L

.7925 .33269 L

.78967 .33511 L

.78684 .33747 L

.78402 .33978 L

.78119 .34203 L

.77837 .34424 L

.77554 .3464 L

.77271 .34852 L

.76989 .3506 L

.76706 .35263 L

.76424 .35464 L

.76141 .35661 L

.75858 .35855 L

.75576 .36046 L

.75293 .36234 L

.75011 .36419 L

.74728 .36602 L

Mistroke

.74445 .36782 L

.74163 .3696 L

.7388 .37136 L

.73598 .3731 L

.73315 .37482 L

.73032 .37652 L

.7275 .3782 L

.72467 .37987 L

.72185 .38152 L

.71902 .38315 L

.71619 .38477 L

.71337 .38638 L

.71054 .38797 L

.70772 .38954 L

.70489 .39111 L

.70206 .39266 L

.69924 .39421 L

.69641 .39574 L

.69358 .39726 L

.69076 .39877 L

.68793 .40027 L

.68511 .40176 L

.68228 .40324 L

.67945 .40471 L

.67663 .40618 L

.6738 .40764 L

.67098 .40908 L

.66815 .41053 L

.66532 .41196 L

.6625 .41339 L

.65967 .41481 L

.65685 .41622 L

.65402 .41762 L

.65119 .41902 L

.64837 .42042 L

.64554 .4218 L

.64272 .42318 L

.63989 .42456 L

.63706 .42593 L

.63424 .42729 L

.63141 .42865 L

.62859 .43 L

.62576 .43135 L

.62293 .43269 L

.62011 .43403 L

.61728 .43536 L

.61446 .43668 L

.61163 .438 L

.6088 .43932 L

.60598 .44063 L

Mistroke

.60315 .44193 L

.60032 .44323 L

.5975 .44453 L

.59467 .44582 L

.59185 .4471 L

.58902 .44838 L

.58619 .44965 L

.58337 .45092 L

.58054 .45219 L

.57772 .45344 L

.57489 .4547 L

.57206 .45594 L

.56924 .45718 L

.56641 .45842 L

.56359 .45965 L

.56076 .46088 L

.55793 .4621 L

.55511 .46331 L

.55228 .46452 L

.54946 .46572 L

.54663 .46692 L

.5438 .46811 L

.54098 .46929 L

.53815 .47047 L

.53533 .47165 L

.5325 .47281 L

.52967 .47398 L

.52685 .47513 L

.52402 .47628 L

.5212 .47743 L

.51837 .47857 L

.51554 .4797 L

.51272 .48082 L

.50989 .48195 L

.50707 .48306 L

.50424 .48417 L

.50141 .48527 L

.49859 .48637 L

.49576 .48746 L

.49293 .48854 L

.49011 .48962 L

.48728 .49069 L

.48446 .49176 L

.48163 .49282 L

.4788 .49388 L

.47598 .49492 L

.47315 .49597 L

.47033 .497 L

.4675 .49804 L

.46467 .49906 L

Mistroke

.46185 .50008 L

.45902 .50109 L

.4562 .5021 L

.45337 .5031 L

.45054 .5041 L

.44772 .50509 L

.44489 .50607 L

.44207 .50705 L

.43924 .50802 L

.43641 .50899 L

.43359 .50995 L

.43076 .5109 L

.42794 .51185 L

.42511 .5128 L

.42228 .51373 L

.41946 .51466 L

.41663 .51559 L

.41381 .51651 L

.41098 .51742 L

.40815 .51833 L

.40533 .51923 L

.4025 .52012 L

.39968 .52101 L

.39685 .52189 L

.39402 .52277 L

.3912 .52364 L

.38837 .5245 L

.38554 .52536 L

.38272 .52621 L

.37989 .52706 L

.37707 .52789 L

.37424 .52872 L

.37141 .52955 L

.36859 .53036 L

.36576 .53117 L

.36294 .53198 L

.36011 .53277 L

.35728 .53356 L

.35446 .53434 L

.35163 .53511 L

.34881 .53588 L

.34598 .53664 L

.34315 .53739 L

.34033 .53813 L

.3375 .53886 L

.33468 .53958 L

.33185 .5403 L

.32902 .54101 L

.3262 .54171 L

.32337 .54239 L

Mistroke

.32055 .54307 L

.31772 .54374 L

.31489 .5444 L

.31207 .54505 L

.30924 .54569 L

.30642 .54632 L

.30359 .54694 L

.30076 .54754 L

.29794 .54814 L

.29511 .54872 L

.29228 .54929 L

.28946 .54985 L

.28663 .5504 L

.28381 .55093 L

.28098 .55145 L

.27815 .55196 L

.27533 .55245 L

.2725 .55293 L

.26968 .5534 L

.26685 .55384 L

.26402 .55428 L

.2612 .55469 L

.25837 .55509 L

.25555 .55548 L

.25272 .55584 L

.24989 .55619 L

.24707 .55652 L

.24424 .55683 L

.24142 .55712 L

.23859 .55739 L

.23576 .55764 L

.23294 .55787 L

.23011 .55807 L

.22729 .55826 L

.22446 .55842 L

.22163 .55855 L

.21881 .55867 L

.21598 .55875 L

.21316 .55881 L

.21033 .55884 L

.2075 .55885 L

.20468 .55882 L

.20185 .55877 L

.19903 .55868 L

.1962 .55856 L

.19337 .55841 L

.19055 .55823 L

.18772 .55801 L

.18489 .55775 L

.18207 .55746 L

Mistroke

.17924 .55713 L

.17642 .55676 L

.17359 .55635 L

.17076 .55589 L

.16794 .55539 L

.16511 .55485 L

.16229 .55425 L

.15946 .55361 L

.15663 .55291 L

.15381 .55217 L

.15098 .55137 L

.14816 .55051 L

.14533 .54959 L

.1425 .54862 L

.13968 .54757 L

.13685 .54646 L

.13403 .54529 L

.1312 .54404 L

.12837 .54272 L

.12555 .54132 L

.12272 .53984 L

.1199 .53827 L

.11707 .53662 L

.11424 .53487 L

.11142 .53303 L

.10859 .53108 L

.10577 .52903 L

.10294 .52687 L

.10011 .52459 L

.09729 .52219 L

.09446 .51966 L

.09163 .51699 L

.08881 .51417 L

.08598 .5112 L

.08316 .50807 L

.08033 .50476 L

.0775 .50126 L

.07468 .49756 L

.07185 .49365 L

.06903 .4895 L

.0662 .4851 L

.06337 .48042 L

.06055 .47543 L

.05772 .47011 L

.0549 .46441 L

.05207 .45829 L

.04924 .45169 L

.04642 .44452 L

.04359 .4367 L

.04077 .42809 L

Mistroke

.03794 .41849 L

.03511 .4076 L

.03229 .39494 L

.02946 .37954 L

.02664 .35892 L

.02381 .32058 L

.02381 .30902 L

Mfstroke

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{567, 350.313},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.776525,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008g0001GPP10`40000100000800002008200000

P800P020P<30`<3L`:K:l00003<006H009T00<`00?l0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV

09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<003o03?o06Ko09Wo0<co

0?oo0000<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I

<c>I<fJI<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0

IYT0I/`0I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bI

I_nIIP3<IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0c

VC<cVFHcVITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<

VIW<VLc<VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`c

c?lcc01Vc3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03o

c3?oc6Koc9Woc<coc?ooc000oc<0ofH0oiT0ol`0ool0o`0coc<cofHcoiTcol`coolco`1Voc=VofIV

oiUVolaVoomVo`2Ioc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<o`3ooc?oofKooiWoolco

ooooo`0000410@820P<30`@410D51@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C

4a@D5?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooe3Q00<0hN40on7Uh@00D>400`3Qh@3ohNGQ

001@h@030>7Q0?oQiN40053Q00<0hN40on7Uh@00D>400`3Qh@3ohNGQ001@h@<0on7Uh@00D>400`3Q

h@3ohNGQ001@h@030>7Q0?oQiN40053Q00<0hN40]>4M__oQ5>40053Q00<0hN40[>48_QgQ2Kkoh@_Q

001@h@030>7Q0:SQ1Kh]h@Nnon44h@00D>400`3Qh@2Th@Bn>>47__gQ001@h@030>7Q0:7Q0ki2h@Fn

nN40053Q00<0hN40W^43_T[Q1;keh@00D>400`3Qh@2Lh@:nD>44__;Q001@h@030>7Q09WQ0kiFh@:n

l>40053Q00<0hN40Un43_U[Q0kk]h@00D>4309GQ0[iPh@:njn40053Q00<0hN40U>400kkQh@1Rh@03

_^7Q0>SQ001@h@030>7Q097Q0kiVh@:nj>40053Q00<0hN40T>42_V[Q00>nhN40iN40053Q00<0hN40

S^42_VgQ00>nhN40i>40053Q00<0hN40SN42_VoQ00>nhN40hn40053Q00<0hN40S>400kkQh@1_h@03

_^7Q0>?Q001@h@030>7Q08_Q00>nhN40LN400kkQh@3Rh@00D>400`3Qh@29h@:nMN400kkQh@3Qh@00

D>400`3Qh@29h@03_^7Q07GQ00>nhN40h>40053Q00<0hN40Qn42_WSQ00>nhN40h>40053Q00<0hN40

Q^400kkQh@1ih@03_^7Q0=oQ001@h@<0QN42_WcQ00>nhN40g^40053Q00<0hN40Q>400kkQh@1lh@03

_^7Q0=kQ001@h@030>7Q01WQ70m>h@03_^7Q07kQ00>nhN40gN40053Q00<0hN404^473acQ20m5h@:n

P>400kkQh@3Mh@00D>400`3Qh@0=h@D?:n483ccQ00>nhN40PN400kkQh@3Lh@00D>400`3Qh@09h@@?

>>463cGQ00>nhN40Pn400kkQh@3Kh@00D>400`3Qh@06h@<?@^443c7Q00>nhN40Q>400kkQh@3Jh@00

D>400`3Qh@03h@<?BN463b[Q00>nhN40QN400kkQh@3Jh@00D>400`3Qh@033e;Q10lUh@03_^7Q08OQ

00>nhN40fN4003oQ1@02h@030>7Q00OQ00<0h@l0FN453b3Q00>nhN40R>400kkQh@3Hh@00@N401`3Q

hN40h@001n433eoQ10lKh@03_^7Q08WQ0[kIh@00>n4300?Q00L0hN7Q0>4000GQ0Pl00n400002067Q

10lFh@03_^7Q08cQ00>nhN40Hn4D3eoQ0011h@070>7Qh@3Q0004h@053n7Qh@00J>433a;Q00>nhN40

S^400kkQh@1Ph@8?5>473eSQ0011h@080>7Qh@3Q0>433`CQ00<0hN40JN453`gQ00>nhN40S^42_V3Q

00<?hN406n473e7Q0010h@801>400`3Q3`07h@030>7Q06kQ0`l9h@03_^7Q097Q00>nhN40Fn423bGQ

1Pm;h@00A^423`SQ00<0hN40LN443`CQ00>nhN40Tn400kkQh@1Jh@033n7Q02[Q20m3h@00AN400`oQ

h@08h@030>7Q07GQ0`l00kkQh@2Eh@03_^7Q05SQ0Pldh@D??^4004?Q0Pl;h@030>7Q07SQ10nEh@03

_^7Q05OQ00<?hN40>>463cSQ0012h@033n7Q00_Q00<0hN40N>401;kQhN433i?Q0[jHh@P?<>40047Q

00<?hN403>400`3Qh@1gh@03_^7Q00GQ0`nBh@03_^7Q0<gQ0010h@033n7Q00gQ00<0hN40M^400kkQ

h@09h@<?T>42_/gQ000oh@033n7Q00kQ00<0hN40MN400kkQh@0=h@D?SN400kkQh@1Ah@033n7Q07KQ

000mh@8?4N400`3Qh@1eh@03_^7Q01;Q0Pn<h@:nDN423gOQ000lh@033n7Q017Q0`1eh@03_^7Q01CQ

0`n;h@03_^7Q04oQ00<?hN40MN4003cQ00<?hN404N400`3Qh@1dh@03_^7Q01SQ0`n9h@:nCn400`oQ

h@1eh@00>^423aCQ00<0hN40Ln400kkQh@0Lh@<?Qn43_TgQ00<?hN40MN4003WQ00<?hN405>400`3Q

h@1ch@03_^7Q01oQ0`n7h@03_^7Q04[Q00<?hN40MN4003WQ00<?hN405>400`3Qh@1ch@03_^7Q02;Q

0`n5h@:nB^423gKQ000gh@8?5n400`3Qh@1bh@03_^7Q02KQ0`n4h@:nBN400`oQh@1dh@00=^400`oQ

h@0Gh@030>7Q07;Q00>nhN40:N433h?Q0[i7h@033n7Q07CQ000fh@033n7Q01OQ00<0hN40LN400kkQ

h@0]h@<?P^42_TGQ00<?hN40M>4003GQ00<?hN406>400`3Qh@1`h@03_^7Q037Q0`n0h@>n@n423gGQ

000eh@033n7Q01SQ00<0hN40L>400kkQh@0dh@<?P>42_T;Q00<?hN40Ln4003CQ00<?hN406N400`3Q

h@1`h@03_^7Q03OQ0`moh@:n@>400`oQh@1ch@00<n400`oQh@0Jh@030>7Q073Q00>nhN40>^433gkQ

0khmh@033n7Q07?Q000bh@033n7Q01_Q0`1_h@03_^7Q03kQ00<?hN40ON43_S_Q0Pmdh@00<^400`oQ

h@0Kh@030>7Q06oQ00>nhN40?n433goQ0khih@033n7Q07;Q000ah@033n7Q01cQ00<0hN40K^400kkQ

h@13h@<?O^43_SOQ00<?hN40L^40033Q00<?hN407N400`3Qh@1^h@03_^7Q04KQ0`mnh@>n=>400`oQ

h@1bh@00;n400`oQh@0Nh@030>7Q06gQ00>nhN40B^433gkQ0[hbh@8?Ln4002oQ00<?hN407^400`3Q

h@1]h@03_^7Q04gQ00<?hN40ON43_S3Q00<?hN40LN4002kQ00<?hN407n400`3Qh@1]h@03_^7Q04kQ

0`moh@:n;^400`oQh@1ah@00;^400`oQh@0Oh@030>7Q06gQ00>nhN40DN433gkQ0kh[h@033n7Q077Q

000]h@033n7Q023Q00<0hN40K>400kkQh@1Eh@<?O^43_RSQ0Pmbh@00;>400`oQh@0Qh@030>7Q06cQ

00>nhN40F>423goQ0khVh@033n7Q073Q000/h@033n7Q027Q00<0hN40Jn400kkQh@1Kh@8?P>43_R?Q

00<?hN40L>4002_Q00<?hN408^400`3Qh@1[h@03_^7Q05gQ0`n0h@>n8>400`oQh@1`h@00:n400`oQ

h@0Rh@<0J^400kkQh@1Qh@8?P>44_QgQ00<?hN40L>4002[Q00<?hN408n400`3Qh@1Zh@03_^7Q06?Q

0`n1h@>n6n400`oQh@1_h@00:^400`oQh@0Sh@030>7Q06[Q00>nhN40I^400`oQh@21h@>n6>400`oQ

h@1_h@00:N400`oQh@0Th@030>7Q06[Q00>nhN40In433h?Q1;hDh@033n7Q06oQ000Yh@033n7Q02CQ

00<0hN40J^400kkQh@1Zh@<?Q>43_Q7Q00<?hN40Kn4002SQ00<?hN409N400`3Qh@1Zh@03_^7Q06gQ

0Pn5h@Bn3N400`oQh@1_h@00:>400`oQh@0Uh@030>7Q06WQ00>nhN40L>423hKQ1;h:h@8?L>4002OQ

00<?hN409^400`3Qh@1Yh@03_^7Q07;Q0Pn8h@>n2>400`oQh@1^h@009n400`oQh@0Vh@030>7Q06SQ

00>nhN40MN433hSQ1;h4h@033n7Q06kQ000Vh@033n7Q02OQ00<0hN40J>400kkQh@1hh@033n7Q08WQ

0kh00n4?h@1_h@009^400`oQh@0Wh@030>7Q06SQ00>nhN40NN433h_Q00Bn3kjnK^4002GQ00<?hN40

:>400`3Qh@1Xh@03_^7Q07cQ0`n9h@033n7Q00BnJ^4002GQ00<?hN40:>4306SQ00>nhN40On423hOQ

00<?hN401>44_VKQ000Th@033n7Q02WQ00<0hN40J>400kkQh@21h@<?Q>400`oQh@08h@BnH^4002CQ

00<?hN40:N400`3Qh@1Wh@03_^7Q08GQ00<?hN40P^400`oQh@0;h@>nGn4002CQ00<?hN40:N400`3Q

h@1Wh@03_^7Q08KQ0`n1h@033n7Q00kQ1KiJh@008n400`oQh@0Zh@030>7Q06OQ00>nhN40RN400`oQ

h@1nh@033n7Q01?Q1;iFh@008n400`oQh@0Zh@030>7Q06KQ00>nhN40Rn423gkQ00<?hN405^45_U;Q

000Sh@033n7Q02[Q00<0hN40I^400kkQh@2=h@<?Nn400`oQh@0Kh@BnC^4002?Q00<?hN40:^400`3Q

h@1Vh@03_^7Q093Q00<?hN40N>400`oQh@0Oh@BnB^4002;Q00<?hN40:n400`3Qh@1Uh@03_^7Q09;Q

0`mgh@033n7Q02?Q1;i6h@008^400`oQh@0[h@030>7Q06GQ00>nhN40UN423gGQ00<?hN409n45_T7Q

000Qh@033n7Q02;Q00<0hN401n400`3Qh@1Uh@03_^7Q09OQ0`mch@033n7Q02_Q1;hmh@008N400`oQ

h@0Qh@030>4000SQ00<0hN40IN400kkQh@2Jh@033n7Q073Q00<?hN40;n45_SSQ000Qh@033n7Q01cQ

0`04h@030>7Q00KQ101Th@03_^7Q09_Q0`m_h@033n7Q03?Q1Khdh@008N400`oQh@0Qh@802N400`3Q

h@1Uh@03_^7Q09kQ0Pm]h@033n7Q03SQ1;h`h@008>400`oQh@0Rh@030>7Q00SQ00<0hN40IN400kkQ

h@2Ph@033n7Q06[Q00<?hN40K>40023Q00<?hN408^4300SQ00<0hN40IN400kkQh@2Qh@<?JN400`oQ

h@1/h@008>400`oQh@0]h@030>7Q06CQ00>nhN40YN400`oQh@1Vh@033n7Q06cQ000Ph@033n7Q02gQ

00<0hN40I>400kkQh@2Vh@8?I^400`oQh@1/h@008>400`oQh@0]h@030>7Q06CQ00>nhN40Z>433f?Q

00<?hN40K>4001oQ00<?hN40;^400`3Qh@1Th@03_^7Q0:_Q00<?hN40H>400`oQh@1/h@007n400`oQ

h@0^h@030>7Q06?Q00>nhN40[N433eoQ00<?hN40K>4001oQ00<?hN40;^400`3Qh@1Sh@03_^7Q0;3Q

0PmMh@033n7Q06cQ000Oh@033n7Q02kQ00<0hN40Hn400kkQh@2bh@033n7Q05[Q00<?hN40K>4001kQ

00<?hN40;n400`3Qh@1Sh@03_^7Q0;?Q0PmJh@033n7Q06cQ000Nh@033n7Q02oQ0`1Sh@03_^7Q0;GQ

0PmHh@033n7Q06cQ000Nh@033n7Q02oQ00<0hN40H^400kkQh@2hh@8?E^400`oQh@1/h@007^400`oQ

h@0_h@030>7Q06;Q00>nhN40^^400`oQh@1Bh@033n7Q06gQ000Mh@033n7Q033Q00<0hN40H^400kkQ

h@2kh@<?DN400`oQh@1]h@007N400`oQh@0`h@030>7Q06;Q00>nhN40_^423doQ00<?hN40KN4001gQ

00<?hN40<>400`3Qh@1Rh@03_^7Q0<3Q00<?hN40C>400`oQh@1]h@007N400`oQh@0`h@030>7Q06;Q

00>nhN40`N423dcQ00<?hN40KN4001gQ00<?hN40<>400`3Qh@1Rh@03_^7Q0<?Q0`m9h@033n7Q06gQ

000Lh@033n7Q037Q00<0hN40H^400kkQh@36h@033n7Q04GQ00<?hN40K^4001cQ00<?hN40<N400`3Q

h@1Rh@03_^7Q0<OQ0Pm5h@033n7Q06kQ000Lh@033n7Q037Q00<0hN40H^400kkQh@39h@033n7Q04;Q

00<?hN40K^4001cQ00<?hN40<N400`3Qh@1Rh@03_^7Q0<[Q0Pm2h@033n7Q06kQ000Lh@033n7Q037Q

0`1Rh@03_^7Q0<cQ00<?hN40?n400`oQh@1^h@007>400`oQh@0ah@030>7Q067Q00>nhN40c^433ckQ

00<?hN40K^4001cQ00<?hN40<N400`3Qh@1Qh@03_^7Q0=7Q00<?hN40>^400`oQh@1_h@006n400`oQ

h@0bh@030>7Q067Q00>nhN40d^423c[Q00<?hN40Kn4001_Q00<?hN40<^400`3Qh@1Qh@03_^7Q0=CQ

00<?hN40=n400`oQh@1_h@006n400`oQh@0bh@030>7Q067Q00>nhN40eN423cKQ00<?hN40L>4001_Q

00<?hN40<^400`3Qh@1Qh@03_^7Q0=OQ00<?hN40<n400`oQh@1`h@006n400`oQh@0bh@030>7Q067Q

00>nhN40f>423c?Q00<?hN40L>4001[Q00<?hN40<n400`3Qh@1Qh@03_^7Q0=[Q00<?hN40;n400`oQ

h@1ah@006^400`oQh@0ch@030>7Q063Q00>nhN40g>423boQ00<?hN40LN4001[Q00<?hN40<n400`3Q

h@1Ph@03_^7Q0=kQ00<?hN40;>400`oQh@1ah@006^400`oQh@0ch@030>7Q063Q00>nhN40gn423bcQ

00<?hN40LN4001[Q00<?hN40<n43063Q00>nhN40hN400`oQh@0Xh@033n7Q07;Q000Jh@033n7Q03?Q

00<0hN40H>400kkQh@3Rh@033n7Q02OQ00<?hN40L^4001[Q00<?hN40<n400`3Qh@1Ph@03_^7Q0>?Q

0PlWh@033n7Q07;Q000Jh@033n7Q03?Q00<0hN40H>400kkQh@3Uh@033n7Q02?Q00<?hN40Ln4001[Q

00<?hN40<n400`3Qh@1Ph@03_^7Q0>KQ0PlSh@033n7Q07?Q000Jh@033n7Q03?Q00<0hN40H>400kkQ

h@3Xh@033n7Q01oQ00<?hN40M>4001[Q00<?hN40<n400`3Qh@1Ph@03_^7Q0>WQ0PlOh@033n7Q07CQ

000Jh@033n7Q03?Q00<0hN40H>400kkQh@3[h@033n7Q01_Q00<?hN40MN4001WQ00<?hN40=>400`3Q

h@1Ph@03_^7Q0>cQ0PlKh@033n7Q07GQ000Ih@033n7Q03CQ00<0hN40H>400kkQh@3]h@033n7Q01SQ

00<?hN40M^4001WQ00<?hN40=>400`3Qh@11h@D00^400`3Qh@0Eh@03_^7Q02OQ1@000n400011h@D0

0^400`3Qh@10h@D00^400`3Qh@0Zh@033n7Q01;Q1@000`l00012h@<00n400`3Qh@0[h@006N400`oQ

h@0dh@030>7Q04?Q00L0hN7Q0>4001KQ00>nhN40:N401`3QhN40h@00@^400`3Qh@02h@030>7Q04;Q

00L0hN7Q0>4002cQ0PlDh@030>4?00?Q00<0hN40?n400`3Qh@02h@030>4002cQ000Ih@033n7Q03CQ

0`13h@030>7Q00?Q00<0hN405>400kkQh@0Yh@070>7Qh@3Q0012h@030>7Q00;Q00<0hN40@^401`3Q

hN40h@00;^400`oQh@0Ah@0300oQ00;Q0P12h@070>7Qh@3Q000/h@006N400`oQh@0dh@030>7Q04?Q

00@0hN7Q0P0Gh@03_^7Q02WQ00@0hN7Q0P13h@030>7Q00?Q00<0hN40@N400`3Qh@02h@030>7Q02kQ

0PlAh@0700oQh@3Q0012h@070>7Qh@3Q000/h@006N400`oQh@0dh@030>7Q04?Q00D0hN7Q000Hh@03

_^7Q02WQ00D0hN7Q0014h@070>7Qh@3Q0013h@070>7Qh@3Q000`h@033n7Q00oQ00L?hN7Q0>40047Q

00<0h@000^400`3Q000/h@006N400`oQh@0dh@030>7Q04;Q0P03h@<05^400kkQh@0Xh@801>42047Q

0P03h@<0@^4200CQ00<0hN40<>400`oQh@0=h@0300oQ00?Q0P12h@030>7Q00;Q00<0hN40:n4001WQ

00<?hN40=>400`3Qh@1Ph@03_^7Q0?GQ0Pl=h@033n7Q07[Q000Ih@033n7Q03CQ00<0hN40H>400kkQ

h@3gh@033n7Q00WQ00<?hN40Nn4001WQ00<?hN40=>400`3Qh@1Ph@03_^7Q0?OQ00<?hN402N400`oQ

h@1kh@006N400`oQh@0dh@030>7Q063Q00>nhN40n>400`oQh@07h@033n7Q07cQ000Ih@033n7Q03CQ

00<0hN40H>400kkQh@3ih@8?1^400`oQh@1mh@006N400`oQh@0dh@030>7Q063Q00>nhN40n^400`oQ

h@03h@033n7Q07kQ000Ih@033n7Q03CQ00<0hN40H>400kkQh@3kh@033n7Q00;Q00<?hN40J^44013Q

000Ih@033n7Q03CQ00<0hN40H>400kkQh@3lh@043n4?3fgQ0`0Ah@003>4=00033`0009L000>n0000

o@000`l0001N017Q00<0hN403n4001GQ00D0hN7Q3`0:h@030>7Q00_Q00<0hN403>400`3Qh@0<h@03

0>7Q00_Q00<0hN403>400`3Qh@0<h@030>7Q00_Q00<0hN403>400`3Qh@0<h@030>7Q00SQ00BnhN40

3^400`3Qh@0;h@030>7Q00cQ00<0hN403>400`3Qh@0;h@030>7Q00cQ00<0hN403>400`3Qh@0;h@03

0>7Q00cQ00<0hN403>400`3Qh@0;h@030>7Q00cQ00<0hN403>400`3Qh@0;h@030>7Q00cQ00<0hN40

3>400`3Qh@0;h@040>7Qh@8?2N400`3Qh@0;h@030>7Q00cQ00<0hN403>400`3Qh@0;h@030>7Q00cQ

00<0hN406^42017Q000Eh@050>7Qh@l02^400`3Qh@0;h@030>7Q00cQ00<0hN403>400`3Qh@0;h@03

0>7Q00cQ00<0hN403>400`3Qh@0;h@030>7Q00cQ00<0hN403>400`3Qh@08h@04_^7Q00kQ00<0hN40

2n400`3Qh@0<h@030>7Q00cQ00<0hN402n400`3Qh@0<h@030>7Q00cQ00<0hN402n400`3Qh@0<h@03

0>7Q00cQ00<0hN402n400`3Qh@0<h@030>7Q00cQ00<0hN402n400`3Qh@0<h@030>7Q00cQ00<0hN40

2n40103Qh@l2h@033n7Q00KQ00<0hN402n400`3Qh@0<h@030>7Q00cQ00<0hN402n400`3Qh@0<h@03

0>7Q02gQ000Ih@033n7Q03CQ00<0hN40A^400`3Qh@0Gh@03_^7Q02cQ00<0hN40A^400`3Qh@17h@03

0>7Q03WQ00<?hN400^400`oQh@05h@030>7Q04KQ00<0hN40;N4001WQ00<?hN40=>400`3Qh@16h@03

0>7Q01OQ00>nhN40;>400`3Qh@16h@030>7Q04OQ00<0hN40>>400`oQh@03h@033n7Q00GQ00<0hN40

A^400`3Qh@0]h@006N400`oQh@0dh@030>7Q063Q00>nhN40nN400`oQh@05h@033n7Q07gQ000Ih@03

3n7Q03CQ00<0hN40H>400kkQh@3hh@033n7Q00OQ00<?hN40O>4001WQ00<?hN40=>400`3Qh@1Ph@03

_^7Q0?OQ00<?hN402N400`oQh@1kh@006N400`oQh@0dh@030>7Q063Q00>nhN40m^400`oQh@0:h@03

3n7Q07_Q000Ih@033n7Q03CQ00<0hN40H>400kkQh@3fh@033n7Q00_Q00<?hN40N^4001WQ00<?hN40

=>400`3Qh@1Ph@03_^7Q0?CQ0Pl?h@033n7Q07WQ000Ih@033n7Q03CQ00<0hN40H>400kkQh@3ch@03

3n7Q013Q00<?hN40N>4001WQ00<?hN40=>43063Q00>nhN40l^400`oQh@0Ah@033n7Q07SQ000Ih@03

3n7Q03CQ00<0hN40H>400kkQh@3ah@033n7Q01?Q00<?hN40Mn4001WQ00<?hN40=>400`3Qh@1Ph@03

_^7Q0?3Q00<?hN405>400`oQh@1gh@006N400`oQh@0dh@030>7Q063Q00>nhN40k^423aSQ00<?hN40

M^4001WQ00<?hN40=>400`3Qh@1Ph@03_^7Q0>gQ00<?hN406N400`oQh@1eh@006^400`oQh@0ch@03

0>7Q063Q00>nhN40jn423acQ00<?hN40MN4001[Q00<?hN40<n400`3Qh@1Ph@03_^7Q0>[Q00<?hN40

7N400`oQh@1dh@006^400`oQh@0ch@030>7Q063Q00>nhN40j^400`oQh@0Mh@033n7Q07CQ000Jh@03

3n7Q03?Q00<0hN40H>400kkQh@3Xh@8?8>400`oQh@1dh@006^400`oQh@0ch@030>7Q063Q00>nhN40

in400`oQh@0Qh@033n7Q07?Q000Jh@033n7Q03?Q00<0hN40H>400kkQh@3Uh@8?9>400`oQh@1ch@00

6^400`oQh@0ch@030>7Q063Q00>nhN40i>400`oQh@0Uh@033n7Q07;Q000Jh@033n7Q03?Q0`1Ph@03

_^7Q0>;Q0PlXh@033n7Q07;Q000Jh@033n7Q03?Q00<0hN40H>400kkQh@3Qh@033n7Q02WQ00<?hN40

LN4001[Q00<?hN40<n400`3Qh@1Ph@03_^7Q0>3Q00<?hN40:^400`oQh@1ah@006^400`oQh@0ch@03

0>7Q063Q00>nhN40g^423bgQ00<?hN40LN4001[Q00<?hN40<n400`3Qh@1Qh@03_^7Q0=cQ00<?hN40

;N400`oQh@1ah@006n400`oQh@0bh@030>7Q067Q00>nhN40f^423c7Q00<?hN40L>4001_Q00<?hN40

<^400`3Qh@1Qh@03_^7Q0=WQ00<?hN40<N400`oQh@1`h@006n400`oQh@0bh@030>7Q067Q00>nhN40

en423cCQ00<?hN40L>4001_Q00<?hN40<^400`3Qh@1Qh@03_^7Q0=KQ00<?hN40=>400`oQh@1`h@00

6n400`oQh@0bh@030>7Q067Q00>nhN40e>423cSQ00<?hN40Kn4001_Q00<?hN40<^400`3Qh@1Qh@03

_^7Q0=7Q0`ljh@033n7Q06oQ000Lh@033n7Q037Q00<0hN40HN400kkQh@3@h@033n7Q03_Q00<?hN40

Kn4001cQ00<?hN40<N4306;Q00>nhN40cN423coQ00<?hN40K^4001cQ00<?hN40<N400`3Qh@1Rh@03

_^7Q0<cQ00<?hN40?n400`oQh@1^h@007>400`oQh@0ah@030>7Q06;Q00>nhN40bn400`oQh@10h@03

3n7Q06kQ000Lh@033n7Q037Q00<0hN40H^400kkQh@39h@8?@n400`oQh@1^h@007>400`oQh@0ah@03

0>7Q06;Q00>nhN40a^433dGQ00<?hN40K^4001cQ00<?hN40<N400`3Qh@1Rh@03_^7Q0<GQ00<?hN40

A^400`oQh@1^h@007N400`oQh@0`h@030>7Q06;Q00>nhN40`n423d[Q00<?hN40KN4001gQ00<?hN40

<>400`3Qh@1Rh@03_^7Q0<;Q00<?hN40B^400`oQh@1]h@007N400`oQh@0`h@030>7Q06;Q00>nhN40

`>423dgQ00<?hN40KN4001gQ00<?hN40<>400`3Qh@1Rh@03_^7Q0;gQ0`m?h@033n7Q06gQ000Mh@03

3n7Q033Q00<0hN40H^400kkQh@2lh@033n7Q053Q00<?hN40KN4001kQ00<?hN40;n400`3Qh@1Rh@03

_^7Q0;[Q0PmCh@033n7Q06gQ000Nh@033n7Q02oQ0`1Sh@03_^7Q0;KQ0`mFh@033n7Q06cQ000Nh@03

3n7Q02oQ00<0hN40Hn400kkQh@2eh@033n7Q05OQ00<?hN40K>4001oQ00<?hN40;^400`3Qh@1Sh@03

_^7Q0;CQ00<?hN40F>400`oQh@1/h@007n400`oQh@0^h@030>7Q06?Q00>nhN40/N433e_Q00<?hN40

K>4001oQ00<?hN40;^400`3Qh@1Sh@03_^7Q0:oQ0PmNh@033n7Q06cQ000Oh@033n7Q02kQ00<0hN40

I>400kkQh@2]h@033n7Q05kQ00<?hN40K>4001oQ00<?hN40;^400`3Qh@1Th@03_^7Q0:[Q0`mQh@03

3n7Q06cQ000Ph@033n7Q02gQ00<0hN40I>400kkQh@2Xh@8?I>400`oQh@1/h@008>400`oQh@0]h@03

0>7Q06CQ00>nhN40Yn400`oQh@1Th@033n7Q06cQ000Ph@033n7Q02gQ00<0hN40I>400kkQh@2Th@<?

In400`oQh@1/h@008>400`oQh@0Sh@030>7Q00OQ00<0hN40IN400kkQh@2Qh@8?J^400`oQh@1/h@00

8>400`oQh@0Rh@030>4000SQ00<0hN40IN400kkQh@2Ph@033n7Q06[Q00<?hN40>n400kkQh@0^h@00

8N400`oQh@0Sh@030>7Q00KQ101Th@03_^7Q09gQ0`m]h@033n7Q03OQ1Kh`h@008N400`oQh@0Qh@80

2N400`3Qh@1Uh@03_^7Q09cQ00<?hN40K^400`oQh@0ch@Bn=N40027Q00<?hN408N400`3Qh@08h@03

0>7Q06GQ00>nhN40VN433g7Q00<?hN40;^45_SWQ000Qh@033n7Q027Q0`08h@030>7Q06GQ00>nhN40

Un423g?Q00<?hN40:n44_SkQ000Rh@033n7Q02_Q00<0hN40IN400kkQh@2Dh@<?MN400`oQh@0Vh@Fn

@^4002;Q00<?hN40:n400`3Qh@1Vh@03_^7Q09;Q00<?hN40M^400`oQh@0Rh@FnA^4002?Q00<?hN40

:^400`3Qh@1Vh@03_^7Q093Q0Pmih@033n7Q01kQ1;i;h@008n400`oQh@0Zh@030>7Q06KQ00>nhN40

SN433g_Q00<?hN406N45_ToQ000Sh@033n7Q02[Q00<0hN40I^400kkQh@2<h@033n7Q07cQ00<?hN40

5^43_UCQ000Sh@033n7Q02[Q00<0hN40In400kkQh@28h@<?On400`oQh@0Ah@FnEn4002CQ00<?hN40

:N400`3Qh@1Wh@03_^7Q08OQ00<?hN40P>400`oQh@0=h@BnG>4002CQ00<?hN40:N400`3Qh@1Wh@03

_^7Q08CQ0`n3h@033n7Q00[Q1;iOh@009N400`oQh@0Xh@<0J>400kkQh@21h@8?QN400`oQh@06h@Fn

Hn4002GQ00<?hN40:>400`3Qh@1Xh@03_^7Q07kQ0`n7h@033n7Q00?Q1;iWh@009^400`oQh@0Wh@03

0>7Q06SQ00>nhN40ON400`oQh@28h@033n6n00>nJn4002KQ00<?hN409n400`3Qh@1Xh@03_^7Q07[Q

0`n9h@:n00<?_^40K^4002KQ00<?hN409n400`3Qh@1Xh@03_^7Q07SQ0Pn9h@Bn00?Q3n40Kn4002OQ

00<?hN409^400`3Qh@1Yh@03_^7Q07CQ0`n7h@Bn1N400`oQh@1^h@009n400`oQh@0Vh@030>7Q06WQ

00>nhN40LN433hKQ1;h9h@033n7Q06kQ000Xh@033n7Q02GQ00<0hN40JN400kkQh@1`h@033n7Q08GQ

0kh;h@8?L>4002SQ00<?hN409N400`3Qh@1Zh@03_^7Q06cQ0`n4h@Bn3^400`oQh@1_h@00:N400`oQ

h@0Th@030>7Q06[Q00>nhN40Jn400`oQh@21h@Bn4^400`oQh@1_h@00:N400`oQh@0Th@030>7Q06[Q

00>nhN40J>433h7Q0khFh@033n7Q06oQ000Zh@033n7Q02?Q00<0hN40J^400kkQh@1Uh@<?PN44_QSQ

00<?hN40Kn4002[Q00<?hN408n4306[Q00>nhN40Hn423h7Q1;hJh@8?LN4002_Q00<?hN408^400`3Q

h@1[h@03_^7Q05oQ0`n0h@>n7^400`oQh@1`h@00:n400`oQh@0Rh@030>7Q06_Q00>nhN40G>433h3Q

0khQh@033n7Q073Q000/h@033n7Q027Q00<0hN40Jn400kkQh@1Kh@033n7Q07kQ0khTh@033n7Q073Q

000/h@033n7Q027Q00<0hN40K>400kkQh@1Gh@<?O^43_ROQ00<?hN40L>4002gQ00<?hN408>400`3Q

h@1/h@03_^7Q05CQ0`mnh@>n:N400`oQh@1ah@00;^400`oQh@0Oh@030>7Q06gQ00>nhN40D^400`oQ

h@1lh@>n;>400`oQh@1ah@00;^400`oQh@0Oh@030>7Q06gQ00>nhN40Cn433ggQ0[h_h@033n7Q077Q

000_h@033n7Q01kQ00<0hN40KN400kkQh@1<h@<?ON43_S7Q00<?hN40LN4002oQ00<?hN407^400`3Q

h@1]h@03_^7Q04WQ0`mnh@:n<n423g?Q000`h@033n7Q01gQ00<0hN40K^400kkQh@16h@8?O^43_SGQ

00<?hN40L^40037Q00<?hN407>400`3Qh@1^h@03_^7Q04?Q0`mnh@:n>>400`oQh@1bh@00<^400`oQ

h@0Kh@<0Kn400kkQh@10h@8?O^43_S[Q00<?hN40L^4003;Q00<?hN406n400`3Qh@1_h@03_^7Q03gQ

0`mnh@>n>n423gCQ000ch@033n7Q01[Q00<0hN40L>400kkQh@0ih@<?O^43_SkQ00<?hN40Ln4003CQ

00<?hN406N400`3Qh@1`h@03_^7Q03KQ0`moh@>n@>400`oQh@1ch@00=N400`oQh@0Hh@030>7Q073Q

00>nhN40<n433h7Q00>nhN40@N400`oQh@1ch@00=N400`oQh@0Hh@030>7Q077Q00>nhN40;n433h7Q

0ki3h@033n7Q07CQ000fh@033n7Q01OQ00<0hN40LN400kkQh@0]h@8?P^43_TGQ00<?hN40M>4003KQ

00<?hN405n400`3Qh@1bh@03_^7Q02WQ0`n2h@>nAn400`oQh@1dh@00=n400`oQh@0Fh@030>7Q07?Q

00>nhN409^423hCQ00>nhN40B>400`oQh@1dh@00>>423aKQ00<0hN40Ln400kkQh@0Sh@<?Pn43_T[Q

0Pmfh@00>N400`oQh@0Dh@030>7Q07?Q00>nhN407^453hGQ0[i<h@033n7Q07GQ000jh@033n7Q01?Q

00<0hN40M>400kkQh@0Jh@<?R>42_TkQ00<?hN40MN4003_Q0PlCh@<0M>400kkQh@0Gh@<?RN43_ToQ

00<?hN40MN4003cQ00<?hN404N400`3Qh@1eh@03_^7Q01?Q0`n;h@:nDN400`oQh@1eh@00?N400`oQ

h@0@h@030>7Q07GQ00>nhN404N423hcQ0[iBh@033n7Q07KQ000nh@8?4>400`3Qh@1eh@03_^7Q00kQ

0`n=h@:nDn400`oQh@1fh@00@>400`oQh@0=h@030>7Q07KQ00>nhN402^433hkQ0[k>h@00@N423`gQ

00<0hN40Mn400kkQh@04h@D?T>42_YcQ0`l`h@00@n400`oQh@0:h@030>7Q07SQ00>nhN400`nDh@03

_^7Q05KQ00<?hN40?N463c?Q0014h@8?2^400`3Qh@1hh@<?U^400kkQh@1Gh@033n7Q03OQ1Plih@00

A^400`oQh@07h@030>7Q07CQ10l00kkQh@2Dh@:nF^423c?Q1@loh@00An423`OQ00<0hN40LN433`GQ

00>nhN40Tn400kkQh@1Jh@033n7Q02WQ20m4h@00?n4500;Q00@0hN4?1^400`3Qh@1]h@@?2N400kkQ

h@2@h@:nGN400`oQh@0Sh@H?C>40047Q00L0hN7Q0>4000;Q0Pl4h@030>7Q06[Q0`l>h@03_^7Q08kQ

00>nhN40G^423acQ1`mBh@00@N401`3QhN40h@001>4010oQhN4406CQ1@lAh@03_^7Q08kQ00>nhN40

H>433a3Q2@mIh@00@N401`3QhN40h@001N4010oQh@1Sh@@?5n400kkQh@2;h@:nI^4@3f;Q0011h@07

0>7Qh@3Q0006h@<?Gn443acQ00>nhN40RN400kkQh@3Hh@00@>4200CQ00<0hN401n40100?3`mGh@D?

8N400kkQh@28h@03_^7Q0=SQ001@h@040>7Qh@8?DN443bKQ00>nhN40Qn400kkQh@3Ih@00D>400`3Q

h@03h@<?B>463b_Q00>nhN40QN400kkQh@3Jh@00D>400`3Qh@06h@@?@>443c;Q00>nhN40Q>400kkQ

h@3Jh@00D>400`3Qh@0:h@@?=>483cKQ0[j4h@03_^7Q0=_Q001@h@030>7Q00kQ1@lXh@L?@>400kkQ

h@20h@03_^7Q0=cQ001@h@030>7Q01?Q2@lEh@X?B>400kkQh@1nh@03_^7Q0=gQ001@h@030>7Q01cQ

5@mBh@03_^7Q07kQ00>nhN40gN40053Q00<0hN40Q>42_WgQ00>nhN40g^40053Q0`26h@03_^7Q07WQ

00>nhN40gn40053Q00<0hN40Q^42_W[Q00>nhN40gn40053Q00<0hN40R>400kkQh@1fh@03_^7Q0>3Q

001@h@030>7Q08WQ00>nhN40MN400kkQh@3Ph@00D>400`3Qh@2:h@03_^7Q07?Q00>nhN40hN40053Q

00<0hN40Rn400kkQh@1ah@03_^7Q0>;Q001@h@030>7Q08cQ0[i`h@03_^7Q0>?Q001@h@030>7Q08kQ

00>nhN40KN400kkQh@3Sh@00D>400`3Qh@2?h@:nJn42_^KQ001@h@030>7Q097Q00>nhN40J>400kkQ

h@3Uh@00D>400`3Qh@2Bh@:nI^42_^SQ001@h@030>7Q09CQ0[iSh@03_^7Q0>SQ001@h@<0U^400kkQ

h@1Mh@>njn40053Q00<0hN40Un43_U[Q0kk]h@00D>400`3Qh@2Ih@BnE>43__3Q001@h@030>7Q09cQ

0ki?h@Bnl^40053Q00<0hN40W^44_TOQ1Kkfh@00D>400`3Qh@2Qh@Bn@>44___Q001@h@030>7Q0:GQ

1;hfh@Jnon40053Q00<0hN40ZN46_RWQ1kkoh@KQ001@h@030>7Q0:oQ2;hFh@^non4=h@00D>400`3Q

h@2ghANnon4Gh@00D>400`3Qh@3ohNGQ001@h@030>7Q0?oQiN40053Q0`3ohNGQ001@h@030>7Q0?oQ

iN40053Q00<0hN40on7Uh@00D>400`3Qh@3ohNGQ001@h@030>7Q0?oQiN40053Q00<0hN40on7Uh@00

on7ohCWQ003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ

>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQ1n420004h@00h@@000?Q00001>400`3Qh@3ohAkQ

003oh@SQ00<0h@002N401@3QhN400?oQ8>400?oQ2>4300;Q1002h@030>7Q00;Q00<0hN40on4Nh@00

on48h@040>4000SQ00<0hN400^400`3Qh@3ohAgQ001>h@80]n400`3Qh@07h@030>4000;Q00<0h@00

on4Oh@00Cn400`3Qh@2dh@802^40103QhN430?oQ7n4004gQ0`02h@030>7Q0?oQhn4004cQ00P0hN40

h@3Q0?oQi>4004cQ00P0hN40h@3Q0?oQi>4004gQ0`001>40h@3ohNCQ001Ah@030>400?oQi>4005;Q

00<0hN40on7Sh@00on7ohCWQ003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400001\

\>"],

  ImageRangeCache->{{{0, 566}, {349.313, 0}} -> {12.906, -13.3633, 0.0136531, 

  0.0834276}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-1.86108 0.141935 0.309017 0.0231564 [

[.26794 .29652 -6 -9 ]

[.26794 .29652 6 0 ]

[.40987 .29652 -6 -9 ]

[.40987 .29652 6 0 ]

[.55181 .29652 -6 -9 ]

[.55181 .29652 6 0 ]

[.69374 .29652 -6 -9 ]

[.69374 .29652 6 0 ]

[.83568 .29652 -6 -9 ]

[.83568 .29652 6 0 ]

[.97761 .29652 -6 -9 ]

[.97761 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.1135 .07745 -18 -4.5 ]

[.1135 .07745 0 4.5 ]

[.1135 .19323 -12 -4.5 ]

[.1135 .19323 0 4.5 ]

[.1135 .4248 -6 -4.5 ]

[.1135 .4248 0 4.5 ]

[.1135 .54058 -12 -4.5 ]

[.1135 .54058 0 4.5 ]

[.126 .64303 -7 0 ]

[.126 .64303 7 16 ]

[.5 .63053 -17 0 ]

[.5 .63053 17 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.26794 .30902 m

.26794 .31527 L

s

[(15)] .26794 .29652 0 1 Mshowa

.40987 .30902 m

.40987 .31527 L

s

[(16)] .40987 .29652 0 1 Mshowa

.55181 .30902 m

.55181 .31527 L

s

[(17)] .55181 .29652 0 1 Mshowa

.69374 .30902 m

.69374 .31527 L

s

[(18)] .69374 .29652 0 1 Mshowa

.83568 .30902 m

.83568 .31527 L

s

[(19)] .83568 .29652 0 1 Mshowa

.97761 .30902 m

.97761 .31527 L

s

[(20)] .97761 .29652 0 1 Mshowa

.125 Mabswid

.15439 .30902 m

.15439 .31277 L

s

.18278 .30902 m

.18278 .31277 L

s

.21116 .30902 m

.21116 .31277 L

s

.23955 .30902 m

.23955 .31277 L

s

.29632 .30902 m

.29632 .31277 L

s

.32471 .30902 m

.32471 .31277 L

s

.3531 .30902 m

.3531 .31277 L

s

.38148 .30902 m

.38148 .31277 L

s

.43826 .30902 m

.43826 .31277 L

s

.46665 .30902 m

.46665 .31277 L

s

.49503 .30902 m

.49503 .31277 L

s

.52342 .30902 m

.52342 .31277 L

s

.58019 .30902 m

.58019 .31277 L

s

.60858 .30902 m

.60858 .31277 L

s

.63697 .30902 m

.63697 .31277 L

s

.66535 .30902 m

.66535 .31277 L

s

.72213 .30902 m

.72213 .31277 L

s

.75051 .30902 m

.75051 .31277 L

s

.7789 .30902 m

.7789 .31277 L

s

.80729 .30902 m

.80729 .31277 L

s

.86406 .30902 m

.86406 .31277 L

s

.89245 .30902 m

.89245 .31277 L

s

.92084 .30902 m

.92084 .31277 L

s

.94922 .30902 m

.94922 .31277 L

s

.09762 .30902 m

.09762 .31277 L

s

.06923 .30902 m

.06923 .31277 L

s

.04084 .30902 m

.04084 .31277 L

s

.01245 .30902 m

.01245 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.126 .07745 m

.13225 .07745 L

s

[(-10)] .1135 .07745 1 0 Mshowa

.126 .19323 m

.13225 .19323 L

s

[(-5)] .1135 .19323 1 0 Mshowa

.126 .4248 m

.13225 .4248 L

s

[(5)] .1135 .4248 1 0 Mshowa

.126 .54058 m

.13225 .54058 L

s

[(10)] .1135 .54058 1 0 Mshowa

.125 Mabswid

.126 .10061 m

.12975 .10061 L

s

.126 .12377 m

.12975 .12377 L

s

.126 .14692 m

.12975 .14692 L

s

.126 .17008 m

.12975 .17008 L

s

.126 .21639 m

.12975 .21639 L

s

.126 .23955 m

.12975 .23955 L

s

.126 .2627 m

.12975 .2627 L

s

.126 .28586 m

.12975 .28586 L

s

.126 .33217 m

.12975 .33217 L

s

.126 .35533 m

.12975 .35533 L

s

.126 .37849 m

.12975 .37849 L

s

.126 .40164 m

.12975 .40164 L

s

.126 .44796 m

.12975 .44796 L

s

.126 .47111 m

.12975 .47111 L

s

.126 .49427 m

.12975 .49427 L

s

.126 .51742 m

.12975 .51742 L

s

.126 .0543 m

.12975 .0543 L

s

.126 .03114 m

.12975 .03114 L

s

.126 .00798 m

.12975 .00798 L

s

.126 .56374 m

.12975 .56374 L

s

.126 .58689 m

.12975 .58689 L

s

.126 .61005 m

.12975 .61005 L

s

.25 Mabswid

.126 0 m

.126 .61803 L

s

gsave

.126 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -78 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(k) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(37.5) show

93.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

1 0 0 r

.5 Mabswid

.97619 .52703 m

.97477 .52728 L

.97335 .52753 L

.97193 .52778 L

.97051 .52803 L

.96909 .52828 L

.96767 .52853 L

.96626 .52878 L

.96484 .52903 L

.96342 .52928 L

.962 .52953 L

.96058 .52978 L

.95916 .53004 L

.95774 .53029 L

.95632 .53054 L

.9549 .53079 L

.95348 .53105 L

.95206 .5313 L

.95064 .53155 L

.94922 .53181 L

.9478 .53206 L

.94638 .53232 L

.94496 .53257 L

.94355 .53283 L

.94213 .53308 L

.94071 .53334 L

.93929 .53359 L

.93787 .53385 L

.93645 .5341 L

.93503 .53436 L

.93361 .53462 L

.93219 .53488 L

.93077 .53513 L

.92935 .53539 L

.92793 .53565 L

.92651 .53591 L

.92509 .53617 L

.92367 .53643 L

.92226 .53668 L

.92084 .53694 L

.91942 .5372 L

.918 .53746 L

.91658 .53772 L

.91516 .53798 L

.91374 .53824 L

.91232 .53851 L

.9109 .53877 L

.90948 .53903 L

.90806 .53929 L

.90664 .53955 L

Mistroke

.90522 .53981 L

.9038 .54008 L

.90238 .54034 L

.90097 .5406 L

.89955 .54087 L

.89813 .54113 L

.89671 .54139 L

.89529 .54166 L

.89387 .54192 L

.89245 .54218 L

.89103 .54245 L

.88961 .54271 L

.88819 .54298 L

.88677 .54324 L

.88535 .54351 L

.88393 .54377 L

.88251 .54404 L

.88109 .5443 L

.87967 .54457 L

.87826 .54483 L

.87684 .5451 L

.87542 .54537 L

.874 .54563 L

.87258 .5459 L

.87116 .54616 L

.86974 .54643 L

.86832 .5467 L

.8669 .54696 L

.86548 .54723 L

.86406 .5475 L

.86264 .54776 L

.86122 .54803 L

.8598 .54829 L

.85838 .54856 L

.85697 .54883 L

.85555 .54909 L

.85413 .54936 L

.85271 .54963 L

.85129 .54989 L

.84987 .55016 L

.84845 .55042 L

.84703 .55069 L

.84561 .55095 L

.84419 .55121 L

.84277 .55148 L

.84135 .55174 L

.83993 .552 L

.83851 .55227 L

.83709 .55253 L

.83568 .55279 L

Mistroke

.83426 .55305 L

.83284 .55331 L

.83142 .55357 L

.83 .55382 L

.82858 .55408 L

.82716 .55433 L

.82574 .55458 L

.82432 .55483 L

.8229 .55508 L

.82148 .55533 L

.82006 .55557 L

.81864 .55581 L

.81722 .55605 L

.8158 .55628 L

.81439 .5565 L

.81297 .55672 L

.81155 .55694 L

.81013 .55714 L

.80871 .55733 L

.80729 .55752 L

.80587 .55768 L

.80445 .55783 L

.80303 .55795 L

.80161 .55803 L

.80019 .55807 L

.79877 .55801 L

.79735 .55778 L

.79593 .55704 L

Mfstroke

.97619 .091 m

.97477 .09075 L

.97335 .0905 L

.97193 .09025 L

.97051 .09 L

.96909 .08975 L

.96767 .0895 L

.96626 .08925 L

.96484 .089 L

.96342 .08875 L

.962 .0885 L

.96058 .08825 L

.95916 .088 L

.95774 .08775 L

.95632 .08749 L

.9549 .08724 L

.95348 .08699 L

.95206 .08673 L

.95064 .08648 L

.94922 .08623 L

.9478 .08597 L

.94638 .08572 L

.94496 .08546 L

.94355 .08521 L

.94213 .08495 L

.94071 .0847 L

.93929 .08444 L

.93787 .08419 L

.93645 .08393 L

.93503 .08367 L

.93361 .08342 L

.93219 .08316 L

.93077 .0829 L

.92935 .08264 L

.92793 .08238 L

.92651 .08213 L

.92509 .08187 L

.92367 .08161 L

.92226 .08135 L

.92084 .08109 L

.91942 .08083 L

.918 .08057 L

.91658 .08031 L

.91516 .08005 L

.91374 .07979 L

.91232 .07953 L

.9109 .07927 L

.90948 .07901 L

.90806 .07874 L

.90664 .07848 L

Mistroke

.90522 .07822 L

.9038 .07796 L

.90238 .07769 L

.90097 .07743 L

.89955 .07717 L

.89813 .07691 L

.89671 .07664 L

.89529 .07638 L

.89387 .07611 L

.89245 .07585 L

.89103 .07559 L

.88961 .07532 L

.88819 .07506 L

.88677 .07479 L

.88535 .07453 L

.88393 .07426 L

.88251 .074 L

.88109 .07373 L

.87967 .07347 L

.87826 .0732 L

.87684 .07293 L

.87542 .07267 L

.874 .0724 L

.87258 .07214 L

.87116 .07187 L

.86974 .0716 L

.86832 .07134 L

.8669 .07107 L

.86548 .0708 L

.86406 .07054 L

.86264 .07027 L

.86122 .07001 L

.8598 .06974 L

.85838 .06947 L

.85697 .06921 L

.85555 .06894 L

.85413 .06867 L

.85271 .06841 L

.85129 .06814 L

.84987 .06788 L

.84845 .06761 L

.84703 .06735 L

.84561 .06708 L

.84419 .06682 L

.84277 .06656 L

.84135 .06629 L

.83993 .06603 L

.83851 .06577 L

.83709 .0655 L

.83568 .06524 L

Mistroke

.83426 .06499 L

.83284 .06473 L

.83142 .06447 L

.83 .06421 L

.82858 .06395 L

.82716 .0637 L

.82574 .06345 L

.82432 .0632 L

.8229 .06295 L

.82148 .06271 L

.82006 .06246 L

.81864 .06223 L

.81722 .06199 L

.8158 .06176 L

.81439 .06153 L

.81297 .06131 L

.81155 .0611 L

.81013 .06089 L

.80871 .0607 L

.80729 .06052 L

.80587 .06035 L

.80445 .0602 L

.80303 .06008 L

.80161 .06 L

.80019 .05997 L

.79877 .06003 L

.79735 .06025 L

.79593 .06099 L

Mfstroke

.84533 .46188 m

.84504 .46279 L

.84476 .46368 L

.84448 .46457 L

.84419 .46544 L

.84391 .46631 L

.84362 .46716 L

.84334 .468 L

.84306 .46884 L

.84277 .46966 L

.84249 .47048 L

.8422 .47129 L

.84192 .47209 L

.84164 .47288 L

.84135 .47367 L

.84107 .47444 L

.84078 .47521 L

.8405 .47597 L

.84022 .47673 L

.83993 .47747 L

.83965 .47822 L

.83937 .47895 L

.83908 .47968 L

.8388 .4804 L

.83851 .48112 L

.83823 .48183 L

.83795 .48253 L

.83766 .48323 L

.83738 .48392 L

.83709 .48461 L

.83681 .4853 L

.83653 .48597 L

.83624 .48665 L

.83596 .48731 L

.83568 .48798 L

.83539 .48863 L

.83511 .48929 L

.83482 .48994 L

.83454 .49058 L

.83426 .49122 L

.83397 .49185 L

.83369 .49249 L

.8334 .49311 L

.83312 .49373 L

.83284 .49435 L

.83255 .49496 L

.83227 .49557 L

.83198 .49618 L

.8317 .49678 L

.83142 .49738 L

Mistroke

.83113 .49797 L

.83085 .49856 L

.83057 .49915 L

.83028 .49974 L

.83 .50032 L

.82971 .5009 L

.82943 .50146 L

.82915 .50203 L

.82886 .5026 L

.82858 .50316 L

.82829 .50373 L

.82801 .50428 L

.82773 .50483 L

.82744 .50538 L

.82716 .50593 L

.82688 .50647 L

.82659 .50701 L

.82631 .50755 L

.82602 .50809 L

.82574 .50862 L

.82546 .50914 L

.82517 .50967 L

.82489 .51019 L

.8246 .51071 L

.82432 .51123 L

.82404 .51174 L

.82375 .51226 L

.82347 .51276 L

.82319 .51327 L

.8229 .51377 L

.82262 .51428 L

.82233 .51477 L

.82205 .51527 L

.82177 .51576 L

.82148 .51625 L

.8212 .51674 L

.82091 .51722 L

.82063 .51771 L

.82035 .51819 L

.82006 .51867 L

.81978 .51915 L

.81949 .51962 L

.81921 .52009 L

.81893 .52056 L

.81864 .52103 L

.81836 .52149 L

.81808 .52195 L

.81779 .52241 L

.81751 .52287 L

.81722 .52332 L

Mistroke

.81694 .52378 L

.81666 .52423 L

.81637 .52468 L

.81609 .52513 L

.8158 .52557 L

.81552 .52601 L

.81524 .52646 L

.81495 .5269 L

.81467 .52734 L

.81439 .52777 L

.8141 .5282 L

.81382 .52863 L

.81353 .52906 L

.81325 .52949 L

.81297 .52992 L

.81268 .53034 L

.8124 .53076 L

.81211 .53118 L

.81183 .5316 L

.81155 .53202 L

.81126 .53244 L

.81098 .53285 L

.81069 .53326 L

.81041 .53368 L

.81013 .53408 L

.80984 .53449 L

.80956 .53489 L

.80928 .5353 L

.80899 .5357 L

.80871 .5361 L

.80842 .5365 L

.80814 .5369 L

.80786 .5373 L

.80757 .5377 L

.80729 .53809 L

.807 .53849 L

.80672 .53888 L

.80644 .53927 L

.80615 .53966 L

.80587 .54005 L

.80559 .54044 L

.8053 .54082 L

.80502 .5412 L

.80473 .54159 L

.80445 .54198 L

.80417 .54236 L

.80388 .54274 L

.8036 .54312 L

.80331 .54351 L

.80303 .54389 L

Mistroke

.80275 .54427 L

.80246 .54465 L

.80218 .54503 L

.80189 .54541 L

.80161 .54579 L

.80133 .54618 L

.80104 .54656 L

.80076 .54694 L

.80048 .54732 L

.80019 .54771 L

.79991 .5481 L

.79962 .54848 L

.79934 .54888 L

.79906 .54928 L

.79877 .54967 L

.79849 .55007 L

.7982 .55048 L

.79792 .5509 L

.79764 .55132 L

.79735 .55176 L

.79707 .55221 L

.79679 .55268 L

.7965 .55317 L

.79622 .55371 L

.79593 .55432 L

.79565 .55516 L

Mfstroke

.84533 .15615 m

.84504 .15524 L

.84476 .15435 L

.84448 .15346 L

.84419 .15259 L

.84391 .15173 L

.84362 .15088 L

.84334 .15003 L

.84306 .1492 L

.84277 .14837 L

.84249 .14755 L

.8422 .14675 L

.84192 .14594 L

.84164 .14515 L

.84135 .14437 L

.84107 .14359 L

.84078 .14283 L

.8405 .14206 L

.84022 .14131 L

.83993 .14056 L

.83965 .13981 L

.83937 .13909 L

.83908 .13835 L

.8388 .13763 L

.83851 .13691 L

.83823 .1362 L

.83795 .1355 L

.83766 .1348 L

.83738 .13411 L

.83709 .13342 L

.83681 .13274 L

.83653 .13206 L

.83624 .13139 L

.83596 .13072 L

.83568 .13005 L

.83539 .1294 L

.83511 .12875 L

.83482 .12809 L

.83454 .12745 L

.83426 .12682 L

.83397 .12618 L

.83369 .12555 L

.8334 .12492 L

.83312 .1243 L

.83284 .12368 L

.83255 .12307 L

.83227 .12246 L

.83198 .12185 L

.8317 .12125 L

.83142 .12065 L

Mistroke

.83113 .12006 L

.83085 .11947 L

.83057 .11888 L

.83028 .11829 L

.83 .11772 L

.82971 .11714 L

.82943 .11657 L

.82915 .116 L

.82886 .11544 L

.82858 .11487 L

.82829 .11431 L

.82801 .11376 L

.82773 .1132 L

.82744 .11265 L

.82716 .11211 L

.82688 .11156 L

.82659 .11102 L

.82631 .11049 L

.82602 .10995 L

.82574 .10942 L

.82546 .10889 L

.82517 .10837 L

.82489 .10784 L

.8246 .10732 L

.82432 .10681 L

.82404 .10629 L

.82375 .10578 L

.82347 .10527 L

.82319 .10476 L

.8229 .10426 L

.82262 .10376 L

.82233 .10326 L

.82205 .10277 L

.82177 .10227 L

.82148 .10179 L

.8212 .10129 L

.82091 .10081 L

.82063 .10032 L

.82035 .09985 L

.82006 .09937 L

.81978 .09889 L

.81949 .09841 L

.81921 .09794 L

.81893 .09747 L

.81864 .09701 L

.81836 .09654 L

.81808 .09608 L

.81779 .09562 L

.81751 .09516 L

.81722 .09471 L

Mistroke

.81694 .09426 L

.81666 .0938 L

.81637 .09335 L

.81609 .0929 L

.8158 .09246 L

.81552 .09202 L

.81524 .09158 L

.81495 .09114 L

.81467 .0907 L

.81439 .09026 L

.8141 .08983 L

.81382 .0894 L

.81353 .08897 L

.81325 .08854 L

.81297 .08812 L

.81268 .08769 L

.8124 .08727 L

.81211 .08685 L

.81183 .08643 L

.81155 .08601 L

.81126 .0856 L

.81098 .08518 L

.81069 .08477 L

.81041 .08436 L

.81013 .08395 L

.80984 .08355 L

.80956 .08314 L

.80928 .08274 L

.80899 .08233 L

.80871 .08193 L

.80842 .08153 L

.80814 .08113 L

.80786 .08073 L

.80757 .08033 L

.80729 .07994 L

.807 .07955 L

.80672 .07915 L

.80644 .07876 L

.80615 .07837 L

.80587 .07798 L

.80559 .0776 L

.8053 .07721 L

.80502 .07683 L

.80473 .07644 L

.80445 .07606 L

.80417 .07567 L

.80388 .07529 L

.8036 .07491 L

.80331 .07453 L

.80303 .07415 L

Mistroke

.80275 .07377 L

.80246 .07338 L

.80218 .073 L

.80189 .07262 L

.80161 .07224 L

.80133 .07186 L

.80104 .07148 L

.80076 .07109 L

.80048 .07071 L

.80019 .07032 L

.79991 .06994 L

.79962 .06955 L

.79934 .06916 L

.79906 .06876 L

.79877 .06836 L

.79849 .06796 L

.7982 .06755 L

.79792 .06714 L

.79764 .06671 L

.79735 .06627 L

.79707 .06583 L

.79679 .06535 L

.7965 .06486 L

.79622 .06433 L

.79593 .06371 L

.79565 .06287 L

Mfstroke

.84575 .4605 m

.84589 .46004 L

.84604 .45957 L

.84618 .45909 L

.84632 .45862 L

.84646 .45813 L

.8466 .45765 L

.84675 .45717 L

.84689 .45667 L

.84703 .45619 L

.84717 .45569 L

.84731 .45519 L

.84746 .45467 L

.8476 .45416 L

.84774 .45366 L

.84788 .45314 L

.84802 .4526 L

.84817 .45209 L

.84831 .45155 L

.84845 .45102 L

.84859 .45047 L

.84873 .44993 L

.84888 .44937 L

.84902 .44881 L

.84916 .44824 L

.8493 .44768 L

.84944 .44711 L

.84958 .44653 L

.84973 .44594 L

.84987 .44534 L

.85001 .44475 L

.85015 .44413 L

.85029 .44352 L

.85044 .4429 L

.85058 .44226 L

.85072 .44163 L

.85086 .44097 L

.851 .44031 L

.85115 .43965 L

.85129 .43897 L

.85143 .43828 L

.85157 .43759 L

.85171 .43688 L

.85186 .43616 L

.852 .43542 L

.85214 .43469 L

.85228 .43392 L

.85242 .43315 L

.85257 .43236 L

.85271 .43156 L

Mistroke

.85285 .43073 L

.85299 .42987 L

.85313 .429 L

.85328 .42811 L

.85342 .4272 L

.85356 .42626 L

.8537 .42529 L

.85384 .4243 L

.85398 .42325 L

.85413 .42217 L

.85427 .42103 L

.85441 .41984 L

.85455 .4186 L

.85469 .41726 L

.85484 .41585 L

.85498 .41431 L

.85512 .41265 L

.85526 .41072 L

.8554 .4085 L

.85555 .40573 L

.85569 .40093 L

Mfstroke

.84575 .15753 m

.84589 .158 L

.84604 .15847 L

.84618 .15894 L

.84632 .15941 L

.84646 .1599 L

.8466 .16038 L

.84675 .16087 L

.84689 .16136 L

.84703 .16185 L

.84717 .16234 L

.84731 .16285 L

.84746 .16336 L

.8476 .16387 L

.84774 .16438 L

.84788 .1649 L

.84802 .16543 L

.84817 .16595 L

.84831 .16648 L

.84845 .16702 L

.84859 .16756 L

.84873 .16811 L

.84888 .16867 L

.84902 .16923 L

.84916 .16979 L

.8493 .17036 L

.84944 .17092 L

.84958 .17151 L

.84973 .17209 L

.84987 .1727 L

.85001 .17329 L

.85015 .1739 L

.85029 .17451 L

.85044 .17513 L

.85058 .17578 L

.85072 .17641 L

.85086 .17706 L

.851 .17772 L

.85115 .17839 L

.85129 .17906 L

.85143 .17975 L

.85157 .18045 L

.85171 .18116 L

.85186 .18187 L

.852 .18261 L

.85214 .18334 L

.85228 .18411 L

.85242 .18489 L

.85257 .18568 L

.85271 .18647 L

Mistroke

.85285 .18731 L

.85299 .18816 L

.85313 .18903 L

.85328 .18992 L

.85342 .19083 L

.85356 .19177 L

.8537 .19274 L

.85384 .19374 L

.85398 .19478 L

.85413 .19586 L

.85427 .197 L

.85441 .19819 L

.85455 .19943 L

.85469 .20077 L

.85484 .20218 L

.85498 .20372 L

.85512 .20539 L

.85526 .20731 L

.8554 .20953 L

.85555 .2123 L

.85569 .2171 L

Mfstroke

.8554 .38791 m

.85526 .38581 L

.85512 .384 L

.85498 .38244 L

.85484 .38102 L

.85469 .37972 L

.85455 .37851 L

.85441 .37738 L

.85427 .37631 L

.85413 .3753 L

.85129 .36075 L

.84845 .3509 L

.84561 .34306 L

.84277 .33639 L

.83993 .33054 L

.83709 .32527 L

.83426 .32047 L

.83142 .31602 L

.82858 .31188 L

.82574 .30799 L

.8229 .30431 L

.82006 .30082 L

.81722 .2975 L

.81439 .29431 L

.81155 .29126 L

.80871 .28832 L

.80587 .28548 L

.80303 .28274 L

.80019 .28009 L

.79735 .27751 L

.79451 .275 L

.79168 .27256 L

.78884 .27019 L

.786 .26787 L

.78316 .2656 L

.78032 .26338 L

.77748 .26121 L

.77464 .25908 L

.7718 .25698 L

.76897 .25493 L

.76613 .25292 L

.76329 .25093 L

.76045 .24898 L

.75761 .24706 L

.75477 .24516 L

.75193 .2433 L

.7491 .24145 L

.74626 .23964 L

.74342 .23784 L

.74058 .23607 L

Mistroke

.73774 .23431 L

.7349 .23258 L

.73206 .23086 L

.72922 .22917 L

.72639 .22749 L

.72355 .22582 L

.72071 .22418 L

.71787 .22254 L

.71503 .22092 L

.71219 .21932 L

.70935 .21773 L

.70651 .21615 L

.70368 .21458 L

.70084 .21303 L

.698 .21148 L

.69516 .20995 L

.69232 .20843 L

.68948 .20692 L

.68664 .20542 L

.68381 .20393 L

.68097 .20244 L

.67813 .20097 L

.67529 .19951 L

.67245 .19805 L

.66961 .19661 L

.66677 .19517 L

.66393 .19374 L

.6611 .19232 L

.65826 .1909 L

.65542 .1895 L

.65258 .1881 L

.64974 .18671 L

.6469 .18533 L

.64406 .18396 L

.64122 .18259 L

.63839 .18123 L

.63555 .17988 L

.63271 .17853 L

.62987 .1772 L

.62703 .17587 L

.62419 .17455 L

.62135 .17323 L

.61852 .17192 L

.61568 .17062 L

.61284 .16933 L

.61 .16805 L

.60716 .16677 L

.60432 .1655 L

.60148 .16423 L

.59864 .16298 L

Mistroke

.59581 .16173 L

.59297 .16049 L

.59013 .15926 L

.58729 .15803 L

.58445 .15681 L

.58161 .1556 L

.57877 .1544 L

.57593 .1532 L

.5731 .15202 L

.57026 .15083 L

.56742 .14966 L

.56458 .14849 L

.56174 .14734 L

.5589 .14618 L

.55606 .14504 L

.55323 .1439 L

.55039 .14277 L

.54755 .14165 L

.54471 .14053 L

.54187 .13943 L

.53903 .13832 L

.53619 .13723 L

.53335 .13614 L

.53052 .13506 L

.52768 .13399 L

.52484 .13292 L

.522 .13186 L

.51916 .1308 L

.51632 .12976 L

.51348 .12871 L

.51065 .12768 L

.50781 .12665 L

.50497 .12563 L

.50213 .12461 L

.49929 .1236 L

.49645 .1226 L

.49361 .1216 L

.49077 .12061 L

.48794 .11962 L

.4851 .11864 L

.48226 .11766 L

.47942 .11669 L

.47658 .11573 L

.47374 .11477 L

.4709 .11382 L

.46806 .11287 L

.46523 .11193 L

.46239 .11099 L

.45955 .11006 L

.45671 .10913 L

Mistroke

.45387 .10821 L

.45103 .1073 L

.44819 .10638 L

.44536 .10548 L

.44252 .10458 L

.43968 .10368 L

.43684 .10279 L

.434 .10191 L

.43116 .10103 L

.42832 .10016 L

.42548 .09929 L

.42265 .09842 L

.41981 .09756 L

.41697 .09671 L

.41413 .09586 L

.41129 .09502 L

.40845 .09418 L

.40561 .09335 L

.40277 .09252 L

.39994 .0917 L

.3971 .09088 L

.39426 .09007 L

.39142 .08927 L

.38858 .08847 L

.38574 .08767 L

.3829 .08689 L

.38007 .08611 L

.37723 .08533 L

.37439 .08456 L

.37155 .0838 L

.36871 .08304 L

.36587 .08229 L

.36303 .08155 L

.36019 .08081 L

.35736 .08008 L

.35452 .07936 L

.35168 .07864 L

.34884 .07793 L

.346 .07723 L

.34316 .07653 L

.34032 .07585 L

.33748 .07517 L

.33465 .0745 L

.33181 .07384 L

.32897 .07318 L

.32613 .07254 L

.32329 .0719 L

.32045 .07127 L

.31761 .07066 L

.31478 .07005 L

Mistroke

.31194 .06945 L

.3091 .06886 L

.30626 .06828 L

.30342 .06772 L

.30058 .06716 L

.29774 .06662 L

.2949 .06608 L

.29207 .06556 L

.28923 .06505 L

.28639 .06455 L

.28355 .06407 L

.28071 .0636 L

.27787 .06314 L

.27503 .06269 L

.2722 .06226 L

.26936 .06185 L

.26652 .06145 L

.26368 .06106 L

.26084 .06069 L

.258 .06034 L

.25516 .06001 L

.25232 .05969 L

.24949 .05939 L

.24665 .05911 L

.24381 .05885 L

.24097 .0586 L

.23813 .05838 L

.23529 .05818 L

.23245 .058 L

.22961 .05784 L

.22678 .05771 L

.22394 .0576 L

.2211 .05751 L

.21826 .05745 L

.21542 .05741 L

.21258 .0574 L

.20974 .05742 L

.20691 .05747 L

.20407 .05755 L

.20123 .05765 L

.19839 .05779 L

.19555 .05796 L

.19271 .05816 L

.18987 .0584 L

.18703 .05867 L

.1842 .05898 L

.18136 .05933 L

.17852 .05971 L

.17568 .06014 L

.17284 .06061 L

Mistroke

.17 .06113 L

.16716 .06168 L

.16432 .06229 L

.16149 .06294 L

.15865 .06364 L

.15581 .0644 L

.15297 .06521 L

.15013 .06607 L

.14729 .067 L

.14445 .06798 L

.14162 .06902 L

.13878 .07013 L

.13594 .07131 L

.1331 .07256 L

.13026 .07388 L

.12742 .07528 L

.12458 .07675 L

.12174 .07831 L

.11891 .07996 L

.11607 .0817 L

.11323 .08353 L

.11039 .08546 L

.10755 .0875 L

.10471 .08964 L

.10187 .0919 L

.09903 .09428 L

.0962 .09679 L

.09336 .09943 L

.09052 .10222 L

.08768 .10515 L

.08484 .10825 L

.082 .11152 L

.07916 .11497 L

.07633 .11862 L

.07349 .12247 L

.07065 .12656 L

.06781 .13089 L

.06497 .13548 L

.06213 .14038 L

.05929 .1456 L

.05645 .15117 L

.05362 .15716 L

.05078 .1636 L

.04794 .17057 L

.0451 .17817 L

.04226 .1865 L

.03942 .19574 L

.03658 .20615 L

.03374 .21811 L

.03091 .23239 L

Mistroke

.02807 .25066 L

.02381 .30902 L

Mfstroke

.8554 .23012 m

.85526 .23223 L

.85512 .23403 L

.85498 .2356 L

.85484 .23701 L

.85469 .23832 L

.85455 .23952 L

.85441 .24066 L

.85427 .24173 L

.85413 .24273 L

.85129 .25729 L

.84845 .26713 L

.84561 .27498 L

.84277 .28164 L

.83993 .28749 L

.83709 .29276 L

.83426 .29757 L

.83142 .30201 L

.82858 .30616 L

.82574 .31005 L

.8229 .31372 L

.82006 .31721 L

.81722 .32054 L

.81439 .32372 L

.81155 .32677 L

.80871 .32971 L

.80587 .33255 L

.80303 .33529 L

.80019 .33795 L

.79735 .34052 L

.79451 .34303 L

.79168 .34547 L

.78884 .34785 L

.786 .35017 L

.78316 .35244 L

.78032 .35466 L

.77748 .35683 L

.77464 .35896 L

.7718 .36105 L

.76897 .3631 L

.76613 .36512 L

.76329 .3671 L

.76045 .36905 L

.75761 .37098 L

.75477 .37287 L

.75193 .37474 L

.7491 .37658 L

.74626 .3784 L

.74342 .38019 L

.74058 .38197 L

Mistroke

.73774 .38372 L

.7349 .38545 L

.73206 .38717 L

.72922 .38887 L

.72639 .39055 L

.72355 .39221 L

.72071 .39386 L

.71787 .39549 L

.71503 .39711 L

.71219 .39871 L

.70935 .40031 L

.70651 .40189 L

.70368 .40345 L

.70084 .40501 L

.698 .40655 L

.69516 .40808 L

.69232 .40961 L

.68948 .41112 L

.68664 .41262 L

.68381 .41411 L

.68097 .41559 L

.67813 .41706 L

.67529 .41853 L

.67245 .41998 L

.66961 .42143 L

.66677 .42287 L

.66393 .4243 L

.6611 .42572 L

.65826 .42713 L

.65542 .42853 L

.65258 .42993 L

.64974 .43132 L

.6469 .4327 L

.64406 .43408 L

.64122 .43544 L

.63839 .4368 L

.63555 .43816 L

.63271 .4395 L

.62987 .44084 L

.62703 .44217 L

.62419 .44349 L

.62135 .4448 L

.61852 .44611 L

.61568 .44741 L

.61284 .4487 L

.61 .44999 L

.60716 .45127 L

.60432 .45254 L

.60148 .4538 L

.59864 .45505 L

Mistroke

.59581 .4563 L

.59297 .45754 L

.59013 .45878 L

.58729 .46 L

.58445 .46122 L

.58161 .46243 L

.57877 .46363 L

.57593 .46483 L

.5731 .46602 L

.57026 .4672 L

.56742 .46837 L

.56458 .46954 L

.56174 .4707 L

.5589 .47185 L

.55606 .47299 L

.55323 .47413 L

.55039 .47526 L

.54755 .47638 L

.54471 .4775 L

.54187 .47861 L

.53903 .47971 L

.53619 .4808 L

.53335 .48189 L

.53052 .48297 L

.52768 .48405 L

.52484 .48511 L

.522 .48618 L

.51916 .48723 L

.51632 .48828 L

.51348 .48932 L

.51065 .49035 L

.50781 .49138 L

.50497 .49241 L

.50213 .49342 L

.49929 .49443 L

.49645 .49544 L

.49361 .49644 L

.49077 .49743 L

.48794 .49841 L

.4851 .4994 L

.48226 .50037 L

.47942 .50134 L

.47658 .50231 L

.47374 .50326 L

.4709 .50422 L

.46806 .50516 L

.46523 .50611 L

.46239 .50704 L

.45955 .50798 L

.45671 .5089 L

Mistroke

.45387 .50982 L

.45103 .51074 L

.44819 .51165 L

.44536 .51255 L

.44252 .51346 L

.43968 .51435 L

.43684 .51524 L

.434 .51612 L

.43116 .517 L

.42832 .51788 L

.42548 .51875 L

.42265 .51961 L

.41981 .52047 L

.41697 .52132 L

.41413 .52217 L

.41129 .52302 L

.40845 .52385 L

.40561 .52469 L

.40277 .52551 L

.39994 .52634 L

.3971 .52715 L

.39426 .52796 L

.39142 .52877 L

.38858 .52957 L

.38574 .53036 L

.3829 .53115 L

.38007 .53193 L

.37723 .5327 L

.37439 .53347 L

.37155 .53424 L

.36871 .53499 L

.36587 .53574 L

.36303 .53649 L

.36019 .53723 L

.35736 .53796 L

.35452 .53868 L

.35168 .5394 L

.34884 .5401 L

.346 .54081 L

.34316 .5415 L

.34032 .54219 L

.33748 .54286 L

.33465 .54354 L

.33181 .5442 L

.32897 .54485 L

.32613 .54549 L

.32329 .54613 L

.32045 .54676 L

.31761 .54738 L

.31478 .54798 L

Mistroke

.31194 .54858 L

.3091 .54917 L

.30626 .54975 L

.30342 .55032 L

.30058 .55087 L

.29774 .55142 L

.2949 .55195 L

.29207 .55247 L

.28923 .55299 L

.28639 .55348 L

.28355 .55397 L

.28071 .55444 L

.27787 .5549 L

.27503 .55534 L

.2722 .55577 L

.26936 .55619 L

.26652 .55659 L

.26368 .55697 L

.26084 .55734 L

.258 .55769 L

.25516 .55803 L

.25232 .55834 L

.24949 .55864 L

.24665 .55893 L

.24381 .55919 L

.24097 .55943 L

.23813 .55965 L

.23529 .55985 L

.23245 .56003 L

.22961 .56019 L

.22678 .56032 L

.22394 .56044 L

.2211 .56052 L

.21826 .56058 L

.21542 .56062 L

.21258 .56063 L

.20974 .56061 L

.20691 .56057 L

.20407 .56049 L

.20123 .56038 L

.19839 .56025 L

.19555 .56008 L

.19271 .55987 L

.18987 .55964 L

.18703 .55936 L

.1842 .55905 L

.18136 .55871 L

.17852 .55832 L

.17568 .55789 L

.17284 .55742 L

Mistroke

.17 .55691 L

.16716 .55635 L

.16432 .55575 L

.16149 .55509 L

.15865 .55439 L

.15581 .55363 L

.15297 .55283 L

.15013 .55196 L

.14729 .55104 L

.14445 .55006 L

.14162 .54901 L

.13878 .5479 L

.13594 .54672 L

.1331 .54548 L

.13026 .54415 L

.12742 .54276 L

.12458 .54128 L

.12174 .53972 L

.11891 .53807 L

.11607 .53634 L

.11323 .5345 L

.11039 .53257 L

.10755 .53054 L

.10471 .52839 L

.10187 .52613 L

.09903 .52375 L

.0962 .52124 L

.09336 .5186 L

.09052 .51582 L

.08768 .51288 L

.08484 .50978 L

.082 .50652 L

.07916 .50306 L

.07633 .49942 L

.07349 .49556 L

.07065 .49148 L

.06781 .48715 L

.06497 .48255 L

.06213 .47766 L

.05929 .47244 L

.05645 .46686 L

.05362 .46088 L

.05078 .45443 L

.04794 .44746 L

.0451 .43987 L

.04226 .43153 L

.03942 .42229 L

.03658 .41189 L

.03374 .39992 L

.03091 .38564 L

Mistroke

.02807 .36737 L

.02381 .30902 L

Mfstroke

0 .4 1 r

.97619 .42124 m

.97477 .42156 L

.97335 .42187 L

.97193 .42219 L

.97051 .4225 L

.96909 .42282 L

.96767 .42313 L

.96626 .42345 L

.96484 .42377 L

.96342 .42409 L

.962 .4244 L

.96058 .42472 L

.95916 .42504 L

.95774 .42537 L

.95632 .42569 L

.9549 .42601 L

.95348 .42633 L

.95206 .42665 L

.95064 .42698 L

.94922 .4273 L

.9478 .42763 L

.94638 .42795 L

.94496 .42828 L

.94355 .42861 L

.94213 .42894 L

.94071 .42926 L

.93929 .42959 L

.93787 .42992 L

.93645 .43026 L

.93503 .43059 L

.93361 .43092 L

.93219 .43125 L

.93077 .43159 L

.92935 .43192 L

.92793 .43226 L

.92651 .43259 L

.92509 .43293 L

.92367 .43327 L

.92226 .43361 L

.92084 .43395 L

.91942 .43429 L

.918 .43463 L

.91658 .43497 L

.91516 .43531 L

.91374 .43566 L

.91232 .436 L

.9109 .43635 L

.90948 .43669 L

.90806 .43704 L

.90664 .43739 L

Mistroke

.90522 .43774 L

.9038 .43809 L

.90238 .43844 L

.90097 .43879 L

.89955 .43914 L

.89813 .43949 L

.89671 .43985 L

.89529 .4402 L

.89387 .44056 L

.89245 .44092 L

.89103 .44128 L

.88961 .44164 L

.88819 .442 L

.88677 .44236 L

.88535 .44272 L

.88393 .44308 L

.88251 .44345 L

.88109 .44381 L

.87967 .44418 L

.87826 .44455 L

.87684 .44492 L

.87542 .44529 L

.874 .44566 L

.87258 .44603 L

.87116 .4464 L

.86974 .44678 L

.86832 .44716 L

.8669 .44753 L

.86548 .44791 L

.86406 .44829 L

.86264 .44867 L

.86122 .44905 L

.8598 .44944 L

.85838 .44982 L

.85697 .45021 L

.85555 .45059 L

.85413 .45098 L

.85271 .45137 L

.85129 .45176 L

.84987 .45216 L

.84845 .45255 L

.84703 .45295 L

.84561 .45334 L

.84419 .45374 L

.84277 .45414 L

.84135 .45454 L

.83993 .45495 L

.83851 .45535 L

.83709 .45576 L

.83568 .45617 L

Mistroke

.83426 .45658 L

.83284 .45699 L

.83142 .4574 L

.83 .45782 L

.82858 .45823 L

.82716 .45865 L

.82574 .45907 L

.82432 .45949 L

.8229 .45992 L

.82148 .46034 L

.82006 .46077 L

.81864 .4612 L

.81722 .46163 L

.8158 .46206 L

.81439 .4625 L

.81297 .46293 L

.81155 .46337 L

.81013 .46382 L

.80871 .46426 L

.80729 .46471 L

.80587 .46515 L

.80445 .46561 L

.80303 .46606 L

.80161 .46651 L

.80019 .46697 L

.79877 .46743 L

.79735 .46789 L

.79593 .46836 L

.79451 .46883 L

.79309 .4693 L

.79168 .46977 L

.79026 .47025 L

.78884 .47073 L

.78742 .47121 L

.786 .47169 L

.78458 .47218 L

.78316 .47267 L

.78174 .47317 L

.78032 .47366 L

.7789 .47416 L

.77748 .47467 L

.77606 .47517 L

.77464 .47569 L

.77322 .4762 L

.7718 .47672 L

.77039 .47724 L

.76897 .47776 L

.76755 .47829 L

.76613 .47883 L

.76471 .47936 L

Mistroke

.76329 .47991 L

.76187 .48045 L

.76045 .481 L

.75903 .48156 L

.75761 .48212 L

.75619 .48268 L

.75477 .48325 L

.75335 .48382 L

.75193 .4844 L

.75051 .48499 L

.7491 .48558 L

.74768 .48617 L

.74626 .48678 L

.74484 .48738 L

.74342 .488 L

.742 .48862 L

.74058 .48925 L

.73916 .48988 L

.73774 .49052 L

.73632 .49117 L

.7349 .49182 L

.73348 .49248 L

.73206 .49316 L

.73064 .49384 L

.72922 .49452 L

.7278 .49522 L

.72639 .49593 L

.72497 .49664 L

.72355 .49737 L

.72213 .4981 L

.72071 .49885 L

.71929 .49961 L

.71787 .50038 L

.71645 .50116 L

.71503 .50196 L

.71361 .50277 L

.71219 .50359 L

.71077 .50443 L

.70935 .50529 L

.70793 .50616 L

.70651 .50705 L

.7051 .50796 L

.70368 .50889 L

.70226 .50985 L

.70084 .51082 L

.69942 .51182 L

.698 .51285 L

.69658 .5139 L

.69516 .51499 L

.69374 .51611 L

Mistroke

.69232 .51727 L

.6909 .51847 L

.68948 .51972 L

.68806 .52101 L

.68664 .52237 L

.68522 .52379 L

.68381 .52529 L

.68239 .52687 L

.68097 .52857 L

.67955 .53039 L

.67813 .53239 L

.67671 .53461 L

.67529 .53715 L

.67387 .5402 L

.67245 .5443 L

Mfstroke

.97619 .19679 m

.97477 .19648 L

.97335 .19616 L

.97193 .19585 L

.97051 .19553 L

.96909 .19522 L

.96767 .1949 L

.96626 .19458 L

.96484 .19427 L

.96342 .19395 L

.962 .19363 L

.96058 .19331 L

.95916 .19299 L

.95774 .19267 L

.95632 .19235 L

.9549 .19203 L

.95348 .1917 L

.95206 .19138 L

.95064 .19106 L

.94922 .19073 L

.9478 .19041 L

.94638 .19008 L

.94496 .18975 L

.94355 .18943 L

.94213 .1891 L

.94071 .18877 L

.93929 .18844 L

.93787 .18811 L

.93645 .18778 L

.93503 .18745 L

.93361 .18711 L

.93219 .18678 L

.93077 .18645 L

.92935 .18611 L

.92793 .18578 L

.92651 .18544 L

.92509 .1851 L

.92367 .18477 L

.92226 .18443 L

.92084 .18409 L

.91942 .18375 L

.918 .18341 L

.91658 .18306 L

.91516 .18272 L

.91374 .18238 L

.91232 .18203 L

.9109 .18169 L

.90948 .18134 L

.90806 .18099 L

.90664 .18065 L

Mistroke

.90522 .1803 L

.9038 .17995 L

.90238 .1796 L

.90097 .17925 L

.89955 .17889 L

.89813 .17854 L

.89671 .17818 L

.89529 .17783 L

.89387 .17747 L

.89245 .17712 L

.89103 .17676 L

.88961 .1764 L

.88819 .17604 L

.88677 .17568 L

.88535 .17531 L

.88393 .17495 L

.88251 .17459 L

.88109 .17422 L

.87967 .17385 L

.87826 .17349 L

.87684 .17312 L

.87542 .17275 L

.874 .17238 L

.87258 .172 L

.87116 .17163 L

.86974 .17125 L

.86832 .17088 L

.8669 .1705 L

.86548 .17012 L

.86406 .16974 L

.86264 .16936 L

.86122 .16898 L

.8598 .1686 L

.85838 .16821 L

.85697 .16783 L

.85555 .16744 L

.85413 .16705 L

.85271 .16666 L

.85129 .16627 L

.84987 .16588 L

.84845 .16548 L

.84703 .16509 L

.84561 .16469 L

.84419 .16429 L

.84277 .16389 L

.84135 .16349 L

.83993 .16309 L

.83851 .16268 L

.83709 .16228 L

.83568 .16187 L

Mistroke

.83426 .16146 L

.83284 .16105 L

.83142 .16063 L

.83 .16022 L

.82858 .1598 L

.82716 .15938 L

.82574 .15896 L

.82432 .15854 L

.8229 .15812 L

.82148 .15769 L

.82006 .15727 L

.81864 .15684 L

.81722 .15641 L

.8158 .15597 L

.81439 .15554 L

.81297 .1551 L

.81155 .15466 L

.81013 .15422 L

.80871 .15377 L

.80729 .15333 L

.80587 .15288 L

.80445 .15243 L

.80303 .15198 L

.80161 .15152 L

.80019 .15106 L

.79877 .1506 L

.79735 .15014 L

.79593 .14967 L

.79451 .14921 L

.79309 .14874 L

.79168 .14826 L

.79026 .14779 L

.78884 .14731 L

.78742 .14683 L

.786 .14634 L

.78458 .14585 L

.78316 .14536 L

.78174 .14487 L

.78032 .14437 L

.7789 .14387 L

.77748 .14337 L

.77606 .14286 L

.77464 .14235 L

.77322 .14183 L

.7718 .14132 L

.77039 .14079 L

.76897 .14027 L

.76755 .13974 L

.76613 .13921 L

.76471 .13867 L

Mistroke

.76329 .13813 L

.76187 .13758 L

.76045 .13703 L

.75903 .13648 L

.75761 .13592 L

.75619 .13535 L

.75477 .13478 L

.75335 .13421 L

.75193 .13363 L

.75051 .13305 L

.7491 .13246 L

.74768 .13186 L

.74626 .13126 L

.74484 .13065 L

.74342 .13004 L

.742 .12942 L

.74058 .12879 L

.73916 .12816 L

.73774 .12752 L

.73632 .12687 L

.7349 .12621 L

.73348 .12555 L

.73206 .12488 L

.73064 .1242 L

.72922 .12351 L

.7278 .12281 L

.72639 .12211 L

.72497 .12139 L

.72355 .12067 L

.72213 .11993 L

.72071 .11918 L

.71929 .11842 L

.71787 .11765 L

.71645 .11687 L

.71503 .11607 L

.71361 .11526 L

.71219 .11444 L

.71077 .1136 L

.70935 .11274 L

.70793 .11187 L

.70651 .11098 L

.7051 .11007 L

.70368 .10914 L

.70226 .10819 L

.70084 .10721 L

.69942 .10621 L

.698 .10519 L

.69658 .10413 L

.69516 .10304 L

.69374 .10192 L

Mistroke

.69232 .10076 L

.6909 .09957 L

.68948 .09832 L

.68806 .09702 L

.68664 .09567 L

.68522 .09425 L

.68381 .09275 L

.68239 .09116 L

.68097 .08947 L

.67955 .08764 L

.67813 .08564 L

.67671 .08343 L

.67529 .08089 L

.67387 .07784 L

.67245 .07374 L

Mfstroke

.67607 .57269 m

.676 .57237 L

.67593 .57204 L

.67586 .57177 L

.67579 .5715 L

.67571 .57125 L

.67564 .57102 L

.67557 .57079 L

.6755 .57055 L

.67543 .57034 L

.67536 .57013 L

.67529 .56991 L

.67522 .56971 L

.67515 .5695 L

.67508 .5693 L

.67501 .56909 L

.67493 .56889 L

.67486 .56869 L

.67479 .56849 L

.67472 .56829 L

.67465 .5681 L

.67458 .56791 L

.67451 .56771 L

.67444 .56752 L

.67437 .56732 L

.6743 .56713 L

.67422 .56692 L

.67415 .56673 L

.67408 .56653 L

.67401 .56632 L

.67394 .56613 L

.67387 .56594 L

.6738 .56573 L

.67373 .56552 L

.67366 .56532 L

.67359 .56512 L

.67352 .56491 L

.67344 .56469 L

.67337 .56448 L

.6733 .56426 L

.67323 .56404 L

.67316 .56382 L

.67309 .56359 L

.67302 .56336 L

.67295 .56313 L

.67288 .56289 L

.67281 .56265 L

.67273 .56241 L

.67266 .56217 L

.67259 .5619 L

Mistroke

.67252 .56164 L

.67245 .56137 L

.67238 .56111 L

.67231 .56081 L

.67224 .56052 L

.67217 .56021 L

.6721 .55989 L

.67202 .55956 L

.67195 .55923 L

.67188 .55887 L

.67181 .55848 L

.67174 .55807 L

.67167 .55763 L

.6716 .55714 L

.67153 .55662 L

.67146 .55601 L

.67139 .55522 L

.67132 .55403 L

Mfstroke

.67607 .04534 m

.676 .04566 L

.67593 .04599 L

.67586 .04626 L

.67579 .04653 L

.67571 .04679 L

.67564 .04701 L

.67557 .04725 L

.6755 .04749 L

.67543 .04769 L

.67536 .04791 L

.67529 .04812 L

.67522 .04833 L

.67515 .04854 L

.67508 .04874 L

.67501 .04894 L

.67493 .04914 L

.67486 .04935 L

.67479 .04954 L

.67472 .04974 L

.67465 .04993 L

.67458 .05013 L

.67451 .05032 L

.67444 .05052 L

.67437 .05071 L

.6743 .05091 L

.67422 .05111 L

.67415 .0513 L

.67408 .0515 L

.67401 .05171 L

.67394 .05191 L

.67387 .0521 L

.6738 .0523 L

.67373 .05252 L

.67366 .05271 L

.67359 .05292 L

.67352 .05312 L

.67344 .05334 L

.67337 .05356 L

.6733 .05378 L

.67323 .054 L

.67316 .05422 L

.67309 .05444 L

.67302 .05467 L

.67295 .0549 L

.67288 .05514 L

.67281 .05538 L

.67273 .05563 L

.67266 .05586 L

.67259 .05613 L

Mistroke

.67252 .05639 L

.67245 .05667 L

.67238 .05693 L

.67231 .05723 L

.67224 .05752 L

.67217 .05783 L

.6721 .05814 L

.67202 .05847 L

.67195 .05881 L

.67188 .05917 L

.67181 .05956 L

.67174 .05997 L

.67167 .0604 L

.6716 .06089 L

.67153 .06142 L

.67146 .06202 L

.67139 .06282 L

.67132 .064 L

Mfstroke

.63186 .59084 m

.63242 .59073 L

.63299 .59062 L

.63356 .59051 L

.63413 .5904 L

.6347 .59029 L

.63526 .59018 L

.63583 .59006 L

.6364 .58995 L

.63697 .58984 L

.63753 .58972 L

.6381 .58961 L

.63867 .58949 L

.63924 .58938 L

.63981 .58926 L

.64037 .58915 L

.64094 .58903 L

.64151 .58891 L

.64208 .58879 L

.64264 .58867 L

.64321 .58855 L

.64378 .58843 L

.64435 .58831 L

.64492 .58819 L

.64548 .58807 L

.64605 .58794 L

.64662 .58782 L

.64719 .58769 L

.64775 .58757 L

.64832 .58744 L

.64889 .58731 L

.64946 .58718 L

.65002 .58705 L

.65059 .58692 L

.65116 .58679 L

.65173 .58666 L

.6523 .58653 L

.65286 .58639 L

.65343 .58625 L

.654 .58612 L

.65457 .58598 L

.65513 .58584 L

.6557 .5857 L

.65627 .58555 L

.65684 .58541 L

.65741 .58526 L

.65797 .58511 L

.65854 .58497 L

.65911 .58481 L

.65968 .58466 L

Mistroke

.66024 .5845 L

.66081 .58434 L

.66138 .58418 L

.66195 .58402 L

.66252 .58385 L

.66308 .58368 L

.66365 .5835 L

.66422 .58333 L

.66479 .58314 L

.66535 .58296 L

.66592 .58276 L

.66649 .58257 L

.66706 .58236 L

.66762 .58215 L

.66819 .58194 L

.66876 .58171 L

.66933 .58147 L

.6699 .58123 L

.67046 .58097 L

.67103 .5807 L

.6716 .5804 L

.67217 .58008 L

.67273 .57974 L

.6733 .57936 L

.67387 .57893 L

.67444 .57844 L

.67501 .57783 L

.67557 .57702 L

.67614 .57547 L

Mfstroke

.63186 .02719 m

.63242 .0273 L

.63299 .02741 L

.63356 .02752 L

.63413 .02763 L

.6347 .02775 L

.63526 .02786 L

.63583 .02797 L

.6364 .02808 L

.63697 .0282 L

.63753 .02831 L

.6381 .02842 L

.63867 .02854 L

.63924 .02866 L

.63981 .02877 L

.64037 .02889 L

.64094 .029 L

.64151 .02912 L

.64208 .02924 L

.64264 .02936 L

.64321 .02948 L

.64378 .0296 L

.64435 .02972 L

.64492 .02985 L

.64548 .02997 L

.64605 .03009 L

.64662 .03022 L

.64719 .03034 L

.64775 .03047 L

.64832 .03059 L

.64889 .03072 L

.64946 .03085 L

.65002 .03098 L

.65059 .03111 L

.65116 .03124 L

.65173 .03137 L

.6523 .03151 L

.65286 .03164 L

.65343 .03178 L

.654 .03192 L

.65457 .03205 L

.65513 .0322 L

.6557 .03234 L

.65627 .03248 L

.65684 .03262 L

.65741 .03277 L

.65797 .03292 L

.65854 .03307 L

.65911 .03322 L

.65968 .03338 L

Mistroke

.66024 .03353 L

.66081 .03369 L

.66138 .03385 L

.66195 .03402 L

.66252 .03419 L

.66308 .03436 L

.66365 .03453 L

.66422 .03471 L

.66479 .03489 L

.66535 .03508 L

.66592 .03527 L

.66649 .03547 L

.66706 .03567 L

.66762 .03588 L

.66819 .0361 L

.66876 .03632 L

.66933 .03656 L

.6699 .0368 L

.67046 .03706 L

.67103 .03734 L

.6716 .03764 L

.67217 .03795 L

.67273 .03829 L

.6733 .03868 L

.67387 .0391 L

.67444 .0396 L

.67501 .0402 L

.67557 .04102 L

.67614 .04257 L

Mfstroke

.62987 .59122 m

.62845 .59149 L

.62703 .59175 L

.62561 .59201 L

.62419 .59228 L

.62277 .59253 L

.62135 .59279 L

.61993 .59304 L

.61852 .59329 L

.6171 .59354 L

.61568 .59378 L

.61426 .59402 L

.61284 .59426 L

.61142 .5945 L

.61 .59474 L

.60858 .59497 L

.60716 .5952 L

.60574 .59543 L

.60432 .59565 L

.6029 .59588 L

.60148 .5961 L

.60006 .59632 L

.59864 .59653 L

.59723 .59675 L

.59581 .59696 L

.59439 .59717 L

.59297 .59737 L

.59155 .59758 L

.59013 .59778 L

.58871 .59797 L

.58729 .59817 L

.58587 .59836 L

.58445 .59855 L

.58303 .59874 L

.58161 .59893 L

.58019 .59911 L

.57877 .59929 L

.57735 .59946 L

.57593 .59963 L

.57452 .5998 L

.5731 .59997 L

.57168 .60013 L

.57026 .60029 L

.56884 .60045 L

.56742 .6006 L

.566 .60075 L

.56458 .6009 L

.56316 .60104 L

.56174 .60118 L

.56032 .60132 L

Mistroke

.5589 .60145 L

.55748 .60158 L

.55606 .6017 L

.55464 .60182 L

.55323 .60194 L

.55181 .60205 L

.55039 .60216 L

.54897 .60226 L

.54755 .60236 L

.54613 .60246 L

.54471 .60255 L

.54329 .60263 L

.54187 .60271 L

.54045 .60279 L

.53903 .60286 L

.53761 .60293 L

.53619 .60299 L

.53477 .60305 L

.53335 .6031 L

.53194 .60315 L

.53052 .60319 L

.5291 .60323 L

.52768 .60326 L

.52626 .60328 L

.52484 .6033 L

.52342 .60331 L

.522 .60332 L

.52058 .60332 L

.51916 .60331 L

.51774 .6033 L

.51632 .60328 L

.5149 .60326 L

.51348 .60322 L

.51206 .60318 L

.51065 .60314 L

.50923 .60309 L

.50781 .60302 L

.50639 .60295 L

.50497 .60288 L

.50355 .6028 L

.50213 .6027 L

.50071 .6026 L

.49929 .60249 L

.49787 .60238 L

.49645 .60225 L

.49503 .60212 L

.49361 .60197 L

.49219 .60182 L

.49077 .60166 L

.48935 .60149 L

Mistroke

.48794 .60131 L

.48652 .60111 L

.4851 .60091 L

.48368 .6007 L

.48226 .60048 L

.48084 .60025 L

.47942 .6 L

.478 .59975 L

.47658 .59948 L

.47516 .5992 L

.47374 .59891 L

.47232 .59861 L

.4709 .59829 L

.46948 .59796 L

.46806 .59762 L

.46665 .59727 L

.46523 .5969 L

.46381 .59652 L

.46239 .59612 L

.46097 .59571 L

.45955 .59528 L

.45813 .59484 L

.45671 .59439 L

.45529 .59391 L

.45387 .59342 L

.45245 .59292 L

.45103 .59239 L

.44961 .59185 L

.44819 .5913 L

.44677 .59072 L

.44536 .59013 L

.44394 .58952 L

.44252 .58888 L

.4411 .58823 L

.43968 .58756 L

.43826 .58687 L

.43684 .58615 L

.43542 .58541 L

.434 .58465 L

.43258 .58387 L

.43116 .58307 L

.42974 .58224 L

.42832 .58139 L

.4269 .58051 L

.42548 .5796 L

.42407 .57867 L

.42265 .57771 L

.42123 .57672 L

.41981 .57571 L

.41839 .57467 L

Mistroke

.41697 .57359 L

.41555 .57249 L

.41413 .57135 L

.41271 .57018 L

.41129 .56898 L

.40987 .56774 L

.40845 .56646 L

.40703 .56515 L

.40561 .5638 L

.40419 .56242 L

.40277 .56099 L

.40136 .55953 L

.39994 .55802 L

.39852 .55646 L

.3971 .55486 L

.39568 .55322 L

.39426 .55153 L

.39284 .54979 L

.39142 .54799 L

.39 .54615 L

.38858 .54425 L

.38716 .54229 L

.38574 .54027 L

.38432 .53819 L

.3829 .53605 L

.38148 .53384 L

.38007 .53157 L

.37865 .52922 L

.37723 .5268 L

.37581 .5243 L

.37439 .52171 L

.37297 .51905 L

.37155 .51629 L

.37013 .51344 L

.36871 .51049 L

.36729 .50744 L

.36587 .50428 L

.36445 .501 L

.36303 .4976 L

.36161 .49406 L

.36019 .49039 L

.35878 .48657 L

.35736 .48259 L

.35594 .47844 L

.35452 .4741 L

.3531 .46956 L

.35168 .4648 L

.35026 .4598 L

.34884 .45452 L

.34742 .44894 L

Mistroke

.346 .44302 L

.34458 .43671 L

.34316 .42995 L

.34174 .42265 L

.34032 .4147 L

.3389 .40595 L

.33748 .39613 L

.33607 .38485 L

.33465 .37131 L

.33323 .35348 L

.33178 .30902 L

Mfstroke

.62987 .02681 m

.62845 .02655 L

.62703 .02628 L

.62561 .02602 L

.62419 .02576 L

.62277 .0255 L

.62135 .02525 L

.61993 .025 L

.61852 .02475 L

.6171 .0245 L

.61568 .02425 L

.61426 .02401 L

.61284 .02377 L

.61142 .02353 L

.61 .0233 L

.60858 .02307 L

.60716 .02283 L

.60574 .0226 L

.60432 .02238 L

.6029 .02216 L

.60148 .02194 L

.60006 .02172 L

.59864 .0215 L

.59723 .02129 L

.59581 .02108 L

.59439 .02087 L

.59297 .02066 L

.59155 .02046 L

.59013 .02026 L

.58871 .02006 L

.58729 .01986 L

.58587 .01967 L

.58445 .01948 L

.58303 .01929 L

.58161 .01911 L

.58019 .01893 L

.57877 .01875 L

.57735 .01857 L

.57593 .0184 L

.57452 .01823 L

.5731 .01807 L

.57168 .0179 L

.57026 .01774 L

.56884 .01759 L

.56742 .01743 L

.566 .01728 L

.56458 .01714 L

.56316 .01699 L

.56174 .01685 L

.56032 .01672 L

Mistroke

.5589 .01659 L

.55748 .01646 L

.55606 .01633 L

.55464 .01621 L

.55323 .0161 L

.55181 .01599 L

.55039 .01588 L

.54897 .01577 L

.54755 .01567 L

.54613 .01558 L

.54471 .01549 L

.54329 .0154 L

.54187 .01532 L

.54045 .01524 L

.53903 .01517 L

.53761 .0151 L

.53619 .01504 L

.53477 .01498 L

.53335 .01493 L

.53194 .01489 L

.53052 .01484 L

.5291 .01481 L

.52768 .01478 L

.52626 .01475 L

.52484 .01474 L

.52342 .01472 L

.522 .01472 L

.52058 .01472 L

.51916 .01472 L

.51774 .01473 L

.51632 .01475 L

.5149 .01478 L

.51348 .01481 L

.51206 .01485 L

.51065 .0149 L

.50923 .01495 L

.50781 .01501 L

.50639 .01508 L

.50497 .01516 L

.50355 .01524 L

.50213 .01533 L

.50071 .01543 L

.49929 .01554 L

.49787 .01566 L

.49645 .01578 L

.49503 .01592 L

.49361 .01606 L

.49219 .01621 L

.49077 .01638 L

.48935 .01655 L

Mistroke

.48794 .01673 L

.48652 .01692 L

.4851 .01712 L

.48368 .01733 L

.48226 .01755 L

.48084 .01779 L

.47942 .01803 L

.478 .01829 L

.47658 .01855 L

.47516 .01883 L

.47374 .01912 L

.47232 .01943 L

.4709 .01974 L

.46948 .02007 L

.46806 .02041 L

.46665 .02077 L

.46523 .02114 L

.46381 .02152 L

.46239 .02191 L

.46097 .02233 L

.45955 .02275 L

.45813 .02319 L

.45671 .02365 L

.45529 .02412 L

.45387 .02461 L

.45245 .02512 L

.45103 .02564 L

.44961 .02618 L

.44819 .02674 L

.44677 .02731 L

.44536 .0279 L

.44394 .02852 L

.44252 .02915 L

.4411 .0298 L

.43968 .03048 L

.43826 .03117 L

.43684 .03188 L

.43542 .03262 L

.434 .03338 L

.43258 .03416 L

.43116 .03497 L

.42974 .03579 L

.42832 .03665 L

.4269 .03753 L

.42548 .03843 L

.42407 .03937 L

.42265 .04032 L

.42123 .04131 L

.41981 .04232 L

.41839 .04337 L

Mistroke

.41697 .04444 L

.41555 .04555 L

.41413 .04668 L

.41271 .04786 L

.41129 .04906 L

.40987 .0503 L

.40845 .05157 L

.40703 .05288 L

.40561 .05423 L

.40419 .05561 L

.40277 .05704 L

.40136 .05851 L

.39994 .06002 L

.39852 .06157 L

.3971 .06317 L

.39568 .06481 L

.39426 .0665 L

.39284 .06825 L

.39142 .07004 L

.39 .07189 L

.38858 .07379 L

.38716 .07575 L

.38574 .07776 L

.38432 .07984 L

.3829 .08198 L

.38148 .08419 L

.38007 .08647 L

.37865 .08882 L

.37723 .09124 L

.37581 .09374 L

.37439 .09632 L

.37297 .09899 L

.37155 .10174 L

.37013 .10459 L

.36871 .10754 L

.36729 .1106 L

.36587 .11376 L

.36445 .11704 L

.36303 .12044 L

.36161 .12397 L

.36019 .12764 L

.35878 .13146 L

.35736 .13544 L

.35594 .13959 L

.35452 .14393 L

.3531 .14847 L

.35168 .15323 L

.35026 .15824 L

.34884 .16351 L

.34742 .16909 L

Mistroke

.346 .17501 L

.34458 .18132 L

.34316 .18808 L

.34174 .19538 L

.34032 .20333 L

.3389 .21209 L

.33748 .2219 L

.33607 .23318 L

.33465 .24672 L

.33323 .26455 L

.33178 .30902 L

Mfstroke

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{567, 350.313},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.776525,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008g0001GPP10`40000100000800002008200000

P800P020P<30`<3L`:K:l00003<006H009T00<`00?l0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV

09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<003o03?o06Ko09Wo0<co

0?oo0000<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I

<c>I<fJI<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0

IYT0I/`0I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bI

I_nIIP3<IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0c

VC<cVFHcVITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<

VIW<VLc<VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`c

c?lcc01Vc3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03o

c3?oc6Koc9Woc<coc?ooc000oc<0ofH0oiT0ol`0ool0o`0coc<cofHcoiTcol`coolco`1Voc=VofIV

oiUVolaVoomVo`2Ioc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<o`3ooc?oofKooiWoolco

ooooo`0000410@820P<30`@410D51@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C

4a@D5?okl:2PY820P?l0003o0?oo0000ool0o`3oooooodkQ00<0hN40on7Wh@00C^400`3Qh@3ohNOQ

001>h@030>7Q0?oQin4004kQ00<0hN40on7Wh@00C^430?oQin4004kQ00<0hN40on7Wh@00C^400`3Q

h@3ohNOQ001>h@030>7Q0?oQin4004kQ00<0hN40_>4N__oQ3N4004kQ00<0hN40]N47_QkQ2kkoh@;Q

001>h@030>7Q0:oQ1[h_h@VnnN4004kQ00<0hN40[>44_SgQ1[kch@00C^400`3Qh@2Xh@BnAn46_^gQ

001>h@030>7Q0:GQ0kiAh@Jnin4004kQ00<0hN40Xn42_U[Q1[kQh@00C^400`3Qh@2Qh@:nHN46_]cQ

001>h@<0Wn42_VSQ1KkHh@00C^400`3Qh@2Lh@>nK^45_]CQ001>h@030>7Q09_Q0[ieh@Bnd>4004kQ

00<0hN40VN42_W[Q0kk>h@00C^400`3Qh@2Hh@:nON43_/cQ001>h@030>7Q09KQ0[j1h@:nbn4004kQ

00<0hN40UN42_X?Q00>nhN40bN4004kQ00<0hN40Tn42__oQD^4004kQ00<0hN40T^42_XKQ00>nhN40

bN4004kQ00<0hN40TN400kkQh@25h@:nbn4004kQ00<0hN40T>42_XOQ00>nhN40b^4004kQ00<0hN40

Sn400kkQh@27h@03_^7Q0<[Q001>h@<0S^400kkQh@27h@:nc>4004kQ00<0hN40SN400kkQh@28h@03

_^7Q0<_Q001>h@030>7Q01kQ6PmDh@03_^7Q08WQ00>nhN40bn4004kQ00<0hN405^483a[Q2Pm9h@03

_^7Q08[Q00>nhN40?^453hSQ001>h@030>7Q017Q1@l/h@L?@N400kkQh@2:h@03_^7Q03kQ00<?hN40

0n473h7Q001>h@030>7Q00kQ0`lhh@H?>^400kkQh@2;h@03_^7Q03kQ00<?hN402N473g_Q001>h@03

0>7Q00WQ1@m1h@H?<n400kkQh@3=h@8?4>463gKQ001>h@030>7Q00KQ0`m<h@D?;^400kkQh@3>h@03

3n7Q01?Q1Pmah@00C^400`3Qh@05h@033n7Q05;Q1PlVh@:ndN423a[Q1Pm[h@00C^400`3Qh@02h@<?

Fn443b;Q00>nhN40dN423akQ1PmVh@00?N4500;Q00<0hN401n400`3Q3`023f;Q10lMh@03_^7Q093Q

00>nhN40@>400`oQh@0Rh@D?HN4003oQ00L0hN7Q0>4000SQ0PmYh@<?6N400kkQh@2Ah@03_^7Q047Q

00<?hN409^453ecQ000ih@<00n401`3QhN40h@001n400`l0000206[Q1@lCh@03_^7Q09?Q00>nhN40

@>423bcQ1PmFh@00?n401`3QhN40h@001N423`03h@3Q077Q10l?h@03_^7Q09?Q00>nhN40@N423c7Q

1@mAh@00?n401`3QhN40h@001>401@oQhN4007KQ1@l:h@03_^7Q09?Q00>nhN40@^400`oQh@0dh@H?

Bn4003kQ0P04h@030>7Q00<?1>400`3Qh@1ih@8?1n400kkQh@2Eh@03_^7Q04;Q00<?hN40>N453dKQ

0016h@033n7Q00GQ00<0hN40Nn453`03hKkQ09OQ00>nhN40@^423coQ1Pm0h@00AN400`oQh@06h@03

0>7Q083Q00>n3`l0V>400kkQh@12h@033n7Q04?Q1@lkh@00A>400`oQh@07h@030>7Q083Q00>nhN40

10nEh@03_^7Q04;Q00<?hN40An463cGQ0013h@033n7Q00SQ00<0hN40On400kkQh@05h@<?T^42_T?Q

0Pm>h@D?<>40047Q0Pl;h@030>7Q07kQ00>nhN402N433i7Q00>nhN40@N400`oQh@21h@00@>400`oQ

h@0;h@030>7Q07kQ00>nhN403>453hgQ00>nhN40@N400`oQh@20h@00?^423`kQ00<0hN40ON400kkQ

h@0Bh@8?Rn42_T;Q0Pn1h@00?N400`oQh@0>h@030>7Q07gQ00>nhN405>433h[Q00>nhN40@>400`oQ

h@1oh@00?N400`oQh@0>h@<0O>400kkQh@0Hh@<?Qn42_T7Q0Pn0h@00>n423a7Q00<0hN40O>400kkQ

h@0Kh@D?Q>400kkQh@0oh@033n7Q07kQ000jh@033n7Q017Q00<0hN40Nn400kkQh@0Qh@<?P^400kkQ

h@0oh@033n7Q07gQ000jh@033n7Q017Q00<0hN40N^400kkQh@0Uh@<?P>42_SoQ00<?hN40ON4003SQ

0PlDh@030>7Q07[Q00>nhN40:>433goQ00>nhN40?N400`oQh@1lh@00=n400`oQh@0Dh@030>7Q07[Q

00>nhN40:n433ggQ0[hmh@8?ON4003OQ00<?hN405>400`3Qh@1jh@03_^7Q02kQ0Pmmh@03_^7Q03_Q

00<?hN40Nn4003KQ00<?hN405N400`3Qh@1ih@03_^7Q037Q0`mkh@:n>n423gcQ000eh@033n7Q01KQ

00<0hN40N>400kkQh@0eh@<?N^42_S[Q00<?hN40N^4003CQ00<?hN405n400`3Qh@1hh@03_^7Q03SQ

0`mih@03_^7Q03OQ0Pmkh@00=>400`oQh@0Gh@030>7Q07SQ00>nhN40>n433gOQ0khgh@033n7Q07WQ

000ch@033n7Q01SQ00<0hN40N>400kkQh@0nh@<?M^43_SGQ0Pmjh@00<^400`oQh@0Ih@<0Mn400kkQ

h@12h@<?M^400kkQh@0ch@033n7Q07SQ000ah@033n7Q01[Q00<0hN40M^400kkQh@16h@<?M>43_S;Q

00<?hN40N>40037Q00<?hN406^400`3Qh@1fh@03_^7Q04WQ0`mch@>n<N400`oQh@1gh@00<>400`oQ

h@0Kh@030>7Q07GQ00>nhN40CN433g;Q0kh_h@033n7Q07OQ000`h@033n7Q01_Q00<0hN40MN400kkQ

h@1@h@033n7Q07;Q0[h^h@033n7Q07KQ000_h@033n7Q01cQ00<0hN40MN400kkQh@1Ah@<?Ln43_R_Q

00<?hN40M^4002kQ00<?hN407N400`3Qh@1eh@03_^7Q05CQ0`mch@:n:N423gOQ000^h@033n7Q01gQ

00<0hN40MN400kkQh@1Gh@<?L^43_ROQ00<?hN40MN4002gQ00<?hN407^400`3Qh@1dh@03_^7Q05_Q

0`mah@>n9N400`oQh@1eh@00;N400`oQh@0Nh@030>7Q07CQ00>nhN40G^423g;Q0khSh@033n7Q07CQ

000/h@033n7Q01oQ00<0hN40Ln400kkQh@1Qh@<?L^43_R3Q00<?hN40M>4002cQ00<?hN407n400`3Q

h@1ch@03_^7Q06CQ0`mah@Bn7N423gGQ000[h@033n7Q023Q0`1bh@03_^7Q06SQ00<?hN40LN44_Q_Q

00<?hN40Ln4002_Q00<?hN408>400`3Qh@1bh@03_^7Q06WQ0`mch@>n6N400`oQh@1ch@00:^400`oQ

h@0Qh@030>7Q07;Q00>nhN40K>433g?Q1;hEh@8?M>4002[Q00<?hN408N400`3Qh@1bh@03_^7Q06oQ

00<?hN40M>43_Q?Q00<?hN40L^4002WQ00<?hN408^400`3Qh@1bh@03_^7Q073Q0`mfh@>n4>400`oQ

h@1bh@00:N400`oQh@0Rh@030>7Q077Q00>nhN40M>433gKQ1;h<h@8?Ln4002SQ00<?hN408n400`3Q

h@1ah@03_^7Q07OQ0Pmgh@Bn2^400`oQh@1ah@00:>400`oQh@0Sh@030>7Q077Q00>nhN40NN433gOQ

1;h7h@033n7Q077Q000Wh@033n7Q02CQ00<0hN40L>400kkQh@1mh@033n7Q07SQ0kh4h@033n7Q077Q

000Wh@033n7Q02CQ00<0hN40L>400kkQh@1nh@<?N^44_P03h@oQ077Q000Vh@033n7Q02GQ00<0hN40

L>400kkQh@21h@8?O>44_W3Q000Vh@033n7Q02GQ00<0hN40Kn400kkQh@24h@<?N^400`oQ_P03_VgQ

000Uh@033n7Q02KQ0`1_h@03_^7Q08OQ00<?hN40Mn423`CQ1;iYh@009N400`oQh@0Vh@030>7Q06oQ

00>nhN40R>433gOQ00<?hN401^44_VGQ000Uh@033n7Q02KQ00<0hN40Kn400kkQh@2;h@033n7Q07CQ

00<?hN402N45_V7Q000Th@033n7Q02OQ00<0hN40Kn400kkQh@2<h@<?Ln400`oQh@0>h@BnGN4002CQ

00<?hN409n400`3Qh@1_h@03_^7Q08oQ0Pmah@033n7Q017Q1;iJh@009>400`oQh@0Wh@030>7Q06kQ

00>nhN40T^433foQ00<?hN405>45_UGQ000Sh@033n7Q02SQ00<0hN40K^400kkQh@2Eh@033n7Q06cQ

00<?hN406N44_U7Q000Sh@033n7Q02SQ00<0hN40K^400kkQh@2Fh@8?K>400`oQh@0Lh@FnCN4002;Q

00<?hN40:N400`3Qh@1]h@03_^7Q09WQ0`mYh@033n7Q027Q1;i9h@008^400`oQh@0Yh@030>7Q06gQ

00>nhN40W>400`oQh@1Vh@033n7Q02GQ1;i5h@008^400`oQh@0Oh@030>7Q00OQ00<0hN40KN400kkQ

h@2Mh@<?IN423b[Q1;i1h@008^400`oQh@0Nh@030>4000SQ00<0hN40KN400kkQh@2Ph@8?I>400`oQ

h@0/h@Fn?>40027Q00<?hN406^4300CQ00<0hN401^4406_Q00>nhN40Xn400`oQh@1Qh@033n7Q037Q

1;hhh@008N400`oQh@0Oh@802N400`3Qh@1/h@03_^7Q0:CQ0`mPh@033n7Q03GQ1Khch@008N400`oQ

h@0Oh@030>7Q00SQ00<0hN40K>400kkQh@2Wh@033n7Q05gQ00<?hN40>N44_S3Q000Qh@033n7Q01oQ

0`08h@030>7Q06cQ00>nhN40Z>423egQ00<?hN40KN40023Q00<?hN40:n400`3Qh@1/h@03_^7Q0:[Q

0`mJh@033n7Q06gQ000Ph@033n7Q02_Q00<0hN40K>400kkQh@2]h@033n7Q05OQ00<?hN40KN4001oQ

00<?hN40;>400`3Qh@1/h@03_^7Q0:kQ0PmHh@033n7Q06cQ000Oh@033n7Q02cQ00<0hN40K>400kkQ

h@2`h@<?EN400`oQh@1/h@007n400`oQh@0/h@030>7Q06_Q00>nhN40]>400`oQh@1Bh@033n7Q06cQ

000Oh@033n7Q02cQ00<0hN40Jn400kkQh@2eh@8?D^400`oQh@1/h@007^400`oQh@0]h@030>7Q06_Q

00>nhN40]n400`oQh@1?h@033n7Q06cQ000Nh@033n7Q02gQ00<0hN40Jn400kkQh@2hh@<?C^400`oQ

h@1/h@007^400`oQh@0]h@<0Jn400kkQh@2kh@8?C>400`oQh@1/h@007^400`oQh@0]h@030>7Q06[Q

00>nhN40_^400`oQh@19h@033n7Q06cQ000Nh@033n7Q02gQ00<0hN40J^400kkQh@2oh@8?^>4001gQ

00<?hN40;^400`3Qh@1Zh@03_^7Q0<7Q00<?hN40]N4001gQ00<?hN40;^400`3Qh@1Zh@03_^7Q0<;Q

0`ndh@007N400`oQh@0^h@030>7Q06[Q00>nhN40aN400`oQh@2ah@007N400`oQh@0^h@030>7Q06[Q

00>nhN40a^423k7Q000Lh@033n7Q02oQ00<0hN40J^400kkQh@38h@033n7Q03oQ00<?hN40K>4001cQ

00<?hN40;n400`3Qh@1Zh@03_^7Q0<WQ0Ploh@033n7Q06cQ000Lh@033n7Q02oQ00<0hN40J^400kkQ

h@3;h@033n7Q03cQ00<?hN40K>4001cQ00<?hN40;n400`3Qh@1Zh@03_^7Q0<cQ0Pllh@033n7Q06cQ

000Lh@033n7Q02oQ00<0hN40J^400kkQh@3>h@<?>>400`oQh@1]h@007>400`oQh@0_h@<0J^400kkQ

h@3Ah@033n7Q03GQ00<?hN40KN4001cQ00<?hN40;n400`3Qh@1Yh@03_^7Q0=?Q0Pleh@033n7Q06gQ

000Kh@033n7Q033Q00<0hN40JN400kkQh@3Eh@033n7Q03;Q00<?hN40KN4001_Q00<?hN40<>400`3Q

h@1Yh@03_^7Q0=KQ0Plbh@033n7Q06gQ000Kh@033n7Q033Q00<0hN40JN400kkQh@3Hh@033n7Q02oQ

00<?hN40KN4001_Q00<?hN40<>400`3Qh@1Yh@03_^7Q0=WQ0Pl_h@033n7Q06gQ000Kh@033n7Q033Q

00<0hN40JN400kkQh@3Kh@033n7Q02_Q00<?hN40K^4001_Q00<?hN40<>400`3Qh@1Yh@03_^7Q0=cQ

00<?hN40:^400`oQh@1^h@006n400`oQh@0`h@030>7Q06WQ00>nhN40gN423b[Q00<?hN40K^4001_Q

00<?hN40<>400`3Qh@1Xh@03_^7Q0>3Q00<?hN409n400`oQh@1^h@006n400`oQh@0`h@030>7Q06SQ

00>nhN40hN423bOQ00<?hN40K^4001_Q00<?hN40<>400`3Qh@1Xh@03_^7Q0>;Q00<?hN409N400`oQ

h@1^h@006n400`oQh@0`h@<0J>400kkQh@3Sh@033n7Q02?Q00<?hN40Kn4001_Q00<?hN40<>400`3Q

h@1Xh@03_^7Q0>CQ0PlSh@033n7Q06oQ000Jh@033n7Q037Q00<0hN40J>400kkQh@3Vh@033n7Q01oQ

00<?hN40L>4001[Q00<?hN40<N400`3Qh@1Xh@03_^7Q0>OQ0PlOh@033n7Q073Q000Jh@033n7Q037Q

00<0hN40J>400kkQh@3Yh@033n7Q01cQ00<?hN40L>4001[Q00<?hN40<N400`3Qh@1Xh@03_^7Q0>[Q

0PlKh@033n7Q077Q000Jh@033n7Q037Q00<0hN40J>400kkQh@3[h@033n7Q01WQ00<?hN40LN4001[Q

00<?hN40<N400`3Qh@1Xh@03_^7Q0>cQ00<?hN406>400`oQh@1ah@006^400`oQh@0ah@030>7Q06SQ

00>nhN40kN423aOQ00<?hN40L^4001[Q00<?hN40<N400`3Qh@1Xh@03_^7Q0>oQ00<?hN405>400`oQ

h@1bh@006^400`oQh@0ah@030>7Q047Q1@02h@030>7Q01gQ00>nhN408>450003h@00047Q1@02h@03

0>7Q043Q1@02h@030>7Q03?Q00<?hN402^450004h@003d7Q0`03h@030>7Q02_Q000Jh@033n7Q037Q

00<0hN40@n401`3QhN40h@007^400kkQh@0Rh@070>7Qh@3Q0012h@030>7Q00;Q00<0hN40@^401`3Q

hN40h@00=N400`oQh@0;h@030>7Q00?Q00<?hN40?n400`3Qh@02h@030>4002cQ000Jh@033n7Q037Q

0`13h@030>7Q00?Q00<0hN407>400kkQh@0Rh@070>7Qh@3Q0012h@030>7Q00;Q00<0hN40@^401`3Q

hN40h@00=^400`oQh@0:h@030>7Q00;Q00<?0>40@N401`3QhN40h@00;>4001[Q00<?hN40<N400`3Q

h@13h@040>7Qh@807^400kkQh@0Sh@040>7Qh@80@n400`3Qh@03h@030>7Q047Q00<0hN400^400`3Q

h@0fh@033n7Q00WQ00L0hN7Q00l004;Q00L0hN7Q0>4002cQ000Jh@033n7Q037Q00<0hN40@n401@3Q

hN4001oQ00>nhN408n401@3QhN4004CQ00L0hN7Q0>4004?Q00L0hN7Q0>4003SQ00<?hN402>401`3Q

hN4?h@00@N400`3Q0002h@030>4002cQ000Jh@033n7Q037Q00<0hN40@^4200?Q0`0Mh@03_^7Q02;Q

0P04h@80@N4200?Q0`12h@801>400`3Qh@0hh@033n7Q00KQ0P03h@033`0004;Q00<0hN400^400`3Q

h@0[h@006^400`oQh@0ah@030>7Q06OQ00>nhN40m^400`oQh@0:h@033n7Q07KQ000Ih@033n7Q03;Q

00<0hN40In400kkQh@3gh@033n7Q00SQ00<?hN40Mn4001WQ00<?hN40<^400`3Qh@1Wh@03_^7Q0?SQ

0Pl8h@033n7Q07OQ000Ih@033n7Q03;Q00<0hN40In400kkQh@3ih@033n7Q00GQ00<?hN40N>4001WQ

00<?hN40<^400`3Qh@1Wh@03_^7Q0?[Q00<?hN401>400`oQh@1hh@006N400`oQh@0bh@030>7Q06OQ

00>nhN40nn400`oQh@02h@033n7Q07WQ000Ih@033n7Q03;Q00<0hN40In400kkQh@3lh@043n7Q3fSQ

100@h@006N400`oQh@0bh@030>7Q06OQ00>nhN40o>4010oQh@mXh@<04N4000cQ3@000`l0002L0003

_P000?d00PmJ017Q00<0hN403n4001?Q00<0hN400n400`oQh@06h@030>7Q00_Q00<0hN403>400`3Q

h@0<h@030>7Q00_Q00<0hN403>400`3Qh@0<h@030>7Q00cQ00<0hN402n400`3Qh@0<h@030>7Q00cQ

00@0hN6n2^400`3Qh@0<h@030>7Q00cQ00<0hN403>400`3Qh@0;h@030>7Q00cQ00<0hN403>400`3Q

h@0;h@030>7Q00cQ00<0hN403>400`3Qh@0<h@030>7Q00_Q00<0hN403>400`3Qh@0<h@030>7Q00_Q

00<0hN403>400`3Qh@0<h@030>7Q00KQ0Pl4h@030>7Q00_Q00<0hN403>400`3Qh@0<h@030>7Q00_Q

00<0hN403>400`3Qh@0Jh@804N4001?Q00<0hN400n400`oQh@06h@030>7Q00_Q00<0hN403>400`3Q

h@0<h@030>7Q00_Q00<0hN403>400`3Qh@0<h@030>7Q00cQ00<0hN402n400`3Qh@0<h@030>7Q00cQ

00@0hN6n2^400`3Qh@0<h@030>7Q00cQ00<0hN403>400`3Qh@0;h@030>7Q00cQ00<0hN403>400`3Q

h@0;h@030>7Q00cQ00<0hN403>400`3Qh@0<h@030>7Q00_Q00<0hN403>400`3Qh@0<h@030>7Q00_Q

00<0hN403>400`3Qh@0<h@030>7Q00GQ00@?hN4?0n400`3Qh@0;h@030>7Q00cQ00<0hN403>400`3Q

h@0;h@030>7Q00cQ00<0hN40;N4001WQ00<?hN40<^400`3Qh@16h@030>7Q01kQ00>nhN409^400`3Q

h@16h@030>7Q04OQ00<0hN40@>4010oQh@l3h@030>7Q04KQ00<0hN40;N4001WQ00<?hN40<^400`3Q

h@16h@030>7Q01kQ00>nhN409^400`3Qh@16h@030>7Q04OQ00<0hN40?n400`oQh@02h@043n7Q04SQ

00<0hN40;N4001WQ00<?hN40<^400`3Qh@1Wh@03_^7Q0?[Q00<?hN401>400`oQh@1hh@006N400`oQ

h@0bh@030>7Q06OQ00>nhN40nN400`oQh@06h@033n7Q07OQ000Ih@033n7Q03;Q00<0hN40In400kkQ

h@3hh@033n7Q00OQ00<?hN40Mn4001[Q00<?hN40<N400`3Qh@1Wh@03_^7Q0?OQ00<?hN402N400`oQ

h@1fh@006^400`oQh@0ah@030>7Q06OQ00>nhN40m^400`oQh@0:h@033n7Q07KQ000Jh@033n7Q037Q

00<0hN40In400kkQh@3fh@033n7Q00_Q00<?hN40MN4001[Q00<?hN40<N400`3Qh@1Wh@03_^7Q0?GQ

00<?hN403>400`oQh@1eh@006^400`oQh@0ah@<0J>400kkQh@3ch@033n7Q00kQ00<?hN40M>4001[Q

00<?hN40<N400`3Qh@1Xh@03_^7Q0?;Q00<?hN403n400`oQh@1dh@006^400`oQh@0ah@030>7Q06SQ

00>nhN40lN400`oQh@0Ah@033n7Q07?Q000Jh@033n7Q037Q00<0hN40J>400kkQh@3_h@8?5>400`oQ

h@1ch@006^400`oQh@0ah@030>7Q06SQ00>nhN40k^400`oQh@0Eh@033n7Q07;Q000Jh@033n7Q037Q

00<0hN40J>400kkQh@3^h@033n7Q01GQ00<?hN40L^4001[Q00<?hN40<N400`3Qh@1Xh@03_^7Q0>cQ

0PlIh@033n7Q077Q000Jh@033n7Q037Q00<0hN40J>400kkQh@3[h@033n7Q01WQ00<?hN40LN4001[Q

00<?hN40<N400`3Qh@1Xh@03_^7Q0>WQ0PlLh@033n7Q077Q000Jh@033n7Q037Q00<0hN40J>400kkQ

h@3Xh@033n7Q01gQ00<?hN40L>4001[Q00<?hN40<N400`3Qh@1Xh@03_^7Q0>SQ00<?hN407N400`oQ

h@1`h@006^400`oQh@0ah@030>7Q06SQ00>nhN40i^423b3Q00<?hN40L>4001_Q00<?hN40<>4306SQ

00>nhN40iN400`oQh@0Qh@033n7Q06oQ000Kh@033n7Q033Q00<0hN40J>400kkQh@3Sh@8?9>400`oQ

h@1_h@006n400`oQh@0`h@030>7Q06SQ00>nhN40h^400`oQh@0Uh@033n7Q06kQ000Kh@033n7Q033Q

00<0hN40J>400kkQh@3Ph@8?:>400`oQh@1^h@006n400`oQh@0`h@030>7Q06SQ00>nhN40gn400`oQ

h@0Xh@033n7Q06kQ000Kh@033n7Q033Q00<0hN40JN400kkQh@3Lh@8?:n400`oQh@1^h@006n400`oQ

h@0`h@030>7Q06WQ00>nhN40fn400`oQh@0[h@033n7Q06kQ000Kh@033n7Q033Q00<0hN40JN400kkQ

h@3Jh@033n7Q02cQ00<?hN40K^4001_Q00<?hN40<>400`3Qh@1Yh@03_^7Q0=SQ0Pl`h@033n7Q06gQ

000Kh@033n7Q033Q00<0hN40JN400kkQh@3Gh@033n7Q033Q00<?hN40KN4001_Q00<?hN40<>400`3Q

h@1Yh@03_^7Q0=GQ0Plch@033n7Q06gQ000Kh@033n7Q033Q00<0hN40JN400kkQh@3Dh@033n7Q03?Q

00<?hN40KN4001cQ00<?hN40;n4306WQ00>nhN40d^423cKQ00<?hN40KN4001cQ00<?hN40;n400`3Q

h@1Zh@03_^7Q0=3Q00<?hN40=^400`oQh@1]h@007>400`oQh@0_h@030>7Q06[Q00>nhN40c^423cWQ

0Pm^h@007>400`oQh@0_h@030>7Q06[Q00>nhN40cN400`oQh@0jh@033n7Q06cQ000Lh@033n7Q02oQ

00<0hN40J^400kkQh@3;h@8??N400`oQh@1/h@007>400`oQh@0_h@030>7Q06[Q00>nhN40b^400`oQ

h@0mh@033n7Q06cQ000Mh@033n7Q02kQ00<0hN40J^400kkQh@38h@8?[n4001gQ00<?hN40;^400`3Q

h@1Zh@03_^7Q0<GQ0`nah@007N400`oQh@0^h@030>7Q06[Q00>nhN40a>400`oQh@2bh@007N400`oQ

h@0^h@030>7Q06[Q00>nhN40`^423kGQ000Nh@033n7Q02gQ00<0hN40J^400kkQh@31h@033n7Q0;GQ

000Nh@033n7Q02gQ00<0hN40J^400kkQh@30h@033n7Q0;KQ000Nh@033n7Q02gQ0`1Zh@03_^7Q0;kQ

0Pm:h@033n7Q06cQ000Nh@033n7Q02gQ00<0hN40Jn400kkQh@2jh@<?C>400`oQh@1/h@007^400`oQ

h@0]h@030>7Q06_Q00>nhN40^N400`oQh@1=h@033n7Q06cQ000Oh@033n7Q02cQ00<0hN40Jn400kkQ

h@2gh@8?D>400`oQh@1/h@007n400`oQh@0/h@030>7Q06_Q00>nhN40]^400`oQh@1@h@033n7Q06cQ

000Oh@033n7Q02cQ00<0hN40Jn400kkQh@2ch@<?Dn400`oQh@1/h@007n400`oQh@0/h@030>7Q06cQ

00>nhN40/>423eKQ00<?hN40K>4001oQ00<?hN40;>400`3Qh@1/h@03_^7Q0:oQ00<?hN40E^400`oQ

h@1/h@008>400`oQh@0[h@030>7Q06cQ00>nhN40[>433eSQ00<?hN40KN40023Q00<?hN40:n400`3Q

h@1/h@03_^7Q0:[Q0PmKh@033n7Q06gQ000Qh@033n7Q023Q00<0hN401n400`3Qh@1/h@03_^7Q0:WQ

00<?hN40Fn400`oQh@1]h@008N400`oQh@0Oh@030>4000SQ00<0hN40K>400kkQh@2Vh@<?G^400`oQ

h@0ih@Bn<>40027Q00<?hN408N400`3Qh@06h@@0Jn400kkQh@2Th@8?HN400`oQh@0dh@Fn=>40027Q

00<?hN407n4200WQ00<0hN40K>400kkQh@2Sh@033n7Q067Q00<?hN40<>45_SSQ000Rh@033n7Q01kQ

00<0hN402>400`3Qh@1]h@03_^7Q09oQ0`mTh@033n7Q02_Q1Khmh@008^400`oQh@0Nh@<02>400`3Q

h@1]h@03_^7Q09kQ00<?hN40I>423bWQ1Ki1h@008^400`oQh@0Yh@030>7Q06gQ00>nhN40Vn433fOQ

00<?hN409>44_TKQ000Rh@033n7Q02WQ00<0hN40KN400kkQh@2Ih@8?J^400`oQh@0Oh@FnB^4002?Q

00<?hN40:>400`3Qh@1^h@03_^7Q09OQ00<?hN40J^400`oQh@0Lh@>nCn4002?Q00<?hN40:>400`3Q

h@1^h@03_^7Q09CQ0`m]h@033n7Q01OQ1KiBh@009>400`oQh@0Wh@030>7Q06kQ00>nhN40T^423foQ

0PlEh@BnEn4002CQ00<?hN409n400`3Qh@1_h@03_^7Q08kQ0`mah@033n7Q013Q1KiJh@009>400`oQ

h@0Wh@030>7Q06oQ00>nhN40SN400`oQh@1bh@033n7Q00cQ1;iOh@009N400`oQh@0Vh@030>7Q06oQ

00>nhN40R^433gGQ00<?hN402N44_V;Q000Uh@033n7Q02KQ0`1_h@03_^7Q08SQ0Pmhh@033n7Q00GQ

1;iVh@009N400`oQh@0Vh@030>7Q06oQ00>nhN40Q^423gWQ0Pl3h@BnJ^4002KQ00<?hN409N400`3Q

h@1_h@03_^7Q08CQ0Pmkh@033n6n00>nKN4002KQ00<?hN409N400`3Qh@1`h@03_^7Q083Q0`mkh@Bn

LN4002OQ00<?hN409>400`3Qh@1`h@03_^7Q07oQ00<?hN40N>44_P03h@l?07;Q000Wh@033n7Q02CQ

00<0hN40L>400kkQh@1lh@<?N>44_PCQ00<?hN40LN4002SQ00<?hN408n400`3Qh@1ah@03_^7Q07WQ

0Pmhh@>n2>400`oQh@1ah@00:>400`oQh@0Sh@030>7Q077Q00>nhN40M^433gKQ1;h;h@033n7Q077Q

000Yh@033n7Q02;Q00<0hN40LN400kkQh@1eh@033n7Q07CQ0kh>h@8?Ln4002WQ00<?hN408^400`3Q

h@1bh@03_^7Q077Q0`mdh@>n4N400`oQh@1bh@00:^400`oQh@0Qh@030>7Q07;Q00>nhN40K^433g?Q

1;hDh@033n7Q07;Q000Zh@033n7Q027Q00<0hN40L^400kkQh@1/h@8?Ln44_QKQ00<?hN40Ln4002_Q

00<?hN408>4307;Q00>nhN40J^423g?Q0khIh@033n7Q07?Q000[h@033n7Q023Q00<0hN40L^400kkQ

h@1Wh@<?L^43_QcQ00<?hN40Ln4002cQ00<?hN407n400`3Qh@1ch@03_^7Q06CQ0Pmbh@>n7^400`oQ

h@1dh@00;>400`oQh@0Oh@030>7Q07?Q00>nhN40HN433g7Q0khQh@033n7Q07CQ000]h@033n7Q01kQ

00<0hN40M>400kkQh@1Mh@<?LN44_R;Q0Pmfh@00;N400`oQh@0Nh@030>7Q07CQ00>nhN40F^433g;Q

0khUh@033n7Q07GQ000^h@033n7Q01gQ00<0hN40MN400kkQh@1Hh@033n7Q073Q1;hWh@033n7Q07GQ

000_h@033n7Q01cQ00<0hN40MN400kkQh@1Eh@<?LN43_RWQ0Pmgh@00;n400`oQh@0Lh@030>7Q07GQ

00>nhN40D^433g;Q0[h/h@033n7Q07KQ000`h@033n7Q01_Q00<0hN40MN400kkQh@1?h@<?L^43_RgQ

0Pmhh@00<>400`oQh@0Kh@030>7Q07KQ00>nhN40Bn433g?Q0[h`h@033n7Q07OQ000ah@033n7Q01[Q

00<0hN40M^400kkQh@18h@<?M>42_S7Q0Pmih@00<N400`oQh@0Jh@<0Mn400kkQh@14h@<?MN42_S?Q

00<?hN40N>4003;Q00<?hN406N400`3Qh@1gh@03_^7Q04?Q00<?hN40M>42_SGQ00<?hN40N>4003?Q

00<?hN406>400`3Qh@1hh@03_^7Q03oQ0`meh@:n=^400`oQh@1ih@00=>400`oQh@0Gh@030>7Q07SQ

00>nhN40?>433gKQ0[hhh@033n7Q07WQ000dh@033n7Q01OQ00<0hN40N>400kkQh@0ih@<?Mn42_SWQ

0Pmkh@00=N400`oQh@0Fh@030>7Q07SQ00>nhN40=^433gWQ00>nhN40>N400`oQh@1jh@00=^400`oQ

h@0Eh@030>7Q07WQ00>nhN40<^433g[Q0[hkh@8?O>4003OQ00<?hN405>400`3Qh@1jh@03_^7Q02gQ

10mkh@:n?N400`oQh@1kh@00>>400`oQh@0Ch@030>7Q07[Q00>nhN40:^433ggQ0[hnh@8?ON4003WQ

00<?hN404^400`3Qh@1jh@03_^7Q02OQ0`moh@:n?^423gkQ000jh@033n7Q017Q00<0hN40Nn400kkQ

h@0Sh@<?PN400kkQh@0nh@033n7Q07gQ000jh@033n7Q017Q00<0hN40Nn400kkQh@0Ph@<?Pn400kkQ

h@0nh@8?On4003_Q00<?hN404>4307cQ00>nhN407>433hCQ0[i1h@033n7Q07kQ000lh@8?4>400`3Q

h@1mh@03_^7Q01SQ0`n6h@03_^7Q043Q0Pn0h@00?^400`oQh@0=h@030>7Q07gQ00>nhN404n453hSQ

0[i2h@033n7Q07oQ000oh@033n7Q00cQ00<0hN40ON400kkQh@0Ah@8?S>400kkQh@11h@033n7Q083Q

0010h@033n7Q00_Q00<0hN40O^400kkQh@0=h@<?SN42_T;Q0Pn2h@00@N400`oQh@0:h@030>7Q07oQ

00>nhN401n453hoQ00>nhN40@^400`oQh@1@h@033n7Q02kQ0012h@8?2^400`3Qh@1oh@03_^7Q00CQ

0`nCh@03_^7Q04;Q0Pm<h@H?<N4004CQ00<?hN401n400`3Qh@20h@03_^7Q00<?U^400kkQh@11h@8?

B>463cKQ0015h@8?1n400`3Qh@1oh@043kh?3iSQ00>nhN40@^400`oQh@11h@H??>4004OQ00<?hN40

1>400`3Qh@1jh@D?0^400kkQh@2Fh@03_^7Q04;Q0Plnh@H?@N4003gQ1@02h@040>7Qh@8?1>400`3Q

h@1hh@8?2>400kkQh@2Dh@03_^7Q04;Q0Plih@H?An4003oQ00L0hN7Q0>4000CQ00D?hN7Q001eh@D?

2n400kkQh@2Ch@03_^7Q04;Q00<?hN40<n463dcQ000oh@070>7Qh@3Q0005h@033n7Q00@0Kn433a3Q

00>nhN40Tn400kkQh@11h@8?;n463e;Q000oh@070>7Qh@3Q0006h@8?00<0hN40K>443aCQ00>nhN40

TN400kkQh@11h@8?:^473eOQ000oh@070>7Qh@3Q0008h@<?In453aWQ00>nhN40T>400kkQh@10h@8?

9^463egQ000nh@801>400`3Qh@07h@040>7Q3f;Q10lOh@03_^7Q0=;Q00<?hN408>463f;Q001>h@04

0>7Qh@<?Fn443b?Q00>nhN40dN400`oQh@0Lh@D?J>4004kQ00<0hN401>433e;Q1PlXh@03_^7Q0<oQ

0PlHh@H?KN4004kQ00<0hN401n433d[Q1@l_h@03_^7Q0<kQ00<?hN404^453g?Q001>h@030>7Q00[Q

0`m1h@H?=>400kkQh@2<h@03_^7Q03kQ00<?hN403^453gSQ001>h@030>7Q00gQ1@leh@L?>n400kkQ

h@2;h@03_^7Q03kQ00<?hN402>463ggQ001>h@030>7Q01;Q1@lYh@L?@n42_X_Q0[hoh@/?Pn4004kQ

00<0hN405n4;3a;Q30m;h@03_^7Q08[Q00>nhN40bn4004kQ00<0hN408^4B3eSQ00>nhN40RN400kkQ

h@3;h@00C^4308gQ0[j9h@03_^7Q0<_Q001>h@030>7Q08kQ00>nhN40Qn42_/cQ001>h@030>7Q08oQ

0[j8h@03_^7Q0<[Q001>h@030>7Q097Q00>nhN40QN400kkQh@3:h@00C^400`3Qh@2Ah@:nQ^42_/_Q

001>h@030>7Q09?Q00>nhN40Q>400kkQh@39h@00C^400`3Qh@2Ch@:nQN400kkQh@39h@00C^400`3Q

h@2Eh@:nPn400kkQh@39h@00C^400`3Qh@2Fh@:nP>42_/cQ001>h@030>7Q09SQ0[imh@:ncN4004kQ

00<0hN40VN43_WSQ0kk?h@00C^400`3Qh@2Lh@03_^7Q077Q1KkAh@00C^4309gQ0ki/h@FneN4004kQ

00<0hN40Wn43_VKQ1KkIh@00C^400`3Qh@2Qh@>nGn46_]gQ001>h@030>7Q0:CQ0[iGh@Jnhn4004kQ

00<0hN40Y^43_ToQ1[kXh@00C^400`3Qh@2Yh@BnAN46_^kQ001>h@030>7Q0:cQ1Khih@Rnm>4004kQ

00<0hN40/N45_RcQ2Kkkh@00C^400`3Qh@2fh@Vn5n4<__oQ1N4004kQ00<0hN40_n4H__oQ4>4004kQ

00<0hN40on7Wh@00C^400`3Qh@3ohNOQ001>h@<0on7Wh@00C^400`3Qh@3ohNOQ001>h@030>7Q0?oQ

in4004kQ00<0hN40on7Wh@00C^400`3Qh@3ohNOQ001>h@030>7Q0?oQin400?oQon4ih@00on7ohCWQ

003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQ

on4ih@00on7ohCWQ003oh@;Q0P001>400>440003h@0000CQ00<0hN400^400`3Qh@02h@030>7Q0?oQ

6N400?oQ0n400`3Q0009h@050>7Qh@002>400`3Q003ohA[Q003oh@?Q0`02h@@00^400`3Qh@02h@03

0>7Q00SQ00<0hN40on4Hh@00on43h@040>4000SQ00<0hN400^400`3Qh@05h@80on4Kh@00C>420;CQ

00<0hN401n400`3Q0002h@030>4000OQ00<0hN40on4Jh@00CN400`3Qh@2ah@802^40103QhN4300OQ

0`3ohA[Q001;h@<00^400`3Qh@3ohNGQ001:h@080>7Q0>40h@3ohNKQ001:h@080>7Q0>40h@3ohNKQ

001;h@<000CQ0>40on7Vh@00Cn400`3Q003ohNKQ001@h@030>7Q0?oQiN400?oQon4ih@00on7ohCWQ

003ohOoQ>N400?oQon4ih@00on7ohCWQ0000\

\>"],

  ImageRangeCache->{{{0, 566}, {349.313, 0}} -> {12.9375, -13.3449, 0.0135923,

   0.083313}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-1.85165 0.140864 0.309017 0.0231404 [

[.26131 .29652 -6 -9 ]

[.26131 .29652 6 0 ]

[.40217 .29652 -6 -9 ]

[.40217 .29652 6 0 ]

[.54303 .29652 -6 -9 ]

[.54303 .29652 6 0 ]

[.6839 .29652 -6 -9 ]

[.6839 .29652 6 0 ]

[.82476 .29652 -6 -9 ]

[.82476 .29652 6 0 ]

[.96563 .29652 -6 -9 ]

[.96563 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.10794 .07761 -18 -4.5 ]

[.10794 .07761 0 4.5 ]

[.10794 .19332 -12 -4.5 ]

[.10794 .19332 0 4.5 ]

[.10794 .42472 -6 -4.5 ]

[.10794 .42472 0 4.5 ]

[.10794 .54042 -12 -4.5 ]

[.10794 .54042 0 4.5 ]

[.12044 .64303 -7 0 ]

[.12044 .64303 7 16 ]

[.5 .63053 -12 0 ]

[.5 .63053 12 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.26131 .30902 m

.26131 .31527 L

s

[(15)] .26131 .29652 0 1 Mshowa

.40217 .30902 m

.40217 .31527 L

s

[(16)] .40217 .29652 0 1 Mshowa

.54303 .30902 m

.54303 .31527 L

s

[(17)] .54303 .29652 0 1 Mshowa

.6839 .30902 m

.6839 .31527 L

s

[(18)] .6839 .29652 0 1 Mshowa

.82476 .30902 m

.82476 .31527 L

s

[(19)] .82476 .29652 0 1 Mshowa

.96563 .30902 m

.96563 .31527 L

s

[(20)] .96563 .29652 0 1 Mshowa

.125 Mabswid

.14861 .30902 m

.14861 .31277 L

s

.17679 .30902 m

.17679 .31277 L

s

.20496 .30902 m

.20496 .31277 L

s

.23313 .30902 m

.23313 .31277 L

s

.28948 .30902 m

.28948 .31277 L

s

.31765 .30902 m

.31765 .31277 L

s

.34582 .30902 m

.34582 .31277 L

s

.374 .30902 m

.374 .31277 L

s

.43034 .30902 m

.43034 .31277 L

s

.45852 .30902 m

.45852 .31277 L

s

.48669 .30902 m

.48669 .31277 L

s

.51486 .30902 m

.51486 .31277 L

s

.57121 .30902 m

.57121 .31277 L

s

.59938 .30902 m

.59938 .31277 L

s

.62755 .30902 m

.62755 .31277 L

s

.65573 .30902 m

.65573 .31277 L

s

.71207 .30902 m

.71207 .31277 L

s

.74024 .30902 m

.74024 .31277 L

s

.76842 .30902 m

.76842 .31277 L

s

.79659 .30902 m

.79659 .31277 L

s

.85293 .30902 m

.85293 .31277 L

s

.88111 .30902 m

.88111 .31277 L

s

.90928 .30902 m

.90928 .31277 L

s

.93745 .30902 m

.93745 .31277 L

s

.09227 .30902 m

.09227 .31277 L

s

.0641 .30902 m

.0641 .31277 L

s

.03592 .30902 m

.03592 .31277 L

s

.00775 .30902 m

.00775 .31277 L

s

.9938 .30902 m

.9938 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.12044 .07761 m

.12669 .07761 L

s

[(-10)] .10794 .07761 1 0 Mshowa

.12044 .19332 m

.12669 .19332 L

s

[(-5)] .10794 .19332 1 0 Mshowa

.12044 .42472 m

.12669 .42472 L

s

[(5)] .10794 .42472 1 0 Mshowa

.12044 .54042 m

.12669 .54042 L

s

[(10)] .10794 .54042 1 0 Mshowa

.125 Mabswid

.12044 .10075 m

.12419 .10075 L

s

.12044 .12389 m

.12419 .12389 L

s

.12044 .14703 m

.12419 .14703 L

s

.12044 .17017 m

.12419 .17017 L

s

.12044 .21646 m

.12419 .21646 L

s

.12044 .2396 m

.12419 .2396 L

s

.12044 .26274 m

.12419 .26274 L

s

.12044 .28588 m

.12419 .28588 L

s

.12044 .33216 m

.12419 .33216 L

s

.12044 .3553 m

.12419 .3553 L

s

.12044 .37844 m

.12419 .37844 L

s

.12044 .40158 m

.12419 .40158 L

s

.12044 .44786 m

.12419 .44786 L

s

.12044 .471 m

.12419 .471 L

s

.12044 .49414 m

.12419 .49414 L

s

.12044 .51728 m

.12419 .51728 L

s

.12044 .05447 m

.12419 .05447 L

s

.12044 .03133 m

.12419 .03133 L

s

.12044 .00819 m

.12419 .00819 L

s

.12044 .56356 m

.12419 .56356 L

s

.12044 .5867 m

.12419 .5867 L

s

.12044 .60984 m

.12419 .60984 L

s

.25 Mabswid

.12044 0 m

.12044 .61803 L

s

gsave

.12044 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -73 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(k) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(38) show

83.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 1 .4 r

.5 Mabswid

.96422 .09293 m

.96281 .09269 L

.9614 .09244 L

.95999 .09219 L

.95858 .09195 L

.95717 .0917 L

.95577 .09145 L

.95436 .09121 L

.95295 .09096 L

.95154 .09071 L

.95013 .09047 L

.94872 .09022 L

.94731 .08997 L

.9459 .08972 L

.9445 .08947 L

.94309 .08922 L

.94168 .08897 L

.94027 .08872 L

.93886 .08847 L

.93745 .08823 L

.93604 .08798 L

.93464 .08772 L

.93323 .08747 L

.93182 .08722 L

.93041 .08697 L

.929 .08672 L

.92759 .08647 L

.92618 .08622 L

.92478 .08597 L

.92337 .08572 L

.92196 .08546 L

.92055 .08521 L

.91914 .08496 L

.91773 .08471 L

.91632 .08445 L

.91491 .0842 L

.91351 .08395 L

.9121 .08369 L

.91069 .08344 L

.90928 .08319 L

.90787 .08293 L

.90646 .08268 L

.90505 .08243 L

.90365 .08217 L

.90224 .08192 L

.90083 .08166 L

.89942 .08141 L

.89801 .08115 L

.8966 .0809 L

.89519 .08064 L

Mistroke

.89379 .08039 L

.89238 .08013 L

.89097 .07988 L

.88956 .07962 L

.88815 .07937 L

.88674 .07911 L

.88533 .07886 L

.88392 .0786 L

.88252 .07835 L

.88111 .07809 L

.8797 .07784 L

.87829 .07758 L

.87688 .07733 L

.87547 .07707 L

.87406 .07681 L

.87266 .07656 L

.87125 .0763 L

.86984 .07605 L

.86843 .07579 L

.86702 .07554 L

.86561 .07528 L

.8642 .07503 L

.8628 .07477 L

.86139 .07452 L

.85998 .07426 L

.85857 .07401 L

.85716 .07376 L

.85575 .0735 L

.85434 .07325 L

.85293 .073 L

.85153 .07274 L

.85012 .07249 L

.84871 .07224 L

.8473 .07199 L

.84589 .07173 L

.84448 .07148 L

.84307 .07123 L

.84167 .07098 L

.84026 .07073 L

.83885 .07048 L

.83744 .07023 L

.83603 .06998 L

.83462 .06973 L

.83321 .06949 L

.8318 .06924 L

.8304 .06899 L

.82899 .06875 L

.82758 .0685 L

.82617 .06826 L

.82476 .06801 L

Mistroke

.82335 .06777 L

.82194 .06753 L

.82054 .06729 L

.81913 .06705 L

.81772 .06681 L

.81631 .06658 L

.8149 .06634 L

.81349 .0661 L

.81208 .06587 L

.81068 .06564 L

.80927 .0654 L

.80786 .06518 L

.80645 .06495 L

.80504 .06472 L

.80363 .06449 L

.80222 .06427 L

.80081 .06405 L

.79941 .06383 L

.798 .06362 L

.79659 .0634 L

.79518 .06319 L

.79377 .06298 L

.79236 .06277 L

.79095 .06257 L

.78955 .06236 L

.78814 .06216 L

.78673 .06197 L

.78532 .06178 L

.78391 .06159 L

.7825 .0614 L

.78109 .06122 L

.77969 .06104 L

.77828 .06086 L

.77687 .0607 L

.77546 .06053 L

.77405 .06037 L

.77264 .06021 L

.77123 .06006 L

.76982 .05992 L

.76842 .05978 L

.76701 .05964 L

.7656 .05952 L

.76419 .0594 L

.76278 .05929 L

.76137 .05918 L

.75996 .05908 L

.75856 .05899 L

.75715 .05891 L

.75574 .05884 L

.75433 .05877 L

Mistroke

.75292 .05872 L

.75151 .05867 L

.7501 .05864 L

.7487 .05862 L

.74729 .05861 L

.74588 .05861 L

.74447 .05862 L

.74306 .05865 L

.74165 .05869 L

.74024 .05874 L

.73883 .05882 L

.73743 .0589 L

.73602 .059 L

.73461 .05912 L

.7332 .05926 L

.73179 .05942 L

.73038 .0596 L

.72897 .05979 L

.72757 .06002 L

.72616 .06026 L

.72475 .06053 L

.72334 .06083 L

.72193 .06115 L

.72052 .0615 L

.71911 .06188 L

.71771 .06229 L

.7163 .06274 L

.71489 .06323 L

.71348 .06376 L

.71207 .06433 L

.71066 .06495 L

.70925 .06563 L

.70784 .06636 L

.70644 .06717 L

.70503 .06805 L

.70362 .06901 L

.70221 .07009 L

.7008 .07129 L

.69939 .07266 L

.69798 .07425 L

.69658 .07617 L

.69517 .07865 L

.69376 .08264 L

Mfstroke

1 0 0 r

.54585 .13486 m

.54867 .13589 L

.55149 .13692 L

.5543 .13796 L

.55712 .13901 L

.55994 .14006 L

.56275 .14112 L

.56557 .14219 L

.56839 .14327 L

.57121 .14436 L

.57402 .14545 L

.57684 .14655 L

.57966 .14766 L

.58248 .14878 L

.58529 .14991 L

.58811 .15105 L

.59093 .1522 L

.59374 .15336 L

.59656 .15452 L

.59938 .1557 L

.6022 .15688 L

.60501 .15808 L

.60783 .15928 L

.61065 .1605 L

.61347 .16172 L

.61628 .16296 L

.6191 .1642 L

.62192 .16545 L

.62473 .16672 L

.62755 .16799 L

.63037 .16928 L

.63319 .17057 L

.636 .17188 L

.63882 .17319 L

.64164 .17452 L

.64446 .17585 L

.64727 .1772 L

.65009 .17856 L

.65291 .17992 L

.65573 .1813 L

.65854 .18269 L

.66136 .18408 L

.66418 .18549 L

.66699 .18691 L

.66981 .18834 L

.67263 .18978 L

.67545 .19123 L

.67826 .19269 L

.68108 .19416 L

.6839 .19564 L

Mistroke

.68672 .19714 L

.68953 .19864 L

.69235 .20016 L

.69517 .20169 L

.69798 .20323 L

.7008 .20479 L

.70362 .20635 L

.70644 .20793 L

.70925 .20953 L

.71207 .21113 L

.71489 .21275 L

.71771 .21439 L

.72052 .21604 L

.72334 .21771 L

.72616 .2194 L

.72897 .2211 L

.73179 .22282 L

.73461 .22456 L

.73743 .22631 L

.74024 .22809 L

.74306 .22989 L

.74588 .23172 L

.7487 .23356 L

.75151 .23544 L

.75433 .23733 L

.75715 .23926 L

.75996 .24122 L

.76278 .2432 L

.7656 .24522 L

.76842 .24728 L

.77123 .24937 L

.77405 .25151 L

.77687 .25368 L

.77969 .2559 L

.7825 .25817 L

.78532 .26049 L

.78814 .26287 L

.79095 .26531 L

.79377 .26782 L

.79659 .27039 L

.79941 .27305 L

.80222 .27579 L

.80504 .27862 L

.80786 .28156 L

.81068 .28461 L

.81349 .2878 L

.81631 .29113 L

.81913 .29462 L

.82194 .29831 L

.82476 .30221 L

Mistroke

.82758 .30638 L

.8304 .31085 L

.83321 .31571 L

.83603 .32104 L

.83885 .327 L

.84167 .33385 L

.84448 .34203 L

Mfstroke

.84603 .2706 m

.84617 .27006 L

.84631 .26952 L

.84645 .26896 L

.8466 .2684 L

.84674 .26782 L

.84688 .26724 L

.84702 .26664 L

.84716 .26602 L

.8473 .2654 L

.84744 .26476 L

.84758 .26411 L

.84772 .26344 L

.84786 .26276 L

.848 .26206 L

.84815 .26133 L

.84829 .26059 L

.84843 .25982 L

.84857 .25903 L

.84871 .25821 L

.84885 .25737 L

.84899 .25647 L

.84913 .25556 L

.84927 .2546 L

.84941 .25359 L

.84955 .25253 L

.84969 .25139 L

.84984 .25017 L

.84998 .24887 L

.85012 .24744 L

.85026 .24581 L

.8504 .24399 L

.85054 .24176 L

.85068 .23872 L

s

.85068 .22688 m

.85054 .22369 L

.8504 .22138 L

.85026 .21945 L

.85012 .21774 L

.84998 .2162 L

.84984 .21477 L

.84969 .21345 L

.84955 .21221 L

.84941 .21104 L

.84927 .20992 L

.84913 .20886 L

.84899 .20784 L

.84885 .20685 L

.84871 .2059 L

.84857 .20498 L

.84843 .20408 L

.84829 .20321 L

.84815 .20236 L

.848 .20154 L

.84786 .20073 L

.84772 .19995 L

.84758 .19918 L

.84744 .19843 L

.8473 .19769 L

.84716 .19697 L

.84702 .19625 L

.84688 .19555 L

.84674 .19486 L

.8466 .19419 L

.84645 .19352 L

.84631 .19287 L

.84617 .19222 L

.84603 .19158 L

.84589 .19096 L

.84575 .19034 L

.84561 .18972 L

.84547 .18912 L

.84533 .18852 L

.84519 .18793 L

.84505 .18736 L

.84491 .18678 L

.84476 .18622 L

.84462 .18566 L

.84448 .18509 L

.84434 .18455 L

.8442 .184 L

.84406 .18347 L

.84392 .18294 L

.84378 .1824 L

Mistroke

.84307 .17984 L

.84237 .17738 L

.84167 .17502 L

.84096 .17274 L

.84026 .17055 L

.83955 .16841 L

.83885 .16636 L

.83814 .16434 L

.83744 .1624 L

.83674 .1605 L

.83603 .15865 L

.83533 .15684 L

.83462 .15508 L

.83392 .15335 L

.83321 .15165 L

.83251 .15 L

.8318 .14837 L

.8311 .14679 L

.8304 .14523 L

.82969 .14369 L

.82899 .14219 L

.82828 .14071 L

.82758 .13926 L

.82687 .13783 L

.82617 .13643 L

.82547 .13504 L

.82476 .13369 L

.82406 .13235 L

.82335 .13103 L

.82265 .12973 L

.82194 .12845 L

.82124 .1272 L

.82054 .12595 L

.81983 .12473 L

.81913 .12352 L

.81842 .12234 L

.81772 .12116 L

.81701 .12001 L

.81631 .11887 L

.81561 .11775 L

.8149 .11664 L

.8142 .11554 L

.81349 .11446 L

.81279 .11339 L

.81208 .11234 L

.81138 .1113 L

.81068 .11028 L

.80997 .10927 L

.80927 .10827 L

.80856 .10728 L

Mistroke

.80786 .10631 L

.80715 .10535 L

.80645 .1044 L

.80575 .10346 L

.80504 .10254 L

.80434 .10163 L

.80363 .10073 L

.80293 .09984 L

.80222 .09896 L

.80152 .09809 L

.80081 .09723 L

.80011 .09638 L

.79941 .09554 L

.7987 .09471 L

.798 .0939 L

.79729 .09309 L

.79659 .09229 L

.79588 .09151 L

.79518 .09073 L

.79448 .08996 L

.79377 .0892 L

.79307 .08845 L

.79236 .08771 L

.79166 .08698 L

.79095 .08626 L

.79025 .08555 L

.78955 .08484 L

.78884 .08414 L

.78814 .08346 L

.78743 .08278 L

.78673 .08211 L

.78602 .08145 L

.78532 .08079 L

.78462 .08015 L

.78391 .07951 L

.78321 .07888 L

.7825 .07826 L

.7818 .07764 L

.78109 .07704 L

.78039 .07644 L

.77969 .07585 L

.77898 .07526 L

.77828 .07469 L

.77757 .07412 L

.77687 .07355 L

.77616 .073 L

.77546 .07246 L

.77476 .07191 L

.77405 .07138 L

.77335 .07085 L

Mistroke

.77264 .07033 L

.77194 .06982 L

.77123 .06931 L

.77053 .06881 L

.76982 .06832 L

.76912 .06783 L

.76842 .06735 L

.76771 .06687 L

.76701 .0664 L

.7663 .06594 L

.7656 .06548 L

.76489 .06503 L

.76419 .06458 L

.76349 .06415 L

.76278 .06371 L

.76208 .06328 L

.76137 .06286 L

.76067 .06244 L

.75996 .06203 L

.75926 .06163 L

.75856 .06123 L

.75785 .06083 L

.75715 .06044 L

.75644 .06006 L

.75574 .05967 L

.75503 .0593 L

.75433 .05893 L

.75363 .05856 L

.75292 .05821 L

.75222 .05785 L

.75151 .0575 L

.75081 .05715 L

.7501 .05681 L

.7494 .05647 L

.7487 .05614 L

.74799 .05581 L

.74729 .05548 L

.74658 .05516 L

.74588 .05485 L

.74517 .05454 L

.74447 .05423 L

.74377 .05392 L

.74306 .05362 L

.74236 .05332 L

.74165 .05303 L

.74095 .05274 L

.74024 .05246 L

.73954 .05217 L

.73883 .0519 L

.73813 .05162 L

Mistroke

.73743 .05135 L

.73672 .05108 L

.73602 .05081 L

.73531 .05055 L

.73461 .05029 L

.7339 .05004 L

.7332 .04978 L

.7325 .04953 L

.73179 .04928 L

.73109 .04904 L

.73038 .0488 L

.72968 .04856 L

.72897 .04832 L

.72827 .04809 L

.72757 .04786 L

.72686 .04763 L

.72616 .0474 L

.72545 .04718 L

.72475 .04696 L

.72404 .04674 L

.72334 .04652 L

.72264 .0463 L

.72193 .04609 L

.72123 .04588 L

.72052 .04567 L

.71982 .04546 L

.71911 .04526 L

.71841 .04505 L

.71771 .04485 L

.717 .04465 L

.7163 .04446 L

.71559 .04426 L

.71489 .04406 L

.71418 .04387 L

.71348 .04368 L

.71277 .04349 L

.71207 .0433 L

.71137 .04311 L

.71066 .04293 L

.70996 .04274 L

.70925 .04256 L

.70855 .04238 L

.70784 .0422 L

.70714 .04202 L

.70644 .04184 L

.70573 .04167 L

.70503 .04149 L

.70432 .04131 L

.70362 .04114 L

.70291 .04097 L

Mistroke

.70221 .0408 L

.70151 .04063 L

.7008 .04046 L

.7001 .04029 L

.69939 .04013 L

.69869 .03996 L

.69798 .03979 L

.69728 .03963 L

.69658 .03947 L

.69587 .0393 L

.69517 .03914 L

.69446 .03898 L

.69376 .03882 L

.69305 .03866 L

.69235 .0385 L

.69165 .03834 L

.69094 .03818 L

.69024 .03803 L

.68953 .03787 L

.68883 .03772 L

.68812 .03756 L

.68742 .03741 L

.68672 .03725 L

.68601 .0371 L

.68531 .03695 L

.6846 .0368 L

.6839 .03665 L

.68319 .03649 L

.68249 .03634 L

.68178 .03619 L

.68108 .03604 L

.68038 .0359 L

.67967 .03575 L

.67897 .0356 L

.67826 .03545 L

.67756 .03531 L

.67685 .03516 L

.67615 .03501 L

.67545 .03487 L

.67474 .03472 L

.67404 .03458 L

.67333 .03443 L

.67263 .03429 L

.67192 .03415 L

.67122 .034 L

.67052 .03386 L

.66981 .03372 L

.66911 .03358 L

.6684 .03344 L

.6677 .03329 L

Mistroke

.66699 .03315 L

.66629 .03301 L

.66559 .03287 L

.66488 .03273 L

.66418 .03259 L

.66347 .03245 L

.66277 .03232 L

.66206 .03218 L

.66136 .03204 L

.66066 .0319 L

.65995 .03176 L

.65925 .03163 L

.65854 .03149 L

.65784 .03136 L

.65713 .03122 L

.65643 .03108 L

.65573 .03095 L

.65502 .03081 L

.65432 .03068 L

.65361 .03054 L

.65291 .03041 L

.6522 .03028 L

.6515 .03014 L

.65079 .03001 L

.65009 .02988 L

.64939 .02974 L

.64868 .02961 L

.64798 .02948 L

.64727 .02935 L

.64657 .02922 L

.64586 .02909 L

.64516 .02896 L

.64446 .02883 L

.64375 .0287 L

.64305 .02857 L

.64234 .02844 L

.64164 .02831 L

.64093 .02818 L

.64023 .02805 L

.63953 .02793 L

.63882 .0278 L

.63812 .02767 L

.63741 .02754 L

.63671 .02742 L

.636 .02729 L

.6353 .02717 L

.6346 .02704 L

.63389 .02691 L

.63319 .02679 L

.63248 .02667 L

Mistroke

.63178 .02654 L

.63107 .02642 L

.63037 .02629 L

.62967 .02617 L

.62896 .02605 L

.62826 .02593 L

.62755 .02581 L

.62685 .02568 L

.62614 .02556 L

.62544 .02544 L

.62473 .02532 L

.62403 .0252 L

.62333 .02508 L

.62262 .02496 L

.62192 .02484 L

.62121 .02473 L

.62051 .02461 L

.6198 .02449 L

.6191 .02437 L

.6184 .02426 L

.61769 .02414 L

.61699 .02402 L

.61628 .02391 L

.61558 .02379 L

.61487 .02368 L

.61417 .02356 L

.61347 .02345 L

.61276 .02333 L

.61206 .02322 L

.61135 .02311 L

.61065 .023 L

.60994 .02289 L

.60924 .02277 L

.60854 .02266 L

.60783 .02255 L

.60713 .02244 L

.60642 .02234 L

.60572 .02223 L

.60501 .02212 L

.60431 .02201 L

.60361 .0219 L

.6029 .0218 L

.6022 .02169 L

.60149 .02158 L

.60079 .02148 L

.60008 .02137 L

.59938 .02127 L

.59868 .02116 L

.59797 .02106 L

.59727 .02096 L

Mistroke

.59656 .02086 L

.59586 .02076 L

.59515 .02066 L

.59445 .02056 L

.59374 .02045 L

.59304 .02036 L

.59234 .02026 L

.59163 .02016 L

.59093 .02006 L

.59022 .01997 L

.58952 .01987 L

.58881 .01977 L

.58811 .01968 L

.58741 .01958 L

.5867 .01949 L

.586 .0194 L

.58529 .0193 L

.58459 .01921 L

.58388 .01912 L

.58318 .01903 L

.58248 .01894 L

.58177 .01885 L

.58107 .01876 L

.58036 .01868 L

.57966 .01859 L

.57895 .0185 L

.57825 .01842 L

.57755 .01833 L

.57684 .01825 L

.57614 .01817 L

.57543 .01808 L

.57473 .018 L

.57402 .01792 L

.57332 .01784 L

.57262 .01776 L

.57191 .01768 L

.57121 .0176 L

.5705 .01753 L

.5698 .01745 L

.56909 .01737 L

.56839 .0173 L

.56769 .01723 L

.56698 .01715 L

.56628 .01708 L

.56557 .01701 L

.56487 .01694 L

.56416 .01687 L

.56346 .0168 L

.56275 .01674 L

.56205 .01667 L

Mistroke

.56064 .01654 L

.55923 .01641 L

.55782 .01629 L

.55642 .01617 L

.55501 .01605 L

.5536 .01594 L

.55219 .01583 L

.55078 .01573 L

.54937 .01563 L

.54796 .01554 L

.54656 .01545 L

.54515 .01537 L

.54374 .01528 L

.54233 .01521 L

.54092 .01514 L

.53951 .01507 L

.5381 .01501 L

.5367 .01496 L

.53529 .01491 L

.53388 .01487 L

.53247 .01483 L

.53106 .01479 L

.52965 .01477 L

.52824 .01474 L

.52683 .01473 L

.52543 .01472 L

.52402 .01472 L

.52261 .01472 L

.5212 .01473 L

.51979 .01475 L

.51838 .01477 L

.51697 .0148 L

.51557 .01484 L

.51416 .01488 L

.51275 .01493 L

.51134 .01499 L

.50993 .01506 L

.50852 .01514 L

.50711 .01522 L

.5057 .01531 L

.5043 .01541 L

.50289 .01552 L

.50148 .01563 L

.50007 .01576 L

.49866 .0159 L

.49725 .01604 L

.49584 .01619 L

.49444 .01636 L

.49303 .01653 L

.49162 .01671 L

Mistroke

.49021 .0169 L

.4888 .01711 L

.48739 .01732 L

.48598 .01755 L

.48458 .01778 L

.48317 .01803 L

.48176 .01829 L

.48035 .01856 L

.47894 .01885 L

.47753 .01914 L

.47612 .01945 L

.47471 .01977 L

.47331 .0201 L

.4719 .02045 L

.47049 .02081 L

.46908 .02119 L

.46767 .02158 L

.46626 .02199 L

.46485 .02241 L

.46345 .02284 L

.46204 .02329 L

.46063 .02376 L

.45922 .02424 L

.45781 .02474 L

.4564 .02526 L

.45499 .0258 L

.45359 .02635 L

.45218 .02692 L

.45077 .02751 L

.44936 .02812 L

.44795 .02875 L

.44654 .0294 L

.44513 .03007 L

.44372 .03076 L

.44232 .03147 L

.44091 .03221 L

.4395 .03297 L

.43809 .03375 L

.43668 .03455 L

.43527 .03538 L

.43386 .03623 L

.43246 .03711 L

.43105 .03802 L

.42964 .03895 L

.42823 .03991 L

.42682 .04089 L

.42541 .04191 L

.424 .04296 L

.4226 .04403 L

.42119 .04514 L

Mistroke

.41978 .04628 L

.41837 .04745 L

.41696 .04866 L

.41555 .0499 L

.41414 .05118 L

.41273 .0525 L

.41133 .05385 L

.40992 .05524 L

.40851 .05667 L

.4071 .05814 L

.40569 .05966 L

.40428 .06122 L

.40287 .06283 L

.40147 .06448 L

.40006 .06618 L

.39865 .06793 L

.39724 .06974 L

.39583 .07159 L

.39442 .0735 L

.39301 .07547 L

.39161 .0775 L

.3902 .07959 L

.38879 .08175 L

.38738 .08397 L

.38597 .08626 L

.38456 .08862 L

.38315 .09106 L

.38174 .09357 L

.38034 .09617 L

.37893 .09885 L

.37752 .10163 L

.37611 .10449 L

.3747 .10746 L

.37329 .11053 L

.37188 .11372 L

.37048 .11701 L

.36907 .12044 L

.36766 .12399 L

.36625 .12769 L

.36484 .13153 L

.36343 .13554 L

.36202 .13971 L

.36062 .14408 L

.35921 .14865 L

.3578 .15344 L

.35639 .15848 L

.35498 .1638 L

.35357 .16941 L

.35216 .17538 L

.35075 .18173 L

Mistroke

.34935 .18855 L

.34794 .19591 L

.34653 .20393 L

.34512 .21278 L

.34371 .2227 L

.3423 .23415 L

.34089 .24795 L

.33949 .26636 L

.33816 .30902 L

Mfstroke

0 1 .4 r

.6939 .09192 m

.69404 .09246 L

.69418 .09296 L

.69432 .09343 L

.69446 .09386 L

.69517 .09571 L

.69587 .09725 L

.69658 .0986 L

.69728 .09982 L

.69798 .10094 L

.69869 .10198 L

.69939 .10295 L

.7001 .10388 L

.7008 .10476 L

.70151 .1056 L

.70221 .1064 L

.70291 .10718 L

.70362 .10792 L

.70432 .10865 L

.70503 .10935 L

.70573 .11003 L

.70644 .11069 L

.70714 .11134 L

.70784 .11197 L

.70855 .11259 L

.70925 .11319 L

.70996 .11377 L

.71066 .11435 L

.71137 .11492 L

.71207 .11547 L

.71277 .11601 L

.71348 .11655 L

.71418 .11707 L

.71489 .11759 L

.71559 .1181 L

.7163 .1186 L

.717 .11909 L

.71771 .11957 L

.71841 .12005 L

.71911 .12053 L

.71982 .12099 L

.72052 .12145 L

.72123 .1219 L

.72193 .12235 L

.72264 .12279 L

.72334 .12323 L

.72404 .12366 L

.72475 .12409 L

.72545 .12451 L

.72616 .12493 L

Mistroke

.72686 .12534 L

.72757 .12575 L

.72827 .12615 L

.72897 .12655 L

.72968 .12695 L

.73038 .12734 L

.73109 .12773 L

.73179 .12812 L

.7325 .1285 L

.7332 .12888 L

.7339 .12925 L

.73461 .12962 L

.73531 .12999 L

.73602 .13036 L

.73672 .13072 L

.73743 .13108 L

.73813 .13144 L

.73883 .13179 L

.73954 .13214 L

.74024 .13249 L

.74095 .13283 L

.74165 .13318 L

.74236 .13352 L

.74306 .13386 L

.74377 .13419 L

.74447 .13452 L

.74517 .13485 L

.74588 .13518 L

.74658 .13551 L

.74729 .13583 L

.74799 .13616 L

.7487 .13648 L

.7494 .13679 L

.7501 .13711 L

.75081 .13743 L

.75151 .13774 L

.75222 .13805 L

.75292 .13836 L

.75363 .13866 L

.75433 .13897 L

.75503 .13927 L

.75574 .13957 L

.75644 .13987 L

.75715 .14017 L

.75785 .14046 L

.75856 .14076 L

.75926 .14105 L

.75996 .14134 L

.76067 .14163 L

.76137 .14192 L

Mistroke

.76208 .14221 L

.76278 .14249 L

.76349 .14278 L

.76419 .14306 L

.76489 .14334 L

.7656 .14362 L

.7663 .1439 L

.76701 .14418 L

.76771 .14445 L

.76842 .14473 L

.76912 .145 L

.76982 .14527 L

.77053 .14555 L

.77123 .14581 L

.77194 .14608 L

.77264 .14635 L

.77335 .14662 L

.77405 .14688 L

.77476 .14715 L

.77546 .14741 L

.77616 .14767 L

.77687 .14793 L

.77757 .14819 L

.77828 .14845 L

.77898 .14871 L

.77969 .14896 L

.78039 .14922 L

.78109 .14947 L

.7818 .14972 L

.7825 .14998 L

.78321 .15023 L

.78391 .15048 L

.78462 .15073 L

.78532 .15098 L

.78602 .15122 L

.78673 .15147 L

.78743 .15172 L

.78814 .15196 L

.78884 .15221 L

.78955 .15245 L

.79025 .15269 L

.79095 .15293 L

.79166 .15317 L

.79236 .15341 L

.79307 .15365 L

.79377 .15389 L

.79448 .15413 L

.79518 .15437 L

.79588 .1546 L

.79659 .15484 L

Mistroke

.79729 .15507 L

.798 .15531 L

.7987 .15554 L

.79941 .15577 L

.80011 .156 L

.80081 .15623 L

.80152 .15646 L

.80222 .15669 L

.80293 .15692 L

.80363 .15715 L

.80434 .15738 L

.80504 .1576 L

.80575 .15783 L

.80645 .15806 L

.80715 .15828 L

.80786 .1585 L

.80856 .15873 L

.80927 .15895 L

.80997 .15917 L

.81068 .15939 L

.81138 .15962 L

.81208 .15984 L

.81279 .16006 L

.81349 .16027 L

.8142 .16049 L

.8149 .16071 L

.81561 .16093 L

.81631 .16115 L

.81701 .16136 L

.81772 .16158 L

.81842 .16179 L

.81913 .16201 L

.81983 .16222 L

.82054 .16243 L

.82124 .16265 L

.82194 .16286 L

.82265 .16307 L

.82335 .16328 L

.82406 .16349 L

.82476 .16371 L

.82547 .16392 L

.82617 .16412 L

.82687 .16433 L

.82758 .16454 L

.82828 .16475 L

.82899 .16496 L

.82969 .16516 L

.8304 .16537 L

.8311 .16558 L

.8318 .16578 L

Mistroke

.83251 .16599 L

.83321 .16619 L

.83392 .1664 L

.83462 .1666 L

.83533 .1668 L

.83603 .16701 L

.83674 .16721 L

.83744 .16741 L

.83814 .16761 L

.83885 .16781 L

.83955 .16802 L

.84026 .16822 L

.84096 .16842 L

.84167 .16861 L

.84237 .16881 L

.84307 .16901 L

.84378 .16921 L

.84448 .16941 L

.84519 .16961 L

.84589 .1698 L

.8466 .17 L

.8473 .1702 L

.848 .17039 L

.84871 .17059 L

.84941 .17078 L

.85012 .17098 L

.85082 .17117 L

.85153 .17137 L

.85223 .17156 L

.85293 .17175 L

.85364 .17195 L

.85434 .17214 L

.85505 .17233 L

.85575 .17252 L

.85646 .17272 L

.85716 .17291 L

.85786 .1731 L

.85857 .17329 L

.85927 .17348 L

.85998 .17367 L

.86068 .17386 L

.86139 .17405 L

.86209 .17424 L

.8628 .17442 L

.8635 .17461 L

.8642 .1748 L

.86491 .17499 L

.86561 .17517 L

.86632 .17536 L

.86702 .17555 L

Mistroke

.86773 .17573 L

.86843 .17592 L

.86913 .17611 L

.86984 .17629 L

.87054 .17648 L

.87125 .17666 L

.87195 .17685 L

.87266 .17703 L

.87336 .17721 L

.87406 .1774 L

.87477 .17758 L

.87547 .17776 L

.87618 .17795 L

.87688 .17813 L

.87759 .17831 L

.87829 .17849 L

.87899 .17867 L

.8797 .17886 L

.8804 .17904 L

.88111 .17922 L

.88181 .1794 L

.88252 .17958 L

.88322 .17976 L

.88392 .17994 L

.88463 .18012 L

.88533 .1803 L

.88604 .18048 L

.88674 .18065 L

.88745 .18083 L

.88815 .18101 L

.88885 .18119 L

.88956 .18137 L

.89026 .18154 L

.89097 .18172 L

.89167 .1819 L

.89238 .18207 L

.89308 .18225 L

.89379 .18243 L

.89449 .1826 L

.89519 .18278 L

.8959 .18295 L

.8966 .18313 L

.89731 .1833 L

.89801 .18348 L

.89872 .18365 L

.89942 .18383 L

.90012 .184 L

.90083 .18417 L

.90153 .18435 L

.90224 .18452 L

Mistroke

.90294 .18469 L

.90365 .18487 L

.90435 .18504 L

.90505 .18521 L

.90576 .18538 L

.90646 .18556 L

.90717 .18573 L

.90787 .1859 L

.90858 .18607 L

.90928 .18624 L

.90998 .18641 L

.91069 .18658 L

.91139 .18675 L

.9121 .18692 L

.9128 .18709 L

.91351 .18726 L

.91421 .18743 L

.91491 .1876 L

.91562 .18777 L

.91632 .18794 L

.91703 .18811 L

.91773 .18828 L

.91844 .18845 L

.91914 .18861 L

.91984 .18878 L

.92055 .18895 L

.92125 .18912 L

.92196 .18929 L

.92266 .18945 L

.92337 .18962 L

.92407 .18979 L

.92478 .18995 L

.92548 .19012 L

.92618 .19029 L

.92689 .19045 L

.92759 .19062 L

.9283 .19078 L

.929 .19095 L

.92971 .19111 L

.93041 .19128 L

.93111 .19144 L

.93182 .19161 L

.93252 .19177 L

.93323 .19194 L

.93393 .1921 L

.93464 .19227 L

.93534 .19243 L

.93604 .19259 L

.93675 .19276 L

.93745 .19292 L

Mistroke

.93816 .19308 L

.93886 .19325 L

.93957 .19341 L

.94027 .19357 L

.94097 .19373 L

.94168 .1939 L

.94238 .19406 L

.94309 .19422 L

.94379 .19438 L

.9445 .19454 L

.9452 .1947 L

.9459 .19487 L

.94661 .19503 L

.94731 .19519 L

.94802 .19535 L

.94872 .19551 L

.94943 .19567 L

.95013 .19583 L

.95083 .19599 L

.95154 .19615 L

.95224 .19631 L

.95295 .19647 L

.95365 .19663 L

.95436 .19679 L

.95506 .19695 L

.95577 .1971 L

.95647 .19726 L

.95717 .19742 L

.95788 .19758 L

.95858 .19774 L

.95929 .1979 L

.95999 .19806 L

.9607 .19821 L

.9614 .19837 L

.9621 .19853 L

.96281 .19869 L

.96351 .19884 L

.96422 .199 L

.96492 .19916 L

.96563 .19931 L

.96633 .19947 L

.96703 .19963 L

.96774 .19978 L

.96844 .19994 L

.96915 .2001 L

.96985 .20025 L

.97056 .20041 L

.97126 .20056 L

.97196 .20072 L

.97267 .20088 L

Mistroke

.97337 .20103 L

.97408 .20119 L

.97478 .20134 L

.97549 .2015 L

.97619 .20165 L

Mfstroke

1 0 0 r

.54163 .13334 m

.54022 .13284 L

.53881 .13233 L

.5374 .13183 L

.53599 .13133 L

.53458 .13084 L

.53317 .13034 L

.53176 .12985 L

.53036 .12935 L

.52895 .12886 L

.52754 .12837 L

.52613 .12788 L

.52472 .1274 L

.52331 .12691 L

.5219 .12643 L

.5205 .12594 L

.51909 .12546 L

.51768 .12498 L

.51627 .12451 L

.51486 .12403 L

.51345 .12355 L

.51204 .12308 L

.51064 .12261 L

.50923 .12214 L

.50782 .12167 L

.50641 .1212 L

.505 .12073 L

.50359 .12027 L

.50218 .1198 L

.50077 .11934 L

.49937 .11888 L

.49796 .11841 L

.49655 .11795 L

.49514 .1175 L

.49373 .11704 L

.49232 .11658 L

.49091 .11613 L

.48951 .11568 L

.4881 .11522 L

.48669 .11477 L

.48528 .11432 L

.48387 .11387 L

.48246 .11342 L

.48105 .11298 L

.47965 .11253 L

.47824 .11209 L

.47683 .11164 L

.47542 .1112 L

.47401 .11076 L

.4726 .11032 L

Mistroke

.47119 .10988 L

.46978 .10944 L

.46838 .10901 L

.46697 .10857 L

.46556 .10814 L

.46415 .1077 L

.46274 .10727 L

.46133 .10684 L

.45992 .10641 L

.45852 .10598 L

.45711 .10555 L

.4557 .10513 L

.45429 .1047 L

.45288 .10427 L

.45147 .10385 L

.45006 .10343 L

.44866 .103 L

.44725 .10258 L

.44584 .10216 L

.44443 .10174 L

.44302 .10133 L

.44161 .10091 L

.4402 .10049 L

.43879 .10008 L

.43739 .09967 L

.43598 .09925 L

.43457 .09884 L

.43316 .09843 L

.43175 .09802 L

.43034 .09761 L

.42893 .0972 L

.42753 .0968 L

.42612 .09639 L

.42471 .09599 L

.4233 .09558 L

.42189 .09518 L

.42048 .09478 L

.41907 .09438 L

.41767 .09398 L

.41626 .09358 L

.41485 .09319 L

.41344 .09279 L

.41203 .09239 L

.41062 .092 L

.40921 .09161 L

.4078 .09122 L

.4064 .09083 L

.40499 .09044 L

.40358 .09005 L

.40217 .08966 L

Mistroke

.40076 .08928 L

.39935 .08889 L

.39794 .08851 L

.39654 .08813 L

.39513 .08774 L

.39372 .08736 L

.39231 .08698 L

.3909 .08661 L

.38949 .08623 L

.38808 .08586 L

.38667 .08548 L

.38527 .08511 L

.38386 .08474 L

.38245 .08437 L

.38104 .084 L

.37963 .08363 L

.37822 .08326 L

.37681 .0829 L

.37541 .08254 L

.374 .08217 L

.37259 .08181 L

.37118 .08145 L

.36977 .0811 L

.36836 .08074 L

.36695 .08038 L

.36555 .08003 L

.36414 .07968 L

.36273 .07933 L

.36132 .07898 L

.35991 .07863 L

.3585 .07828 L

.35709 .07794 L

.35568 .07759 L

.35428 .07725 L

.35287 .07691 L

.35146 .07657 L

.35005 .07624 L

.34864 .0759 L

.34723 .07557 L

.34582 .07524 L

.34442 .07491 L

.34301 .07458 L

.3416 .07425 L

.34019 .07393 L

.33878 .07361 L

.33737 .07328 L

.33596 .07296 L

.33456 .07265 L

.33315 .07233 L

.33174 .07202 L

Mistroke

.33033 .07171 L

.32892 .0714 L

.32751 .07109 L

.3261 .07078 L

.32469 .07048 L

.32329 .07018 L

.32188 .06988 L

.32047 .06958 L

.31906 .06928 L

.31765 .06899 L

.31624 .0687 L

.31483 .06841 L

.31343 .06813 L

.31202 .06784 L

.31061 .06756 L

.3092 .06728 L

.30779 .06701 L

.30638 .06673 L

.30497 .06646 L

.30357 .06619 L

.30216 .06592 L

.30075 .06566 L

.29934 .0654 L

.29793 .06514 L

.29652 .06488 L

.29511 .06463 L

.2937 .06438 L

.2923 .06413 L

.29089 .06389 L

.28948 .06365 L

.28807 .0634 L

.28666 .06317 L

.28525 .06294 L

.28384 .06271 L

.28244 .06248 L

.28103 .06225 L

.27962 .06203 L

.27821 .06182 L

.2768 .0616 L

.27539 .06139 L

.27398 .06119 L

.27258 .06098 L

.27117 .06078 L

.26976 .06059 L

.26835 .06039 L

.26694 .0602 L

.26553 .06002 L

.26412 .05984 L

.26271 .05966 L

.26131 .05948 L

Mistroke

.2599 .05931 L

.25849 .05915 L

.25708 .05898 L

.25567 .05883 L

.25426 .05867 L

.25285 .05852 L

.25145 .05838 L

.25004 .05824 L

.24863 .0581 L

.24722 .05797 L

.24581 .05784 L

.2444 .05772 L

.24299 .0576 L

.24159 .05749 L

.24018 .05738 L

.23877 .05727 L

.23736 .05717 L

.23595 .05708 L

.23454 .05699 L

.23313 .05691 L

.23172 .05683 L

.23032 .05676 L

.22891 .05669 L

.2275 .05663 L

.22609 .05657 L

.22468 .05652 L

.22327 .05648 L

.22186 .05644 L

.22046 .05641 L

.21905 .05638 L

.21764 .05636 L

.21623 .05635 L

.21482 .05634 L

.21341 .05634 L

.212 .05635 L

.2106 .05636 L

.20919 .05638 L

.20778 .0564 L

.20637 .05644 L

.20496 .05648 L

.20355 .05653 L

.20214 .05658 L

.20073 .05664 L

.19933 .05671 L

.19792 .05679 L

.19651 .05688 L

.1951 .05697 L

.19369 .05707 L

.19228 .05718 L

.19087 .0573 L

Mistroke

.18524 .05786 L

.17961 .05857 L

.17397 .05944 L

.16834 .06047 L

.1627 .06168 L

.15707 .06309 L

.15143 .0647 L

.1458 .06653 L

.14016 .0686 L

.13453 .07093 L

.12889 .07355 L

.12326 .07647 L

.11762 .07971 L

.11199 .08332 L

.10636 .08733 L

.10072 .09178 L

.09509 .0967 L

.08945 .10217 L

.08382 .10824 L

.07818 .115 L

.07255 .12254 L

.06691 .13099 L

.06128 .14053 L

.05564 .15137 L

.05001 .16384 L

.04438 .17847 L

.03874 .19611 L

.03311 .21861 L

.02747 .25147 L

.02381 .30902 L

Mfstroke

0 1 .4 r

.96422 .5251 m

.96281 .52535 L

.9614 .52559 L

.95999 .52584 L

.95858 .52609 L

.95717 .52633 L

.95577 .52658 L

.95436 .52683 L

.95295 .52707 L

.95154 .52732 L

.95013 .52757 L

.94872 .52782 L

.94731 .52806 L

.9459 .52831 L

.9445 .52856 L

.94309 .52881 L

.94168 .52906 L

.94027 .52931 L

.93886 .52956 L

.93745 .52981 L

.93604 .53006 L

.93464 .53031 L

.93323 .53056 L

.93182 .53081 L

.93041 .53106 L

.929 .53131 L

.92759 .53156 L

.92618 .53182 L

.92478 .53207 L

.92337 .53232 L

.92196 .53257 L

.92055 .53282 L

.91914 .53308 L

.91773 .53333 L

.91632 .53358 L

.91491 .53383 L

.91351 .53409 L

.9121 .53434 L

.91069 .53459 L

.90928 .53485 L

.90787 .5351 L

.90646 .53535 L

.90505 .53561 L

.90365 .53586 L

.90224 .53612 L

.90083 .53637 L

.89942 .53663 L

.89801 .53688 L

.8966 .53714 L

.89519 .53739 L

Mistroke

.89379 .53765 L

.89238 .5379 L

.89097 .53816 L

.88956 .53841 L

.88815 .53867 L

.88674 .53892 L

.88533 .53918 L

.88392 .53943 L

.88252 .53969 L

.88111 .53994 L

.8797 .5402 L

.87829 .54045 L

.87688 .54071 L

.87547 .54096 L

.87406 .54122 L

.87266 .54147 L

.87125 .54173 L

.86984 .54199 L

.86843 .54224 L

.86702 .54249 L

.86561 .54275 L

.8642 .54301 L

.8628 .54326 L

.86139 .54351 L

.85998 .54377 L

.85857 .54402 L

.85716 .54428 L

.85575 .54453 L

.85434 .54478 L

.85293 .54504 L

.85153 .54529 L

.85012 .54554 L

.84871 .5458 L

.8473 .54605 L

.84589 .5463 L

.84448 .54655 L

.84307 .5468 L

.84167 .54705 L

.84026 .5473 L

.83885 .54755 L

.83744 .5478 L

.83603 .54805 L

.83462 .5483 L

.83321 .54855 L

.8318 .5488 L

.8304 .54904 L

.82899 .54929 L

.82758 .54953 L

.82617 .54978 L

.82476 .55002 L

Mistroke

.82335 .55026 L

.82194 .5505 L

.82054 .55074 L

.81913 .55098 L

.81772 .55122 L

.81631 .55146 L

.8149 .5517 L

.81349 .55193 L

.81208 .55216 L

.81068 .5524 L

.80927 .55263 L

.80786 .55286 L

.80645 .55309 L

.80504 .55331 L

.80363 .55354 L

.80222 .55376 L

.80081 .55398 L

.79941 .5542 L

.798 .55442 L

.79659 .55463 L

.79518 .55484 L

.79377 .55505 L

.79236 .55526 L

.79095 .55547 L

.78955 .55567 L

.78814 .55587 L

.78673 .55607 L

.78532 .55626 L

.78391 .55645 L

.7825 .55664 L

.78109 .55682 L

.77969 .55699 L

.77828 .55717 L

.77687 .55734 L

.77546 .5575 L

.77405 .55767 L

.77264 .55782 L

.77123 .55797 L

.76982 .55812 L

.76842 .55826 L

.76701 .55839 L

.7656 .55851 L

.76419 .55863 L

.76278 .55875 L

.76137 .55885 L

.75996 .55895 L

.75856 .55904 L

.75715 .55913 L

.75574 .5592 L

.75433 .55926 L

Mistroke

.75292 .55932 L

.75151 .55936 L

.7501 .5594 L

.7487 .55942 L

.74729 .55943 L

.74588 .55943 L

.74447 .55941 L

.74306 .55939 L

.74165 .55935 L

.74024 .55929 L

.73883 .55922 L

.73743 .55913 L

.73602 .55903 L

.73461 .55891 L

.7332 .55877 L

.73179 .55861 L

.73038 .55844 L

.72897 .55824 L

.72757 .55801 L

.72616 .55777 L

.72475 .5575 L

.72334 .55721 L

.72193 .55689 L

.72052 .55654 L

.71911 .55616 L

.71771 .55574 L

.7163 .55529 L

.71489 .5548 L

.71348 .55428 L

.71207 .5537 L

.71066 .55308 L

.70925 .5524 L

.70784 .55167 L

.70644 .55087 L

.70503 .54999 L

.70362 .54902 L

.70221 .54795 L

.7008 .54675 L

.69939 .54538 L

.69798 .54378 L

.69658 .54187 L

.69517 .53938 L

.69376 .5354 L

Mfstroke

1 0 0 r

.54585 .48317 m

.54867 .48214 L

.55149 .48111 L

.5543 .48007 L

.55712 .47903 L

.55994 .47797 L

.56275 .47691 L

.56557 .47584 L

.56839 .47476 L

.57121 .47368 L

.57402 .47258 L

.57684 .47148 L

.57966 .47037 L

.58248 .46925 L

.58529 .46812 L

.58811 .46698 L

.59093 .46583 L

.59374 .46468 L

.59656 .46351 L

.59938 .46234 L

.6022 .46115 L

.60501 .45996 L

.60783 .45875 L

.61065 .45754 L

.61347 .45631 L

.61628 .45508 L

.6191 .45383 L

.62192 .45258 L

.62473 .45131 L

.62755 .45004 L

.63037 .44876 L

.63319 .44746 L

.636 .44616 L

.63882 .44484 L

.64164 .44352 L

.64446 .44218 L

.64727 .44083 L

.65009 .43948 L

.65291 .43811 L

.65573 .43673 L

.65854 .43535 L

.66136 .43395 L

.66418 .43254 L

.66699 .43112 L

.66981 .4297 L

.67263 .42826 L

.67545 .42681 L

.67826 .42535 L

.68108 .42387 L

.6839 .42239 L

Mistroke

.68672 .4209 L

.68953 .41939 L

.69235 .41787 L

.69517 .41634 L

.69798 .4148 L

.7008 .41325 L

.70362 .41168 L

.70644 .4101 L

.70925 .40851 L

.71207 .4069 L

.71489 .40528 L

.71771 .40364 L

.72052 .40199 L

.72334 .40032 L

.72616 .39864 L

.72897 .39694 L

.73179 .39522 L

.73461 .39348 L

.73743 .39172 L

.74024 .38994 L

.74306 .38814 L

.74588 .38632 L

.7487 .38447 L

.75151 .3826 L

.75433 .3807 L

.75715 .37877 L

.75996 .37682 L

.76278 .37483 L

.7656 .37281 L

.76842 .37075 L

.77123 .36866 L

.77405 .36653 L

.77687 .36435 L

.77969 .36213 L

.7825 .35986 L

.78532 .35754 L

.78814 .35516 L

.79095 .35272 L

.79377 .35022 L

.79659 .34764 L

.79941 .34499 L

.80222 .34225 L

.80504 .33941 L

.80786 .33647 L

.81068 .33342 L

.81349 .33023 L

.81631 .32691 L

.81913 .32341 L

.82194 .31973 L

.82476 .31582 L

Mistroke

.82758 .31166 L

.8304 .30718 L

.83321 .30233 L

.83603 .297 L

.83885 .29103 L

.84167 .28419 L

.84448 .27601 L

Mfstroke

.84603 .34743 m

.84617 .34797 L

.84631 .34852 L

.84645 .34907 L

.8466 .34963 L

.84674 .35021 L

.84688 .3508 L

.84702 .3514 L

.84716 .35201 L

.8473 .35263 L

.84744 .35327 L

.84758 .35392 L

.84772 .35459 L

.84786 .35528 L

.848 .35598 L

.84815 .3567 L

.84829 .35745 L

.84843 .35821 L

.84857 .359 L

.84871 .35982 L

.84885 .36067 L

.84899 .36156 L

.84913 .36247 L

.84927 .36343 L

.84941 .36445 L

.84955 .36551 L

.84969 .36664 L

.84984 .36786 L

.84998 .36916 L

.85012 .3706 L

.85026 .37222 L

.8504 .37404 L

.85054 .37627 L

.85068 .37932 L

s

.85068 .39115 m

.85054 .39434 L

.8504 .39665 L

.85026 .39859 L

.85012 .4003 L

.84998 .40184 L

.84984 .40326 L

.84969 .40458 L

.84955 .40582 L

.84941 .40699 L

.84927 .40812 L

.84913 .40917 L

.84899 .4102 L

.84885 .41119 L

.84871 .41213 L

.84857 .41306 L

.84843 .41395 L

.84829 .41482 L

.84815 .41567 L

.848 .41649 L

.84786 .4173 L

.84772 .41809 L

.84758 .41885 L

.84744 .41961 L

.8473 .42034 L

.84716 .42107 L

.84702 .42178 L

.84688 .42249 L

.84674 .42317 L

.8466 .42384 L

.84645 .42451 L

.84631 .42516 L

.84617 .42581 L

.84603 .42645 L

.84589 .42707 L

.84575 .42769 L

.84561 .42831 L

.84547 .42892 L

.84533 .42951 L

.84519 .4301 L

.84505 .43068 L

.84491 .43125 L

.84476 .43182 L

.84462 .43238 L

.84448 .43294 L

.84434 .43349 L

.8442 .43403 L

.84406 .43457 L

.84392 .4351 L

.84378 .43563 L

Mistroke

.84307 .43819 L

.84237 .44065 L

.84167 .44301 L

.84096 .44529 L

.84026 .44749 L

.83955 .44962 L

.83885 .45168 L

.83814 .45369 L

.83744 .45564 L

.83674 .45753 L

.83603 .45938 L

.83533 .46119 L

.83462 .46296 L

.83392 .46468 L

.83321 .46638 L

.83251 .46803 L

.8318 .46966 L

.8311 .47125 L

.8304 .4728 L

.82969 .47434 L

.82899 .47584 L

.82828 .47732 L

.82758 .47878 L

.82687 .4802 L

.82617 .48161 L

.82547 .48299 L

.82476 .48435 L

.82406 .48569 L

.82335 .48701 L

.82265 .4883 L

.82194 .48958 L

.82124 .49084 L

.82054 .49208 L

.81983 .4933 L

.81913 .49451 L

.81842 .4957 L

.81772 .49687 L

.81701 .49803 L

.81631 .49916 L

.81561 .50029 L

.8149 .5014 L

.8142 .50249 L

.81349 .50357 L

.81279 .50464 L

.81208 .50569 L

.81138 .50673 L

.81068 .50775 L

.80997 .50877 L

.80927 .50976 L

.80856 .51075 L

Mistroke

.80786 .51172 L

.80715 .51268 L

.80645 .51363 L

.80575 .51457 L

.80504 .51549 L

.80434 .51641 L

.80363 .51731 L

.80293 .5182 L

.80222 .51908 L

.80152 .51995 L

.80081 .52081 L

.80011 .52166 L

.79941 .52249 L

.7987 .52332 L

.798 .52414 L

.79729 .52494 L

.79659 .52574 L

.79588 .52653 L

.79518 .52731 L

.79448 .52807 L

.79377 .52883 L

.79307 .52958 L

.79236 .53032 L

.79166 .53105 L

.79095 .53178 L

.79025 .53249 L

.78955 .53319 L

.78884 .53389 L

.78814 .53458 L

.78743 .53526 L

.78673 .53592 L

.78602 .53659 L

.78532 .53724 L

.78462 .53788 L

.78391 .53852 L

.78321 .53915 L

.7825 .53978 L

.7818 .54039 L

.78109 .541 L

.78039 .54159 L

.77969 .54219 L

.77898 .54277 L

.77828 .54335 L

.77757 .54392 L

.77687 .54448 L

.77616 .54503 L

.77546 .54558 L

.77476 .54612 L

.77405 .54666 L

.77335 .54718 L

Mistroke

.77264 .5477 L

.77194 .54822 L

.77123 .54872 L

.77053 .54922 L

.76982 .54972 L

.76912 .55021 L

.76842 .55069 L

.76771 .55117 L

.76701 .55163 L

.7663 .5521 L

.7656 .55255 L

.76489 .553 L

.76419 .55345 L

.76349 .55389 L

.76278 .55432 L

.76208 .55475 L

.76137 .55517 L

.76067 .55559 L

.75996 .556 L

.75926 .55641 L

.75856 .55681 L

.75785 .5572 L

.75715 .55759 L

.75644 .55798 L

.75574 .55836 L

.75503 .55873 L

.75433 .5591 L

.75363 .55947 L

.75292 .55983 L

.75222 .56019 L

.75151 .56054 L

.75081 .56088 L

.7501 .56122 L

.7494 .56156 L

.7487 .5619 L

.74799 .56222 L

.74729 .56255 L

.74658 .56287 L

.74588 .56319 L

.74517 .5635 L

.74447 .56381 L

.74377 .56411 L

.74306 .56441 L

.74236 .56471 L

.74165 .565 L

.74095 .56529 L

.74024 .56558 L

.73954 .56586 L

.73883 .56614 L

.73813 .56641 L

Mistroke

.73743 .56669 L

.73672 .56695 L

.73602 .56722 L

.73531 .56748 L

.73461 .56774 L

.7339 .568 L

.7332 .56825 L

.7325 .5685 L

.73179 .56875 L

.73109 .56899 L

.73038 .56924 L

.72968 .56947 L

.72897 .56971 L

.72827 .56995 L

.72757 .57018 L

.72686 .57041 L

.72616 .57063 L

.72545 .57086 L

.72475 .57108 L

.72404 .5713 L

.72334 .57151 L

.72264 .57173 L

.72193 .57194 L

.72123 .57216 L

.72052 .57236 L

.71982 .57257 L

.71911 .57278 L

.71841 .57298 L

.71771 .57318 L

.717 .57338 L

.7163 .57358 L

.71559 .57378 L

.71489 .57397 L

.71418 .57416 L

.71348 .57436 L

.71277 .57455 L

.71207 .57473 L

.71137 .57492 L

.71066 .57511 L

.70996 .57529 L

.70925 .57547 L

.70855 .57565 L

.70784 .57584 L

.70714 .57601 L

.70644 .57619 L

.70573 .57637 L

.70503 .57654 L

.70432 .57672 L

.70362 .57689 L

.70291 .57706 L

Mistroke

.70221 .57724 L

.70151 .5774 L

.7008 .57757 L

.7001 .57774 L

.69939 .57791 L

.69869 .57808 L

.69798 .57824 L

.69728 .57841 L

.69658 .57857 L

.69587 .57873 L

.69517 .57889 L

.69446 .57905 L

.69376 .57922 L

.69305 .57938 L

.69235 .57953 L

.69165 .57969 L

.69094 .57985 L

.69024 .58001 L

.68953 .58016 L

.68883 .58032 L

.68812 .58047 L

.68742 .58063 L

.68672 .58078 L

.68601 .58093 L

.68531 .58109 L

.6846 .58124 L

.6839 .58139 L

.68319 .58154 L

.68249 .58169 L

.68178 .58184 L

.68108 .58199 L

.68038 .58214 L

.67967 .58229 L

.67897 .58243 L

.67826 .58258 L

.67756 .58273 L

.67685 .58287 L

.67615 .58302 L

.67545 .58317 L

.67474 .58331 L

.67404 .58346 L

.67333 .5836 L

.67263 .58374 L

.67192 .58389 L

.67122 .58403 L

.67052 .58417 L

.66981 .58432 L

.66911 .58446 L

.6684 .5846 L

.6677 .58474 L

Mistroke

.66699 .58488 L

.66629 .58502 L

.66559 .58516 L

.66488 .5853 L

.66418 .58544 L

.66347 .58558 L

.66277 .58572 L

.66206 .58586 L

.66136 .58599 L

.66066 .58613 L

.65995 .58627 L

.65925 .58641 L

.65854 .58654 L

.65784 .58668 L

.65713 .58682 L

.65643 .58695 L

.65573 .58709 L

.65502 .58722 L

.65432 .58736 L

.65361 .58749 L

.65291 .58762 L

.6522 .58776 L

.6515 .58789 L

.65079 .58802 L

.65009 .58816 L

.64939 .58829 L

.64868 .58842 L

.64798 .58855 L

.64727 .58868 L

.64657 .58881 L

.64586 .58895 L

.64516 .58908 L

.64446 .58921 L

.64375 .58934 L

.64305 .58946 L

.64234 .58959 L

.64164 .58972 L

.64093 .58985 L

.64023 .58998 L

.63953 .59011 L

.63882 .59024 L

.63812 .59036 L

.63741 .59049 L

.63671 .59062 L

.636 .59074 L

.6353 .59087 L

.6346 .59099 L

.63389 .59112 L

.63319 .59124 L

.63248 .59137 L

Mistroke

.63178 .59149 L

.63107 .59161 L

.63037 .59174 L

.62967 .59186 L

.62896 .59198 L

.62826 .59211 L

.62755 .59223 L

.62685 .59235 L

.62614 .59247 L

.62544 .59259 L

.62473 .59271 L

.62403 .59283 L

.62333 .59295 L

.62262 .59307 L

.62192 .59319 L

.62121 .59331 L

.62051 .59343 L

.6198 .59354 L

.6191 .59366 L

.6184 .59378 L

.61769 .5939 L

.61699 .59401 L

.61628 .59413 L

.61558 .59424 L

.61487 .59436 L

.61417 .59447 L

.61347 .59459 L

.61276 .5947 L

.61206 .59481 L

.61135 .59492 L

.61065 .59504 L

.60994 .59515 L

.60924 .59526 L

.60854 .59537 L

.60783 .59548 L

.60713 .59559 L

.60642 .5957 L

.60572 .59581 L

.60501 .59592 L

.60431 .59603 L

.60361 .59613 L

.6029 .59624 L

.6022 .59634 L

.60149 .59645 L

.60079 .59655 L

.60008 .59666 L

.59938 .59677 L

.59868 .59687 L

.59797 .59697 L

.59727 .59707 L

Mistroke

.59656 .59718 L

.59586 .59728 L

.59515 .59738 L

.59445 .59748 L

.59374 .59758 L

.59304 .59768 L

.59234 .59778 L

.59163 .59787 L

.59093 .59797 L

.59022 .59807 L

.58952 .59817 L

.58881 .59826 L

.58811 .59836 L

.58741 .59845 L

.5867 .59855 L

.586 .59864 L

.58529 .59873 L

.58459 .59882 L

.58388 .59891 L

.58318 .599 L

.58248 .59909 L

.58177 .59918 L

.58107 .59927 L

.58036 .59936 L

.57966 .59945 L

.57895 .59953 L

.57825 .59962 L

.57755 .5997 L

.57684 .59979 L

.57614 .59987 L

.57543 .59995 L

.57473 .60003 L

.57402 .60011 L

.57332 .60019 L

.57262 .60027 L

.57191 .60035 L

.57121 .60043 L

.5705 .60051 L

.5698 .60058 L

.56909 .60066 L

.56839 .60073 L

.56769 .60081 L

.56698 .60088 L

.56628 .60095 L

.56557 .60102 L

.56487 .6011 L

.56416 .60116 L

.56346 .60123 L

.56275 .6013 L

.56205 .60137 L

Mistroke

.56064 .6015 L

.55923 .60163 L

.55782 .60175 L

.55642 .60187 L

.55501 .60198 L

.5536 .60209 L

.55219 .6022 L

.55078 .6023 L

.54937 .6024 L

.54796 .6025 L

.54656 .60258 L

.54515 .60267 L

.54374 .60275 L

.54233 .60283 L

.54092 .6029 L

.53951 .60296 L

.5381 .60302 L

.5367 .60308 L

.53529 .60312 L

.53388 .60317 L

.53247 .60321 L

.53106 .60324 L

.52965 .60327 L

.52824 .60329 L

.52683 .60331 L

.52543 .60331 L

.52402 .60332 L

.52261 .60331 L

.5212 .60331 L

.51979 .60329 L

.51838 .60327 L

.51697 .60323 L

.51557 .6032 L

.51416 .60315 L

.51275 .6031 L

.51134 .60304 L

.50993 .60297 L

.50852 .6029 L

.50711 .60282 L

.5057 .60272 L

.5043 .60262 L

.50289 .60252 L

.50148 .6024 L

.50007 .60228 L

.49866 .60214 L

.49725 .602 L

.49584 .60184 L

.49444 .60168 L

.49303 .60151 L

.49162 .60132 L

Mistroke

.49021 .60113 L

.4888 .60093 L

.48739 .60071 L

.48598 .60049 L

.48458 .60025 L

.48317 .6 L

.48176 .59974 L

.48035 .59947 L

.47894 .59919 L

.47753 .59889 L

.47612 .59858 L

.47471 .59826 L

.47331 .59793 L

.4719 .59758 L

.47049 .59722 L

.46908 .59684 L

.46767 .59645 L

.46626 .59605 L

.46485 .59563 L

.46345 .59519 L

.46204 .59474 L

.46063 .59427 L

.45922 .59379 L

.45781 .59329 L

.4564 .59277 L

.45499 .59224 L

.45359 .59168 L

.45218 .59111 L

.45077 .59052 L

.44936 .58991 L

.44795 .58928 L

.44654 .58863 L

.44513 .58796 L

.44372 .58727 L

.44232 .58656 L

.44091 .58583 L

.4395 .58507 L

.43809 .58429 L

.43668 .58349 L

.43527 .58266 L

.43386 .5818 L

.43246 .58092 L

.43105 .58002 L

.42964 .57909 L

.42823 .57813 L

.42682 .57714 L

.42541 .57612 L

.424 .57508 L

.4226 .574 L

.42119 .57289 L

Mistroke

.41978 .57175 L

.41837 .57058 L

.41696 .56937 L

.41555 .56813 L

.41414 .56685 L

.41273 .56554 L

.41133 .56419 L

.40992 .56279 L

.40851 .56136 L

.4071 .55989 L

.40569 .55837 L

.40428 .55681 L

.40287 .55521 L

.40147 .55355 L

.40006 .55185 L

.39865 .5501 L

.39724 .5483 L

.39583 .54644 L

.39442 .54453 L

.39301 .54256 L

.39161 .54053 L

.3902 .53844 L

.38879 .53629 L

.38738 .53407 L

.38597 .53178 L

.38456 .52942 L

.38315 .52698 L

.38174 .52446 L

.38034 .52186 L

.37893 .51918 L

.37752 .51641 L

.37611 .51354 L

.3747 .51057 L

.37329 .5075 L

.37188 .50432 L

.37048 .50102 L

.36907 .4976 L

.36766 .49404 L

.36625 .49035 L

.36484 .4865 L

.36343 .4825 L

.36202 .47832 L

.36062 .47395 L

.35921 .46938 L

.3578 .46459 L

.35639 .45955 L

.35498 .45424 L

.35357 .44862 L

.35216 .44266 L

.35075 .4363 L

Mistroke

.34935 .42948 L

.34794 .42212 L

.34653 .4141 L

.34512 .40526 L

.34371 .39533 L

.3423 .38389 L

.34089 .37008 L

.33949 .35167 L

.33816 .30902 L

Mfstroke

0 1 .4 r

.6939 .52611 m

.69404 .52557 L

.69418 .52507 L

.69432 .52461 L

.69446 .52418 L

.69517 .52232 L

.69587 .52078 L

.69658 .51943 L

.69728 .51822 L

.69798 .5171 L

.69869 .51606 L

.69939 .51508 L

.7001 .51416 L

.7008 .51328 L

.70151 .51244 L

.70221 .51163 L

.70291 .51086 L

.70362 .51011 L

.70432 .50939 L

.70503 .50868 L

.70573 .508 L

.70644 .50734 L

.70714 .50669 L

.70784 .50606 L

.70855 .50545 L

.70925 .50485 L

.70996 .50426 L

.71066 .50368 L

.71137 .50312 L

.71207 .50256 L

.71277 .50202 L

.71348 .50149 L

.71418 .50096 L

.71489 .50045 L

.71559 .49994 L

.7163 .49944 L

.717 .49894 L

.71771 .49846 L

.71841 .49798 L

.71911 .49751 L

.71982 .49704 L

.72052 .49658 L

.72123 .49613 L

.72193 .49568 L

.72264 .49524 L

.72334 .4948 L

.72404 .49437 L

.72475 .49395 L

.72545 .49352 L

.72616 .4931 L

Mistroke

.72686 .49269 L

.72757 .49228 L

.72827 .49188 L

.72897 .49148 L

.72968 .49108 L

.73038 .49069 L

.73109 .4903 L

.73179 .48992 L

.7325 .48953 L

.7332 .48916 L

.7339 .48878 L

.73461 .48841 L

.73531 .48804 L

.73602 .48768 L

.73672 .48731 L

.73743 .48695 L

.73813 .4866 L

.73883 .48624 L

.73954 .48589 L

.74024 .48555 L

.74095 .4852 L

.74165 .48486 L

.74236 .48452 L

.74306 .48418 L

.74377 .48384 L

.74447 .48351 L

.74517 .48318 L

.74588 .48285 L

.74658 .48252 L

.74729 .4822 L

.74799 .48188 L

.7487 .48156 L

.7494 .48124 L

.7501 .48092 L

.75081 .48061 L

.75151 .4803 L

.75222 .47999 L

.75292 .47968 L

.75363 .47937 L

.75433 .47907 L

.75503 .47876 L

.75574 .47846 L

.75644 .47816 L

.75715 .47787 L

.75785 .47757 L

.75856 .47727 L

.75926 .47698 L

.75996 .47669 L

.76067 .4764 L

.76137 .47611 L

Mistroke

.76208 .47583 L

.76278 .47554 L

.76349 .47526 L

.76419 .47497 L

.76489 .47469 L

.7656 .47441 L

.7663 .47413 L

.76701 .47386 L

.76771 .47358 L

.76842 .47331 L

.76912 .47303 L

.76982 .47276 L

.77053 .47249 L

.77123 .47222 L

.77194 .47195 L

.77264 .47168 L

.77335 .47142 L

.77405 .47115 L

.77476 .47089 L

.77546 .47063 L

.77616 .47036 L

.77687 .4701 L

.77757 .46984 L

.77828 .46959 L

.77898 .46933 L

.77969 .46907 L

.78039 .46882 L

.78109 .46856 L

.7818 .46831 L

.7825 .46806 L

.78321 .46781 L

.78391 .46755 L

.78462 .46731 L

.78532 .46706 L

.78602 .46681 L

.78673 .46656 L

.78743 .46632 L

.78814 .46607 L

.78884 .46583 L

.78955 .46558 L

.79025 .46534 L

.79095 .4651 L

.79166 .46486 L

.79236 .46462 L

.79307 .46438 L

.79377 .46414 L

.79448 .4639 L

.79518 .46367 L

.79588 .46343 L

.79659 .4632 L

Mistroke

.79729 .46296 L

.798 .46273 L

.7987 .46249 L

.79941 .46226 L

.80011 .46203 L

.80081 .4618 L

.80152 .46157 L

.80222 .46134 L

.80293 .46111 L

.80363 .46088 L

.80434 .46066 L

.80504 .46043 L

.80575 .4602 L

.80645 .45998 L

.80715 .45975 L

.80786 .45953 L

.80856 .45931 L

.80927 .45908 L

.80997 .45886 L

.81068 .45864 L

.81138 .45842 L

.81208 .4582 L

.81279 .45798 L

.81349 .45776 L

.8142 .45754 L

.8149 .45732 L

.81561 .45711 L

.81631 .45689 L

.81701 .45667 L

.81772 .45646 L

.81842 .45624 L

.81913 .45603 L

.81983 .45581 L

.82054 .4556 L

.82124 .45539 L

.82194 .45517 L

.82265 .45496 L

.82335 .45475 L

.82406 .45454 L

.82476 .45433 L

.82547 .45412 L

.82617 .45391 L

.82687 .4537 L

.82758 .45349 L

.82828 .45328 L

.82899 .45308 L

.82969 .45287 L

.8304 .45266 L

.8311 .45246 L

.8318 .45225 L

Mistroke

.83251 .45205 L

.83321 .45184 L

.83392 .45164 L

.83462 .45143 L

.83533 .45123 L

.83603 .45103 L

.83674 .45082 L

.83744 .45062 L

.83814 .45042 L

.83885 .45022 L

.83955 .45002 L

.84026 .44982 L

.84096 .44962 L

.84167 .44942 L

.84237 .44922 L

.84307 .44902 L

.84378 .44882 L

.84448 .44862 L

.84519 .44843 L

.84589 .44823 L

.8466 .44803 L

.8473 .44784 L

.848 .44764 L

.84871 .44745 L

.84941 .44725 L

.85012 .44706 L

.85082 .44686 L

.85153 .44667 L

.85223 .44647 L

.85293 .44628 L

.85364 .44609 L

.85434 .44589 L

.85505 .4457 L

.85575 .44551 L

.85646 .44532 L

.85716 .44513 L

.85786 .44494 L

.85857 .44475 L

.85927 .44456 L

.85998 .44437 L

.86068 .44418 L

.86139 .44399 L

.86209 .4438 L

.8628 .44361 L

.8635 .44342 L

.8642 .44323 L

.86491 .44305 L

.86561 .44286 L

.86632 .44267 L

.86702 .44249 L

Mistroke

.86773 .4423 L

.86843 .44211 L

.86913 .44193 L

.86984 .44174 L

.87054 .44156 L

.87125 .44137 L

.87195 .44119 L

.87266 .441 L

.87336 .44082 L

.87406 .44064 L

.87477 .44045 L

.87547 .44027 L

.87618 .44009 L

.87688 .4399 L

.87759 .43972 L

.87829 .43954 L

.87899 .43936 L

.8797 .43918 L

.8804 .439 L

.88111 .43882 L

.88181 .43864 L

.88252 .43846 L

.88322 .43828 L

.88392 .4381 L

.88463 .43792 L

.88533 .43774 L

.88604 .43756 L

.88674 .43738 L

.88745 .4372 L

.88815 .43702 L

.88885 .43685 L

.88956 .43667 L

.89026 .43649 L

.89097 .43631 L

.89167 .43614 L

.89238 .43596 L

.89308 .43578 L

.89379 .43561 L

.89449 .43543 L

.89519 .43526 L

.8959 .43508 L

.8966 .43491 L

.89731 .43473 L

.89801 .43456 L

.89872 .43438 L

.89942 .43421 L

.90012 .43403 L

.90083 .43386 L

.90153 .43369 L

.90224 .43351 L

Mistroke

.90294 .43334 L

.90365 .43317 L

.90435 .43299 L

.90505 .43282 L

.90576 .43265 L

.90646 .43248 L

.90717 .43231 L

.90787 .43213 L

.90858 .43196 L

.90928 .43179 L

.90998 .43162 L

.91069 .43145 L

.91139 .43128 L

.9121 .43111 L

.9128 .43094 L

.91351 .43077 L

.91421 .4306 L

.91491 .43043 L

.91562 .43026 L

.91632 .43009 L

.91703 .42992 L

.91773 .42976 L

.91844 .42959 L

.91914 .42942 L

.91984 .42925 L

.92055 .42908 L

.92125 .42892 L

.92196 .42875 L

.92266 .42858 L

.92337 .42841 L

.92407 .42825 L

.92478 .42808 L

.92548 .42792 L

.92618 .42775 L

.92689 .42758 L

.92759 .42742 L

.9283 .42725 L

.929 .42709 L

.92971 .42692 L

.93041 .42676 L

.93111 .42659 L

.93182 .42643 L

.93252 .42626 L

.93323 .4261 L

.93393 .42593 L

.93464 .42577 L

.93534 .4256 L

.93604 .42544 L

.93675 .42528 L

.93745 .42511 L

Mistroke

.93816 .42495 L

.93886 .42479 L

.93957 .42463 L

.94027 .42446 L

.94097 .4243 L

.94168 .42414 L

.94238 .42398 L

.94309 .42381 L

.94379 .42365 L

.9445 .42349 L

.9452 .42333 L

.9459 .42317 L

.94661 .42301 L

.94731 .42285 L

.94802 .42269 L

.94872 .42253 L

.94943 .42237 L

.95013 .42221 L

.95083 .42205 L

.95154 .42189 L

.95224 .42173 L

.95295 .42157 L

.95365 .42141 L

.95436 .42125 L

.95506 .42109 L

.95577 .42093 L

.95647 .42077 L

.95717 .42061 L

.95788 .42045 L

.95858 .42029 L

.95929 .42014 L

.95999 .41998 L

.9607 .41982 L

.9614 .41966 L

.9621 .4195 L

.96281 .41935 L

.96351 .41919 L

.96422 .41903 L

.96492 .41888 L

.96563 .41872 L

.96633 .41856 L

.96703 .41841 L

.96774 .41825 L

.96844 .41809 L

.96915 .41794 L

.96985 .41778 L

.97056 .41763 L

.97126 .41747 L

.97196 .41731 L

.97267 .41716 L

Mistroke

.97337 .417 L

.97408 .41685 L

.97478 .41669 L

.97549 .41654 L

.97619 .41638 L

Mfstroke

1 0 0 r

.54163 .48469 m

.54022 .4852 L

.53881 .4857 L

.5374 .4862 L

.53599 .4867 L

.53458 .4872 L

.53317 .48769 L

.53176 .48819 L

.53036 .48868 L

.52895 .48917 L

.52754 .48966 L

.52613 .49015 L

.52472 .49064 L

.52331 .49112 L

.5219 .49161 L

.5205 .49209 L

.51909 .49257 L

.51768 .49305 L

.51627 .49353 L

.51486 .494 L

.51345 .49448 L

.51204 .49495 L

.51064 .49543 L

.50923 .4959 L

.50782 .49637 L

.50641 .49684 L

.505 .4973 L

.50359 .49777 L

.50218 .49823 L

.50077 .4987 L

.49937 .49916 L

.49796 .49962 L

.49655 .50008 L

.49514 .50054 L

.49373 .50099 L

.49232 .50145 L

.49091 .50191 L

.48951 .50236 L

.4881 .50281 L

.48669 .50326 L

.48528 .50371 L

.48387 .50416 L

.48246 .50461 L

.48105 .50506 L

.47965 .5055 L

.47824 .50595 L

.47683 .50639 L

.47542 .50683 L

.47401 .50727 L

.4726 .50771 L

Mistroke

.47119 .50815 L

.46978 .50859 L

.46838 .50903 L

.46697 .50946 L

.46556 .5099 L

.46415 .51033 L

.46274 .51076 L

.46133 .51119 L

.45992 .51162 L

.45852 .51205 L

.45711 .51248 L

.4557 .51291 L

.45429 .51334 L

.45288 .51376 L

.45147 .51418 L

.45006 .51461 L

.44866 .51503 L

.44725 .51545 L

.44584 .51587 L

.44443 .51629 L

.44302 .51671 L

.44161 .51712 L

.4402 .51754 L

.43879 .51795 L

.43739 .51837 L

.43598 .51878 L

.43457 .51919 L

.43316 .5196 L

.43175 .52001 L

.43034 .52042 L

.42893 .52083 L

.42753 .52124 L

.42612 .52164 L

.42471 .52205 L

.4233 .52245 L

.42189 .52285 L

.42048 .52325 L

.41907 .52365 L

.41767 .52405 L

.41626 .52445 L

.41485 .52485 L

.41344 .52524 L

.41203 .52564 L

.41062 .52603 L

.40921 .52643 L

.4078 .52682 L

.4064 .52721 L

.40499 .5276 L

.40358 .52798 L

.40217 .52837 L

Mistroke

.40076 .52876 L

.39935 .52914 L

.39794 .52953 L

.39654 .52991 L

.39513 .53029 L

.39372 .53067 L

.39231 .53105 L

.3909 .53143 L

.38949 .5318 L

.38808 .53218 L

.38667 .53255 L

.38527 .53292 L

.38386 .5333 L

.38245 .53367 L

.38104 .53404 L

.37963 .5344 L

.37822 .53477 L

.37681 .53513 L

.37541 .5355 L

.374 .53586 L

.37259 .53622 L

.37118 .53658 L

.36977 .53694 L

.36836 .5373 L

.36695 .53765 L

.36555 .538 L

.36414 .53836 L

.36273 .53871 L

.36132 .53906 L

.35991 .5394 L

.3585 .53975 L

.35709 .5401 L

.35568 .54044 L

.35428 .54078 L

.35287 .54112 L

.35146 .54146 L

.35005 .5418 L

.34864 .54213 L

.34723 .54246 L

.34582 .5428 L

.34442 .54313 L

.34301 .54345 L

.3416 .54378 L

.34019 .54411 L

.33878 .54443 L

.33737 .54475 L

.33596 .54507 L

.33456 .54539 L

.33315 .5457 L

.33174 .54602 L

Mistroke

.33033 .54633 L

.32892 .54664 L

.32751 .54695 L

.3261 .54725 L

.32469 .54756 L

.32329 .54786 L

.32188 .54816 L

.32047 .54845 L

.31906 .54875 L

.31765 .54904 L

.31624 .54933 L

.31483 .54962 L

.31343 .54991 L

.31202 .55019 L

.31061 .55047 L

.3092 .55075 L

.30779 .55103 L

.30638 .5513 L

.30497 .55157 L

.30357 .55184 L

.30216 .55211 L

.30075 .55238 L

.29934 .55264 L

.29793 .55289 L

.29652 .55315 L

.29511 .55341 L

.2937 .55365 L

.2923 .5539 L

.29089 .55415 L

.28948 .55439 L

.28807 .55463 L

.28666 .55487 L

.28525 .5551 L

.28384 .55533 L

.28244 .55555 L

.28103 .55578 L

.27962 .556 L

.27821 .55622 L

.2768 .55643 L

.27539 .55664 L

.27398 .55685 L

.27258 .55705 L

.27117 .55725 L

.26976 .55745 L

.26835 .55764 L

.26694 .55783 L

.26553 .55802 L

.26412 .5582 L

.26271 .55838 L

.26131 .55855 L

Mistroke

.2599 .55872 L

.25849 .55889 L

.25708 .55905 L

.25567 .55921 L

.25426 .55936 L

.25285 .55951 L

.25145 .55966 L

.25004 .5598 L

.24863 .55994 L

.24722 .56007 L

.24581 .56019 L

.2444 .56032 L

.24299 .56044 L

.24159 .56055 L

.24018 .56066 L

.23877 .56076 L

.23736 .56086 L

.23595 .56095 L

.23454 .56104 L

.23313 .56112 L

.23172 .5612 L

.23032 .56128 L

.22891 .56134 L

.2275 .5614 L

.22609 .56146 L

.22468 .56151 L

.22327 .56156 L

.22186 .56159 L

.22046 .56162 L

.21905 .56165 L

.21764 .56167 L

.21623 .56168 L

.21482 .56169 L

.21341 .56169 L

.212 .56169 L

.2106 .56168 L

.20919 .56165 L

.20778 .56163 L

.20637 .5616 L

.20496 .56156 L

.20355 .56151 L

.20214 .56145 L

.20073 .56139 L

.19933 .56132 L

.19792 .56124 L

.19651 .56115 L

.1951 .56106 L

.19369 .56096 L

.19228 .56085 L

.19087 .56073 L

Mistroke

.18524 .56017 L

.17961 .55946 L

.17397 .5586 L

.16834 .55756 L

.1627 .55635 L

.15707 .55495 L

.15143 .55334 L

.1458 .55151 L

.14016 .54943 L

.13453 .5471 L

.12889 .54449 L

.12326 .54157 L

.11762 .53832 L

.11199 .53471 L

.10636 .5307 L

.10072 .52626 L

.09509 .52133 L

.08945 .51586 L

.08382 .50979 L

.07818 .50303 L

.07255 .49549 L

.06691 .48704 L

.06128 .47751 L

.05564 .46667 L

.05001 .45419 L

.04438 .43957 L

.03874 .42192 L

.03311 .39943 L

.02747 .36656 L

.02381 .30902 L

Mfstroke

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{567, 350.313},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.776525,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008g0001GPP10`40000100000800002008200000

P800P020P<30`<3L`:K:l00003<006H009T00<`00?l0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV

09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<003o03?o06Ko09Wo0<co

0?oo0000<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I

<c>I<fJI<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0

IYT0I/`0I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bI

I_nIIP3<IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0c

VC<cVFHcVITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<

VIW<VLc<VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`c

c?lcc01Vc3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03o

c3?oc6Koc9Woc<coc?ooc000oc<0ofH0oiT0ol`0ool0o`0coc<cofHcoiTcol`coolco`1Voc=VofIV

oiUVolaVoomVo`2Ioc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<o`3ooc?oofKooiWoolco

ooooo`0000410@820P<30`@410D51@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C

4a@D5?okl:2PY820P?l0003o0?oo0000ool0o`3ooooood_Q00<0hN40on7Zh@00Bn400`3Qh@3ohN[Q

001;h@030>7Q0?oQj^4004_Q00<0hN40on7Zh@00Bn430?oQj^4004_Q00<0hN40on7Zh@00Bn400`3Q

h@3ohN[Q001;h@030>7Q0?oQj^4004_Q00<0hN40`N4M3ooQ3>4004_Q00<0hN40^^473agQ2`ooh@7Q

001;h@030>7Q0;CQ1Pl^h@T?n>4004_Q00<0hN40/N443c_Q20oah@00Bn400`3Qh@2^h@<?A^473n_Q

001;h@030>7Q0:_Q0`m?h@L?iN4004_Q00<0hN40Z>433eWQ1PoOh@00Bn400`3Qh@2Vh@8?HN463m[Q

001;h@<0Y>423fWQ1@oEh@00Bn400`3Qh@2Rh@8?L>453m3Q001;h@030>7Q0:7Q00<?hN40MN463l[Q

001;h@030>7Q09oQ0Pmmh@D?a^4004_Q00<0hN40WN423hCQ1@o1h@00Bn400`3Qh@2Lh@033n7Q08SQ

1@nmh@00Bn400`3Qh@2Jh@8?Sn453kWQ001;h@030>7Q09WQ00<?hN40Tn443kKQ001;h@030>7Q09SQ

0PnIh@@?/^4004_Q00<0hN40U^423ikQ10n_h@00Bn400`3Qh@2Fh@033n7Q0:3Q0`n]h@00Bn400`3Q

h@2Dh@8?Y^433j[Q001;h@<0U>400`oQh@2Wh@@?Yn4004_Q00<0hN40:>4<3eoQ00<?hN40Zn433jGQ

001;h@030>7Q01gQ2`l<h@h?Cn423k3Q0`nSh@00Bn400`3Qh@0Hh@D?9>493dOQ00<?hN40Xn4>:08?

2RRHh@00Bn400`3Qh@0Bh@H?<^473coQ00<?hN40Wn45:13Q0Pl7h@PXTN4004_Q00<0hN403n433coQ

1Plhh@033n7Q09kQ0bPFh@8?3N46:8_Q001;h@030>7Q00cQ0`m8h@H?<N400`oQh@2Mh@8X6^433a7Q

1bR4h@00Bn400`3Qh@09h@<?D>453bcQ00<?hN40W>42:1kQ0PlGh@HXO^4004_Q00<0hN401^433eSQ

1@lVh@033n7Q09cQ00<XhN407n423acQ1RQhh@00Bn400`3Qh@03h@<?H>453b7Q00<?hN40Vn400bSQ

h@0Rh@8?7n46:7?Q000jh@D00^400`3Qh@07h@040>7Qh@8?In453acQ00<?hN40Vn400bSQh@0Th@8?

9>46:6gQ000lh@070>7Qh@3Q0008h@040>4?3fkQ10lGh@033n7Q09_Q00<XhN409^423bSQ1RQXh@00

=^4300?Q00L0hN7Q0>4000SQ00@03`00L^453a7Q00<?hN40Vn400bSQh@0Xh@<?;>46:6;Q000lh@07

0>7Qh@3Q0007h@8?NN453`gQ00<?hN40Vn400bSQh@0Zh@8?<>46:5gQ000lh@070>7Qh@3Q0005h@8?

00?Q0>40ON443`SQ00<?hN40Vn400bSQh@0/h@8?=N46:5OQ000kh@801>400`3Qh@02h@8?0n400`3Q

h@1oh@@?1N400`oQh@2Kh@03:>7Q02gQ0Plih@HXD^4004CQ0Pl5h@030>7Q08?Q1@o?h@8??^46:4cQ

0013h@033n7Q00GQ00<0hN40Q^400`oQ3`023lgQ0Pm3h@DXAn4004;Q00<?hN401^400`3Qh@26h@03

3n7Q00;Q10o:h@8?An46:47Q0012h@033n7Q00KQ00<0hN40QN400`oQh@07h@@?an423dcQ1RPkh@00

@N400`oQh@07h@030>7Q08CQ00<?hN402n443i3Q00<XhN40<^423e7Q1BPfh@00?n423`[Q00<0hN40

Q>400`oQh@0?h@<?SN400bSQh@0ch@033n7Q08[Q000nh@033n7Q00[Q00<0hN40Pn400`oQh@0Ch@@?

R^400bSQh@0ch@033n7Q08WQ000mh@033n7Q00_Q00<0hN40Pn400`oQh@0Gh@@?Q^400bSQh@0ch@8?

R^4003cQ00<?hN403>4308;Q00<?hN406n443hCQ00<XhN40=>400`oQh@27h@00>n400`oQh@0=h@03

0>7Q08;Q00<?hN407n433h7Q0RPeh@8?R>4003[Q00<?hN403^400`3Qh@21h@033n7Q02?Q10mnh@8X

=N400`oQh@26h@00>N400`oQh@0?h@030>7Q087Q00<?hN409n433gcQ00<XhN40=>400`oQh@25h@00

>>400`oQh@0@h@030>7Q087Q00<?hN40:N443g[Q00<XhN40<n423hKQ000gh@033n7Q017Q00<0hN40

P>400`oQh@0^h@<?Mn42:3GQ0Pn5h@00=^400`oQh@0Bh@030>7Q07oQ00<?hN40<^433gKQ00<XhN40

<n400`oQh@23h@00=^400`oQh@0Bh@030>7Q07oQ00<?hN40=N443g?Q0RPdh@033n7Q08;Q000eh@03

3n7Q01?Q00<0hN40O^400`oQh@0jh@<?LN42:3?Q00<?hN40P^4003CQ00<?hN405>400`3Qh@1nh@03

3n7Q03gQ0`m_h@8X<n400`oQh@21h@00<n400`oQh@0Eh@030>7Q07kQ00<?hN40?n443fkQ0RPah@8?

P^4003?Q00<?hN405N400`3Qh@1nh@033n7Q04;Q10m/h@8X<N400`oQh@20h@00<^400`oQh@0Fh@<0

ON400`oQh@17h@<?Jn42:33Q00<?hN40On40037Q00<?hN405n400`3Qh@1lh@033n7Q04_Q0`mYh@8X

;n423h3Q000`h@033n7Q01SQ00<0hN40O>400`oQh@1>h@<?J>42:2kQ00<?hN40O^40033Q00<?hN40

6>400`3Qh@1kh@033n7Q05;Q0`mWh@8X;>423goQ000_h@033n7Q01WQ00<0hN40Nn400`oQh@1Eh@8?

I^43:2_Q00<?hN40ON4002kQ00<?hN406^400`3Qh@1kh@033n7Q05OQ0`mVh@8X:N423gkQ000^h@03

3n7Q01[Q00<0hN40Nn400`oQh@1Kh@033n7Q06CQ0RPXh@033n7Q07cQ000]h@033n7Q01_Q00<0hN40

Nn400`oQh@1Lh@<?IN43:2KQ00<?hN40Nn4002gQ00<?hN406n400`3Qh@1jh@033n7Q063Q0`mTh@<X

9>400`oQh@1kh@00;>400`oQh@0Lh@030>7Q07[Q00<?hN40Hn433f?Q0bPSh@033n7Q07[Q000[h@03

3n7Q01gQ00<0hN40NN400`oQh@1Wh@<?Hn43:23Q00<?hN40N^4002_Q00<?hN407N400`3Qh@1ih@03

3n7Q06[Q00<?hN40H^43:1kQ0Pmkh@00:^400`oQh@0Nh@<0NN400`oQh@1[h@<?I>43:1cQ00<?hN40

NN4002[Q00<?hN407^400`3Qh@1ih@033n7Q06kQ0`mSh@<X6n400`oQh@1hh@00:N400`oQh@0Oh@03

0>7Q07WQ00<?hN40LN433f?Q0bPHh@033n7Q07SQ000Yh@033n7Q01oQ00<0hN40N>400`oQh@1eh@8?

I>43:1GQ00<?hN40N>4002SQ00<?hN408>400`3Qh@1hh@033n7Q07OQ0`mTh@<X4n400`oQh@1gh@00

:>400`oQh@0Ph@030>7Q07OQ00<?hN40Nn400`oQh@1Th@<X4>400`oQh@1gh@009n400`oQh@0Qh@03

0>7Q07OQ00<?hN40O>433fKQ0bP>h@033n7Q07KQ000Wh@033n7Q027Q00<0hN40Mn400`oQh@1oh@<?

I^44:0[Q00<?hN40M^4002KQ00<?hN408^400`3Qh@1fh@033n7Q08?Q00<?hN40I^44:0OQ00<?hN40

M^4002KQ00<?hN408^400`3Qh@1fh@033n7Q08CQ0`mXh@@X1N400`oQh@1eh@009^400`oQh@0Rh@03

0>7Q07KQ00<?hN40Qn423f[Q12P00n4?h@1fh@009N400`oQh@0Sh@030>7Q07KQ00<?hN40RN433f[Q

12Qfh@009N400`oQh@0Sh@<0M^400`oQh@2<h@033n7Q06[Q00<?:2P00RQbh@009>400`oQh@0Th@03

0>7Q07KQ00<?hN40SN433fWQ00@?hN7Q12Q_h@009>400`oQh@0Th@030>7Q07GQ00<?hN40TN400`oQ

h@1Vh@033n7Q00GQ12Q[h@009>400`oQh@0Th@030>7Q07GQ00<?hN40T^433fKQ00<?hN401n45:6OQ

000Sh@033n7Q02GQ00<0hN40MN400`oQh@2Eh@8?I>400`oQh@0;h@DXHn4002?Q00<?hN409N400`3Q

h@1dh@033n7Q09SQ0`mQh@033n7Q00oQ1BQOh@008n400`oQh@0Uh@030>7Q07CQ00<?hN40Vn400`oQ

h@1Nh@033n7Q01?Q1BQKh@008^400`oQh@0Vh@030>7Q07CQ00<?hN40W>423eoQ00<?hN405^45:5OQ

000Rh@033n7Q02KQ00<0hN40Ln400`oQh@2Oh@<?G>400`oQh@0Jh@DXDn4002;Q00<?hN409^400`3Q

h@1ch@033n7Q0:;Q00<?hN40FN400`oQh@0Nh@DXCn40027Q00<?hN407N400`3Qh@07h@030>7Q07?Q

00<?hN40Xn423eWQ0PlSh@DXBn40027Q00<?hN407>400`3Q0008h@030>7Q07?Q00<?hN40YN423eSQ

00<?hN409N45:4OQ000Qh@033n7Q01OQ0`04h@030>7Q00KQ101bh@033n7Q0:OQ0PmFh@033n7Q02WQ

1BQ3h@008>400`oQh@0Mh@802N400`3Qh@1ch@033n7Q0:WQ00<?hN40Dn400`oQh@0^h@DX?^40023Q

00<?hN407N400`3Qh@08h@030>7Q07?Q00<?hN40Z^433e;Q00<?hN40<^45:3[Q000Ph@033n7Q01gQ

0`08h@030>7Q07?Q00<?hN40[N423e7Q00<?hN40=N46:3GQ000Ph@033n7Q02SQ00<0hN40L^400`oQ

h@2`h@033n7Q04kQ00<?hN40>^45:37Q000Oh@033n7Q02WQ00<0hN40L^400`oQh@2ah@8?C^400`oQ

h@0oh@03:>7Q02kQ000Oh@033n7Q02WQ00<0hN40L^400`oQh@2ch@<?Bn400`oQh@1`h@007n400`oQ

h@0Yh@030>7Q07;Q00<?hN40]^400`oQh@18h@033n7Q073Q000Oh@033n7Q02WQ00<0hN40LN400`oQ

h@2hh@8?B>400`oQh@1`h@007n400`oQh@0Yh@030>7Q077Q00<?hN40^^400`oQh@16h@033n7Q06oQ

000Oh@033n7Q02WQ00<0hN40LN400`oQh@2kh@<?AN400`oQh@1_h@007^400`oQh@0Zh@030>7Q077Q

00<?hN40_^400`oQh@12h@033n7Q06oQ000Nh@033n7Q02[Q0`1ah@033n7Q0;oQ0Pm2h@033n7Q06oQ

000Nh@033n7Q02[Q00<0hN40LN400`oQh@31h@033n7Q03oQ00<?hN40Kn4001kQ00<?hN40:^400`3Q

h@1ah@033n7Q0<;Q0Ploh@033n7Q06oQ000Nh@033n7Q02[Q00<0hN40LN400`oQh@34h@033n7Q03cQ

00<?hN40Kn4001kQ00<?hN40:^400`3Qh@1ah@033n7Q0<GQ0Pllh@033n7Q06oQ000Mh@033n7Q02_Q

00<0hN40LN400`oQh@37h@<?>N400`oQh@1_h@007N400`oQh@0[h@030>7Q077Q00<?hN40b^400`oQ

h@0fh@033n7Q06oQ000Mh@033n7Q02_Q00<0hN40L>400`oQh@3<h@8?Z>4001gQ00<?hN40:n400`3Q

h@1`h@033n7Q0<kQ00<?hN40YN4001gQ00<?hN40:n400`3Qh@1`h@033n7Q0<oQ00<?hN40Y>4001gQ

00<?hN40:n400`3Qh@1`h@033n7Q0=3Q0PnTh@007>400`oQh@0/h@030>7Q073Q00<?hN40d^400`oQ

h@2Qh@007>400`oQh@0/h@<0L>400`oQh@3Ch@8?;n400`oQh@1_h@007>400`oQh@0/h@030>7Q073Q

00<?hN40eN400`oQh@0/h@033n7Q06oQ000Lh@033n7Q02cQ00<0hN40Kn400`oQh@3Gh@8?;>400`oQ

h@1_h@007>400`oQh@0/h@030>7Q06oQ00<?hN40fN400`oQh@0Yh@033n7Q06oQ000Lh@033n7Q02cQ

00<0hN40Kn400`oQh@3Jh@8?:N400`oQh@1_h@006n400`oQh@0]h@030>7Q06oQ00<?hN40g>400`oQ

h@0Vh@033n7Q06oQ000Kh@033n7Q02gQ00<0hN40Kn400`oQh@3Mh@033n7Q02GQ00<?hN40Kn4001_Q

00<?hN40;N400`3Qh@1_h@033n7Q0=kQ00<?hN409>400`oQh@1_h@006n400`oQh@0]h@030>7Q06oQ

00<?hN40gn400`oQh@0Sh@033n7Q06oQ000Kh@033n7Q02gQ00<0hN40Kn400`oQh@3Ph@033n7Q027Q

00<?hN40L>4001_Q00<?hN40;N400`3Qh@1^h@033n7Q0>;Q0PlQh@033n7Q073Q000Kh@033n7Q02gQ

00<0hN40K^400`oQh@3Th@033n7Q01kQ00<?hN40L>4001_Q00<?hN40;N4306kQ00<?hN40iN423akQ

00<?hN40L>4001_Q00<?hN40;N400`3Qh@1^h@033n7Q0>KQ00<?hN407>400`oQh@1`h@006n400`oQ

h@0]h@030>7Q06kQ00<?hN40in400`oQh@0Jh@8?L^4001[Q00<?hN40;^400`3Qh@1^h@033n7Q0>SQ

0PlJh@033n7Q077Q000Jh@033n7Q02kQ00<0hN40K^400`oQh@3Zh@033n7Q01OQ00<?hN40LN4001[Q

00<?hN40;^400`3Qh@1^h@033n7Q0>_Q00<?hN40R^4001[Q00<?hN40;^400`3Qh@1^h@033n7Q0>cQ

00<?hN40RN4001[Q00<?hN40;^400`3Qh@1^h@033n7Q0>gQ00<?hN404n400`oQh@1bh@006^400`oQ

h@0^h@030>7Q06kQ00<?hN40k^400`oQh@0Bh@033n7Q07;Q000Jh@033n7Q02kQ00<0hN40K^400`oQ

h@3_h@033n7Q013Q00<?hN40Ln4001[Q00<?hN40;^400`3Qh@11h@D00^400`3Qh@0Sh@033n7Q01WQ

1@000n400011h@D00^400`3Qh@0oh@D00^400`3Qh@0kh@043n7Qh@D000?Q00001^400`oQh@0ih@<0

0n400`3Qh@0ah@006^400`oQh@0^h@030>7Q04?Q00L0hN7Q0>4002CQ00<?hN406n401`3QhN40h@00

@^400`3Qh@02h@030>7Q047Q00L0hN7Q0>4003gQ00<?hN400^400`3Qh@03h@030>7Q00?Q00<?hN40

>N400`3Qh@02h@030>4003;Q000Jh@033n7Q02kQ0`13h@030>7Q00?Q00<0hN408^400`oQh@0Kh@07

0>7Qh@3Q0012h@030>7Q00;Q00<0hN40@N401`3QhN40h@00?^401@oQhN4000CQ0P04h@033n7Q03_Q

00L0hN7Q0>4003;Q000Jh@033n7Q02kQ00<0hN40@n40103QhN4202GQ00<?hN406n40103QhN4204?Q

00<0hN400n400`3Qh@10h@030>7Q00;Q00<0hN40?^4010oQh@03h@030>4000CQ00<?hN40>n401`3Q

hN40h@00<^4001[Q00<?hN40;^400`3Qh@13h@050>7Qh@009^400`oQh@0Kh@050>7Qh@00A>401`3Q

hN40h@00@^401`3QhN40h@00?n4010oQh@03h@030>4000?Q00<?hN40>n400`3Q0002h@030>4003;Q

000Jh@033n7Q02kQ00<0hN40@^4200?Q0`0Th@033n7Q01[Q0P04h@80@N4200?Q0`11h@801>400`3Q

h@0oh@033`0000CQ0P03h@033n7Q03cQ00<0hN400^400`3Qh@0ah@006^400`oQh@0^h@030>7Q06kQ

00<?hN40mN400`oQh@08h@033n7Q07GQ000Ih@033n7Q02oQ00<0hN40K^400`oQh@3fh@033n7Q00KQ

00<?hN40M^4001WQ00<?hN40;n400`3Qh@1^h@033n7Q0?KQ00<?hN401^400`oQh@1fh@006N400`oQ

h@0_h@030>7Q06kQ00<?hN40mn400`oQh@04h@033n7Q07OQ000Ih@033n7Q02oQ00<0hN40K^400`oQ

h@3hh@033n7Q00?Q00<?hN40Mn4001WQ00<?hN40;n400`3Qh@1^h@033n7Q0?WQ00D?hN7Q3`1jh@00

6N400`oQh@0_h@030>7Q06kQ00<?hN40nN4010oQh@mWh@@04>4001WQ00<?hN40;n400`3Qh@1^h@03

3n7Q0?[Q00<?h@l0In43017Q000<h@d000<?0000X0000`l0003k00033`0005L04N400`3Qh@0?h@00

4>400`3Qh@06h@033n7Q00?Q00<0hN403>400`3Qh@0;h@030>7Q00cQ00<0hN402n400`3Qh@0<h@03

0>7Q00cQ00<0hN402n400`3Qh@0<h@030>7Q00_Q00<0hN403>400`3Qh@08h@053n7Qh@003N400`3Q

h@0<h@030>7Q00_Q00<0hN403>400`3Qh@0<h@030>7Q00_Q00<0hN403>400`3Qh@0;h@030>7Q00cQ

00<0hN403>400`3Qh@0;h@030>7Q00cQ00<0hN402n400`3Qh@0<h@030>7Q00cQ00<0hN402n400`3Q

h@0<h@040>4?3`[Q00<0hN403>400`3Qh@0<h@030>7Q00_Q00<0hN403>400`3Qh@0;h@030>7Q01;Q

0P0Ah@004>400`3Qh@06h@033n7Q00?Q00<0hN403>400`3Qh@0;h@030>7Q00cQ00<0hN402n400`3Q

h@0<h@030>7Q00cQ00<0hN402n400`3Qh@0<h@030>7Q00_Q00<0hN403>400`3Qh@08h@053n7Qh@00

3N400`3Qh@0<h@030>7Q00_Q00<0hN403>400`3Qh@0<h@030>7Q00_Q00<0hN403>400`3Qh@0;h@03

0>7Q00cQ00<0hN403>400`3Qh@0;h@030>7Q00cQ00<0hN402n400`3Qh@0<h@030>7Q00cQ00<0hN40

2n400`3Qh@0<h@0400oQ3`[Q00<0hN403>400`3Qh@0<h@030>7Q00_Q00<0hN403>400`3Qh@0;h@03

0>7Q02GQ000Ih@033n7Q02oQ00<0hN40A^400`3Qh@0Uh@033n7Q01kQ00<0hN40A^400`3Qh@16h@03

0>7Q04KQ00D?hN7Q3`14h@030>7Q03?Q000Ih@033n7Q02oQ00<0hN40A^400`3Qh@0Uh@033n7Q01kQ

00<0hN40A^400`3Qh@16h@030>7Q04KQ00D?hN7Q3`14h@030>7Q03?Q000Ih@033n7Q02oQ00<0hN40

K^400`oQh@3hh@033n7Q00?Q00<?hN40Mn4001WQ00<?hN40;n400`3Qh@1^h@033n7Q0?OQ00<?hN40

1>400`oQh@1gh@006N400`oQh@0_h@030>7Q06kQ00<?hN40m^400`oQh@06h@033n7Q07KQ000Jh@03

3n7Q02kQ00<0hN40K^400`oQh@3fh@033n7Q00KQ00<?hN40M^4001[Q00<?hN40;^400`3Qh@1^h@03

3n7Q0?GQ00<?hN402>400`oQh@1eh@006^400`oQh@0^h@030>7Q06kQ00<?hN40m>400`oQh@09h@03

3n7Q07GQ000Jh@033n7Q02kQ00<0hN40K^400`oQh@3ch@033n7Q00_Q00<?hN40M>4001[Q00<?hN40

;^4306kQ00<?hN40l^400`oQh@0<h@033n7Q07CQ000Jh@033n7Q02kQ00<0hN40K^400`oQh@3bh@03

3n7Q00gQ00<?hN40Ln4001[Q00<?hN40;^400`3Qh@1^h@033n7Q0?7Q00<?hN403^400`oQh@1ch@00

6^400`oQh@0^h@030>7Q06kQ00<?hN40l>400`oQh@0?h@033n7Q07?Q000Jh@033n7Q02kQ00<0hN40

K^400`oQh@3_h@033n7Q017Q00<?hN40L^4001[Q00<?hN40;^400`3Qh@1^h@033n7Q0>kQ00<?hN40

4^400`oQh@1bh@006^400`oQh@0^h@030>7Q06kQ00<?hN40kN400`oQh@28h@006^400`oQh@0^h@03

0>7Q06kQ00<?hN40k>400`oQh@29h@006^400`oQh@0^h@030>7Q06kQ00<?hN40j^423aSQ00<?hN40

LN4001[Q00<?hN40;^400`3Qh@1^h@033n7Q0>WQ00<?hN406>400`oQh@1ah@006^400`oQh@0^h@03

0>7Q06kQ00<?hN40jN400`oQh@0Hh@033n7Q077Q000Kh@033n7Q02gQ00<0hN40K^400`oQh@3Wh@8?

6n423g;Q000Kh@033n7Q02gQ0`1^h@033n7Q0>KQ00<?hN407>400`oQh@1`h@006n400`oQh@0]h@03

0>7Q06kQ00<?hN40iN400`oQh@0Mh@033n7Q073Q000Kh@033n7Q02gQ00<0hN40K^400`oQh@3Th@03

3n7Q01kQ00<?hN40L>4001_Q00<?hN40;N400`3Qh@1^h@033n7Q0>?Q00<?hN407n400`oQh@1`h@00

6n400`oQh@0]h@030>7Q06oQ00<?hN40h>423b;Q00<?hN40L>4001_Q00<?hN40;N400`3Qh@1_h@03

3n7Q0=oQ00<?hN408n400`oQh@1_h@006n400`oQh@0]h@030>7Q06oQ00<?hN40g^400`oQh@0Th@03

3n7Q06oQ000Kh@033n7Q02gQ00<0hN40Kn400`oQh@3Lh@8?9n400`oQh@1_h@006n400`oQh@0]h@03

0>7Q06oQ00<?hN40fn400`oQh@0Wh@033n7Q06oQ000Lh@033n7Q02cQ00<0hN40Kn400`oQh@3Ih@8?

:^400`oQh@1_h@007>400`oQh@0/h@030>7Q06oQ00<?hN40f>400`oQh@0Zh@033n7Q06oQ000Lh@03

3n7Q02cQ00<0hN40Kn400`oQh@3Gh@033n7Q02_Q00<?hN40Kn4001cQ00<?hN40;>43073Q00<?hN40

eN400`oQh@0/h@033n7Q06oQ000Lh@033n7Q02cQ00<0hN40L>400`oQh@3Dh@033n7Q02gQ00<?hN40

Kn4001cQ00<?hN40;>400`3Qh@1`h@033n7Q0=;Q0PnRh@007N400`oQh@0[h@030>7Q073Q00<?hN40

cn433jCQ000Mh@033n7Q02_Q00<0hN40L>400`oQh@3>h@033n7Q0:GQ000Mh@033n7Q02_Q00<0hN40

L>400`oQh@3=h@033n7Q0:KQ000Mh@033n7Q02_Q00<0hN40L>400`oQh@3;h@8?ZN4001gQ00<?hN40

:n400`3Qh@1ah@033n7Q0<WQ00<?hN40=n400`oQh@1_h@007N400`oQh@0[h@030>7Q077Q00<?hN40

an423c[Q00<?hN40Kn4001kQ00<?hN40:^400`3Qh@1ah@033n7Q0<KQ00<?hN40>^400`oQh@1_h@00

7^400`oQh@0Zh@030>7Q077Q00<?hN40a>423cgQ00<?hN40Kn4001kQ00<?hN40:^400`3Qh@1ah@03

3n7Q0<?Q00<?hN40?N400`oQh@1_h@007^400`oQh@0Zh@<0LN400`oQh@31h@8?@>400`oQh@1_h@00

7^400`oQh@0Zh@030>7Q077Q00<?hN40_^433d;Q00<?hN40Kn4001kQ00<?hN40:^400`3Qh@1ah@03

3n7Q0;gQ00<?hN40@n400`oQh@1_h@007n400`oQh@0Yh@030>7Q077Q00<?hN40^n423dKQ00<?hN40

Kn4001oQ00<?hN40:N400`3Qh@1ah@033n7Q0;[Q00<?hN40AN423g7Q000Oh@033n7Q02WQ00<0hN40

L^400`oQh@2hh@033n7Q04KQ00<?hN40L>4001oQ00<?hN40:N400`3Qh@1bh@033n7Q0;GQ0`m9h@03

3n7Q073Q000Oh@033n7Q02WQ00<0hN40L^400`oQh@2ch@8?C>400`oQh@1`h@007n400`oQh@0Yh@03

0>7Q07;Q00<?hN40/^400`oQh@1<h@033n7Q03gQ0bP`h@008>400`oQh@0Xh@030>7Q07;Q00<?hN40

/>423doQ00<?hN40>N45:3;Q000Ph@033n7Q01kQ00<0hN401n400`3Qh@1ch@033n7Q0:cQ0`m@h@8?

=^45:3OQ000Ph@033n7Q01gQ00<0h@002>400`3Qh@1ch@033n7Q0:_Q00<?hN40DN400`oQh@0ah@DX

>n40023Q00<?hN407n400`3Qh@06h@@0L^400`oQh@2Yh@8?E>400`oQh@0]h@DX?n40027Q00<?hN40

7>4200WQ00<0hN40Ln400`oQh@2Vh@<?E^400`oQh@0Xh@DXA>40027Q00<?hN407>400`3Qh@08h@03

0>7Q07?Q00<?hN40YN400`oQh@1Gh@033n7Q02CQ1BQ8h@008N400`oQh@0Lh@<02>400`3Qh@1ch@03

3n7Q0:CQ00<?hN40En423b;Q1BQ<h@008^400`oQh@0Vh@030>7Q07?Q00<?hN40XN433e[Q00<?hN40

7N44:57Q000Rh@033n7Q02KQ00<0hN40M>400`oQh@2Nh@8?GN400`oQh@0Ih@@XEN4002;Q00<?hN40

9^400`3Qh@1dh@033n7Q09gQ00<?hN40GN400`oQh@0Eh@@XFN4002?Q00<?hN409N400`3Qh@1dh@03

3n7Q09[Q0`mOh@033n7Q01;Q12QMh@008n400`oQh@0Uh@030>7Q07CQ00<?hN40V>423f;Q00<?hN40

3^44:67Q000Sh@033n7Q02GQ00<0hN40MN400`oQh@2Dh@<?I>400`oQh@0:h@@XIN4002CQ00<?hN40

9>400`3Qh@1eh@033n7Q09?Q00<?hN40IN400`oQh@06h@DXJ>4002CQ00<?hN409>400`3Qh@1eh@03

3n7Q093Q0`mWh@033n7Q00CQ12Q/h@009>400`oQh@0Th@<0M^400`oQh@2>h@033n7Q06SQ00<?hN40

12Q`h@009N400`oQh@0Sh@030>7Q07KQ00<?hN40Rn433f_Q12Qch@009N400`oQh@0Sh@030>7Q07KQ

00<?hN40RN423f[Q12Qgh@009^400`oQh@0Rh@030>7Q07KQ00<?hN40Q^433fWQ12P2h@033n7Q07GQ

000Vh@033n7Q02;Q00<0hN40M^400`oQh@25h@033n7Q06KQ12P5h@033n7Q07KQ000Vh@033n7Q02;Q

00<0hN40M^400`oQh@22h@<?I^44:0SQ00<?hN40M^4002OQ00<?hN408N400`3Qh@1gh@033n7Q07oQ

0PmVh@@X2n400`oQh@1fh@009n400`oQh@0Qh@030>7Q07OQ00<?hN40O>433fGQ0bP>h@033n7Q07OQ

000Xh@033n7Q023Q00<0hN40N>400`oQh@1ih@8?IN43:17Q00<?hN40Mn4002SQ00<?hN408>400`3Q

h@1hh@033n7Q07OQ0PmTh@@X4n400`oQh@1gh@00:N400`oQh@0Oh@030>7Q07SQ00<?hN40M>433f?Q

12PEh@033n7Q07SQ000Yh@033n7Q01oQ00<0hN40NN400`oQh@1`h@<?Hn44:1SQ00<?hN40N>4002[Q

00<?hN407^4307WQ00<?hN40Kn400`oQh@1Rh@<X6^423g[Q000Zh@033n7Q01kQ00<0hN40NN400`oQ

h@1/h@<?H^43:1gQ00<?hN40NN4002_Q00<?hN407N400`3Qh@1ih@033n7Q06WQ0`mRh@@X7^400`oQ

h@1jh@00:n400`oQh@0Mh@030>7Q07WQ00<?hN40I^433f?Q0bPQh@033n7Q07[Q000/h@033n7Q01cQ

00<0hN40N^400`oQh@1Rh@<?I>43:2;Q0Pmlh@00;N400`oQh@0Kh@030>7Q07[Q00<?hN40HN400`oQ

h@1Rh@<X9N400`oQh@1kh@00;N400`oQh@0Kh@030>7Q07_Q00<?hN40GN433f?Q0bPWh@033n7Q07_Q

000^h@033n7Q01[Q00<0hN40Nn400`oQh@1Ih@043n4?3fCQ0bPXh@033n7Q07cQ000^h@033n7Q01[Q

00<0hN40Nn400`oQh@1Fh@<?I^43:2WQ00<?hN40ON4002oQ00<?hN406N400`3Qh@1kh@033n7Q05?Q

0`mWh@<X:n400`oQh@1mh@00<>400`oQh@0Hh@030>7Q07cQ00<?hN40D>433fOQ0bP/h@033n7Q07kQ

000`h@033n7Q01SQ00<0hN40O>400`oQh@1=h@<?J>43:2kQ00<?hN40O^40037Q00<?hN405n4307gQ

00<?hN40B>443f[Q0RP_h@033n7Q07oQ000bh@033n7Q01KQ00<0hN40ON400`oQh@16h@<?Jn42:37Q

00<?hN40On4003?Q00<?hN405N400`3Qh@1nh@033n7Q04;Q0`m]h@8X<N400`oQh@20h@00<n400`oQ

h@0Eh@030>7Q07kQ00<?hN40?n433fkQ0RPbh@033n7Q087Q000dh@033n7Q01CQ00<0hN40O^400`oQ

h@0lh@<?L>42:3?Q00<?hN40PN4003GQ00<?hN404n400`3Qh@1nh@033n7Q03WQ0`mbh@03:>7Q03;Q

00<?hN40P^4003KQ00<?hN404^400`3Qh@1oh@033n7Q03CQ10mch@8X=>423hCQ000gh@033n7Q017Q

00<0hN40P>400`oQh@0`h@@?M^400bSQh@0ch@033n7Q08?Q000hh@033n7Q013Q00<0hN40P>400`oQ

h@0]h@@?Mn42:3GQ00<?hN40Q>4003WQ00<?hN403n400`3Qh@21h@033n7Q02WQ0`mjh@8X=N400`oQ

h@25h@00>N400`oQh@0?h@030>7Q087Q00<?hN409N443ggQ00<XhN40<n423hOQ000jh@033n7Q00kQ

00<0hN40PN400`oQh@0Rh@<?P>400bSQh@0dh@033n7Q08KQ000kh@033n7Q00gQ0`22h@033n7Q01kQ

0`n2h@8X=N400`oQh@27h@00?>423`gQ00<0hN40Pn400`oQh@0Jh@<?Q>42:3GQ0Pn9h@00?^400`oQ

h@0:h@030>7Q08?Q00<?hN405^443hOQ00<XhN40<n423h[Q000oh@033n7Q00WQ00<0hN40Pn400`oQ

h@0Bh@@?Rn400bSQh@0bh@8?Rn40043Q00<?hN402>400`3Qh@24h@033n7Q00kQ10n=h@03:>7Q03?Q

00<?hN40D^42:3KQ0011h@033n7Q00OQ00<0hN40QN400`oQh@09h@@?TN400bSQh@0bh@033n7Q04kQ

1RPgh@00@^400`oQh@06h@030>7Q08GQ00<?hN401N443lWQ0Pm:h@LX?>4004?Q00<?hN401N400`3Q

h@26h@043n7Qh@@?bn400`oQh@15h@HX@^4004CQ0Pl5h@030>7Q08KQ10o>h@033n7Q047Q1BQ8h@00

A^400`oQh@02h@030>7Q08;Q10l00n4?h@3>h@8??N46:4gQ000jh@D00^400`3Qh@03h@8?0^400`3Q

h@1oh@@?1N400`oQh@2Kh@03:>7Q02gQ0Plhh@HXDn4003cQ00L0hN7Q0>4000KQ00<?h@00O>453`[Q

00<?hN40V^400bSQh@0/h@033n7Q03?Q1BQIh@00?>401`3QhN40h@001n423`<0MN453`kQ00<?hN40

Vn400bSQh@0Zh@033n7Q02kQ1RQNh@00?>401`3QhN40h@002>400`0?3`1bh@@?5>400`oQh@2Jh@03

:>7Q02SQ0Pl/h@DXI>4003cQ00L0hN7Q0>4000SQ00<0hN400Pm/h@D?6>400`oQh@2Jh@03:>7Q02KQ

0PlWh@HXJN4003_Q0P04h@030>7Q00OQ00<0hN400^423fKQ10lNh@033n7Q09[Q00<XhN409>423b;Q

1RQ_h@00Bn400`3Qh@04h@8?G^463b;Q00<?hN40Vn400bSQh@0Qh@<?7^45:7GQ001;h@030>7Q00KQ

0`mGh@D?:>400`oQh@2Kh@8X8>423a[Q1RQjh@00Bn400`3Qh@09h@<?Cn453bkQ00<?hN40W>400bSQ

h@0Lh@8?5N46:83Q001;h@030>7Q00cQ0`m6h@H?<n400`oQh@2Mh@<X6N423a7Q1bR5h@00Bn400`3Q

h@0?h@<??N463c[Q00<?hN40Wn43:1CQ0`l;h@LXS>4004_Q00<0hN404^463c3Q1`m1h@033n7Q0:7Q

12P>h@<?1>49:9?Q001;h@030>7Q01SQ1@lQh@X?BN400`oQh@2Th@dX0Pl7:9_Q001;h@030>7Q01gQ

8PmCh@033n7Q0:gQ0`nTh@00Bn4309?Q00<?hN40Z^433jKQ001;h@030>7Q09CQ00<?hN40Yn433jSQ

001;h@030>7Q09GQ00<?hN40Xn433j_Q001;h@030>7Q09KQ00<?hN40Wn443jgQ001;h@030>7Q09OQ

00<?hN40Vn443k3Q001;h@030>7Q09SQ0PnHh@@?/n4004_Q00<0hN40VN423i?Q10ngh@00Bn400`3Q

h@2Kh@8?SN453k[Q001;h@030>7Q09cQ0Pn8h@D?_^4004_Q00<0hN40W^423h7Q1Po2h@00Bn400`3Q

h@2Oh@8?Nn463lOQ001;h@030>7Q0:7Q0Pmdh@H?c>4004_Q0`2Sh@8?K^453m7Q001;h@030>7Q0:CQ

0`mVh@H?e^4004_Q00<0hN40Yn423eoQ1PoKh@00Bn400`3Qh@2Yh@<?E^463n7Q001;h@030>7Q0:cQ

0`m=h@H?in4004_Q00<0hN40[n433d?Q20o/h@00Bn400`3Qh@2ah@D?>>483o?Q001;h@030>7Q0;KQ

1@l[h@T?n^4004_Q00<0hN40^n493aKQ30ooh@CQ001;h@030>7Q0<CQ5`ooh@oQ001;h@030>7Q0?oQ

j^4004_Q00<0hN40on7Zh@00Bn430?oQj^4004_Q00<0hN40on7Zh@00Bn400`3Qh@3ohN[Q001;h@03

0>7Q0?oQj^4004_Q00<0hN40on7Zh@00Bn400`3Qh@3ohN[Q003ohOoQ>N400?oQon4ih@00on7ohCWQ

003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQ

on4ih@00on47h@8000CQ003Q10000n400004h@030>7Q0?oQ7^400?oQ2>400`3Q0009h@060>7Q0>40

on4Oh@00on48h@<00^4400;Q00L0hN7Q0>400?oQ7n400?oQ2>40103Q0008h@050>7Qh@00on4Ph@00

BN420;cQ00<0hN401n400`3Q0002h@030>400?oQ7n4004[Q00<0hN40^N4200[Q00<0hN400^400`3Q

h@3ohAkQ0018h@<00^400`3Qh@3ohNSQ0017h@080>7Q0>40h@3ohNWQ0017h@080>7Q0>40h@3ohNWQ

0018h@<000CQ0>40on7Yh@00C>400`3Q003ohNWQ001=h@030>7Q0?oQj>400?oQon4ih@00on7ohCWQ

003ohOoQ>N400?oQon4ih@00on7ohCWQ0000\

\>"],

  ImageRangeCache->{{{0, 566}, {349.313, 0}} -> {12.969, -13.3541, 0.0136957, 

  0.0833706}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-1.65934 0.125561 0.309017 0.0226592 [

[.22408 .29652 -6 -9 ]

[.22408 .29652 6 0 ]

[.34964 .29652 -6 -9 ]

[.34964 .29652 6 0 ]

[.4752 .29652 -6 -9 ]

[.4752 .29652 6 0 ]

[.60076 .29652 -6 -9 ]

[.60076 .29652 6 0 ]

[.72632 .29652 -6 -9 ]

[.72632 .29652 6 0 ]

[.85188 .29652 -6 -9 ]

[.85188 .29652 6 0 ]

[.97745 .29652 -6 -9 ]

[.97745 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.08602 .08243 -18 -4.5 ]

[.08602 .08243 0 4.5 ]

[.08602 .19572 -12 -4.5 ]

[.08602 .19572 0 4.5 ]

[.08602 .42231 -6 -4.5 ]

[.08602 .42231 0 4.5 ]

[.08602 .53561 -12 -4.5 ]

[.08602 .53561 0 4.5 ]

[.09852 .64303 -7 0 ]

[.09852 .64303 7 16 ]

[.5 .63053 -19.5 0 ]

[.5 .63053 19.5 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.22408 .30902 m

.22408 .31527 L

s

[(15)] .22408 .29652 0 1 Mshowa

.34964 .30902 m

.34964 .31527 L

s

[(16)] .34964 .29652 0 1 Mshowa

.4752 .30902 m

.4752 .31527 L

s

[(17)] .4752 .29652 0 1 Mshowa

.60076 .30902 m

.60076 .31527 L

s

[(18)] .60076 .29652 0 1 Mshowa

.72632 .30902 m

.72632 .31527 L

s

[(19)] .72632 .29652 0 1 Mshowa

.85188 .30902 m

.85188 .31527 L

s

[(20)] .85188 .29652 0 1 Mshowa

.97745 .30902 m

.97745 .31527 L

s

[(21)] .97745 .29652 0 1 Mshowa

.125 Mabswid

.12363 .30902 m

.12363 .31277 L

s

.14874 .30902 m

.14874 .31277 L

s

.17386 .30902 m

.17386 .31277 L

s

.19897 .30902 m

.19897 .31277 L

s

.24919 .30902 m

.24919 .31277 L

s

.2743 .30902 m

.2743 .31277 L

s

.29942 .30902 m

.29942 .31277 L

s

.32453 .30902 m

.32453 .31277 L

s

.37475 .30902 m

.37475 .31277 L

s

.39987 .30902 m

.39987 .31277 L

s

.42498 .30902 m

.42498 .31277 L

s

.45009 .30902 m

.45009 .31277 L

s

.50031 .30902 m

.50031 .31277 L

s

.52543 .30902 m

.52543 .31277 L

s

.55054 .30902 m

.55054 .31277 L

s

.57565 .30902 m

.57565 .31277 L

s

.62588 .30902 m

.62588 .31277 L

s

.65099 .30902 m

.65099 .31277 L

s

.6761 .30902 m

.6761 .31277 L

s

.70121 .30902 m

.70121 .31277 L

s

.75144 .30902 m

.75144 .31277 L

s

.77655 .30902 m

.77655 .31277 L

s

.80166 .30902 m

.80166 .31277 L

s

.82677 .30902 m

.82677 .31277 L

s

.877 .30902 m

.877 .31277 L

s

.90211 .30902 m

.90211 .31277 L

s

.92722 .30902 m

.92722 .31277 L

s

.95233 .30902 m

.95233 .31277 L

s

.07341 .30902 m

.07341 .31277 L

s

.04829 .30902 m

.04829 .31277 L

s

.02318 .30902 m

.02318 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.09852 .08243 m

.10477 .08243 L

s

[(-10)] .08602 .08243 1 0 Mshowa

.09852 .19572 m

.10477 .19572 L

s

[(-5)] .08602 .19572 1 0 Mshowa

.09852 .42231 m

.10477 .42231 L

s

[(5)] .08602 .42231 1 0 Mshowa

.09852 .53561 m

.10477 .53561 L

s

[(10)] .08602 .53561 1 0 Mshowa

.125 Mabswid

.09852 .10508 m

.10227 .10508 L

s

.09852 .12774 m

.10227 .12774 L

s

.09852 .1504 m

.10227 .1504 L

s

.09852 .17306 m

.10227 .17306 L

s

.09852 .21838 m

.10227 .21838 L

s

.09852 .24104 m

.10227 .24104 L

s

.09852 .2637 m

.10227 .2637 L

s

.09852 .28636 m

.10227 .28636 L

s

.09852 .33168 m

.10227 .33168 L

s

.09852 .35434 m

.10227 .35434 L

s

.09852 .37699 m

.10227 .37699 L

s

.09852 .39965 m

.10227 .39965 L

s

.09852 .44497 m

.10227 .44497 L

s

.09852 .46763 m

.10227 .46763 L

s

.09852 .49029 m

.10227 .49029 L

s

.09852 .51295 m

.10227 .51295 L

s

.09852 .05977 m

.10227 .05977 L

s

.09852 .03711 m

.10227 .03711 L

s

.09852 .01445 m

.10227 .01445 L

s

.09852 .55827 m

.10227 .55827 L

s

.09852 .58093 m

.10227 .58093 L

s

.09852 .60359 m

.10227 .60359 L

s

.25 Mabswid

.09852 0 m

.09852 .61803 L

s

gsave

.09852 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -80.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(k) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(39.65) show

98.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

1 0 0 r

.5 Mabswid

.41368 .58145 m

.41242 .58055 L

.41117 .57962 L

.40991 .57867 L

.40865 .57769 L

.4074 .57669 L

.40614 .57565 L

.40489 .57458 L

.40363 .57349 L

.40238 .57236 L

.40112 .5712 L

.39987 .57 L

.39861 .56877 L

.39735 .56751 L

.3961 .56621 L

.39484 .56488 L

.39359 .56351 L

.39233 .5621 L

.39108 .56065 L

.38982 .55916 L

.38856 .55762 L

.38731 .55605 L

.38605 .55442 L

.3848 .55275 L

.38354 .55104 L

.38229 .54927 L

.38103 .54746 L

.37978 .54559 L

.37852 .54367 L

.37726 .54169 L

.37601 .53965 L

.37475 .53756 L

.3735 .5354 L

.37224 .53318 L

.37099 .53089 L

.36973 .52853 L

.36847 .52609 L

.36722 .52358 L

.36596 .521 L

.36471 .51833 L

.36345 .51557 L

.3622 .51272 L

.36094 .50978 L

.35969 .50674 L

.35843 .50359 L

.35717 .50033 L

.35592 .49695 L

.35466 .49345 L

.35341 .48981 L

.35215 .48603 L

Mistroke

.3509 .4821 L

.34964 .47801 L

.34838 .47374 L

.34713 .46927 L

.34587 .4646 L

.34462 .4597 L

.34336 .45455 L

.34211 .44911 L

.34085 .44335 L

.3396 .43723 L

.33834 .4307 L

.33708 .42367 L

.33583 .41606 L

.33457 .40772 L

.33332 .39844 L

.33206 .38791 L

.33081 .37552 L

.32955 .35993 L

.3283 .33608 L

.32804 .30902 L

Mfstroke

.41368 .03659 m

.41242 .03749 L

.41117 .03841 L

.40991 .03936 L

.40865 .04034 L

.4074 .04135 L

.40614 .04238 L

.40489 .04345 L

.40363 .04455 L

.40238 .04568 L

.40112 .04684 L

.39987 .04803 L

.39861 .04926 L

.39735 .05052 L

.3961 .05182 L

.39484 .05315 L

.39359 .05452 L

.39233 .05594 L

.39108 .05739 L

.38982 .05888 L

.38856 .06041 L

.38731 .06199 L

.38605 .06361 L

.3848 .06528 L

.38354 .067 L

.38229 .06876 L

.38103 .07058 L

.37978 .07244 L

.37852 .07437 L

.37726 .07634 L

.37601 .07838 L

.37475 .08048 L

.3735 .08264 L

.37224 .08486 L

.37099 .08715 L

.36973 .08951 L

.36847 .09194 L

.36722 .09445 L

.36596 .09704 L

.36471 .09971 L

.36345 .10246 L

.3622 .10531 L

.36094 .10826 L

.35969 .1113 L

.35843 .11445 L

.35717 .11771 L

.35592 .12108 L

.35466 .12459 L

.35341 .12822 L

.35215 .132 L

Mistroke

.3509 .13593 L

.34964 .14003 L

.34838 .1443 L

.34713 .14876 L

.34587 .15343 L

.34462 .15833 L

.34336 .16349 L

.34211 .16893 L

.34085 .17468 L

.3396 .1808 L

.33834 .18734 L

.33708 .19436 L

.33583 .20198 L

.33457 .21032 L

.33332 .21959 L

.33206 .23012 L

.33081 .24251 L

.32955 .2581 L

.3283 .28196 L

.32804 .30902 L

Mfstroke

.41242 .58003 m

.41493 .58232 L

.41744 .58399 L

.41995 .58556 L

.42247 .58704 L

.42498 .58844 L

.42749 .58975 L

.43 .59098 L

.43251 .59213 L

.43502 .59321 L

.43753 .59422 L

.44004 .59516 L

.44256 .59603 L

.44507 .59685 L

.44758 .5976 L

.45009 .5983 L

.4526 .59894 L

.45511 .59953 L

.45762 .60007 L

.46013 .60056 L

.46265 .60101 L

.46516 .60141 L

.46767 .60177 L

.47018 .60208 L

.47269 .60236 L

.4752 .6026 L

.47771 .6028 L

.48022 .60297 L

.48274 .6031 L

.48525 .6032 L

.48776 .60327 L

.49027 .60331 L

.49278 .60332 L

.49529 .6033 L

.4978 .60326 L

.50031 .60319 L

.50283 .60309 L

.50534 .60297 L

.50785 .60283 L

.51036 .60267 L

.51287 .60248 L

.51538 .60228 L

.51789 .60205 L

.5204 .60181 L

.52291 .60155 L

.52543 .60127 L

.52794 .60097 L

.53045 .60065 L

.53296 .60032 L

.53547 .59997 L

Mistroke

.53798 .59961 L

.54049 .59924 L

.543 .59885 L

.54552 .59844 L

.54803 .59802 L

.55054 .59759 L

.55305 .59715 L

.55556 .59669 L

.55807 .59622 L

.56058 .59574 L

.56309 .59525 L

.56561 .59474 L

.56812 .59422 L

.57063 .5937 L

.57314 .59316 L

.57565 .59261 L

.57816 .59204 L

.58067 .59147 L

.58318 .59089 L

.5857 .59029 L

.58821 .58968 L

.59072 .58906 L

.59323 .58843 L

.59574 .58779 L

.59825 .58714 L

.60076 .58647 L

.60327 .5858 L

.60579 .58511 L

.6083 .5844 L

.61081 .58369 L

.61332 .58296 L

.61583 .58221 L

.61834 .58146 L

.62085 .58068 L

.62336 .57989 L

.62588 .57909 L

.62839 .57827 L

.6309 .57743 L

.63341 .57657 L

.63592 .5757 L

.63843 .5748 L

.64094 .57389 L

.64345 .57295 L

.64596 .57199 L

.64848 .57101 L

.65099 .57001 L

.6535 .56898 L

.65601 .56792 L

.65852 .56684 L

.66103 .56573 L

Mistroke

.66354 .56458 L

.66605 .56341 L

.66857 .5622 L

.67108 .56096 L

.67359 .55969 L

.6761 .55838 L

.67861 .55702 L

.68112 .55563 L

.68363 .5542 L

.68614 .55272 L

.68866 .55119 L

.69117 .54962 L

.69368 .548 L

.69619 .54632 L

.6987 .54459 L

.70121 .5428 L

.70372 .54095 L

.70623 .53904 L

.70875 .53707 L

.71126 .53502 L

.71377 .53291 L

.71628 .53072 L

.71879 .52845 L

.7213 .5261 L

.72381 .52367 L

.72632 .52115 L

.72884 .51854 L

.73135 .51583 L

.73386 .51302 L

.73637 .5101 L

.73888 .50707 L

.74139 .50392 L

.7439 .50065 L

.74641 .49724 L

.74892 .49371 L

.75144 .49002 L

.75395 .48617 L

.75646 .48216 L

.75897 .47796 L

.76148 .47358 L

.76399 .46898 L

.7665 .46414 L

.76901 .45906 L

.77153 .45368 L

.77404 .44798 L

.77655 .44189 L

.77906 .43536 L

.78157 .42827 L

.78408 .42049 L

.78659 .41176 L

Mistroke

.7891 .4016 L

.79162 .3889 L

.79413 .368 L

Mfstroke

.41242 .038 m

.41493 .03572 L

.41744 .03405 L

.41995 .03247 L

.42247 .03099 L

.42498 .0296 L

.42749 .02829 L

.43 .02706 L

.43251 .0259 L

.43502 .02483 L

.43753 .02382 L

.44004 .02287 L

.44256 .022 L

.44507 .02118 L

.44758 .02043 L

.45009 .01973 L

.4526 .01909 L

.45511 .0185 L

.45762 .01796 L

.46013 .01747 L

.46265 .01702 L

.46516 .01663 L

.46767 .01627 L

.47018 .01595 L

.47269 .01567 L

.4752 .01544 L

.47771 .01523 L

.48022 .01507 L

.48274 .01493 L

.48525 .01484 L

.48776 .01476 L

.49027 .01473 L

.49278 .01472 L

.49529 .01473 L

.4978 .01478 L

.50031 .01485 L

.50283 .01494 L

.50534 .01506 L

.50785 .0152 L

.51036 .01537 L

.51287 .01555 L

.51538 .01576 L

.51789 .01598 L

.5204 .01623 L

.52291 .01649 L

.52543 .01677 L

.52794 .01707 L

.53045 .01738 L

.53296 .01771 L

.53547 .01806 L

Mistroke

.53798 .01842 L

.54049 .0188 L

.543 .01919 L

.54552 .01959 L

.54803 .02001 L

.55054 .02044 L

.55305 .02089 L

.55556 .02135 L

.55807 .02181 L

.56058 .02229 L

.56309 .02279 L

.56561 .02329 L

.56812 .02381 L

.57063 .02434 L

.57314 .02488 L

.57565 .02543 L

.57816 .02599 L

.58067 .02656 L

.58318 .02715 L

.5857 .02774 L

.58821 .02835 L

.59072 .02897 L

.59323 .0296 L

.59574 .03024 L

.59825 .03089 L

.60076 .03156 L

.60327 .03224 L

.60579 .03293 L

.6083 .03363 L

.61081 .03435 L

.61332 .03508 L

.61583 .03582 L

.61834 .03658 L

.62085 .03735 L

.62336 .03814 L

.62588 .03895 L

.62839 .03977 L

.6309 .04061 L

.63341 .04146 L

.63592 .04234 L

.63843 .04323 L

.64094 .04415 L

.64345 .04509 L

.64596 .04604 L

.64848 .04702 L

.65099 .04803 L

.6535 .04906 L

.65601 .05011 L

.65852 .0512 L

.66103 .05231 L

Mistroke

.66354 .05345 L

.66605 .05462 L

.66857 .05583 L

.67108 .05707 L

.67359 .05835 L

.6761 .05966 L

.67861 .06101 L

.68112 .0624 L

.68363 .06384 L

.68614 .06532 L

.68866 .06684 L

.69117 .06841 L

.69368 .07004 L

.69619 .07171 L

.6987 .07345 L

.70121 .07523 L

.70372 .07708 L

.70623 .07899 L

.70875 .08097 L

.71126 .08301 L

.71377 .08513 L

.71628 .08732 L

.71879 .08958 L

.7213 .09193 L

.72381 .09436 L

.72632 .09688 L

.72884 .0995 L

.73135 .10221 L

.73386 .10502 L

.73637 .10794 L

.73888 .11097 L

.74139 .11411 L

.7439 .11738 L

.74641 .12079 L

.74892 .12433 L

.75144 .12802 L

.75395 .13186 L

.75646 .13587 L

.75897 .14007 L

.76148 .14445 L

.76399 .14905 L

.7665 .15389 L

.76901 .15898 L

.77153 .16436 L

.77404 .17006 L

.77655 .17614 L

.77906 .18268 L

.78157 .18976 L

.78408 .19754 L

.78659 .20627 L

Mistroke

.7891 .21643 L

.79162 .22913 L

.79413 .25003 L

Mfstroke

.67736 .44247 m

.67798 .44196 L

.67861 .44143 L

.67924 .44088 L

.67987 .44032 L

.68049 .43975 L

.68112 .43917 L

.68175 .43857 L

.68238 .43798 L

.68301 .43737 L

.68363 .43675 L

.68426 .43615 L

.68489 .43554 L

.68552 .43491 L

.68614 .4343 L

.68677 .43368 L

.6874 .43306 L

.68803 .43244 L

.68866 .43183 L

.68928 .43121 L

.68991 .4306 L

.69054 .42999 L

.69117 .42938 L

.69179 .42876 L

.69242 .42815 L

.69305 .42755 L

.69368 .42694 L

.69431 .42634 L

.69493 .42573 L

.69556 .42513 L

.69619 .42453 L

.69682 .42393 L

.69744 .42334 L

.69807 .42274 L

.6987 .42214 L

.69933 .42155 L

.69996 .42096 L

.70058 .42036 L

.70121 .41977 L

.70184 .41918 L

.70247 .4186 L

.7031 .418 L

.70372 .41742 L

.70435 .41683 L

.70498 .41625 L

.70561 .41566 L

.70623 .41507 L

.70686 .41449 L

.70749 .41391 L

.70812 .41332 L

Mistroke

.70875 .41274 L

.70937 .41216 L

.71 .41157 L

.71063 .41099 L

.71126 .41041 L

.71188 .40982 L

.71251 .40924 L

.71314 .40866 L

.71377 .40808 L

.7144 .40749 L

.71502 .40691 L

.71565 .40633 L

.71628 .40574 L

.71691 .40516 L

.71753 .40457 L

.71816 .40399 L

.71879 .4034 L

.71942 .40282 L

.72005 .40223 L

.72067 .40164 L

.7213 .40105 L

.72193 .40046 L

.72256 .39987 L

.72318 .39928 L

.72381 .39869 L

.72444 .39809 L

.72507 .3975 L

.7257 .3969 L

.72632 .3963 L

.72695 .3957 L

.72758 .3951 L

.72821 .3945 L

.72884 .3939 L

.72946 .39329 L

.73009 .39269 L

.73072 .39208 L

.73135 .39147 L

.73197 .39085 L

.7326 .39024 L

.73323 .38963 L

.73386 .38901 L

.73449 .38839 L

.73511 .38776 L

.73574 .38714 L

.73637 .38651 L

.737 .38588 L

.73762 .38525 L

.73825 .38461 L

.73888 .38398 L

.73951 .38334 L

Mistroke

.74014 .38269 L

.74076 .38205 L

.74139 .3814 L

.74202 .38075 L

.74265 .38009 L

.74327 .37943 L

.7439 .37877 L

.74453 .3781 L

.74516 .37743 L

.74579 .37676 L

.74641 .37608 L

.74704 .3754 L

.74767 .37472 L

.7483 .37403 L

.74892 .37333 L

.74955 .37264 L

.75018 .37193 L

.75081 .37123 L

.75144 .37051 L

.75206 .3698 L

.75269 .36908 L

.75332 .36835 L

.75395 .36761 L

.75458 .36688 L

.7552 .36613 L

.75583 .36538 L

.75646 .36462 L

.75709 .36386 L

.75771 .36309 L

.75834 .36231 L

.75897 .36153 L

.7596 .36074 L

.76023 .35994 L

.76085 .35913 L

.76148 .35832 L

.76211 .3575 L

.76274 .35667 L

.76336 .35583 L

.76399 .35498 L

.76462 .35412 L

.76525 .35325 L

.76588 .35238 L

.7665 .35149 L

.76713 .35059 L

.76776 .34968 L

.76839 .34875 L

.76901 .34782 L

.76964 .34687 L

.77027 .34591 L

.7709 .34493 L

Mistroke

.77153 .34394 L

.77215 .34294 L

.77278 .34191 L

.77341 .34087 L

.77404 .33982 L

.77466 .33874 L

.77529 .33765 L

.77592 .33654 L

.77655 .3354 L

.77718 .33424 L

.7778 .33305 L

.77843 .33185 L

.77906 .33061 L

.77969 .32935 L

.78032 .32805 L

.78094 .32672 L

.78157 .32536 L

.7822 .32396 L

.78283 .32251 L

.78345 .32102 L

.78408 .31949 L

.78471 .3179 L

.78534 .31625 L

.78597 .31454 L

.78659 .31275 L

.78722 .31088 L

.78785 .30892 L

.78848 .30686 L

.7891 .30467 L

.78973 .30234 L

.79036 .29984 L

.79099 .29712 L

.79162 .29412 L

.79224 .29077 L

.79287 .28687 L

.7935 .28211 L

.79413 .27548 L

Mfstroke

.67736 .17556 m

.67798 .17608 L

.67861 .17661 L

.67924 .17716 L

.67987 .17771 L

.68049 .17828 L

.68112 .17886 L

.68175 .17946 L

.68238 .18006 L

.68301 .18066 L

.68363 .18128 L

.68426 .18189 L

.68489 .1825 L

.68552 .18312 L

.68614 .18374 L

.68677 .18436 L

.6874 .18497 L

.68803 .18559 L

.68866 .18621 L

.68928 .18682 L

.68991 .18743 L

.69054 .18804 L

.69117 .18866 L

.69179 .18927 L

.69242 .18988 L

.69305 .19049 L

.69368 .19109 L

.69431 .1917 L

.69493 .1923 L

.69556 .1929 L

.69619 .1935 L

.69682 .1941 L

.69744 .1947 L

.69807 .19529 L

.6987 .19589 L

.69933 .19648 L

.69996 .19708 L

.70058 .19767 L

.70121 .19826 L

.70184 .19885 L

.70247 .19944 L

.7031 .20003 L

.70372 .20062 L

.70435 .2012 L

.70498 .20179 L

.70561 .20237 L

.70623 .20296 L

.70686 .20354 L

.70749 .20413 L

.70812 .20471 L

Mistroke

.70875 .2053 L

.70937 .20588 L

.71 .20646 L

.71063 .20704 L

.71126 .20763 L

.71188 .20821 L

.71251 .20879 L

.71314 .20938 L

.71377 .20996 L

.7144 .21054 L

.71502 .21112 L

.71565 .21171 L

.71628 .21229 L

.71691 .21288 L

.71753 .21346 L

.71816 .21405 L

.71879 .21463 L

.71942 .21522 L

.72005 .21581 L

.72067 .21639 L

.7213 .21698 L

.72193 .21757 L

.72256 .21816 L

.72318 .21876 L

.72381 .21935 L

.72444 .21994 L

.72507 .22054 L

.7257 .22114 L

.72632 .22173 L

.72695 .22233 L

.72758 .22293 L

.72821 .22353 L

.72884 .22414 L

.72946 .22474 L

.73009 .22535 L

.73072 .22596 L

.73135 .22657 L

.73197 .22718 L

.7326 .22779 L

.73323 .22841 L

.73386 .22903 L

.73449 .22965 L

.73511 .23027 L

.73574 .2309 L

.73637 .23152 L

.737 .23215 L

.73762 .23279 L

.73825 .23342 L

.73888 .23406 L

.73951 .2347 L

Mistroke

.74014 .23534 L

.74076 .23599 L

.74139 .23664 L

.74202 .23729 L

.74265 .23795 L

.74327 .2386 L

.7439 .23927 L

.74453 .23993 L

.74516 .2406 L

.74579 .24127 L

.74641 .24195 L

.74704 .24263 L

.74767 .24332 L

.7483 .24401 L

.74892 .2447 L

.74955 .2454 L

.75018 .2461 L

.75081 .24681 L

.75144 .24752 L

.75206 .24824 L

.75269 .24896 L

.75332 .24969 L

.75395 .25042 L

.75458 .25116 L

.7552 .2519 L

.75583 .25265 L

.75646 .25341 L

.75709 .25417 L

.75771 .25494 L

.75834 .25572 L

.75897 .2565 L

.7596 .25729 L

.76023 .25809 L

.76085 .2589 L

.76148 .25971 L

.76211 .26054 L

.76274 .26137 L

.76336 .2622 L

.76399 .26305 L

.76462 .26391 L

.76525 .26478 L

.76588 .26566 L

.7665 .26655 L

.76713 .26745 L

.76776 .26836 L

.76839 .26928 L

.76901 .27022 L

.76964 .27116 L

.77027 .27213 L

.7709 .2731 L

Mistroke

.77153 .27409 L

.77215 .2751 L

.77278 .27612 L

.77341 .27716 L

.77404 .27821 L

.77466 .27929 L

.77529 .28039 L

.77592 .2815 L

.77655 .28264 L

.77718 .28379 L

.7778 .28498 L

.77843 .28619 L

.77906 .28742 L

.77969 .28869 L

.78032 .28998 L

.78094 .29131 L

.78157 .29267 L

.7822 .29408 L

.78283 .29552 L

.78345 .29701 L

.78408 .29855 L

.78471 .30014 L

.78534 .30179 L

.78597 .3035 L

.78659 .30528 L

.78722 .30715 L

.78785 .30911 L

.78848 .31118 L

.7891 .31336 L

.78973 .31569 L

.79036 .31819 L

.79099 .32092 L

.79162 .32391 L

.79224 .32726 L

.79287 .33116 L

.7935 .33593 L

.79413 .34255 L

Mfstroke

.6648 .44897 m

.66229 .44956 L

.65978 .45033 L

.65727 .45107 L

.65475 .45178 L

.65224 .45248 L

.64973 .45318 L

.64722 .45386 L

.64471 .45455 L

.6422 .45522 L

.63969 .4559 L

.63718 .45657 L

.63466 .45724 L

.63215 .45791 L

.62964 .45858 L

.62713 .45925 L

.62462 .45991 L

.62211 .46058 L

.6196 .46125 L

.61709 .46192 L

.61457 .46258 L

.61206 .46325 L

.60955 .46392 L

.60704 .46459 L

.60453 .46526 L

.60202 .46593 L

.59951 .4666 L

.597 .46727 L

.59448 .46794 L

.59197 .46861 L

.58946 .46929 L

.58695 .46996 L

.58444 .47063 L

.58193 .47131 L

.57942 .47199 L

.57691 .47266 L

.57439 .47334 L

.57188 .47402 L

.56937 .47469 L

.56686 .47537 L

.56435 .47605 L

.56184 .47673 L

.55933 .47742 L

.55682 .4781 L

.55431 .47878 L

.55179 .47946 L

.54928 .48015 L

.54677 .48083 L

.54426 .48152 L

.54175 .4822 L

Mistroke

.53924 .48289 L

.53673 .48358 L

.53422 .48426 L

.5317 .48495 L

.52919 .48564 L

.52668 .48633 L

.52417 .48702 L

.52166 .48771 L

.51915 .4884 L

.51664 .4891 L

.51413 .48979 L

.51161 .49048 L

.5091 .49117 L

.50659 .49187 L

.50408 .49256 L

.50157 .49326 L

.49906 .49395 L

.49655 .49465 L

.49404 .49534 L

.49152 .49604 L

.48901 .49673 L

.4865 .49743 L

.48399 .49813 L

.48148 .49882 L

.47897 .49952 L

.47646 .50022 L

.47395 .50092 L

.47143 .50161 L

.46892 .50231 L

.46641 .50301 L

.4639 .5037 L

.46139 .5044 L

.45888 .5051 L

.45637 .50579 L

.45386 .50649 L

.45135 .50719 L

.44883 .50788 L

.44632 .50858 L

.44381 .50927 L

.4413 .50997 L

.43879 .51066 L

.43628 .51136 L

.43377 .51205 L

.43126 .51275 L

.42874 .51344 L

.42623 .51413 L

.42372 .51482 L

.42121 .51551 L

.4187 .5162 L

.41619 .51689 L

Mistroke

.41368 .51758 L

.41117 .51826 L

.40865 .51895 L

.40614 .51963 L

.40363 .52031 L

.40112 .52099 L

.39861 .52167 L

.3961 .52235 L

.39359 .52303 L

.39108 .5237 L

.38856 .52438 L

.38605 .52505 L

.38354 .52572 L

.38103 .52639 L

.37852 .52705 L

.37601 .52772 L

.3735 .52838 L

.37099 .52904 L

.36847 .5297 L

.36596 .53035 L

.36345 .531 L

.36094 .53165 L

.35843 .5323 L

.35592 .53294 L

.35341 .53358 L

.3509 .53422 L

.34838 .53485 L

.34587 .53548 L

.34336 .53611 L

.34085 .53673 L

.33834 .53735 L

.33583 .53797 L

.33332 .53858 L

.33081 .53919 L

.3283 .53979 L

.32578 .54039 L

.32327 .54098 L

.32076 .54157 L

.31825 .54215 L

.31574 .54273 L

.31323 .54331 L

.31072 .54387 L

.30821 .54444 L

.30569 .54499 L

.30318 .54554 L

.30067 .54608 L

.29816 .54662 L

.29565 .54715 L

.29314 .54767 L

.29063 .54819 L

Mistroke

.28812 .5487 L

.2856 .5492 L

.28309 .54969 L

.28058 .55017 L

.27807 .55065 L

.27556 .55112 L

.27305 .55157 L

.27054 .55202 L

.26803 .55246 L

.26551 .55289 L

.263 .55331 L

.26049 .55372 L

.25798 .55411 L

.25547 .5545 L

.25296 .55487 L

.25045 .55524 L

.24794 .55559 L

.24542 .55592 L

.24291 .55625 L

.2404 .55656 L

.23789 .55685 L

.23538 .55713 L

.23287 .5574 L

.23036 .55765 L

.22785 .55789 L

.22534 .55811 L

.22282 .55831 L

.22031 .5585 L

.2178 .55866 L

.21529 .55881 L

.21278 .55894 L

.21027 .55905 L

.20776 .55914 L

.20525 .55921 L

.20273 .55925 L

.20022 .55928 L

.19771 .55928 L

.1952 .55926 L

.19269 .55921 L

.19018 .55914 L

.18767 .55904 L

.18516 .55891 L

.18264 .55876 L

.18013 .55857 L

.17762 .55836 L

.17511 .55811 L

.1726 .55784 L

.17009 .55753 L

.16758 .55718 L

.16507 .5568 L

Mistroke

.16255 .55639 L

.16004 .55593 L

.15753 .55544 L

.15502 .55491 L

.15251 .55433 L

.15 .55372 L

.14749 .55305 L

.14498 .55234 L

.14246 .55158 L

.13995 .55077 L

.13744 .54991 L

.13493 .549 L

.13242 .54803 L

.12991 .547 L

.1274 .54591 L

.12489 .54475 L

.12237 .54353 L

.11986 .54225 L

.11735 .54089 L

.11484 .53946 L

.11233 .53795 L

.10982 .53636 L

.10731 .53469 L

.1048 .53293 L

.10229 .53107 L

.09977 .52912 L

.09726 .52707 L

.09475 .52492 L

.09224 .52265 L

.08973 .52026 L

.08722 .51775 L

.08471 .5151 L

.0822 .51232 L

.07968 .50939 L

.07717 .50631 L

.07466 .50306 L

.07215 .49963 L

.06964 .496 L

.06713 .49218 L

.06462 .48813 L

.06211 .48384 L

.05959 .47928 L

.05708 .47444 L

.05457 .46928 L

.05206 .46377 L

.04955 .45785 L

.04704 .45149 L

.04453 .44461 L

.04202 .43711 L

.0395 .42889 L

Mistroke

.03699 .41977 L

.03448 .4095 L

.03197 .39768 L

.02946 .38355 L

.02695 .36541 L

.02632 .35976 L

.02569 .35336 L

.02507 .3458 L

.02444 .33611 L

Mfstroke

.66417 .16907 m

.66229 .16847 L

.65978 .1677 L

.65727 .16697 L

.65475 .16625 L

.65224 .16555 L

.64973 .16486 L

.64722 .16417 L

.64471 .16349 L

.6422 .16281 L

.63969 .16214 L

.63718 .16146 L

.63466 .16079 L

.63215 .16012 L

.62964 .15946 L

.62713 .15879 L

.62462 .15812 L

.62211 .15745 L

.6196 .15678 L

.61709 .15612 L

.61457 .15545 L

.61206 .15478 L

.60955 .15411 L

.60704 .15344 L

.60453 .15277 L

.60202 .1521 L

.59951 .15143 L

.597 .15076 L

.59448 .15009 L

.59197 .14942 L

.58946 .14875 L

.58695 .14807 L

.58444 .1474 L

.58193 .14672 L

.57942 .14605 L

.57691 .14537 L

.57439 .1447 L

.57188 .14402 L

.56937 .14334 L

.56686 .14266 L

.56435 .14198 L

.56184 .1413 L

.55933 .14062 L

.55682 .13994 L

.55431 .13925 L

.55179 .13857 L

.54928 .13789 L

.54677 .1372 L

.54426 .13652 L

.54175 .13583 L

Mistroke

.53924 .13514 L

.53673 .13446 L

.53422 .13377 L

.5317 .13308 L

.52919 .13239 L

.52668 .1317 L

.52417 .13101 L

.52166 .13032 L

.51915 .12963 L

.51664 .12894 L

.51413 .12825 L

.51161 .12755 L

.5091 .12686 L

.50659 .12617 L

.50408 .12547 L

.50157 .12478 L

.49906 .12408 L

.49655 .12339 L

.49404 .12269 L

.49152 .122 L

.48901 .1213 L

.4865 .1206 L

.48399 .11991 L

.48148 .11921 L

.47897 .11851 L

.47646 .11782 L

.47395 .11712 L

.47143 .11642 L

.46892 .11572 L

.46641 .11503 L

.4639 .11433 L

.46139 .11363 L

.45888 .11294 L

.45637 .11224 L

.45386 .11154 L

.45135 .11085 L

.44883 .11015 L

.44632 .10945 L

.44381 .10876 L

.4413 .10806 L

.43879 .10737 L

.43628 .10668 L

.43377 .10598 L

.43126 .10529 L

.42874 .1046 L

.42623 .1039 L

.42372 .10321 L

.42121 .10252 L

.4187 .10183 L

.41619 .10115 L

Mistroke

.41368 .10046 L

.41117 .09977 L

.40865 .09909 L

.40614 .0984 L

.40363 .09772 L

.40112 .09704 L

.39861 .09636 L

.3961 .09568 L

.39359 .095 L

.39108 .09433 L

.38856 .09366 L

.38605 .09298 L

.38354 .09231 L

.38103 .09165 L

.37852 .09098 L

.37601 .09032 L

.3735 .08965 L

.37099 .08899 L

.36847 .08834 L

.36596 .08768 L

.36345 .08703 L

.36094 .08638 L

.35843 .08573 L

.35592 .08509 L

.35341 .08445 L

.3509 .08381 L

.34838 .08318 L

.34587 .08255 L

.34336 .08192 L

.34085 .0813 L

.33834 .08068 L

.33583 .08006 L

.33332 .07945 L

.33081 .07885 L

.3283 .07824 L

.32578 .07764 L

.32327 .07705 L

.32076 .07646 L

.31825 .07588 L

.31574 .0753 L

.31323 .07473 L

.31072 .07416 L

.30821 .0736 L

.30569 .07304 L

.30318 .07249 L

.30067 .07195 L

.29816 .07141 L

.29565 .07088 L

.29314 .07036 L

.29063 .06984 L

Mistroke

.28812 .06934 L

.2856 .06884 L

.28309 .06834 L

.28058 .06786 L

.27807 .06738 L

.27556 .06692 L

.27305 .06646 L

.27054 .06601 L

.26803 .06557 L

.26551 .06514 L

.263 .06472 L

.26049 .06432 L

.25798 .06392 L

.25547 .06353 L

.25296 .06316 L

.25045 .0628 L

.24794 .06245 L

.24542 .06211 L

.24291 .06179 L

.2404 .06148 L

.23789 .06118 L

.23538 .0609 L

.23287 .06063 L

.23036 .06038 L

.22785 .06014 L

.22534 .05992 L

.22282 .05972 L

.22031 .05954 L

.2178 .05937 L

.21529 .05922 L

.21278 .05909 L

.21027 .05898 L

.20776 .05889 L

.20525 .05883 L

.20273 .05878 L

.20022 .05876 L

.19771 .05876 L

.1952 .05878 L

.19269 .05883 L

.19018 .0589 L

.18767 .059 L

.18516 .05912 L

.18264 .05928 L

.18013 .05946 L

.17762 .05968 L

.17511 .05992 L

.1726 .0602 L

.17009 .06051 L

.16758 .06085 L

.16507 .06123 L

Mistroke

.16255 .06165 L

.16004 .0621 L

.15753 .06259 L

.15502 .06313 L

.15251 .0637 L

.15 .06432 L

.14749 .06498 L

.14498 .06569 L

.14246 .06645 L

.13995 .06726 L

.13744 .06812 L

.13493 .06904 L

.13242 .07001 L

.12991 .07104 L

.1274 .07213 L

.12489 .07328 L

.12237 .0745 L

.11986 .07578 L

.11735 .07714 L

.11484 .07857 L

.11233 .08008 L

.10982 .08167 L

.10731 .08334 L

.1048 .08511 L

.10229 .08696 L

.09977 .08891 L

.09726 .09096 L

.09475 .09312 L

.09224 .09539 L

.08973 .09778 L

.08722 .10029 L

.08471 .10293 L

.0822 .10571 L

.07968 .10864 L

.07717 .11172 L

.07466 .11498 L

.07215 .11841 L

.06964 .12203 L

.06713 .12586 L

.06462 .12991 L

.06211 .1342 L

.05959 .13875 L

.05708 .14359 L

.05457 .14875 L

.05206 .15427 L

.04955 .16018 L

.04704 .16654 L

.04453 .17343 L

.04202 .18092 L

.0395 .18914 L

Mistroke

.03699 .19826 L

.03448 .20853 L

.03197 .22036 L

.02946 .23448 L

.02695 .25263 L

.02632 .25827 L

.02569 .26467 L

.02507 .27224 L

.02444 .28193 L

Mfstroke

0 1 .4 r

.67861 .4491 m

.67987 .44836 L

.68112 .4477 L

.68238 .44712 L

.68363 .44659 L

.68489 .4461 L

.68614 .44565 L

.6874 .44522 L

.68866 .44481 L

.68991 .44441 L

.69117 .44403 L

.69242 .44365 L

.69368 .44329 L

.69493 .44293 L

.69619 .44257 L

.69744 .44222 L

.6987 .44188 L

.69996 .44154 L

.70121 .4412 L

.70247 .44086 L

.70372 .44053 L

.70498 .4402 L

.70623 .43987 L

.70749 .43954 L

.70875 .43921 L

.71 .43889 L

.71126 .43856 L

.71251 .43824 L

.71377 .43792 L

.71502 .4376 L

.71628 .43728 L

.71753 .43696 L

.71879 .43664 L

.72005 .43632 L

.7213 .43601 L

.72256 .43569 L

.72381 .43538 L

.72507 .43506 L

.72632 .43475 L

.72758 .43444 L

.72884 .43413 L

.73009 .43381 L

.73135 .4335 L

.7326 .43319 L

.73386 .43288 L

.73511 .43257 L

.73637 .43226 L

.73762 .43195 L

.73888 .43164 L

.74014 .43133 L

Mistroke

.74139 .43103 L

.74265 .43072 L

.7439 .43041 L

.74516 .43011 L

.74641 .4298 L

.74767 .42949 L

.74892 .42919 L

.75018 .42888 L

.75144 .42858 L

.75269 .42827 L

.75395 .42797 L

.7552 .42767 L

.75646 .42736 L

.75771 .42706 L

.75897 .42676 L

.76023 .42645 L

.76148 .42615 L

.76274 .42585 L

.76399 .42555 L

.76525 .42525 L

.7665 .42494 L

.76776 .42464 L

.76901 .42434 L

.77027 .42404 L

.77153 .42374 L

.77278 .42344 L

.77404 .42315 L

.77529 .42285 L

.77655 .42255 L

.7778 .42225 L

.77906 .42195 L

.78032 .42165 L

.78157 .42136 L

.78283 .42106 L

.78408 .42076 L

.78534 .42046 L

.78659 .42017 L

.78785 .41987 L

.7891 .41958 L

.79036 .41928 L

.79162 .41898 L

.79287 .41869 L

.79413 .41839 L

.79538 .4181 L

.79664 .4178 L

.79789 .41751 L

.79915 .41722 L

.8004 .41692 L

.80166 .41663 L

.80292 .41634 L

Mistroke

.80417 .41604 L

.80543 .41575 L

.80668 .41546 L

.80794 .41516 L

.80919 .41487 L

.81045 .41458 L

.81171 .41429 L

.81296 .414 L

.81422 .41371 L

.81547 .41342 L

.81673 .41313 L

.81798 .41283 L

.81924 .41254 L

.82049 .41225 L

.82175 .41196 L

.82301 .41167 L

.82426 .41139 L

.82552 .4111 L

.82677 .41081 L

.82803 .41052 L

.82928 .41023 L

.83054 .40994 L

.8318 .40965 L

.83305 .40937 L

.83431 .40908 L

.83556 .40879 L

.83682 .4085 L

.83807 .40822 L

.83933 .40793 L

.84058 .40764 L

.84184 .40736 L

.8431 .40707 L

.84435 .40679 L

.84561 .4065 L

.84686 .40621 L

.84812 .40593 L

.84937 .40564 L

.85063 .40536 L

.85188 .40507 L

.85314 .40479 L

.8544 .40451 L

.85565 .40422 L

.85691 .40394 L

.85816 .40365 L

.85942 .40337 L

.86067 .40309 L

.86193 .4028 L

.86319 .40252 L

.86444 .40224 L

.8657 .40196 L

Mistroke

.86695 .40167 L

.86821 .40139 L

.86946 .40111 L

.87072 .40083 L

.87197 .40055 L

.87323 .40026 L

.87449 .39998 L

.87574 .3997 L

.877 .39942 L

.87825 .39914 L

.87951 .39886 L

.88076 .39858 L

.88202 .3983 L

.88328 .39802 L

.88453 .39774 L

.88579 .39746 L

.88704 .39718 L

.8883 .3969 L

.88955 .39662 L

.89081 .39634 L

.89206 .39607 L

.89332 .39579 L

.89458 .39551 L

.89583 .39523 L

.89709 .39495 L

.89834 .39467 L

.8996 .3944 L

.90085 .39412 L

.90211 .39384 L

.90337 .39356 L

.90462 .39329 L

.90588 .39301 L

.90713 .39273 L

.90839 .39246 L

.90964 .39218 L

.9109 .3919 L

.91215 .39163 L

.91341 .39135 L

.91467 .39108 L

.91592 .3908 L

.91718 .39052 L

.91843 .39025 L

.91969 .38997 L

.92094 .3897 L

.9222 .38942 L

.92345 .38915 L

.92471 .38887 L

.92597 .3886 L

.92722 .38832 L

.92848 .38805 L

Mistroke

.92973 .38778 L

.93099 .3875 L

.93224 .38723 L

.9335 .38695 L

.93476 .38668 L

.93601 .38641 L

.93727 .38613 L

.93852 .38586 L

.93978 .38559 L

.94103 .38531 L

.94229 .38504 L

.94354 .38477 L

.9448 .3845 L

.94606 .38422 L

.94731 .38395 L

.94857 .38368 L

.94982 .38341 L

.95108 .38314 L

.95233 .38286 L

.95359 .38259 L

.95485 .38232 L

.9561 .38205 L

.95736 .38178 L

.95861 .38151 L

.95987 .38124 L

.96112 .38096 L

.96238 .38069 L

.96363 .38042 L

.96489 .38015 L

.96615 .37988 L

.9674 .37961 L

.96866 .37934 L

.96991 .37907 L

.97117 .3788 L

.97242 .37853 L

.97368 .37826 L

.97493 .37799 L

.97619 .37772 L

Mfstroke

.67861 .16893 m

.67987 .16968 L

.68112 .17033 L

.68238 .17091 L

.68363 .17144 L

.68489 .17193 L

.68614 .17239 L

.6874 .17282 L

.68866 .17323 L

.68991 .17362 L

.69117 .17401 L

.69242 .17438 L

.69368 .17475 L

.69493 .17511 L

.69619 .17547 L

.69744 .17581 L

.6987 .17616 L

.69996 .1765 L

.70121 .17684 L

.70247 .17717 L

.70372 .17751 L

.70498 .17784 L

.70623 .17817 L

.70749 .1785 L

.70875 .17882 L

.71 .17915 L

.71126 .17947 L

.71251 .17979 L

.71377 .18012 L

.71502 .18044 L

.71628 .18076 L

.71753 .18108 L

.71879 .18139 L

.72005 .18171 L

.7213 .18203 L

.72256 .18234 L

.72381 .18266 L

.72507 .18297 L

.72632 .18328 L

.72758 .1836 L

.72884 .18391 L

.73009 .18422 L

.73135 .18453 L

.7326 .18484 L

.73386 .18515 L

.73511 .18546 L

.73637 .18577 L

.73762 .18608 L

.73888 .18639 L

.74014 .1867 L

Mistroke

.74139 .18701 L

.74265 .18731 L

.7439 .18762 L

.74516 .18793 L

.74641 .18823 L

.74767 .18854 L

.74892 .18885 L

.75018 .18915 L

.75144 .18946 L

.75269 .18976 L

.75395 .19006 L

.7552 .19037 L

.75646 .19067 L

.75771 .19097 L

.75897 .19128 L

.76023 .19158 L

.76148 .19188 L

.76274 .19219 L

.76399 .19249 L

.76525 .19279 L

.7665 .19309 L

.76776 .19339 L

.76901 .19369 L

.77027 .19399 L

.77153 .19429 L

.77278 .19459 L

.77404 .19489 L

.77529 .19519 L

.77655 .19549 L

.7778 .19578 L

.77906 .19608 L

.78032 .19638 L

.78157 .19668 L

.78283 .19698 L

.78408 .19727 L

.78534 .19757 L

.78659 .19787 L

.78785 .19816 L

.7891 .19846 L

.79036 .19875 L

.79162 .19905 L

.79287 .19934 L

.79413 .19964 L

.79538 .19994 L

.79664 .20023 L

.79789 .20052 L

.79915 .20082 L

.8004 .20111 L

.80166 .2014 L

.80292 .2017 L

Mistroke

.80417 .20199 L

.80543 .20228 L

.80668 .20258 L

.80794 .20287 L

.80919 .20316 L

.81045 .20345 L

.81171 .20374 L

.81296 .20404 L

.81422 .20433 L

.81547 .20462 L

.81673 .20491 L

.81798 .2052 L

.81924 .20549 L

.82049 .20578 L

.82175 .20607 L

.82301 .20636 L

.82426 .20665 L

.82552 .20694 L

.82677 .20723 L

.82803 .20752 L

.82928 .2078 L

.83054 .20809 L

.8318 .20838 L

.83305 .20867 L

.83431 .20895 L

.83556 .20924 L

.83682 .20953 L

.83807 .20982 L

.83933 .2101 L

.84058 .21039 L

.84184 .21068 L

.8431 .21096 L

.84435 .21125 L

.84561 .21153 L

.84686 .21182 L

.84812 .2121 L

.84937 .21239 L

.85063 .21267 L

.85188 .21296 L

.85314 .21324 L

.8544 .21353 L

.85565 .21381 L

.85691 .2141 L

.85816 .21438 L

.85942 .21466 L

.86067 .21495 L

.86193 .21523 L

.86319 .21551 L

.86444 .2158 L

.8657 .21608 L

Mistroke

.86695 .21636 L

.86821 .21664 L

.86946 .21692 L

.87072 .21721 L

.87197 .21749 L

.87323 .21777 L

.87449 .21805 L

.87574 .21833 L

.877 .21861 L

.87825 .21889 L

.87951 .21917 L

.88076 .21945 L

.88202 .21973 L

.88328 .22001 L

.88453 .22029 L

.88579 .22057 L

.88704 .22085 L

.8883 .22113 L

.88955 .22141 L

.89081 .22169 L

.89206 .22197 L

.89332 .22225 L

.89458 .22253 L

.89583 .2228 L

.89709 .22308 L

.89834 .22336 L

.8996 .22364 L

.90085 .22392 L

.90211 .22419 L

.90337 .22447 L

.90462 .22475 L

.90588 .22502 L

.90713 .2253 L

.90839 .22558 L

.90964 .22585 L

.9109 .22613 L

.91215 .22641 L

.91341 .22668 L

.91467 .22696 L

.91592 .22723 L

.91718 .22751 L

.91843 .22779 L

.91969 .22806 L

.92094 .22834 L

.9222 .22861 L

.92345 .22889 L

.92471 .22916 L

.92597 .22944 L

.92722 .22971 L

.92848 .22998 L

Mistroke

.92973 .23026 L

.93099 .23053 L

.93224 .23081 L

.9335 .23108 L

.93476 .23135 L

.93601 .23163 L

.93727 .2319 L

.93852 .23217 L

.93978 .23245 L

.94103 .23272 L

.94229 .23299 L

.94354 .23326 L

.9448 .23354 L

.94606 .23381 L

.94731 .23408 L

.94857 .23435 L

.94982 .23463 L

.95108 .2349 L

.95233 .23517 L

.95359 .23544 L

.95485 .23571 L

.9561 .23598 L

.95736 .23626 L

.95861 .23653 L

.95987 .2368 L

.96112 .23707 L

.96238 .23734 L

.96363 .23761 L

.96489 .23788 L

.96615 .23815 L

.9674 .23842 L

.96866 .23869 L

.96991 .23896 L

.97117 .23923 L

.97242 .2395 L

.97368 .23977 L

.97493 .24004 L

.97619 .24031 L

Mfstroke

.97619 .48895 m

.97493 .48913 L

.97368 .48931 L

.97242 .48949 L

.97117 .48968 L

.96991 .48986 L

.96866 .49004 L

.9674 .49022 L

.96615 .4904 L

.96489 .49058 L

.96363 .49076 L

.96238 .49094 L

.96112 .49112 L

.95987 .4913 L

.95861 .49148 L

.95736 .49166 L

.9561 .49185 L

.95485 .49203 L

.95359 .49221 L

.95233 .49239 L

.95108 .49257 L

.94982 .49275 L

.94857 .49293 L

.94731 .49311 L

.94606 .49329 L

.9448 .49347 L

.94354 .49365 L

.94229 .49383 L

.94103 .49401 L

.93978 .49419 L

.93852 .49437 L

.93727 .49455 L

.93601 .49473 L

.93476 .49491 L

.9335 .49509 L

.93224 .49527 L

.93099 .49545 L

.92973 .49563 L

.92848 .49581 L

.92722 .49599 L

.92597 .49617 L

.92471 .49635 L

.92345 .49653 L

.9222 .49671 L

.92094 .49688 L

.91969 .49706 L

.91843 .49724 L

.91718 .49742 L

.91592 .4976 L

.91467 .49777 L

Mistroke

.91341 .49795 L

.91215 .49813 L

.9109 .49831 L

.90964 .49848 L

.90839 .49866 L

.90713 .49884 L

.90588 .49901 L

.90462 .49919 L

.90337 .49936 L

.90211 .49954 L

.90085 .49971 L

.8996 .49989 L

.89834 .50006 L

.89709 .50024 L

.89583 .50041 L

.89458 .50058 L

.89332 .50076 L

.89206 .50093 L

.89081 .5011 L

.88955 .50127 L

.8883 .50145 L

.88704 .50162 L

.88579 .50179 L

.88453 .50196 L

.88328 .50213 L

.88202 .5023 L

.88076 .50247 L

.87951 .50264 L

.87825 .5028 L

.877 .50297 L

.87574 .50314 L

.87449 .50331 L

.87323 .50347 L

.87197 .50364 L

.87072 .5038 L

.86946 .50397 L

.86821 .50413 L

.86695 .5043 L

.8657 .50446 L

.86444 .50462 L

.86319 .50478 L

.86193 .50494 L

.86067 .5051 L

.85942 .50526 L

.85816 .50542 L

.85691 .50558 L

.85565 .50574 L

.8544 .50589 L

.85314 .50605 L

.85188 .50621 L

Mistroke

.85063 .50636 L

.84937 .50651 L

.84812 .50667 L

.84686 .50682 L

.84561 .50697 L

.84435 .50712 L

.8431 .50727 L

.84184 .50742 L

.84058 .50756 L

.83933 .50771 L

.83807 .50786 L

.83682 .508 L

.83556 .50814 L

.83431 .50829 L

.83305 .50843 L

.8318 .50857 L

.83054 .50871 L

.82928 .50884 L

.82803 .50898 L

.82677 .50912 L

.82552 .50925 L

.82426 .50938 L

.82301 .50951 L

.82175 .50964 L

.82049 .50977 L

.81924 .5099 L

.81798 .51003 L

.81673 .51015 L

.81547 .51027 L

.81422 .5104 L

.81296 .51052 L

.81171 .51064 L

.81045 .51075 L

.80919 .51087 L

.80794 .51098 L

.80668 .51109 L

.80543 .5112 L

.80417 .51131 L

.80292 .51142 L

.80166 .51152 L

.8004 .51163 L

.79915 .51173 L

.79789 .51183 L

.79664 .51192 L

.79538 .51202 L

.79413 .51211 L

.79287 .5122 L

.79162 .51229 L

.79036 .51238 L

.7891 .51246 L

Mistroke

.78785 .51254 L

.78659 .51262 L

.78534 .5127 L

.78408 .51278 L

.78283 .51285 L

.78157 .51292 L

.78032 .51298 L

.77906 .51305 L

.7778 .51311 L

.77655 .51317 L

.77529 .51322 L

.77404 .51328 L

.77278 .51333 L

.77153 .51337 L

.77027 .51342 L

.76901 .51346 L

.76776 .51349 L

.7665 .51353 L

.76525 .51356 L

.76399 .51358 L

.76274 .51361 L

.76148 .51363 L

.76023 .51364 L

.75897 .51366 L

.75771 .51367 L

.75646 .51367 L

.7552 .51367 L

.75395 .51367 L

.75269 .51366 L

.75144 .51365 L

.75018 .51363 L

.74892 .51361 L

.74767 .51358 L

.74641 .51355 L

.74516 .51352 L

.7439 .51348 L

.74265 .51343 L

.74139 .51338 L

.74014 .51333 L

.73888 .51326 L

.73762 .5132 L

.73637 .51313 L

.73511 .51305 L

.73386 .51296 L

.7326 .51287 L

.73135 .51278 L

.73009 .51267 L

.72884 .51256 L

.72758 .51244 L

.72632 .51232 L

Mistroke

.72507 .51219 L

.72381 .51205 L

.72256 .5119 L

.7213 .51175 L

.72005 .51159 L

.71879 .51141 L

.71753 .51124 L

.71628 .51105 L

.71502 .51085 L

.71377 .51064 L

.71251 .51043 L

.71126 .5102 L

.71 .50996 L

.70875 .50971 L

.70749 .50945 L

.70623 .50918 L

.70498 .5089 L

.70372 .5086 L

.70247 .50829 L

.70121 .50796 L

.69996 .50763 L

.6987 .50727 L

.69744 .5069 L

.69619 .50651 L

.69493 .50611 L

.69368 .50569 L

.69242 .50524 L

.69117 .50478 L

.68991 .50429 L

.68866 .50378 L

.6874 .50325 L

.68614 .50268 L

.68489 .50209 L

.68363 .50146 L

.68238 .5008 L

.68112 .5001 L

.67987 .49935 L

.67861 .49856 L

.67736 .49771 L

.6761 .49681 L

.67484 .49582 L

.67359 .49476 L

.67233 .49359 L

.67108 .49229 L

.66982 .49083 L

.66857 .48913 L

.66731 .48711 L

.66605 .48447 L

.6648 .48019 L

Mfstroke

.97619 .12908 m

.97493 .1289 L

.97368 .12872 L

.97242 .12854 L

.97117 .12836 L

.96991 .12818 L

.96866 .128 L

.9674 .12782 L

.96615 .12764 L

.96489 .12745 L

.96363 .12727 L

.96238 .12709 L

.96112 .12691 L

.95987 .12673 L

.95861 .12655 L

.95736 .12637 L

.9561 .12619 L

.95485 .12601 L

.95359 .12583 L

.95233 .12565 L

.95108 .12547 L

.94982 .12529 L

.94857 .1251 L

.94731 .12492 L

.94606 .12474 L

.9448 .12456 L

.94354 .12438 L

.94229 .1242 L

.94103 .12402 L

.93978 .12384 L

.93852 .12366 L

.93727 .12348 L

.93601 .1233 L

.93476 .12312 L

.9335 .12294 L

.93224 .12276 L

.93099 .12258 L

.92973 .1224 L

.92848 .12222 L

.92722 .12204 L

.92597 .12186 L

.92471 .12169 L

.92345 .12151 L

.9222 .12133 L

.92094 .12115 L

.91969 .12097 L

.91843 .12079 L

.91718 .12061 L

.91592 .12044 L

.91467 .12026 L

Mistroke

.91341 .12008 L

.91215 .1199 L

.9109 .11973 L

.90964 .11955 L

.90839 .11937 L

.90713 .1192 L

.90588 .11902 L

.90462 .11885 L

.90337 .11867 L

.90211 .1185 L

.90085 .11832 L

.8996 .11815 L

.89834 .11797 L

.89709 .1178 L

.89583 .11762 L

.89458 .11745 L

.89332 .11728 L

.89206 .1171 L

.89081 .11693 L

.88955 .11676 L

.8883 .11659 L

.88704 .11642 L

.88579 .11625 L

.88453 .11608 L

.88328 .11591 L

.88202 .11574 L

.88076 .11557 L

.87951 .1154 L

.87825 .11523 L

.877 .11506 L

.87574 .11489 L

.87449 .11473 L

.87323 .11456 L

.87197 .1144 L

.87072 .11423 L

.86946 .11407 L

.86821 .1139 L

.86695 .11374 L

.8657 .11358 L

.86444 .11341 L

.86319 .11325 L

.86193 .11309 L

.86067 .11293 L

.85942 .11277 L

.85816 .11261 L

.85691 .11245 L

.85565 .1123 L

.8544 .11214 L

.85314 .11198 L

.85188 .11183 L

Mistroke

.85063 .11167 L

.84937 .11152 L

.84812 .11137 L

.84686 .11122 L

.84561 .11107 L

.84435 .11092 L

.8431 .11077 L

.84184 .11062 L

.84058 .11047 L

.83933 .11032 L

.83807 .11018 L

.83682 .11003 L

.83556 .10989 L

.83431 .10975 L

.83305 .10961 L

.8318 .10947 L

.83054 .10933 L

.82928 .10919 L

.82803 .10905 L

.82677 .10892 L

.82552 .10878 L

.82426 .10865 L

.82301 .10852 L

.82175 .10839 L

.82049 .10826 L

.81924 .10813 L

.81798 .10801 L

.81673 .10788 L

.81547 .10776 L

.81422 .10764 L

.81296 .10752 L

.81171 .1074 L

.81045 .10728 L

.80919 .10717 L

.80794 .10705 L

.80668 .10694 L

.80543 .10683 L

.80417 .10672 L

.80292 .10662 L

.80166 .10651 L

.8004 .10641 L

.79915 .10631 L

.79789 .10621 L

.79664 .10611 L

.79538 .10601 L

.79413 .10592 L

.79287 .10583 L

.79162 .10574 L

.79036 .10566 L

.7891 .10557 L

Mistroke

.78785 .10549 L

.78659 .10541 L

.78534 .10533 L

.78408 .10526 L

.78283 .10519 L

.78157 .10512 L

.78032 .10505 L

.77906 .10499 L

.7778 .10492 L

.77655 .10487 L

.77529 .10481 L

.77404 .10476 L

.77278 .10471 L

.77153 .10466 L

.77027 .10462 L

.76901 .10458 L

.76776 .10454 L

.7665 .10451 L

.76525 .10448 L

.76399 .10445 L

.76274 .10443 L

.76148 .10441 L

.76023 .10439 L

.75897 .10438 L

.75771 .10437 L

.75646 .10436 L

.7552 .10436 L

.75395 .10437 L

.75269 .10437 L

.75144 .10439 L

.75018 .1044 L

.74892 .10442 L

.74767 .10445 L

.74641 .10448 L

.74516 .10452 L

.7439 .10456 L

.74265 .1046 L

.74139 .10465 L

.74014 .10471 L

.73888 .10477 L

.73762 .10484 L

.73637 .10491 L

.73511 .10499 L

.73386 .10507 L

.7326 .10516 L

.73135 .10526 L

.73009 .10536 L

.72884 .10547 L

.72758 .10559 L

.72632 .10571 L

Mistroke

.72507 .10585 L

.72381 .10598 L

.72256 .10613 L

.7213 .10629 L

.72005 .10645 L

.71879 .10662 L

.71753 .1068 L

.71628 .10699 L

.71502 .10718 L

.71377 .10739 L

.71251 .10761 L

.71126 .10784 L

.71 .10807 L

.70875 .10832 L

.70749 .10858 L

.70623 .10885 L

.70498 .10914 L

.70372 .10944 L

.70247 .10975 L

.70121 .11007 L

.69996 .11041 L

.6987 .11076 L

.69744 .11113 L

.69619 .11152 L

.69493 .11192 L

.69368 .11235 L

.69242 .11279 L

.69117 .11326 L

.68991 .11374 L

.68866 .11425 L

.6874 .11479 L

.68614 .11535 L

.68489 .11595 L

.68363 .11657 L

.68238 .11723 L

.68112 .11794 L

.67987 .11868 L

.67861 .11947 L

.67736 .12032 L

.6761 .12123 L

.67484 .12221 L

.67359 .12328 L

.67233 .12445 L

.67108 .12574 L

.66982 .12721 L

.66857 .1289 L

.66731 .13093 L

.66605 .13356 L

.6648 .13785 L

Mfstroke

.6648 .48019 m

.66442 .47503 L

.66455 .47321 L

.66467 .47222 L

.6648 .47142 L

.66505 .47014 L

.66568 .46774 L

.66631 .46585 L

.66693 .46425 L

.66756 .46283 L

.66819 .46155 L

.66944 .45926 L

.67032 .45783 L

.67083 .45706 L

.67183 .45565 L

.67233 .45498 L

.67359 .45347 L

.67484 .45214 L

.67579 .45125 L

.67612 .45095 L

.67736 .44997 L

.67836 .44926 L

.67861 .4491 L

s

.6648 .13785 m

.66442 .143 L

.66455 .14482 L

.66467 .14582 L

.6648 .14661 L

.66505 .14789 L

.66568 .1503 L

.66631 .15218 L

.66693 .15379 L

.66756 .1552 L

.66819 .15649 L

.66944 .15877 L

.67032 .1602 L

.67083 .16097 L

.67183 .16238 L

.67233 .16305 L

.67359 .16457 L

.67484 .16589 L

.67579 .16678 L

.67612 .16709 L

.67736 .16807 L

.67836 .16877 L

.67861 .16893 L

s

1 0 0 r

.67798 .44196 m

.67736 .44247 L

.6761 .44342 L

.67484 .44427 L

.67359 .44504 L

.67233 .44572 L

.67108 .44634 L

.66982 .4469 L

.66857 .44741 L

.66731 .44789 L

.66605 .44833 L

.6648 .44876 L

.66417 .44897 L

.66229 .44956 L

.65978 .45033 L

.65727 .45107 L

.65475 .45178 L

.65224 .45248 L

.64973 .45318 L

.64722 .45386 L

.64471 .45455 L

.6422 .45522 L

.63969 .4559 L

.63718 .45657 L

.63466 .45724 L

.63215 .45791 L

.62964 .45858 L

.62713 .45925 L

.62462 .45991 L

.62211 .46058 L

.6196 .46125 L

.61709 .46192 L

.61457 .46258 L

.61206 .46325 L

.60955 .46392 L

.60704 .46459 L

.60453 .46526 L

.60202 .46593 L

.59951 .4666 L

.597 .46727 L

.59448 .46794 L

.59197 .46861 L

.58946 .46929 L

.58695 .46996 L

.58444 .47063 L

.58193 .47131 L

.57942 .47199 L

.57691 .47266 L

.57439 .47334 L

.57188 .47402 L

Mistroke

.56937 .47469 L

.56686 .47537 L

.56435 .47605 L

.56184 .47673 L

.55933 .47742 L

.55682 .4781 L

.55431 .47878 L

.55179 .47946 L

.54928 .48015 L

.54677 .48083 L

.54426 .48152 L

.54175 .4822 L

.53924 .48289 L

.53673 .48358 L

.53422 .48426 L

.5317 .48495 L

.52919 .48564 L

.52668 .48633 L

.52417 .48702 L

.52166 .48771 L

.51915 .4884 L

.51664 .4891 L

.51413 .48979 L

.51161 .49048 L

.5091 .49117 L

.50659 .49187 L

.50408 .49256 L

.50157 .49326 L

.49906 .49395 L

.49655 .49465 L

.49404 .49534 L

.49152 .49604 L

.48901 .49673 L

.4865 .49743 L

.48399 .49813 L

.48148 .49882 L

.47897 .49952 L

.47646 .50022 L

.47395 .50092 L

.47143 .50161 L

.46892 .50231 L

.46641 .50301 L

.4639 .5037 L

.46139 .5044 L

.45888 .5051 L

.45637 .50579 L

.45386 .50649 L

.45135 .50719 L

.44883 .50788 L

.44632 .50858 L

Mistroke

.44381 .50927 L

.4413 .50997 L

.43879 .51066 L

.43628 .51136 L

.43377 .51205 L

.43126 .51275 L

.42874 .51344 L

.42623 .51413 L

.42372 .51482 L

.42121 .51551 L

.4187 .5162 L

.41619 .51689 L

.41368 .51758 L

.41117 .51826 L

.40865 .51895 L

.40614 .51963 L

.40363 .52031 L

.40112 .52099 L

.39861 .52167 L

.3961 .52235 L

.39359 .52303 L

.39108 .5237 L

.38856 .52438 L

.38605 .52505 L

.38354 .52572 L

.38103 .52639 L

.37852 .52705 L

.37601 .52772 L

.3735 .52838 L

.37099 .52904 L

.36847 .5297 L

.36596 .53035 L

.36345 .531 L

.36094 .53165 L

.35843 .5323 L

.35592 .53294 L

.35341 .53358 L

.3509 .53422 L

.34838 .53485 L

.34587 .53548 L

.34336 .53611 L

.34085 .53673 L

.33834 .53735 L

.33583 .53797 L

.33332 .53858 L

.33081 .53919 L

.3283 .53979 L

.32578 .54039 L

.32327 .54098 L

.32076 .54157 L

Mistroke

.31825 .54215 L

.31574 .54273 L

.31323 .54331 L

.31072 .54387 L

.30821 .54444 L

.30569 .54499 L

.30318 .54554 L

.30067 .54608 L

.29816 .54662 L

.29565 .54715 L

.29314 .54767 L

.29063 .54819 L

.28812 .5487 L

.2856 .5492 L

.28309 .54969 L

.28058 .55017 L

.27807 .55065 L

.27556 .55112 L

.27305 .55157 L

.27054 .55202 L

.26803 .55246 L

.26551 .55289 L

.263 .55331 L

.26049 .55372 L

.25798 .55411 L

.25547 .5545 L

.25296 .55487 L

.25045 .55524 L

.24794 .55559 L

.24542 .55592 L

.24291 .55625 L

.2404 .55656 L

.23789 .55685 L

.23538 .55713 L

.23287 .5574 L

.23036 .55765 L

.22785 .55789 L

.22534 .55811 L

.22282 .55831 L

.22031 .5585 L

.2178 .55866 L

.21529 .55881 L

.21278 .55894 L

.21027 .55905 L

.20776 .55914 L

.20525 .55921 L

.20273 .55925 L

.20022 .55928 L

.19771 .55928 L

.1952 .55926 L

Mistroke

.19269 .55921 L

.19018 .55914 L

.18767 .55904 L

.18516 .55891 L

.18264 .55876 L

.18013 .55857 L

.17762 .55836 L

.17511 .55811 L

.1726 .55784 L

.17009 .55753 L

.16758 .55718 L

.16507 .5568 L

.16255 .55639 L

.16004 .55593 L

.15753 .55544 L

.15502 .55491 L

.15251 .55433 L

.15 .55372 L

.14749 .55305 L

.14498 .55234 L

.14246 .55158 L

.13995 .55077 L

.13744 .54991 L

.13493 .549 L

.13242 .54803 L

.12991 .547 L

.1274 .54591 L

.12489 .54475 L

.12237 .54353 L

.11986 .54225 L

.11735 .54089 L

.11484 .53946 L

.11233 .53795 L

.10982 .53636 L

.10731 .53469 L

.1048 .53293 L

.10229 .53107 L

.09977 .52912 L

.09726 .52707 L

.09475 .52492 L

.09224 .52265 L

.08973 .52026 L

.08722 .51775 L

.08471 .5151 L

.0822 .51232 L

.07968 .50939 L

.07717 .50631 L

.07466 .50306 L

.07215 .49963 L

.06964 .496 L

Mistroke

.06713 .49218 L

.06462 .48813 L

.06211 .48384 L

.05959 .47928 L

.05708 .47444 L

.05457 .46928 L

.05206 .46377 L

.04955 .45785 L

.04704 .45149 L

.04453 .44461 L

.04202 .43711 L

.0395 .42889 L

.03699 .41977 L

.03448 .4095 L

.03197 .39768 L

.02946 .38355 L

.02695 .36541 L

.02632 .35976 L

.02569 .35336 L

.02507 .3458 L

.02444 .33611 L

.02381 .30902 L

Mfstroke

.67798 .17608 m

.67736 .17556 L

.6761 .17461 L

.67484 .17376 L

.67359 .17299 L

.67233 .17231 L

.67108 .17169 L

.66982 .17114 L

.66857 .17063 L

.66731 .17015 L

.66605 .1697 L

.6648 .16927 L

.66417 .16907 L

.66229 .16847 L

.65978 .1677 L

.65727 .16697 L

.65475 .16625 L

.65224 .16555 L

.64973 .16486 L

.64722 .16417 L

.64471 .16349 L

.6422 .16281 L

.63969 .16214 L

.63718 .16146 L

.63466 .16079 L

.63215 .16012 L

.62964 .15946 L

.62713 .15879 L

.62462 .15812 L

.62211 .15745 L

.6196 .15678 L

.61709 .15612 L

.61457 .15545 L

.61206 .15478 L

.60955 .15411 L

.60704 .15344 L

.60453 .15277 L

.60202 .1521 L

.59951 .15143 L

.597 .15076 L

.59448 .15009 L

.59197 .14942 L

.58946 .14875 L

.58695 .14807 L

.58444 .1474 L

.58193 .14672 L

.57942 .14605 L

.57691 .14537 L

.57439 .1447 L

.57188 .14402 L

Mistroke

.56937 .14334 L

.56686 .14266 L

.56435 .14198 L

.56184 .1413 L

.55933 .14062 L

.55682 .13994 L

.55431 .13925 L

.55179 .13857 L

.54928 .13789 L

.54677 .1372 L

.54426 .13652 L

.54175 .13583 L

.53924 .13514 L

.53673 .13446 L

.53422 .13377 L

.5317 .13308 L

.52919 .13239 L

.52668 .1317 L

.52417 .13101 L

.52166 .13032 L

.51915 .12963 L

.51664 .12894 L

.51413 .12825 L

.51161 .12755 L

.5091 .12686 L

.50659 .12617 L

.50408 .12547 L

.50157 .12478 L

.49906 .12408 L

.49655 .12339 L

.49404 .12269 L

.49152 .122 L

.48901 .1213 L

.4865 .1206 L

.48399 .11991 L

.48148 .11921 L

.47897 .11851 L

.47646 .11782 L

.47395 .11712 L

.47143 .11642 L

.46892 .11572 L

.46641 .11503 L

.4639 .11433 L

.46139 .11363 L

.45888 .11294 L

.45637 .11224 L

.45386 .11154 L

.45135 .11085 L

.44883 .11015 L

.44632 .10945 L

Mistroke

.44381 .10876 L

.4413 .10806 L

.43879 .10737 L

.43628 .10668 L

.43377 .10598 L

.43126 .10529 L

.42874 .1046 L

.42623 .1039 L

.42372 .10321 L

.42121 .10252 L

.4187 .10183 L

.41619 .10115 L

.41368 .10046 L

.41117 .09977 L

.40865 .09909 L

.40614 .0984 L

.40363 .09772 L

.40112 .09704 L

.39861 .09636 L

.3961 .09568 L

.39359 .095 L

.39108 .09433 L

.38856 .09366 L

.38605 .09298 L

.38354 .09231 L

.38103 .09165 L

.37852 .09098 L

.37601 .09032 L

.3735 .08965 L

.37099 .08899 L

.36847 .08834 L

.36596 .08768 L

.36345 .08703 L

.36094 .08638 L

.35843 .08573 L

.35592 .08509 L

.35341 .08445 L

.3509 .08381 L

.34838 .08318 L

.34587 .08255 L

.34336 .08192 L

.34085 .0813 L

.33834 .08068 L

.33583 .08006 L

.33332 .07945 L

.33081 .07885 L

.3283 .07824 L

.32578 .07764 L

.32327 .07705 L

.32076 .07646 L

Mistroke

.31825 .07588 L

.31574 .0753 L

.31323 .07473 L

.31072 .07416 L

.30821 .0736 L

.30569 .07304 L

.30318 .07249 L

.30067 .07195 L

.29816 .07141 L

.29565 .07088 L

.29314 .07036 L

.29063 .06984 L

.28812 .06934 L

.2856 .06884 L

.28309 .06834 L

.28058 .06786 L

.27807 .06738 L

.27556 .06692 L

.27305 .06646 L

.27054 .06601 L

.26803 .06557 L

.26551 .06514 L

.263 .06472 L

.26049 .06432 L

.25798 .06392 L

.25547 .06353 L

.25296 .06316 L

.25045 .0628 L

.24794 .06245 L

.24542 .06211 L

.24291 .06179 L

.2404 .06148 L

.23789 .06118 L

.23538 .0609 L

.23287 .06063 L

.23036 .06038 L

.22785 .06014 L

.22534 .05992 L

.22282 .05972 L

.22031 .05954 L

.2178 .05937 L

.21529 .05922 L

.21278 .05909 L

.21027 .05898 L

.20776 .05889 L

.20525 .05883 L

.20273 .05878 L

.20022 .05876 L

.19771 .05876 L

.1952 .05878 L

Mistroke

.19269 .05883 L

.19018 .0589 L

.18767 .059 L

.18516 .05912 L

.18264 .05928 L

.18013 .05946 L

.17762 .05968 L

.17511 .05992 L

.1726 .0602 L

.17009 .06051 L

.16758 .06085 L

.16507 .06123 L

.16255 .06165 L

.16004 .0621 L

.15753 .06259 L

.15502 .06313 L

.15251 .0637 L

.15 .06432 L

.14749 .06498 L

.14498 .06569 L

.14246 .06645 L

.13995 .06726 L

.13744 .06812 L

.13493 .06904 L

.13242 .07001 L

.12991 .07104 L

.1274 .07213 L

.12489 .07328 L

.12237 .0745 L

.11986 .07578 L

.11735 .07714 L

.11484 .07857 L

.11233 .08008 L

.10982 .08167 L

.10731 .08334 L

.1048 .08511 L

.10229 .08696 L

.09977 .08891 L

.09726 .09096 L

.09475 .09312 L

.09224 .09539 L

.08973 .09778 L

.08722 .10029 L

.08471 .10293 L

.0822 .10571 L

.07968 .10864 L

.07717 .11172 L

.07466 .11498 L

.07215 .11841 L

.06964 .12203 L

Mistroke

.06713 .12586 L

.06462 .12991 L

.06211 .1342 L

.05959 .13875 L

.05708 .14359 L

.05457 .14875 L

.05206 .15427 L

.04955 .16018 L

.04704 .16654 L

.04453 .17343 L

.04202 .18092 L

.0395 .18914 L

.03699 .19826 L

.03448 .20853 L

.03197 .22036 L

.02946 .23448 L

.02695 .25263 L

.02632 .25827 L

.02569 .26467 L

.02507 .27224 L

.02444 .28193 L

.02381 .30902 L

Mfstroke

.67736 .44247 m

.67798 .44196 L

.67861 .44143 L

.67924 .44088 L

.67987 .44032 L

.68049 .43975 L

.68112 .43917 L

.68175 .43857 L

.68238 .43798 L

.68301 .43737 L

.68363 .43675 L

.68426 .43615 L

.68489 .43554 L

.68552 .43491 L

.68614 .4343 L

.68677 .43368 L

.6874 .43306 L

.68803 .43244 L

.68866 .43183 L

.68928 .43121 L

.68991 .4306 L

.69054 .42999 L

.69117 .42938 L

.69179 .42876 L

.69242 .42815 L

.69305 .42755 L

.69368 .42694 L

.69431 .42634 L

.69493 .42573 L

.69556 .42513 L

.69619 .42453 L

.69682 .42393 L

.69744 .42334 L

.69807 .42274 L

.6987 .42214 L

.69933 .42155 L

.69996 .42096 L

.70058 .42036 L

.70121 .41977 L

.70184 .41918 L

.70247 .4186 L

.7031 .418 L

.70372 .41742 L

.70435 .41683 L

.70498 .41625 L

.70561 .41566 L

.70623 .41507 L

.70686 .41449 L

.70749 .41391 L

.70812 .41332 L

Mistroke

.70875 .41274 L

.70937 .41216 L

.71 .41157 L

.71063 .41099 L

.71126 .41041 L

.71188 .40982 L

.71251 .40924 L

.71314 .40866 L

.71377 .40808 L

.7144 .40749 L

.71502 .40691 L

.71565 .40633 L

.71628 .40574 L

.71691 .40516 L

.71753 .40457 L

.71816 .40399 L

.71879 .4034 L

.71942 .40282 L

.72005 .40223 L

.72067 .40164 L

.7213 .40105 L

.72193 .40046 L

.72256 .39987 L

.72318 .39928 L

.72381 .39869 L

.72444 .39809 L

.72507 .3975 L

.7257 .3969 L

.72632 .3963 L

.72695 .3957 L

.72758 .3951 L

.72821 .3945 L

.72884 .3939 L

.72946 .39329 L

.73009 .39269 L

.73072 .39208 L

.73135 .39147 L

.73197 .39085 L

.7326 .39024 L

.73323 .38963 L

.73386 .38901 L

.73449 .38839 L

.73511 .38776 L

.73574 .38714 L

.73637 .38651 L

.737 .38588 L

.73762 .38525 L

.73825 .38461 L

.73888 .38398 L

.73951 .38334 L

Mistroke

.74014 .38269 L

.74076 .38205 L

.74139 .3814 L

.74202 .38075 L

.74265 .38009 L

.74327 .37943 L

.7439 .37877 L

.74453 .3781 L

.74516 .37743 L

.74579 .37676 L

.74641 .37608 L

.74704 .3754 L

.74767 .37472 L

.7483 .37403 L

.74892 .37333 L

.74955 .37264 L

.75018 .37193 L

.75081 .37123 L

.75144 .37051 L

.75206 .3698 L

.75269 .36908 L

.75332 .36835 L

.75395 .36761 L

.75458 .36688 L

.7552 .36613 L

.75583 .36538 L

.75646 .36462 L

.75709 .36386 L

.75771 .36309 L

.75834 .36231 L

.75897 .36153 L

.7596 .36074 L

.76023 .35994 L

.76085 .35913 L

.76148 .35832 L

.76211 .3575 L

.76274 .35667 L

.76336 .35583 L

.76399 .35498 L

.76462 .35412 L

.76525 .35325 L

.76588 .35238 L

.7665 .35149 L

.76713 .35059 L

.76776 .34968 L

.76839 .34875 L

.76901 .34782 L

.76964 .34687 L

.77027 .34591 L

.7709 .34493 L

Mistroke

.77153 .34394 L

.77215 .34294 L

.77278 .34191 L

.77341 .34087 L

.77404 .33982 L

.77466 .33874 L

.77529 .33765 L

.77592 .33654 L

.77655 .3354 L

.77718 .33424 L

.7778 .33305 L

.77843 .33185 L

.77906 .33061 L

.77969 .32935 L

.78032 .32805 L

.78094 .32672 L

.78157 .32536 L

.7822 .32396 L

.78283 .32251 L

.78345 .32102 L

.78408 .31949 L

.78471 .3179 L

.78534 .31625 L

.78597 .31454 L

.78659 .31275 L

.78722 .31088 L

.78785 .30892 L

.78848 .30686 L

.7891 .30467 L

.78973 .30234 L

.79036 .29984 L

.79099 .29712 L

.79162 .29412 L

.79224 .29077 L

.79287 .28687 L

.7935 .28211 L

.79413 .27548 L

.79475 .26276 L

.79413 .25003 L

Mfstroke

.67736 .17556 m

.67798 .17608 L

.67861 .17661 L

.67924 .17716 L

.67987 .17771 L

.68049 .17828 L

.68112 .17886 L

.68175 .17946 L

.68238 .18006 L

.68301 .18066 L

.68363 .18128 L

.68426 .18189 L

.68489 .1825 L

.68552 .18312 L

.68614 .18374 L

.68677 .18436 L

.6874 .18497 L

.68803 .18559 L

.68866 .18621 L

.68928 .18682 L

.68991 .18743 L

.69054 .18804 L

.69117 .18866 L

.69179 .18927 L

.69242 .18988 L

.69305 .19049 L

.69368 .19109 L

.69431 .1917 L

.69493 .1923 L

.69556 .1929 L

.69619 .1935 L

.69682 .1941 L

.69744 .1947 L

.69807 .19529 L

.6987 .19589 L

.69933 .19648 L

.69996 .19708 L

.70058 .19767 L

.70121 .19826 L

.70184 .19885 L

.70247 .19944 L

.7031 .20003 L

.70372 .20062 L

.70435 .2012 L

.70498 .20179 L

.70561 .20237 L

.70623 .20296 L

.70686 .20354 L

.70749 .20413 L

.70812 .20471 L

Mistroke

.70875 .2053 L

.70937 .20588 L

.71 .20646 L

.71063 .20704 L

.71126 .20763 L

.71188 .20821 L

.71251 .20879 L

.71314 .20938 L

.71377 .20996 L

.7144 .21054 L

.71502 .21112 L

.71565 .21171 L

.71628 .21229 L

.71691 .21288 L

.71753 .21346 L

.71816 .21405 L

.71879 .21463 L

.71942 .21522 L

.72005 .21581 L

.72067 .21639 L

.7213 .21698 L

.72193 .21757 L

.72256 .21816 L

.72318 .21876 L

.72381 .21935 L

.72444 .21994 L

.72507 .22054 L

.7257 .22114 L

.72632 .22173 L

.72695 .22233 L

.72758 .22293 L

.72821 .22353 L

.72884 .22414 L

.72946 .22474 L

.73009 .22535 L

.73072 .22596 L

.73135 .22657 L

.73197 .22718 L

.7326 .22779 L

.73323 .22841 L

.73386 .22903 L

.73449 .22965 L

.73511 .23027 L

.73574 .2309 L

.73637 .23152 L

.737 .23215 L

.73762 .23279 L

.73825 .23342 L

.73888 .23406 L

.73951 .2347 L

Mistroke

.74014 .23534 L

.74076 .23599 L

.74139 .23664 L

.74202 .23729 L

.74265 .23795 L

.74327 .2386 L

.7439 .23927 L

.74453 .23993 L

.74516 .2406 L

.74579 .24127 L

.74641 .24195 L

.74704 .24263 L

.74767 .24332 L

.7483 .24401 L

.74892 .2447 L

.74955 .2454 L

.75018 .2461 L

.75081 .24681 L

.75144 .24752 L

.75206 .24824 L

.75269 .24896 L

.75332 .24969 L

.75395 .25042 L

.75458 .25116 L

.7552 .2519 L

.75583 .25265 L

.75646 .25341 L

.75709 .25417 L

.75771 .25494 L

.75834 .25572 L

.75897 .2565 L

.7596 .25729 L

.76023 .25809 L

.76085 .2589 L

.76148 .25971 L

.76211 .26054 L

.76274 .26137 L

.76336 .2622 L

.76399 .26305 L

.76462 .26391 L

.76525 .26478 L

.76588 .26566 L

.7665 .26655 L

.76713 .26745 L

.76776 .26836 L

.76839 .26928 L

.76901 .27022 L

.76964 .27116 L

.77027 .27213 L

.7709 .2731 L

Mistroke

.77153 .27409 L

.77215 .2751 L

.77278 .27612 L

.77341 .27716 L

.77404 .27821 L

.77466 .27929 L

.77529 .28039 L

.77592 .2815 L

.77655 .28264 L

.77718 .28379 L

.7778 .28498 L

.77843 .28619 L

.77906 .28742 L

.77969 .28869 L

.78032 .28998 L

.78094 .29131 L

.78157 .29267 L

.7822 .29408 L

.78283 .29552 L

.78345 .29701 L

.78408 .29855 L

.78471 .30014 L

.78534 .30179 L

.78597 .3035 L

.78659 .30528 L

.78722 .30715 L

.78785 .30911 L

.78848 .31118 L

.7891 .31336 L

.78973 .31569 L

.79036 .31819 L

.79099 .32092 L

.79162 .32391 L

.79224 .32726 L

.79287 .33116 L

.7935 .33593 L

.79413 .34255 L

.79475 .35528 L

.79413 .368 L

Mfstroke

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{567, 350.313},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.776525,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008g0001GPP10`40000100000800002008200000

P800P020P<30`<3L`:K:l00003<006H009T00<`00?l0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV

09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<003o03?o06Ko09Wo0<co

0?oo0000<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I

<c>I<fJI<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0

IYT0I/`0I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bI

I_nIIP3<IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0c

VC<cVFHcVITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<

VIW<VLc<VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`c

c?lcc01Vc3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03o

c3?oc6Koc9Woc<coc?ooc000oc<0ofH0oiT0ol`0ool0o`0coc<cofHcoiTcol`coolco`1Voc=VofIV

oiUVolaVoomVo`2Ioc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<o`3ooc?oofKooiWoolco

ooooo`0000410@820P<30`@410D51@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C

4a@D5?okl:2PY820P?l0003o0?oo0000ool0o`3oooooocoQ00<0hN40on7fh@00?n400`3Qh@3ohOKQ

000oh@030>7Q0?oQm^4003oQ00<0hN40on7fh@00?n400`3Qh@3ohOKQ000oh@030>7Q0?oQm^4003oQ

00<0hN40on7fh@00?n400`3Qh@3ohOKQ000oh@<0_^4J3ooQ7^4003oQ00<0hN40^>463a[Q20oohAKQ

000oh@030>7Q0;CQ10lXh@H?on4@h@00?n400`3Qh@2ah@<?<^473ooQ2N4003oQ00<0hN40[^433ccQ

10ooh@GQ000oh@030>7Q0:cQ0Pm3h@D?on4003oQ00<0hN40ZN433d[Q10okh@00?n400`3Qh@2Xh@03

3n7Q04oQ10ogh@00?n400`3Qh@2Uh@<?E^433oCQ000oh@030>7Q0:CQ00<?hN40F^443o3Q000oh@03

0>7Q0:?Q00<?hN40Gn443ncQ000oh@<0XN423fKQ0`oYh@00?n400`3Qh@2Oh@8?Jn443nGQ000oh@03

0>7Q09kQ0Pm`h@8?hn4003oQ00<0hN40WN423g?Q0`oPh@00?n400`3Qh@2Lh@033n7Q07KQ0`oMh@00

?n400`3Qh@2Jh@8?O>423m_Q000oh@030>7Q09[Q00<?hN40ON433mSQ000oh@030>7Q09SQ0Pn3h@8?

e^4003oQ00<0hN40V>400`oQh@24h@<?dn4003oQ00<0hN40U^423h[Q0`o@h@00?n400`3Qh@2Fh@03

3n7Q08cQ00<?hN40cN4003oQ00<0hN40UN400`oQh@2>h@<?c>4003oQ0`0ThAl?DN400`oQh@2Bh@03

3n7Q0<WQ000oh@030>7Q01gQ1`lOh@P?B>423iGQ00<?hN40b>4003oQ00<0hN406N443bkQ1Pm1h@03

3n7Q09KQ0`o7h@00?n400`3Qh@0Fh@<?>>473c[Q00<?hN40VN400`oQh@34h@00?n400`3Qh@0Bh@@?

@^453cCQ00<?hN40Vn400`oQh@33h@00?n400`3Qh@0?h@<?Bn453boQ00<?hN40W>433l;Q000oh@03

0>7Q00kQ00<?hN40DN453bWQ00<?hN40X>400`oQh@2oh@00?n400`3Qh@0;h@<?FN443bCQ00<?hN40

X^423koQ000oh@030>7Q00SQ0`mPh@@?8>400`oQh@2Th@033n7Q0;cQ000oh@030>7Q00OQ00<?hN40

IN453a[Q00<?hN40Y^400`oQh@2kh@00;n4500;Q00<0hN401^400`3Qh@06h@033n7Q06_Q10lEh@03

3n7Q0:SQ00<?hN40^^40037Q00L0hN7Q0>4000OQ00<0hN401N400`oQh@1`h@@?4N400`oQh@2Yh@8?

^^4002_Q0`03h@070>7Qh@3Q0007h@D00`mgh@@?3>400`oQh@2/h@033n7Q0;OQ000ah@070>7Qh@3Q

0007h@050>7Qh@l0O^443`OQ00<?hN40[^400`oQh@2fh@00<N401`3QhN40h@001n40103Q3`n3h@@?

0n400`oQh@2_h@8?]^40033Q0P04h@030>7Q00KQ00<03n40R>443k;Q00<?hN40]>4003oQ00<?hN40

R^400`oQ3`033joQ00<?hN40/n4003gQ0Pl00`3Qh@29h@033n7Q00CQ0`n]h@033n7Q0;;Q000lh@04

3n7Q08_Q00<?hN401n443j[Q0Pnbh@00?>4010oQh@2:h@033n7Q00cQ10nXh@033n7Q0:oQ000kh@05

3n7Qh@00RN400`oQh@0Ah@<?YN400`oQh@2_h@00>^400`oQh@02h@030>7Q08OQ00<?hN405>443j;Q

00<?hN40[^4003WQ00<?hN400n400`3Qh@27h@033n7Q01SQ10nOh@033n7Q0:gQ000hh@033n7Q00CQ

00<0hN40Q^400`oQh@0Mh@@?W>400`oQh@0D:9SQ000gh@033n7Q00GQ0`26h@033n7Q027Q0`nBh@/X

4^4@:8WQ000fh@033n7Q00KQ00<0hN40QN400`oQh@0Uh@<?RN46:0WQ00<?hN408>4;:7oQ000eh@03

3n7Q00OQ00<0hN40QN400`oQh@0Xh@@?PN44:0oQ00<?hN40:n49:7KQ000dh@033n7Q00SQ00<0hN40

QN400`oQh@0/h@@?N^44:1?Q00<?hN40<n49:6gQ000ch@033n7Q00WQ00<0hN40Q>400`oQh@0ah@@?

Ln43:1SQ0Plkh@PXI^4003?Q00<?hN402N400`3Qh@24h@033n7Q03GQ0Pm_h@<X6n400`oQh@11h@LX

Gn4003;Q00<?hN402^400`3Qh@23h@033n7Q03SQ10mYh@<X7^400`oQh@17h@PXEn4003;Q00<?hN40

2^400`3Qh@23h@033n7Q03cQ10mTh@8X8>400`oQh@1>h@PXD>40033Q0Pl=h@030>7Q08?Q00<?hN40

@>443eoQ00<XhN408N400`oQh@1Dh@PXBN4002oQ00<?hN403N400`3Qh@22h@033n7Q04GQ0`mKh@03

:>7Q02?Q00<?hN40Fn47:4;Q000_h@033n7Q00gQ00<0hN40P^400`oQh@18h@@?EN42:2OQ00<?hN40

HN47:3_Q000_h@033n7Q00gQ0`22h@033n7Q04cQ10mAh@03:>7Q02KQ00<?hN40In48:3CQ000^h@03

3n7Q00kQ00<0hN40P^400`oQh@1@h@<?CN400bSQh@0Xh@033n7Q06gQ1BP`h@00;^400`oQh@0>h@03

0>7Q087Q00<?hN40E>443dSQ00<XhN40:N400`oQh@2Rh@00;N400`oQh@0?h@030>7Q087Q00<?hN40

F>433dGQ00<XhN40:^400`oQh@2Qh@00;N400`oQh@0?h@030>7Q083Q00<?hN40G>443d7Q00<XhN40

:^400`oQh@2Qh@00;>400`oQh@0@h@030>7Q083Q00<?hN40H>443ccQ00<XhN40;>400`oQh@2Ph@00

:n400`oQh@0Ah@030>7Q083Q00<?hN40I>443cSQ00<XhN40;N400`oQh@2Oh@00:n400`oQh@0Ah@03

0>7Q083Q00<?hN40J>443cCQ00<XhN40;^400`oQh@2Nh@00:^400`oQh@0Bh@030>7Q07oQ00<?hN40

KN433c7Q00<XhN40;^400`oQh@2Nh@00:^400`oQh@0Bh@030>7Q07oQ00<?hN40L>433bkQ00<XhN40

;n400`oQh@2Mh@00:N400`oQh@0Ch@030>7Q07kQ00<?hN40M>443b[Q00<XhN40;n400`oQh@2Mh@00

:N400`oQh@0Ch@030>7Q07kQ00<?hN40N>443bKQ00<XhN40<>400`oQh@2Lh@00:>400`oQh@0Dh@<0

O^400`oQh@1lh@@?8^400bSQh@0ah@033n7Q09_Q000Xh@033n7Q01CQ00<0hN40O^400`oQh@20h@@?

7n400bSQh@0`h@033n7Q09_Q000Wh@033n7Q01GQ00<0hN40O^400`oQh@24h@@?6n400bSQh@0ah@03

3n7Q09[Q000Wh@033n7Q01GQ00<0hN40ON400`oQh@29h@@?5n42:3;Q00<?hN40V^4002KQ00<?hN40

5^400`3Qh@1mh@033n7Q08gQ0`lEh@03:>7Q037Q00<?hN40VN4002KQ00<?hN405^400`3Qh@1mh@03

3n7Q093Q0`lCh@03:>7Q033Q00<?hN40VN4002KQ00<?hN405^400`3Qh@1lh@033n7Q09CQ10l?h@8X

<N400`oQh@2Ih@009N400`oQh@0Gh@030>7Q07cQ00<?hN40V>443`cQ0RPah@033n7Q09SQ000Uh@03

3n7Q01OQ00<0hN40O>400`oQh@2Lh@@?2N400bSQh@0`h@033n7Q09OQ000Uh@033n7Q01OQ00<0hN40

O>400`oQh@2Ph@8?2>400bSQh@0_h@033n7Q09OQ000Th@033n7Q01SQ00<0hN40O>400`oQh@2Rh@@?

1N42:33Q00<?hN40U^4002CQ00<?hN406>400`3Qh@1lh@033n7Q0:KQ0Pl5h@8X;^400`oQh@2Fh@00

8n400`oQh@0Ih@<0Nn400`oQh@2Yh@8?1N44:2_Q00<?hN40UN4002?Q00<?hN406N400`3Qh@1kh@03

3n7Q0:_Q0Pl6h@DX9n400`oQh@2Eh@008^400`oQh@0Jh@030>7Q07_Q00<?hN40[>423`WQ12PTh@03

3n7Q09GQ000Rh@033n7Q01[Q00<0hN40N^400`oQh@2^h@8?2n45:23Q00<?hN40UN4002;Q00<?hN40

6^400`3Qh@1jh@033n7Q0:oQ0Pl>h@DX7N400`oQh@2Dh@008^400`oQh@0Jh@030>7Q07[Q00<?hN40

/>423a7Q12PJh@033n7Q09CQ000Qh@033n7Q01_Q00<0hN40N^400`oQh@2ah@8?5>45:1GQ00<?hN40

U>40027Q00<?hN406n400`3Qh@1jh@033n7Q0;;Q0PlHh@@X4N400`oQh@2Dh@008N400`oQh@0Kh@03

0>7Q07[Q00<?hN40/n423a_Q12P>h@033n7Q09?Q000Qh@033n7Q01_Q00<0hN40NN400`oQh@2eh@8?

7^44:0[Q00<?hN40Tn40027Q00<?hN404^400`3Qh@06h@030>7Q07WQ00<?hN40]^423b7Q12P6h@03

3n7Q09?Q000Ph@033n7Q01;Q00<0h@001n400`3Qh@1ih@033n7Q0;SQ00<?hN408^44:0?Q00<?hN40

T^40023Q00<?hN403N4300CQ00<0hN401N4507OQ00<?hN40^N400`oQh@0Uh@DXTn40023Q00<?hN40

4^4200SQ00<0hN40N>400`oQh@2jh@8?:^45:8oQ000Ph@033n7Q01;Q00<0hN401n400`3Qh@1hh@03

3n7Q0;_Q0PlYh@043n7Qh@DXRn4001oQ00<?hN404n4300OQ00<0hN40N>400`oQh@2mh@033n7Q02KQ

00<?hN401^45:8KQ000Oh@033n7Q01gQ00<0hN40N>400`oQh@2nh@033n7Q02KQ00<?hN402N45:8;Q

000Nh@033n7Q01kQ00<0hN40N>400`oQh@2oh@033n7Q02GQ00<?hN403N45:7kQ000Nh@033n7Q01kQ

00<0hN40N>400`oQh@30h@8?9N400`oQh@0Bh@DXNN4001kQ00<?hN407^400`3Qh@1hh@033n7Q0<7Q

0PlTh@033n7Q01KQ1BQeh@007^400`oQh@0Nh@030>7Q07SQ00<?hN40`^423bCQ00<?hN406N45:77Q

000Mh@033n7Q01oQ00<0hN40N>400`oQh@33h@8?8n400`oQh@0Nh@DXK>4001gQ00<?hN407n400`3Q

h@1gh@033n7Q0<GQ0PlRh@033n7Q02;Q1BQXh@007N400`oQh@0Oh@<0Mn400`oQh@36h@8?8N400`oQ

h@0Wh@@XI>4001gQ00<?hN407n400`3Qh@1gh@033n7Q0<OQ0PlQh@033n7Q02[Q1BQOh@007N400`oQ

h@0Oh@030>7Q07OQ00<?hN40b>423b3Q00<?hN40;^45:5_Q000Mh@033n7Q01oQ00<0hN40Mn400`oQ

h@39h@8?7n400`oQh@0ch@DXE^4001gQ00<?hN407n400`3Qh@1fh@033n7Q0<_Q0PlNh@033n7Q03SQ

1BQAh@007>400`oQh@0Ph@030>7Q07KQ00<?hN40c>423akQ00<?hN40>n45:4gQ000Lh@033n7Q023Q

00<0hN40M^400`oQh@3=h@8?7N400`oQh@10h@DXB>4001cQ00<?hN408>400`3Qh@1fh@033n7Q0<kQ

0PlLh@033n7Q04CQ1BQ4h@007>400`oQh@0Ph@030>7Q07KQ00<?hN40cn423a_Q00<?hN40BN45:3oQ

000Lh@033n7Q023Q00<0hN40M^400`oQh@3@h@8?6^400`oQh@1=h@DX>n4001cQ00<?hN408>400`3Q

h@1fh@033n7Q0=7Q0PlIh@033n7Q05;Q1BPfh@007>400`oQh@0Ph@030>7Q07KQ00<?hN40d^423aSQ

00<?hN40En45:37Q000Kh@033n7Q027Q0`1fh@033n7Q0=?Q0PlHh@033n7Q05_Q00<XhN40;^4001_Q

00<?hN408N400`3Qh@1fh@033n7Q0=CQ0PlGh@033n7Q08cQ000Kh@033n7Q027Q00<0hN40M^400`oQ

h@3Eh@8?5^400`oQh@2<h@006n400`oQh@0Qh@030>7Q07KQ00<?hN40e^423aGQ00<?hN40S>4001[Q

00<?hN408^400`3Qh@1fh@033n7Q0=OQ0PlDh@033n7Q08cQ000Jh@033n7Q02;Q00<0hN40MN400`oQ

h@3Ih@033n7Q01;Q00<?hN40S>4001[Q00<?hN408^400`3Qh@1eh@033n7Q0=[Q00<?hN404N400`oQ

h@2<h@006^400`oQh@0Rh@030>7Q07GQ00<?hN40f^423a;Q00<?hN40S>4001[Q00<?hN408^400`3Q

h@1eh@033n7Q0=_Q0PlAh@033n7Q08cQ000Jh@033n7Q02;Q00<0hN40MN400`oQh@3Lh@8?4>400`oQ

h@2<h@006^400`oQh@0Rh@030>7Q07GQ00<?hN40gN400`oQh@0>h@033n7Q08cQ000Jh@033n7Q02;Q

00<0hN40MN400`oQh@3Nh@033n7Q00gQ00<?hN40S>4001[Q00<?hN408^4307GQ00<?hN40g^423`kQ

00<?hN40S>4001[Q00<?hN408^400`3Qh@1eh@033n7Q0=oQ0Pl=h@033n7Q08cQ000Ih@033n7Q02?Q

00<0hN40MN400`oQh@3Ph@033n7Q00_Q00<?hN40S>4001WQ00<?hN408n400`3Qh@1eh@033n7Q0>7Q

00<?hN402^400`oQh@2<h@006N400`oQh@0Sh@030>7Q07GQ00<?hN40hN423`_Q00<?hN40S>4001WQ

00<?hN408n400`3Qh@1eh@033n7Q0>;Q00<?hN402N400`oQh@2<h@006N400`oQh@0Sh@030>7Q07GQ

00<?hN40hn400`oQh@08h@033n7Q08cQ000Ih@033n7Q02?Q00<0hN40MN400`oQh@3Sh@8?2N400`oQ

h@2<h@006N400`oQh@0Sh@030>7Q07GQ00<?hN40i>400`oQh@07h@033n7Q08cQ000Ih@033n7Q02?Q

00<0hN40>^4500;Q00<0hN40<N400`oQh@03h@D000?Q0000>N4500;Q00<0hN40=n4500;Q00<0hN40

=n450003h@0001KQ0Pl8h@033n7Q01OQ0`03h@030>7Q03SQ0`000n40000302_Q000Ih@033n7Q02?Q

00<0hN40?>401`3QhN40h@00<^400`oQh@05h@070>7Qh@3Q000jh@030>7Q00;Q00<0hN40>N401`3Q

hN40h@00>^400`3Qh@03h@030>7Q01CQ00<?hN401^400`oQh@0Gh@030>7Q00;Q00<0h@00>N400`3Q

h@03h@030>7Q02_Q000Ih@033n7Q02?Q00<0hN40?>400`3Qh@03h@030>7Q033Q00<?hN401N401`3Q

hN40h@00>^400`3Qh@02h@030>7Q03WQ00L0hN7Q0>4003[Q00<0hN400^4201OQ00<?hN401>400`oQ

h@0Ih@070>7Qh@3Q000jh@030>7Q00;Q00<0hN40:n4001WQ00<?hN408n4303cQ00@0hN7Q0P0ch@03

3n7Q00GQ00@0hN7Q0P0kh@030>7Q00?Q00<0hN40>>400`3Qh@02h@030>7Q03WQ00L0hN7Q0>4001OQ

00<?hN401>400`oQh@0Ih@070>7Qh@3Q000jh@030>7Q00;Q00<0hN40:n4001WQ00<?hN408n400`3Q

h@0lh@050>7Qh@00=>400`oQh@05h@050>7Qh@00?>401`3QhN40h@00>^401`3QhN40h@00>^401`3Q

hN40h@005n423`GQ00<?hN406>400`3Q0002h@030>4003WQ00<0h@000n400`3Qh@0[h@006N400`oQ

h@0Sh@030>7Q03_Q0P03h@<0<^400`oQh@04h@801>4203WQ0P03h@<0>N4200CQ00<0hN40>>4200CQ

0P0Hh@033n7Q00?Q00<?hN406N400`3Qh@02h@030>7Q03WQ00@0hN7Q0P0]h@006N400`oQh@0Sh@03

0>7Q07GQ00<?hN40in400`oQh@03h@033n7Q08gQ000Ih@033n7Q02?Q00<0hN40M>400`oQh@3Yh@03

3n7Q00;Q00<?hN40SN4001WQ00<?hN408n400`3Qh@1dh@033n7Q0>WQ00D?hN7Q3`2@h@006N400`oQ

h@0Sh@030>7Q07CQ00<?hN40j^4010oQh@n@h@006N400`oQh@0Sh@030>7Q07CQ00<?hN40j^4010oQ

h@n@h@006N400`oQh@0Sh@030>7Q07CQ00<?hN40j^4010oQh@n@h@006N400`oQh@0Sh@030>7Q07CQ

00<?hN40jn423ggQ100@h@006N400`oQh@0Sh@030>7Q07CQ00<?hN40jn423ggQ0`0Ah@003>4=0003

3`0009X000<?0000k0000`l0001/017Q00<0hN403n4001SQ00<03n402^400`3Qh@0:h@030>7Q00[Q

00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Qh@0;h@030>7Q00[Q00<0hN402^400`3Q

h@0:h@030>7Q00[Q00<03n402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q

00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Q

h@0:h@030>7Q00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN400^423`KQ00<0hN402^400`3Q

h@0:h@030>7Q00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Qh@0Jh@804N4001SQ

00<03n402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Q

h@0;h@030>7Q00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q00<03n402^400`3Qh@0:h@030>7Q00[Q

00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Q

h@0:h@030>7Q00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q

00<0hN400^423`KQ00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q

00<0hN402^400`3Qh@0]h@006N400`oQh@0Sh@030>7Q03oQ00<0hN40<^400`oQh@09h@030>7Q03kQ

00<0hN40?^400`3Qh@0nh@030>7Q01cQ0PlPh@030>7Q03kQ00<0hN40;N4001WQ00<?hN408n400`3Q

h@0oh@030>7Q03;Q00<?hN402N400`3Qh@0nh@030>7Q03kQ00<0hN40?^400`3Qh@0Kh@043n7Q3aoQ

00<0hN40?^400`3Qh@0]h@006N400`oQh@0Sh@030>7Q07CQ00<?hN40j^4010oQh@n@h@006N400`oQ

h@0Sh@030>7Q07CQ00<?hN40j^4010oQh@n@h@006N400`oQh@0Sh@030>7Q07CQ00<?hN40jN401@oQ

hN4?093Q000Ih@033n7Q02?Q00<0hN40MN400`oQh@3Xh@033n7Q00;Q00<?hN40SN4001WQ00<?hN40

8n400`3Qh@1eh@033n7Q0>OQ00<?hN400n400`oQh@2=h@006N400`oQh@0Sh@030>7Q07GQ00<?hN40

in400`oQh@03h@033n7Q08gQ000Ih@033n7Q02?Q00<0hN40MN400`oQh@3Vh@033n7Q00CQ00<?hN40

SN4001WQ00<?hN408n4307GQ00<?hN40i^400`oQh@04h@033n7Q08gQ000Ih@033n7Q02?Q00<0hN40

MN400`oQh@3Uh@8?1^400`oQh@2=h@006N400`oQh@0Sh@030>7Q07GQ00<?hN40iN400`oQh@06h@03

3n7Q08cQ000Ih@033n7Q02?Q00<0hN40MN400`oQh@3Th@8?2>400`oQh@2<h@006N400`oQh@0Sh@03

0>7Q07GQ00<?hN40i>400`oQh@07h@033n7Q08cQ000Ih@033n7Q02?Q00<0hN40MN400`oQh@3Sh@03

3n7Q00SQ00<?hN40S>4001WQ00<?hN408n400`3Qh@1eh@033n7Q0>;Q0Pl:h@033n7Q08cQ000Ih@03

3n7Q02?Q00<0hN40MN400`oQh@3Rh@033n7Q00WQ00<?hN40S>4001WQ00<?hN408n400`3Qh@1eh@03

3n7Q0>7Q00<?hN402^400`oQh@2<h@006N400`oQh@0Sh@030>7Q07GQ00<?hN40h>423`cQ00<?hN40

S>4001[Q00<?hN408^400`3Qh@1eh@033n7Q0>3Q00<?hN402n400`oQh@2<h@006^400`oQh@0Rh@03

0>7Q07GQ00<?hN40gn400`oQh@0<h@033n7Q08cQ000Jh@033n7Q02;Q0`1eh@033n7Q0=kQ0Pl>h@03

3n7Q08cQ000Jh@033n7Q02;Q00<0hN40MN400`oQh@3Mh@8?3n400`oQh@2<h@006^400`oQh@0Rh@03

0>7Q07GQ00<?hN40gN400`oQh@0>h@033n7Q08cQ000Jh@033n7Q02;Q00<0hN40MN400`oQh@3Lh@03

3n7Q00oQ00<?hN40S>4001[Q00<?hN408^400`3Qh@1eh@033n7Q0=_Q0PlAh@033n7Q08cQ000Jh@03

3n7Q02;Q00<0hN40MN400`oQh@3Jh@8?4^400`oQh@2<h@006^400`oQh@0Rh@030>7Q07GQ00<?hN40

fN423a?Q00<?hN40S>4001[Q00<?hN408^400`3Qh@1eh@033n7Q0=WQ00<?hN404^400`oQh@2<h@00

6^400`oQh@0Rh@030>7Q07KQ00<?hN40en400`oQh@0Ch@033n7Q08cQ000Kh@033n7Q027Q00<0hN40

M^400`oQh@3Fh@8?5N400`oQh@2<h@006n400`oQh@0Qh@030>7Q07KQ00<?hN40eN423aKQ00<?hN40

S>4001_Q00<?hN408N400`3Qh@1fh@033n7Q0=CQ0PlGh@033n7Q08cQ000Kh@033n7Q027Q0`1fh@03

3n7Q0=?Q0PlHh@033n7Q05WQ0bP`h@007>400`oQh@0Ph@030>7Q07KQ00<?hN40d^423aSQ00<?hN40

E^45:3;Q000Lh@033n7Q023Q00<0hN40M^400`oQh@3Ah@8?6N400`oQh@1Ah@DX=n4001cQ00<?hN40

8>400`3Qh@1fh@033n7Q0=3Q0PlJh@033n7Q04cQ1BPlh@007>400`oQh@0Ph@030>7Q07KQ00<?hN40

cn423a_Q00<?hN40B>44:47Q000Lh@033n7Q023Q00<0hN40M^400`oQh@3>h@8?7>400`oQh@13h@DX

AN4001cQ00<?hN408>400`3Qh@1fh@033n7Q0<gQ0PlMh@033n7Q03kQ1BQ:h@007N400`oQh@0Oh@03

0>7Q07KQ00<?hN40c>423akQ00<?hN40>^45:4kQ000Mh@033n7Q01oQ00<0hN40M^400`oQh@3;h@8?

7^400`oQh@0fh@DXDn4001gQ00<?hN407n400`3Qh@1gh@033n7Q0<WQ0PlOh@033n7Q03;Q1BQGh@00

7N400`oQh@0Oh@030>7Q07OQ00<?hN40b>423b3Q00<?hN40;N45:5cQ000Mh@033n7Q01oQ0`1gh@03

3n7Q0<OQ0PlPh@033n7Q02[Q1BQPh@007N400`oQh@0Oh@030>7Q07OQ00<?hN40a^423b7Q00<?hN40

9^45:6CQ000Mh@033n7Q01oQ00<0hN40Mn400`oQh@35h@8?8^400`oQh@0Qh@DXJN4001kQ00<?hN40

7^400`3Qh@1hh@033n7Q0<?Q0PlSh@033n7Q01gQ1BQ]h@007^400`oQh@0Nh@030>7Q07SQ00<?hN40

`^400`oQh@0Rh@033n7Q01WQ1BQbh@007^400`oQh@0Nh@030>7Q07SQ00<?hN40`N400`oQh@0Sh@03

3n7Q01GQ12Qgh@007^400`oQh@0Nh@030>7Q07SQ00<?hN40`>400`oQh@0Th@033n7Q017Q1BQjh@00

7n400`oQh@0Mh@030>7Q07SQ00<?hN40_^423bOQ00<?hN403>45:7oQ000Oh@033n7Q01gQ00<0hN40

N>400`oQh@2mh@8?:>400`oQh@08h@@XQ>4001oQ00<?hN407N400`3Qh@1hh@033n7Q0;cQ0PlXh@03

3n7Q00GQ12R8h@008>400`oQh@0Ch@030>7Q00KQ00<0hN40N>400`oQh@2kh@8?:N4010oQhN44:8cQ

000Ph@033n7Q01;Q00<0h@001n400`3Qh@1hh@033n7Q0;[Q0PlYh@DXT>40023Q00<?hN405>400`3Q

h@05h@D0Mn400`oQh@2hh@8?9^44:0033n7Q09;Q000Ph@033n7Q01;Q0P08h@030>7Q07WQ00<?hN40

]n423b?Q1BP3h@033n7Q09;Q000Qh@033n7Q017Q00<0hN401n400`3Qh@1ih@033n7Q0;KQ0PlPh@@X

1n400`oQh@2Ch@008N400`oQh@0Ah@<01n400`3Qh@1jh@033n7Q0;CQ0PlLh@DX2n400`oQh@2Ch@00

8N400`oQh@0Kh@030>7Q07[Q00<?hN40/n423aWQ1BP?h@033n7Q09?Q000Qh@033n7Q01_Q00<0hN40

N^400`oQh@2bh@8?5^45:1;Q00<?hN40U>4002;Q00<?hN406^400`3Qh@1jh@033n7Q0;7Q0PlCh@DX

5^400`oQh@2Dh@008^400`oQh@0Jh@030>7Q07[Q00<?hN40/>423a7Q12PJh@033n7Q09CQ000Rh@03

3n7Q01[Q00<0hN40N^400`oQh@2_h@8?3^44:1kQ00<?hN40U>4002;Q00<?hN406^400`3Qh@1jh@03

3n7Q0:kQ0Pl;h@@X8N400`oQh@2Eh@008^400`oQh@0Jh@030>7Q07_Q00<?hN40[>400`oQh@07h@@X

9N400`oQh@2Eh@008n400`oQh@0Ih@030>7Q07_Q00<?hN40Z^423`OQ0bPYh@033n7Q09GQ000Sh@03

3n7Q01WQ0`1kh@033n7Q0:WQ0Pl4h@@X:n400`oQh@2Fh@009>400`oQh@0Hh@030>7Q07cQ00<?hN40

YN433`CQ0bP^h@033n7Q09KQ000Th@033n7Q01SQ00<0hN40O>400`oQh@2Sh@<?1>43:2oQ00<?hN40

Un4002GQ00<?hN405n400`3Qh@1lh@033n7Q09oQ10l7h@03:>7Q02oQ00<?hN40Un4002GQ00<?hN40

5n400`3Qh@1lh@033n7Q09_Q10l:h@03:>7Q02oQ00<?hN40V>4002GQ00<?hN405n400`3Qh@1lh@03

3n7Q09OQ10l=h@03:>7Q033Q00<?hN40V>4002KQ00<?hN405^400`3Qh@1lh@033n7Q09CQ0`l@h@03

:>7Q033Q00<?hN40VN4002KQ00<?hN405^400`3Qh@1mh@033n7Q08oQ10lBh@03:>7Q037Q00<?hN40

VN4002KQ00<?hN405^400`3Qh@1mh@033n7Q08cQ0`lFh@03:>7Q037Q00<?hN40VN4002OQ00<?hN40

5N400`3Qh@1nh@033n7Q08OQ10lHh@03:>7Q037Q00<?hN40V^4002OQ00<?hN405N400`3Qh@1nh@03

3n7Q08?Q10lLh@03:>7Q037Q00<?hN40V^4002SQ00<?hN405>400`3Qh@1nh@033n7Q07oQ10lPh@03

:>7Q033Q00<?hN40Vn4002WQ00<?hN404n4307kQ00<?hN40Nn443b?Q00<XhN40<>400`oQh@2Lh@00

:N400`oQh@0Ch@030>7Q07kQ00<?hN40Mn443bOQ00<XhN40<>400`oQh@2Lh@00:^400`oQh@0Bh@03

0>7Q07oQ00<?hN40Ln433b_Q00<XhN40;n400`oQh@2Mh@00:^400`oQh@0Bh@030>7Q07oQ00<?hN40

Kn443bkQ00<XhN40;n400`oQh@2Mh@00:^400`oQh@0Bh@030>7Q07oQ00<?hN40K>433c;Q00<XhN40

;^400`oQh@2Nh@00:n400`oQh@0Ah@030>7Q083Q00<?hN40In443cGQ00<XhN40;^400`oQh@2Nh@00

:n400`oQh@0Ah@030>7Q083Q00<?hN40Hn443cWQ00<XhN40;N400`oQh@2Oh@00;>400`oQh@0@h@03

0>7Q083Q00<?hN40Gn443cgQ00<XhN40;>400`oQh@2Ph@00;N400`oQh@0?h@030>7Q083Q00<?hN40

G>433d;Q00<XhN40:^400`oQh@2Qh@00;N400`oQh@0?h@030>7Q087Q00<?hN40En443dGQ00<XhN40

:^400`oQh@2Qh@00;^400`oQh@0>h@030>7Q087Q00<?hN40Dn443dWQ00<XhN40:N400`oQh@2Rh@00

;^400`oQh@0>h@<0P^400`oQh@1?h@<?C^400bSQh@0Xh@033n7Q06_Q1bP`h@00;n400`oQh@0=h@03

0>7Q08;Q00<?hN40C>433e;Q00<XhN409^400`oQh@1Vh@LX=^4002oQ00<?hN403N400`3Qh@22h@03

3n7Q04SQ10mFh@03:>7Q02GQ00<?hN40Gn47:3gQ000`h@033n7Q00cQ00<0hN40P^400`oQh@14h@@?

Fn400bSQh@0Sh@033n7Q05WQ1bQ4h@00<N400`oQh@0;h@030>7Q08?Q00<?hN40?n443f3Q00<XhN40

8N400`oQh@1Ch@LXBn4003;Q00<?hN402^400`3Qh@23h@033n7Q03_Q10mUh@8X8>400`oQh@1<h@PX

D^4003;Q00<?hN402^400`3Qh@23h@033n7Q03WQ0Pm[h@8X7^400`oQh@15h@PXFN4003?Q00<?hN40

2N400`3Qh@24h@033n7Q03CQ10m_h@8X6n400`oQh@0nh@TXH>4003?Q00<?hN402N400`3Qh@24h@03

3n7Q033Q10meh@<X5n400`oQh@0hh@PXJ>4003CQ00<?hN402>400`3Qh@25h@033n7Q02_Q10mlh@@X

4^400`oQh@0ah@PXL>4003GQ0Pl8h@030>7Q08GQ00<?hN40:>433h?Q1BP=h@033n7Q02SQ2RQhh@00

=^400`oQh@06h@030>7Q08GQ00<?hN409>443h[Q1bP7h@033n7Q01gQ2bR2h@00=n400`oQh@05h@<0

Q^400`oQh@0Ph@<?UN4W:8gQ000hh@033n7Q00CQ00<0hN40Qn400`oQh@0Kh@@?WN400`oQh@2/h@00

>N400`oQh@03h@030>7Q08OQ00<?hN405n443j3Q00<?hN40[N4003[Q00<?hN400^400`3Qh@27h@03

3n7Q01CQ0`nSh@033n7Q0:kQ000kh@053n7Qh@00R^400`oQh@0?h@@?YN400`oQh@2_h@00?>4010oQ

h@2:h@033n7Q00_Q10nXh@033n7Q0;3Q000mh@033n4008_Q00<?hN401^443jcQ00<?hN40/>4003kQ

0Pn;h@033n7Q00?Q0`n^h@8?/n4003oQ00<03n40R^453k3Q00<?hN40/n4003oQ00<0h@l0Qn453k;Q

00<?hN40]>4002oQ1@02h@030>7Q00KQ00<0hN400Pn1h@@?1>400`oQh@2^h@8?]n40037Q00L0hN7Q

0>4000OQ00<0hN400^400`oQh@1jh@@?2>400`oQh@2]h@033n7Q0;OQ000ah@070>7Qh@3Q0007h@D0

00?Q3n40M^443`gQ00<?hN40[>400`oQh@2gh@00<N401`3QhN40h@001n400`3Qh@04h@8?LN443a;Q

00<?hN40Z^400`oQh@2hh@00<N401`3QhN40h@001n400`3Qh@06h@033n7Q06[Q10lFh@033n7Q0:SQ

0Pnkh@00<>4200CQ00<0hN401^400`3Qh@07h@8?I^443a_Q00<?hN40Y^400`oQh@2kh@00?n400`3Q

h@09h@8?Gn453b3Q00<?hN40Xn423kkQ000oh@030>7Q00_Q0PmIh@@?9N400`oQh@2Qh@8?`>4003oQ

00<0hN403N433e7Q1@lZh@033n7Q09oQ00<?hN40`>4003oQ00<0hN404>433dWQ1@l`h@033n7Q09gQ

00<?hN40`N4003oQ00<0hN404n443d3Q1@leh@033n7Q09_Q0Po4h@00?n400`3Qh@0Gh@8?=n473c_Q

00<?hN40V>423lKQ000oh@030>7Q01WQ1@l/h@H?@^423iOQ0Po8h@00?n400`3Qh@0Nh@P?6N4;3d[Q

00<?hN40Tn400`oQh@38h@00?n4302KQ6@mEh@033n7Q097Q0Po;h@00?n400`3Qh@2Eh@033n7Q08kQ

0Po=h@00?n400`3Qh@2Fh@033n7Q08_Q0Po?h@00?n400`3Qh@2Gh@033n7Q08OQ0`oAh@00?n400`3Q

h@2Hh@033n7Q08GQ00<?hN40d^4003oQ00<0hN40VN400`oQh@21h@<?eN4003oQ00<0hN40V^400`oQ

h@1mh@<?f>4003oQ00<0hN40Vn423g_Q0PoKh@00?n400`3Qh@2Lh@033n7Q07KQ0`oMh@00?n400`3Q

h@2Mh@8?L^443n3Q000oh@030>7Q09kQ0Pm_h@8?i>4003oQ0`2Oh@8?Jn433nKQ000oh@030>7Q0:7Q

00<?hN40I>443nWQ000oh@030>7Q0:;Q0PmPh@@?kN4003oQ00<0hN40Y>423ecQ0Poah@00?n400`3Q

h@2Vh@8?E^443o?Q000oh@030>7Q0:SQ00<?hN40C^453oOQ000oh@030>7Q0:WQ0`m9h@@?o>4003oQ

00<0hN40[>423d;Q1@ooh@7Q000oh@030>7Q0:kQ0`lih@H?on46h@00?n400`3Qh@2ah@@?<>453ooQ

3>4003oQ00<0hN40]N453bGQ1PoohA7Q000oh@030>7Q0;[Q1PlDh@/?on4Gh@00?n430<3Q50oohB;Q

000oh@030>7Q0?oQm^4003oQ00<0hN40on7fh@00?n400`3Qh@3ohOKQ000oh@030>7Q0?oQm^4003oQ

00<0hN40on7fh@00?n400`3Qh@3ohOKQ000oh@030>7Q0?oQm^4003oQ00<0hN40on7fh@00on7ohCWQ

003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQ

on4ih@00on7ohCWQ003ohOoQ>N400?kQ0P001>400>440003h@0000?Q0P04h@040>7Qh@801>400`3Q

h@3ohAOQ003oh@030>4000WQ00<0hN400^400`3Qh@05h@030>4000;Q00<0h@00on4Hh@00on4300;Q

1002h@030>7Q00;Q0P07h@030>4000CQ00<0hN40on4Fh@00on40103Q0008h@060>7Q0>401n4200?Q

0P3ohAWQ000mh@80`>400`3Qh@07h@030>4000;Q00<0h@001n400`3Qh@02h@030>7Q0?oQ6>4003kQ

00<0hN40_N4200[Q00<0hN400^4200SQ0P02h@<0on4Hh@00?>4300;Q00<0hN40on7dh@00>n40203Q

h@3Q0>40on7eh@00>n40203Qh@3Q0>40on7eh@00?>430004h@3Q0?oQmN40043Q00<0h@00on7eh@00

@N400`3Qh@3ohOCQ003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQon4ih@00\

\>"],

  ImageRangeCache->{{{0, 566}, {349.313, 0}} -> {13.018, -13.6377, 0.0153649, 

  0.0851411}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-1.65768 0.125422 0.309017 0.022637 [

[.22366 .29652 -6 -9 ]

[.22366 .29652 6 0 ]

[.34908 .29652 -6 -9 ]

[.34908 .29652 6 0 ]

[.4745 .29652 -6 -9 ]

[.4745 .29652 6 0 ]

[.59992 .29652 -6 -9 ]

[.59992 .29652 6 0 ]

[.72535 .29652 -6 -9 ]

[.72535 .29652 6 0 ]

[.85077 .29652 -6 -9 ]

[.85077 .29652 6 0 ]

[.97619 .29652 -6 -9 ]

[.97619 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.08574 .08265 -18 -4.5 ]

[.08574 .08265 0 4.5 ]

[.08574 .19583 -12 -4.5 ]

[.08574 .19583 0 4.5 ]

[.08574 .4222 -6 -4.5 ]

[.08574 .4222 0 4.5 ]

[.08574 .53539 -12 -4.5 ]

[.08574 .53539 0 4.5 ]

[.09824 .64303 -7 0 ]

[.09824 .64303 7 16 ]

[.5 .63053 -27 0 ]

[.5 .63053 27 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.22366 .30902 m

.22366 .31527 L

s

[(15)] .22366 .29652 0 1 Mshowa

.34908 .30902 m

.34908 .31527 L

s

[(16)] .34908 .29652 0 1 Mshowa

.4745 .30902 m

.4745 .31527 L

s

[(17)] .4745 .29652 0 1 Mshowa

.59992 .30902 m

.59992 .31527 L

s

[(18)] .59992 .29652 0 1 Mshowa

.72535 .30902 m

.72535 .31527 L

s

[(19)] .72535 .29652 0 1 Mshowa

.85077 .30902 m

.85077 .31527 L

s

[(20)] .85077 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(21)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.12332 .30902 m

.12332 .31277 L

s

.1484 .30902 m

.1484 .31277 L

s

.17349 .30902 m

.17349 .31277 L

s

.19857 .30902 m

.19857 .31277 L

s

.24874 .30902 m

.24874 .31277 L

s

.27383 .30902 m

.27383 .31277 L

s

.29891 .30902 m

.29891 .31277 L

s

.324 .30902 m

.324 .31277 L

s

.37416 .30902 m

.37416 .31277 L

s

.39925 .30902 m

.39925 .31277 L

s

.42433 .30902 m

.42433 .31277 L

s

.44942 .30902 m

.44942 .31277 L

s

.49959 .30902 m

.49959 .31277 L

s

.52467 .30902 m

.52467 .31277 L

s

.54975 .30902 m

.54975 .31277 L

s

.57484 .30902 m

.57484 .31277 L

s

.62501 .30902 m

.62501 .31277 L

s

.65009 .30902 m

.65009 .31277 L

s

.67518 .30902 m

.67518 .31277 L

s

.70026 .30902 m

.70026 .31277 L

s

.75043 .30902 m

.75043 .31277 L

s

.77551 .30902 m

.77551 .31277 L

s

.8006 .30902 m

.8006 .31277 L

s

.82568 .30902 m

.82568 .31277 L

s

.87585 .30902 m

.87585 .31277 L

s

.90094 .30902 m

.90094 .31277 L

s

.92602 .30902 m

.92602 .31277 L

s

.95111 .30902 m

.95111 .31277 L

s

.07315 .30902 m

.07315 .31277 L

s

.04807 .30902 m

.04807 .31277 L

s

.02298 .30902 m

.02298 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.09824 .08265 m

.10449 .08265 L

s

[(-10)] .08574 .08265 1 0 Mshowa

.09824 .19583 m

.10449 .19583 L

s

[(-5)] .08574 .19583 1 0 Mshowa

.09824 .4222 m

.10449 .4222 L

s

[(5)] .08574 .4222 1 0 Mshowa

.09824 .53539 m

.10449 .53539 L

s

[(10)] .08574 .53539 1 0 Mshowa

.125 Mabswid

.09824 .10528 m

.10199 .10528 L

s

.09824 .12792 m

.10199 .12792 L

s

.09824 .15056 m

.10199 .15056 L

s

.09824 .17319 m

.10199 .17319 L

s

.09824 .21847 m

.10199 .21847 L

s

.09824 .24111 m

.10199 .24111 L

s

.09824 .26374 m

.10199 .26374 L

s

.09824 .28638 m

.10199 .28638 L

s

.09824 .33165 m

.10199 .33165 L

s

.09824 .35429 m

.10199 .35429 L

s

.09824 .37693 m

.10199 .37693 L

s

.09824 .39957 m

.10199 .39957 L

s

.09824 .44484 m

.10199 .44484 L

s

.09824 .46748 m

.10199 .46748 L

s

.09824 .49011 m

.10199 .49011 L

s

.09824 .51275 m

.10199 .51275 L

s

.09824 .06001 m

.10199 .06001 L

s

.09824 .03737 m

.10199 .03737 L

s

.09824 .01474 m

.10199 .01474 L

s

.09824 .55802 m

.10199 .55802 L

s

.09824 .58066 m

.10199 .58066 L

s

.09824 .6033 m

.10199 .6033 L

s

.25 Mabswid

.09824 0 m

.09824 .61803 L

s

gsave

.09824 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(k) show

78.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

88.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(39.7) show

113.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

1 0 0 r

.5 Mabswid

.70026 .50635 m

.69901 .506 L

.69775 .50562 L

.6965 .50524 L

.69524 .50484 L

.69399 .50441 L

.69274 .50397 L

.69148 .50351 L

.69023 .50303 L

.68897 .50252 L

.68772 .50199 L

.68647 .50143 L

.68396 .50022 L

.68145 .49888 L

.67894 .49737 L

.67643 .49566 L

.67392 .49368 L

.67141 .49133 L

.66891 .48842 L

.6674 .48623 L

.6664 .48446 L

.66489 .48094 L

.66389 .47699 L

.66383 .47662 L

.66376 .47621 L

.6637 .47575 L

.66364 .47519 L

.66358 .47453 L

s

.70026 .11169 m

.69901 .11204 L

.69775 .11241 L

.6965 .1128 L

.69524 .1132 L

.69399 .11362 L

.69274 .11406 L

.69148 .11452 L

.69023 .11501 L

.68897 .11552 L

.68772 .11605 L

.68647 .11661 L

.68396 .11781 L

.68145 .11916 L

.67894 .12066 L

.67643 .12237 L

.67392 .12435 L

.67141 .1267 L

.66891 .12961 L

.6674 .1318 L

.6664 .13357 L

.66489 .13709 L

.66389 .14105 L

.66383 .14141 L

.66376 .14183 L

.6637 .14228 L

.66364 .14285 L

.66358 .1435 L

s

.66314 .45604 m

.66326 .45616 L

.66339 .45628 L

.66351 .45643 L

.66364 .45659 L

.66376 .45678 L

.66389 .457 L

.66395 .45713 L

s

.66314 .162 m

.66326 .16188 L

.66339 .16175 L

.66351 .1616 L

.66364 .16144 L

.66376 .16125 L

.66389 .16103 L

.66395 .1609 L

s

.66188 .45531 m

.66063 .45497 L

.65937 .45482 L

.65762 .45477 L

.65511 .45491 L

.6526 .45519 L

.65009 .45555 L

.64758 .45597 L

.64508 .45644 L

.64257 .45693 L

.64006 .45745 L

.63755 .45799 L

.63504 .45854 L

.63253 .45911 L

.63003 .45968 L

.62752 .46027 L

.62501 .46086 L

.6225 .46146 L

.61999 .46207 L

.61748 .46268 L

.61497 .46329 L

.61247 .46391 L

.60996 .46454 L

.60745 .46516 L

.60494 .46579 L

.60243 .46643 L

.59992 .46707 L

.59742 .46771 L

.59491 .46835 L

.5924 .46899 L

.58989 .46964 L

.58738 .47029 L

.58487 .47094 L

.58236 .47159 L

.57986 .47225 L

.57735 .4729 L

.57484 .47356 L

.57233 .47422 L

.56982 .47488 L

.56731 .47554 L

.56481 .47621 L

.5623 .47687 L

.55979 .47754 L

.55728 .47821 L

.55477 .47888 L

.55226 .47955 L

.54975 .48022 L

.54725 .48089 L

.54474 .48157 L

.54223 .48224 L

Mistroke

.53972 .48292 L

.53721 .48359 L

.5347 .48427 L

.5322 .48495 L

.52969 .48563 L

.52718 .48631 L

.52467 .48699 L

.52216 .48767 L

.51965 .48836 L

.51715 .48904 L

.51464 .48973 L

.51213 .49041 L

.50962 .4911 L

.50711 .49178 L

.5046 .49247 L

.50209 .49316 L

.49959 .49385 L

.49708 .49453 L

.49457 .49522 L

.49206 .49591 L

.48955 .4966 L

.48704 .49729 L

.48454 .49798 L

.48203 .49868 L

.47952 .49937 L

.47701 .50006 L

.4745 .50075 L

.47199 .50144 L

.46948 .50214 L

.46698 .50283 L

.46447 .50352 L

.46196 .50421 L

.45945 .50491 L

.45694 .5056 L

.45443 .50629 L

.45193 .50698 L

.44942 .50767 L

.44691 .50837 L

.4444 .50906 L

.44189 .50975 L

.43938 .51044 L

.43688 .51113 L

.43437 .51182 L

.43186 .51251 L

.42935 .5132 L

.42684 .51389 L

.42433 .51457 L

.42182 .51526 L

.41932 .51595 L

.41681 .51663 L

Mistroke

.4143 .51732 L

.41179 .518 L

.40928 .51868 L

.40677 .51936 L

.40427 .52004 L

.40176 .52072 L

.39925 .5214 L

.39674 .52208 L

.39423 .52275 L

.39172 .52342 L

.38921 .5241 L

.38671 .52476 L

.3842 .52543 L

.38169 .5261 L

.37918 .52676 L

.37667 .52743 L

.37416 .52808 L

.37166 .52874 L

.36915 .5294 L

.36664 .53005 L

.36413 .5307 L

.36162 .53135 L

.35911 .53199 L

.3566 .53264 L

.3541 .53327 L

.35159 .53391 L

.34908 .53454 L

.34657 .53517 L

.34406 .5358 L

.34155 .53642 L

.33905 .53704 L

.33654 .53765 L

.33403 .53826 L

.33152 .53887 L

.32901 .53947 L

.3265 .54007 L

.324 .54066 L

.32149 .54125 L

.31898 .54184 L

.31647 .54241 L

.31396 .54299 L

.31145 .54355 L

.30894 .54412 L

.30644 .54467 L

.30393 .54522 L

.30142 .54577 L

.29891 .5463 L

.2964 .54683 L

.29389 .54736 L

.29139 .54787 L

Mistroke

.28888 .54838 L

.28637 .54888 L

.28386 .54938 L

.28135 .54986 L

.27884 .55034 L

.27633 .55081 L

.27383 .55127 L

.27132 .55172 L

.26881 .55216 L

.2663 .55259 L

.26379 .55301 L

.26128 .55342 L

.25878 .55382 L

.25627 .55421 L

.25376 .55459 L

.25125 .55495 L

.24874 .5553 L

.24623 .55564 L

.24372 .55597 L

.24122 .55628 L

.23871 .55658 L

.2362 .55687 L

.23369 .55714 L

.23118 .5574 L

.22867 .55764 L

.22617 .55786 L

.22366 .55807 L

.22115 .55826 L

.21864 .55843 L

.21613 .55859 L

.21362 .55872 L

.21112 .55884 L

.20861 .55893 L

.2061 .55901 L

.20359 .55906 L

.20108 .55909 L

.19857 .5591 L

.19606 .55908 L

.19356 .55905 L

.19105 .55898 L

.18854 .55889 L

.18603 .55877 L

.18352 .55863 L

.18101 .55845 L

.17851 .55825 L

.176 .55802 L

.17349 .55775 L

.17098 .55745 L

.16847 .55712 L

.16596 .55676 L

Mistroke

.16345 .55635 L

.16095 .55591 L

.15844 .55543 L

.15593 .55492 L

.15342 .55436 L

.15091 .55376 L

.1484 .55311 L

.1459 .55241 L

.14339 .55167 L

.14088 .55088 L

.13837 .55004 L

.13586 .54915 L

.13335 .5482 L

.13084 .54719 L

.12834 .54612 L

.12583 .545 L

.12332 .5438 L

.12081 .54254 L

.1183 .54121 L

.11579 .53981 L

.11329 .53833 L

.11078 .53677 L

.10827 .53513 L

.10576 .53341 L

.10325 .53159 L

.10074 .52968 L

.09824 .52766 L

.09573 .52555 L

.09322 .52332 L

.09071 .52098 L

.0882 .51852 L

.08569 .51593 L

.08318 .5132 L

.08068 .51033 L

.07817 .50731 L

.07566 .50412 L

.07315 .50076 L

.07064 .49722 L

.06813 .49347 L

.06563 .48951 L

.06312 .48531 L

.06061 .48087 L

.0581 .47614 L

.05559 .47111 L

.05308 .46573 L

.05057 .45998 L

.04807 .4538 L

.04556 .44712 L

.04305 .43988 L

.04054 .43195 L

Mistroke

.03803 .4232 L

.03552 .41341 L

.03302 .40224 L

.03051 .38911 L

.028 .37282 L

.02549 .34971 L

.02465 .32936 L

.02381 .30902 L

Mfstroke

.66188 .16272 m

.66063 .16306 L

.65937 .16321 L

.65762 .16326 L

.65511 .16312 L

.6526 .16284 L

.65009 .16248 L

.64758 .16206 L

.64508 .1616 L

.64257 .1611 L

.64006 .16058 L

.63755 .16005 L

.63504 .15949 L

.63253 .15893 L

.63003 .15835 L

.62752 .15777 L

.62501 .15717 L

.6225 .15657 L

.61999 .15597 L

.61748 .15536 L

.61497 .15474 L

.61247 .15412 L

.60996 .1535 L

.60745 .15287 L

.60494 .15224 L

.60243 .1516 L

.59992 .15097 L

.59742 .15033 L

.59491 .14969 L

.5924 .14904 L

.58989 .14839 L

.58738 .14775 L

.58487 .1471 L

.58236 .14644 L

.57986 .14579 L

.57735 .14513 L

.57484 .14447 L

.57233 .14381 L

.56982 .14315 L

.56731 .14249 L

.56481 .14183 L

.5623 .14116 L

.55979 .14049 L

.55728 .13983 L

.55477 .13916 L

.55226 .13849 L

.54975 .13782 L

.54725 .13714 L

.54474 .13647 L

.54223 .13579 L

Mistroke

.53972 .13512 L

.53721 .13444 L

.5347 .13376 L

.5322 .13308 L

.52969 .1324 L

.52718 .13172 L

.52467 .13104 L

.52216 .13036 L

.51965 .12968 L

.51715 .12899 L

.51464 .12831 L

.51213 .12762 L

.50962 .12694 L

.50711 .12625 L

.5046 .12556 L

.50209 .12488 L

.49959 .12419 L

.49708 .1235 L

.49457 .12281 L

.49206 .12212 L

.48955 .12143 L

.48704 .12074 L

.48454 .12005 L

.48203 .11936 L

.47952 .11867 L

.47701 .11797 L

.4745 .11728 L

.47199 .11659 L

.46948 .1159 L

.46698 .11521 L

.46447 .11451 L

.46196 .11382 L

.45945 .11313 L

.45694 .11244 L

.45443 .11174 L

.45193 .11105 L

.44942 .11036 L

.44691 .10967 L

.4444 .10898 L

.44189 .10828 L

.43938 .10759 L

.43688 .1069 L

.43437 .10621 L

.43186 .10552 L

.42935 .10483 L

.42684 .10415 L

.42433 .10346 L

.42182 .10277 L

.41932 .10209 L

.41681 .1014 L

Mistroke

.4143 .10072 L

.41179 .10003 L

.40928 .09935 L

.40677 .09867 L

.40427 .09799 L

.40176 .09731 L

.39925 .09663 L

.39674 .09596 L

.39423 .09528 L

.39172 .09461 L

.38921 .09394 L

.38671 .09327 L

.3842 .0926 L

.38169 .09194 L

.37918 .09127 L

.37667 .09061 L

.37416 .08995 L

.37166 .08929 L

.36915 .08864 L

.36664 .08798 L

.36413 .08733 L

.36162 .08669 L

.35911 .08604 L

.3566 .0854 L

.3541 .08476 L

.35159 .08412 L

.34908 .08349 L

.34657 .08286 L

.34406 .08223 L

.34155 .08161 L

.33905 .08099 L

.33654 .08038 L

.33403 .07977 L

.33152 .07916 L

.32901 .07856 L

.3265 .07796 L

.324 .07737 L

.32149 .07678 L

.31898 .0762 L

.31647 .07562 L

.31396 .07505 L

.31145 .07448 L

.30894 .07392 L

.30644 .07336 L

.30393 .07281 L

.30142 .07227 L

.29891 .07173 L

.2964 .0712 L

.29389 .07068 L

.29139 .07016 L

Mistroke

.28888 .06965 L

.28637 .06915 L

.28386 .06866 L

.28135 .06817 L

.27884 .06769 L

.27633 .06723 L

.27383 .06677 L

.27132 .06632 L

.26881 .06588 L

.2663 .06544 L

.26379 .06502 L

.26128 .06461 L

.25878 .06422 L

.25627 .06383 L

.25376 .06345 L

.25125 .06308 L

.24874 .06273 L

.24623 .06239 L

.24372 .06206 L

.24122 .06175 L

.23871 .06145 L

.2362 .06116 L

.23369 .06089 L

.23118 .06064 L

.22867 .0604 L

.22617 .06017 L

.22366 .05997 L

.22115 .05978 L

.21864 .0596 L

.21613 .05945 L

.21362 .05931 L

.21112 .0592 L

.20861 .0591 L

.2061 .05903 L

.20359 .05898 L

.20108 .05894 L

.19857 .05893 L

.19606 .05895 L

.19356 .05899 L

.19105 .05905 L

.18854 .05914 L

.18603 .05926 L

.18352 .05941 L

.18101 .05958 L

.17851 .05978 L

.176 .06002 L

.17349 .06028 L

.17098 .06058 L

.16847 .06091 L

.16596 .06128 L

Mistroke

.16345 .06168 L

.16095 .06212 L

.15844 .0626 L

.15593 .06312 L

.15342 .06368 L

.15091 .06428 L

.1484 .06493 L

.1459 .06562 L

.14339 .06636 L

.14088 .06715 L

.13837 .06799 L

.13586 .06889 L

.13335 .06984 L

.13084 .07084 L

.12834 .07191 L

.12583 .07304 L

.12332 .07423 L

.12081 .07549 L

.1183 .07682 L

.11579 .07822 L

.11329 .0797 L

.11078 .08126 L

.10827 .0829 L

.10576 .08463 L

.10325 .08645 L

.10074 .08836 L

.09824 .09037 L

.09573 .09249 L

.09322 .09471 L

.09071 .09705 L

.0882 .09951 L

.08569 .10211 L

.08318 .10483 L

.08068 .1077 L

.07817 .11073 L

.07566 .11391 L

.07315 .11727 L

.07064 .12082 L

.06813 .12456 L

.06563 .12852 L

.06312 .13272 L

.06061 .13717 L

.0581 .1419 L

.05559 .14693 L

.05308 .1523 L

.05057 .15805 L

.04807 .16424 L

.04556 .17091 L

.04305 .17816 L

.04054 .18608 L

Mistroke

.03803 .19483 L

.03552 .20463 L

.03302 .2158 L

.03051 .22892 L

.028 .24522 L

.02549 .26832 L

.02465 .28867 L

.02381 .30902 L

Mfstroke

0 .4 1 r

.70026 .4251 m

.69963 .42585 L

.69901 .42662 L

.69838 .42742 L

.69775 .42824 L

.69713 .42911 L

.6965 .43003 L

.69587 .43105 L

.69524 .43224 L

.69499 .43282 L

.69474 .43358 L

.69468 .43385 L

s

.70026 .19293 m

.69963 .19218 L

.69901 .19141 L

.69838 .19062 L

.69775 .18979 L

.69713 .18893 L

.6965 .18801 L

.69587 .18699 L

.69524 .18579 L

.69499 .18521 L

.69474 .18445 L

.69468 .18418 L

s

.70152 .42365 m

.70277 .42224 L

.70402 .42087 L

.70528 .41953 L

.70653 .41822 L

.70779 .41692 L

.70904 .41563 L

.7103 .41436 L

.71155 .4131 L

.7128 .41185 L

.71406 .41061 L

.71531 .40937 L

.71657 .40814 L

.71782 .40691 L

.71907 .40568 L

.72033 .40446 L

.72158 .40324 L

.72284 .40201 L

.72409 .40079 L

.72535 .39956 L

.7266 .39834 L

.72785 .3971 L

.72911 .39587 L

.73036 .39463 L

.73162 .39339 L

.73287 .39214 L

.73413 .39088 L

.73538 .38962 L

.73663 .38835 L

.73789 .38707 L

.73914 .38579 L

.7404 .38449 L

.74165 .38318 L

.74291 .38186 L

.74416 .38053 L

.74541 .37919 L

.74667 .37783 L

.74792 .37646 L

.74918 .37508 L

.75043 .37367 L

.75168 .37225 L

.75294 .37081 L

.75419 .36935 L

.75545 .36787 L

.7567 .36637 L

.75796 .36484 L

.75921 .36328 L

.76046 .3617 L

.76172 .36009 L

.76297 .35845 L

Mistroke

.76423 .35677 L

.76548 .35506 L

.76674 .35331 L

.76799 .35152 L

.76924 .34968 L

.7705 .34779 L

.77175 .34585 L

.77301 .34385 L

.77426 .34179 L

.77551 .33966 L

.77677 .33745 L

.77802 .33515 L

.77928 .33276 L

.78053 .33027 L

.78179 .32764 L

.78304 .32488 L

.78429 .32195 L

.78555 .31883 L

.7868 .31548 L

.78806 .31184 L

.78931 .30783 L

.79057 .30334 L

.79182 .29814 L

.79307 .29186 L

.79433 .28334 L

Mfstroke

.70152 .19439 m

.70277 .19579 L

.70402 .19716 L

.70528 .1985 L

.70653 .19982 L

.70779 .20112 L

.70904 .2024 L

.7103 .20367 L

.71155 .20493 L

.7128 .20618 L

.71406 .20743 L

.71531 .20866 L

.71657 .2099 L

.71782 .21112 L

.71907 .21235 L

.72033 .21357 L

.72158 .2148 L

.72284 .21602 L

.72409 .21724 L

.72535 .21847 L

.7266 .2197 L

.72785 .22093 L

.72911 .22216 L

.73036 .2234 L

.73162 .22465 L

.73287 .22589 L

.73413 .22715 L

.73538 .22841 L

.73663 .22968 L

.73789 .23096 L

.73914 .23225 L

.7404 .23354 L

.74165 .23485 L

.74291 .23617 L

.74416 .2375 L

.74541 .23884 L

.74667 .2402 L

.74792 .24157 L

.74918 .24296 L

.75043 .24436 L

.75168 .24578 L

.75294 .24722 L

.75419 .24868 L

.75545 .25016 L

.7567 .25167 L

.75796 .25319 L

.75921 .25475 L

.76046 .25633 L

.76172 .25794 L

.76297 .25958 L

Mistroke

.76423 .26126 L

.76548 .26297 L

.76674 .26472 L

.76799 .26652 L

.76924 .26835 L

.7705 .27024 L

.77175 .27218 L

.77301 .27418 L

.77426 .27624 L

.77551 .27837 L

.77677 .28058 L

.77802 .28288 L

.77928 .28527 L

.78053 .28777 L

.78179 .29039 L

.78304 .29315 L

.78429 .29608 L

.78555 .2992 L

.7868 .30256 L

.78806 .30619 L

.78931 .31021 L

.79057 .3147 L

.79182 .31989 L

.79307 .32618 L

.79433 .33469 L

Mfstroke

.78555 .41786 m

.78304 .42584 L

.78053 .43308 L

.77802 .43973 L

.77551 .44592 L

.77301 .45171 L

.7705 .45717 L

.76799 .46233 L

.76548 .46723 L

.76297 .47189 L

.76046 .47634 L

.75796 .48058 L

.75545 .48464 L

.75294 .48853 L

.75043 .49226 L

.74792 .49585 L

.74541 .49929 L

.74291 .5026 L

.7404 .50578 L

.73789 .50885 L

.73538 .5118 L

.73287 .51464 L

.73036 .51738 L

.72785 .52003 L

.72535 .52258 L

.72284 .52504 L

.72033 .52741 L

.71782 .5297 L

.71531 .53192 L

.7128 .53406 L

.7103 .53613 L

.70779 .53813 L

.70528 .54006 L

.70277 .54193 L

.70026 .54374 L

.69775 .54549 L

.69524 .54719 L

.69274 .54883 L

.69023 .55043 L

.68772 .55197 L

.68521 .55347 L

.6827 .55492 L

.68019 .55633 L

.67769 .55769 L

.67518 .55902 L

.67267 .56031 L

.67016 .56157 L

.66765 .56279 L

.66514 .56398 L

.66263 .56513 L

Mistroke

.66013 .56626 L

.65762 .56735 L

.65511 .56842 L

.6526 .56946 L

.65009 .57048 L

.64758 .57147 L

.64508 .57244 L

.64257 .57339 L

.64006 .57431 L

.63755 .57522 L

.63504 .5761 L

.63253 .57697 L

.63003 .57781 L

.62752 .57864 L

.62501 .57946 L

.6225 .58025 L

.61999 .58103 L

.61748 .5818 L

.61497 .58255 L

.61247 .58329 L

.60996 .58401 L

.60745 .58472 L

.60494 .58542 L

.60243 .58611 L

.59992 .58678 L

.59742 .58744 L

.59491 .58808 L

.5924 .58872 L

.58989 .58935 L

.58738 .58996 L

.58487 .59056 L

.58236 .59115 L

.57986 .59173 L

.57735 .5923 L

.57484 .59286 L

.57233 .5934 L

.56982 .59394 L

.56731 .59446 L

.56481 .59497 L

.5623 .59547 L

.55979 .59596 L

.55728 .59643 L

.55477 .5969 L

.55226 .59735 L

.54975 .59779 L

.54725 .59821 L

.54474 .59862 L

.54223 .59902 L

.53972 .59941 L

.53721 .59978 L

Mistroke

.5347 .60013 L

.5322 .60047 L

.52969 .60079 L

.52718 .6011 L

.52467 .60139 L

.52216 .60167 L

.51965 .60192 L

.51715 .60216 L

.51464 .60237 L

.51213 .60257 L

.50962 .60275 L

.50711 .6029 L

.5046 .60303 L

.50209 .60314 L

.49959 .60322 L

.49708 .60328 L

.49457 .60331 L

.49206 .60332 L

.48955 .6033 L

.48704 .60324 L

.48454 .60316 L

.48203 .60304 L

.47952 .6029 L

.47701 .60272 L

.4745 .6025 L

.47199 .60224 L

.46948 .60195 L

.46698 .60162 L

.46447 .60124 L

.46196 .60082 L

.45945 .60036 L

.45694 .59985 L

.45443 .59928 L

.45193 .59867 L

.44942 .59801 L

.44691 .59728 L

.4444 .59651 L

.44189 .59567 L

.43938 .59476 L

.43688 .59379 L

.43437 .59275 L

.43186 .59164 L

.42935 .59046 L

.42684 .5892 L

.42433 .58785 L

.42182 .58642 L

.41932 .5849 L

.41681 .58329 L

.4143 .58158 L

.41179 .57977 L

Mistroke

.40928 .57785 L

.40677 .57581 L

.40427 .57366 L

.40176 .57138 L

.39925 .56898 L

.39674 .56643 L

.39423 .56374 L

.39172 .5609 L

.38921 .55789 L

.38671 .55471 L

.3842 .55134 L

.38169 .54779 L

.37918 .54402 L

.37667 .54003 L

.37416 .53581 L

.37166 .53132 L

.36915 .52657 L

.36664 .52151 L

.36413 .51612 L

.36162 .51038 L

.35911 .50424 L

.3566 .49766 L

.3541 .49059 L

.35159 .48296 L

.34908 .47468 L

.34657 .46565 L

.34406 .45572 L

.34155 .44469 L

.33905 .43225 L

.33654 .4179 L

.33403 .40076 L

.33152 .37875 L

.33039 .36581 L

.32964 .35509 L

.32901 .34356 L

.32838 .30902 L

Mfstroke

.78555 .20018 m

.78304 .1922 L

.78053 .18496 L

.77802 .1783 L

.77551 .17211 L

.77301 .16632 L

.7705 .16086 L

.76799 .1557 L

.76548 .1508 L

.76297 .14614 L

.76046 .1417 L

.75796 .13745 L

.75545 .13339 L

.75294 .1295 L

.75043 .12577 L

.74792 .12219 L

.74541 .11875 L

.74291 .11544 L

.7404 .11225 L

.73789 .10919 L

.73538 .10624 L

.73287 .10339 L

.73036 .10065 L

.72785 .09801 L

.72535 .09546 L

.72284 .093 L

.72033 .09062 L

.71782 .08833 L

.71531 .08611 L

.7128 .08398 L

.7103 .08191 L

.70779 .07991 L

.70528 .07797 L

.70277 .0761 L

.70026 .07429 L

.69775 .07254 L

.69524 .07084 L

.69274 .0692 L

.69023 .06761 L

.68772 .06606 L

.68521 .06457 L

.6827 .06312 L

.68019 .06171 L

.67769 .06034 L

.67518 .05901 L

.67267 .05772 L

.67016 .05647 L

.66765 .05525 L

.66514 .05406 L

.66263 .0529 L

Mistroke

.66013 .05178 L

.65762 .05068 L

.65511 .04961 L

.6526 .04857 L

.65009 .04755 L

.64758 .04656 L

.64508 .04559 L

.64257 .04465 L

.64006 .04372 L

.63755 .04282 L

.63504 .04193 L

.63253 .04107 L

.63003 .04022 L

.62752 .03939 L

.62501 .03858 L

.6225 .03778 L

.61999 .037 L

.61748 .03623 L

.61497 .03548 L

.61247 .03474 L

.60996 .03402 L

.60745 .03331 L

.60494 .03261 L

.60243 .03193 L

.59992 .03126 L

.59742 .0306 L

.59491 .02995 L

.5924 .02931 L

.58989 .02869 L

.58738 .02808 L

.58487 .02747 L

.58236 .02688 L

.57986 .0263 L

.57735 .02573 L

.57484 .02518 L

.57233 .02463 L

.56982 .0241 L

.56731 .02358 L

.56481 .02306 L

.5623 .02257 L

.55979 .02208 L

.55728 .0216 L

.55477 .02114 L

.55226 .02068 L

.54975 .02025 L

.54725 .01982 L

.54474 .01941 L

.54223 .01901 L

.53972 .01863 L

.53721 .01826 L

Mistroke

.5347 .0179 L

.5322 .01756 L

.52969 .01724 L

.52718 .01693 L

.52467 .01664 L

.52216 .01637 L

.51965 .01611 L

.51715 .01588 L

.51464 .01566 L

.51213 .01546 L

.50962 .01529 L

.50711 .01513 L

.5046 .015 L

.50209 .0149 L

.49959 .01481 L

.49708 .01475 L

.49457 .01472 L

.49206 .01472 L

.48955 .01474 L

.48704 .01479 L

.48454 .01487 L

.48203 .01499 L

.47952 .01514 L

.47701 .01532 L

.4745 .01553 L

.47199 .01579 L

.46948 .01608 L

.46698 .01642 L

.46447 .01679 L

.46196 .01721 L

.45945 .01768 L

.45694 .01819 L

.45443 .01875 L

.45193 .01936 L

.44942 .02003 L

.44691 .02075 L

.4444 .02153 L

.44189 .02237 L

.43938 .02327 L

.43688 .02424 L

.43437 .02528 L

.43186 .02639 L

.42935 .02757 L

.42684 .02884 L

.42433 .03018 L

.42182 .03161 L

.41932 .03313 L

.41681 .03474 L

.4143 .03645 L

.41179 .03827 L

Mistroke

.40928 .04019 L

.40677 .04222 L

.40427 .04437 L

.40176 .04665 L

.39925 .04906 L

.39674 .0516 L

.39423 .05429 L

.39172 .05714 L

.38921 .06015 L

.38671 .06333 L

.3842 .06669 L

.38169 .07025 L

.37918 .07401 L

.37667 .078 L

.37416 .08223 L

.37166 .08671 L

.36915 .09147 L

.36664 .09653 L

.36413 .10191 L

.36162 .10766 L

.35911 .11379 L

.3566 .12037 L

.3541 .12745 L

.35159 .13508 L

.34908 .14335 L

.34657 .15238 L

.34406 .16231 L

.34155 .17334 L

.33905 .18578 L

.33654 .20013 L

.33403 .21728 L

.33152 .23929 L

.33039 .25222 L

.32964 .26294 L

.32901 .27448 L

.32838 .30902 L

Mfstroke

1 0 0 r

.70152 .50669 m

.70277 .50701 L

.70402 .50732 L

.70528 .50762 L

.70653 .50791 L

.70779 .50818 L

.70904 .50844 L

.7103 .50869 L

.71155 .50893 L

.7128 .50916 L

.71406 .50938 L

.71531 .50959 L

.71657 .50979 L

.71782 .50998 L

.71907 .51016 L

.72033 .51034 L

.72158 .5105 L

.72284 .51066 L

.72409 .51081 L

.72535 .51095 L

.7266 .51108 L

.72785 .51121 L

.72911 .51133 L

.73036 .51144 L

.73162 .51155 L

.73287 .51165 L

.73413 .51175 L

.73538 .51183 L

.73663 .51191 L

.73789 .51199 L

.73914 .51206 L

.7404 .51213 L

.74165 .51219 L

.74291 .51224 L

.74416 .51229 L

.74541 .51233 L

.74667 .51237 L

.74792 .5124 L

.74918 .51243 L

.75043 .51246 L

.75168 .51248 L

.75294 .51249 L

.75419 .5125 L

.75545 .51251 L

.7567 .51252 L

.75796 .51251 L

.75921 .51251 L

.76046 .5125 L

.76172 .51249 L

.76297 .51247 L

Mistroke

.76423 .51245 L

.76548 .51243 L

.76674 .5124 L

.76799 .51237 L

.76924 .51234 L

.7705 .5123 L

.77175 .51226 L

.77301 .51222 L

.77426 .51217 L

.77551 .51212 L

.77677 .51207 L

.77802 .51201 L

.77928 .51196 L

.78053 .5119 L

.78179 .51183 L

.78304 .51177 L

.78429 .5117 L

.78555 .51163 L

.7868 .51155 L

.78806 .51148 L

.78931 .5114 L

.79057 .51132 L

.79182 .51124 L

.79307 .51115 L

.79433 .51106 L

.79558 .51098 L

.79684 .51088 L

.79809 .51079 L

.79935 .51069 L

.8006 .5106 L

.80185 .5105 L

.80311 .51039 L

.80436 .51029 L

.80562 .51019 L

.80687 .51008 L

.80812 .50997 L

.80938 .50986 L

.81063 .50975 L

.81189 .50963 L

.81314 .50952 L

.8144 .5094 L

.81565 .50928 L

.8169 .50916 L

.81816 .50904 L

.81941 .50892 L

.82067 .50879 L

.82192 .50867 L

.82318 .50854 L

.82443 .50841 L

.82568 .50828 L

Mistroke

.82694 .50815 L

.82819 .50802 L

.82945 .50789 L

.8307 .50775 L

.83195 .50762 L

.83321 .50748 L

.83446 .50734 L

.83572 .5072 L

.83697 .50706 L

.83823 .50692 L

.83948 .50678 L

.84073 .50663 L

.84199 .50649 L

.84324 .50634 L

.8445 .5062 L

.84575 .50605 L

.84701 .5059 L

.84826 .50575 L

.84951 .5056 L

.85077 .50545 L

.85202 .5053 L

.85328 .50515 L

.85453 .50499 L

.85579 .50484 L

.85704 .50469 L

.85829 .50453 L

.85955 .50437 L

.8608 .50422 L

.86206 .50406 L

.86331 .5039 L

.86456 .50374 L

.86582 .50358 L

.86707 .50342 L

.86833 .50326 L

.86958 .5031 L

.87084 .50294 L

.87209 .50277 L

.87334 .50261 L

.8746 .50245 L

.87585 .50228 L

.87711 .50212 L

.87836 .50195 L

.87962 .50179 L

.88087 .50162 L

.88212 .50145 L

.88338 .50129 L

.88463 .50112 L

.88589 .50095 L

.88714 .50078 L

.88839 .50061 L

Mistroke

.88965 .50044 L

.8909 .50027 L

.89216 .5001 L

.89341 .49993 L

.89467 .49976 L

.89592 .49959 L

.89717 .49942 L

.89843 .49925 L

.89968 .49908 L

.90094 .4989 L

.90219 .49873 L

.90345 .49856 L

.9047 .49838 L

.90595 .49821 L

.90721 .49804 L

.90846 .49786 L

.90972 .49769 L

.91097 .49751 L

.91223 .49734 L

.91348 .49716 L

.91473 .49699 L

.91599 .49681 L

.91724 .49664 L

.9185 .49646 L

.91975 .49628 L

.921 .49611 L

.92226 .49593 L

.92351 .49575 L

.92477 .49558 L

.92602 .4954 L

.92728 .49522 L

.92853 .49505 L

.92978 .49487 L

.93104 .49469 L

.93229 .49451 L

.93355 .49434 L

.9348 .49416 L

.93606 .49398 L

.93731 .4938 L

.93856 .49362 L

.93982 .49345 L

.94107 .49327 L

.94233 .49309 L

.94358 .49291 L

.94483 .49273 L

.94609 .49255 L

.94734 .49237 L

.9486 .49219 L

.94985 .49202 L

.95111 .49184 L

Mistroke

.95236 .49166 L

.95361 .49148 L

.95487 .4913 L

.95612 .49112 L

.95738 .49094 L

.95863 .49076 L

.95989 .49058 L

.96114 .4904 L

.96239 .49022 L

.96365 .49004 L

.9649 .48987 L

.96616 .48969 L

.96741 .48951 L

.96867 .48933 L

.96992 .48915 L

.97117 .48897 L

.97243 .48879 L

.97368 .48861 L

.97494 .48843 L

.97619 .48825 L

Mfstroke

.70152 .11135 m

.70277 .11102 L

.70402 .11071 L

.70528 .11041 L

.70653 .11013 L

.70779 .10985 L

.70904 .10959 L

.7103 .10934 L

.71155 .1091 L

.7128 .10887 L

.71406 .10865 L

.71531 .10844 L

.71657 .10824 L

.71782 .10805 L

.71907 .10787 L

.72033 .1077 L

.72158 .10753 L

.72284 .10737 L

.72409 .10723 L

.72535 .10708 L

.7266 .10695 L

.72785 .10682 L

.72911 .1067 L

.73036 .10659 L

.73162 .10648 L

.73287 .10638 L

.73413 .10629 L

.73538 .1062 L

.73663 .10612 L

.73789 .10604 L

.73914 .10597 L

.7404 .10591 L

.74165 .10585 L

.74291 .1058 L

.74416 .10575 L

.74541 .1057 L

.74667 .10566 L

.74792 .10563 L

.74918 .1056 L

.75043 .10558 L

.75168 .10556 L

.75294 .10554 L

.75419 .10553 L

.75545 .10552 L

.7567 .10552 L

.75796 .10552 L

.75921 .10552 L

.76046 .10553 L

.76172 .10555 L

.76297 .10556 L

Mistroke

.76423 .10558 L

.76548 .10561 L

.76674 .10563 L

.76799 .10566 L

.76924 .1057 L

.7705 .10573 L

.77175 .10577 L

.77301 .10582 L

.77426 .10586 L

.77551 .10591 L

.77677 .10596 L

.77802 .10602 L

.77928 .10608 L

.78053 .10614 L

.78179 .1062 L

.78304 .10627 L

.78429 .10633 L

.78555 .10641 L

.7868 .10648 L

.78806 .10656 L

.78931 .10663 L

.79057 .10671 L

.79182 .1068 L

.79307 .10688 L

.79433 .10697 L

.79558 .10706 L

.79684 .10715 L

.79809 .10724 L

.79935 .10734 L

.8006 .10744 L

.80185 .10754 L

.80311 .10764 L

.80436 .10774 L

.80562 .10785 L

.80687 .10795 L

.80812 .10806 L

.80938 .10817 L

.81063 .10829 L

.81189 .1084 L

.81314 .10852 L

.8144 .10863 L

.81565 .10875 L

.8169 .10887 L

.81816 .10899 L

.81941 .10911 L

.82067 .10924 L

.82192 .10937 L

.82318 .10949 L

.82443 .10962 L

.82568 .10975 L

Mistroke

.82694 .10988 L

.82819 .11001 L

.82945 .11015 L

.8307 .11028 L

.83195 .11042 L

.83321 .11056 L

.83446 .11069 L

.83572 .11083 L

.83697 .11097 L

.83823 .11111 L

.83948 .11126 L

.84073 .1114 L

.84199 .11154 L

.84324 .11169 L

.8445 .11184 L

.84575 .11198 L

.84701 .11213 L

.84826 .11228 L

.84951 .11243 L

.85077 .11258 L

.85202 .11273 L

.85328 .11289 L

.85453 .11304 L

.85579 .11319 L

.85704 .11335 L

.85829 .1135 L

.85955 .11366 L

.8608 .11382 L

.86206 .11397 L

.86331 .11413 L

.86456 .11429 L

.86582 .11445 L

.86707 .11461 L

.86833 .11477 L

.86958 .11493 L

.87084 .1151 L

.87209 .11526 L

.87334 .11542 L

.8746 .11559 L

.87585 .11575 L

.87711 .11592 L

.87836 .11608 L

.87962 .11625 L

.88087 .11641 L

.88212 .11658 L

.88338 .11675 L

.88463 .11691 L

.88589 .11708 L

.88714 .11725 L

.88839 .11742 L

Mistroke

.88965 .11759 L

.8909 .11776 L

.89216 .11793 L

.89341 .1181 L

.89467 .11827 L

.89592 .11844 L

.89717 .11861 L

.89843 .11879 L

.89968 .11896 L

.90094 .11913 L

.90219 .1193 L

.90345 .11948 L

.9047 .11965 L

.90595 .11982 L

.90721 .12 L

.90846 .12017 L

.90972 .12035 L

.91097 .12052 L

.91223 .1207 L

.91348 .12087 L

.91473 .12105 L

.91599 .12122 L

.91724 .1214 L

.9185 .12157 L

.91975 .12175 L

.921 .12193 L

.92226 .1221 L

.92351 .12228 L

.92477 .12246 L

.92602 .12263 L

.92728 .12281 L

.92853 .12299 L

.92978 .12317 L

.93104 .12334 L

.93229 .12352 L

.93355 .1237 L

.9348 .12388 L

.93606 .12405 L

.93731 .12423 L

.93856 .12441 L

.93982 .12459 L

.94107 .12477 L

.94233 .12495 L

.94358 .12512 L

.94483 .1253 L

.94609 .12548 L

.94734 .12566 L

.9486 .12584 L

.94985 .12602 L

.95111 .1262 L

Mistroke

.95236 .12638 L

.95361 .12656 L

.95487 .12673 L

.95612 .12691 L

.95738 .12709 L

.95863 .12727 L

.95989 .12745 L

.96114 .12763 L

.96239 .12781 L

.96365 .12799 L

.9649 .12817 L

.96616 .12835 L

.96741 .12853 L

.96867 .12871 L

.96992 .12889 L

.97117 .12906 L

.97243 .12924 L

.97368 .12942 L

.97494 .1296 L

.97619 .12978 L

Mfstroke

0 .4 1 r

.73852 .43004 m

.73839 .43007 L

.73826 .4301 L

.73814 .43013 L

.73801 .43016 L

.73789 .43019 L

.73776 .43021 L

.73764 .43024 L

.73751 .43027 L

.73739 .4303 L

.73726 .43033 L

.73714 .43035 L

.73701 .43038 L

.73688 .43041 L

.73676 .43044 L

.73663 .43047 L

.73651 .43049 L

.73638 .43052 L

.73626 .43055 L

.73613 .43058 L

.73601 .43061 L

.73588 .43063 L

.73576 .43066 L

.73563 .43069 L

.73551 .43072 L

.73538 .43075 L

.73525 .43077 L

.73513 .4308 L

.735 .43083 L

.73488 .43086 L

.73475 .43089 L

.73463 .43091 L

.7345 .43094 L

.73438 .43097 L

.73425 .431 L

.73413 .43102 L

.734 .43105 L

.73387 .43108 L

.73375 .43111 L

.73362 .43114 L

.7335 .43116 L

.73337 .43119 L

.73325 .43122 L

.73312 .43125 L

.733 .43127 L

.73287 .4313 L

.73275 .43133 L

.73262 .43136 L

.7325 .43138 L

.73237 .43141 L

Mistroke

.73224 .43144 L

.73212 .43147 L

.73199 .4315 L

.73187 .43152 L

.73174 .43155 L

.73162 .43158 L

.73149 .43161 L

.73137 .43163 L

.73124 .43166 L

.73112 .43169 L

.73099 .43172 L

.73086 .43174 L

.73074 .43177 L

.73061 .4318 L

.73049 .43183 L

.73036 .43185 L

.73024 .43188 L

.73011 .43191 L

.72999 .43194 L

.72986 .43196 L

.72974 .43199 L

.72961 .43202 L

.72949 .43205 L

.72936 .43207 L

.72923 .4321 L

.72911 .43213 L

.72898 .43216 L

.72886 .43218 L

.72873 .43221 L

.72861 .43224 L

.72848 .43227 L

.72836 .43229 L

.72823 .43232 L

.72811 .43235 L

.72798 .43237 L

.72785 .4324 L

.72773 .43243 L

.7276 .43246 L

.72748 .43248 L

.72735 .43251 L

.72723 .43254 L

.7271 .43256 L

.72698 .43259 L

.72685 .43262 L

.72673 .43265 L

.7266 .43267 L

.72647 .4327 L

.72635 .43273 L

.72622 .43275 L

.7261 .43278 L

Mistroke

.72597 .43281 L

.72585 .43283 L

.72572 .43286 L

.7256 .43289 L

.72547 .43291 L

.72535 .43294 L

.72522 .43297 L

.7251 .433 L

.72497 .43302 L

.72484 .43305 L

.72472 .43308 L

.72459 .4331 L

.72447 .43313 L

.72434 .43316 L

.72422 .43318 L

.72409 .43321 L

.72397 .43324 L

.72384 .43326 L

.72372 .43329 L

.72359 .43332 L

.72346 .43334 L

.72334 .43337 L

.72321 .43339 L

.72309 .43342 L

.72296 .43345 L

.72284 .43347 L

.72271 .4335 L

.72259 .43353 L

.72246 .43355 L

.72234 .43358 L

.72221 .4336 L

.72209 .43363 L

.72196 .43366 L

.72183 .43368 L

.72171 .43371 L

.72158 .43374 L

.72146 .43376 L

.72133 .43379 L

.72121 .43382 L

.72108 .43384 L

.72096 .43387 L

.72083 .43389 L

.72071 .43392 L

.72058 .43395 L

.72045 .43397 L

.72033 .434 L

.7202 .43402 L

.72008 .43405 L

.71995 .43407 L

.71983 .4341 L

Mistroke

.7197 .43412 L

.71958 .43415 L

.71945 .43418 L

.71933 .4342 L

.7192 .43423 L

.71907 .43425 L

.71895 .43428 L

.71882 .4343 L

.7187 .43433 L

.71857 .43436 L

.71845 .43438 L

.71832 .43441 L

.7182 .43443 L

.71807 .43446 L

.71795 .43448 L

.71782 .43451 L

.7177 .43453 L

.71757 .43456 L

.71744 .43458 L

.71732 .43461 L

.71719 .43463 L

.71707 .43466 L

.71694 .43468 L

.71682 .43471 L

.71669 .43473 L

.71657 .43476 L

.71644 .43478 L

.71632 .43481 L

.71619 .43483 L

.71606 .43486 L

.71594 .43488 L

.71581 .4349 L

.71569 .43493 L

.71556 .43495 L

.71544 .43498 L

.71531 .435 L

.71519 .43503 L

.71506 .43505 L

.71494 .43507 L

.71481 .4351 L

.71469 .43512 L

.71456 .43515 L

.71443 .43517 L

.71431 .43519 L

.71418 .43522 L

.71406 .43524 L

.71393 .43527 L

.71381 .43529 L

.71368 .43531 L

.71356 .43534 L

Mistroke

.71343 .43536 L

.71331 .43538 L

.71318 .4354 L

.71305 .43543 L

.71293 .43545 L

.7128 .43548 L

.71268 .4355 L

.71255 .43552 L

.71243 .43555 L

.7123 .43557 L

.71218 .43559 L

.71205 .43561 L

.71193 .43564 L

.7118 .43566 L

.71168 .43568 L

.71155 .4357 L

.71142 .43573 L

.7113 .43575 L

.71117 .43577 L

.71105 .43579 L

.71092 .43582 L

.7108 .43584 L

.71067 .43586 L

.71055 .43588 L

.71042 .4359 L

.7103 .43592 L

.71017 .43595 L

.71004 .43597 L

.70992 .43599 L

.70979 .43601 L

.70967 .43603 L

.70954 .43605 L

.70942 .43607 L

.70929 .43609 L

.70917 .43611 L

.70904 .43613 L

.70892 .43615 L

.70879 .43617 L

.70866 .43619 L

.70854 .43621 L

.70841 .43623 L

.70829 .43625 L

.70816 .43627 L

.70804 .43629 L

.70791 .43631 L

.70779 .43633 L

.70766 .43635 L

.70754 .43637 L

.70741 .43639 L

.70729 .43641 L

Mistroke

.70716 .43643 L

.70703 .43645 L

.70691 .43647 L

.70678 .43649 L

.70666 .43651 L

.70653 .43652 L

.70641 .43654 L

.70628 .43656 L

.70616 .43658 L

.70603 .4366 L

.70591 .43661 L

.70578 .43663 L

.70565 .43665 L

.70553 .43666 L

.7054 .43668 L

.70528 .4367 L

.70515 .43671 L

.70503 .43673 L

.7049 .43674 L

.70478 .43676 L

.70465 .43678 L

.70453 .43679 L

.7044 .43681 L

.70428 .43682 L

.70415 .43684 L

.70402 .43685 L

.7039 .43686 L

.70377 .43688 L

.70365 .43689 L

.70352 .43691 L

.7034 .43692 L

.70327 .43693 L

.70315 .43694 L

.70302 .43696 L

.7029 .43697 L

.70277 .43698 L

.70264 .43699 L

.70252 .437 L

.70239 .43701 L

.70227 .43702 L

.70214 .43703 L

.70202 .43704 L

.70189 .43705 L

.70177 .43706 L

.70164 .43707 L

.70152 .43708 L

.70139 .43709 L

.70127 .4371 L

.70114 .4371 L

.70101 .43711 L

Mistroke

.70089 .43712 L

.70076 .43712 L

.70064 .43713 L

.70051 .43713 L

.70039 .43713 L

.70026 .43714 L

.70014 .43714 L

.70001 .43714 L

.69989 .43714 L

.69976 .43715 L

.69963 .43715 L

.69951 .43715 L

.69938 .43714 L

.69926 .43714 L

.69913 .43714 L

.69901 .43714 L

.69888 .43713 L

.69876 .43713 L

.69863 .43712 L

.69851 .43711 L

.69838 .4371 L

.69825 .4371 L

.69813 .43708 L

.698 .43707 L

.69788 .43706 L

.69775 .43704 L

.69763 .43703 L

.6975 .437 L

.69738 .43698 L

.69725 .43696 L

.69713 .43694 L

.697 .43691 L

.69688 .43688 L

.69675 .43685 L

.69662 .43682 L

.6965 .43678 L

.69637 .43674 L

.69625 .4367 L

.69612 .43666 L

.696 .43659 L

.69587 .43655 L

.69575 .43649 L

.69562 .43641 L

.6955 .43633 L

.69537 .43624 L

.69524 .43613 L

.69512 .43601 L

.69499 .43586 L

.69487 .43567 L

.69474 .43541 L

Mistroke

.69462 .43489 L

Mfstroke

.73852 .18799 m

.73839 .18796 L

.73826 .18793 L

.73814 .18791 L

.73801 .18788 L

.73789 .18785 L

.73776 .18782 L

.73764 .18779 L

.73751 .18776 L

.73739 .18774 L

.73726 .18771 L

.73714 .18768 L

.73701 .18765 L

.73688 .18762 L

.73676 .1876 L

.73663 .18757 L

.73651 .18754 L

.73638 .18751 L

.73626 .18748 L

.73613 .18746 L

.73601 .18743 L

.73588 .1874 L

.73576 .18737 L

.73563 .18734 L

.73551 .18732 L

.73538 .18729 L

.73525 .18726 L

.73513 .18723 L

.735 .1872 L

.73488 .18718 L

.73475 .18715 L

.73463 .18712 L

.7345 .18709 L

.73438 .18707 L

.73425 .18704 L

.73413 .18701 L

.734 .18698 L

.73387 .18695 L

.73375 .18693 L

.73362 .1869 L

.7335 .18687 L

.73337 .18684 L

.73325 .18681 L

.73312 .18679 L

.733 .18676 L

.73287 .18673 L

.73275 .1867 L

.73262 .18668 L

.7325 .18665 L

.73237 .18662 L

Mistroke

.73224 .18659 L

.73212 .18657 L

.73199 .18654 L

.73187 .18651 L

.73174 .18648 L

.73162 .18646 L

.73149 .18643 L

.73137 .1864 L

.73124 .18637 L

.73112 .18635 L

.73099 .18632 L

.73086 .18629 L

.73074 .18626 L

.73061 .18623 L

.73049 .18621 L

.73036 .18618 L

.73024 .18615 L

.73011 .18612 L

.72999 .1861 L

.72986 .18607 L

.72974 .18604 L

.72961 .18601 L

.72949 .18599 L

.72936 .18596 L

.72923 .18593 L

.72911 .1859 L

.72898 .18588 L

.72886 .18585 L

.72873 .18582 L

.72861 .1858 L

.72848 .18577 L

.72836 .18574 L

.72823 .18571 L

.72811 .18569 L

.72798 .18566 L

.72785 .18563 L

.72773 .1856 L

.7276 .18558 L

.72748 .18555 L

.72735 .18552 L

.72723 .1855 L

.7271 .18547 L

.72698 .18544 L

.72685 .18541 L

.72673 .18539 L

.7266 .18536 L

.72647 .18533 L

.72635 .18531 L

.72622 .18528 L

.7261 .18525 L

Mistroke

.72597 .18523 L

.72585 .1852 L

.72572 .18517 L

.7256 .18515 L

.72547 .18512 L

.72535 .18509 L

.72522 .18506 L

.7251 .18504 L

.72497 .18501 L

.72484 .18498 L

.72472 .18496 L

.72459 .18493 L

.72447 .1849 L

.72434 .18488 L

.72422 .18485 L

.72409 .18482 L

.72397 .1848 L

.72384 .18477 L

.72372 .18474 L

.72359 .18472 L

.72346 .18469 L

.72334 .18467 L

.72321 .18464 L

.72309 .18461 L

.72296 .18459 L

.72284 .18456 L

.72271 .18453 L

.72259 .18451 L

.72246 .18448 L

.72234 .18445 L

.72221 .18443 L

.72209 .1844 L

.72196 .18438 L

.72183 .18435 L

.72171 .18432 L

.72158 .1843 L

.72146 .18427 L

.72133 .18424 L

.72121 .18422 L

.72108 .18419 L

.72096 .18417 L

.72083 .18414 L

.72071 .18411 L

.72058 .18409 L

.72045 .18406 L

.72033 .18404 L

.7202 .18401 L

.72008 .18399 L

.71995 .18396 L

.71983 .18394 L

Mistroke

.7197 .18391 L

.71958 .18388 L

.71945 .18386 L

.71933 .18383 L

.7192 .18381 L

.71907 .18378 L

.71895 .18375 L

.71882 .18373 L

.7187 .1837 L

.71857 .18368 L

.71845 .18365 L

.71832 .18363 L

.7182 .1836 L

.71807 .18358 L

.71795 .18355 L

.71782 .18353 L

.7177 .1835 L

.71757 .18348 L

.71744 .18345 L

.71732 .18343 L

.71719 .1834 L

.71707 .18338 L

.71694 .18335 L

.71682 .18333 L

.71669 .1833 L

.71657 .18328 L

.71644 .18325 L

.71632 .18323 L

.71619 .1832 L

.71606 .18318 L

.71594 .18315 L

.71581 .18313 L

.71569 .18311 L

.71556 .18308 L

.71544 .18306 L

.71531 .18303 L

.71519 .18301 L

.71506 .18298 L

.71494 .18296 L

.71481 .18294 L

.71469 .18291 L

.71456 .18289 L

.71443 .18286 L

.71431 .18284 L

.71418 .18282 L

.71406 .18279 L

.71393 .18277 L

.71381 .18275 L

.71368 .18272 L

.71356 .1827 L

Mistroke

.71343 .18268 L

.71331 .18265 L

.71318 .18263 L

.71305 .18261 L

.71293 .18258 L

.7128 .18256 L

.71268 .18254 L

.71255 .18251 L

.71243 .18249 L

.7123 .18247 L

.71218 .18244 L

.71205 .18242 L

.71193 .1824 L

.7118 .18237 L

.71168 .18235 L

.71155 .18233 L

.71142 .18231 L

.7113 .18229 L

.71117 .18226 L

.71105 .18224 L

.71092 .18222 L

.7108 .1822 L

.71067 .18217 L

.71055 .18215 L

.71042 .18213 L

.7103 .18211 L

.71017 .18209 L

.71004 .18207 L

.70992 .18205 L

.70979 .18202 L

.70967 .182 L

.70954 .18198 L

.70942 .18196 L

.70929 .18194 L

.70917 .18192 L

.70904 .1819 L

.70892 .18188 L

.70879 .18186 L

.70866 .18184 L

.70854 .18182 L

.70841 .1818 L

.70829 .18178 L

.70816 .18176 L

.70804 .18174 L

.70791 .18172 L

.70779 .1817 L

.70766 .18168 L

.70754 .18166 L

.70741 .18164 L

.70729 .18162 L

Mistroke

.70716 .1816 L

.70703 .18158 L

.70691 .18157 L

.70678 .18155 L

.70666 .18153 L

.70653 .18151 L

.70641 .18149 L

.70628 .18147 L

.70616 .18146 L

.70603 .18144 L

.70591 .18142 L

.70578 .1814 L

.70565 .18139 L

.70553 .18137 L

.7054 .18135 L

.70528 .18134 L

.70515 .18132 L

.70503 .18131 L

.7049 .18129 L

.70478 .18127 L

.70465 .18126 L

.70453 .18124 L

.7044 .18123 L

.70428 .18121 L

.70415 .1812 L

.70402 .18118 L

.7039 .18117 L

.70377 .18116 L

.70365 .18114 L

.70352 .18113 L

.7034 .18111 L

.70327 .1811 L

.70315 .18109 L

.70302 .18108 L

.7029 .18106 L

.70277 .18105 L

.70264 .18104 L

.70252 .18103 L

.70239 .18102 L

.70227 .18101 L

.70214 .181 L

.70202 .18099 L

.70189 .18098 L

.70177 .18097 L

.70164 .18096 L

.70152 .18095 L

.70139 .18095 L

.70127 .18094 L

.70114 .18093 L

.70101 .18093 L

Mistroke

.70089 .18092 L

.70076 .18091 L

.70064 .18091 L

.70051 .1809 L

.70039 .1809 L

.70026 .1809 L

.70014 .18089 L

.70001 .18089 L

.69989 .18089 L

.69976 .18089 L

.69963 .18089 L

.69951 .18089 L

.69938 .18089 L

.69926 .18089 L

.69913 .18089 L

.69901 .1809 L

.69888 .1809 L

.69876 .18091 L

.69863 .18091 L

.69851 .18092 L

.69838 .18093 L

.69825 .18094 L

.69813 .18095 L

.698 .18096 L

.69788 .18097 L

.69775 .18099 L

.69763 .18101 L

.6975 .18103 L

.69738 .18105 L

.69725 .18107 L

.69713 .1811 L

.697 .18112 L

.69688 .18115 L

.69675 .18118 L

.69662 .18122 L

.6965 .18125 L

.69637 .18129 L

.69625 .18134 L

.69612 .18137 L

.696 .18144 L

.69587 .18148 L

.69575 .18155 L

.69562 .18162 L

.6955 .1817 L

.69537 .1818 L

.69524 .1819 L

.69512 .18203 L

.69499 .18217 L

.69487 .18236 L

.69474 .18263 L

Mistroke

.69462 .18314 L

Mfstroke

.78806 .40884 m

.78818 .40835 L

.78831 .40786 L

.78843 .40736 L

.78856 .40687 L

.78868 .40637 L

.78881 .40586 L

.78894 .40535 L

.78906 .40484 L

.78919 .40431 L

.78931 .40379 L

.78944 .40325 L

.78956 .40272 L

.78969 .40218 L

.78981 .40163 L

.78994 .40108 L

.79006 .40053 L

.79019 .39996 L

.79031 .39939 L

.79044 .39881 L

.79057 .39823 L

.79069 .39764 L

.79082 .39704 L

.79094 .39644 L

.79107 .39583 L

.79119 .39521 L

.79132 .39457 L

.79144 .39394 L

.79157 .39328 L

.79169 .39263 L

.79182 .39196 L

.79195 .39128 L

.79207 .3906 L

.7922 .38988 L

.79232 .38918 L

.79245 .38843 L

.79257 .38769 L

.7927 .38694 L

.79282 .38617 L

.79295 .38538 L

.79307 .38457 L

.7932 .38373 L

.79332 .38288 L

.79345 .38199 L

.79358 .38109 L

.7937 .38016 L

.79383 .3792 L

.79395 .3782 L

.79408 .37715 L

.7942 .37605 L

Mistroke

.79433 .37493 L

.79445 .37373 L

.79458 .37246 L

.7947 .37109 L

.79483 .36961 L

.79496 .36796 L

.79508 .36612 L

.79521 .36394 L

.79533 .36114 L

.79539 .3592 L

Mfstroke

.78806 .2092 m

.78818 .20969 L

.78831 .21018 L

.78843 .21067 L

.78856 .21117 L

.78868 .21167 L

.78881 .21217 L

.78894 .21268 L

.78906 .2132 L

.78919 .21372 L

.78931 .21425 L

.78944 .21478 L

.78956 .21531 L

.78969 .21585 L

.78981 .2164 L

.78994 .21695 L

.79006 .21751 L

.79019 .21807 L

.79031 .21864 L

.79044 .21922 L

.79057 .2198 L

.79069 .2204 L

.79082 .221 L

.79094 .2216 L

.79107 .22221 L

.79119 .22283 L

.79132 .22346 L

.79144 .2241 L

.79157 .22475 L

.79169 .22541 L

.79182 .22607 L

.79195 .22675 L

.79207 .22744 L

.7922 .22815 L

.79232 .22886 L

.79245 .2296 L

.79257 .23034 L

.7927 .23109 L

.79282 .23186 L

.79295 .23265 L

.79307 .23347 L

.7932 .23431 L

.79332 .23515 L

.79345 .23605 L

.79358 .23695 L

.7937 .23787 L

.79383 .23883 L

.79395 .23983 L

.79408 .24088 L

.7942 .24198 L

Mistroke

.79433 .2431 L

.79445 .2443 L

.79458 .24558 L

.7947 .24694 L

.79483 .24842 L

.79496 .25007 L

.79508 .25191 L

.79521 .25409 L

.79533 .25689 L

.79539 .25884 L

Mfstroke

.73789 .43019 m

.73914 .4299 L

.7404 .42962 L

.74165 .42934 L

.74291 .42906 L

.74416 .42877 L

.74541 .42849 L

.74667 .4282 L

.74792 .42792 L

.74918 .42763 L

.75043 .42734 L

.75168 .42706 L

.75294 .42677 L

.75419 .42648 L

.75545 .4262 L

.7567 .42591 L

.75796 .42562 L

.75921 .42533 L

.76046 .42505 L

.76172 .42476 L

.76297 .42447 L

.76423 .42418 L

.76548 .42389 L

.76674 .4236 L

.76799 .42332 L

.76924 .42303 L

.7705 .42274 L

.77175 .42245 L

.77301 .42216 L

.77426 .42187 L

.77551 .42158 L

.77677 .42129 L

.77802 .42101 L

.77928 .42072 L

.78053 .42043 L

.78179 .42014 L

.78304 .41985 L

.78429 .41956 L

.78555 .41927 L

.7868 .41899 L

.78806 .4187 L

.78931 .41841 L

.79057 .41812 L

.79182 .41783 L

.79307 .41755 L

.79433 .41726 L

.79558 .41697 L

.79684 .41668 L

.79809 .41639 L

.79935 .41611 L

Mistroke

.8006 .41582 L

.80185 .41553 L

.80311 .41525 L

.80436 .41496 L

.80562 .41467 L

.80687 .41438 L

.80812 .4141 L

.80938 .41381 L

.81063 .41353 L

.81189 .41324 L

.81314 .41295 L

.8144 .41267 L

.81565 .41238 L

.8169 .4121 L

.81816 .41181 L

.81941 .41152 L

.82067 .41124 L

.82192 .41095 L

.82318 .41067 L

.82443 .41038 L

.82568 .4101 L

.82694 .40981 L

.82819 .40953 L

.82945 .40925 L

.8307 .40896 L

.83195 .40868 L

.83321 .40839 L

.83446 .40811 L

.83572 .40783 L

.83697 .40754 L

.83823 .40726 L

.83948 .40698 L

.84073 .40669 L

.84199 .40641 L

.84324 .40613 L

.8445 .40584 L

.84575 .40556 L

.84701 .40528 L

.84826 .405 L

.84951 .40472 L

.85077 .40443 L

.85202 .40415 L

.85328 .40387 L

.85453 .40359 L

.85579 .40331 L

.85704 .40303 L

.85829 .40275 L

.85955 .40247 L

.8608 .40219 L

.86206 .40191 L

Mistroke

.86331 .40163 L

.86456 .40134 L

.86582 .40106 L

.86707 .40079 L

.86833 .40051 L

.86958 .40023 L

.87084 .39995 L

.87209 .39967 L

.87334 .39939 L

.8746 .39911 L

.87585 .39883 L

.87711 .39855 L

.87836 .39827 L

.87962 .398 L

.88087 .39772 L

.88212 .39744 L

.88338 .39716 L

.88463 .39688 L

.88589 .39661 L

.88714 .39633 L

.88839 .39605 L

.88965 .39577 L

.8909 .3955 L

.89216 .39522 L

.89341 .39494 L

.89467 .39467 L

.89592 .39439 L

.89717 .39411 L

.89843 .39384 L

.89968 .39356 L

.90094 .39329 L

.90219 .39301 L

.90345 .39273 L

.9047 .39246 L

.90595 .39218 L

.90721 .39191 L

.90846 .39163 L

.90972 .39136 L

.91097 .39108 L

.91223 .39081 L

.91348 .39053 L

.91473 .39026 L

.91599 .38999 L

.91724 .38971 L

.9185 .38944 L

.91975 .38916 L

.921 .38889 L

.92226 .38862 L

.92351 .38834 L

.92477 .38807 L

Mistroke

.92602 .3878 L

.92728 .38752 L

.92853 .38725 L

.92978 .38698 L

.93104 .3867 L

.93229 .38643 L

.93355 .38616 L

.9348 .38589 L

.93606 .38561 L

.93731 .38534 L

.93856 .38507 L

.93982 .3848 L

.94107 .38453 L

.94233 .38425 L

.94358 .38398 L

.94483 .38371 L

.94609 .38344 L

.94734 .38317 L

.9486 .3829 L

.94985 .38263 L

.95111 .38235 L

.95236 .38208 L

.95361 .38181 L

.95487 .38154 L

.95612 .38127 L

.95738 .381 L

.95863 .38073 L

.95989 .38046 L

.96114 .38019 L

.96239 .37992 L

.96365 .37965 L

.9649 .37938 L

.96616 .37911 L

.96741 .37884 L

.96867 .37857 L

.96992 .3783 L

.97117 .37803 L

.97243 .37776 L

.97368 .37749 L

.97494 .37722 L

.97619 .37695 L

Mfstroke

.73789 .18785 m

.73914 .18813 L

.7404 .18841 L

.74165 .1887 L

.74291 .18898 L

.74416 .18926 L

.74541 .18955 L

.74667 .18983 L

.74792 .19012 L

.74918 .1904 L

.75043 .19069 L

.75168 .19098 L

.75294 .19126 L

.75419 .19155 L

.75545 .19184 L

.7567 .19213 L

.75796 .19241 L

.75921 .1927 L

.76046 .19299 L

.76172 .19328 L

.76297 .19357 L

.76423 .19385 L

.76548 .19414 L

.76674 .19443 L

.76799 .19472 L

.76924 .19501 L

.7705 .1953 L

.77175 .19558 L

.77301 .19587 L

.77426 .19616 L

.77551 .19645 L

.77677 .19674 L

.77802 .19703 L

.77928 .19732 L

.78053 .19761 L

.78179 .19789 L

.78304 .19818 L

.78429 .19847 L

.78555 .19876 L

.7868 .19905 L

.78806 .19934 L

.78931 .19962 L

.79057 .19991 L

.79182 .2002 L

.79307 .20049 L

.79433 .20078 L

.79558 .20106 L

.79684 .20135 L

.79809 .20164 L

.79935 .20193 L

Mistroke

.8006 .20221 L

.80185 .2025 L

.80311 .20279 L

.80436 .20308 L

.80562 .20336 L

.80687 .20365 L

.80812 .20394 L

.80938 .20422 L

.81063 .20451 L

.81189 .20479 L

.81314 .20508 L

.8144 .20537 L

.81565 .20565 L

.8169 .20594 L

.81816 .20622 L

.81941 .20651 L

.82067 .2068 L

.82192 .20708 L

.82318 .20737 L

.82443 .20765 L

.82568 .20793 L

.82694 .20822 L

.82819 .2085 L

.82945 .20879 L

.8307 .20907 L

.83195 .20936 L

.83321 .20964 L

.83446 .20992 L

.83572 .21021 L

.83697 .21049 L

.83823 .21077 L

.83948 .21106 L

.84073 .21134 L

.84199 .21162 L

.84324 .21191 L

.8445 .21219 L

.84575 .21247 L

.84701 .21275 L

.84826 .21304 L

.84951 .21332 L

.85077 .2136 L

.85202 .21388 L

.85328 .21416 L

.85453 .21444 L

.85579 .21472 L

.85704 .21501 L

.85829 .21529 L

.85955 .21557 L

.8608 .21585 L

.86206 .21613 L

Mistroke

.86331 .21641 L

.86456 .21669 L

.86582 .21697 L

.86707 .21725 L

.86833 .21753 L

.86958 .21781 L

.87084 .21809 L

.87209 .21837 L

.87334 .21865 L

.8746 .21892 L

.87585 .2192 L

.87711 .21948 L

.87836 .21976 L

.87962 .22004 L

.88087 .22032 L

.88212 .22059 L

.88338 .22087 L

.88463 .22115 L

.88589 .22143 L

.88714 .22171 L

.88839 .22198 L

.88965 .22226 L

.8909 .22254 L

.89216 .22281 L

.89341 .22309 L

.89467 .22337 L

.89592 .22364 L

.89717 .22392 L

.89843 .2242 L

.89968 .22447 L

.90094 .22475 L

.90219 .22502 L

.90345 .2253 L

.9047 .22558 L

.90595 .22585 L

.90721 .22613 L

.90846 .2264 L

.90972 .22668 L

.91097 .22695 L

.91223 .22723 L

.91348 .2275 L

.91473 .22777 L

.91599 .22805 L

.91724 .22832 L

.9185 .2286 L

.91975 .22887 L

.921 .22914 L

.92226 .22942 L

.92351 .22969 L

.92477 .22997 L

Mistroke

.92602 .23024 L

.92728 .23051 L

.92853 .23078 L

.92978 .23106 L

.93104 .23133 L

.93229 .2316 L

.93355 .23188 L

.9348 .23215 L

.93606 .23242 L

.93731 .23269 L

.93856 .23296 L

.93982 .23324 L

.94107 .23351 L

.94233 .23378 L

.94358 .23405 L

.94483 .23432 L

.94609 .2346 L

.94734 .23487 L

.9486 .23514 L

.94985 .23541 L

.95111 .23568 L

.95236 .23595 L

.95361 .23622 L

.95487 .23649 L

.95612 .23676 L

.95738 .23703 L

.95863 .2373 L

.95989 .23757 L

.96114 .23784 L

.96239 .23811 L

.96365 .23838 L

.9649 .23865 L

.96616 .23892 L

.96741 .23919 L

.96867 .23946 L

.96992 .23973 L

.97117 .24 L

.97243 .24027 L

.97368 .24054 L

.97494 .24081 L

.97619 .24108 L

Mfstroke

1 0 0 r

.66314 .45604 m

.66326 .45616 L

.66339 .45628 L

.66351 .45643 L

.66364 .45659 L

.66376 .45678 L

.66389 .457 L

.66395 .45713 L

.66358 .47453 L

s

.66314 .162 m

.66326 .16188 L

.66339 .16175 L

.66351 .1616 L

.66364 .16144 L

.66376 .16125 L

.66389 .16103 L

.66395 .1609 L

.66358 .1435 L

s

0 .4 1 r

.78555 .41786 m

.78806 .40884 L

.78818 .40835 L

.78831 .40786 L

.78843 .40736 L

.78856 .40687 L

.78868 .40637 L

.78881 .40586 L

.78894 .40535 L

.78906 .40484 L

.78919 .40431 L

.78931 .40379 L

.78944 .40325 L

.78956 .40272 L

.78969 .40218 L

.78981 .40163 L

.78994 .40108 L

.79006 .40053 L

.79019 .39996 L

.79031 .39939 L

.79044 .39881 L

.79057 .39823 L

.79069 .39764 L

.79082 .39704 L

.79094 .39644 L

.79107 .39583 L

.79119 .39521 L

.79132 .39457 L

.79144 .39394 L

.79157 .39328 L

.79169 .39263 L

.79182 .39196 L

.79195 .39128 L

.79207 .3906 L

.7922 .38988 L

.79232 .38918 L

.79245 .38843 L

.79257 .38769 L

.7927 .38694 L

.79282 .38617 L

.79295 .38538 L

.79307 .38457 L

.7932 .38373 L

.79332 .38288 L

.79345 .38199 L

.79358 .38109 L

.7937 .38016 L

.79383 .3792 L

.79395 .3782 L

.79408 .37715 L

Mistroke

.7942 .37605 L

.79433 .37493 L

.79445 .37373 L

.79458 .37246 L

.7947 .37109 L

.79483 .36961 L

.79496 .36796 L

.79508 .36612 L

.79521 .36394 L

.79533 .36114 L

.79539 .3592 L

.79546 .35298 L

Mfstroke

.78555 .20018 m

.78806 .2092 L

.78818 .20969 L

.78831 .21018 L

.78843 .21067 L

.78856 .21117 L

.78868 .21167 L

.78881 .21217 L

.78894 .21268 L

.78906 .2132 L

.78919 .21372 L

.78931 .21425 L

.78944 .21478 L

.78956 .21531 L

.78969 .21585 L

.78981 .2164 L

.78994 .21695 L

.79006 .21751 L

.79019 .21807 L

.79031 .21864 L

.79044 .21922 L

.79057 .2198 L

.79069 .2204 L

.79082 .221 L

.79094 .2216 L

.79107 .22221 L

.79119 .22283 L

.79132 .22346 L

.79144 .2241 L

.79157 .22475 L

.79169 .22541 L

.79182 .22607 L

.79195 .22675 L

.79207 .22744 L

.7922 .22815 L

.79232 .22886 L

.79245 .2296 L

.79257 .23034 L

.7927 .23109 L

.79282 .23186 L

.79295 .23265 L

.79307 .23347 L

.7932 .23431 L

.79332 .23515 L

.79345 .23605 L

.79358 .23695 L

.7937 .23787 L

.79383 .23883 L

.79395 .23983 L

.79408 .24088 L

Mistroke

.7942 .24198 L

.79433 .2431 L

.79445 .2443 L

.79458 .24558 L

.7947 .24694 L

.79483 .24842 L

.79496 .25007 L

.79508 .25191 L

.79521 .25409 L

.79533 .25689 L

.79539 .25884 L

.79546 .26506 L

Mfstroke

.70152 .42365 m

.70277 .42224 L

.70402 .42087 L

.70528 .41953 L

.70653 .41822 L

.70779 .41692 L

.70904 .41563 L

.7103 .41436 L

.71155 .4131 L

.7128 .41185 L

.71406 .41061 L

.71531 .40937 L

.71657 .40814 L

.71782 .40691 L

.71907 .40568 L

.72033 .40446 L

.72158 .40324 L

.72284 .40201 L

.72409 .40079 L

.72535 .39956 L

.7266 .39834 L

.72785 .3971 L

.72911 .39587 L

.73036 .39463 L

.73162 .39339 L

.73287 .39214 L

.73413 .39088 L

.73538 .38962 L

.73663 .38835 L

.73789 .38707 L

.73914 .38579 L

.7404 .38449 L

.74165 .38318 L

.74291 .38186 L

.74416 .38053 L

.74541 .37919 L

.74667 .37783 L

.74792 .37646 L

.74918 .37508 L

.75043 .37367 L

.75168 .37225 L

.75294 .37081 L

.75419 .36935 L

.75545 .36787 L

.7567 .36637 L

.75796 .36484 L

.75921 .36328 L

.76046 .3617 L

.76172 .36009 L

.76297 .35845 L

Mistroke

.76423 .35677 L

.76548 .35506 L

.76674 .35331 L

.76799 .35152 L

.76924 .34968 L

.7705 .34779 L

.77175 .34585 L

.77301 .34385 L

.77426 .34179 L

.77551 .33966 L

.77677 .33745 L

.77802 .33515 L

.77928 .33276 L

.78053 .33027 L

.78179 .32764 L

.78304 .32488 L

.78429 .32195 L

.78555 .31883 L

.7868 .31548 L

.78806 .31184 L

.78931 .30783 L

.79057 .30334 L

.79182 .29814 L

.79307 .29186 L

.79433 .28334 L

.79496 .27695 L

.79508 .27523 L

.79546 .26506 L

Mfstroke

.70152 .19439 m

.70277 .19579 L

.70402 .19716 L

.70528 .1985 L

.70653 .19982 L

.70779 .20112 L

.70904 .2024 L

.7103 .20367 L

.71155 .20493 L

.7128 .20618 L

.71406 .20743 L

.71531 .20866 L

.71657 .2099 L

.71782 .21112 L

.71907 .21235 L

.72033 .21357 L

.72158 .2148 L

.72284 .21602 L

.72409 .21724 L

.72535 .21847 L

.7266 .2197 L

.72785 .22093 L

.72911 .22216 L

.73036 .2234 L

.73162 .22465 L

.73287 .22589 L

.73413 .22715 L

.73538 .22841 L

.73663 .22968 L

.73789 .23096 L

.73914 .23225 L

.7404 .23354 L

.74165 .23485 L

.74291 .23617 L

.74416 .2375 L

.74541 .23884 L

.74667 .2402 L

.74792 .24157 L

.74918 .24296 L

.75043 .24436 L

.75168 .24578 L

.75294 .24722 L

.75419 .24868 L

.75545 .25016 L

.7567 .25167 L

.75796 .25319 L

.75921 .25475 L

.76046 .25633 L

.76172 .25794 L

.76297 .25958 L

Mistroke

.76423 .26126 L

.76548 .26297 L

.76674 .26472 L

.76799 .26652 L

.76924 .26835 L

.7705 .27024 L

.77175 .27218 L

.77301 .27418 L

.77426 .27624 L

.77551 .27837 L

.77677 .28058 L

.77802 .28288 L

.77928 .28527 L

.78053 .28777 L

.78179 .29039 L

.78304 .29315 L

.78429 .29608 L

.78555 .2992 L

.7868 .30256 L

.78806 .30619 L

.78931 .31021 L

.79057 .3147 L

.79182 .31989 L

.79307 .32618 L

.79433 .33469 L

.79496 .34108 L

.79508 .34281 L

.79546 .35298 L

Mfstroke

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{567, 350.313},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.776525,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008g0001GPP10`40000100000800002008200000

P800P020P<30`<3L`:K:l00003<006H009T00<`00?l0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV

09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<003o03?o06Ko09Wo0<co

0?oo0000<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I

<c>I<fJI<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0

IYT0I/`0I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bI

I_nIIP3<IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0c

VC<cVFHcVITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<

VIW<VLc<VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`c

c?lcc01Vc3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03o

c3?oc6Koc9Woc<coc?ooc000oc<0ofH0oiT0ol`0ool0o`0coc<cofHcoiTcol`coolco`1Voc=VofIV

oiUVolaVoomVo`2Ioc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<o`3ooc?oofKooiWoolco

ooooo`0000410@820P<30`@410D51@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C

4a@D5?okl:2PY820P?l0003o0?oo0000ool0o`3oooooocoQ00<0hN40on7fh@00?n400`3Qh@3ohOKQ

000oh@030>7Q0?oQm^4003oQ00<0hN40on7fh@00?n400`3Qh@3ohOKQ000oh@030>7Q0?oQm^4003oQ

00<0hN40on7fh@00?n400`3Qh@3ohOKQ000oh@<0_n4H__oQ7n4003oQ00<0hN40^N46_QSQ2[kohAGQ

000oh@030>7Q0;GQ1;hXh@Jnon4?h@00?n400`3Qh@2ah@Bn<^45__oQ2^4003oQ00<0hN40[^43_S_Q

1Kkoh@GQ000oh@030>7Q0:cQ0[i3h@Bnon41h@00?n400`3Qh@2Yh@>nBN46__[Q000oh@030>7Q0:SQ

00>nhN40D>43__OQ000oh@030>7Q0:KQ0[iFh@Bnln4003oQ00<0hN40Y>42_UcQ1;k_h@00?n400`3Q

h@2Rh@:nH^43_^cQ000oh@030>7Q0:7Q00>nhN40IN44_^SQ000oh@<0X>400kkQh@1Zh@:ni^4003oQ

00<0hN40W^42_VoQ1;kRh@00?n400`3Qh@2Mh@03_^7Q07?Q0kkOh@00?n400`3Qh@2Lh@03_^7Q07OQ

0[kMh@00?n400`3Qh@2Kh@03_^7Q07[Q0kkJh@00?n400`3Qh@2Jh@03_^7Q07kQ0kkGh@00?n400`3Q

h@2Ih@03_^7Q08;Q0[kEh@00?n400`3Qh@2Hh@03_^7Q08GQ0[kCh@00?n400`3Qh@2Gh@03_^7Q08SQ

0[kAh@00?n400`3Qh@2Fh@03_^7Q08_Q0kk>h@00?n400`3Qh@2Eh@03_^7Q08oQ00>nhN40bn4003oQ

0`0ThAh?D^400kkQh@2Ah@>nb^4003oQ00<0hN407^463akQ20m9h@03_^7Q09GQ00>nhN40an4003oQ

00<0hN406^443bcQ1`m2h@03_^7Q09KQ00>nhN40a^4003oQ00<0hN405^443cOQ1Plkh@03_^7Q09SQ

0kk5h@00?n400`3Qh@0Bh@@?@N453cGQ00>nhN40W>400kkQh@32h@00?n400`3Qh@0?h@<?B^453boQ

00>nhN40W^400kkQh@31h@00?n400`3Qh@0=h@8?D^453b[Q00>nhN40Wn42_/7Q000oh@030>7Q00cQ

00<?hN40En443bGQ00>nhN40X^400kkQh@2nh@00?n400`3Qh@09h@<?G^453b3Q00>nhN40Xn400kkQ

h@2mh@00?n400`3Qh@08h@033n7Q06CQ10lKh@03_^7Q0:GQ0[jmh@00;n4500;Q00<0hN401^400`3Q

h@05h@<?Jn443aOQ00>nhN40Yn400kkQh@2jh@00<N401`3QhN40h@001n400`3Qh@04h@033n7Q073Q

1@lAh@03_^7Q0:WQ00>nhN40^N4002_Q0`03h@070>7Qh@3Q0007h@D00Pmhh@@?3>400kkQh@2[h@:n

^N40037Q00L0hN7Q0>4000OQ00D0hN7Q3`1nh@@?1n400kkQh@2^h@03_^7Q0;KQ000ah@070>7Qh@3Q

0007h@040>7Q3h?Q10l3h@03_^7Q0:oQ00>nhN40]N40033Q0P04h@030>7Q00KQ00<0h@l0R>433`03

_^7Q0;3Q00>nhN40]>4003oQ0Pn;h@03_^4?00<?[n42_[CQ000nh@033`3Q08_Q00>nhN400n423joQ

00>nhN40/N4003gQ00<?h@00Rn400kkQh@06h@@?Zn400kkQh@2ah@00>n423`;Q00<0hN40R>400kkQ

h@0;h@@?Z>400kkQh@2`h@00>^400`oQh@02h@030>7Q08SQ00>nhN403n443jGQ0[j`h@00>^400`oQ

h@02h@030>7Q08OQ00>nhN405>443j?Q00>nhN40[N4003WQ00<?hN400n400`3Qh@27h@03_^7Q01SQ

10nOh@03_^7Q0:gQ000hh@033n7Q00CQ00<0hN40Qn400kkQh@0Lh@<?WN400kkQh@2/h@00=n400`oQ

h@05h@<0Q^400kkQh@0Ph@@?Un4Q3i3Q000fh@033n7Q00KQ00<0hN40Q^400kkQh@0Th@<?SN483`?Q

00>nhN406^4<3hCQ000eh@033n7Q00OQ00<0hN40QN400kkQh@0Xh@@?Q>453`cQ00>nhN409N4:3g[Q

000eh@033n7Q00OQ00<0hN40QN400kkQh@0/h@@?O>443a;Q00>nhN40;^493g7Q000dh@033n7Q00SQ

00<0hN40Q>400kkQh@0ah@<?M^433aKQ00>nhN40=^483f[Q000ch@033n7Q00WQ00<0hN40Q>400kkQ

h@0dh@@?L>433aWQ00>nhN40?N483f;Q000bh@033n7Q00[Q00<0hN40Pn400kkQh@0ih@@?J^423agQ

00>nhN40A>483e[Q000ah@033n7Q00_Q00<0hN40Pn400kkQh@0mh@@?IN400`oQh@0Nh@03_^7Q04_Q

1`mCh@00<N400`oQh@0;h@030>7Q08?Q00>nhN40@N433f3Q0PlQh@03_^7Q05;Q1`m<h@00<>400`oQ

h@0<h@030>7Q08?Q00>nhN40A>433ecQ00<?hN408^400kkQh@1Hh@P?A>40033Q00<?hN403>400`3Q

h@22h@03_^7Q04SQ10mGh@033n7Q02CQ00>nhN40G^473ckQ000_h@033n7Q00gQ0`22h@03_^7Q04cQ

10mAh@8?:>400kkQh@1Th@L?=n4002kQ00<?hN403^400`3Qh@22h@03_^7Q053Q10m<h@033n7Q02WQ

00>nhN40J^473c3Q000]h@033n7Q00oQ00<0hN40PN400kkQh@1Eh@@?An400`oQh@0Zh@03_^7Q0:7Q

000]h@033n7Q00oQ00<0hN40PN400kkQh@1Ih@8?AN400`oQh@0[h@03_^7Q0:3Q000/h@033n7Q013Q

00<0hN40PN400kkQh@1Kh@@?@>400`oQh@0/h@03_^7Q0:3Q000/h@033n7Q013Q00<0hN40P>400kkQ

h@1Ph@@??>400`oQh@0]h@03_^7Q09oQ000[h@033n7Q017Q00<0hN40P>400kkQh@1Th@@?=n400`oQ

h@0_h@03_^7Q09kQ000[h@033n7Q017Q00<0hN40On400kkQh@1Yh@@?<n400`oQh@0_h@03_^7Q09kQ

000Zh@033n7Q01;Q00<0hN40On400kkQh@1]h@@?;n400`oQh@0`h@03_^7Q09gQ000Yh@033n7Q01?Q

00<0hN40On400kkQh@1ah@@?:n400`oQh@0`h@03_^7Q09gQ000Yh@033n7Q01?Q00<0hN40On400kkQ

h@1eh@@?9n400`oQh@0ah@03_^7Q09cQ000Yh@033n7Q01?Q00<0hN40O^400kkQh@1jh@<?9>400`oQ

h@0ah@03_^7Q09cQ000Xh@033n7Q01CQ0`1nh@03_^7Q07gQ10lPh@033n7Q03;Q00>nhN40Vn4002SQ

00<?hN405>400`3Qh@1nh@03_^7Q087Q10lLh@033n7Q03;Q00>nhN40Vn4002SQ00<?hN405>400`3Q

h@1nh@03_^7Q08GQ10lIh@033n7Q03;Q00>nhN40V^4002OQ00<?hN405N400`3Qh@1nh@03_^7Q08WQ

10lEh@033n7Q03;Q00>nhN40V^4002OQ00<?hN405N400`3Qh@1mh@03_^7Q08kQ10lAh@033n7Q03?Q

00>nhN40VN4002KQ00<?hN405^400`3Qh@1mh@03_^7Q09;Q1@l<h@033n7Q03?Q00>nhN40VN4002KQ

00<?hN405^400`3Qh@1mh@03_^7Q09OQ1@l6h@8?=^400kkQh@2Hh@009N400`oQh@0Gh@030>7Q07gQ

00>nhN40W>463cSQ00>nhN40V>4002GQ00<?hN405n400`3Qh@1lh@03_^7Q0=cQ00>nhN40Un4002CQ

00<?hN406>400`3Qh@1lh@03_^7Q0=cQ00>nhN40Un4002CQ00<?hN406>400`3Qh@1lh@03_^7Q0=gQ

00>nhN40U^4002CQ00<?hN406>400`3Qh@1kh@03_^7Q0=kQ00>nhN40U^4002CQ00<?hN406>4307_Q

00>nhN40g^400kkQh@2Fh@008n400`oQh@0Ih@030>7Q07_Q00>nhN40gn400kkQh@2Eh@008n400`oQ

h@0Ih@030>7Q07_Q00>nhN40gn400kkQh@2Eh@008n400`oQh@0Ih@030>7Q07[Q00>nhN40hN400kkQ

h@2Dh@008^400`oQh@0Jh@030>7Q07[Q00>nhN40]^48_R?Q00>nhN40U>4002;Q00<?hN406^400`3Q

h@1jh@03_^7Q0;GQ0[h6h@Jn7n400kkQh@2Ch@008N400`oQh@0Kh@030>7Q07[Q00>nhN40]N42_P_Q

1[hJh@03_^7Q09?Q000Qh@033n7Q01_Q00<0hN40N^400kkQh@2fh@03_^7Q00kQ1[hEh@03_^7Q09?Q

000Qh@033n7Q01_Q00<0hN40N^400kkQh@2fh@:n5>45_Q7Q00>nhN40Tn40023Q00<?hN407>400`3Q

h@1jh@03_^7Q0;OQ0[hGh@Fn3^400kkQh@2Bh@008>400`oQh@0Ch@030>7Q00KQ00<0hN40NN400kkQ

h@2ih@03_^7Q01[Q1;h:h@03_^7Q09;Q000Ph@033n7Q01;Q00<0h@001n400`3Qh@1ih@03_^7Q0;[Q

00>nhN407N45_PGQ00>nhN40T^40023Q00<?hN403N4300CQ00<0hN401N4507OQ00>nhN40^n400kkQ

h@0Ph@Fn0^400kkQh@2Ah@008>400`oQh@0Bh@802>400`3Qh@1ih@03_^7Q0;cQ00>nhN409>44_Y;Q

000Oh@033n7Q01?Q00<0hN401n400`3Qh@1ih@03_^7Q0;gQ00>nhN409^46_XgQ000Oh@033n7Q01?Q

0`07h@030>7Q07WQ00>nhN40_^400kkQh@0Uh@03_^7Q00;Q1Kj9h@007n400`oQh@0Mh@030>7Q07WQ

00>nhN40_n400kkQh@0Th@03_^7Q00OQ1Kj4h@007n400`oQh@0Mh@030>7Q07SQ00>nhN40`N400kkQ

h@0Th@03_^7Q00[Q1Kj0h@007^400`oQh@0Nh@030>7Q07SQ00>nhN40`N42_RGQ00>nhN403^45_WcQ

000Nh@033n7Q01kQ00<0hN40N>400kkQh@33h@03_^7Q02;Q00>nhN404n45_WOQ000Nh@033n7Q01kQ

00<0hN40N>400kkQh@33h@:n8n400kkQh@0Gh@FnLn4001gQ00<?hN407n400`3Qh@1gh@03_^7Q0<KQ

00>nhN408>400kkQh@0Lh@FnK^4001gQ00<?hN407n400`3Qh@1gh@03_^7Q0<KQ0[hRh@03_^7Q023Q

1;iZh@007N400`oQh@0Oh@<0Mn400kkQh@38h@03_^7Q01oQ00>nhN408n45_VKQ000Mh@033n7Q01oQ

00<0hN40Mn400kkQh@39h@03_^7Q01kQ00>nhN40:>45_V7Q000Mh@033n7Q01oQ00<0hN40Mn400kkQ

h@3:h@03_^7Q01gQ00>nhN40;N44_UgQ000Lh@033n7Q023Q00<0hN40Mn400kkQh@3;h@03_^7Q01cQ

0[hbh@FnF>4001cQ00<?hN408>400`3Qh@1gh@03_^7Q0<cQ00>nhN407>400kkQh@0eh@FnDn4001cQ

00<?hN408>400`3Qh@1gh@03_^7Q0<gQ00>nhN406n400kkQh@0ih@FnCn4001cQ00<?hN408>400`3Q

h@1fh@03_^7Q0<oQ00>nhN406^400kkQh@0nh@FnB^4001cQ00<?hN408>400`3Qh@1fh@03_^7Q0=3Q

00>nhN406N400kkQh@12h@FnA^4001cQ00<?hN408>400`3Qh@1fh@03_^7Q0=3Q0[hJh@03_^7Q04OQ

1Ki1h@007>400`oQh@0Ph@030>7Q07KQ00>nhN40d^400kkQh@0Hh@03_^7Q04[Q1[hlh@006n400`oQ

h@0Qh@030>7Q07KQ00>nhN40d^42_QWQ00>nhN40D>45_SOQ000Kh@033n7Q027Q00<0hN40M^400kkQ

h@3Dh@03_^7Q01KQ00>nhN40E>45_S?Q000Kh@033n7Q027Q0`1fh@03_^7Q0=CQ0[hGh@03_^7Q05WQ

0kh`h@006n400`oQh@0Qh@030>7Q07KQ00>nhN40e^400kkQh@0Dh@03_^7Q08cQ000Kh@033n7Q027Q

00<0hN40M^400kkQh@3Fh@03_^7Q01CQ00>nhN40S>4001_Q00<?hN408N400`3Qh@1fh@03_^7Q0=OQ

0[hDh@03_^7Q08cQ000Kh@033n7Q027Q00<0hN40M^400kkQh@3Hh@03_^7Q01;Q00>nhN40S>4001_Q

00<?hN408N400`3Qh@1fh@03_^7Q0=WQ00>nhN404N400kkQh@2<h@006n400`oQh@0Qh@030>7Q07KQ

00>nhN40f^400kkQh@0@h@03_^7Q08cQ000Kh@033n7Q027Q00<0hN40M^400kkQh@3Kh@03_^7Q013Q

00>nhN40Rn4001[Q00<?hN408^400`3Qh@1fh@03_^7Q0=cQ00>nhN403n400kkQh@2;h@006^400`oQ

h@0Rh@030>7Q07GQ00>nhN40gN400kkQh@0?h@03_^7Q08_Q000Jh@033n7Q02;Q00<0hN40MN400kkQ

h@3Nh@03_^7Q00kQ00>nhN40Rn4001[Q00<?hN408^400`3Qh@1eh@03_^7Q0=kQ0[h?h@03_^7Q08_Q

000Jh@033n7Q02;Q0`1eh@03_^7Q0>3Q00>nhN403>400kkQh@2;h@006^400`oQh@0Rh@030>7Q07GQ

00>nhN40h>400kkQh@0<h@03_^7Q08_Q000Jh@033n7Q02;Q00<0hN40MN400kkQh@3Qh@03_^7Q00_Q

00>nhN40Rn4001[Q00<?hN408^400`3Qh@1eh@03_^7Q0>;Q00>nhN402^400kkQh@2;h@006^400`oQ

h@0Rh@030>7Q07GQ00>nhN40h^400kkQh@09h@03_^7Q08cQ000Jh@033n7Q02;Q00<0hN40MN400kkQ

h@3Sh@03_^7Q00SQ00>nhN40S>4001[Q00<?hN408^400`3Qh@1eh@03_^7Q0>CQ00>nhN401n400kkQ

h@2<h@006^400`oQh@0Rh@030>7Q07GQ00>nhN40i>400kkQh@07h@03_^7Q08cQ000Ih@033n7Q02?Q

00<0hN40MN400kkQh@3Th@03_^7Q00OQ00>nhN40S>4001WQ00<?hN408n400`3Qh@0ih@D00^400`3Q

h@0bh@03_^7Q00;Q1@000n40000ih@D00^400`3Qh@0gh@D00^400`3Qh@0gh@D000?Q00006>400kkQ

h@06h@03_^7Q01KQ0`03h@030>7Q03SQ0`000n40000302cQ000Ih@033n7Q02?Q00<0hN40>n401`3Q

hN40h@00<n400kkQh@04h@070>7Qh@3Q000jh@030>7Q00;Q00<0hN40>N401`3QhN40h@00>^400`3Q

h@03h@030>7Q01KQ00>nhN401N400kkQh@0Fh@030>7Q00;Q00<0h@00>N400`3Qh@03h@030>7Q02cQ

000Ih@033n7Q02?Q00<0hN40>n400`3Qh@03h@030>7Q037Q00>nhN401>401`3QhN40h@00>^400`3Q

h@02h@030>7Q03WQ00L0hN7Q0>4003[Q00<0hN400^4201SQ00>nhN401N400kkQh@0Gh@070>7Qh@3Q

000jh@030>7Q00;Q00<0hN40;>4001WQ00<?hN408n4303_Q00@0hN7Q0P0dh@03_^7Q00CQ00@0hN7Q

0P0kh@030>7Q00?Q00<0hN40>>400`3Qh@02h@030>7Q03WQ00L0hN7Q0>4001WQ00>nhN400n400kkQ

h@0Hh@070>7Qh@3Q000jh@030>7Q00;Q00<0hN40;>4001WQ00<?hN408n400`3Qh@0kh@050>7Qh@00

=N400kkQh@04h@050>7Qh@00?>401`3QhN40h@00>^401`3QhN40h@00>^401`3QhN40h@006N400kkQ

h@03h@03_^7Q01OQ00<0h@000^400`3Q000ih@030>4000?Q00<0hN40;>4001WQ00<?hN408n400`3Q

h@0jh@800n4303?Q00>nhN400n4200CQ0P0ih@800n4303WQ0P04h@030>7Q03SQ0P04h@806^400kkQ

h@02h@03_^7Q01SQ00<0hN400^400`3Qh@0ih@040>7Qh@80;^4001WQ00<?hN408n400`3Qh@1eh@03

_^7Q0>SQ00>nhN400^400kkQh@2=h@006N400`oQh@0Sh@030>7Q07GQ00>nhN40j>400kkQh@02h@03

_^7Q08gQ000Ih@033n7Q02?Q00<0hN40MN400kkQh@3Yh@05_^7QhKh0Sn4001WQ00<?hN408n400`3Q

h@1eh@03_^7Q0>[Q00BnhN6nSn4001WQ00<?hN408n400`3Qh@1eh@03_^7Q0>[Q00>nhKh0T>4001WQ

00<?hN408n400`3Qh@1eh@03_^7Q0>[Q00>nhKh0T>4001WQ00<?hN408n400`3Qh@1eh@03_^7Q0>[Q

00>nhKh0O>44013Q000Ih@033n7Q02?Q00<0hN40MN400kkQh@3[h@03_^7Q07_Q0`0Ah@003>4=0003

3`0009/000>n0000j`000kh0001/017Q00<0hN403n4001SQ00<03n402^400`3Qh@0:h@030>7Q00[Q

00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Q

h@0:h@030>7Q00[Q00@0hN6n2N400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q

00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Q

h@0:h@030>7Q00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN401>400kkQh@03h@030>7Q00[Q

00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN406n42017Q

000Hh@0300oQ00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q

00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Qh@0:h@040>7Q_PWQ00<0hN402^400`3Q

h@0:h@030>7Q00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q

00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Q

h@0:h@030>7Q00CQ00>nhN400n400`3Qh@0:h@030>7Q00[Q00<0hN402^400`3Qh@0:h@030>7Q00[Q

00<0hN402^400`3Qh@0:h@030>7Q02kQ000Ih@033n7Q02?Q00<0hN40?^400`3Qh@0dh@03_^7Q00OQ

00<0hN40?^400`3Qh@0nh@030>7Q03kQ00<0hN407N400kkQ_P0Nh@030>7Q03kQ00<0hN40;^4001WQ

00<?hN408n400`3Qh@0nh@030>7Q03CQ00>nhN401n400`3Qh@0nh@030>7Q03kQ00<0hN40?^400`3Q

h@0Mh@03_^6n01kQ00<0hN40?^400`3Qh@0^h@006N400`oQh@0Sh@030>7Q07GQ00>nhN40j^401;kQ

hKj?h@006N400`oQh@0Sh@030>7Q07GQ00>nhN40jN401KkQhN6n08oQ000Ih@033n7Q02?Q00<0hN40

MN400kkQh@3Yh@05_^7QhKh0Sn4001WQ00<?hN408n400`3Qh@1eh@03_^7Q0>SQ00>nhN400^400kkQ

h@2=h@006N400`oQh@0Sh@030>7Q07GQ00>nhN40j>400kkQh@02h@03_^7Q08gQ000Ih@033n7Q02?Q

00<0hN40MN400kkQh@3Xh@03_^7Q00;Q00>nhN40SN4001WQ00<?hN408n400`3Qh@1eh@03_^7Q0>OQ

00>nhN400n400kkQh@2=h@006N400`oQh@0Sh@<0MN400kkQh@3Vh@03_^7Q00GQ00>nhN40S>4001WQ

00<?hN408n400`3Qh@1eh@03_^7Q0>KQ00>nhN401N400kkQh@2<h@006N400`oQh@0Sh@030>7Q07GQ

00>nhN40i^400kkQh@05h@03_^7Q08cQ000Ih@033n7Q02?Q00<0hN40MN400kkQh@3Uh@03_^7Q00KQ

00>nhN40S>4001WQ00<?hN408n400`3Qh@1eh@03_^7Q0>CQ00>nhN401n400kkQh@2<h@006^400`oQ

h@0Rh@030>7Q07GQ00>nhN40i>400kkQh@07h@03_^7Q08cQ000Jh@033n7Q02;Q00<0hN40MN400kkQ

h@3Sh@03_^7Q00SQ00>nhN40S>4001[Q00<?hN408^400`3Qh@1eh@03_^7Q0>;Q00>nhN402N400kkQ

h@2<h@006^400`oQh@0Rh@030>7Q07GQ00>nhN40h^400kkQh@09h@03_^7Q08cQ000Jh@033n7Q02;Q

00<0hN40MN400kkQh@3Qh@03_^7Q00_Q00>nhN40Rn4001[Q00<?hN408^400`3Qh@1eh@03_^7Q0>3Q

00>nhN403>400kkQh@2;h@006^400`oQh@0Rh@030>7Q07GQ00>nhN40h>400kkQh@0<h@03_^7Q08_Q

000Jh@033n7Q02;Q0`1eh@03_^7Q0=oQ00>nhN403N400kkQh@2;h@006^400`oQh@0Rh@030>7Q07GQ

00>nhN40g^400kkQh@0>h@03_^7Q08_Q000Jh@033n7Q02;Q00<0hN40MN400kkQh@3Nh@03_^7Q00kQ

00>nhN40Rn4001[Q00<?hN408^400`3Qh@1eh@03_^7Q0=gQ00>nhN403n400kkQh@2;h@006n400`oQ

h@0Qh@030>7Q07KQ00>nhN40fn42_Q7Q00>nhN40Rn4001_Q00<?hN408N400`3Qh@1fh@03_^7Q0=[Q

00>nhN404N400kkQh@2;h@006n400`oQh@0Qh@030>7Q07KQ00>nhN40f^400kkQh@0@h@03_^7Q08cQ

000Kh@033n7Q027Q00<0hN40M^400kkQh@3Ih@03_^7Q017Q00>nhN40S>4001_Q00<?hN408N400`3Q

h@1fh@03_^7Q0=SQ00>nhN404^400kkQh@2<h@006n400`oQh@0Qh@030>7Q07KQ00>nhN40en400kkQ

h@0Ch@03_^7Q08cQ000Kh@033n7Q027Q00<0hN40M^400kkQh@3Fh@03_^7Q01CQ00>nhN40S>4001_Q

00<?hN408N400`3Qh@1fh@03_^7Q0=GQ0[hFh@03_^7Q08cQ000Kh@033n7Q027Q0`1fh@03_^7Q0=CQ

00>nhN405^400kkQh@1Gh@Fn<>4001_Q00<?hN408N400`3Qh@1fh@03_^7Q0=?Q0[hHh@03_^7Q05?Q

1Khdh@007>400`oQh@0Ph@030>7Q07KQ00>nhN40d^400kkQh@0Hh@03_^7Q04kQ1Khih@007>400`oQ

h@0Ph@030>7Q07KQ00>nhN40dN42_Q[Q00>nhN40B^45_SgQ000Lh@033n7Q023Q00<0hN40M^400kkQ

h@3@h@03_^7Q01WQ00>nhN40A^45_T;Q000Lh@033n7Q023Q00<0hN40M^400kkQh@3?h@:n6n400kkQ

h@11h@FnAn4001cQ00<?hN408>400`3Qh@1fh@03_^7Q0<oQ00>nhN406^400kkQh@0lh@FnC>4001cQ

00<?hN408>400`3Qh@1gh@03_^7Q0<cQ0[hMh@03_^7Q03SQ1Ki@h@007>400`oQh@0Ph@030>7Q07OQ

00>nhN40c>400kkQh@0Lh@03_^7Q03?Q1KiEh@007>400`oQh@0Ph@030>7Q07OQ00>nhN40b^42_QkQ

0[hah@FnFN4001gQ00<?hN407n400`3Qh@1gh@03_^7Q0<[Q00>nhN407N400kkQh@0[h@FnG^4001gQ

00<?hN407n4307OQ00>nhN40b>42_R3Q00>nhN409n45_V;Q000Mh@033n7Q01oQ00<0hN40Mn400kkQ

h@38h@03_^7Q01oQ00>nhN408n44_VOQ000Mh@033n7Q01oQ00<0hN40Mn400kkQh@36h@:n8N42_R3Q

1Ki[h@007N400`oQh@0Oh@030>7Q07OQ00>nhN40aN42_R;Q00>nhN406n45_VoQ000Nh@033n7Q01kQ

00<0hN40N>400kkQh@33h@03_^7Q02;Q00>nhN405^45_WCQ000Nh@033n7Q01kQ00<0hN40N>400kkQ

h@32h@:n9>400kkQh@0Bh@FnN>4001oQ00<?hN407N400`3Qh@1hh@03_^7Q0<7Q00>nhN409>400kkQ

h@0=h@FnON4001oQ00<?hN407N400`3Qh@1hh@03_^7Q0<3Q0[hVh@03_^7Q00WQ1;j2h@007n400`oQ

h@0Mh@030>7Q07WQ00>nhN40_n400kkQh@0Th@03_^7Q00KQ1Kj5h@007n400`oQh@0Mh@030>7Q07WQ

00>nhN40_N42_ROQ00BnhN7Q1Kj:h@007n400`oQh@0Dh@030>7Q00KQ00<0hN40NN400kkQh@2mh@03

_^7Q02KQ1;j?h@008>400`oQh@0Bh@030>4000OQ00<0hN40NN400kkQh@2kh@:n9N45_Y;Q000Ph@03

3n7Q01CQ00<0hN401N4507OQ00>nhN40^n400kkQh@0Oh@Fn0n400kkQh@2Ah@008>400`oQh@0Bh@80

2>400`3Qh@1ih@03_^7Q0;[Q00>nhN407>44_POQ00>nhN40T^40023Q00<?hN404^400`3Qh@07h@03

0>7Q07[Q00>nhN40^>400kkQh@0Ih@Fn2^400kkQh@2Bh@008>400`oQh@0Bh@<01n400`3Qh@1jh@03

_^7Q0;OQ00>nhN405N45_PoQ00>nhN40T^40027Q00<?hN406n400`3Qh@1jh@03_^7Q0;KQ0[hBh@Fn

4n400kkQh@2Ch@008N400`oQh@0Kh@030>7Q07[Q00>nhN40]^400kkQh@0=h@Fn5n400kkQh@2Ch@00

8N400`oQh@0Kh@030>7Q07[Q00>nhN40]N42_P[Q1[hKh@03_^7Q09?Q000Rh@033n7Q01[Q00<0hN40

N^400kkQh@2eh@:n1>47_R3Q00>nhN40Tn4002;Q00<?hN406^400`3Qh@1jh@03_^7Q0;KQ1[hUh@03

_^7Q09CQ000Sh@033n7Q01WQ00<0hN40Nn400kkQh@3Ph@03_^7Q09CQ000Sh@033n7Q01WQ00<0hN40

Nn400kkQh@3Oh@03_^7Q09GQ000Sh@033n7Q01WQ00<0hN40Nn400kkQh@3Oh@03_^7Q09GQ000Th@03

3n7Q01SQ0`1kh@03_^7Q0=kQ00>nhN40U^4002CQ00<?hN406>400`3Qh@1kh@03_^7Q0=kQ00>nhN40

U^4002CQ00<?hN406>400`3Qh@1lh@03_^7Q0=cQ00>nhN40Un4002GQ00<?hN405n400`3Qh@1lh@03

_^7Q0=cQ00>nhN40Un4002GQ00<?hN405n400`3Qh@1mh@03_^7Q0=_Q00>nhN40Un4002GQ00<?hN40

5n400`3Qh@1mh@03_^7Q09_Q1`lhh@03_^7Q09SQ000Vh@033n7Q01KQ00<0hN40ON400kkQh@2Fh@D?

1n423cKQ00>nhN40V>4002KQ00<?hN405^400`3Qh@1mh@03_^7Q097Q1@l=h@033n7Q03?Q00>nhN40

VN4002OQ00<?hN405N400`3Qh@1mh@03_^7Q08gQ10lBh@033n7Q03?Q00>nhN40VN4002OQ00<?hN40

5N400`3Qh@1nh@03_^7Q08SQ10lFh@033n7Q03;Q00>nhN40V^4002SQ00<?hN405>400`3Qh@1nh@03

_^7Q08CQ10lJh@033n7Q037Q00>nhN40Vn4002SQ00<?hN405>400`3Qh@1nh@03_^7Q083Q10lMh@03

3n7Q03;Q00>nhN40Vn4002SQ00<?hN405>4307kQ00>nhN40O>443b7Q00<?hN40<^400kkQh@2Kh@00

:N400`oQh@0Ch@030>7Q07kQ00>nhN40NN433bGQ00<?hN40<N400kkQh@2Lh@00:N400`oQh@0Ch@03

0>7Q07oQ00>nhN40M>443bSQ00<?hN40<N400kkQh@2Lh@00:^400`oQh@0Bh@030>7Q07oQ00>nhN40

L>443bcQ00<?hN40<>400kkQh@2Mh@00:^400`oQh@0Bh@030>7Q07oQ00>nhN40K>443c3Q00<?hN40

<>400kkQh@2Mh@00:n400`oQh@0Ah@030>7Q083Q00>nhN40In443cCQ00<?hN40;n400kkQh@2Nh@00

;>400`oQh@0@h@030>7Q083Q00>nhN40Hn443cWQ00<?hN40;N400kkQh@2Oh@00;>400`oQh@0@h@03

0>7Q087Q00>nhN40Gn433cgQ00<?hN40;>400kkQh@2Ph@00;N400`oQh@0?h@030>7Q087Q00>nhN40

G>433d7Q00<?hN40:n400kkQh@2Ph@00;N400`oQh@0?h@030>7Q087Q00>nhN40F>443dCQ00<?hN40

:^400kkQh@2Qh@00;N400`oQh@0?h@030>7Q08;Q00>nhN40Dn443dWQ00<?hN40:N400kkQh@1_h@8?

<>4002kQ00<?hN403^4308;Q00>nhN40Cn443dgQ00<?hN40:>400kkQh@1Yh@L?<^4002oQ00<?hN40

3N400`3Qh@22h@03_^7Q04_Q10mBh@033n7Q02KQ00>nhN40Hn473cWQ000`h@033n7Q00cQ00<0hN40

P^400kkQh@18h@<?En423bGQ00>nhN40GN473d3Q000`h@033n7Q00cQ00<0hN40Pn400kkQh@13h@@?

G>400`oQh@0Rh@03_^7Q05KQ20m6h@00<N400`oQh@0;h@030>7Q08?Q00>nhN40@>433f7Q00<?hN40

8>400kkQh@1@h@L?C^40037Q00<?hN402n400`3Qh@23h@03_^7Q03cQ10mUh@<?7n400kkQh@18h@P?

EN4003;Q00<?hN402^400`3Qh@23h@03_^7Q03SQ10m/h@8?7>400kkQh@12h@L?GN4003?Q0Pl:h@03

0>7Q08CQ00>nhN40=>433g7Q0`lIh@03_^7Q03_Q20mTh@00=>400`oQh@08h@030>7Q08CQ00>nhN40

<>443gOQ10lDh@03_^7Q03CQ2@m[h@00=N400`oQh@07h@030>7Q08GQ00>nhN40:n443gkQ1@l?h@03

_^7Q02cQ2@mdh@00=N400`oQh@07h@030>7Q08GQ00>nhN409n443hKQ1Pl:h@03_^7Q02;Q2`mlh@00

=^400`oQh@06h@030>7Q08KQ00>nhN408n433hoQ2`lGh@h?Qn4003OQ00<?hN401N4308KQ00>nhN40

8>433i_Q00>n3`l05PnEh@00>>400`oQh@04h@030>7Q08OQ00>nhN406n443igQ00>nhN40[>4003WQ

00<?hN400n400`3Qh@27h@03_^7Q01OQ10nPh@03_^7Q0:gQ000jh@033n7Q00;Q00<0hN40Qn400kkQ

h@0Ch@@?Xn400kkQh@2^h@00>n401@oQhN4008[Q00>nhN403^443jOQ00>nhN40[^4003cQ0Pl00n40

h@29h@03_^7Q00[Q10nYh@:n/N4003gQ00<?h@00Rn400kkQh@07h@8?[>400kkQh@2ah@00?^400`l0

h@2;h@03_^7Q00;Q10n]h@03_^7Q0;;Q000oh@033n7Q08[Q00>n3`l00Pnah@03_^7Q0;;Q000oh@03

00l?08OQ10l00kkQh@2`h@:n]N4002oQ1@02h@030>7Q00KQ00@0hN4?P^443`CQ00>nhN40[n400kkQ

h@2eh@00<N401`3QhN40h@001n401@3QhN4?07gQ10l8h@03_^7Q0:kQ00>nhN40]^40037Q00L0hN7Q

0>4000OQ1@033gKQ10l=h@03_^7Q0:cQ00>nhN40]n40037Q00L0hN7Q0>4000OQ00<0hN401N400`oQ

h@1_h@@?4^400kkQh@2Yh@:n^^40037Q00L0hN7Q0>4000OQ00<0hN401^400`oQh@1Yh@D?5n400kkQ

h@2Wh@03_^7Q0;[Q000`h@801>400`3Qh@06h@030>7Q00OQ0`mTh@@?7>400kkQh@2Vh@03_^7Q0;_Q

000oh@030>7Q00[Q00<?hN40GN443b7Q00>nhN40Xn42_[kQ000oh@030>7Q00_Q0`mGh@D?9N400kkQ

h@2Rh@03_^7Q0;kQ000oh@030>7Q00kQ0Pm@h@D?:n400kkQh@2Ph@03_^7Q0;oQ000oh@030>7Q013Q

0`m8h@D?<>400kkQh@2Mh@>n`^4003oQ00<0hN404n433d3Q1@lfh@03_^7Q09_Q00>nhN40`n4003oQ

00<0hN405^443cGQ1`llh@03_^7Q09WQ00>nhN40a>4003oQ00<0hN406^453b[Q1Pm4h@03_^7Q09KQ

0[k7h@00?n4301oQ20lGh@/?Bn400kkQh@2Ch@:nbN4003oQ00<0hN409n4G3eKQ00>nhN40TN42_/_Q

000oh@030>7Q09GQ00>nhN40S^42_/gQ000oh@030>7Q09KQ0[j<h@:ncn4003oQ00<0hN40Un400kkQ

h@28h@:ndN4003oQ00<0hN40V>400kkQh@24h@>ndn4003oQ00<0hN40VN400kkQh@21h@:ne^4003oQ

00<0hN40V^42_WkQ0kkHh@00?n400`3Qh@2Kh@03_^7Q07WQ0kkKh@00?n400`3Qh@2Lh@03_^7Q07KQ

0[kNh@00?n400`3Qh@2Mh@03_^7Q07;Q0kkPh@00?n400`3Qh@2Nh@03_^7Q06oQ0[kSh@00?n4309oQ

0[i[h@BniN4003oQ00<0hN40XN400kkQh@1Uh@>njN4003oQ00<0hN40X^43_V3Q1;k/h@00?n400`3Q

h@2Uh@03_^7Q05WQ1;k`h@00?n400`3Qh@2Vh@03_^7Q05CQ1;kdh@00?n400`3Qh@2Wh@>nD>43__SQ

000oh@030>7Q0:[Q0ki7h@Jnnn4003oQ00<0hN40[N42_T7Q1;koh@;Q000oh@030>7Q0:oQ0khih@Fn

on46h@00?n400`3Qh@2bh@:n<N46__oQ2n4003oQ00<0hN40]>46_RCQ1kkohA7Q000oh@030>7Q0;[Q

1khDh@Vnon4Hh@00?n430<7Q5;kohB7Q000oh@030>7Q0?oQm^4003oQ00<0hN40on7fh@00?n400`3Q

h@3ohOKQ000oh@030>7Q0?oQm^4003oQ00<0hN40on7fh@00?n400`3Qh@3ohOKQ000oh@030>7Q0?oQ

m^4003oQ00<0hN40on7fh@00on7ohCWQ003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQ

on4ih@00on7ohCWQ003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?cQ0P000n400006h@@0

1^4200?Q0P04h@030>7Q00;Q00<0hN40on4Dh@00oN400`3Q000Ch@030>7Q00;Q00<0hN401^400`3Q

h@3ohACQ003mh@<01n4400OQ00<0hN400^4200SQ00<0hN40on4Dh@00oN40103Q000Bh@060>7Q0>40

2N400`3Qh@3ohA?Q000mh@80_^400`3Qh@0Ah@030>4000;Q00<0h@001n400`3Q003ohAGQ000nh@03

0>7Q0;_Q0P0Dh@030>7Q00;Q0P07h@<0on4Eh@00?>4300;Q00<0hN40on7dh@00>n40203Qh@3Q0>40

on7eh@00>n40203Qh@3Q0>40on7eh@00?>430004h@3Q0?oQmN40043Q00<0h@00on7eh@00@N400`3Q

h@3ohOCQ003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQon4ih@00\

\>"],

  ImageRangeCache->{{{0, 566}, {349.313, 0}} -> {13.0192, -13.6511, 0.0153819,

   0.0852246}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-1.92154 0.144959 0.309017 0.0224991 [

[.25284 .29652 -6 -9 ]

[.25284 .29652 6 0 ]

[.3978 .29652 -6 -9 ]

[.3978 .29652 6 0 ]

[.54276 .29652 -6 -9 ]

[.54276 .29652 6 0 ]

[.68772 .29652 -6 -9 ]

[.68772 .29652 6 0 ]

[.83268 .29652 -6 -9 ]

[.83268 .29652 6 0 ]

[.97764 .29652 -6 -9 ]

[.97764 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.09539 .08403 -18 -4.5 ]

[.09539 .08403 0 4.5 ]

[.09539 .19652 -12 -4.5 ]

[.09539 .19652 0 4.5 ]

[.09539 .42151 -6 -4.5 ]

[.09539 .42151 0 4.5 ]

[.09539 .53401 -12 -4.5 ]

[.09539 .53401 0 4.5 ]

[.10789 .64303 -7 0 ]

[.10789 .64303 7 16 ]

[.5 .63053 -12 0 ]

[.5 .63053 12 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.25284 .30902 m

.25284 .31527 L

s

[(15)] .25284 .29652 0 1 Mshowa

.3978 .30902 m

.3978 .31527 L

s

[(16)] .3978 .29652 0 1 Mshowa

.54276 .30902 m

.54276 .31527 L

s

[(17)] .54276 .29652 0 1 Mshowa

.68772 .30902 m

.68772 .31527 L

s

[(18)] .68772 .29652 0 1 Mshowa

.83268 .30902 m

.83268 .31527 L

s

[(19)] .83268 .29652 0 1 Mshowa

.97764 .30902 m

.97764 .31527 L

s

[(20)] .97764 .29652 0 1 Mshowa

.125 Mabswid

.13688 .30902 m

.13688 .31277 L

s

.16587 .30902 m

.16587 .31277 L

s

.19486 .30902 m

.19486 .31277 L

s

.22385 .30902 m

.22385 .31277 L

s

.28184 .30902 m

.28184 .31277 L

s

.31083 .30902 m

.31083 .31277 L

s

.33982 .30902 m

.33982 .31277 L

s

.36881 .30902 m

.36881 .31277 L

s

.4268 .30902 m

.4268 .31277 L

s

.45579 .30902 m

.45579 .31277 L

s

.48478 .30902 m

.48478 .31277 L

s

.51377 .30902 m

.51377 .31277 L

s

.57175 .30902 m

.57175 .31277 L

s

.60075 .30902 m

.60075 .31277 L

s

.62974 .30902 m

.62974 .31277 L

s

.65873 .30902 m

.65873 .31277 L

s

.71671 .30902 m

.71671 .31277 L

s

.74571 .30902 m

.74571 .31277 L

s

.7747 .30902 m

.7747 .31277 L

s

.80369 .30902 m

.80369 .31277 L

s

.86167 .30902 m

.86167 .31277 L

s

.89066 .30902 m

.89066 .31277 L

s

.91966 .30902 m

.91966 .31277 L

s

.94865 .30902 m

.94865 .31277 L

s

.07889 .30902 m

.07889 .31277 L

s

.0499 .30902 m

.0499 .31277 L

s

.02091 .30902 m

.02091 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.10789 .08403 m

.11414 .08403 L

s

[(-10)] .09539 .08403 1 0 Mshowa

.10789 .19652 m

.11414 .19652 L

s

[(-5)] .09539 .19652 1 0 Mshowa

.10789 .42151 m

.11414 .42151 L

s

[(5)] .09539 .42151 1 0 Mshowa

.10789 .53401 m

.11414 .53401 L

s

[(10)] .09539 .53401 1 0 Mshowa

.125 Mabswid

.10789 .10652 m

.11164 .10652 L

s

.10789 .12902 m

.11164 .12902 L

s

.10789 .15152 m

.11164 .15152 L

s

.10789 .17402 m

.11164 .17402 L

s

.10789 .21902 m

.11164 .21902 L

s

.10789 .24152 m

.11164 .24152 L

s

.10789 .26402 m

.11164 .26402 L

s

.10789 .28652 m

.11164 .28652 L

s

.10789 .33152 m

.11164 .33152 L

s

.10789 .35402 m

.11164 .35402 L

s

.10789 .37651 m

.11164 .37651 L

s

.10789 .39901 m

.11164 .39901 L

s

.10789 .44401 m

.11164 .44401 L

s

.10789 .46651 m

.11164 .46651 L

s

.10789 .48901 m

.11164 .48901 L

s

.10789 .51151 m

.11164 .51151 L

s

.10789 .06153 m

.11164 .06153 L

s

.10789 .03903 m

.11164 .03903 L

s

.10789 .01653 m

.11164 .01653 L

s

.10789 .55651 m

.11164 .55651 L

s

.10789 .57901 m

.11164 .57901 L

s

.10789 .60151 m

.11164 .60151 L

s

.25 Mabswid

.10789 0 m

.10789 .61803 L

s

gsave

.10789 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -73 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(k) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(40) show

83.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 .4 1 r

.5 Mabswid

.75875 .56902 m

.7573 .56953 L

.75585 .57004 L

.7544 .57054 L

.75295 .57103 L

.7515 .57151 L

.75005 .57199 L

.7486 .57247 L

.74716 .57294 L

.74571 .5734 L

.74426 .57386 L

.74281 .57432 L

.74136 .57477 L

.73991 .57521 L

.73846 .57565 L

.73701 .57609 L

.73556 .57652 L

.73411 .57694 L

.73266 .57737 L

.73121 .57778 L

.72976 .5782 L

.72831 .57861 L

.72686 .57901 L

.72541 .57941 L

.72396 .57981 L

.72251 .5802 L

.72106 .58059 L

.71961 .58098 L

.71816 .58136 L

.71671 .58174 L

.71526 .58212 L

.71381 .58249 L

.71237 .58286 L

.71092 .58322 L

.70947 .58358 L

.70802 .58394 L

.70657 .58429 L

.70512 .58464 L

.70367 .58499 L

.70222 .58534 L

.70077 .58568 L

.69932 .58602 L

.69787 .58636 L

.69642 .58669 L

.69497 .58702 L

.69352 .58735 L

.69207 .58767 L

.69062 .58799 L

.68917 .58831 L

.68772 .58863 L

Mistroke

.68627 .58894 L

.68482 .58925 L

.68337 .58956 L

.68192 .58986 L

.68047 .59016 L

.67902 .59046 L

.67757 .59076 L

.67613 .59105 L

.67468 .59134 L

.67323 .59163 L

.67178 .59191 L

.67033 .5922 L

.66888 .59247 L

.66743 .59275 L

.66598 .59303 L

.66453 .5933 L

.66308 .59357 L

.66163 .59383 L

.66018 .59409 L

.65873 .59435 L

.65728 .59461 L

.65583 .59487 L

.65438 .59512 L

.65293 .59537 L

.65148 .59561 L

.65003 .59585 L

.64858 .59609 L

.64713 .59633 L

.64568 .59656 L

.64423 .59679 L

.64278 .59702 L

.64134 .59724 L

.63989 .59747 L

.63844 .59769 L

.63699 .5979 L

.63554 .59811 L

.63409 .59832 L

.63264 .59852 L

.63119 .59873 L

.62974 .59892 L

.62829 .59912 L

.62684 .59931 L

.62539 .5995 L

.62394 .59968 L

.62249 .59987 L

.62104 .60004 L

.61959 .60021 L

.61814 .60038 L

.61669 .60055 L

.61524 .60071 L

Mistroke

.61379 .60087 L

.61234 .60102 L

.61089 .60117 L

.60944 .60131 L

.60799 .60145 L

.60654 .60159 L

.6051 .60172 L

.60365 .60185 L

.6022 .60197 L

.60075 .60209 L

.5993 .6022 L

.59785 .60231 L

.5964 .60241 L

.59495 .60251 L

.5935 .60261 L

.59205 .6027 L

.5906 .60278 L

.58915 .60286 L

.5877 .60293 L

.58625 .60299 L

.5848 .60305 L

.58335 .60311 L

.5819 .60315 L

.58045 .6032 L

.579 .60324 L

.57755 .60326 L

.5761 .60329 L

.57465 .60331 L

.5732 .60332 L

.57175 .60332 L

.57031 .60332 L

.56886 .60331 L

.56741 .60329 L

.56596 .60326 L

.56451 .60323 L

.56306 .60319 L

.56161 .60314 L

.56016 .60309 L

.55871 .60303 L

.55726 .60295 L

.55581 .60287 L

.55436 .60279 L

.55291 .60269 L

.55146 .60258 L

.55001 .60247 L

.54856 .60234 L

.54711 .60221 L

.54566 .60206 L

.54421 .60191 L

.54276 .60175 L

Mistroke

.54131 .60157 L

.53986 .60139 L

.53841 .60119 L

.53696 .60099 L

.53551 .60077 L

.53407 .60054 L

.53262 .6003 L

.53117 .60005 L

.52972 .59979 L

.52827 .59951 L

.52682 .59922 L

.52537 .59892 L

.52392 .59861 L

.52247 .59828 L

.52102 .59794 L

.51957 .59759 L

.51812 .59722 L

.51667 .59683 L

.51522 .59644 L

.51377 .59602 L

.51232 .59559 L

.51087 .59515 L

.50942 .59469 L

.50797 .59422 L

.50652 .59372 L

.50507 .59321 L

.50362 .59269 L

.50217 .59214 L

.50072 .59158 L

.49928 .591 L

.49783 .5904 L

.49638 .58978 L

.49493 .58914 L

.49348 .58848 L

.49203 .58779 L

.49058 .58709 L

.48913 .58637 L

.48768 .58563 L

.48623 .58486 L

.48478 .58407 L

.48333 .58325 L

.48188 .58241 L

.48043 .58155 L

.47898 .58066 L

.47753 .57975 L

.47608 .57881 L

.47463 .57784 L

.47318 .57684 L

.47173 .57582 L

.47028 .57477 L

Mistroke

.46883 .57368 L

.46738 .57257 L

.46593 .57142 L

.46449 .57025 L

.46304 .56904 L

.46159 .56779 L

.46014 .56651 L

.45869 .5652 L

.45724 .56385 L

.45579 .56246 L

.45434 .56103 L

.45289 .55956 L

.45144 .55806 L

.44999 .5565 L

.44854 .55491 L

.44709 .55327 L

.44564 .55159 L

.44419 .54985 L

.44274 .54807 L

.44129 .54624 L

.43984 .54436 L

.43839 .54242 L

.43694 .54043 L

.43549 .53838 L

.43404 .53626 L

.43259 .53409 L

.43114 .53185 L

.42969 .52955 L

.42825 .52717 L

.4268 .52472 L

.42535 .5222 L

.4239 .5196 L

.42245 .51691 L

.421 .51414 L

.41955 .51128 L

.4181 .50832 L

.41665 .50527 L

.4152 .50211 L

.41375 .49883 L

.4123 .49544 L

.41085 .49193 L

.4094 .48828 L

.40795 .48449 L

.4065 .48054 L

.40505 .47643 L

.4036 .47215 L

.40215 .46767 L

.4007 .46299 L

.39925 .45807 L

.3978 .4529 L

Mistroke

.39635 .44744 L

.3949 .44166 L

.39346 .43552 L

.39201 .42895 L

.39056 .42188 L

.38911 .41421 L

.38766 .4058 L

.38621 .39643 L

.38476 .38575 L

.38318 .35986 L

.38084 .33444 L

.38005 .30902 L

Mfstroke

.75875 .04901 m

.7573 .0485 L

.75585 .048 L

.7544 .0475 L

.75295 .04701 L

.7515 .04652 L

.75005 .04604 L

.7486 .04557 L

.74716 .0451 L

.74571 .04463 L

.74426 .04417 L

.74281 .04372 L

.74136 .04327 L

.73991 .04282 L

.73846 .04238 L

.73701 .04195 L

.73556 .04152 L

.73411 .04109 L

.73266 .04067 L

.73121 .04025 L

.72976 .03984 L

.72831 .03943 L

.72686 .03902 L

.72541 .03862 L

.72396 .03822 L

.72251 .03783 L

.72106 .03744 L

.71961 .03705 L

.71816 .03667 L

.71671 .03629 L

.71526 .03592 L

.71381 .03555 L

.71237 .03518 L

.71092 .03481 L

.70947 .03445 L

.70802 .03409 L

.70657 .03374 L

.70512 .03339 L

.70367 .03304 L

.70222 .03269 L

.70077 .03235 L

.69932 .03201 L

.69787 .03168 L

.69642 .03134 L

.69497 .03101 L

.69352 .03069 L

.69207 .03036 L

.69062 .03004 L

.68917 .02972 L

.68772 .02941 L

Mistroke

.68627 .02909 L

.68482 .02878 L

.68337 .02848 L

.68192 .02817 L

.68047 .02787 L

.67902 .02757 L

.67757 .02728 L

.67613 .02698 L

.67468 .02669 L

.67323 .02641 L

.67178 .02612 L

.67033 .02584 L

.66888 .02556 L

.66743 .02528 L

.66598 .02501 L

.66453 .02474 L

.66308 .02447 L

.66163 .0242 L

.66018 .02394 L

.65873 .02368 L

.65728 .02342 L

.65583 .02317 L

.65438 .02292 L

.65293 .02267 L

.65148 .02242 L

.65003 .02218 L

.64858 .02194 L

.64713 .02171 L

.64568 .02147 L

.64423 .02124 L

.64278 .02101 L

.64134 .02079 L

.63989 .02057 L

.63844 .02035 L

.63699 .02014 L

.63554 .01992 L

.63409 .01971 L

.63264 .01951 L

.63119 .01931 L

.62974 .01911 L

.62829 .01891 L

.62684 .01872 L

.62539 .01854 L

.62394 .01835 L

.62249 .01817 L

.62104 .01799 L

.61959 .01782 L

.61814 .01765 L

.61669 .01748 L

.61524 .01732 L

Mistroke

.61379 .01717 L

.61234 .01701 L

.61089 .01686 L

.60944 .01672 L

.60799 .01658 L

.60654 .01644 L

.6051 .01631 L

.60365 .01618 L

.6022 .01606 L

.60075 .01594 L

.5993 .01583 L

.59785 .01572 L

.5964 .01562 L

.59495 .01552 L

.5935 .01543 L

.59205 .01534 L

.5906 .01526 L

.58915 .01518 L

.5877 .01511 L

.58625 .01504 L

.5848 .01498 L

.58335 .01493 L

.5819 .01488 L

.58045 .01484 L

.579 .0148 L

.57755 .01477 L

.5761 .01475 L

.57465 .01473 L

.5732 .01472 L

.57175 .01472 L

.57031 .01472 L

.56886 .01473 L

.56741 .01474 L

.56596 .01477 L

.56451 .0148 L

.56306 .01484 L

.56161 .01489 L

.56016 .01494 L

.55871 .01501 L

.55726 .01508 L

.55581 .01516 L

.55436 .01525 L

.55291 .01535 L

.55146 .01545 L

.55001 .01557 L

.54856 .01569 L

.54711 .01583 L

.54566 .01597 L

.54421 .01612 L

.54276 .01629 L

Mistroke

.54131 .01646 L

.53986 .01665 L

.53841 .01684 L

.53696 .01705 L

.53551 .01726 L

.53407 .01749 L

.53262 .01773 L

.53117 .01798 L

.52972 .01825 L

.52827 .01852 L

.52682 .01881 L

.52537 .01911 L

.52392 .01942 L

.52247 .01975 L

.52102 .02009 L

.51957 .02045 L

.51812 .02082 L

.51667 .0212 L

.51522 .0216 L

.51377 .02201 L

.51232 .02244 L

.51087 .02288 L

.50942 .02334 L

.50797 .02382 L

.50652 .02431 L

.50507 .02482 L

.50362 .02535 L

.50217 .02589 L

.50072 .02646 L

.49928 .02704 L

.49783 .02764 L

.49638 .02826 L

.49493 .0289 L

.49348 .02956 L

.49203 .03024 L

.49058 .03094 L

.48913 .03166 L

.48768 .03241 L

.48623 .03318 L

.48478 .03397 L

.48333 .03478 L

.48188 .03562 L

.48043 .03648 L

.47898 .03737 L

.47753 .03829 L

.47608 .03923 L

.47463 .0402 L

.47318 .04119 L

.47173 .04222 L

.47028 .04327 L

Mistroke

.46883 .04435 L

.46738 .04546 L

.46593 .04661 L

.46449 .04779 L

.46304 .049 L

.46159 .05024 L

.46014 .05152 L

.45869 .05284 L

.45724 .05419 L

.45579 .05558 L

.45434 .057 L

.45289 .05847 L

.45144 .05998 L

.44999 .06153 L

.44854 .06312 L

.44709 .06476 L

.44564 .06645 L

.44419 .06818 L

.44274 .06996 L

.44129 .07179 L

.43984 .07368 L

.43839 .07561 L

.43694 .07761 L

.43549 .07966 L

.43404 .08177 L

.43259 .08394 L

.43114 .08618 L

.42969 .08849 L

.42825 .09086 L

.4268 .09331 L

.42535 .09583 L

.4239 .09844 L

.42245 .10112 L

.421 .10389 L

.41955 .10675 L

.4181 .10971 L

.41665 .11277 L

.4152 .11593 L

.41375 .1192 L

.4123 .12259 L

.41085 .12611 L

.4094 .12976 L

.40795 .13355 L

.4065 .13749 L

.40505 .1416 L

.4036 .14588 L

.40215 .15036 L

.4007 .15505 L

.39925 .15997 L

.3978 .16514 L

Mistroke

.39635 .1706 L

.3949 .17637 L

.39346 .18252 L

.39201 .18909 L

.39056 .19615 L

.38911 .20382 L

.38766 .21223 L

.38621 .2216 L

.38476 .23228 L

.38318 .25817 L

.38084 .28359 L

.38005 .30902 L

Mfstroke

1 0 0 r

.3949 .53505 m

.39201 .53566 L

.38911 .53626 L

.38621 .53686 L

.38331 .53746 L

.38041 .53806 L

.37751 .53865 L

.37461 .53923 L

.37171 .53982 L

.36881 .54039 L

.36591 .54096 L

.36301 .54153 L

.36011 .5421 L

.35722 .54265 L

.35432 .5432 L

.35142 .54375 L

.34852 .54429 L

.34562 .54482 L

.34272 .54535 L

.33982 .54587 L

.33692 .54639 L

.33402 .54689 L

.33112 .54739 L

.32822 .54789 L

.32532 .54837 L

.32243 .54885 L

.31953 .54932 L

.31663 .54978 L

.31373 .55023 L

.31083 .55067 L

.30793 .5511 L

.30503 .55153 L

.30213 .55194 L

.29923 .55234 L

.29633 .55274 L

.29343 .55312 L

.29053 .55349 L

.28763 .55385 L

.28474 .55419 L

.28184 .55453 L

.27894 .55485 L

.27604 .55516 L

.27314 .55545 L

.27024 .55574 L

.26734 .556 L

.26444 .55625 L

.26154 .55649 L

.25864 .55671 L

.25574 .55691 L

.25284 .5571 L

Mistroke

.24995 .55727 L

.24705 .55742 L

.24415 .55756 L

.24125 .55767 L

.23835 .55776 L

.23545 .55783 L

.23255 .55789 L

.22965 .55792 L

.22675 .55793 L

.22385 .55791 L

.22095 .55787 L

.21805 .55781 L

.21516 .55772 L

.21226 .55761 L

.20936 .55746 L

.20646 .55729 L

.20356 .55709 L

.20066 .55686 L

.19776 .5566 L

.19486 .5563 L

.19196 .55598 L

.18906 .55562 L

.18616 .55522 L

.18326 .55479 L

.18037 .55432 L

.17747 .55381 L

.17457 .55326 L

.17167 .55266 L

.16877 .55203 L

.16587 .55135 L

.16297 .55062 L

.16007 .54984 L

.15717 .54901 L

.15427 .54813 L

.15137 .54719 L

.14847 .5462 L

.14558 .54515 L

.14268 .54404 L

.13978 .54287 L

.13688 .54163 L

.13398 .54032 L

.13108 .53894 L

.12818 .53749 L

.12528 .53595 L

.12238 .53434 L

.11948 .53264 L

.11658 .53086 L

.11368 .52898 L

.11078 .527 L

.10789 .52492 L

Mistroke

.10499 .52273 L

.10209 .52043 L

.09919 .51801 L

.09629 .51546 L

.09339 .51279 L

.09049 .50997 L

.08759 .507 L

.08469 .50387 L

.08179 .50057 L

.07889 .49709 L

.07599 .49342 L

.0731 .48954 L

.0702 .48542 L

.0673 .48106 L

.0644 .47644 L

.0615 .47151 L

.0586 .46626 L

.0557 .46064 L

.0528 .45461 L

.0499 .4481 L

.047 .44105 L

.0441 .43336 L

.0412 .42488 L

.03831 .41544 L

.03541 .40473 L

.03251 .39226 L

.02961 .37706 L

.02671 .35655 L

.02381 .30902 L

Mfstroke

.3949 .08299 m

.39201 .08238 L

.38911 .08177 L

.38621 .08117 L

.38331 .08057 L

.38041 .07998 L

.37751 .07939 L

.37461 .0788 L

.37171 .07822 L

.36881 .07764 L

.36591 .07707 L

.36301 .0765 L

.36011 .07594 L

.35722 .07538 L

.35432 .07483 L

.35142 .07428 L

.34852 .07374 L

.34562 .07321 L

.34272 .07268 L

.33982 .07216 L

.33692 .07165 L

.33402 .07114 L

.33112 .07064 L

.32822 .07015 L

.32532 .06966 L

.32243 .06919 L

.31953 .06872 L

.31663 .06826 L

.31373 .06781 L

.31083 .06736 L

.30793 .06693 L

.30503 .06651 L

.30213 .06609 L

.29923 .06569 L

.29633 .0653 L

.29343 .06492 L

.29053 .06455 L

.28763 .06419 L

.28474 .06384 L

.28184 .0635 L

.27894 .06318 L

.27604 .06287 L

.27314 .06258 L

.27024 .0623 L

.26734 .06203 L

.26444 .06178 L

.26154 .06154 L

.25864 .06132 L

.25574 .06112 L

.25284 .06093 L

Mistroke

.24995 .06076 L

.24705 .06061 L

.24415 .06048 L

.24125 .06037 L

.23835 .06027 L

.23545 .0602 L

.23255 .06015 L

.22965 .06012 L

.22675 .06011 L

.22385 .06012 L

.22095 .06016 L

.21805 .06022 L

.21516 .06031 L

.21226 .06043 L

.20936 .06057 L

.20646 .06074 L

.20356 .06094 L

.20066 .06117 L

.19776 .06143 L

.19486 .06173 L

.19196 .06206 L

.18906 .06242 L

.18616 .06281 L

.18326 .06324 L

.18037 .06372 L

.17747 .06423 L

.17457 .06478 L

.17167 .06537 L

.16877 .06601 L

.16587 .06669 L

.16297 .06742 L

.16007 .0682 L

.15717 .06902 L

.15427 .0699 L

.15137 .07084 L

.14847 .07183 L

.14558 .07288 L

.14268 .07399 L

.13978 .07516 L

.13688 .0764 L

.13398 .07771 L

.13108 .07909 L

.12818 .08055 L

.12528 .08208 L

.12238 .08369 L

.11948 .08539 L

.11658 .08718 L

.11368 .08906 L

.11078 .09104 L

.10789 .09312 L

Mistroke

.10499 .0953 L

.10209 .0976 L

.09919 .10002 L

.09629 .10257 L

.09339 .10525 L

.09049 .10807 L

.08759 .11104 L

.08469 .11416 L

.08179 .11746 L

.07889 .12094 L

.07599 .12462 L

.0731 .1285 L

.0702 .13261 L

.0673 .13697 L

.0644 .1416 L

.0615 .14652 L

.0586 .15177 L

.0557 .15739 L

.0528 .16343 L

.0499 .16993 L

.047 .17698 L

.0441 .18468 L

.0412 .19315 L

.03831 .2026 L

.03541 .21331 L

.03251 .22578 L

.02961 .24098 L

.02671 .26148 L

.02381 .30902 L

Mfstroke

.97619 .50094 m

.97474 .50107 L

.97329 .5012 L

.97184 .50132 L

.97039 .50145 L

.96894 .50157 L

.96749 .50169 L

.96604 .50182 L

.96459 .50194 L

.96314 .50205 L

.96169 .50217 L

.96024 .50229 L

.9588 .5024 L

.95735 .50252 L

.9559 .50263 L

.95445 .50274 L

.953 .50285 L

.95155 .50296 L

.9501 .50307 L

.94865 .50317 L

.9472 .50328 L

.94575 .50338 L

.9443 .50348 L

.94285 .50358 L

.9414 .50367 L

.93995 .50377 L

.9385 .50386 L

.93705 .50396 L

.9356 .50405 L

.93415 .50414 L

.9327 .50422 L

.93125 .50431 L

.9298 .50439 L

.92835 .50447 L

.9269 .50455 L

.92545 .50463 L

.92401 .5047 L

.92256 .50478 L

.92111 .50485 L

.91966 .50492 L

.91821 .50498 L

.91676 .50505 L

.91531 .50511 L

.91386 .50517 L

.91241 .50523 L

.91096 .50528 L

.90951 .50533 L

.90806 .50538 L

.90661 .50543 L

.90516 .50547 L

Mistroke

.90371 .50551 L

.90226 .50555 L

.90081 .50559 L

.89936 .50562 L

.89791 .50565 L

.89646 .50568 L

.89501 .5057 L

.89356 .50573 L

.89211 .50574 L

.89066 .50576 L

.88922 .50577 L

.88777 .50578 L

.88632 .50578 L

.88487 .50578 L

.88342 .50578 L

.88197 .50578 L

.88052 .50577 L

.87907 .50575 L

.87762 .50574 L

.87617 .50572 L

.87472 .50569 L

.87327 .50566 L

.87182 .50563 L

.87037 .50559 L

.86892 .50555 L

.86747 .5055 L

.86602 .50545 L

.86457 .5054 L

.86312 .50533 L

.86167 .50527 L

.86022 .5052 L

.85877 .50512 L

.85732 .50504 L

.85587 .50496 L

.85442 .50487 L

.85298 .50477 L

.85153 .50467 L

.85008 .50456 L

.84863 .50445 L

.84718 .50433 L

.84573 .5042 L

.84428 .50407 L

.84283 .50393 L

.84138 .50378 L

.83993 .50363 L

.83848 .50347 L

.83703 .5033 L

.83558 .50313 L

.83413 .50294 L

.83268 .50275 L

Mistroke

.83123 .50256 L

.82978 .50235 L

.82833 .50213 L

.82688 .50191 L

.82543 .50168 L

.82398 .50143 L

.82253 .50118 L

.82108 .50092 L

.81963 .50065 L

.81819 .50036 L

.81674 .50007 L

.81529 .49976 L

.81384 .49945 L

.81239 .49912 L

.81094 .49878 L

.80949 .49842 L

.80804 .49805 L

.80659 .49767 L

.80514 .49727 L

.80369 .49685 L

.80224 .49642 L

.80079 .49597 L

.79934 .49551 L

.79789 .49502 L

.79644 .49452 L

.79499 .49399 L

.79354 .49345 L

.79209 .49288 L

.79064 .49228 L

.78919 .49166 L

.78774 .49102 L

.78629 .49034 L

.78484 .48963 L

.78339 .48889 L

.78195 .48812 L

.7805 .48731 L

.77905 .48645 L

.7776 .48556 L

.77615 .48463 L

.7747 .48365 L

.77325 .48262 L

.7718 .48155 L

.77035 .48044 L

.7689 .47928 L

.76745 .47809 L

.766 .47688 L

.76455 .47567 L

.7631 .47447 L

.76165 .47332 L

.7602 .47223 L

Mistroke

.75875 .47122 L

.7573 .4703 L

.75585 .46948 L

.7544 .46875 L

.75295 .46812 L

.7515 .46758 L

.75005 .46712 L

.7486 .46673 L

.74716 .4664 L

.74571 .46612 L

.74426 .4659 L

.74281 .46572 L

.74136 .46557 L

.73991 .46547 L

.73846 .46539 L

.73701 .46534 L

.73556 .46532 L

.73411 .46532 L

.73266 .46534 L

.73121 .46537 L

.72976 .46543 L

.72831 .4655 L

.72686 .46558 L

.72541 .46568 L

.72396 .46579 L

.72251 .46591 L

.72106 .46604 L

.71961 .46618 L

.71816 .46633 L

.71671 .46649 L

.71526 .46665 L

.71381 .46682 L

.71237 .467 L

.71092 .46719 L

.70947 .46738 L

.70802 .46757 L

.70657 .46778 L

.70512 .46798 L

.70367 .46819 L

.70222 .46841 L

.70077 .46863 L

.69932 .46885 L

.69787 .46908 L

.69642 .46932 L

.69497 .46955 L

.69352 .46979 L

.69207 .47003 L

.69062 .47027 L

.68917 .47052 L

.68772 .47077 L

Mistroke

.68627 .47102 L

.68482 .47128 L

.68337 .47154 L

.68192 .4718 L

.68047 .47206 L

.67902 .47232 L

.67757 .47259 L

.67613 .47286 L

.67468 .47313 L

.67323 .4734 L

.67178 .47368 L

.67033 .47395 L

.66888 .47423 L

.66743 .47451 L

.66598 .47479 L

.66453 .47507 L

.66308 .47535 L

.66163 .47564 L

.66018 .47593 L

.65873 .47621 L

.65728 .4765 L

.65583 .47679 L

.65438 .47708 L

.65293 .47738 L

.65148 .47767 L

.65003 .47797 L

.64858 .47826 L

.64713 .47856 L

.64568 .47886 L

.64423 .47915 L

.64278 .47945 L

.64134 .47976 L

.63989 .48006 L

.63844 .48036 L

.63699 .48066 L

.63554 .48097 L

.63409 .48127 L

.63264 .48158 L

.63119 .48189 L

.62974 .48219 L

.62829 .4825 L

.62684 .48281 L

.62539 .48312 L

.62394 .48343 L

.62249 .48374 L

.62104 .48406 L

.61959 .48437 L

.61814 .48468 L

.61669 .485 L

.61524 .48531 L

Mistroke

.61379 .48563 L

.61234 .48594 L

.61089 .48626 L

.60944 .48658 L

.60799 .48689 L

.60654 .48721 L

.6051 .48753 L

.60365 .48785 L

.6022 .48817 L

.60075 .48849 L

.5993 .48881 L

.59785 .48913 L

.5964 .48945 L

.59495 .48977 L

.5935 .4901 L

.59205 .49042 L

.5906 .49074 L

.58915 .49107 L

.5877 .49139 L

.58625 .49172 L

.5848 .49204 L

.58335 .49237 L

.5819 .49269 L

.58045 .49302 L

.579 .49334 L

.57755 .49367 L

.5761 .494 L

.57465 .49433 L

.5732 .49465 L

.57175 .49498 L

.57031 .49531 L

.56886 .49564 L

.56741 .49597 L

.56596 .4963 L

.56451 .49663 L

.56306 .49696 L

.56161 .49729 L

.56016 .49762 L

.55871 .49795 L

.55726 .49828 L

.55581 .49861 L

.55436 .49894 L

.55291 .49927 L

.55146 .49961 L

.55001 .49994 L

.54856 .50027 L

.54711 .5006 L

.54566 .50093 L

.54421 .50127 L

.54276 .5016 L

Mistroke

.54131 .50193 L

.53986 .50227 L

.53841 .5026 L

.53696 .50293 L

.53551 .50327 L

.53407 .5036 L

.53262 .50394 L

.53117 .50427 L

.52972 .5046 L

.52827 .50494 L

.52682 .50527 L

.52537 .50561 L

.52392 .50594 L

.52247 .50628 L

.52102 .50661 L

.51957 .50695 L

.51812 .50728 L

.51667 .50761 L

.51522 .50795 L

.51377 .50828 L

.51232 .50862 L

.51087 .50895 L

.50942 .50929 L

.50797 .50962 L

.50652 .50996 L

.50507 .51029 L

.50362 .51063 L

.50217 .51096 L

.50072 .5113 L

.49928 .51163 L

.49783 .51197 L

.49638 .5123 L

.49493 .51264 L

.49348 .51297 L

.49203 .51331 L

.49058 .51364 L

.48913 .51398 L

.48768 .51431 L

.48623 .51464 L

.48478 .51498 L

.48333 .51531 L

.48188 .51565 L

.48043 .51598 L

.47898 .51631 L

.47753 .51665 L

.47608 .51698 L

.47463 .51731 L

.47318 .51765 L

.47173 .51798 L

.47028 .51831 L

Mistroke

.46883 .51864 L

.46738 .51897 L

.46593 .51931 L

.46449 .51964 L

.46304 .51997 L

.46159 .5203 L

.46014 .52063 L

.45869 .52096 L

.45724 .52129 L

.45579 .52162 L

.45434 .52195 L

.45289 .52228 L

.45144 .52261 L

.44999 .52294 L

.44854 .52326 L

.44709 .52359 L

.44564 .52392 L

.44419 .52425 L

.44274 .52457 L

.44129 .5249 L

.43984 .52522 L

.43839 .52555 L

.43694 .52587 L

.43549 .5262 L

.43404 .52652 L

.43259 .52685 L

.43114 .52717 L

.42969 .52749 L

.42825 .52781 L

.4268 .52813 L

.42535 .52846 L

.4239 .52878 L

.42245 .5291 L

.421 .52941 L

.41955 .52973 L

.4181 .53005 L

.41665 .53037 L

.4152 .53069 L

.41375 .531 L

.4123 .53132 L

.41085 .53163 L

.4094 .53195 L

.40795 .53226 L

.4065 .53257 L

.40505 .53288 L

.4036 .53319 L

.40215 .5335 L

.4007 .53381 L

.39925 .53412 L

.3978 .53443 L

Mistroke

Mfstroke

.97619 .11709 m

.97474 .11697 L

.97329 .11684 L

.97184 .11671 L

.97039 .11659 L

.96894 .11646 L

.96749 .11634 L

.96604 .11622 L

.96459 .1161 L

.96314 .11598 L

.96169 .11586 L

.96024 .11575 L

.9588 .11563 L

.95735 .11552 L

.9559 .1154 L

.95445 .11529 L

.953 .11518 L

.95155 .11507 L

.9501 .11497 L

.94865 .11486 L

.9472 .11476 L

.94575 .11466 L

.9443 .11456 L

.94285 .11446 L

.9414 .11436 L

.93995 .11426 L

.9385 .11417 L

.93705 .11408 L

.9356 .11399 L

.93415 .1139 L

.9327 .11381 L

.93125 .11373 L

.9298 .11364 L

.92835 .11356 L

.9269 .11348 L

.92545 .11341 L

.92401 .11333 L

.92256 .11326 L

.92111 .11319 L

.91966 .11312 L

.91821 .11305 L

.91676 .11299 L

.91531 .11293 L

.91386 .11287 L

.91241 .11281 L

.91096 .11275 L

.90951 .1127 L

.90806 .11265 L

.90661 .11261 L

.90516 .11256 L

Mistroke

.90371 .11252 L

.90226 .11248 L

.90081 .11244 L

.89936 .11241 L

.89791 .11238 L

.89646 .11235 L

.89501 .11233 L

.89356 .11231 L

.89211 .11229 L

.89066 .11228 L

.88922 .11226 L

.88777 .11226 L

.88632 .11225 L

.88487 .11225 L

.88342 .11225 L

.88197 .11226 L

.88052 .11227 L

.87907 .11228 L

.87762 .1123 L

.87617 .11232 L

.87472 .11234 L

.87327 .11237 L

.87182 .11241 L

.87037 .11244 L

.86892 .11249 L

.86747 .11253 L

.86602 .11258 L

.86457 .11264 L

.86312 .1127 L

.86167 .11277 L

.86022 .11283 L

.85877 .11291 L

.85732 .11299 L

.85587 .11308 L

.85442 .11317 L

.85298 .11326 L

.85153 .11337 L

.85008 .11347 L

.84863 .11359 L

.84718 .11371 L

.84573 .11384 L

.84428 .11397 L

.84283 .11411 L

.84138 .11425 L

.83993 .11441 L

.83848 .11457 L

.83703 .11473 L

.83558 .11491 L

.83413 .11509 L

.83268 .11528 L

Mistroke

.83123 .11548 L

.82978 .11569 L

.82833 .1159 L

.82688 .11613 L

.82543 .11636 L

.82398 .1166 L

.82253 .11685 L

.82108 .11712 L

.81963 .11739 L

.81819 .11767 L

.81674 .11796 L

.81529 .11827 L

.81384 .11859 L

.81239 .11892 L

.81094 .11926 L

.80949 .11961 L

.80804 .11998 L

.80659 .12037 L

.80514 .12077 L

.80369 .12118 L

.80224 .12161 L

.80079 .12206 L

.79934 .12253 L

.79789 .12301 L

.79644 .12351 L

.79499 .12404 L

.79354 .12459 L

.79209 .12516 L

.79064 .12575 L

.78919 .12637 L

.78774 .12702 L

.78629 .1277 L

.78484 .1284 L

.78339 .12914 L

.78195 .12992 L

.7805 .13073 L

.77905 .13158 L

.7776 .13247 L

.77615 .13341 L

.7747 .13439 L

.77325 .13541 L

.7718 .13648 L

.77035 .1376 L

.7689 .13876 L

.76745 .13994 L

.766 .14115 L

.76455 .14236 L

.7631 .14356 L

.76165 .14471 L

.7602 .1458 L

Mistroke

.75875 .14682 L

.7573 .14774 L

.75585 .14856 L

.7544 .14928 L

.75295 .14991 L

.7515 .15045 L

.75005 .15092 L

.7486 .15131 L

.74716 .15164 L

.74571 .15191 L

.74426 .15214 L

.74281 .15232 L

.74136 .15246 L

.73991 .15257 L

.73846 .15264 L

.73701 .15269 L

.73556 .15272 L

.73411 .15272 L

.73266 .1527 L

.73121 .15266 L

.72976 .15261 L

.72831 .15254 L

.72686 .15245 L

.72541 .15235 L

.72396 .15225 L

.72251 .15213 L

.72106 .152 L

.71961 .15185 L

.71816 .15171 L

.71671 .15155 L

.71526 .15138 L

.71381 .15121 L

.71237 .15103 L

.71092 .15085 L

.70947 .15066 L

.70802 .15046 L

.70657 .15026 L

.70512 .15005 L

.70367 .14984 L

.70222 .14962 L

.70077 .1494 L

.69932 .14918 L

.69787 .14895 L

.69642 .14872 L

.69497 .14848 L

.69352 .14825 L

.69207 .148 L

.69062 .14776 L

.68917 .14751 L

.68772 .14726 L

Mistroke

.68627 .14701 L

.68482 .14675 L

.68337 .1465 L

.68192 .14624 L

.68047 .14597 L

.67902 .14571 L

.67757 .14544 L

.67613 .14517 L

.67468 .1449 L

.67323 .14463 L

.67178 .14436 L

.67033 .14408 L

.66888 .14381 L

.66743 .14353 L

.66598 .14325 L

.66453 .14296 L

.66308 .14268 L

.66163 .1424 L

.66018 .14211 L

.65873 .14182 L

.65728 .14153 L

.65583 .14124 L

.65438 .14095 L

.65293 .14066 L

.65148 .14036 L

.65003 .14007 L

.64858 .13977 L

.64713 .13948 L

.64568 .13918 L

.64423 .13888 L

.64278 .13858 L

.64134 .13828 L

.63989 .13798 L

.63844 .13767 L

.63699 .13737 L

.63554 .13707 L

.63409 .13676 L

.63264 .13645 L

.63119 .13615 L

.62974 .13584 L

.62829 .13553 L

.62684 .13522 L

.62539 .13491 L

.62394 .1346 L

.62249 .13429 L

.62104 .13398 L

.61959 .13366 L

.61814 .13335 L

.61669 .13304 L

.61524 .13272 L

Mistroke

.61379 .13241 L

.61234 .13209 L

.61089 .13177 L

.60944 .13146 L

.60799 .13114 L

.60654 .13082 L

.6051 .1305 L

.60365 .13018 L

.6022 .12986 L

.60075 .12954 L

.5993 .12922 L

.59785 .1289 L

.5964 .12858 L

.59495 .12826 L

.5935 .12794 L

.59205 .12761 L

.5906 .12729 L

.58915 .12697 L

.5877 .12664 L

.58625 .12632 L

.5848 .12599 L

.58335 .12567 L

.5819 .12534 L

.58045 .12502 L

.579 .12469 L

.57755 .12436 L

.5761 .12404 L

.57465 .12371 L

.5732 .12338 L

.57175 .12305 L

.57031 .12272 L

.56886 .12239 L

.56741 .12207 L

.56596 .12174 L

.56451 .12141 L

.56306 .12108 L

.56161 .12075 L

.56016 .12042 L

.55871 .12009 L

.55726 .11975 L

.55581 .11942 L

.55436 .11909 L

.55291 .11876 L

.55146 .11843 L

.55001 .1181 L

.54856 .11776 L

.54711 .11743 L

.54566 .1171 L

.54421 .11677 L

.54276 .11643 L

Mistroke

.54131 .1161 L

.53986 .11577 L

.53841 .11543 L

.53696 .1151 L

.53551 .11477 L

.53407 .11443 L

.53262 .1141 L

.53117 .11376 L

.52972 .11343 L

.52827 .1131 L

.52682 .11276 L

.52537 .11243 L

.52392 .11209 L

.52247 .11176 L

.52102 .11142 L

.51957 .11109 L

.51812 .11075 L

.51667 .11042 L

.51522 .11008 L

.51377 .10975 L

.51232 .10941 L

.51087 .10908 L

.50942 .10874 L

.50797 .10841 L

.50652 .10807 L

.50507 .10774 L

.50362 .1074 L

.50217 .10707 L

.50072 .10673 L

.49928 .1064 L

.49783 .10607 L

.49638 .10573 L

.49493 .1054 L

.49348 .10506 L

.49203 .10473 L

.49058 .10439 L

.48913 .10406 L

.48768 .10372 L

.48623 .10339 L

.48478 .10306 L

.48333 .10272 L

.48188 .10239 L

.48043 .10205 L

.47898 .10172 L

.47753 .10139 L

.47608 .10105 L

.47463 .10072 L

.47318 .10039 L

.47173 .10006 L

.47028 .09972 L

Mistroke

.46883 .09939 L

.46738 .09906 L

.46593 .09873 L

.46449 .0984 L

.46304 .09807 L

.46159 .09774 L

.46014 .0974 L

.45869 .09707 L

.45724 .09674 L

.45579 .09641 L

.45434 .09608 L

.45289 .09576 L

.45144 .09543 L

.44999 .0951 L

.44854 .09477 L

.44709 .09444 L

.44564 .09412 L

.44419 .09379 L

.44274 .09346 L

.44129 .09314 L

.43984 .09281 L

.43839 .09248 L

.43694 .09216 L

.43549 .09184 L

.43404 .09151 L

.43259 .09119 L

.43114 .09087 L

.42969 .09054 L

.42825 .09022 L

.4268 .0899 L

.42535 .08958 L

.4239 .08926 L

.42245 .08894 L

.421 .08862 L

.41955 .0883 L

.4181 .08798 L

.41665 .08767 L

.4152 .08735 L

.41375 .08703 L

.4123 .08672 L

.41085 .0864 L

.4094 .08609 L

.40795 .08578 L

.4065 .08546 L

.40505 .08515 L

.4036 .08484 L

.40215 .08453 L

.4007 .08422 L

.39925 .08391 L

.3978 .0836 L

Mistroke

Mfstroke

0 .4 1 r

.76093 .56825 m

.76165 .56799 L

.76238 .56773 L

.7631 .56746 L

.76383 .56719 L

.76455 .56692 L

.76528 .56665 L

.766 .56638 L

.76672 .56611 L

.76745 .56584 L

.76817 .56556 L

.7689 .56528 L

.76962 .565 L

.77035 .56471 L

.77107 .56443 L

.7718 .56415 L

.77252 .56386 L

.77325 .56357 L

.77397 .56328 L

.7747 .56298 L

.77542 .56269 L

.77615 .56239 L

.77687 .56209 L

.7776 .56179 L

.77832 .56149 L

.77905 .56118 L

.77977 .56087 L

.7805 .56056 L

.78122 .56025 L

.78195 .55994 L

.78267 .55962 L

.78339 .5593 L

.78412 .55898 L

.78484 .55866 L

.78557 .55834 L

.78629 .55801 L

.78702 .55768 L

.78774 .55735 L

.78847 .55701 L

.78919 .55668 L

.78992 .55634 L

.79064 .556 L

.79137 .55565 L

.79209 .55531 L

.79282 .55496 L

.79354 .55461 L

.79427 .55425 L

.79499 .5539 L

.79572 .55354 L

.79644 .55317 L

Mistroke

.79717 .55281 L

.79789 .55244 L

.79862 .55207 L

.79934 .5517 L

.80007 .55132 L

.80079 .55094 L

.80151 .55056 L

.80224 .55018 L

.80296 .54979 L

.80369 .5494 L

.80441 .54901 L

.80514 .54861 L

.80586 .54821 L

.80659 .54781 L

.80731 .54741 L

.80804 .547 L

.80876 .54659 L

.80949 .54617 L

.81021 .54575 L

.81094 .54533 L

.81166 .54491 L

.81239 .54448 L

.81311 .54405 L

.81384 .54362 L

.81456 .54318 L

.81529 .54274 L

.81601 .54229 L

.81674 .54184 L

.81746 .54139 L

.81819 .54094 L

.81891 .54047 L

.81963 .54001 L

.82036 .53955 L

.82108 .53907 L

.82181 .5386 L

.82253 .53812 L

.82326 .53764 L

.82398 .53716 L

.82471 .53666 L

.82543 .53617 L

.82616 .53567 L

.82688 .53517 L

.82761 .53466 L

.82833 .53415 L

.82906 .53364 L

.82978 .53312 L

.83051 .53259 L

.83123 .53207 L

.83196 .53153 L

.83268 .531 L

Mistroke

.83341 .53045 L

.83413 .52991 L

.83486 .52936 L

.83558 .5288 L

.8363 .52824 L

.83703 .52768 L

.83775 .52711 L

.83848 .52653 L

.8392 .52595 L

.83993 .52537 L

.84065 .52478 L

.84138 .52418 L

.8421 .52359 L

.84283 .52298 L

.84355 .52237 L

.84428 .52176 L

.845 .52114 L

.84573 .52051 L

.84645 .51988 L

.84718 .51924 L

.8479 .5186 L

.84863 .51795 L

.84935 .51729 L

.85008 .51663 L

.8508 .51596 L

.85153 .51529 L

.85225 .51461 L

.85298 .51393 L

.8537 .51324 L

.85442 .51254 L

.85515 .51184 L

.85587 .51113 L

.8566 .51041 L

.85732 .50969 L

Mfstroke

.76093 .04978 m

.76165 .05005 L

.76238 .05031 L

.7631 .05057 L

.76383 .05084 L

.76455 .05111 L

.76528 .05138 L

.766 .05165 L

.76672 .05192 L

.76745 .0522 L

.76817 .05248 L

.7689 .05275 L

.76962 .05304 L

.77035 .05332 L

.77107 .0536 L

.7718 .05389 L

.77252 .05418 L

.77325 .05447 L

.77397 .05476 L

.7747 .05505 L

.77542 .05535 L

.77615 .05564 L

.77687 .05594 L

.7776 .05624 L

.77832 .05655 L

.77905 .05685 L

.77977 .05716 L

.7805 .05747 L

.78122 .05778 L

.78195 .0581 L

.78267 .05841 L

.78339 .05873 L

.78412 .05905 L

.78484 .05937 L

.78557 .0597 L

.78629 .06003 L

.78702 .06035 L

.78774 .06069 L

.78847 .06102 L

.78919 .06136 L

.78992 .0617 L

.79064 .06204 L

.79137 .06238 L

.79209 .06273 L

.79282 .06308 L

.79354 .06343 L

.79427 .06378 L

.79499 .06414 L

.79572 .0645 L

.79644 .06486 L

Mistroke

.79717 .06523 L

.79789 .06559 L

.79862 .06596 L

.79934 .06633 L

.80007 .06671 L

.80079 .06709 L

.80151 .06747 L

.80224 .06785 L

.80296 .06824 L

.80369 .06863 L

.80441 .06903 L

.80514 .06942 L

.80586 .06982 L

.80659 .07022 L

.80731 .07063 L

.80804 .07103 L

.80876 .07145 L

.80949 .07186 L

.81021 .07228 L

.81094 .0727 L

.81166 .07313 L

.81239 .07355 L

.81311 .07398 L

.81384 .07442 L

.81456 .07486 L

.81529 .0753 L

.81601 .07574 L

.81674 .07619 L

.81746 .07664 L

.81819 .0771 L

.81891 .07756 L

.81963 .07802 L

.82036 .07849 L

.82108 .07896 L

.82181 .07943 L

.82253 .07991 L

.82326 .08039 L

.82398 .08088 L

.82471 .08137 L

.82543 .08186 L

.82616 .08236 L

.82688 .08286 L

.82761 .08337 L

.82833 .08388 L

.82906 .0844 L

.82978 .08492 L

.83051 .08544 L

.83123 .08597 L

.83196 .0865 L

.83268 .08704 L

Mistroke

.83341 .08758 L

.83413 .08812 L

.83486 .08867 L

.83558 .08923 L

.8363 .08979 L

.83703 .09036 L

.83775 .09092 L

.83848 .0915 L

.8392 .09208 L

.83993 .09266 L

.84065 .09325 L

.84138 .09385 L

.8421 .09445 L

.84283 .09505 L

.84355 .09566 L

.84428 .09628 L

.845 .0969 L

.84573 .09752 L

.84645 .09816 L

.84718 .09879 L

.8479 .09944 L

.84863 .10009 L

.84935 .10074 L

.85008 .1014 L

.8508 .10207 L

.85153 .10274 L

.85225 .10342 L

.85298 .1041 L

.8537 .10479 L

.85442 .10549 L

.85515 .10619 L

.85587 .1069 L

.8566 .10762 L

.85732 .10834 L

Mfstroke

.85805 .50896 m

.85877 .50823 L

.8595 .50749 L

.86022 .50674 L

.86095 .50598 L

.86167 .50522 L

.8624 .50445 L

.86312 .50367 L

.86385 .50288 L

.86457 .50209 L

.8653 .50129 L

.86602 .50048 L

.86675 .49967 L

.86747 .49884 L

.8682 .49801 L

.86892 .49718 L

.86965 .49633 L

.87037 .49547 L

.8711 .49461 L

.87182 .49374 L

.87254 .49285 L

.87327 .49197 L

.87399 .49107 L

.87472 .49016 L

.87544 .48924 L

.87617 .48832 L

.87689 .48738 L

.87762 .48644 L

.87834 .48548 L

.87907 .48452 L

.87979 .48354 L

.88052 .48256 L

.88124 .48157 L

.88197 .48056 L

.88269 .47954 L

.88342 .47852 L

.88414 .47748 L

.88487 .47643 L

.88559 .47537 L

.88632 .47429 L

.88704 .47321 L

.88777 .47211 L

.88849 .471 L

.88922 .46988 L

.88994 .46874 L

.89066 .4676 L

.89139 .46643 L

.89211 .46526 L

.89284 .46407 L

.89356 .46286 L

Mistroke

.89429 .46163 L

.89501 .4604 L

.89574 .45915 L

.89646 .45788 L

.89719 .45659 L

.89791 .45529 L

.89864 .45397 L

.89936 .45263 L

.90009 .45128 L

.90081 .4499 L

.90154 .4485 L

.90226 .44709 L

.90299 .44565 L

.90371 .44419 L

.90444 .44271 L

.90516 .4412 L

.90589 .43966 L

.90661 .4381 L

.90733 .43652 L

.90806 .4349 L

.90878 .43326 L

.90951 .43159 L

.91023 .42988 L

.91096 .42813 L

.91168 .42635 L

.91241 .42453 L

.91313 .42267 L

.91386 .42077 L

.91458 .41882 L

.91531 .41681 L

.91603 .41475 L

.91676 .41263 L

.91748 .41044 L

.91821 .40819 L

.91893 .40584 L

.91966 .40341 L

.92038 .40088 L

.92111 .39824 L

.92183 .39545 L

.92256 .39251 L

.92328 .38939 L

.92401 .38602 L

.92473 .38234 L

.92545 .37824 L

.92618 .37354 L

.9269 .36774 L

.92763 .35916 L

.92727 .34569 L

.9269 .33223 L

Mfstroke

.85805 .10907 m

.85877 .1098 L

.8595 .11055 L

.86022 .1113 L

.86095 .11205 L

.86167 .11282 L

.8624 .11359 L

.86312 .11437 L

.86385 .11515 L

.86457 .11594 L

.8653 .11674 L

.86602 .11755 L

.86675 .11837 L

.86747 .11919 L

.8682 .12002 L

.86892 .12086 L

.86965 .1217 L

.87037 .12256 L

.8711 .12343 L

.87182 .1243 L

.87254 .12518 L

.87327 .12607 L

.87399 .12696 L

.87472 .12787 L

.87544 .12879 L

.87617 .12971 L

.87689 .13065 L

.87762 .1316 L

.87834 .13255 L

.87907 .13352 L

.87979 .13449 L

.88052 .13547 L

.88124 .13647 L

.88197 .13747 L

.88269 .13849 L

.88342 .13952 L

.88414 .14056 L

.88487 .14161 L

.88559 .14267 L

.88632 .14374 L

.88704 .14482 L

.88777 .14592 L

.88849 .14703 L

.88922 .14815 L

.88994 .14929 L

.89066 .15044 L

.89139 .1516 L

.89211 .15278 L

.89284 .15397 L

.89356 .15517 L

Mistroke

.89429 .1564 L

.89501 .15764 L

.89574 .15889 L

.89646 .16016 L

.89719 .16144 L

.89791 .16274 L

.89864 .16406 L

.89936 .1654 L

.90009 .16676 L

.90081 .16813 L

.90154 .16953 L

.90226 .17095 L

.90299 .17238 L

.90371 .17385 L

.90444 .17533 L

.90516 .17684 L

.90589 .17837 L

.90661 .17993 L

.90733 .18152 L

.90806 .18313 L

.90878 .18477 L

.90951 .18645 L

.91023 .18816 L

.91096 .1899 L

.91168 .19168 L

.91241 .1935 L

.91313 .19536 L

.91386 .19726 L

.91458 .19922 L

.91531 .20123 L

.91603 .20329 L

.91676 .2054 L

.91748 .20759 L

.91821 .20985 L

.91893 .21219 L

.91966 .21462 L

.92038 .21715 L

.92111 .2198 L

.92183 .22258 L

.92256 .22552 L

.92328 .22864 L

.92401 .23201 L

.92473 .2357 L

.92545 .23979 L

.92618 .24449 L

.9269 .25029 L

.92763 .25888 L

.92727 .27234 L

.9269 .2858 L

Mfstroke

.97619 .40035 m

.97474 .4006 L

.97329 .40086 L

.97184 .40112 L

.97039 .40137 L

.96894 .40163 L

.96749 .40188 L

.96604 .40214 L

.96459 .40239 L

.96314 .40264 L

.96169 .4029 L

.96024 .40315 L

.9588 .4034 L

.95735 .40365 L

.9559 .4039 L

.95445 .40415 L

.953 .4044 L

.95155 .40465 L

.9501 .4049 L

.94865 .40515 L

.9472 .40539 L

.94575 .40564 L

.9443 .40589 L

.94285 .40613 L

.9414 .40637 L

.93995 .40662 L

.9385 .40686 L

.93705 .4071 L

.9356 .40734 L

.93415 .40758 L

.9327 .40782 L

.93125 .40805 L

.9298 .40829 L

.92835 .40852 L

.9269 .40875 L

.92545 .40898 L

.92401 .40921 L

.92256 .40944 L

.92111 .40967 L

.91966 .40989 L

.91821 .41012 L

.91676 .41034 L

.91531 .41056 L

.91386 .41078 L

.91241 .41099 L

.91096 .4112 L

.90951 .41141 L

.90806 .41162 L

.90661 .41182 L

.90516 .41203 L

Mistroke

.90371 .41222 L

.90226 .41242 L

.90081 .41261 L

.89936 .4128 L

.89791 .41298 L

.89646 .41316 L

.89501 .41334 L

.89356 .41351 L

.89211 .41367 L

.89066 .41383 L

.88922 .41399 L

.88777 .41413 L

.88632 .41427 L

.88487 .4144 L

.88342 .41453 L

.88197 .41464 L

.88052 .41474 L

.87907 .41483 L

.87762 .41491 L

.87617 .41498 L

.87472 .41502 L

.87327 .41505 L

.87182 .41506 L

.87037 .41504 L

.86892 .41499 L

.86747 .41491 L

.86602 .41479 L

.86457 .41461 L

.86312 .41437 L

.86167 .41402 L

.86022 .41354 L

.85877 .41285 L

.85732 .41166 L

Mfstroke

.97619 .21769 m

.97474 .21743 L

.97329 .21717 L

.97184 .21692 L

.97039 .21666 L

.96894 .21641 L

.96749 .21615 L

.96604 .2159 L

.96459 .21564 L

.96314 .21539 L

.96169 .21514 L

.96024 .21488 L

.9588 .21463 L

.95735 .21438 L

.9559 .21413 L

.95445 .21388 L

.953 .21363 L

.95155 .21338 L

.9501 .21313 L

.94865 .21289 L

.9472 .21264 L

.94575 .21239 L

.9443 .21215 L

.94285 .2119 L

.9414 .21166 L

.93995 .21142 L

.9385 .21118 L

.93705 .21093 L

.9356 .21069 L

.93415 .21046 L

.9327 .21022 L

.93125 .20998 L

.9298 .20975 L

.92835 .20951 L

.9269 .20928 L

.92545 .20905 L

.92401 .20882 L

.92256 .20859 L

.92111 .20836 L

.91966 .20814 L

.91821 .20792 L

.91676 .2077 L

.91531 .20748 L

.91386 .20726 L

.91241 .20704 L

.91096 .20683 L

.90951 .20662 L

.90806 .20641 L

.90661 .20621 L

.90516 .20601 L

Mistroke

.90371 .20581 L

.90226 .20561 L

.90081 .20542 L

.89936 .20523 L

.89791 .20505 L

.89646 .20487 L

.89501 .20469 L

.89356 .20452 L

.89211 .20436 L

.89066 .2042 L

.88922 .20405 L

.88777 .2039 L

.88632 .20376 L

.88487 .20363 L

.88342 .20351 L

.88197 .20339 L

.88052 .20329 L

.87907 .2032 L

.87762 .20312 L

.87617 .20306 L

.87472 .20301 L

.87327 .20298 L

.87182 .20298 L

.87037 .20299 L

.86892 .20304 L

.86747 .20312 L

.86602 .20325 L

.86457 .20342 L

.86312 .20367 L

.86167 .20401 L

.86022 .20449 L

.85877 .20519 L

.85732 .20638 L

Mfstroke

.85863 .41275 m

.85848 .41266 L

.85834 .41256 L

.85819 .41246 L

.85805 .41235 L

.8579 .41223 L

.85776 .4121 L

.85761 .41197 L

.85747 .41182 L

.85732 .41166 L

.85718 .41147 L

.85703 .41128 L

.85689 .41106 L

.85674 .4108 L

.8566 .41051 L

.85645 .41013 L

.85631 .40955 L

s

.85863 .20528 m

.85848 .20537 L

.85834 .20547 L

.85819 .20557 L

.85805 .20569 L

.8579 .20581 L

.85776 .20593 L

.85761 .20607 L

.85747 .20622 L

.85732 .20638 L

.85718 .20656 L

.85703 .20676 L

.85689 .20698 L

.85674 .20723 L

.8566 .20752 L

.85645 .20791 L

.85631 .20848 L

s

.9269 .33223 m

.92618 .32702 L

.92545 .32287 L

.92473 .31934 L

.92401 .31623 L

.92328 .31341 L

.92256 .31082 L

.92183 .30842 L

.92111 .30617 L

.92038 .30406 L

.91966 .30205 L

.91893 .30014 L

.91821 .29831 L

.91748 .29656 L

.91676 .29487 L

.91603 .29325 L

.91531 .29167 L

.91458 .29015 L

.91386 .28867 L

.91313 .28724 L

.91241 .28584 L

.91168 .28448 L

.91096 .28316 L

.91023 .28186 L

.90951 .28059 L

.90878 .27935 L

.90806 .27813 L

.90733 .27694 L

.90661 .27577 L

.90589 .27463 L

.90516 .2735 L

.90444 .27239 L

.90371 .2713 L

.90299 .27022 L

.90226 .26917 L

.90154 .26813 L

.90081 .2671 L

.90009 .26608 L

.89936 .26508 L

.89864 .2641 L

.89791 .26312 L

.89719 .26215 L

.89646 .2612 L

.89574 .26026 L

.89501 .25933 L

.89429 .2584 L

.89356 .25749 L

.89284 .25658 L

.89211 .25568 L

.89139 .25479 L

Mistroke

.89066 .25391 L

.88994 .25303 L

.88922 .25217 L

.88849 .2513 L

.88777 .25044 L

.88704 .2496 L

.88632 .24875 L

.88559 .24791 L

.88487 .24707 L

.88414 .24624 L

.88342 .24541 L

.88269 .24459 L

.88197 .24377 L

.88124 .24296 L

.88052 .24214 L

.87979 .24133 L

.87907 .24052 L

.87834 .23972 L

.87762 .23891 L

.87689 .23811 L

.87617 .23731 L

.87544 .2365 L

.87472 .2357 L

.87399 .2349 L

.87327 .23409 L

.87254 .23329 L

.87182 .23248 L

.8711 .23168 L

.87037 .23087 L

.86965 .23005 L

.86892 .22923 L

.8682 .22841 L

.86747 .22758 L

.86675 .22674 L

.86602 .22589 L

.8653 .22503 L

.86457 .22416 L

.86385 .22328 L

.86312 .22238 L

.8624 .22146 L

.86167 .22052 L

.86095 .21954 L

.86022 .21853 L

.8595 .21745 L

.85877 .21632 L

.85805 .21506 L

.85732 .21364 L

.8566 .21175 L

Mfstroke

.9269 .2858 m

.92618 .29102 L

.92545 .29516 L

.92473 .29869 L

.92401 .30181 L

.92328 .30463 L

.92256 .30721 L

.92183 .30961 L

.92111 .31186 L

.92038 .31398 L

.91966 .31598 L

.91893 .31789 L

.91821 .31972 L

.91748 .32147 L

.91676 .32316 L

.91603 .32479 L

.91531 .32636 L

.91458 .32788 L

.91386 .32936 L

.91313 .3308 L

.91241 .33219 L

.91168 .33355 L

.91096 .33488 L

.91023 .33618 L

.90951 .33745 L

.90878 .33868 L

.90806 .3399 L

.90733 .34109 L

.90661 .34226 L

.90589 .34341 L

.90516 .34453 L

.90444 .34565 L

.90371 .34674 L

.90299 .34781 L

.90226 .34887 L

.90154 .34991 L

.90081 .35094 L

.90009 .35195 L

.89936 .35295 L

.89864 .35394 L

.89791 .35491 L

.89719 .35588 L

.89646 .35683 L

.89574 .35778 L

.89501 .35871 L

.89429 .35963 L

.89356 .36055 L

.89284 .36146 L

.89211 .36235 L

.89139 .36324 L

Mistroke

.89066 .36412 L

.88994 .365 L

.88922 .36587 L

.88849 .36673 L

.88777 .36759 L

.88704 .36844 L

.88632 .36929 L

.88559 .37013 L

.88487 .37096 L

.88414 .37179 L

.88342 .37262 L

.88269 .37344 L

.88197 .37426 L

.88124 .37508 L

.88052 .37589 L

.87979 .3767 L

.87907 .37751 L

.87834 .37832 L

.87762 .37912 L

.87689 .37993 L

.87617 .38073 L

.87544 .38153 L

.87472 .38233 L

.87399 .38313 L

.87327 .38394 L

.87254 .38474 L

.87182 .38555 L

.8711 .38636 L

.87037 .38717 L

.86965 .38799 L

.86892 .38881 L

.8682 .38963 L

.86747 .39046 L

.86675 .3913 L

.86602 .39214 L

.8653 .393 L

.86457 .39387 L

.86385 .39475 L

.86312 .39565 L

.8624 .39657 L

.86167 .39752 L

.86095 .39849 L

.86022 .39951 L

.8595 .40058 L

.85877 .40172 L

.85805 .40297 L

.85732 .4044 L

.8566 .40629 L

Mfstroke

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{567, 350.313},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.776525,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008g0001GPP10`40000100000800002008200000

P800P020P<30`<3L`:K:l00003<006H009T00<`00?l0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV

09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<003o03?o06Ko09Wo0<co

0?oo0000<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I

<c>I<fJI<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0

IYT0I/`0I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bI

I_nIIP3<IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0c

VC<cVFHcVITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<

VIW<VLc<VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`c

c?lcc01Vc3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03o

c3?oc6Koc9Woc<coc?ooc000oc<0ofH0oiT0ol`0ool0o`0coc<cofHcoiTcol`coolco`1Voc=VofIV

oiUVolaVoomVo`2Ioc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<o`3ooc?oofKooiWoolco

ooooo`0000410@820P<30`@410D51@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C

4a@D5?okl:2PY820P?l0003o0?oo0000ool0o`3oooooodCQ00<0hN40on7ah@00A>400`3Qh@3ohO7Q

0014h@030>7Q0?oQlN4004CQ00<0hN40on7ah@00A>400`3Qh@3ohO7Q0014h@030>7Q0?oQlN4004CQ

00<0hN40on7ah@00A>400`3Qh@3ohO7Q0014h@030>7Q0>3Q7[kbh@00A>430=WQ1khMh@^nj>4004CQ

00<0hN40e>46_RgQ2;kQh@00A>400`3Qh@3@h@Bn>n47_][Q0014h@030>7Q0<gQ1;i5h@Jne>4004CQ

00<0hN40b^44_TkQ1Kk?h@00A>400`3Qh@38h@>nE^45_/[Q0014h@030>7Q0<KQ0[iNh@FnaN4004CQ

00<0hN40a>42_VGQ1;k1h@00A>400`3Qh@31h@>nJn45_[cQ0014h@030>7Q0<3Q0[ibh@Bn^>4004CQ

00<0hN40_^42_WOQ1;jeh@00A>430;gQ0[ilh@Bn/N4004CQ00<0hN40^n42_X;Q1;j]h@00A>400`3Q

h@2jh@:nQn43_Z[Q0014h@030>7Q0;SQ0[j<h@>nYn4004CQ00<0hN40]n42_Y3Q0kjTh@00A>400`3Q

h@2fh@03_^7Q09?Q0kjQh@00A>400`3Qh@2eh@03_^7Q09OQ0kjNh@00A>400`3Qh@2dh@03_^7Q09[Q

1;jKh@00A>400`3Qh@2bh@:nX>43_YWQ0014h@030>7Q0;;Q00>nhN40X^43_YKQ0014h@030>7Q0;3Q

0[jWh@>nU>4004CQ00<0hN40=N4>3fcQ00>nhN40ZN43_Y;Q0014h@<0:N4<3`kQ3`mMh@03_^7Q0:cQ

0[j@h@00A>400`3Qh@0Qh@P?:N493e?Q00>nhN40[n42_XkQ0014h@030>7Q01gQ10ljh@P?B^400kkQ

h@2bh@:nS>4004CQ00<0hN406^433dKQ1Pm3h@03_^7Q0;GQ0[j:h@00A>400`3Qh@0Eh@D?Cn463ccQ

0[jih@:nR>4004CQ00<0hN404^433e[Q1Pleh@03_^7Q0;[Q0kj6h@00A>400`3Qh@0Ah@033n7Q067Q

1Pl^h@03_^7Q0;gQ0[j5h@00A>400`3Qh@0>h@<?J^453bWQ00>nhN40_n42_X?Q0014h@030>7Q00_Q

0`mbh@H?8^400kkQh@32h@:nPN4004CQ00<0hN402N423g_Q10lMh@03_^7Q0<CQ0[j0h@00=>4500;Q

00<0hN401^400`3Qh@08h@033n7Q07oQ1@lGh@03_^7Q0<OQ0[inh@00=^401`3QhN40h@001n400`3Q

h@06h@8?Qn443a?Q00>nhN40b>42_WgQ000`h@<00n401`3QhN40h@001n450004h@l?3hkQ1@l=h@03

_^7Q0<[Q0[ikh@00=^401`3QhN40h@001n400`3Qh@02h@033n7Q09CQ1@l7h@03_^7Q0<cQ0[ijh@00

=^401`3QhN40h@001n400`3Qh@023i_Q1@l2h@03_^7Q0<kQ0[iih@00=N4200CQ00<0hN401^400`3Q

3`2Rh@D?d>42_WOQ0014h@8?Y>400kkQh@053lgQ0[ifh@00@n400`l0h@2Th@03_^7Q00GQ1@o9h@:n

MN4004?Q00<?0>40Xn400kkQh@0:h@@?b>400kkQh@1bh@00@N423`03h@3Q0:;Q00>nhN403n453lCQ

00>nhN40LN40043Q00D?hN7Q002Rh@03_^7Q01GQ10o1h@:nLN4003kQ0Pl4h@030>7Q0:3Q00>nhN40

6N453kgQ0[i`h@00?N400`oQh@04h@030>7Q0:3Q00>nhN407^443k[Q00>nhN40K^4003gQ00<?hN40

1>4309oQ00>nhN408n443kOQ0[i^h@00>n423`OQ00<0hN40Wn400kkQh@0Wh@D?/n42_VgQ000jh@03

3n7Q00OQ00<0hN40W^400kkQh@0/h@D?/>42_VcQ000jh@033n7Q00OQ00<0hN40WN400kkQh@0bh@D?

[>42_P?Q4PmFh@00>>423`[Q00<0hN40WN400kkQh@0fh@@?Wn4;3`:n0PlBhA@?@^4003OQ00<?hN40

2^400`3Qh@2Mh@03_^7Q03[Q1@nCh@L?3>400kkQh@0Vh@h?=>4003OQ00<?hN402^400`3Qh@2Lh@03

_^7Q043Q10n9h@H?5>400kkQh@0ch@@?<>4003KQ00<?hN402n400`3Qh@2Lh@03_^7Q04CQ1@n0h@@?

6n400kkQh@1Vh@00=N400`oQh@0<h@030>7Q09_Q00>nhN40B^443gSQ10lPh@03_^7Q06GQ000dh@03

3n7Q00gQ00<0hN40Vn400kkQh@1>h@D?L>443bCQ00>nhN40I>4003CQ00<?hN403N400`3Qh@2Jh@03

_^7Q05CQ10mZh@<?9n42_VGQ000ch@033n7Q00kQ00<0hN40V^400kkQh@1Hh@@?I>423b_Q0[iTh@00

<^400`oQh@0?h@<0V^400kkQh@1Lh@D?GN423bkQ0[iSh@00<N400`oQh@0@h@030>7Q09WQ00>nhN40

H^453eKQ0`l`h@03_^7Q067Q000ah@033n7Q013Q00<0hN40VN400kkQh@1Wh@D?D>400`oQh@0bh@03

_^7Q063Q000`h@033n7Q017Q00<0hN40V>400kkQh@1/h@D?B^423cGQ0[iQh@00;n400`oQh@0Bh@03

0>7Q09SQ00>nhN40LN453dCQ00<?hN40=^42_V3Q000_h@033n7Q01;Q00<0hN40V>400kkQh@1eh@H?

?^423cWQ00>nhN40G^4002kQ00<?hN404n400`3Qh@2Gh@03_^7Q07cQ10lhh@8?>n42_UoQ000^h@03

3n7Q01?Q00<0hN40Un400kkQh@20h@H?<^400`oQh@0kh@03_^7Q05gQ000]h@033n7Q01CQ00<0hN40

Un400kkQh@25h@H?:n423coQ00>nhN40G>4002cQ00<?hN405N400`3Qh@2Gh@03_^7Q08_Q1@lUh@03

3n7Q043Q00>nhN40Fn4002cQ00<?hN405N400`3Qh@2Fh@03_^7Q097Q1PlMh@8?@n400kkQh@1Kh@00

:n400`oQh@0Fh@030>7Q09KQ00>nhN40Un483a;Q0`m6h@03_^7Q05[Q000[h@033n7Q01KQ0`2Fh@03

_^7Q09kQ4`m9h@:nFn4002[Q00<?hN405n400`3Qh@2Eh@03_^7Q0?cQ00>nhN40FN4002[Q00<?hN40

5n400`3Qh@2Eh@03_^7Q0?gQ00>nhN40F>4002WQ00<?hN406>400`3Qh@2Dh@03_^7Q0?kQ00>nhN40

F>4002WQ00<?hN406>400`3Qh@2Dh@03_^7Q0?oQ00>nhN40En4002SQ00<?hN406N400`3Qh@2Dh@03

_^7Q0?oQ00>nhN40En4002SQ00<?hN406N400`3Qh@2Dh@03_^7Q0?oQ0N400kkQh@1Fh@009n400`oQ

h@0Jh@030>7Q09CQ00>nhN40on42h@03_^7Q05GQ000Wh@033n7Q01[Q00<0hN40U>400kkQh@3oh@;Q

00>nhN40EN4002KQ00<?hN406n400`3Qh@2Ch@03_^7Q0?oQ1>400kkQh@1Dh@009^400`oQh@0Kh@03

0>7Q09?Q00>nhN40on44h@03_^7Q05CQ000Uh@033n7Q01cQ0`2Ch@03_^7Q0?oQ1>42_UGQ000Uh@03

3n7Q01cQ00<0hN40T^400kkQh@3oh@KQ00>nhN40Dn4002GQ00<?hN407>400`3Qh@2Bh@03_^7Q0?oQ

1n400kkQh@1Bh@009>400`oQh@0Mh@030>7Q09;Q00>nhN40on47h@03_^7Q05;Q000Th@033n7Q01gQ

00<0hN40TN400kkQh@3oh@WQ00>nhN40DN4002?Q00<?hN407^400`3Qh@2Ah@03_^7Q0?oQ2N400kkQ

h@1Ah@008n400`oQh@0Nh@030>7Q097Q00>nhN40on49h@03_^7Q057Q000Sh@033n7Q01kQ00<0hN40

TN400kkQh@3oh@[Q00>nhN40D>4002;Q00<?hN407n400`3Qh@2Ah@03_^7Q0?oQ2^400kkQh@1@h@00

8^400`oQh@0Oh@030>7Q097Q00>nhN40on4;h@03_^7Q04oQ000Rh@033n7Q01KQ00<0hN401^400`3Q

h@2@h@03_^7Q0?oQ3>400kkQh@1?h@008^400`oQh@0Eh@030>4000OQ00<0hN40T>400kkQh@3oh@gQ

00>nhN40C^40027Q00<?hN404N4300CQ00<0hN401N4508kQ00>nhN40on4=h@03_^7Q04kQ000Qh@03

3n7Q01KQ0P08h@030>7Q093Q00>nhN40on4=h@03_^7Q04kQ000Ph@033n7Q01OQ00<0hN401n400`3Q

h@2?h@03_^7Q0?oQ3n400kkQh@1=h@008>400`oQh@0Gh@<01n400`3Qh@2?h@03_^7Q0?GQ1[hCh@03

_^7Q04gQ000Ph@033n7Q027Q00<0hN40Sn400kkQh@3ah@Bn1^4;_PSQ00>nhN40CN40023Q00<?hN40

8N400`3Qh@2?h@03_^7Q0?3Q00>nhN404n47_P;Q00>nhN40C>4001oQ00<?hN408^400`3Qh@2>h@03

_^7Q0?3Q00>nhN406^47_T_Q000Oh@033n7Q02;Q00<0hN40S^400kkQh@3ohA7Q00BnhN7Q1[i5h@00

7n400`oQh@0Rh@030>7Q08kQ00>nhN40l>400kkQh@0Nh@03_^7Q00KQ1[hoh@007n400`oQh@0Rh@03

0>7Q08kQ00>nhN40lN400kkQh@0Mh@03_^7Q00cQ1[hih@007n400`oQh@0Rh@030>7Q08kQ00>nhN40

lN400kkQh@0Mh@03_^7Q01;Q1[hch@007^400`oQh@0Sh@030>7Q08kQ00>nhN40l^400kkQh@0Lh@03

_^7Q01SQ0kh`h@007^400`oQh@0Sh@<0S^400kkQh@3ch@03_^7Q01cQ00>nhN40B^4001kQ00<?hN40

8n400`3Qh@2>h@03_^7Q0??Q0[hMh@03_^7Q04[Q000Mh@033n7Q02CQ00<0hN40S^400kkQh@3dh@03

_^7Q01_Q00>nhN40B^4001gQ00<?hN409>400`3Qh@2>h@03_^7Q0?GQ00>nhN406n400kkQh@19h@00

7N400`oQh@0Th@030>7Q08gQ00>nhN40mn400kkQh@0Jh@03_^7Q04WQ000Mh@033n7Q02CQ00<0hN40

SN400kkQh@3gh@:n6n400kkQh@19h@007N400`oQh@0Th@030>7Q08gQ00>nhN40nN400kkQh@0Hh@03

_^7Q04WQ000Lh@033n7Q02GQ00<0hN40SN400kkQh@3ih@:n6N400kkQh@19h@007>400`oQh@0Uh@03

0>7Q08gQ00>nhN40n^42_QWQ00>nhN40B>4001cQ00<?hN409N400`3Qh@2=h@03_^7Q0?_Q0[hHh@03

_^7Q04SQ000Lh@033n7Q02GQ00<0hN40SN400kkQh@3lh@:n5n400kkQh@18h@007>400`oQh@0Uh@<0

SN400kkQh@3mh@03_^7Q01GQ00>nhN40B>4001cQ00<?hN409N400`3Qh@2=h@03_^7Q0?kQ00>nhN40

5>400kkQh@18h@007>400`oQh@0Uh@030>7Q08gQ00>nhN40on400kkQh@0Ch@03_^7Q04SQ000Kh@03

3n7Q02KQ00<0hN40S>400kkQh@3oh@;Q00>nhN404^400kkQh@18h@006n400`oQh@0Vh@030>7Q08cQ

00>nhN40on42h@:n5>400kkQh@17h@006n400`oQh@0Vh@030>7Q08cQ00>nhN40on43h@:n4n400kkQ

h@17h@006n400`oQh@0Vh@030>7Q08cQ00>nhN40on44h@:n4^400kkQh@17h@006n400`oQh@0Vh@03

0>7Q08cQ00>nhN40on45h@03_^7Q013Q00>nhN40An4001_Q00<?hN409^400`3Qh@2<h@03_^7Q0?oQ

1^400kkQh@0?h@03_^7Q04OQ000Jh@033n7Q02OQ00<0hN40S>400kkQh@3oh@OQ00>nhN403^400kkQ

h@17h@006^400`oQh@0Wh@030>7Q08cQ00>nhN40on47h@:n3n400kkQh@17h@006^400`oQh@0Wh@03

0>7Q08cQ00>nhN40on48h@03_^7Q00gQ00>nhN40An4001[Q00<?hN409n4308cQ00>nhN40on49h@03

_^7Q00cQ00>nhN40An4001[Q00<?hN409n400`3Qh@2<h@03_^7Q0?oQ2^400kkQh@0;h@03_^7Q04OQ

000Jh@033n7Q02OQ00<0hN40S>400kkQh@3oh@[Q0[h<h@03_^7Q04OQ000Jh@033n7Q02OQ00<0hN40

S>400kkQh@3oh@_Q00>nhN402^400kkQh@17h@006^400`oQh@0Wh@030>7Q08_Q00>nhN40on4=h@03

_^7Q00WQ00>nhN40An4001[Q00<?hN409n400`3Qh@2;h@03_^7Q0?oQ3^400kkQh@08h@03_^7Q04OQ

000Jh@033n7Q02OQ00<0hN40Rn400kkQh@3oh@kQ00>nhN402>400kkQh@17h@006^400`oQh@0Wh@03

0>7Q08_Q00>nhN40on4?h@03_^7Q00OQ00>nhN40An4001[Q00<?hN409n400`3Qh@2;h@03_^7Q0?oQ

3n400kkQh@07h@03_^7Q04OQ000Jh@033n7Q02OQ00<0hN40@n4500;Q00<0hN40?^401;kQhN450003

h@0004?Q1@02h@030>7Q047Q1@02h@030>7Q047Q1@000n40000Uh@03_^7Q00KQ00>nhN404n4300?Q

00<0hN40:n4001[Q00<?hN409n400`3Qh@15h@070>7Qh@3Q000oh@03_^7Q00?Q00L0hN7Q0>4004CQ

00<0hN400^400`3Qh@13h@070>7Qh@3Q0014h@030>7Q00?Q00<0hN408n400kkQh@05h@03_^7Q01?Q

00<0hN400^400`3Q000/h@006N400`oQh@0Xh@030>7Q04GQ00<0hN400n400`3Qh@0mh@03_^7Q00?Q

00L0hN7Q0>4004CQ00<0hN400^400`3Qh@13h@070>7Qh@3Q0014h@030>7Q00;Q0P0Uh@03_^7Q00GQ

00>nhN405>401`3QhN40h@00;>4001WQ00<?hN40:>4304GQ00@0hN7Q0P10h@03_^7Q00?Q00@0hN7Q

0P15h@030>7Q00?Q00<0hN40@^400`3Qh@02h@030>7Q04?Q00L0hN7Q0>4002KQ00>nhN401>400kkQ

h@0Dh@070>7Qh@3Q000/h@006N400`oQh@0Xh@030>7Q04GQ00D0hN7Q0011h@03_^7Q00?Q00D0hN7Q

0016h@070>7Qh@3Q0014h@070>7Qh@3Q0014h@070>7Qh@3Q000Vh@03_^7Q00?Q00>nhN405>400`3Q

0002h@030>4002cQ000Ih@033n7Q02SQ00<0hN40A>4200?Q0`0oh@03_^7Q00;Q0P04h@80@n4200?Q

0`13h@801>400`3Qh@12h@801>4202KQ0[h4h@03_^7Q01GQ00<0hN400^400`3Qh@0[h@006N400`oQ

h@0Xh@030>7Q08_Q00>nhN40on4Ch@03_^7Q00;Q00>nhN40B>4001WQ00<?hN40:>400`3Qh@2;h@03

_^7Q0?oQ5>401KkQhN6n04[Q000Ih@033n7Q02SQ00<0hN40R^400kkQh@3ohAGQ00FnhN7Q_P1:h@00

6N400`oQh@0Xh@030>7Q08[Q00>nhN40on4Eh@05_^7QhKh0B^4001WQ00<?hN40:>400`3Qh@2:h@03

_^7Q0?oQ5^400kkQ_P1;h@006N400`oQh@0Xh@030>7Q08[Q00>nhN40on4Fh@03_^6n04_Q000Ih@03

3n7Q02SQ00<0hN40R^400kkQh@3ohAKQ00>nhKh0=n44013Q000Ih@033n7Q02SQ00<0hN40R^400kkQ

h@3ohAOQ0[hgh@<04N4000cQ3@000`l0002e0003_P000?l05`000kh0000W017Q00<0hN403n4001OQ

00<0h@l03>400`3Qh@0<h@030>7Q00cQ00<0hN403>400`3Qh@0<h@030>7Q00cQ00<0hN403>400`3Q

h@0<h@030>7Q00cQ00<0hN403>400`3Qh@0<h@030>7Q00gQ00<0hN400^400kkQh@07h@030>7Q00cQ

00<0hN403>400`3Qh@0<h@030>7Q00cQ00<0hN403>400`3Qh@0<h@030>7Q00cQ00<0hN403>400`3Q

h@0<h@030>7Q00cQ00<0hN403>400`3Qh@0<h@030>7Q00cQ00<0hN403>400`3Qh@0<h@030>7Q00cQ

00<0hN403>400`3Qh@0<h@030;jn00cQ00<0hN403>400`3Qh@0Jh@804N4001OQ00<0h@l03>400`3Q

h@0<h@030>7Q00cQ00<0hN403>400`3Qh@0<h@030>7Q00cQ00<0hN403>400`3Qh@0<h@030>7Q00cQ

00<0hN403>400`3Qh@0<h@030>7Q00gQ00<0hN400^400kkQh@07h@030>7Q00cQ00<0hN403>400`3Q

h@0<h@030>7Q00cQ00<0hN403>400`3Qh@0<h@030>7Q00cQ00<0hN403>400`3Qh@0<h@030>7Q00cQ

00<0hN403>400`3Qh@0<h@030>7Q00cQ00<0hN403>400`3Qh@0<h@030>7Q00cQ00<0hN403>400`3Q

h@0<h@030;jn00cQ00<0hN403>400`3Qh@0]h@006N400`oQh@0Xh@030>7Q04SQ00<0hN40?n400kkQ

h@07h@030>7Q04SQ00<0hN40B>400`3Qh@18h@030>7Q02[Q00>nhKh06n400`3Qh@0]h@006N400`oQ

h@0Xh@030>7Q04SQ00<0hN40?n400kkQh@07h@030>7Q04SQ00<0hN40B>400`3Qh@18h@030>7Q02[Q

00>nhKh06n400`3Qh@0]h@006N400`oQh@0Xh@030>7Q08[Q00>nhN40on4Fh@03_^6n04_Q000Ih@03

3n7Q02SQ00<0hN40R^400kkQh@3ohAGQ00FnhN7Q_P1:h@006N400`oQh@0Xh@030>7Q08[Q00>nhN40

on4Eh@05_^7QhKh0B^4001WQ00<?hN40:>400`3Qh@2;h@03_^7Q0?oQ5>401KkQhN6n04[Q000Ih@03

3n7Q02SQ00<0hN40Rn400kkQh@3ohA?Q00>nhN400^400kkQh@18h@006N400`oQh@0Xh@030>7Q08_Q

00>nhN40on4Bh@03_^7Q00?Q00>nhN40B>4001WQ00<?hN40:>400`3Qh@2;h@03_^7Q0?oQ4^400kkQ

h@03h@03_^7Q04SQ000Ih@033n7Q02SQ0`2;h@03_^7Q0?oQ4N42_PKQ00>nhN40An4001[Q00<?hN40

9n400`3Qh@2;h@03_^7Q0?oQ4N400kkQh@05h@03_^7Q04OQ000Jh@033n7Q02OQ00<0hN40Rn400kkQ

h@3ohA3Q0[h7h@03_^7Q04OQ000Jh@033n7Q02OQ00<0hN40Rn400kkQh@3ohA3Q00>nhN401^400kkQ

h@17h@006^400`oQh@0Wh@030>7Q08_Q00>nhN40on4?h@03_^7Q00OQ00>nhN40An4001[Q00<?hN40

9n400`3Qh@2;h@03_^7Q0?oQ3n400kkQh@07h@03_^7Q04OQ000Jh@033n7Q02OQ00<0hN40Rn400kkQ

h@3oh@kQ00>nhN402>400kkQh@17h@006^400`oQh@0Wh@030>7Q08_Q00>nhN40on4=h@:n2^400kkQ

h@17h@006^400`oQh@0Wh@030>7Q08_Q00>nhN40on4<h@:n2n400kkQh@17h@006^400`oQh@0Wh@03

0>7Q08cQ00>nhN40on4;h@03_^7Q00[Q00>nhN40An4001[Q00<?hN409n400`3Qh@2<h@03_^7Q0?oQ

2^42_PcQ00>nhN40An4001[Q00<?hN409n400`3Qh@2<h@03_^7Q0?oQ2^400kkQh@0;h@03_^7Q04OQ

000Jh@033n7Q02OQ0`2<h@03_^7Q0?oQ2N400kkQh@0<h@03_^7Q04OQ000Jh@033n7Q02OQ00<0hN40

S>400kkQh@3oh@SQ00>nhN403N400kkQh@17h@006^400`oQh@0Wh@030>7Q08cQ00>nhN40on47h@:n

3n400kkQh@17h@006^400`oQh@0Wh@030>7Q08cQ00>nhN40on47h@03_^7Q00kQ00>nhN40An4001_Q

00<?hN409^400`3Qh@2<h@03_^7Q0?oQ1N42_Q7Q00>nhN40An4001_Q00<?hN409^400`3Qh@2<h@03

_^7Q0?oQ1N400kkQh@0@h@03_^7Q04OQ000Kh@033n7Q02KQ00<0hN40S>400kkQh@3oh@CQ00>nhN40

4N400kkQh@17h@006n400`oQh@0Vh@030>7Q08cQ00>nhN40on43h@:n4n400kkQh@17h@006n400`oQ

h@0Vh@030>7Q08cQ00>nhN40on42h@:n5>400kkQh@17h@006n400`oQh@0Vh@030>7Q08cQ00>nhN40

on41h@:n5>400kkQh@18h@007>400`oQh@0Uh@030>7Q08gQ00>nhN40on400kkQh@0Ch@03_^7Q04SQ

000Lh@033n7Q02GQ0`2=h@03_^7Q0?gQ0[hFh@03_^7Q04SQ000Lh@033n7Q02GQ00<0hN40SN400kkQ

h@3mh@03_^7Q01GQ00>nhN40B>4001cQ00<?hN409N400`3Qh@2=h@03_^7Q0?cQ00>nhN405^400kkQ

h@18h@007>400`oQh@0Uh@030>7Q08gQ00>nhN40nn42_QSQ00>nhN40B>4001cQ00<?hN409N400`3Q

h@2=h@03_^7Q0?[Q00>nhN405n400kkQh@19h@007>400`oQh@0Uh@030>7Q08gQ00>nhN40nN42_QWQ

00>nhN40BN4001gQ00<?hN409>400`3Qh@2=h@03_^7Q0?SQ0[hJh@03_^7Q04WQ000Mh@033n7Q02CQ

00<0hN40SN400kkQh@3gh@:n6n400kkQh@19h@007N400`oQh@0Th@030>7Q08gQ00>nhN40m^42_QcQ

00>nhN40BN4001gQ00<?hN409>400`3Qh@2>h@03_^7Q0?CQ0[hMh@03_^7Q04WQ000Mh@033n7Q02CQ

00<0hN40S^400kkQh@3dh@03_^7Q01_Q00>nhN40B^4001kQ00<?hN408n400`3Qh@2>h@03_^7Q0??Q

00>nhN407>400kkQh@1:h@007^400`oQh@0Sh@<0S^400kkQh@3bh@:n7^400kkQh@1:h@007^400`oQ

h@0Sh@030>7Q08kQ00>nhN40lN42_QkQ00>nhN405^45_S3Q000Oh@033n7Q02;Q00<0hN40S^400kkQ

h@3ah@03_^7Q01gQ00>nhN404N45_SGQ000Oh@033n7Q02;Q00<0hN40S^400kkQh@3ah@03_^7Q01gQ

00>nhN402n46_S[Q000Oh@033n7Q02;Q00<0hN40S^400kkQh@3`h@03_^7Q01kQ00>nhN401N46_T3Q

000Oh@033n7Q02;Q00<0hN40S^400kkQh@3`h@03_^7Q01gQ00>nhN401[i6h@007n400`oQh@0Rh@03

0>7Q08kQ00>nhN40l>42_Q[Q1ki<h@008>400`oQh@0Qh@030>7Q08oQ00>nhN40l>400kkQh@0@h@Rn

1>400kkQh@1<h@008>400`oQh@0Qh@030>7Q08oQ00>nhN40lN4C_P[Q00>nhN40CN40023Q00<?hN40

8N400`3Qh@2?h@03_^7Q0?oQ3n400kkQh@1=h@008>400`oQh@0Hh@030>7Q00KQ00<0hN40Sn400kkQ

h@3oh@kQ00>nhN40C^40027Q00<?hN405^400`3Q0007h@030>7Q093Q00>nhN40on4=h@03_^7Q04kQ

000Qh@033n7Q01SQ00<0hN401N4508kQ00>nhN40on4=h@03_^7Q04kQ000Rh@033n7Q01GQ0P08h@03

0>7Q093Q00>nhN40on4<h@03_^7Q04oQ000Rh@033n7Q01GQ00<0hN401n400`3Qh@2@h@03_^7Q0?oQ

3>400kkQh@1?h@008^400`oQh@0Eh@<01n400`3Qh@2Ah@03_^7Q0?oQ2n400kkQh@1?h@008n400`oQ

h@0Nh@030>7Q097Q00>nhN40on4:h@03_^7Q053Q000Sh@033n7Q01kQ00<0hN40TN400kkQh@3oh@[Q

00>nhN40D>4002?Q00<?hN407^400`3Qh@2Ah@03_^7Q0?oQ2N400kkQh@1Ah@008n400`oQh@0Nh@03

0>7Q097Q00>nhN40on49h@03_^7Q057Q000Th@033n7Q01gQ00<0hN40TN400kkQh@3oh@SQ00>nhN40

D^4002CQ00<?hN407N400`3Qh@2Bh@03_^7Q0?oQ1n400kkQh@1Bh@009N400`oQh@0Lh@030>7Q09;Q

00>nhN40on47h@03_^7Q05;Q000Uh@033n7Q01cQ0`2Bh@03_^7Q0?oQ1^400kkQh@1Ch@009^400`oQ

h@0Kh@030>7Q09?Q00>nhN40on44h@03_^7Q05CQ000Vh@033n7Q01_Q00<0hN40Tn400kkQh@3oh@CQ

00>nhN40E>4002KQ00<?hN406n400`3Qh@2Ch@03_^7Q0?oQ0n42_UKQ000Wh@033n7Q01[Q00<0hN40

U>400kkQh@3oh@;Q00>nhN40EN4002OQ00<?hN406^400`3Qh@2Dh@03_^7Q0?oQ0N42_UOQ000Xh@03

3n7Q01WQ00<0hN40U>400kkQh@3oh@7Q00>nhN40E^4002SQ00<?hN406N400`3Qh@2Dh@03_^7Q0?oQ

00>nhN40En4002WQ00<?hN406>400`3Qh@2Dh@03_^7Q0?oQ00>nhN40En4002WQ00<?hN406>400`3Q

h@2Dh@03_^7Q0?kQ00>nhN40F>4002[Q00<?hN405n400`3Qh@2Eh@03_^7Q0?gQ00>nhN40F>4002[Q

00<?hN405n400`3Qh@2Eh@03_^7Q0:OQ1`m>h@03_^7Q05WQ000[h@033n7Q01KQ0`2Fh@03_^7Q09cQ

2Pl7h@D?B>400kkQh@1Jh@00:n400`oQh@0Fh@030>7Q09KQ00>nhN40UN473aKQ0Pm6h@03_^7Q05[Q

000/h@033n7Q01GQ00<0hN40U^400kkQh@2?h@L?7^433d;Q00>nhN40Fn4002cQ00<?hN405N400`3Q

h@2Gh@03_^7Q08WQ1PlVh@033n7Q03oQ0[iMh@00;N400`oQh@0Dh@030>7Q09OQ00>nhN40Q>453bgQ

0Ploh@03_^7Q05cQ000^h@033n7Q01?Q00<0hN40Un400kkQh@1oh@D?=>400`oQh@0kh@03_^7Q05gQ

000^h@033n7Q01?Q00<0hN40Un400kkQh@1jh@D?>^400`oQh@0ih@:nGn4002oQ00<?hN404^400`3Q

h@2Hh@03_^7Q07CQ1@m0h@8?>N400kkQh@1Nh@00;n400`oQh@0Bh@030>7Q09SQ00>nhN40Kn453dKQ

0Plgh@03_^7Q05oQ000`h@033n7Q017Q00<0hN40VN400kkQh@1Zh@D?C>423cCQ00>nhN40H>40037Q

00<?hN404>400`3Qh@2Ih@03_^7Q06GQ1@mBh@8?<^42_V;Q000ah@033n7Q013Q00<0hN40V^400kkQ

h@1Ph@@?FN423c3Q00>nhN40HN4003;Q00<?hN403n4309[Q00>nhN40Fn453ekQ0`l]h@03_^7Q06;Q

000ch@033n7Q00kQ00<0hN40V^400kkQh@1Gh@@?I^423b[Q00>nhN40Hn4003CQ00<?hN403N400`3Q

h@2Jh@03_^7Q05;Q1@m/h@8?9n42_VGQ000dh@033n7Q00gQ00<0hN40Vn400kkQh@1=h@@?Ln433b?Q

0[iVh@00=N400`oQh@0<h@030>7Q09_Q00>nhN40B>453g[Q10lNh@:nIn4003KQ00<?hN402n400`3Q

h@2Lh@03_^7Q04?Q10n3h@D?6N400kkQh@1Vh@00=n400`oQh@0:h@030>7Q09gQ00>nhN40?^443h_Q

1`lAh@:n<N483c3Q000hh@033n7Q00WQ00<0hN40WN400kkQh@0ih@D?UN493`WQ00>nhN408^4>3cSQ

000ih@033n7Q00SQ00<0hN40WN400kkQh@0eh@D?X^483`03_Pl?02@?AN4003[Q00<?hN401n400`3Q

h@2Mh@03_^7Q033Q1@n^h@03_^7Q06[Q000jh@033n7Q00OQ00<0hN40W^400kkQh@0/h@@?/N400kkQ

h@1[h@00>n400`oQh@06h@<0Wn400kkQh@0Vh@D?]>400kkQh@1/h@00?>423`KQ00<0hN40Wn400kkQ

h@0Rh@@?^>400kkQh@1]h@00?^400`oQh@03h@030>7Q0:3Q00>nhN407>453k_Q00>nhN40K^4003oQ

00<?hN400^400`3Qh@2Ph@03_^7Q01SQ10noh@03_^7Q06oQ0010h@053n7Qh@00X^400kkQh@0Dh@D?

`>42_W;Q0011h@043n7Q0:?Q00>nhN403^453lCQ0[ich@00@^423`030>7Q0:;Q00>nhN402N453lOQ

0[idh@00A>400`oQh@2Sh@03_^7Q00?Q1@o;h@:nMN4004CQ00<03`l0Xn400kkQ3`043lkQ0[ifh@00

A>40103Qh@nOh@D?dN42_WSQ000dh@D00^400`3Qh@06h@040>7Qh@8?VN453`?Q00>nhN40c^42_WWQ

000fh@070>7Qh@3Q0007h@030>7Q00?Q00<?hN40TN453`WQ00>nhN40c>42_W[Q000fh@070>7Qh@3Q

0007h@D00^423hkQ10l>h@03_^7Q0<WQ0[ilh@00=^401`3QhN40h@001n400`3Qh@06h@033n7Q08GQ

1@lCh@03_^7Q0<SQ0[imh@00=^401`3QhN40h@001n400`3Qh@07h@8?P>453aWQ00>nhN40aN42_WoQ

000eh@801>400`3Qh@06h@030>7Q00WQ0`mih@@?7n400kkQh@33h@:nP>4004CQ00<0hN403>400`oQ

h@1`h@H?9>400kkQh@30h@:nP^4004CQ00<0hN403N433f[Q1@lZh@03_^7Q0;kQ0kj3h@00A>400`3Q

h@0@h@<?HN463c3Q00>nhN40_>42_XGQ0014h@030>7Q01?Q0`mHh@H?=n400kkQh@2ih@>nQ^4004CQ

00<0hN405^433doQ1Plnh@03_^7Q0;KQ0kj8h@00A>400`3Qh@0Ih@D?@^483dCQ00>nhN40]>43_X[Q

0014h@030>7Q01kQ10lgh@L?CN400kkQh@2ah@>nS>4004CQ00<0hN408^483bKQ2@mEh@03_^7Q0:kQ

0kj>h@00A>4302[Q9PmOh@03_^7Q0:_Q0kj@h@00A>400`3Qh@2`h@03_^7Q0:SQ0kjBh@00A>400`3Q

h@2ah@03_^7Q0:CQ0kjEh@00A>400`3Qh@2bh@03_^7Q0:7Q0kjGh@00A>400`3Qh@2ch@03_^7Q09gQ

0kjJh@00A>400`3Qh@2dh@:nVn43_YcQ0014h@030>7Q0;GQ00>nhN40U^43_YoQ0014h@030>7Q0;KQ

0[jCh@>nX^4004CQ00<0hN40^>400kkQh@2=h@>nYN4004CQ00<0hN40^>42_X_Q0kjXh@00A>400`3Q

h@2jh@:nQN44_Z_Q0014h@<0^n42_X7Q0kj_h@00A>400`3Qh@2mh@:nNn44_[;Q0014h@030>7Q0;kQ

0[ifh@Fn]N4004CQ00<0hN40`>42_W3Q1;jjh@00A>400`3Qh@32h@:nJ^44_[kQ0014h@030>7Q0<CQ

0[iSh@Fn`^4004CQ00<0hN40a^42_UgQ1;k7h@00A>400`3Qh@38h@>nE>46_/_Q0014h@030>7Q0<_Q

0ki<h@Jnd>4004CQ00<0hN40c^43_T?Q1[kFh@00A>400`3Qh@3Ah@Fn=n47_]cQ0014h@030>7Q0=KQ

1KhZh@Vnh^4004CQ0`3Kh@Rn5n4;_^_Q0014h@030>7Q0>?Q5kkfh@00A>400`3Qh@3ohO7Q0014h@03

0>7Q0?oQlN4004CQ00<0hN40on7ah@00A>400`3Qh@3ohO7Q0014h@030>7Q0?oQlN4004CQ00<0hN40

on7ah@00A>400`3Qh@3ohO7Q0014h@030>7Q0?oQlN400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQ

on4ih@00on7ohCWQ003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQon4ih@00on7ohCWQ

003oh@OQ0P001>400>4400;Q0`02h@030>7Q0?oQ7^400?oQ2>400`3Q0009h@060>7Q0>40on4Oh@00

on48h@<00^440003h@00008000CQ0>40on4Oh@00on48h@040>4000KQ00<0h@000^400`3Q003ohAoQ

0012h@80`n400`3Qh@08h@800^400`3Q003ohAoQ0013h@030>7Q0<3Q0P0;h@050>7Qh@00on4Ph@00

@N4300;Q00<0hN40on7_h@00@>40203Qh@3Q0>40on7`h@00@>40203Qh@3Q0>40on7`h@00@N430004

h@3Q0?oQl>4004GQ00<0h@00on7`h@00A^400`3Qh@3ohNoQ003ohOoQ>N400?oQon4ih@00on7ohCWQ

003ohOoQ>N400?oQon4ih@00\

\>"],

  ImageRangeCache->{{{0, 566}, {349.313, 0}} -> {13.0847, -13.7348, 0.0133088,

   0.085747}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-1.36252 0.0935486 0.309017 0.0207805 [

[.32135 .29652 -6 -9 ]

[.32135 .29652 6 0 ]

[.50845 .29652 -6 -9 ]

[.50845 .29652 6 0 ]

[.69554 .29652 -6 -9 ]

[.69554 .29652 6 0 ]

[.88264 .29652 -6 -9 ]

[.88264 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12175 .10121 -18 -4.5 ]

[.12175 .10121 0 4.5 ]

[.12175 .20511 -12 -4.5 ]

[.12175 .20511 0 4.5 ]

[.12175 .41292 -6 -4.5 ]

[.12175 .41292 0 4.5 ]

[.12175 .51682 -12 -4.5 ]

[.12175 .51682 0 4.5 ]

[.13425 .64303 -7 0 ]

[.13425 .64303 7 16 ]

[.5 .63053 -17 0 ]

[.5 .63053 17 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.32135 .30902 m

.32135 .31527 L

s

[(18)] .32135 .29652 0 1 Mshowa

.50845 .30902 m

.50845 .31527 L

s

[(20)] .50845 .29652 0 1 Mshowa

.69554 .30902 m

.69554 .31527 L

s

[(22)] .69554 .29652 0 1 Mshowa

.88264 .30902 m

.88264 .31527 L

s

[(24)] .88264 .29652 0 1 Mshowa

.125 Mabswid

.18103 .30902 m

.18103 .31277 L

s

.2278 .30902 m

.2278 .31277 L

s

.27458 .30902 m

.27458 .31277 L

s

.36812 .30902 m

.36812 .31277 L

s

.4149 .30902 m

.4149 .31277 L

s

.46167 .30902 m

.46167 .31277 L

s

.55522 .30902 m

.55522 .31277 L

s

.602 .30902 m

.602 .31277 L

s

.64877 .30902 m

.64877 .31277 L

s

.74232 .30902 m

.74232 .31277 L

s

.78909 .30902 m

.78909 .31277 L

s

.83587 .30902 m

.83587 .31277 L

s

.08748 .30902 m

.08748 .31277 L

s

.0407 .30902 m

.0407 .31277 L

s

.92942 .30902 m

.92942 .31277 L

s

.97619 .30902 m

.97619 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13425 .10121 m

.1405 .10121 L

s

[(-10)] .12175 .10121 1 0 Mshowa

.13425 .20511 m

.1405 .20511 L

s

[(-5)] .12175 .20511 1 0 Mshowa

.13425 .41292 m

.1405 .41292 L

s

[(5)] .12175 .41292 1 0 Mshowa

.13425 .51682 m

.1405 .51682 L

s

[(10)] .12175 .51682 1 0 Mshowa

.125 Mabswid

.13425 .01809 m

.138 .01809 L

s

.13425 .03887 m

.138 .03887 L

s

.13425 .05965 m

.138 .05965 L

s

.13425 .08043 m

.138 .08043 L

s

.13425 .12199 m

.138 .12199 L

s

.13425 .14277 m

.138 .14277 L

s

.13425 .16355 m

.138 .16355 L

s

.13425 .18433 m

.138 .18433 L

s

.13425 .22589 m

.138 .22589 L

s

.13425 .24668 m

.138 .24668 L

s

.13425 .26746 m

.138 .26746 L

s

.13425 .28824 m

.138 .28824 L

s

.13425 .3298 m

.138 .3298 L

s

.13425 .35058 m

.138 .35058 L

s

.13425 .37136 m

.138 .37136 L

s

.13425 .39214 m

.138 .39214 L

s

.13425 .4337 m

.138 .4337 L

s

.13425 .45448 m

.138 .45448 L

s

.13425 .47526 m

.138 .47526 L

s

.13425 .49604 m

.138 .49604 L

s

.13425 .5376 m

.138 .5376 L

s

.13425 .55838 m

.138 .55838 L

s

.13425 .57916 m

.138 .57916 L

s

.13425 .59994 m

.138 .59994 L

s

.25 Mabswid

.13425 0 m

.13425 .61803 L

s

gsave

.13425 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -78 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(k) show

73.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

83.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(70) show

93.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 .4 1 r

.5 Mabswid

.4149 .59567 m

.41481 .59569 L

.41387 .59597 L

.41293 .59624 L

.412 .59651 L

.41106 .59677 L

.41013 .59703 L

.40919 .59728 L

.40826 .59753 L

.40732 .59778 L

.40639 .59802 L

.40545 .59826 L

.40451 .59849 L

.40358 .59872 L

.40264 .59895 L

.40171 .59917 L

.40077 .59938 L

.39984 .59959 L

.3989 .5998 L

.39797 .6 L

.39703 .60019 L

.3961 .60038 L

.39516 .60057 L

.39422 .60075 L

.39329 .60092 L

.39235 .60109 L

.39142 .60126 L

.39048 .60142 L

.38955 .60157 L

.38861 .60172 L

.38768 .60186 L

.38674 .60199 L

.38581 .60212 L

.38487 .60224 L

.38393 .60236 L

.383 .60247 L

.38206 .60258 L

.38113 .60267 L

.38019 .60277 L

.37926 .60285 L

.37832 .60293 L

.37739 .603 L

.37645 .60307 L

.37551 .60312 L

.37458 .60317 L

.37364 .60322 L

.37271 .60325 L

.37177 .60328 L

.37084 .6033 L

.3699 .60331 L

Mistroke

.36897 .60332 L

.36803 .60332 L

.3671 .60331 L

.36616 .60329 L

.36522 .60326 L

.36429 .60323 L

.36335 .60318 L

.36242 .60313 L

.36148 .60307 L

.36055 .603 L

.35961 .60292 L

.35868 .60283 L

.35774 .60273 L

.35681 .60263 L

.35587 .60251 L

.35493 .60239 L

.354 .60225 L

.35306 .60211 L

.35213 .60195 L

.35119 .60179 L

.35026 .60161 L

.34932 .60142 L

.34839 .60123 L

.34745 .60102 L

.34651 .6008 L

.34558 .60057 L

.34464 .60033 L

.34371 .60008 L

.34277 .59981 L

.34184 .59954 L

.3409 .59925 L

.33997 .59895 L

.33903 .59863 L

.3381 .59831 L

.33716 .59797 L

.33622 .59762 L

.33529 .59726 L

.33435 .59688 L

.33342 .59649 L

.33248 .59609 L

.33155 .59567 L

.33061 .59524 L

.32968 .59479 L

.32874 .59433 L

.32781 .59385 L

.32687 .59336 L

.32593 .59285 L

.325 .59233 L

.32406 .59179 L

.32313 .59124 L

Mistroke

.32219 .59067 L

.32126 .59008 L

.32032 .58948 L

.31939 .58886 L

.31845 .58822 L

.31751 .58756 L

.31658 .58689 L

.31564 .5862 L

.31471 .58548 L

.31377 .58475 L

.31284 .584 L

.3119 .58323 L

.31097 .58244 L

.31003 .58164 L

.3091 .58081 L

.30816 .57996 L

.30722 .57908 L

.30629 .57819 L

.30535 .57727 L

.30442 .57633 L

.30348 .57536 L

.30255 .57438 L

.30161 .57337 L

.30068 .57233 L

.29974 .57127 L

.29881 .57018 L

.29787 .56907 L

.29693 .56793 L

.296 .56676 L

.29506 .56557 L

.29413 .56435 L

.29319 .56309 L

.29226 .56181 L

.29132 .5605 L

.29039 .55915 L

.28945 .55778 L

.28851 .55637 L

.28758 .55492 L

.28664 .55345 L

.28571 .55193 L

.28477 .55038 L

.28384 .5488 L

.2829 .54717 L

.28197 .54551 L

.28103 .54381 L

.2801 .54206 L

.27916 .54027 L

.27822 .53844 L

.27729 .53656 L

.27635 .53464 L

Mistroke

.27542 .53266 L

.27448 .53064 L

.27355 .52857 L

.27261 .52644 L

.27168 .52426 L

.27074 .52202 L

.2698 .51971 L

.26887 .51735 L

.26793 .51493 L

.267 .51243 L

.26606 .50987 L

.26513 .50724 L

.26419 .50453 L

.26326 .50173 L

.26232 .49886 L

.26139 .4959 L

.26045 .49284 L

.25951 .48969 L

.25858 .48643 L

.25764 .48307 L

.25671 .47959 L

.25577 .47598 L

.25484 .47225 L

.2539 .46837 L

.25297 .46433 L

.25203 .46013 L

.2511 .45575 L

.25016 .45117 L

.24922 .44637 L

.24829 .44133 L

.24735 .43601 L

.24642 .43038 L

.24548 .4244 L

.24455 .41801 L

.24361 .41112 L

.24268 .40362 L

.24174 .39537 L

.2408 .38611 L

.23987 .37542 L

.23893 .36248 L

.238 .34483 L

.23724 .30902 L

Mfstroke

.4149 .02237 m

.41481 .02234 L

.41387 .02207 L

.41293 .0218 L

.412 .02153 L

.41106 .02127 L

.41013 .02101 L

.40919 .02075 L

.40826 .0205 L

.40732 .02025 L

.40639 .02001 L

.40545 .01977 L

.40451 .01954 L

.40358 .01931 L

.40264 .01909 L

.40171 .01887 L

.40077 .01865 L

.39984 .01844 L

.3989 .01824 L

.39797 .01804 L

.39703 .01784 L

.3961 .01765 L

.39516 .01746 L

.39422 .01728 L

.39329 .01711 L

.39235 .01694 L

.39142 .01678 L

.39048 .01662 L

.38955 .01646 L

.38861 .01632 L

.38768 .01618 L

.38674 .01604 L

.38581 .01591 L

.38487 .01579 L

.38393 .01567 L

.383 .01556 L

.38206 .01546 L

.38113 .01536 L

.38019 .01527 L

.37926 .01518 L

.37832 .0151 L

.37739 .01503 L

.37645 .01497 L

.37551 .01491 L

.37458 .01486 L

.37364 .01482 L

.37271 .01478 L

.37177 .01475 L

.37084 .01473 L

.3699 .01472 L

Mistroke

.36897 .01472 L

.36803 .01472 L

.3671 .01473 L

.36616 .01475 L

.36522 .01477 L

.36429 .01481 L

.36335 .01485 L

.36242 .0149 L

.36148 .01496 L

.36055 .01504 L

.35961 .01511 L

.35868 .0152 L

.35774 .0153 L

.35681 .01541 L

.35587 .01552 L

.35493 .01565 L

.354 .01578 L

.35306 .01593 L

.35213 .01608 L

.35119 .01625 L

.35026 .01642 L

.34932 .01661 L

.34839 .01681 L

.34745 .01702 L

.34651 .01723 L

.34558 .01746 L

.34464 .01771 L

.34371 .01796 L

.34277 .01822 L

.34184 .0185 L

.3409 .01879 L

.33997 .01909 L

.33903 .0194 L

.3381 .01972 L

.33716 .02006 L

.33622 .02041 L

.33529 .02078 L

.33435 .02115 L

.33342 .02154 L

.33248 .02195 L

.33155 .02237 L

.33061 .0228 L

.32968 .02325 L

.32874 .02371 L

.32781 .02418 L

.32687 .02468 L

.32593 .02518 L

.325 .0257 L

.32406 .02624 L

.32313 .0268 L

Mistroke

.32219 .02737 L

.32126 .02795 L

.32032 .02856 L

.31939 .02918 L

.31845 .02982 L

.31751 .03047 L

.31658 .03115 L

.31564 .03184 L

.31471 .03255 L

.31377 .03328 L

.31284 .03403 L

.3119 .0348 L

.31097 .03559 L

.31003 .0364 L

.3091 .03723 L

.30816 .03808 L

.30722 .03895 L

.30629 .03985 L

.30535 .04077 L

.30442 .0417 L

.30348 .04267 L

.30255 .04366 L

.30161 .04467 L

.30068 .0457 L

.29974 .04676 L

.29881 .04785 L

.29787 .04896 L

.29693 .0501 L

.296 .05127 L

.29506 .05246 L

.29413 .05369 L

.29319 .05494 L

.29226 .05622 L

.29132 .05754 L

.29039 .05888 L

.28945 .06026 L

.28851 .06167 L

.28758 .06311 L

.28664 .06459 L

.28571 .0661 L

.28477 .06765 L

.28384 .06923 L

.2829 .07086 L

.28197 .07252 L

.28103 .07423 L

.2801 .07597 L

.27916 .07776 L

.27822 .0796 L

.27729 .08147 L

.27635 .0834 L

Mistroke

.27542 .08537 L

.27448 .08739 L

.27355 .08947 L

.27261 .0916 L

.27168 .09378 L

.27074 .09602 L

.2698 .09832 L

.26887 .10068 L

.26793 .10311 L

.267 .1056 L

.26606 .10816 L

.26513 .1108 L

.26419 .11351 L

.26326 .1163 L

.26232 .11917 L

.26139 .12214 L

.26045 .12519 L

.25951 .12834 L

.25858 .1316 L

.25764 .13496 L

.25671 .13845 L

.25577 .14205 L

.25484 .14579 L

.2539 .14967 L

.25297 .1537 L

.25203 .1579 L

.2511 .16228 L

.25016 .16686 L

.24922 .17166 L

.24829 .17671 L

.24735 .18202 L

.24642 .18765 L

.24548 .19363 L

.24455 .20003 L

.24361 .20692 L

.24268 .21441 L

.24174 .22267 L

.2408 .23193 L

.23987 .24261 L

.23893 .25555 L

.238 .27321 L

.23724 .30902 L

Mfstroke

.4149 .59567 m

.41864 .59453 L

.42238 .59334 L

.42612 .59209 L

.42987 .59079 L

.43361 .58945 L

.43735 .58807 L

.44109 .58665 L

.44483 .58519 L

.44858 .58369 L

.45232 .58217 L

.45606 .58061 L

.4598 .57903 L

.46354 .57742 L

.46729 .5758 L

.47103 .57415 L

.47477 .57248 L

.47851 .5708 L

.48225 .5691 L

.486 .56739 L

.48974 .56566 L

.49348 .56393 L

.49722 .56219 L

.50096 .56044 L

.50471 .55868 L

.50845 .55692 L

.51219 .55516 L

.51593 .55339 L

.51967 .55162 L

.52342 .54985 L

.52716 .54808 L

.5309 .54631 L

.53464 .54454 L

.53838 .54278 L

.54212 .54101 L

.54587 .53925 L

.54961 .5375 L

.55335 .53575 L

.55709 .53401 L

.56083 .53227 L

.56458 .53054 L

.56832 .52881 L

.57206 .5271 L

.5758 .52539 L

.57954 .52369 L

.58329 .52199 L

.58703 .52031 L

.59077 .51863 L

.59451 .51697 L

.59825 .51531 L

Mistroke

.602 .51366 L

.60574 .51203 L

.60948 .5104 L

.61322 .50879 L

.61696 .50718 L

.62071 .50559 L

.62445 .504 L

.62819 .50243 L

.63193 .50087 L

.63567 .49932 L

.63942 .49778 L

.64316 .49626 L

.6469 .49474 L

.65064 .49324 L

.65438 .49175 L

.65813 .49027 L

.66187 .48881 L

.66561 .48735 L

.66935 .48591 L

.67309 .48448 L

.67683 .48306 L

.68058 .48165 L

.68432 .48026 L

.68806 .47888 L

.6918 .47751 L

.69554 .47615 L

.69929 .47481 L

.70303 .47347 L

.70677 .47215 L

.71051 .47085 L

.71425 .46955 L

.718 .46827 L

.72174 .467 L

.72548 .46574 L

.72922 .46449 L

.73296 .46326 L

.73671 .46204 L

.74045 .46083 L

.74419 .45963 L

.74793 .45844 L

.75167 .45727 L

.75542 .45611 L

.75916 .45496 L

.7629 .45382 L

.76664 .4527 L

.77038 .45158 L

.77413 .45048 L

.77787 .44939 L

.78161 .44831 L

.78535 .44725 L

Mistroke

.78909 .44619 L

.79284 .44515 L

.79658 .44412 L

.80032 .4431 L

.80406 .44209 L

.8078 .44109 L

.81154 .44011 L

.81529 .43913 L

.81903 .43817 L

.82277 .43722 L

.82651 .43628 L

.83025 .43535 L

.834 .43443 L

.83774 .43352 L

.84148 .43263 L

.84522 .43174 L

.84896 .43086 L

.85271 .43 L

.85645 .42915 L

.86019 .4283 L

.86393 .42747 L

.86767 .42665 L

.87142 .42584 L

.87516 .42504 L

.8789 .42424 L

.88264 .42346 L

.88638 .42269 L

.89013 .42193 L

.89387 .42118 L

.89761 .42044 L

.90135 .41971 L

.90509 .41898 L

.90884 .41827 L

.91258 .41757 L

.91632 .41688 L

.92006 .41619 L

.9238 .41552 L

.92755 .41485 L

.93129 .4142 L

.93503 .41355 L

.93877 .41291 L

.94251 .41228 L

.94625 .41166 L

.95 .41105 L

.95374 .41044 L

.95748 .40985 L

.96122 .40926 L

.96496 .40868 L

.96871 .40811 L

.97245 .40755 L

Mistroke

.97619 .407 L

Mfstroke

.4149 .02237 m

.41864 .02351 L

.42238 .0247 L

.42612 .02594 L

.42987 .02724 L

.43361 .02858 L

.43735 .02996 L

.44109 .03139 L

.44483 .03285 L

.44858 .03434 L

.45232 .03587 L

.45606 .03742 L

.4598 .03901 L

.46354 .04061 L

.46729 .04224 L

.47103 .04389 L

.47477 .04556 L

.47851 .04724 L

.48225 .04894 L

.486 .05065 L

.48974 .05237 L

.49348 .0541 L

.49722 .05585 L

.50096 .0576 L

.50471 .05935 L

.50845 .06111 L

.51219 .06288 L

.51593 .06465 L

.51967 .06641 L

.52342 .06819 L

.52716 .06996 L

.5309 .07172 L

.53464 .07349 L

.53838 .07526 L

.54212 .07702 L

.54587 .07878 L

.54961 .08053 L

.55335 .08228 L

.55709 .08403 L

.56083 .08576 L

.56458 .0875 L

.56832 .08922 L

.57206 .09094 L

.5758 .09265 L

.57954 .09435 L

.58329 .09604 L

.58703 .09773 L

.59077 .0994 L

.59451 .10107 L

.59825 .10272 L

Mistroke

.602 .10437 L

.60574 .10601 L

.60948 .10763 L

.61322 .10925 L

.61696 .11085 L

.62071 .11245 L

.62445 .11403 L

.62819 .1156 L

.63193 .11716 L

.63567 .11871 L

.63942 .12025 L

.64316 .12178 L

.6469 .12329 L

.65064 .12479 L

.65438 .12628 L

.65813 .12776 L

.66187 .12923 L

.66561 .13068 L

.66935 .13213 L

.67309 .13356 L

.67683 .13497 L

.68058 .13638 L

.68432 .13777 L

.68806 .13916 L

.6918 .14053 L

.69554 .14188 L

.69929 .14323 L

.70303 .14456 L

.70677 .14588 L

.71051 .14719 L

.71425 .14848 L

.718 .14977 L

.72174 .15104 L

.72548 .1523 L

.72922 .15354 L

.73296 .15478 L

.73671 .156 L

.74045 .15721 L

.74419 .15841 L

.74793 .15959 L

.75167 .16076 L

.75542 .16193 L

.75916 .16308 L

.7629 .16421 L

.76664 .16534 L

.77038 .16645 L

.77413 .16755 L

.77787 .16864 L

.78161 .16972 L

.78535 .17079 L

Mistroke

.78909 .17184 L

.79284 .17289 L

.79658 .17392 L

.80032 .17494 L

.80406 .17594 L

.8078 .17694 L

.81154 .17793 L

.81529 .1789 L

.81903 .17986 L

.82277 .18082 L

.82651 .18176 L

.83025 .18269 L

.834 .1836 L

.83774 .18451 L

.84148 .18541 L

.84522 .18629 L

.84896 .18717 L

.85271 .18803 L

.85645 .18889 L

.86019 .18973 L

.86393 .19056 L

.86767 .19139 L

.87142 .1922 L

.87516 .193 L

.8789 .19379 L

.88264 .19457 L

.88638 .19534 L

.89013 .1961 L

.89387 .19685 L

.89761 .1976 L

.90135 .19833 L

.90509 .19905 L

.90884 .19976 L

.91258 .20046 L

.91632 .20116 L

.92006 .20184 L

.9238 .20252 L

.92755 .20318 L

.93129 .20384 L

.93503 .20449 L

.93877 .20512 L

.94251 .20575 L

.94625 .20638 L

.95 .20699 L

.95374 .20759 L

.95748 .20819 L

.96122 .20877 L

.96496 .20935 L

.96871 .20992 L

.97245 .21048 L

Mistroke

.97619 .21104 L

Mfstroke

1 0 0 r

.50845 .39176 m

.50658 .39252 L

.50471 .39328 L

.50283 .39404 L

.50096 .39481 L

.49909 .39557 L

.49722 .39634 L

.49535 .3971 L

.49348 .39787 L

.49161 .39864 L

.48974 .3994 L

.48787 .40017 L

.486 .40094 L

.48412 .40171 L

.48225 .40248 L

.48038 .40325 L

.47851 .40402 L

.47664 .4048 L

.47477 .40557 L

.4729 .40634 L

.47103 .40712 L

.46916 .40789 L

.46729 .40866 L

.46542 .40944 L

.46354 .41022 L

.46167 .41099 L

.4598 .41177 L

.45793 .41255 L

.45606 .41332 L

.45419 .4141 L

.45232 .41488 L

.45045 .41566 L

.44858 .41644 L

.44671 .41721 L

.44483 .41799 L

.44296 .41877 L

.44109 .41955 L

.43922 .42033 L

.43735 .42111 L

.43548 .4219 L

.43361 .42268 L

.43174 .42346 L

.42987 .42424 L

.428 .42502 L

.42612 .4258 L

.42425 .42658 L

.42238 .42736 L

.42051 .42814 L

.41864 .42893 L

.41677 .42971 L

Mistroke

.4149 .43049 L

.41303 .43127 L

.41116 .43205 L

.40929 .43283 L

.40741 .43362 L

.40554 .4344 L

.40367 .43518 L

.4018 .43596 L

.39993 .43674 L

.39806 .43752 L

.39619 .4383 L

.39432 .43908 L

.39245 .43986 L

.39058 .44064 L

.38871 .44142 L

.38683 .4422 L

.38496 .44298 L

.38309 .44375 L

.38122 .44453 L

.37935 .44531 L

.37748 .44608 L

.37561 .44686 L

.37374 .44764 L

.37187 .44841 L

.37 .44919 L

.36812 .44996 L

.36625 .45073 L

.36438 .4515 L

.36251 .45228 L

.36064 .45305 L

.35877 .45382 L

.3569 .45459 L

.35503 .45535 L

.35316 .45612 L

.35129 .45689 L

.34941 .45765 L

.34754 .45842 L

.34567 .45918 L

.3438 .45994 L

.34193 .4607 L

.34006 .46146 L

.33819 .46222 L

.33632 .46298 L

.33445 .46374 L

.33258 .46449 L

.33071 .46525 L

.32883 .466 L

.32696 .46675 L

.32509 .4675 L

.32322 .46825 L

Mistroke

.32135 .46899 L

.31948 .46974 L

.31761 .47048 L

.31574 .47122 L

.31387 .47196 L

.312 .4727 L

.31012 .47343 L

.30825 .47417 L

.30638 .4749 L

.30451 .47563 L

.30264 .47636 L

.30077 .47708 L

.2989 .47781 L

.29703 .47853 L

.29516 .47925 L

.29329 .47996 L

.29141 .48068 L

.28954 .48139 L

.28767 .4821 L

.2858 .4828 L

.28393 .4835 L

.28206 .48421 L

.28019 .4849 L

.27832 .4856 L

.27645 .48629 L

.27458 .48698 L

.2727 .48766 L

.27083 .48834 L

.26896 .48902 L

.26709 .4897 L

.26522 .49037 L

.26335 .49104 L

.26148 .4917 L

.25961 .49236 L

.25774 .49302 L

.25587 .49367 L

.254 .49432 L

.25212 .49497 L

.25025 .49561 L

.24838 .49624 L

.24651 .49687 L

.24464 .4975 L

.24277 .49812 L

.2409 .49874 L

.23903 .49935 L

.23716 .49996 L

.23529 .50056 L

.23341 .50116 L

.23154 .50175 L

.22967 .50233 L

Mistroke

.2278 .50291 L

.22593 .50349 L

.22406 .50406 L

.22219 .50462 L

.22032 .50517 L

.21845 .50572 L

.21658 .50626 L

.2147 .5068 L

.21283 .50733 L

.21096 .50785 L

.20909 .50836 L

.20722 .50886 L

.20535 .50936 L

.20348 .50985 L

.20161 .51033 L

.19974 .51081 L

.19787 .51127 L

.196 .51172 L

.19412 .51217 L

.19225 .51261 L

.19038 .51303 L

.18851 .51345 L

.18664 .51386 L

.18477 .51425 L

.1829 .51464 L

.18103 .51501 L

.17916 .51537 L

.17729 .51572 L

.17541 .51606 L

.17354 .51639 L

.17167 .5167 L

.1698 .517 L

.16793 .51728 L

.16606 .51755 L

.16419 .51781 L

.16232 .51805 L

.16045 .51828 L

.15858 .51849 L

.1567 .51868 L

.15483 .51885 L

.15296 .51901 L

.15109 .51915 L

.14922 .51928 L

.14735 .51938 L

.14548 .51946 L

.14361 .51952 L

.14174 .51956 L

.13987 .51958 L

.13799 .51957 L

.13612 .51954 L

Mistroke

.13425 .51949 L

.13238 .51941 L

.13051 .5193 L

.12864 .51917 L

.12677 .51901 L

.1249 .51881 L

.12303 .51859 L

.12116 .51834 L

.11929 .51805 L

.11741 .51773 L

.11554 .51737 L

.11367 .51698 L

.1118 .51654 L

.10993 .51607 L

.10806 .51555 L

.10619 .51499 L

.10432 .51438 L

.10245 .51373 L

.10058 .51303 L

.0987 .51227 L

.09683 .51146 L

.09496 .51059 L

.09309 .50966 L

.09122 .50867 L

.08935 .50761 L

.08748 .50649 L

.08561 .50529 L

.08374 .50401 L

.08187 .50265 L

.07999 .50121 L

.07812 .49968 L

.07625 .49806 L

.07438 .49633 L

.07251 .4945 L

.07064 .49256 L

.06877 .49049 L

.0669 .4883 L

.06503 .48597 L

.06316 .4835 L

.06129 .48087 L

.05941 .47807 L

.05754 .4751 L

.05567 .47193 L

.0538 .46854 L

.05193 .46493 L

.05006 .46106 L

.04819 .45692 L

.04632 .45246 L

.04445 .44766 L

.04258 .44247 L

Mistroke

.0407 .43684 L

.03883 .43069 L

.03696 .42394 L

.03509 .41645 L

.03322 .40807 L

.03135 .39851 L

.02948 .38735 L

.02761 .37374 L

.02574 .35553 L

.02381 .30902 L

Mfstroke

.50845 .22628 m

.50658 .22552 L

.50471 .22475 L

.50283 .22399 L

.50096 .22323 L

.49909 .22246 L

.49722 .2217 L

.49535 .22093 L

.49348 .22017 L

.49161 .2194 L

.48974 .21863 L

.48787 .21786 L

.486 .21709 L

.48412 .21632 L

.48225 .21555 L

.48038 .21478 L

.47851 .21401 L

.47664 .21324 L

.47477 .21247 L

.4729 .21169 L

.47103 .21092 L

.46916 .21014 L

.46729 .20937 L

.46542 .20859 L

.46354 .20782 L

.46167 .20704 L

.4598 .20627 L

.45793 .20549 L

.45606 .20471 L

.45419 .20393 L

.45232 .20316 L

.45045 .20238 L

.44858 .2016 L

.44671 .20082 L

.44483 .20004 L

.44296 .19926 L

.44109 .19848 L

.43922 .1977 L

.43735 .19692 L

.43548 .19614 L

.43361 .19536 L

.43174 .19458 L

.42987 .1938 L

.428 .19302 L

.42612 .19223 L

.42425 .19145 L

.42238 .19067 L

.42051 .18989 L

.41864 .18911 L

.41677 .18833 L

Mistroke

.4149 .18754 L

.41303 .18676 L

.41116 .18598 L

.40929 .1852 L

.40741 .18442 L

.40554 .18364 L

.40367 .18286 L

.4018 .18208 L

.39993 .18129 L

.39806 .18051 L

.39619 .17973 L

.39432 .17895 L

.39245 .17817 L

.39058 .17739 L

.38871 .17662 L

.38683 .17584 L

.38496 .17506 L

.38309 .17428 L

.38122 .1735 L

.37935 .17273 L

.37748 .17195 L

.37561 .17117 L

.37374 .1704 L

.37187 .16962 L

.37 .16885 L

.36812 .16808 L

.36625 .1673 L

.36438 .16653 L

.36251 .16576 L

.36064 .16499 L

.35877 .16422 L

.3569 .16345 L

.35503 .16268 L

.35316 .16191 L

.35129 .16115 L

.34941 .16038 L

.34754 .15962 L

.34567 .15885 L

.3438 .15809 L

.34193 .15733 L

.34006 .15657 L

.33819 .15581 L

.33632 .15505 L

.33445 .1543 L

.33258 .15354 L

.33071 .15279 L

.32883 .15204 L

.32696 .15128 L

.32509 .15054 L

.32322 .14979 L

Mistroke

.32135 .14904 L

.31948 .1483 L

.31761 .14755 L

.31574 .14681 L

.31387 .14607 L

.312 .14534 L

.31012 .1446 L

.30825 .14387 L

.30638 .14313 L

.30451 .1424 L

.30264 .14168 L

.30077 .14095 L

.2989 .14023 L

.29703 .13951 L

.29516 .13879 L

.29329 .13807 L

.29141 .13736 L

.28954 .13665 L

.28767 .13594 L

.2858 .13523 L

.28393 .13453 L

.28206 .13383 L

.28019 .13313 L

.27832 .13244 L

.27645 .13175 L

.27458 .13106 L

.2727 .13037 L

.27083 .12969 L

.26896 .12901 L

.26709 .12834 L

.26522 .12766 L

.26335 .127 L

.26148 .12633 L

.25961 .12567 L

.25774 .12501 L

.25587 .12436 L

.254 .12371 L

.25212 .12307 L

.25025 .12243 L

.24838 .12179 L

.24651 .12116 L

.24464 .12053 L

.24277 .11991 L

.2409 .11929 L

.23903 .11868 L

.23716 .11807 L

.23529 .11747 L

.23341 .11688 L

.23154 .11629 L

.22967 .1157 L

Mistroke

.2278 .11512 L

.22593 .11455 L

.22406 .11398 L

.22219 .11342 L

.22032 .11286 L

.21845 .11231 L

.21658 .11177 L

.2147 .11124 L

.21283 .11071 L

.21096 .11019 L

.20909 .10968 L

.20722 .10917 L

.20535 .10867 L

.20348 .10818 L

.20161 .1077 L

.19974 .10723 L

.19787 .10676 L

.196 .10631 L

.19412 .10586 L

.19225 .10543 L

.19038 .105 L

.18851 .10458 L

.18664 .10418 L

.18477 .10378 L

.1829 .1034 L

.18103 .10302 L

.17916 .10266 L

.17729 .10231 L

.17541 .10197 L

.17354 .10165 L

.17167 .10134 L

.1698 .10104 L

.16793 .10075 L

.16606 .10048 L

.16419 .10022 L

.16232 .09998 L

.16045 .09976 L

.15858 .09955 L

.1567 .09935 L

.15483 .09918 L

.15296 .09902 L

.15109 .09888 L

.14922 .09876 L

.14735 .09866 L

.14548 .09857 L

.14361 .09851 L

.14174 .09847 L

.13987 .09846 L

.13799 .09846 L

.13612 .09849 L

Mistroke

.13425 .09855 L

.13238 .09862 L

.13051 .09873 L

.12864 .09886 L

.12677 .09903 L

.1249 .09922 L

.12303 .09944 L

.12116 .09969 L

.11929 .09998 L

.11741 .10031 L

.11554 .10066 L

.11367 .10106 L

.1118 .10149 L

.10993 .10197 L

.10806 .10248 L

.10619 .10304 L

.10432 .10365 L

.10245 .1043 L

.10058 .10501 L

.0987 .10576 L

.09683 .10658 L

.09496 .10745 L

.09309 .10837 L

.09122 .10936 L

.08935 .11042 L

.08748 .11155 L

.08561 .11275 L

.08374 .11402 L

.08187 .11538 L

.07999 .11682 L

.07812 .11835 L

.07625 .11998 L

.07438 .1217 L

.07251 .12353 L

.07064 .12548 L

.06877 .12754 L

.0669 .12973 L

.06503 .13206 L

.06316 .13454 L

.06129 .13716 L

.05941 .13996 L

.05754 .14294 L

.05567 .14611 L

.0538 .14949 L

.05193 .15311 L

.05006 .15697 L

.04819 .16112 L

.04632 .16557 L

.04445 .17037 L

.04258 .17556 L

Mistroke

.0407 .1812 L

.03883 .18735 L

.03696 .1941 L

.03509 .20158 L

.03322 .20997 L

.03135 .21952 L

.02948 .23069 L

.02761 .2443 L

.02574 .2625 L

.02381 .30902 L

Mfstroke

.50845 .39176 m

.51312 .38986 L

.5178 .38796 L

.52248 .38608 L

.52716 .38419 L

.53183 .38232 L

.53651 .38045 L

.54119 .37858 L

.54587 .37673 L

.55054 .37488 L

.55522 .37304 L

.5599 .3712 L

.56458 .36938 L

.56925 .36756 L

.57393 .36575 L

.57861 .36395 L

.58329 .36216 L

.58796 .36038 L

.59264 .3586 L

.59732 .35684 L

.602 .35509 L

.60667 .35335 L

.61135 .35162 L

.61603 .34991 L

.62071 .3482 L

.62538 .34651 L

.63006 .34483 L

.63474 .34317 L

.63942 .34152 L

.64409 .33988 L

.64877 .33826 L

.65345 .33665 L

.65813 .33506 L

.6628 .33348 L

.66748 .33192 L

.67216 .33038 L

.67683 .32886 L

.68151 .32736 L

.68619 .32587 L

.69087 .3244 L

.69554 .32296 L

.70022 .32153 L

.7049 .32012 L

.70958 .31874 L

.71425 .31738 L

.71893 .31604 L

.72361 .31472 L

.72829 .31343 L

.73296 .31216 L

.73764 .31092 L

Mistroke

.74232 .3097 L

.747 .3085 L

.75167 .30734 L

.75635 .30619 L

.76103 .30508 L

.76571 .30399 L

.77038 .30293 L

.77506 .3019 L

.77974 .30089 L

.78442 .29991 L

.78909 .29897 L

.79377 .29805 L

.79845 .29716 L

.80313 .2963 L

.8078 .29547 L

.81248 .29466 L

.81716 .29389 L

.82184 .29315 L

.82651 .29244 L

.83119 .29176 L

.83587 .2911 L

.84054 .29048 L

.84522 .28989 L

.8499 .28932 L

.85458 .28879 L

.85925 .28828 L

.86393 .28781 L

.86861 .28736 L

.87329 .28694 L

.87796 .28655 L

.88264 .28618 L

.88732 .28585 L

.892 .28554 L

.89667 .28526 L

.90135 .285 L

.90603 .28477 L

.91071 .28457 L

.91538 .28439 L

.92006 .28424 L

.92474 .28411 L

.92942 .284 L

.93409 .28392 L

.93877 .28386 L

.94345 .28382 L

.94813 .2838 L

.9528 .28381 L

.95748 .28384 L

.96216 .28388 L

.96684 .28395 L

.97151 .28403 L

Mistroke

.97619 .28413 L

Mfstroke

.50845 .22628 m

.51312 .22818 L

.5178 .23007 L

.52248 .23196 L

.52716 .23384 L

.53183 .23572 L

.53651 .23759 L

.54119 .23945 L

.54587 .24131 L

.55054 .24316 L

.55522 .245 L

.5599 .24683 L

.56458 .24866 L

.56925 .25048 L

.57393 .25228 L

.57861 .25409 L

.58329 .25588 L

.58796 .25766 L

.59264 .25943 L

.59732 .26119 L

.602 .26294 L

.60667 .26468 L

.61135 .26641 L

.61603 .26813 L

.62071 .26983 L

.62538 .27152 L

.63006 .2732 L

.63474 .27487 L

.63942 .27652 L

.64409 .27816 L

.64877 .27978 L

.65345 .28139 L

.65813 .28298 L

.6628 .28455 L

.66748 .28611 L

.67216 .28765 L

.67683 .28917 L

.68151 .29068 L

.68619 .29216 L

.69087 .29363 L

.69554 .29508 L

.70022 .2965 L

.7049 .29791 L

.70958 .29929 L

.71425 .30065 L

.71893 .30199 L

.72361 .30331 L

.72829 .3046 L

.73296 .30587 L

.73764 .30712 L

Mistroke

.74232 .30834 L

.747 .30953 L

.75167 .3107 L

.75635 .31184 L

.76103 .31296 L

.76571 .31404 L

.77038 .31511 L

.77506 .31614 L

.77974 .31714 L

.78442 .31812 L

.78909 .31907 L

.79377 .31999 L

.79845 .32088 L

.80313 .32174 L

.8078 .32257 L

.81248 .32337 L

.81716 .32414 L

.82184 .32488 L

.82651 .3256 L

.83119 .32628 L

.83587 .32693 L

.84054 .32755 L

.84522 .32815 L

.8499 .32871 L

.85458 .32925 L

.85925 .32975 L

.86393 .33023 L

.86861 .33068 L

.87329 .3311 L

.87796 .33149 L

.88264 .33185 L

.88732 .33219 L

.892 .33249 L

.89667 .33278 L

.90135 .33303 L

.90603 .33326 L

.91071 .33347 L

.91538 .33364 L

.92006 .3338 L

.92474 .33393 L

.92942 .33403 L

.93409 .33412 L

.93877 .33418 L

.94345 .33421 L

.94813 .33423 L

.9528 .33422 L

.95748 .3342 L

.96216 .33415 L

.96684 .33409 L

.97151 .334 L

Mistroke

.97619 .3339 L

Mfstroke

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{567, 350.313},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.776525,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008g0001GPP10`40000100000800002008200000

P800P020P<30`<3L`:K:l00003<006H009T00<`00?l0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV

09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<003o03?o06Ko09Wo0<co

0?oo0000<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I

<c>I<fJI<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0

IYT0I/`0I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bI

I_nIIP3<IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0c

VC<cVFHcVITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<

VIW<VLc<VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`c

c?lcc01Vc3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03o

c3?oc6Koc9Woc<coc?ooc000oc<0ofH0oiT0ol`0ool0o`0coc<cofHcoiTcol`coolco`1Voc=VofIV

oiUVolaVoomVo`2Ioc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<o`3ooc?oofKooiWoolco

ooooo`0000410@820P<30`@410D51@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C

4a@D5?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooe;Q00<0hN40on7Sh@00D^400`3Qh@3ohN?Q

001Bh@030>7Q0?oQhn4005;Q00<0hN40on7Sh@00D^400`3Qh@3ohN?Q001Bh@030>7Q0?oQhn4005;Q

00<0hN40on7Sh@00D^400`3Qh@3ohN?Q001Bh@030>7Q06kQ4[kohF?Q001Bh@030>7Q06[Q1KhAh@Jn

on5Mh@00D^4306OQ0khLh@Fnon5Hh@00D^400`3Qh@1Th@>n8n44__oQEN4005;Q00<0hN40H^43_RWQ

0kkohE;Q001Bh@030>7Q063Q0[h_h@:non5@h@00D^400`3Qh@1Nh@>n<^44__oQC>4005;Q00<0hN40

GN42_SSQ0[kohD[Q001Bh@030>7Q05_Q0[hlh@Bnon56h@00D^400`3Qh@1Jh@:n@N42__oQA>4005;Q

00<0hN40FN42_TCQ0[kohD;Q001Bh@030>7Q05SQ0[i7h@:non50h@00D^4305OQ00>nhN40BN44__oQ

?>4005;Q00<0hN40E^400kkQh@1>h@:non4jh@00D^400`3Qh@1Eh@03_^7Q057Q0[kohCSQ001Bh@03

0>7Q05CQ00>nhN40E>42__oQ=^4005;Q00<0hN40Dn400kkQh@1Gh@03_^7Q0?oQ<n4005;Q00<0hN40

D^400kkQh@1Ih@:non4ch@00D^400`3Qh@1Ah@:nGN44__oQ;n4005;Q00<0hN40D>42_V;Q0[kohBgQ

001Bh@030>7Q053Q00>nhN40Hn42__oQ:n4005;Q00<0hN40Cn400kkQh@1Vh@:non4Yh@00D^400`3Q

h@1>h@03_^7Q06WQ0[kohBOQ001Bh@<0CN42_VgQ0[kohBGQ001Bh@030>7Q04gQ00>nhN40K^42__oQ

8n4005;Q00<0hN40C>400kkQh@1ah@:non4Qh@00D^400`3Qh@1;h@:nMN42__oQ7n4005;Q00<0hN40

Bn400kkQh@1fh@:non4Mh@00D^400`3Qh@1:h@03_^7Q07WQ1;kohAWQ001Bh@030>7Q04[Q00>nhN40

ON42__oQ5n4005;Q00<0hN40B^400kkQh@1oh@03_^7Q0?oQ5>4005;Q00<0hN40BN400kkQh@21h@:n

on4Dh@00D^400`3Qh@18h@:nQN42__oQ4^4005;Q00<0hN40B>400kkQh@26h@:non4@h@00D^4304OQ

00>nhN40RN42__oQ3^4005;Q00<0hN40An400kkQh@2;h@:non4<h@00D^400`3Qh@16h@03_^7Q08kQ

0[koh@[Q001Bh@030>7Q04KQ00>nhN40T>42__oQ2>4005;Q00<0hN40AN400kkQh@2Ch@Bnon44h@00

D^400`3Qh@15h@03_^7Q09OQ0[koh@;Q001Bh@030>7Q04GQ00>nhN40VN42__oQ001Bh@030>7Q04CQ

00>nhN40W>42__gQ001Bh@030>7Q04CQ00>nhN40W^42___Q0011h@D00^400`3Qh@04h@d??>400kkQ

h@2Qh@:nnN4004?Q00D0hN7Q00073`?Q00<0hN401n483cCQ00>nhN40Xn42__OQ000mh@<00n400`0?

3`023`03h@3Q00OQ100>h@H?;N400kkQh@2Vh@>nm>40047Q0`l3h@030>4000SQ00<0hN405N453bSQ

00>nhN40ZN42__;Q000oh@8?0^401`3QhN40h@002>400`3Qh@0Jh@@?9>400kkQh@2[h@:nl>4003gQ

0Pl3h@801>400`3Qh@07h@030>7Q01kQ10lOh@03_^7Q0:kQ0[k^h@00>n423aGQ00<0hN408^443a_Q

00>nhN40/>42_^cQ000jh@033n7Q01GQ00<0hN409^443aOQ00>nhN40/^44_^SQ000hh@8?6>400`3Q

h@0Zh@8?5>400kkQh@2gh@:ni^4003OQ00<?hN406>400`3Qh@0/h@@?4>400kkQh@2ih@:ni>4003KQ

00<?hN406N400`3Qh@0`h@<?3>400kkQh@2lh@:nh^4003CQ0PlLh@030>7Q03?Q0`l9h@03_^7Q0;kQ

0[kPh@00<n400`oQh@0Lh@<0=^433`KQ00>nhN40`>44_]cQ000bh@033n7Q01gQ00<0hN40>N433`;Q

00>nhN40aN42_][Q000ah@033n7Q01kQ00<0hN40?>433lWQ0[kHh@00<>400`oQh@0Oh@030>7Q03kQ

00Bn3`l?b>43_]GQ000_h@033n7Q023Q00<0hN40?^401;kQhN433lSQ0[kCh@00;^400`oQh@0Qh@03

0>7Q03gQ00>nhN401N433lOQ0[kAh@00;^400`oQh@0Qh@030>7Q03gQ00>nhN402>423lOQ1;k=h@00

;N400`oQh@0Rh@030>7Q03gQ00>nhN402^423lWQ0[k;h@00;>400`oQh@0Sh@030>7Q03cQ00>nhN40

3N433lSQ0[k9h@00:n400`oQh@0Th@030>7Q03cQ00>nhN404>423lSQ1;k5h@00:n400`oQh@0Th@03

0>7Q03cQ00>nhN404^433lWQ0[k3h@00:^400`oQh@0Uh@<0?>400kkQh@0Eh@<?b>44_[oQ000Yh@03

3n7Q02KQ00<0hN40>n400kkQh@0Ih@8?b^42_[gQ000Yh@033n7Q02KQ00<0hN40>n400kkQh@0Kh@<?

bN44_[WQ000Xh@033n7Q02OQ00<0hN40>n400kkQh@0Nh@<?b^42_[OQ000Xh@033n7Q02OQ00<0hN40

>n400kkQh@0Qh@8?b^43_[CQ000Wh@033n7Q02SQ00<0hN40>^400kkQh@0Th@<?b^42_[;Q000Wh@03

3n7Q02SQ00<0hN40>^400kkQh@0Wh@8?b^44_ZkQ000Vh@033n7Q02WQ00<0hN40>^400kkQh@0Yh@<?

bn42_ZcQ000Vh@033n7Q02WQ00<0hN40>^400kkQh@0/h@8?bn44_ZSQ000Uh@033n7Q02[Q00<0hN40

>^400kkQh@0^h@8?cN42_ZKQ000Uh@033n7Q02[Q00<0hN40>^400kkQh@0`h@8?cN44_Z;Q000Th@03

3n7Q02_Q0`0jh@03_^7Q03;Q0`o>h@BnW^4002CQ00<?hN40:n400`3Qh@0ih@03_^7Q03KQ0Po@h@Bn

V^4002?Q00<?hN40;>400`3Qh@0ih@03_^7Q03SQ0`oAh@:nV>4002?Q00<?hN40;>400`3Qh@0ih@03

_^7Q03_Q0PoAh@>nUN4002?Q00<?hN40;>400`3Qh@0ih@03_^7Q03gQ0`oAh@BnTN4002;Q00<?hN40

;N400`3Qh@0ih@03_^7Q043Q0PoCh@BnSN4002;Q00<?hN40;N400`3Qh@0hh@03_^7Q04?Q0`oDh@Bn

RN4002;Q00<?hN40;N400`3Qh@0hh@03_^7Q04KQ0PoFh@BnQN40027Q00<?hN40;^400`3Qh@0hh@03

_^7Q04SQ0`oGh@BnPN40027Q00<?hN40;^400`3Qh@0hh@03_^7Q04_Q0PoIh@BnON40027Q00<?hN40

;^400`3Qh@0hh@03_^7Q04gQ0`oJh@BnNN40023Q00<?hN40;n4303OQ00>nhN40DN423mcQ1;ieh@00

8>400`oQh@0_h@030>7Q03OQ00>nhN40D^433mkQ0kibh@008>400`oQh@0_h@030>7Q03OQ00>nhN40

EN423moQ1;i^h@008>400`oQh@0_h@030>7Q03OQ00>nhN40En433n3Q1[iXh@008>400`oQh@0_h@03

0>7Q03OQ00>nhN40F^423nCQ1;iTh@008>400`oQh@0_h@030>7Q03OQ00>nhN40G>433nGQ1[iNh@00

8>400`oQh@0_h@030>7Q03OQ00>nhN40Gn423nWQ1;iJh@007n400`oQh@0`h@030>7Q03KQ00>nhN40

H^433n[Q1KiEh@007n400`oQh@0`h@030>7Q03KQ00>nhN40IN423ngQ1[i?h@007n400`oQh@0Vh@03

0>7Q00OQ00<0hN40=^400kkQh@1Wh@<?l>44_T_Q000Oh@033n7Q02GQ00<0h@002>400`3Qh@0fh@03

_^7Q06[Q0Pobh@JnAN4001kQ00<?hN408N4300CQ00<0hN401^4403GQ00>nhN40K>423oKQ2;hmh@00

7^400`oQh@0Vh@802N400`3Qh@0fh@03_^7Q06kQ0`okh@Jn=n4001kQ00<?hN409^400`3Qh@08h@03

0>7Q03GQ00>nhN40L^423ooQ1Khbh@007^400`oQh@0Vh@<02>400`3Qh@0eh@03_^7Q07CQ0Pooh@?Q

0[h`h@007^400`oQh@0ah@030>7Q03GQ00>nhN40M^423ooQ<n4001gQ00<?hN40<^400`3Qh@0eh@03

_^7Q07SQ0`oohC3Q000Mh@033n7Q03;Q00<0hN40=N400kkQh@1kh@8?on4^h@007N400`oQh@0bh@03

0>7Q03GQ00>nhN40ON433ooQ:n4001gQ00<?hN40<^400`3Qh@0eh@03_^7Q083Q0`oohBSQ000Mh@03

3n7Q03;Q00<0hN40=N400kkQh@23h@8?on4Vh@007>400`oQh@0ch@<0=N400kkQh@25h@<?on4Sh@00

7>400`oQh@0ch@030>7Q03CQ00>nhN40RN433ooQ8>4001cQ00<?hN40<n400`3Qh@0dh@03_^7Q08cQ

0PoohAkQ000Lh@033n7Q03?Q00<0hN40=>400kkQh@2>h@<?on4Kh@007>400`oQh@0ch@030>7Q03CQ

00>nhN40TN423ooQ6N4001cQ00<?hN40<n400`3Qh@0dh@03_^7Q09?Q0PoohAOQ000Lh@033n7Q03?Q

00<0hN40=>400kkQh@2Eh@<?on4Dh@006n400`oQh@0dh@030>7Q03CQ00>nhN40V>423ooQ4^4001_Q

00<?hN40=>400`3Qh@0dh@03_^7Q09[Q0`ooh@oQ000Kh@033n7Q03CQ00<0hN40=>400kkQh@2Mh@8?

on4=h@006n400`oQh@0dh@030>7Q03CQ00>nhN40Wn433ooQ2^4001_Q00<?hN40=>4303CQ00>nhN40

X^423ooQ2>4001_Q00<?hN40=>400`3Qh@0dh@03_^7Q0:CQ0Pooh@KQ000Kh@033n7Q03CQ00<0hN40

<n400kkQh@2Wh@<?on43h@006n400`oQh@0dh@030>7Q03?Q00>nhN40Z^423ooQ0N4001[Q00<?hN40

=N400`3Qh@0ch@03_^7Q0:cQ0`omh@006^400`oQh@0eh@030>7Q03?Q00>nhN40[n423o_Q000Jh@03

3n7Q03GQ00<0hN40<n400kkQh@2ah@<?n>4001[Q00<?hN40=N400`3Qh@0ch@03_^7Q0;CQ0Pofh@00

6^400`oQh@0eh@030>7Q03?Q00>nhN40]^453o7Q000Jh@033n7Q03GQ00<0hN40<n400kkQh@2kh@8?

kn4001[Q00<?hN40=N400`3Qh@0ch@03_^7Q0;gQ0`o/h@006^400`oQh@0eh@<0<n400kkQh@30h@8?

j^4001[Q00<?hN40=N400`3Qh@0ch@03_^7Q0<;Q0`oWh@006^400`oQh@0eh@030>7Q03?Q00>nhN40

aN423nGQ000Jh@033n7Q03GQ00<0hN40<n400kkQh@37h@8?hn4001[Q00<?hN40=N400`3Qh@0ch@03

_^7Q0<WQ0`oPh@006^400`oQh@0eh@030>7Q03?Q00>nhN40c>453m_Q000Jh@033n7Q03GQ00<0hN40

<n400kkQh@3Ah@8?fN4001[Q00<?hN40=N400`3Qh@0ch@03_^7Q02?Q1@02h@030>7Q05SQ0`03h@03

0>7Q04GQ0PlAh@<00^4305WQ0`03h@<0G>4001[Q00<?hN40=N400`3Qh@0ch@03_^7Q02GQ00L0hN7Q

0>4005WQ00<0hN400^400`3Q0018h@<?3^400`3Qh@02h@030>7Q05WQ00<0hN401>400`3Qh@0?hA`?

<>4001WQ00<?hN40=^400`3Qh@0ch@03_^7Q02GQ00L0hN7Q0>4005[Q00L0hN7Q0>4004_Q1@l:h@03

0>7Q00;Q00<0hN40FN401@3QhN4001<?C>4001WQ00<?hN40=^400`3Qh@0ch@03_^7Q02GQ00<0hN40

0^400`3Qh@1Ih@070>7Qh@3Q001@h@8?2>400`3Qh@02h@030>7Q05;Q30l00n40h@1Lh@006N400`oQ

h@0fh@<0<n400kkQh@0Uh@070>7Qh@3Q001Ih@030>4000;Q00<0h@00D^433`CQ00<0h@000^400`3Q

0019h@X?1^400`3Q0003h@80GN4001WQ00<?hN40=^400`3Qh@0bh@03_^7Q02GQ0P04h@030>7Q05WQ

00<0hN400^400`3Qh@1Dh@8?0n400`3Qh@02h@030>7Q047Q1`lAh@030>7Q00?Q00<0hN40Fn4001WQ

00<?hN40=^400`3Qh@0bh@03_^7Q0>GQ1@m2h@D?O>4001WQ00<?hN40=^400`3Qh@0bh@03_^7Q0>[Q

0Plih@L?PN4001WQ00<?hN40=^400`3Qh@0bh@03_^7Q0>cQ0`lah@D?R>4001WQ00<?hN40=^400`3Q

h@0bh@03_^7Q0>oQ1@lWh@D?SN4001WQ00<?hN40=^400`3Qh@0bh@03_^7Q0?CQ0PlPh@D?T^4001WQ

00<?hN40=^400`3Qh@0bh@03_^7Q0?KQ1@lFh@D?Un4001WQ00<?hN40=^400`3Qh@0bh@03_^7Q0?_Q

0Pl?h@D?R>44013Q000Ih@033n7Q03KQ00<0hN40<^400kkQh@3mh@D?1^443hgQ0`0Ah@003>4=0003

3`0006/000>n0000o`0300H?PP0Ah@030>7Q00oQ000Ih@033n7Q00GQ00<0hN405^400`3Qh@0Eh@03

0>7Q01GQ00<0hN405N400`3Qh@02h@03_^7Q017Q00<0hN405N400`3Qh@0Eh@030>7Q01GQ00<0hN40

5^400`3Qh@0Eh@030>7Q01GQ00<0hN405N400`3Qh@0Fh@030>7Q01GQ00<0hN404^493a;Q00<0hN40

5^400`3Qh@0Eh@030>7Q01GQ00<0hN405N400`3Qh@0Kh@804N4001WQ00<?hN401N400`3Qh@0Fh@03

0>7Q01GQ00<0hN405N400`3Qh@0Eh@030>7Q00;Q00>nhN404N400`3Qh@0Eh@030>7Q01GQ00<0hN40

5N400`3Qh@0Fh@030>7Q01GQ00<0hN405N400`3Qh@0Eh@030>7Q01KQ00<0hN405N400`3Qh@0@h@8?

0n400`3Qh@03h@D?3N400`3Qh@0Fh@030>7Q01GQ00<0hN405N400`3Qh@0Eh@030>7Q02kQ000Ih@03

3n7Q03KQ00<0hN40<^400kkQh@0Yh@030>7Q05kQ00<0hN40G^400`3Qh@0;h@D?4>433c_Q00<0hN40

G^4001WQ00<?hN40=^400`3Qh@0bh@03_^7Q02WQ00<0hN40G^400`3Qh@1Nh@030>7Q00WQ0PlHh@D?

=^400`3Qh@1Nh@006N400`oQh@0fh@030>7Q03;Q00>nhN40l^453aoQ10nCh@006N400`oQh@0fh@03

0>7Q03;Q00>nhN40kn433bSQ1@n>h@006N400`oQh@0fh@030>7Q03;Q00>nhN40kN423c3Q1`n7h@00

6N400`oQh@0fh@030>7Q03;Q00>nhN40j>453cWQ1@n2h@006N400`oQh@0fh@030>7Q03;Q00>nhN40

i^423d?Q20mjh@006N400`oQh@0fh@030>7Q03?Q00>nhN40h^433dgQ1`mch@006N400`oQh@0fh@<0

<n400kkQh@3Mh@D?En4:3fWQ000Ih@033n7Q03KQ00<0hN40<n400kkQh@3Kh@8?I^4<3egQ000Jh@03

3n7Q03GQ00<0hN40<n400kkQh@3Hh@<?M>4]3c3Q000Jh@033n7Q03GQ00<0hN40<n400kkQh@3Fh@8?

e>4001[Q00<?hN40=N400`3Qh@0ch@03_^7Q0=CQ0PoFh@006^400`oQh@0eh@030>7Q03?Q00>nhN40

cn453mSQ000Jh@033n7Q03GQ00<0hN40<n400kkQh@3<h@<?gN4001[Q00<?hN40=N400`3Qh@0ch@03

_^7Q0<[Q0PoPh@006^400`oQh@0eh@030>7Q03?Q00>nhN40b>423n;Q000Jh@033n7Q03GQ00<0hN40

<n400kkQh@35h@<?i>4001[Q00<?hN40=N400`3Qh@0ch@03_^7Q0<?Q0PoWh@006^400`oQh@0eh@<0

<n400kkQh@2nh@D?jN4001[Q00<?hN40=N400`3Qh@0ch@03_^7Q0;_Q0`o^h@006^400`oQh@0eh@03

0>7Q03?Q00>nhN40^N423o7Q000Jh@033n7Q03GQ00<0hN40<n400kkQh@2gh@8?ln4001[Q00<?hN40

=N400`3Qh@0ch@03_^7Q0;CQ0`oeh@006^400`oQh@0eh@030>7Q03?Q00>nhN40/^423oSQ000Jh@03

3n7Q03GQ00<0hN40<n400kkQh@2_h@<?n^4001[Q00<?hN40=N400`3Qh@0ch@03_^7Q0:gQ0Pomh@00

6n400`oQh@0dh@030>7Q03?Q00>nhN40Z^433ooQ000Kh@033n7Q03CQ00<0hN40<n400kkQh@2Xh@8?

on43h@006n400`oQh@0dh@030>7Q03CQ00>nhN40YN423ooQ1N4001_Q00<?hN40=>4303CQ00>nhN40

X^433ooQ1n4001_Q00<?hN40=>400`3Qh@0dh@03_^7Q0:3Q0Pooh@[Q000Kh@033n7Q03CQ00<0hN40

=>400kkQh@2Kh@D?on4<h@006n400`oQh@0dh@030>7Q03CQ00>nhN40V>433ooQ4N4001_Q00<?hN40

=>400`3Qh@0dh@03_^7Q09KQ0PoohACQ000Lh@033n7Q03?Q00<0hN40=>400kkQh@2Dh@8?on4Fh@00

7>400`oQh@0ch@030>7Q03CQ00>nhN40TN433ooQ6>4001cQ00<?hN40<n400`3Qh@0dh@03_^7Q08oQ

0PoohA_Q000Lh@033n7Q03?Q00<0hN40=>400kkQh@2<h@<?on4Mh@007>400`oQh@0ch@030>7Q03CQ

00>nhN40R^423ooQ8>4001cQ00<?hN40<n4303GQ00>nhN40Qn423ooQ8^4001cQ00<?hN40<n400`3Q

h@0eh@03_^7Q08CQ0`oohBCQ000Mh@033n7Q03;Q00<0hN40=N400kkQh@22h@8?on4Wh@007N400`oQ

h@0bh@030>7Q03GQ00>nhN40On433ooQ:N4001gQ00<?hN40<^400`3Qh@0eh@03_^7Q07gQ0PoohBcQ

000Mh@033n7Q03;Q00<0hN40=N400kkQh@1jh@<?on4^h@007N400`oQh@0bh@030>7Q03GQ00>nhN40

N>423ooQ<N4001kQ00<?hN40<N400`3Qh@0eh@03_^7Q07GQ0`oohC?Q000Nh@033n7Q037Q00<0hN40

=N400kkQh@1dh@033n7Q0?oQ0N43_S3Q000Nh@033n7Q02OQ00<0hN401n400`3Qh@0fh@03_^7Q073Q

0`onh@Fn<n4001kQ00<?hN409^400`3Q0008h@030>7Q03KQ00>nhN40K^423o_Q1[hhh@007^400`oQ

h@0Xh@030>7Q00KQ100eh@03_^7Q06_Q0`ogh@Jn?^4001oQ00<?hN409N4200WQ00<0hN40=^400kkQ

h@1Yh@8?m>46_TCQ000Oh@033n7Q02GQ00<0hN402>400`3Qh@0fh@03_^7Q06KQ0`o`h@JnB^4001oQ

00<?hN409N4300SQ00<0hN40=^400kkQh@1Th@8?kN46_U3Q000Oh@033n7Q033Q00<0hN40=^400kkQ

h@1Qh@<?k>43_UKQ000Ph@033n7Q02oQ00<0hN40=n400kkQh@1Nh@8?jN46_UWQ000Ph@033n7Q02oQ

00<0hN40=n400kkQh@1Kh@<?in44_UoQ000Ph@033n7Q02oQ00<0hN40=n400kkQh@1Ih@8?i>46_V?Q

000Ph@033n7Q02oQ00<0hN40=n400kkQh@1Gh@8?h^44_VWQ000Ph@033n7Q02oQ00<0hN40=n400kkQ

h@1Dh@<?h>44_VgQ000Ph@033n7Q02oQ00<0hN40=n400kkQh@1Bh@8?g^45_W7Q000Ph@033n7Q02oQ

0`0hh@03_^7Q04oQ0`oKh@BnM^40027Q00<?hN40;^400`3Qh@0hh@03_^7Q04gQ0PoJh@BnN^40027Q

00<?hN40;^400`3Qh@0hh@03_^7Q04[Q0`oHh@BnO^40027Q00<?hN40;^400`3Qh@0hh@03_^7Q04SQ

0PoGh@BnP^4002;Q00<?hN40;N400`3Qh@0hh@03_^7Q04GQ0`oEh@BnQ^4002;Q00<?hN40;N400`3Q

h@0hh@03_^7Q04?Q0PoDh@BnR^4002;Q00<?hN40;N400`3Qh@0ih@03_^7Q03oQ0`oBh@BnS^4002?Q

00<?hN40;>400`3Qh@0ih@03_^7Q03gQ0PoCh@:nT^4002?Q00<?hN40;>400`3Qh@0ih@03_^7Q03[Q

0`oBh@>nU>4002CQ00<?hN40:n400`3Qh@0ih@03_^7Q03SQ0PoAh@BnUn4002CQ00<?hN40:n400`3Q

h@0ih@03_^7Q03GQ0`o?h@BnVn4002CQ00<?hN40:n4303[Q00>nhN40<^423m3Q0[jOh@009N400`oQ

h@0Zh@030>7Q03[Q00>nhN40;n433lkQ1;jQh@009N400`oQh@0Zh@030>7Q03[Q00>nhN40;^400`oQ

h@3;h@BnYN4002KQ00<?hN40:N400`3Qh@0jh@03_^7Q02_Q0`o<h@:nZN4002KQ00<?hN40:N400`3Q

h@0jh@03_^7Q02WQ0Po;h@BnZn4002OQ00<?hN40:>400`3Qh@0jh@03_^7Q02KQ0`o;h@:n[n4002OQ

00<?hN40:>400`3Qh@0jh@03_^7Q02CQ0Po:h@Bn/N4002SQ00<?hN409n400`3Qh@0kh@03_^7Q023Q

0`o;h@03_^7Q0;?Q000Xh@033n7Q02OQ00<0hN40>n400kkQh@0Mh@<?b^44_[KQ000Yh@033n7Q02KQ

00<0hN40>n400kkQh@0Kh@8?bn42_[[Q000Zh@033n7Q02GQ00<0hN40>n400kkQh@0Hh@<?bN44_[cQ

000Zh@033n7Q02GQ0`0lh@03_^7Q01CQ0`o:h@:n`>4002_Q00<?hN409>400`3Qh@0lh@03_^7Q01;Q

0Po9h@Bn`^4002cQ00<?hN408n400`3Qh@0lh@03_^7Q00oQ0`o9h@:na^4002cQ00<?hN408n400`3Q

h@0lh@03_^7Q00cQ0`o:h@:nb>4002gQ00<?hN408^400`3Qh@0mh@03_^7Q00[Q0Po8h@Bnb^4002kQ

00<?hN408N400`3Qh@0mh@03_^7Q00OQ0`o8h@:nc^4002oQ00<?hN408>400`3Qh@0mh@03_^7Q00CQ

0`o9h@:nd>40033Q00<?hN407n400`3Qh@0nh@03_^7Q00<?b>44_];Q000`h@033n7Q01oQ00<0hN40

?^433l[Q00>nhN40e>40037Q00<?hN407^400`3Qh@0kh@<?00>nhN40b>42_]OQ000bh@8?7^4303SQ

0`l4h@03_^7Q0<?Q1;kIh@00=>400`oQh@0Kh@030>7Q03GQ0`l7h@03_^7Q0<7Q0[kMh@00=N400`oQ

h@0Jh@030>7Q03;Q0`l:h@03_^7Q0;oQ0[kOh@00=^400`oQh@0Ih@030>7Q02oQ0`l>h@03_^7Q0;cQ

0[kQh@00=n423aWQ00<0hN40:n443a7Q00>nhN40^>44_^?Q000ih@033n7Q01KQ00<0hN40:N433aCQ

00>nhN40]^42_^OQ000jh@8?5^400`3Qh@0Uh@@?6>400kkQh@2ch@:njN4003cQ0PlDh@030>7Q027Q

10lLh@03_^7Q0;7Q0[k[h@00?^423a;Q00<0hN407N443b3Q00>nhN40[n42_^gQ0010h@8?1002h@03

0>7Q00OQ00<0hN406N443bGQ00>nhN40Z^44_^oQ0012h@<?0^400`3Q0008h@030>7Q01CQ1@lYh@03

_^7Q0:SQ0[kch@00@n400`3Q3`033`030>7Q00KQ100<h@L?;n400kkQh@2Vh@03_^7Q0??Q0013h@06

0>7Qh@3Q2`l2h@`?=^400kkQh@2Th@:nm^4004?Q00L0hN7Q0>4000SQ00@0h@l?@^400kkQh@2Rh@:n

n>4004;Q0P04h@030>7Q00OQ00<0hN40A>400kkQh@2Oh@:nn^4005;Q00<0hN40A>400kkQh@2Mh@:n

o>4005;Q00<0hN40AN400kkQh@2Hh@Bno^4005;Q00<0hN40AN400kkQh@2Fh@:non43h@00D^400`3Q

h@16h@03_^7Q09?Q0[koh@GQ001Bh@030>7Q04KQ00>nhN40TN42__oQ1n4005;Q00<0hN40An400kkQ

h@2>h@:non49h@00D^400`3Qh@17h@03_^7Q08cQ0[koh@_Q001Bh@<0B>400kkQh@29h@:non4=h@00

D^400`3Qh@18h@03_^7Q08OQ0[koh@oQ001Bh@030>7Q04WQ00>nhN40Q>42__oQ4N4005;Q00<0hN40

BN400kkQh@20h@Bnon4Ch@00D^400`3Qh@1:h@03_^7Q07kQ00>nhN40on4Eh@00D^400`3Qh@1:h@03

_^7Q07cQ0[kohASQ001Bh@030>7Q04[Q0[ikh@:non4Jh@00D^400`3Qh@1;h@03_^7Q07OQ0[kohAcQ

001Bh@030>7Q04cQ00>nhN40M>42__oQ7^4005;Q00<0hN40C>400kkQh@1bh@:non4Ph@00D^400`3Q

h@1=h@03_^7Q06oQ0[kohB;Q001Bh@<0C^400kkQh@1/h@:non4Th@00D^400`3Qh@1>h@:nJn42__oQ

9^4005;Q00<0hN40Cn400kkQh@1Uh@Bnon4Xh@00D^400`3Qh@1@h@03_^7Q06;Q0[kohBcQ001Bh@03

0>7Q057Q00>nhN40Gn42__oQ;^4005;Q00<0hN40DN42_UkQ0[kohC3Q001Bh@030>7Q05;Q0[iKh@:n

on4bh@00D^400`3Qh@1Ch@:nF>42__oQ=>4005;Q00<0hN40E>42_UKQ00>nhN40on4dh@00D^400`3Q

h@1Eh@:nDN44__oQ=n4005;Q0`1Fh@:nC^42__oQ>n4005;Q00<0hN40En42_T_Q0[kohCgQ001Bh@03

0>7Q05SQ0[i8h@:non4oh@00D^400`3Qh@1Jh@03_^7Q04?Q0[kohD7Q001Bh@030>7Q05[Q0[i0h@Bn

on53h@00D^400`3Qh@1Lh@:n?>42__oQAn4005;Q00<0hN40GN42_SOQ1;kohDWQ001Bh@030>7Q05oQ

0[hch@:non5=h@00D^400`3Qh@1Qh@:n;N44__oQCn4005;Q00<0hN40Hn42_RSQ0kkohE?Q001Bh@03

0>7Q06GQ0khQh@Bnon5Fh@00D^4306SQ0khIh@Jnon5Ih@00D^400`3Qh@1[h@Jn3N47__oQG^4005;Q

00<0hN40L>4>__oQIN4005;Q00<0hN40on7Sh@00D^400`3Qh@3ohN?Q001Bh@030>7Q0?oQhn4005;Q

00<0hN40on7Sh@00D^400`3Qh@3ohN?Q001Bh@030>7Q0?oQhn4005;Q00<0hN40on7Sh@00D^400`3Q

h@3ohN?Q003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ

>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400?oQon4ih@00on42h@8000?Q00001^4400OQ00<0hN40

0^400`3Qh@3ohAWQ003oh@?Q00<0h@004^401`3QhN40h@00on4Jh@00on43h@<01n4400OQ00L0hN7Q

0>400?oQ6^400?oQ0n40103Q000Bh@060>7Q0>40on4Jh@00D>420;3Q00<0hN404N400`3Q0002h@03

0>400?oQ6^40057Q00<0hN40[N4201?Q0`03h@030>7Q0?oQ6N4004oQ0`02h@030>7Q0?oQhN4004kQ

00P0hN40h@3Q0?oQh^4004kQ00P0hN40h@3Q0?oQh^4004oQ0`001>40h@3ohN;Q001Ch@030>400?oQ

h^4005CQ00<0hN40on7Qh@00on7ohCWQ003ohOoQ>N400?oQon4ih@00on7ohCWQ003ohOoQ>N400001

\

\>"],

  ImageRangeCache->{{{0, 566}, {349.313, 0}} -> {14.2998, -14.8707, 0.0206228,

   0.0928385}}]

}, Closed]]

}, Open  ]],



Cell[TextData[{

  "\nAt any point on a branch of solutions defined by (q0,p0,w0)  we may \n\

calculate the deflection of the plate",

  StyleBox[" w",

    FontSlant->"Italic"],

  "(r). This is done by using (2.5), \nfrom which we get   ",

  StyleBox["w",

    FontSlant->"Italic"],

  "(",

  StyleBox["r",

    FontSlant->"Italic"],

  ") = -",

  StyleBox["r ",

    FontSlant->"Italic"],

  StyleBox["W1(",

    FontSize->16],

  StyleBox["r",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[") -2 W(",

    FontSize->16],

  StyleBox["r",

    FontSize->16,

    FontSlant->"Italic"],

  StyleBox[

  "). \nWe can plot a sequence of deflection curves along a branch of \

solutions \nby using the following code.    ",

    FontSize->16]

}], "Input",

  FormatType->TextForm,

  FontSize->16],



Cell[CellGroupData[{



Cell[BoxData[

    \(Length[k38loopf]\)], "Input"],



Cell[BoxData[

    \(1990\)], "Output"]

}, Open  ]],



Cell[BoxData[

    \("\<k38loopf is in k38loopf\>"\)], "Input"],



Cell[CellGroupData[{



Cell[BoxData[

    \(loop = \n\ \ \ \ \ 

      Show[Graphics[{

            Line[Table[{k38loopf[\([i, 2]\)], k38loopf[\([i, 3, 1]\)]}, {i, 

                  1990}]]}\ ], \n\ \ \ \ \ \ \ \ \ \ Axes -> Automatic, 

        AxesLabel -> {a, q0}, \ PlotRange -> All\ ]\)], "Input"],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{288, 177.938},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l00003<006H009T00<`00?l0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV

09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<003o03?o06Ko09Wo0<co

0?oo0000<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I

<c>I<fJI<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0

IYT0I/`0I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bI

I_nIIP3<IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0c

VC<cVFHcVITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<

VIW<VLc<VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`c

c?lcc01Vc3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03o

c3?oc6Koc9Woc<coc?ooc000oc<0ofH0oiT0ol`0ool0o`0coc<cofHcoiTcol`coolco`1Voc=VofIV

oiUVolaVoomVo`2Ioc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<o`3ooc?oofKooiWoolco

ooooo`0000410@820P<30`@410D51@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C

4a@D5?okl:2PY820P?l0003o0?oo0000ool0o`3oooooobcQ00<0hN40lN4002cQ00<0hN40lN4002cQ

0P3bh@00;>400`3Qh@1[h@l0Mn4002cQ00<0hN40I>4700oQ2`1/h@00;>400`3Qh@1Ph@@08>4906CQ

000/h@030>7Q05cQ100/h@L0G^4002cQ0P1Kh@<0=N4705SQ000/h@030>7Q05SQ0P0oh@H0D^4002cQ

00<0hN40E^4204KQ1P1=h@00;>400`3Qh@1Eh@80CN4504SQ000/h@030>7Q05?Q0P1Ch@D0A>4002cQ

00<0hN40D^4205SQ1011h@00;>42057Q0P1Mh@@0?^4002cQ00<0hN403>4K02SQ0P1Qh@<0?>4002cQ

00<0hN402>4401[Q2@0Oh@80I>4303[Q000/h@030>7Q00CQ100Vh@L06N400`3Qh@1Uh@<0>>4001oQ

1@02h@030>7Q00?Q00@0hN7Q0`0`h@H04^4206[Q0P0gh@008N401`3QhN40h@001>40103Q000ih@D0

3N400`3Qh@1[h@80=N4001_Q0`03h@070>7Qh@3Q0004h@<0?n4500OQ00<0hN40KN4203CQ000Qh@07

0>7Qh@3Q0002h@<0AN460003h@3Q077Q0P0bh@008N401P3QhN40h@<00^400`3Qh@18h@D0LN42037Q

000Ph@801>4200CQ00<0hN40BN400`3Qh@0506kQ0P0`h@009^400`3Qh@03h@030>7Q04SQ00<0hN40

1^4406_Q0P0_h@009N400`3Qh@04h@030>7Q04SQ00<0hN402^4406SQ0P0^h@008n4200OQ0P18h@03

0>7Q00kQ1@1Uh@80;N4002;Q00<0hN401n400`3Qh@16h@805>4506;Q00<0hN40:n40027Q00<0hN40

2>400`3Qh@16h@030>7Q01OQ101Ph@030>7Q02[Q000Ph@030>7Q00WQ00<0hN40A^400`3Qh@0Kh@@0

G>4202_Q000Oh@030>7Q00[Q00<0hN40AN400`3Qh@0Oh@D0FN4202[Q000Nh@030>7Q00_Q00<0hN40

AN400`3Qh@0Sh@@0En400`3Qh@0Xh@007N400`3Qh@0<h@80AN400`3Qh@0Xh@@0E>400`3Qh@0Wh@00

7N400`3Qh@0<h@030>7Q04CQ00<0hN40:n44057Q0P0Xh@007>400`3Qh@0=h@030>7Q04?Q00<0hN40

;n4404oQ00<0hN409^4001cQ00<0hN403N400`3Qh@13h@030>7Q03;Q101<h@809n4001_Q00<0hN40

3^400`3Qh@13h@030>7Q03KQ0`1:h@030>7Q02GQ000Jh@030>7Q00oQ0P13h@030>7Q03[Q0`18h@03

0>7Q02CQ000Ih@030>7Q013Q00<0hN40@^400`3Qh@0lh@@0AN400`3Qh@0Th@006N400`3Qh@0@h@03

0>7Q047Q00<0hN40@N4204CQ00<0hN408n4001SQ00<0hN404N400`3Qh@11h@030>7Q04?Q1010h@03

0>7Q02?Q000Hh@030>7Q017Q00<0hN40@N400`3Qh@16h@<0?n400`3Qh@0Rh@006>400`3Qh@0Ah@03

0>7Q047Q00<0hN40BN4203gQ00<0hN408^4001OQ00<0hN404^42047Q00<0hN40C>4303[Q0P0Sh@00

5n400`3Qh@0Bh@030>7Q043Q00<0hN40Cn4203WQ00<0hN408N4001KQ00<0hN404n400`3Qh@0oh@03

0>7Q05;Q0`0fh@030>7Q027Q000Fh@030>7Q01?Q00<0hN40?n400`3Qh@1Eh@80=>4202;Q000Eh@03

0>7Q00kQ00<0hN400n400`3Qh@0oh@030>7Q05OQ0`0bh@030>7Q023Q000Eh@030>7Q00gQ00<0h@00

1>400`3Qh@0oh@030>7Q05WQ0`0`h@030>7Q023Q000Dh@030>7Q00WQ0`04h@030>7Q00;Q0`0oh@03

0>7Q05cQ0P0^h@030>7Q023Q000Dh@030>7Q00kQ0P05h@030>7Q03oQ00<0hN40GN4302cQ0P0Qh@00

5>400`3Qh@0>h@030>7Q00CQ00<0hN40?^400`3Qh@1Qh@<0:^400`3Qh@0Oh@005>400`3Qh@0>h@<0

1>400`3Qh@0nh@030>7Q06?Q0P0Yh@030>7Q01oQ000Ch@030>7Q01KQ00<0hN40?^400`3Qh@1Uh@<0

9^400`3Qh@0Oh@004n400`3Qh@0Fh@030>7Q03kQ00<0hN40In4202GQ00<0hN407n4001?Q00<0hN40

5^4203kQ00<0hN40J^4302;Q00<0hN407n4001?Q00<0hN405^400`3Qh@0mh@030>7Q06cQ0P0Qh@03

0>7Q01oQ000Bh@030>7Q01OQ00<0hN40?N400`3Qh@1^h@808>400`3Qh@0Nh@004^400`3Qh@0Gh@03

0>7Q03gQ00<0hN40L>4201kQ00<0hN407^4001;Q00<0hN405n400`3Qh@0mh@030>7Q077Q0`0Lh@03

0>7Q01kQ000Bh@030>7Q01OQ00<0hN40?N400`3Qh@1dh@806^400`3Qh@0Nh@004N400`3Qh@0Hh@80

?^400`3Qh@1eh@806>400`3Qh@0Oh@004N400`3Qh@0Hh@030>7Q03gQ00<0hN40Mn4201KQ00<0hN40

7n40017Q00<0hN406>400`3Qh@0mh@030>7Q07WQ00<0hN404n400`3Qh@0Oh@004N400`3Qh@0Hh@03

0>7Q03gQ00<0hN40NN4201CQ00<0hN407n40017Q00<0hN406>400`3Qh@0lh@030>7Q07cQ0P0Bh@03

0>7Q01oQ000Ah@030>7Q01SQ0P0mh@030>7Q07kQ0P0@h@030>7Q01oQ000Ah@030>7Q01SQ00<0hN40

8N4500;Q00<0hN404N400`3Qh@0:h@D000?Q00008N4500;Q00<0hN407^4500;Q00<0hN406^400`3Q

h@02h@D000?Q00000n400`3Qh@0Ph@004N400`3Qh@0Hh@030>7Q02?Q00L0hN7Q0>4001;Q00<0hN40

3>401`3QhN40h@008^400`3Qh@02h@030>7Q023Q00L0hN7Q0>4001cQ0P04h@030>7Q00?Q00@0hN40

8^40017Q00<0hN406>400`3Qh@0Sh@030>7Q00?Q00<0hN404>400`3Qh@0<h@070>7Qh@3Q000Rh@03

0>7Q00;Q00<0hN408>401`3QhN40h@007^401@3QhN4000CQ0P02h@030>7Q023Q000Ah@030>7Q01SQ

00<0hN408n40103QhN4201?Q00<0hN403>40103QhN4202?Q00<0hN400n400`3Qh@0Oh@030>7Q00;Q

00<0hN407^40103Qh@03h@030>4000;Q00<0hN408>40013Q00<0hN406N400`3Qh@0Sh@050>7Qh@00

5>400`3Qh@0<h@050>7Qh@009>401`3QhN40h@008N401`3QhN40h@008>400`3Q0003h@050>40h@00

8n40013Q00<0hN406N4202?Q0P03h@<04^400`3Qh@0;h@801>42027Q0P03h@<08>4200CQ00<0hN40

8>4200CQ0P000n40h@0Rh@004>400`3Qh@0Ih@030>7Q03cQ00<0hN40Q^4200GQ00<0hN408^40013Q

00<0hN406N400`3Qh@0lh@030>7Q08OQ00<0hN400^400`3Qh@0Sh@004>400`3Qh@0Ih@030>7Q03cQ

00<0hN40R>401@3QhN4002GQ000@h@030>7Q01WQ00<0hN40?>400`3Qh@29h@040>7Q01?Q100>h@00

4>400`3Qh@0Ih@030>7Q03cQ00<0hN40R^4201CQ0`0?h@002^7l00[Q00<0hN403N4000cQ00D0hN7Q

0003h@030>7Q00GQ00<0hN401N400`3Qh@05h@030>7Q00GQ00<0hN401N400`3Qh@05h@030>7Q00KQ

00<0hN401N400`3Qh@05h@030>7Q00GQ00<0hN400n400`3Q0007h@030>7Q00GQ00<0hN401N400`3Q

h@06h@030>7Q00GQ00<0hN401N400`3Qh@05h@030>7Q00GQ00<0hN401N400`3Qh@05h@030>7Q00GQ

00<0hN401N400`3Qh@06h@030>7Q00GQ00<0hN401N400`3Qh@05h@030>7Q00GQ0`05h@030>7Q00gQ

0P0?h@004>400`3Qh@0Ih@030>7Q03cQ00<0hN40RN40103Qh@0Uh@004>400`3Qh@0Ih@030>7Q03cQ

00<0hN40R>401@3QhN4002GQ000@h@030>7Q01WQ00<0hN40?>400`3Qh@27h@030>7Q00?Q00<0hN40

8^40013Q00<0hN406N400`3Qh@0lh@030>7Q08KQ00<0hN401>400`3Qh@0Rh@004>400`3Qh@0Ih@80

?N400`3Qh@25h@030>7Q00KQ00<0hN408N40013Q00<0hN406N400`3Qh@0lh@030>7Q08CQ00<0hN40

1n400`3Qh@0Qh@004N400`3Qh@0Hh@030>7Q03cQ00<0hN40Pn400`3Qh@09h@030>7Q023Q000Ah@03

0>7Q01SQ00<0hN40?>400`3Qh@22h@030>7Q00[Q00<0hN408>40017Q00<0hN406>400`3Qh@0lh@03

0>7Q083Q0P0=h@030>7Q023Q000Ah@030>7Q01SQ0P0mh@030>7Q07oQ00<0hN403N400`3Qh@0Ph@00

4N400`3Qh@0Hh@030>7Q03cQ00<0hN40O^400`3Qh@0?h@030>7Q01oQ000Ah@030>7Q01SQ00<0hN40

?>400`3Qh@1lh@804^400`3Qh@0Oh@004N400`3Qh@0Hh@030>7Q03gQ00<0hN40NN4201CQ00<0hN40

7n40017Q00<0hN406>400`3Qh@0mh@030>7Q07SQ0P0Eh@030>7Q01oQ000Ah@030>7Q01SQ00<0hN40

?N400`3Qh@1fh@805n400`3Qh@0Oh@004^400`3Qh@0Gh@80?^400`3Qh@1eh@030>7Q01OQ00<0hN40

7n4001;Q00<0hN405n400`3Qh@0mh@030>7Q07?Q0P0Kh@030>7Q01kQ000Bh@030>7Q01OQ00<0hN40

?N400`3Qh@1ah@807N400`3Qh@0Nh@004^400`3Qh@0Gh@030>7Q03gQ00<0hN40L>4201kQ00<0hN40

7^4001?Q00<0hN405^400`3Qh@0mh@030>7Q06gQ0`0Ph@030>7Q01kQ000Ch@030>7Q01KQ00<0hN40

?N400`3Qh@1/h@030>7Q023Q00<0hN407n4001?Q00<0hN405^4203kQ00<0hN40J^4202?Q00<0hN40

7n4001?Q00<0hN405^400`3Qh@0nh@030>7Q06OQ0P0Uh@030>7Q01oQ000Ch@030>7Q01KQ00<0hN40

?^400`3Qh@1Uh@809n400`3Qh@0Oh@005>400`3Qh@0Eh@030>7Q03kQ00<0hN40Hn4202WQ00<0hN40

7n4001CQ00<0hN403n400`3Qh@03h@030>7Q03kQ00<0hN40HN4202_Q00<0hN407n4001CQ00<0hN40

3^400`3Q0004h@030>7Q03oQ00<0hN40GN4302cQ0P0Qh@005>400`3Qh@0@h@030>7Q00;Q0`0oh@03

0>7Q05_Q0`0^h@030>7Q023Q000Eh@030>7Q00gQ0P05h@030>7Q03oQ00<0hN40FN42037Q00<0hN40

8>4001GQ00<0hN403N400`3Qh@04h@030>7Q03oQ00<0hN40En4203?Q00<0hN408>4001KQ00<0hN40

3>4300CQ00<0hN40?n400`3Qh@1Eh@80=>4202;Q000Fh@030>7Q01?Q00<0hN40@>400`3Qh@1Ah@<0

=^400`3Qh@0Qh@005n400`3Qh@0Bh@030>7Q043Q00<0hN40Cn4203WQ00<0hN408N4001OQ00<0hN40

4^42047Q00<0hN40C>4303[Q0P0Sh@006>400`3Qh@0Ah@030>7Q047Q00<0hN40B>4303gQ00<0hN40

8^4001SQ00<0hN404N400`3Qh@11h@030>7Q04KQ0P10h@030>7Q02;Q000Ih@030>7Q013Q00<0hN40

@N400`3Qh@13h@<0@N400`3Qh@0Sh@006N400`3Qh@0@h@030>7Q047Q00<0hN40@>4304CQ00<0hN40

8n4001[Q00<0hN403n4204?Q00<0hN40?>4304KQ00<0hN409>4001[Q00<0hN403n400`3Qh@12h@03

0>7Q03WQ1018h@030>7Q02CQ000Kh@030>7Q00kQ00<0hN40@n400`3Qh@0eh@<0Bn400`3Qh@0Uh@00

7>400`3Qh@0=h@030>7Q04?Q00<0hN40<^4304gQ0P0Wh@007N400`3Qh@0<h@030>7Q04CQ00<0hN40

;N44053Q00<0hN409^4001gQ00<0hN403>400`3Qh@14h@030>7Q02[Q101Bh@030>7Q02OQ000Nh@03

0>7Q00_Q0P15h@030>7Q02OQ101Dh@80:N4001kQ00<0hN402n400`3Qh@15h@030>7Q02;Q1@1Gh@03

0>7Q02SQ000Oh@802n400`3Qh@15h@030>7Q01oQ101Jh@030>7Q02WQ000Ph@030>7Q00WQ00<0hN40

A^400`3Qh@0Jh@D0G>4202_Q000Qh@030>7Q00SQ00<0hN40A^400`3Qh@0Gh@@0Gn4202cQ000Rh@03

0>7Q00OQ00<0hN40An400`3Qh@0Bh@@0Hn400`3Qh@0[h@008n400`3Qh@06h@80B>400`3Qh@0>h@@0

I^400`3Qh@0/h@009>4200KQ00<0hN40B>400`3Qh@09h@D0J>400`3Qh@0]h@009^400`3Qh@03h@03

0>7Q04SQ0P06h@D0Jn4202oQ000Wh@800n400`3Qh@19h@030>4000@0Kn42033Q000Oh@D00^400`3Q

h@020003h@3Q04SQ1@1bh@030>7Q033Q000Qh@070>7Qh@3Q0003h@80A>4600;Q0P1`h@80<n40027Q

00L0hN7Q0>4000CQ0`0nh@D02>4206kQ0P0dh@008N401`3QhN40h@001>400`3Q000203OQ1@0>h@03

0>7Q06[Q0`0eh@008N401`3QhN40h@001>400`3Qh@02h@80;n4601CQ00<0hN40J>4203OQ000Ph@80

1>400`3Qh@03h@030>7Q00CQ1@0Th@L06^400`3Qh@1Uh@<0>>4002cQ00<0hN402N4401OQ2@0Qh@80

I>4303[Q000/h@030>7Q00gQ600[h@030>7Q05oQ0`0lh@00;>4205;Q0P1Lh@<0?n4002cQ00<0hN40

D^4205OQ1012h@00;>400`3Qh@1Ch@<0DN4504GQ000/h@030>7Q05GQ0P1<h@D0BN4002cQ00<0hN40

En4204CQ1P1>h@00;>4205WQ0`0lh@L0Dn4002cQ00<0hN40F^4303CQ1`1Ih@00;>400`3Qh@1Mh@@0

:N4805oQ000/h@030>7Q063Q1@0Mh@T0I^4002cQ00<0hN40I>4;00KQ3P1^h@00;>400`3Qh@1^h@P0

Nn4002cQ0P3bh@00;>400`3Qh@3ah@00;>400`3Qh@3ah@00on4Qh@00on4Qh@00on4Qh@00on4Qh@00

on4Qh@00on4Qh@00on4Qh@00on4Qh@00on4Qh@00:^420?CQ000[h@030>7Q0?;Q000Yh@<00^400`3Q

h@3_h@00:>40203Qh@3Q0>40l>4002SQ00P0hN40h@3Q0?3Q000Yh@<000CQ0>40l>4002gQ00<0h@00

l>4002kQ00<0hN40kn400?oQ8N400?oQ8N400?oQ8N400?oQ8N400?oQ8N400001\

\>"],

  ImageRangeCache->{{{73.4375, 302.813}, {246.625, 105.313}} -> {10.6353, 

  9.41776, 0.0246723, 0.172985}}],



Cell[BoxData[

    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),

      False,

      Editable->False]], "Output"]

}, Open  ]],



Cell[BoxData[{

    \(\neqnsmall[q0_, p0_, w0_, a_, k_]\  := \n

      \ \ \ \ \ \ {\(q'\)[r]\  == \ q1[r], \ \(p'\)[r]\  == \ p1[r], \ 

        \(w'\)[r]\  == \ w1[r], \n\ \ \ \ \ \ \ \ \ \ \ \ 

        \(q1'\)[r] + 3/r\ q1[r] + a^2\ p[r]\ q[r] == k^2\ w[r], \n

        \ \ \ \ \ \ \ \ \ \ \ \ \(p1'\)[r] + 3/r\ p1[r]\  == \ .5\ q[r]^2, \n

        \ \ \ \ \ \ \ \ \ \ \ \ \(w1'\)[r] + 3/r\ w1[r] + q[r]\  == 0, \n

        \ \ \ \ \ \ \ \ \ \ \ \ q1[10^\(-6\)] == 0, p1[10^\(-6\)] == 0, 

        w1[10^\(-6\)] == 0, \n\ \ \ \ \ \ \ \ \ \ \ \ q[10^\(-6\)] == q0, 

        p[10^\(-6\)] == p0, w[10^\(-6\)] == w0}\n\ \ \ \ \ \ \ \ \ \ \ \), 

    \(ivpsmall[{q0_, p0_, w0_}, a_, k_]\  := \n\ \ \ \ \ 

      NDSolve[eqnsmall[q0, p0, w0, a, k], {q, p, w, q1, p1, w1}, {r, 1}\ , 

        MaxSteps -> 5000\ ]\)}], "Input"],



Cell["\<\





deflection[{q0_,p0_,w0_},a_,k_,r_]:= 

     (-r*w1[r] - 2*w[r])/.Flatten[ivpsmall[{q0,p0,w0},a,k]]





\

\>", "Input",

  PageWidth->Infinity,

  InitializationCell->True,

  ShowSpecialCharacters->False,

  FormatType->InputForm],



Cell[BoxData[

    \(plotdeflection := \n

      Plot[deflection[k38loopf[\([i, 3]\)], k38loopf[\([i, 2]\)], 

          k38loopf[\([i, 1]\)], r], {r, 10^\(-6\), 1}, \n\ Axes -> Automatic, 

        AxesLabel -> {r, DEFLECTION}, PlotRange -> {\(-1.\), 1.}, \n\t\t

        PlotStyle -> Hue[1], \n\ 

        PlotLabel -> StringForm["\<a=``\>", k38loopf[\([i, 2]\)]], 

        DisplayFunction -> Identity]\)], "Input"],



Cell[BoxData[

    \(plotloop := \n

      Show[{loop, 

          Graphics[{Hue[1], PointSize[.05], 

              Point[{k38loopf[\([i, 2]\)], k38loopf[\([i, 3, 1]\)]}]}]}, \n

        \t\tDisplayFunction -> Identity]\)], "Input"],



Cell[BoxData[

    \(deflectionloop[imin_, imax_, di_] := \n

      Table[Show[GraphicsArray[{plotdeflection, plotloop}]], {i, imin, imax, 

          di}]\)], "Input"],



Cell[CellGroupData[{



Cell[BoxData[

    \(deflectionloop[2, 1989, 56]\)], "Input"],



Cell[CellGroupData[{



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -57 0 ]

[.5 .63053 57 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -118 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(13.3400000000000007`) show

173.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .29243 m

.02499 .29243 L

.02606 .29244 L

.02729 .29244 L

.02846 .29244 L

.03053 .29245 L

.03279 .29247 L

.03527 .29249 L

.0379 .29252 L

.04262 .29258 L

.05205 .29277 L

.06245 .29306 L

.07293 .29343 L

.0842 .29392 L

.10458 .29501 L

.14581 .29778 L

.18551 .30072 L

.22371 .30327 L

.24502 .30442 L

.26435 .30523 L

.27403 .30555 L

.2845 .30583 L

.28931 .30594 L

.29439 .30603 L

.29906 .3061 L

.30348 .30615 L

.30586 .30618 L

.30844 .3062 L

.31059 .30622 L

.31296 .30623 L

.31552 .30624 L

.31692 .30624 L

.31824 .30625 L

.31946 .30625 L

.32059 .30625 L

.32182 .30625 L

.32312 .30625 L

.32427 .30625 L

.32531 .30625 L

.32652 .30624 L

.32766 .30624 L

.32968 .30623 L

.33188 .30622 L

.33686 .30618 L

.34145 .30614 L

.35115 .30601 L

.36022 .30585 L

.38086 .30539 L

.41968 .30428 L

.43943 .30372 L

Mistroke

.46096 .30319 L

.47095 .303 L

.48159 .30282 L

.48676 .30276 L

.49163 .3027 L

.49633 .30266 L

.50072 .30264 L

.50297 .30262 L

.50539 .30262 L

.50676 .30261 L

.50807 .30261 L

.50924 .30261 L

.51051 .3026 L

.51175 .3026 L

.51245 .3026 L

.51311 .3026 L

.51381 .3026 L

.51444 .30261 L

.51514 .30261 L

.51588 .30261 L

.5171 .30261 L

.51825 .30261 L

.52084 .30262 L

.52325 .30264 L

.52552 .30265 L

.52978 .30268 L

.53436 .30273 L

.53932 .30279 L

.54881 .30294 L

.55924 .30316 L

.58029 .30374 L

.62068 .30531 L

.65956 .30709 L

.70089 .30888 L

.72156 .30962 L

.7407 .31017 L

.75926 .31057 L

.76864 .31071 L

.77368 .31078 L

.779 .31083 L

.78381 .31087 L

.78635 .31089 L

.78908 .3109 L

.79158 .31092 L

.79386 .31092 L

.79496 .31093 L

.79616 .31093 L

.7972 .31093 L

.79832 .31093 L

.79962 .31094 L

Mistroke

.80083 .31094 L

.80157 .31094 L

.80227 .31094 L

.80359 .31094 L

.80426 .31094 L

.80497 .31094 L

.80625 .31093 L

.80778 .31093 L

.80916 .31093 L

.81164 .31092 L

.81432 .31091 L

.81917 .31089 L

.82409 .31085 L

.82868 .31082 L

.83912 .31071 L

.86019 .31043 L

.89912 .30979 L

.91895 .30948 L

.9294 .30933 L

.9405 .30921 L

.94932 .30913 L

.954 .30909 L

.95904 .30906 L

.96366 .30904 L

.96568 .30903 L

.96789 .30903 L

.96999 .30902 L

.97193 .30902 L

.97301 .30902 L

.97399 .30902 L

.97512 .30902 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.02803 .36656 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4gdC00<04a<0oa<64`00oa=m4`0301<C0?lC1Q<002TC1@3o4dlC0P3o4`LC

000[4`0301<C0?lCCa<00`0C4`1^4`d0RQ<002DC0`034`0301<C00@C0P3o4dTC00<04a<0IQ<800`C

3@1n4`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`1Q4`D081<807LC000[4`0301<C00@C00<04a<0

oa=84`0301<C05hC100/4`L0L1<002XC0P064`0301<C0?lCB1<00`0C4`1L4`<0=A<706XC000b4`03

01<C0?lCB1<205/C0P0o4`H0I1<0038C00<04a<0oa=84`0301<C05PC0P164`H0Ga<0038C00<04a<0

oa=84`0301<C05HC0P1>4`D0FQ<0038C00<04a<0oa=84`0301<C05DC0P1C4`D0EQ<0038C00<04a<0

oa=84`0301<C05@C00<04a<0Ea<5058C000b4`0301<C0?lCB1<205<C0P1N4`<0D1<0038C00<04a<0

oa=84`0301<C00lC5P0/4`80HA<404dC000b4`0301<C0?lCB1<00`0C4`0:4`D05Q<9028C0P1U4`<0

Ba<0038C00<04a<0oa=84`0301<C00DC1@0S4`L06a<206PC0`194`00<Q<00`0C4`3o4c/C1@024`03

01<C00<C00<04a<00a<202lC1P0D4`80Ja<204PC000b4`0301<C0?lC?A<01`0C4a<04`0011<00`0C

4`0303HC1P0>4`80KA<304HC000b4`0301<C0?lC=a<300<C00L04a<C01<000@C0`0n4`H02A<00`0C

4`1^4`80AA<0038C00<04a<0oa<m4`0701<C4`0C00034`80AA<500@C00<04a<0L1<204@C000L4`03

01<C008C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0oa<m4`0701<C4`0C00024`0301<004XC

1@1d4`80@Q<001/C00<04`0021<01`0C4a<04`001A<00`0C4`3o4c`C0P044`0401<0008C00<04a<0

Ba<6074C0P114`005Q<3008C00<04`0021<00`0C4`034`0301<C00<C0P3o4d<C0P044`0301<C04XC

00<04a<011<406hC0P104`006a<00`0C00094`0301<C00801Q<00`0C4`3o4d4C00<04a<011<00`0C

4`194`0301<C00TC101[4`0301<C03hC000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C0?lC

@1<00`0C4`054`80BQ<00`0C4`0=4`@0J1<203hC000L4`0301<C00HC0`024`<01A<00`0C4`3o4clC

00<04a<01Q<00`0C4`184`0301<C018C101U4`0301<C03`C000b4`0301<C0?lC?Q<00`0C4`074`03

01<C04PC00<04a<05A<5068C00<04a<0>a<0038C00<04a<0oa<m4`0301<C00PC00<04a<0Aa<00`0C

4`0J4`@0Ga<203`C000b4`0301<C0?lC?1<00`0C4`094`0301<C04HC00<04a<07a<405`C0P0k4`00

<Q<00`0C4`3o4c/C00<04a<02Q<00`0C4`164`0301<C028C1@1I4`0301<C03TC000b4`0301<C0?lC

>Q<00`0C4`0;4`80Aa<00`0C4`0V4`@0Ea<00`0C4`0h4`00<Q<00`0C4`3o4cTC00<04a<031<00`0C

4`154`0301<C02XC101D4`80>A<0038C00<04a<0oa<i4`0301<C00`C00<04a<0AA<00`0C4`0^4`@0

DA<00`0C4`0g4`00<Q<00`0C4`3o4cPC00<04a<03A<00`0C4`144`0301<C03<C0P1?4`80>1<0038C

00<04a<0oa<g4`0301<C00hC00<04a<0A1<00`0C4`0e4`@0C1<203LC000b4`0301<C0?lC=Q<00`0C

4`0?4`0301<C04@C00<04a<0>A<204/C00<04a<0=A<0038C00<04a<0oa<f4`0301<C00lC0P144`03

01<C03`C10174`80=Q<0038C00<04a<0oa<e4`0301<C010C00<04a<0@a<00`0C4`0o4`<0AQ<00`0C

4`0d4`00<Q<00`0C4`3o4cDC00<04a<041<00`0C4`134`0301<C048C0`134`80=A<0024C00<04a<0

0Q<00`0C4`024`0301<C00@C00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`164`<0@A<00`0C

4`0c4`0081<00`0C00074`0301<000DC00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`194`80

?a<00`0C4`0c4`006a<3008C00<04`002A<00`0C4`034`80oa<d4`0301<C018C00<04a<0@Q<00`0C

4`1;4`<0?A<00`0C4`0b4`0081<00`0C00074`801Q<00`0C4`3o4c<C00<04a<04Q<204<C00<04a<0

CQ<203/C00<04a<0<Q<0020C00<04`001a<00`0C4`054`0301<C0?lC<Q<00`0C4`0C4`0301<C044C

00<04a<0DA<303PC00<04a<0<Q<0024C00<04a<01Q<300DC00<04a<0oa<b4`0301<C01<C00<04a<0

@A<00`0C4`1D4`80=a<00`0C4`0a4`00<Q<00`0C4`3o4c4C00<04a<051<00`0C4`114`0301<C05HC

0`0d4`0301<C034C000b4`0301<C0?lC<A<00`0C4`0>4`0301<C00<C00<04a<0@1<00`0C4`1I4`<0

<Q<2038C000b4`0301<C0?lC<1<00`0C4`0>4`0301<000@C00<04a<0@1<00`0C4`1L4`80<A<00`0C

4`0`4`00<Q<00`0C4`3o4c0C00<04a<02A<300@C00<04a<00Q<3040C00<04a<0GQ<202lC00<04a<0

<1<0038C00<04a<0oa<`4`0301<C00hC0P054`0301<C03lC00<04a<0HA<302`C00<04a<0<1<0038C

00<04a<0oa<`4`0301<C00hC00<04a<011<00`0C4`0o4`0301<C06@C00<04a<0:A<00`0C4`0`4`00

<Q<00`0C4`3o4blC00<04a<03a<300@C00<04a<0?a<00`0C4`1U4`<0:1<2034C000b4`0301<C0?lC

;a<00`0C4`0F4`0301<C03lC00<04a<0J1<00`0C4`0V4`0301<C02lC000b4`0301<C0?lC;a<00`0C

4`0F4`0301<C03lC00<04a<0JA<302DC00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC0P104`03

01<C06`C0P0S4`0301<C02lC000b4`0301<C0?lC;a<00`0C4`0F4`0301<C03lC00<04a<0KA<2028C

00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC00<04a<0?a<00`0C4`1_4`8081<00`0C4`0_4`00

<Q<00`0C4`3o4bhC00<04a<05a<00`0C4`0n4`0301<C078C0P0N4`0301<C02lC000L4`0301<C008C

00@04a<C0`034`0301<C00@C00<04a<0oa<^4`0301<C01LC00<04a<0?Q<00`0C4`1d4`8071<00`0C

4`0_4`006a<00`0C00074`0301<C008C00<04`001A<00`0C4`3o4bhC00<04a<05a<203lC00<04a<0

MQ<201XC00<04a<0;a<001HC0`024`0301<000PC00<04a<00a<00`0C4`034`80oa<_4`0301<C01LC

00<04a<0?Q<00`0C4`1h4`0301<C01HC00<04a<0<1<001/C00<04`0021<0100C4a<200HC00<04a<0

oa<]4`0301<C01PC00<04a<0?Q<00`0C4`1i4`805Q<00`0C4`0`4`006a<00`0C00074`0301<0008C

00<04a<01A<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07/C00<04a<04a<00`0C4`0`4`00

71<00`0C4`074`0401<C4`<01A<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07`C00<04a<0

4Q<00`0C4`0`4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0m4`0301<C07hC0P0B4`0301<C030C

000b4`0301<C0?lC;A<00`0C4`0H4`80?Q<00`0C4`204`8041<00`0C4`0`4`00<Q<00`0C4`3o4bdC

00<04a<061<00`0C4`0Q4`D00Q<00`0C4`0B4`0301<C00/C1@000a<0000Q4`D00Q<00`0C4`0O4`D0

0Q<00`0C4`0K4`0401<C4`D000<C00000a<00`0C4`0a4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C

4`0S4`0701<C4`0C000C4`0301<C00dC00L04a<C01<0028C00<04a<00Q<00`0C4`0Q4`0701<C4`0C

000L4`8011<00`0C4`034`0401<C03<C000b4`0301<C02HC00<04a<00Q<0100C4a<302<C00<04a<0

0Q<00`0C4`024`<08Q<00`0C4`024`0401<C4`8091<00`0C4`024`0301<C008C00<04a<09Q<5044C

00<04a<061<00`0C4`0S4`0301<C00<C00<04a<04A<00`0C4`0=4`0701<C4`0C000R4`0301<C008C

00<04a<08A<01`0C4a<04`007Q<01@0C4a<000@C0P024`0301<C034C000b4`0301<C02DC00<04`00

1a<00`0C4`0R4`0301<000TC00<04a<081<00`0C00074`0301<0028C00<04`001a<00`0C000Y4`03

01<C044C00<04a<061<00`0C4`0S4`0401<C4`8051<00`0C4`0=4`0401<C4`808a<00`0C4`034`03

01<C020C00<04a<00Q<00`0C4`0N4`8000<C01<00Q<00`0C00024`0301<C034C000b4`0301<C02DC

00<04`0021<00`0C4`0Q4`0301<000LC100Q4`0301<000LC00<04`008Q<00`0C00074`0301<002TC

00<04a<0@1<00`0C4`0I4`0301<C02<C00D04a<C000E4`0301<C00dC00D04a<C000T4`0701<C4`0C

000R4`0701<C4`0C000Q4`800a<01@0C01<003@C000b4`0301<C02DC00<04`0021<00`0C4`0Q4`03

01<000LC00<04`008Q<00`0C00074`808a<00`0C00084`0301<C02PC00<04a<0@1<00`0C4`0I4`80

8a<200<C0`0C4`0301<C00`C0P044`808A<200<C0`0Q4`8011<00`0C4`0P4`8011<200034`0C03<C

000b4`0301<C02DC00<04`001a<00`0C000R4`0301<000PC0P0R4`0301<000LC00<04a<08Q<00`0C

00074`0301<002TC00<04a<0@1<00`0C4`0I4`0301<C03dC00<04a<0R1<00`0C4`054`0301<C038C

000b4`0301<C02HC00<04a<01a<00`0C4`0R4`0301<C00PC00<04a<08A<00`0C4`074`808a<00`0C

4`074`0301<C02LC0P124`0301<C01TC00<04a<0?A<00`0C4`294`801A<00`0C4`0b4`00<Q<00`0C

4`3o4b`C00<04a<06A<00`0C4`0m4`0301<C08/C00D04a<C000e4`00<Q<83OlC9a<00`0C4`0I4`03

01<C03dC00<04a<0Ra<0100C4`0C4`@07a<0038C00<04a<01A<A3OlC5Q<00`0C4`0I4`0301<C03dC

00<04a<0S1<201@C0`0P4`00<Q<00`0C4`0F4a@=cA<302/Co`0:4`0301<C01hC000b4`0301<C02XC

30dT4c4=KA<00`0C4`0[4`0301<C008C00@04a<021<00`0C4`054`0301<C00DC00<04a<01A<00`0C

4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`034`0301<000LC

00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C

4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC

00<04a<01A<300HC00<04a<031<2020C000/4cl090da01`=>P083@H02A<00`0C4`0`4`0301<C01TC

00<04a<09Q<00`0C4`0D4`0301<C010C00<04a<09Q<00`0C4`0V4`0301<C02HC00@04a<0=Q<0038C

00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0C4`084`0301<C00TC00<04a<02A<00`0C

4`094`0301<C00PC00<04a<02A<00`0C4`094`0301<C00TC00<04a<02A<00`0C4`084`0301<C00<C

>Pd74`0301<C00`C100`4`0301<C01TC00<04a<0?A<00`0C4`2;4`0501<C4`00=A<0038C00<04a<0

;1<00`0C4`0/4`0301<C02`C00<04a<0;1<00`0C4`0/4`0301<C040C00<04a<06A<00`0C4`0m4`03

01<C08XC00<04a<00Q<00`0C4`0c4`00<Q<00`0C4`3o4b`C00<04a<06A<00`0C4`0m4`0301<C08TC

00<04a<011<00`0C4`0b4`00<Q<00`0C4`3o4b`C00<04a<06A<203hC00<04a<0Qa<200LC00<04a<0

<Q<0038C00<04a<0oa</4`0301<C01TC00<04a<0?A<00`0C4`274`0301<C00HC00<04a<0<Q<0038C

00<04a<0oa<]4`0301<C01PC00<04a<0?A<00`0C4`264`0301<C00PC00<04a<0<A<0038C00<04a<0

oa<]4`0301<C01PC00<04a<0?A<00`0C4`244`802a<00`0C4`0a4`00<Q<00`0C4`3o4bdC00<04a<0

61<00`0C4`0m4`0301<C08<C00<04a<02a<00`0C4`0a4`00<Q<00`0C4`3o4b`C00<=01<06A<00`0C

4`0m4`0301<C088C00<04a<031<00`0C4`0a4`00<Q<00`0C4`3o4bTC1PdI4`80?Q<00`0C4`204`80

3a<00`0C4`0a4`00<Q<00`0C4`3o4bPC2@dG4`0301<C03dC00<04a<0Oa<00`0C4`0@4`0301<C030C

000b4`0301<C0?lC:1<93ALC00<04a<0?Q<00`0C4`1l4`804a<00`0C4`0`4`00<Q<00`0C4`3o4bPC

2@dG4`0301<C03hC00<04a<0Na<201@C00<04a<0<1<0038C00<04a<0oa<W4`/=5Q<00`0C4`0n4`03

01<C07TC0P0F4`0301<C030C000b4`0301<C0?lC:1<93ALC00<04a<0?Q<00`0C4`1h4`0301<C01HC

00<04a<0<1<0038C00<04a<0oa<X4`T=5a<203lC00<04a<0MQ<201TC00<04a<0<1<0038C00<04a<0

oa<X4`T=5a<00`0C4`0n4`0301<C07@C0P0L4`0301<C02lC000L4`0301<C008C00@04a<C0`034`03

01<C00@C00<04a<0oa<Y4`H=6A<00`0C4`0n4`0301<C07<C00<04a<071<00`0C4`0_4`006a<00`0C

00074`0301<C008C00<04`001A<00`0C4`3o4b`C00<=4`006A<00`0C4`0o4`0301<C070C0P0O4`03

01<C02lC000K4`0301<000PC00<04a<00a<00`0C4`034`80oa<`4`0301<C01HC00<04a<0?a<00`0C

4`1]4`<08A<00`0C4`0_4`006a<00`0C00084`0401<C4`801Q<00`0C4`3o4blC00<04a<05Q<00`0C

4`0o4`0301<C06`C0P0S4`0301<C02lC000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C0?lC

;a<00`0C4`0F4`80@1<00`0C4`1Z4`809A<00`0C4`0_4`0071<00`0C4`074`0401<C4`<01A<00`0C

4`3o4blC00<04a<05Q<00`0C4`0o4`0301<C06PC0P0W4`0301<C02lC000b4`0301<C0?lC;a<00`0C

4`0F4`0301<C03lC00<04a<0IQ<202TC00<04a<0;a<0038C00<04a<0oa<`4`0301<C01DC00<04a<0

?a<00`0C4`1T4`80:Q<00`0C4`0`4`00<Q<00`0C4`3o4c0C00<04a<03a<00`0C4`034`0301<C03lC

00<04a<0HQ<202`C00<04a<0<1<0038C00<04a<0oa<`4`0301<C00hC00<04`0011<00`0C4`104`03

01<C05hC0`0^4`0301<C030C000b4`0301<C0?lC<1<00`0C4`0@4`0301<C008C0`104`0301<C05`C

0`0`4`0301<C030C000b4`0301<C0?lC<A<00`0C4`0=4`801A<00`0C4`104`0301<C05XC0P0b4`80

<Q<0038C00<04a<0oa<a4`0301<C00dC00<04a<011<00`0C4`114`0301<C05LC0P0d4`0301<C034C

000b4`0301<C0?lC<Q<00`0C4`0<4`<011<00`0C4`114`0301<C05@C0`0f4`0301<C034C000b4`03

01<C0?lC<Q<00`0C4`0C4`0301<C044C00<04a<0DQ<303LC0P0c4`00<Q<00`0C4`3o4c<C00<04a<0

4Q<2048C00<04a<0Ca<303XC00<04a<0<Q<0038C00<04a<0oa<c4`0301<C018C00<04a<0@Q<00`0C

4`1<4`<0?1<00`0C4`0b4`00<Q<00`0C4`3o4c@C00<04a<04A<00`0C4`124`0301<C04TC0`0n4`03

01<C03<C000b4`0301<C0?lC=1<00`0C4`0A4`0301<C048C00<04a<0Aa<3040C00<04a<0<a<0024C

00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0oa<e4`0301<C010C00<04a<0@Q<00`0C4`144`<0

@Q<203DC000P4`0301<000LC00<04`001A<00`0C4`3o4cDC00<04a<041<00`0C4`134`0301<C040C

0`154`0301<C03@C000P4`0301<000TC00<04a<00a<20?lC=a<00`0C4`0?4`80A1<00`0C4`0m4`<0

Aa<203HC000P4`0301<000LC0P064`0301<C0?lC=Q<00`0C4`0?4`0301<C04@C00<04a<0>A<304XC

00<04a<0=A<0020C00<04`001a<00`0C4`054`0301<C0?lC=a<00`0C4`0>4`0301<C04@C00<04a<0

=Q<404/C0P0g4`008A<00`0C4`064`<01A<00`0C4`3o4cPC00<04a<03A<00`0C4`144`0301<C03<C

0`1?4`0301<C03HC000b4`0301<C0?lC>A<00`0C4`0<4`0301<C04DC00<04a<0;a<3054C00<04a<0

=a<0038C00<04a<0oa<i4`0301<C00`C00<04a<0AA<00`0C4`0[4`@0Da<203TC000b4`0301<C0?lC

>Q<00`0C4`0;4`80Aa<00`0C4`0W4`@0EQ<00`0C4`0h4`00<Q<00`0C4`3o4cXC00<04a<02a<00`0C

4`164`0301<C02<C1@1H4`80>Q<0038C00<04a<0oa<k4`802a<00`0C4`164`0301<C020C101K4`80

>a<0038C00<04a<0oa<m4`0301<C00PC00<04a<0Aa<00`0C4`0K4`@0Ga<00`0C4`0j4`00<Q<00`0C

4`3o4chC00<04a<01a<00`0C4`174`8061<5064C00<04a<0>a<0038C00<04a<0oa<n4`0301<C00LC

00<04a<0B1<00`0C4`0C4`@0I1<203dC000b4`0301<C0?lC?a<00`0C4`064`80BQ<00`0C4`0>4`@0

Ia<203hC000b4`0301<C0?lC@1<200HC00<04a<0BA<00`0C4`0:4`@0JQ<203lC000b4`0301<C0?lC

@Q<00`0C4`034`0301<C04XC00<04a<01A<506`C0P104`00<Q<00`0C4`3o4d<C0P034`0301<C04XC

0P000a<00003070C0P114`00<Q<00`0C4`3o4c/C1@024`0401<C008C00<04a<0BA<507<C0P124`00

71<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`044`0301<C0?lC?A<01`0C4a<04`000Q<304LC

1@024`0301<C074C0P134`006a<00`0C00084`0701<C4`0C00054`0301<C0?lC?A<01`0C4a<04`00

11<3040C1@084`0301<C06hC0P154`006a<00`0C00084`0301<C00<C00<04a<00a<20?lC?Q<01`0C

4a<04`0011<0100C000j4`D03A<00`0C4`1]4`80AQ<001/C00<04`002A<00`0C4`0200HC00<04a<0

oa<m4`0701<C4`0C00044`0401<C4`<0<A<601<C0P1[4`<0Aa<001/C00<04`001a<00`0C00024`03

01<C00DC00<04a<0oa<l4`8011<00`0C4`034`0301<C00@C0`0X4`L06A<206TC0P194`0071<00`0C

4`064`<00Q<300DC00<04a<0oa=84`0301<C00LC1@0K4`T081<00`0C4`1T4`<0Ba<0038C00<04a<0

oa=84`0301<C00`C700Y4`80HQ<304dC000b4`0301<C0?lCB1<205<C0P1O4`<0Ca<0038C00<04a<0

oa=84`0301<C05<C0P1J4`@0DQ<0038C00<04a<0oa=84`0301<C05@C0P1F4`@0EA<0038C00<04a<0

oa=84`0301<C05HC0P1?4`D0FA<0038C00<04a<0oa=84`0301<C05LC0`184`H0GA<0038C00<04a<0

oa=84`0301<C05TC0`104`L0HQ<0038C00<04a<0oa=84`80G1<303PC1`1X4`00<Q<00`0C4`3o4dPC

00<04a<0GQ<302hC201^4`00<Q<00`0C4`3o4dPC00<04a<0H1<502<C201e4`00<Q<00`0C4`3o4dPC

00<04a<0I1<701@C2P1l4`00<Q<00`0C4`3o4dPC00<04a<0JQ<E08HC000b4`0301<C0?lCB1<00`0C

4`3o4`HC000Y4`D011<00`0C4`3o4dPC0P3o4`LC000[4`0301<C00@C00<04a<0oa=84`0301<C0?lC

1Q<002/C00<04a<011<20?lCBA<00`0C4`3o4`HC000[4`0301<C0?lCoa=H4`00:a<00`0C4`3o4olC

F1<002XC0P3o4olCFQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC001a4`@0

00<C00001`000a<000044`0401<C4`8011<3008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<0

0Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`03

01<C008C00<04a<00Q<00`0C4`3o4j`C001a4`<021<00`0C4`034`0301<C00LC00<04a<00Q<01P0C

4`0C008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<000<C00<04a<0XA<20?lC2A<007<C

00<04a<010024`0301<C008C00<04a<01a<0100C4a<400044`0C008C00<04`000Q<00`0C00024`03

01<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0Q<00`0C00024`0301<000<C00<04a<0XQ<00`0C4`3o4`LC000I4`@000<C00001P024`X00Q<2008C

0`024`<00a<200064`0001<09a<200PC00<04a<00a<00`0C4`074`0601<C01<00Q<00`0C00024`03

01<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0Q<00`0C00024`0301<0008C00<04`000Q<00`0C00044`0301<C09lC0`024`0301<C0?lC11<001XC

00H04a<04`024`0301<000@C00H04a<04`024`0301<000DC00<04a<00Q<01@0C4a<0008C00@04`0C

0P0a4`0701<C4`0C00074`0301<000<C0P024`0301<0008C00<04`000Q<00`0C00024`0301<0008C

00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C

00024`0301<0008C00<04`0011<00`0C4`2I4`0801<C01<04`3o4`DC000J4`0601<C01<011<00`0C

4`024`0301<C008C00<04a<00Q<00`0C4`034`0301<C008C00D04a<C00024`0401<04`80<1<200@C

00<04a<01a<00`0C4`034`0501<C4`0011<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`03

01<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00@04a<C

0`034`0301<C09XC00P04a<04`0C0?lC1A<001XC00D04a<04`0200<C0P034`0301<C008C0P034`03

01<C00<C00<04a<00Q<01@0C4a<0008C00H04`004`3o4blC0`0011<04`3o4`DC000J4`0601<C01<0

0Q<00`0C00024`0301<000@C00h04a<04`0C01<04`0C008C00D04a<C00024`0601<001<0oa<c4`03

01<00?lC1A<001TC10000a<0000;008C1@001A<0000C00D000@C00000a<200044`004`80oa<d4`03

01<C0?lC11<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4olCQQ<00001\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.77084, -14.119, 0.0242408, 0.16996}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -57 0 ]

[.5 .63053 57 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -118 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(14.7699999999999898`) show

173.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .1809 m

.02499 .1809 L

.02606 .18091 L

.02729 .18092 L

.02846 .18094 L

.03053 .18098 L

.03279 .18105 L

.03527 .18114 L

.0379 .18127 L

.04262 .18155 L

.04749 .18194 L

.05205 .18238 L

.06245 .18366 L

.07305 .18536 L

.08274 .18726 L

.10458 .19271 L

.14429 .2063 L

.18248 .22277 L

.22313 .24204 L

.26226 .2599 L

.28223 .26797 L

.30384 .27544 L

.32471 .28116 L

.33464 .28331 L

.34391 .28498 L

.35299 .28628 L

.36273 .28732 L

.36828 .28776 L

.37101 .28793 L

.37354 .28806 L

.37578 .28816 L

.37826 .28824 L

.38075 .28831 L

.38211 .28834 L

.38339 .28835 L

.38457 .28837 L

.38583 .28838 L

.38701 .28838 L

.38809 .28838 L

.38936 .28837 L

.39007 .28836 L

.39073 .28836 L

.39194 .28834 L

.39322 .28832 L

.39577 .28826 L

.39815 .28818 L

.40358 .28795 L

.40824 .28768 L

.4125 .28738 L

.42208 .28655 L

Mistroke

.4411 .28435 L

.46184 .28143 L

.4832 .27831 L

.50254 .27574 L

.51224 .27466 L

.52273 .27369 L

.52754 .27333 L

.53263 .27301 L

.5373 .27277 L

.54172 .2726 L

.5441 .27253 L

.54536 .2725 L

.54669 .27247 L

.54781 .27245 L

.54905 .27244 L

.55017 .27242 L

.55122 .27242 L

.55247 .27241 L

.55378 .27241 L

.5549 .27242 L

.55612 .27243 L

.55682 .27243 L

.55745 .27244 L

.55886 .27246 L

.5614 .27252 L

.56376 .27259 L

.56593 .27266 L

.57084 .27289 L

.57517 .27316 L

.57974 .2735 L

.58921 .27441 L

.59936 .27568 L

.61768 .27873 L

.65901 .28833 L

.69883 .29926 L

.73712 .30888 L

.75687 .31282 L

.76697 .31447 L

.77787 .31596 L

.78801 .31705 L

.79246 .31744 L

.79732 .3178 L

.80162 .31807 L

.80622 .3183 L

.80876 .31841 L

.81107 .31849 L

.81341 .31855 L

.81559 .3186 L

.81789 .31864 L

.81912 .31866 L

Mistroke

.82043 .31867 L

.82109 .31867 L

.8218 .31868 L

.82311 .31868 L

.82438 .31868 L

.82556 .31868 L

.82676 .31867 L

.82789 .31866 L

.82891 .31865 L

.83001 .31863 L

.83248 .31859 L

.83475 .31854 L

.83957 .31839 L

.84486 .31818 L

.85554 .31759 L

.87507 .31609 L

.89599 .31413 L

.91581 .31223 L

.92627 .31132 L

.93737 .31047 L

.94696 .30987 L

.95205 .30961 L

.95754 .30937 L

.96256 .30921 L

.96476 .30915 L

.96716 .3091 L

.96944 .30907 L

.97156 .30904 L

.97273 .30903 L

.9738 .30902 L

.97503 .30902 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.26004 .56134 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4gdC00<04a<0oa<64`00oa=m4`0301<C0?lC1Q<002TC1@3o4dlC0P3o4`LC

000[4`0301<C0?lCCa<00`0C4`1^4`d0RQ<002DC0`034`0301<C00@C0P3o4dTC00<04a<0IQ<800`C

3@1n4`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`1Q4`D081<807LC000[4`0301<C00@C00<04a<0

oa=84`0301<C05hC100/4`L0L1<002XC0P064`0301<C0?lCB1<00`0C4`1L4`<0=A<706XC000b4`03

01<C0?lCB1<205/C0P0o4`H0I1<0038C00<04a<0oa=84`0301<C05PC0P164`H0Ga<0038C00<04a<0

oa=84`0301<C05HC0P1>4`D0FQ<0038C00<04a<0oa=84`0301<C05DC0P1C4`D0EQ<0038C00<04a<0

oa=84`0301<C05@C00<04a<0Ea<5058C000b4`0301<C0?lCB1<205<C0P1N4`<0D1<0038C00<04a<0

oa=84`0301<C00lC5P0/4`80HA<404dC000b4`0301<C0?lCB1<00`0C4`0:4`D05Q<9028C0P1U4`<0

Ba<0038C00<04a<0oa=84`0301<C00DC1@0S4`L06a<206PC0`194`00<Q<00`0C4`3o4c/C1@024`03

01<C00<C00<04a<00a<202lC1P0D4`80Ja<204PC000b4`0301<C0?lC?A<01`0C4a<04`0011<00`0C

4`0303HC1P0>4`80KA<304HC000b4`0301<C0?lC=a<300<C00L04a<C01<000@C0`0n4`H02A<00`0C

4`1^4`80AA<0038C00<04a<0oa<m4`0701<C4`0C00034`80AA<500@C00<04a<0L1<204@C000L4`03

01<C008C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0oa<m4`0701<C4`0C00024`0301<004XC

1@1d4`80@Q<001/C00<04`0021<01`0C4a<04`001A<00`0C4`3o4c`C0P044`0401<0008C00<04a<0

Ba<6074C0P114`005Q<3008C00<04`0021<00`0C4`034`0301<C00<C0P3o4d<C0P044`0301<C04XC

00<04a<011<406hC0P104`006a<00`0C00094`0301<C00801Q<00`0C4`3o4d4C00<04a<011<00`0C

4`194`0301<C00TC101[4`0301<C03hC000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C0?lC

@1<00`0C4`054`80BQ<00`0C4`0=4`@0J1<203hC000L4`0301<C00HC0`024`<01A<00`0C4`3o4clC

00<04a<01Q<00`0C4`184`0301<C018C101U4`0301<C03`C000b4`0301<C0?lC?Q<00`0C4`074`03

01<C04PC00<04a<05A<5068C00<04a<0>a<0038C00<04a<0oa<m4`0301<C00PC00<04a<0Aa<00`0C

4`0J4`@0Ga<203`C000b4`0301<C0?lC?1<00`0C4`094`0301<C04HC00<04a<07a<405`C0P0k4`00

<Q<00`0C4`3o4c/C00<04a<02Q<00`0C4`164`0301<C028C1@1I4`0301<C03TC000b4`0301<C0?lC

>Q<00`0C4`0;4`80Aa<00`0C4`0V4`@0Ea<00`0C4`0h4`00<Q<00`0C4`3o4cTC00<04a<031<00`0C

4`154`0301<C02XC101D4`80>A<0038C00<04a<0oa<i4`0301<C00`C00<04a<0AA<00`0C4`0^4`@0

DA<00`0C4`0g4`00<Q<00`0C4`3o4cPC00<04a<03A<00`0C4`144`0301<C03<C0P1?4`80>1<0038C

00<04a<0oa<g4`0301<C00hC00<04a<0A1<00`0C4`0e4`@0C1<203LC000b4`0301<C0?lC=Q<00`0C

4`0?4`0301<C04@C00<04a<0>A<204/C00<04a<0=A<0038C00<04a<0oa<f4`0301<C00lC0P144`03

01<C03`C10174`80=Q<0038C00<04a<0oa<e4`0301<C010C00<04a<0@a<00`0C4`0o4`<0AQ<00`0C

4`0d4`00<Q<00`0C4`3o4cDC00<04a<041<00`0C4`134`0301<C048C0`134`80=A<0024C00<04a<0

0Q<00`0C4`024`0301<C00@C00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`164`<0@A<00`0C

4`0c4`0081<00`0C00074`0301<000DC00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`194`80

?a<00`0C4`0c4`006a<3008C00<04`002A<00`0C4`034`80oa<d4`0301<C018C00<04a<0@Q<00`0C

4`1;4`<0?A<00`0C4`0b4`0081<00`0C00074`801Q<00`0C4`3o4c<C00<04a<04Q<204<C00<04a<0

CQ<203/C00<04a<0<Q<0020C00<04`001a<00`0C4`054`0301<C0?lC<Q<00`0C4`0C4`0301<C044C

00<04a<0DA<303PC00<04a<0<Q<0024C00<04a<01Q<300DC00<04a<0oa<b4`0301<C01<C00<04a<0

@A<00`0C4`1D4`80=a<00`0C4`0a4`00<Q<00`0C4`3o4c4C00<04a<051<00`0C4`114`0301<C05HC

0`0d4`0301<C034C000b4`0301<C0?lC<A<00`0C4`0>4`0301<C00<C00<04a<0@1<00`0C4`1I4`<0

<Q<2038C000b4`0301<C0?lC<1<00`0C4`0>4`0301<000@C00<04a<0@1<00`0C4`1L4`80<A<00`0C

4`0`4`00<Q<;3OlC:1<00`0C4`094`<011<00`0C4`024`<0@1<00`0C4`1N4`80;a<00`0C4`0`4`00

<Q<00`0C4`084`D=oa<S4`0301<C00hC0P054`0301<C03lC00<04a<0HA<302`C00<04a<0<1<0038C

00<04a<03A<23OlC8A<00`0C4`0>4`0301<C00@C00<04a<0?a<00`0C4`1T4`0301<C02TC00<04a<0

<1<0038C00<04a<03a<33OlC7A<00`0C4`0?4`<011<00`0C4`0o4`0301<C06DC0`0X4`80<A<0038C

00<04a<04Q<33OlC6Q<00`0C4`0F4`0301<C03lC00<04a<0J1<00`0C4`0V4`0301<C02lC000b4`03

01<C01DC10go4aHC00<04a<05Q<00`0C4`0o4`0301<C06TC0`0U4`0301<C02lC000b4`0301<C01TC

0`go4a<C00<04a<05Q<2040C00<04a<0K1<202<C00<04a<0;a<0038C00<04a<071<23OlC4A<00`0C

4`0F4`0301<C03lC00<04a<0KA<2028C00<04a<0;a<0038C00<04a<07Q<33OlC3Q<00`0C4`0F4`03

01<C03lC00<04a<0Ka<2020C00<04a<0;a<0038C00<04a<08A<23OlC2a<00`0C4`0G4`0301<C03hC

00<04a<0LQ<201hC00<04a<0;a<001`C00<04a<00Q<0100C4a<300<C00<04a<011<00`0C4`0S4`8=

oa<94`0301<C01LC00<04a<0?Q<00`0C4`1d4`8071<00`0C4`0_4`006a<00`0C00074`0301<C008C

00<04`001A<00`0C4`0U4`8=oa<74`0301<C01LC0P0o4`0301<C07HC0P0J4`0301<C02lC000F4`<0

0Q<00`0C00084`0301<C00<C00<04a<00a<202PC0Pgo4`DC00<04a<05a<00`0C4`0n4`0301<C07PC

00<04a<05Q<00`0C4`0`4`006a<00`0C00084`0401<C4`801Q<00`0C4`0Y4`8=oa<24`0301<C01PC

00<04a<0?Q<00`0C4`1i4`805Q<00`0C4`0`4`006a<00`0C00074`0301<0008C00<04a<01A<00`0C

4`0[4`8=oa<00`0C4`0H4`0301<C03hC00<04a<0Na<00`0C4`0C4`0301<C030C000L4`0301<C00LC

00@04a<C0`054`0301<C02dC0`gl4`0301<C01PC00<04a<0?Q<00`0C4`1l4`0301<C018C00<04a<0

<1<0038C00<04a<0<1<23OXC00<04a<061<00`0C4`0m4`0301<C07hC0P0B4`0301<C030C000b4`03

01<C038C0Pgh4`0301<C01PC0P0n4`0301<C080C0P0@4`0301<C030C000b4`0301<C03@C0Pgf4`03

01<C01PC00<04a<08A<5008C00<04a<04Q<00`0C4`0;4`D000<C00008A<5008C00<04a<07a<5008C

00<04a<06a<0100C4a<500034`0000<C00<04a<0<A<0038C00<04a<0=Q<33O<C00<04a<061<00`0C

4`0S4`0701<C4`0C000C4`0301<C00dC00L04a<C01<0028C00<04a<00Q<00`0C4`0Q4`0701<C4`0C

000L4`8011<00`0C4`034`0401<C03<C000b4`0301<C02HC00<04a<00Q<0100C4a<300LC0PdJ4`03

01<C008C00<04a<00Q<3028C00<04a<00Q<0100C4a<202@C00<04a<00Q<00`0C4`024`0301<C02HC

1@114`0301<C01PC00<04a<08a<00`0C4`034`0301<C014C00<04a<03A<01`0C4a<04`008Q<00`0C

4`024`0301<C024C00L04a<C01<001hC00D04a<C00044`800Q<00`0C4`0a4`00<Q<00`0C4`0U4`03

01<000LC00<04a<02A<33AHC00<04`002A<00`0C4`0P4`0301<000LC00<04`008Q<00`0C00074`03

01<002TC00<04a<0@A<00`0C4`0H4`0301<C02<C00@04a<C0P0D4`0301<C00dC00@04a<C0P0S4`03

01<C00<C00<04a<081<00`0C4`024`0301<C01hC0P000a<04`024`0301<0008C00<04a<0<A<0038C

00<04a<09A<00`0C00084`0301<C00/C0`dC4`0301<000LC100K4`L=00<C01<01Q<00`0C000R4`03

01<000LC00<04`00:A<00`0C4`104`0301<C01TC00<04a<08a<01@0C4a<001DC00<04a<03A<01@0C

4a<002@C00L04a<C01<0028C00L04a<C01<0024C0P034`0501<04`00=1<0038C00<04a<09A<00`0C

00084`0301<C00hC0`d@4`0301<000LC00<04`0041<<3@HC00<03@d01`d202<C00<04`0021<00`0C

4`0X4`0301<C040C00<04a<06A<202<C0P034`<04a<00`0C4`0<4`8011<2024C0P034`<08A<200@C

00<04a<081<200@C0P000a<04`0c4`00<Q<00`0C4`0U4`0301<000LC00<04`004Q<23@hC00<04`00

21<200/C1@dB4`0301<000LC1@dP4`0301<000LC00<04`00:A<00`0C4`104`0301<C01TC00<04a<0

?A<00`0C4`284`0301<C00DC00<04a<0<Q<0038C00<04a<09Q<00`0C4`074`0301<C01<C1@d:4`03

01<C00PC00<04`d02@dH4`0301<C00LC0P024`H=6a<00`0C4`074`0301<C02LC0P124`0301<C01TC

00<04a<0?A<00`0C4`294`801A<00`0C4`0b4`00<Q<00`0C4`1;4aL==Q<43HlC00<04a<06A<00`0C

4`0m4`0301<C08/C00D04a<C000e4`00<Q<00`0C4`2L4`<=S1<00`0C4`0I4`0301<C03dC00<04a<0

Ra<0100C4`0C4`@07a<0038C00<04a<0Wa<33HTC00<04a<06A<00`0C4`0m4`0301<C08`C0P0D4`<0

81<0038C00<04a<0XQ<43E4C0`0[4ol02Q<00`0C4`0N4`00<Q<00`0C4`2V4`D=CA<00`0C4`0[4`03

01<C008C00@04a<021<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<0

1A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`034`0301<000LC00<04a<01Q<00`0C4`054`03

01<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<0

1A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<300HC00<04a<0

31<2020C000/4k@01@df00<=1P094`0301<C030C00<04a<06A<00`0C4`0V4`0301<C01@C00<04a<0

41<00`0C4`0V4`0301<C02HC00<04a<09Q<0100C4`0f4`00<Q<00`0C4`084`0301<C00TC00<04a<0

2A<00`0C4`094`0301<C00PC00<04a<02A<00`0C4`094`0301<C00TC00<04a<021<00`0C4`094`03

01<C00TC00<04a<02A<00`0C4`094`0301<C00PC00<04a<02A<00`0C4`033@HC00<04a<02A<00`0C

4`084`0301<C00@C3`d24`0301<C00`C100`4`0301<C01TC00<04a<0?A<00`0C4`2;4`0501<C4`00

=A<0038C00<04a<0;1<00`0C4`0/4`0301<C02`C00<04a<09Q<73A<C2PdA4`0301<C040C00<04a<0

6A<00`0C4`0m4`0301<C08XC00<04a<00Q<00`0C4`0c4`00<Q<00`0C4`2j4a<=GQ<00`0C4`0I4`03

01<C03dC00<04a<0RA<00`0C4`044`0301<C038C000b4`0301<C0?lC;1<00`0C4`0I4`80?Q<00`0C

4`274`801a<00`0C4`0b4`00<Q<00`0C4`3o4b`C00<04a<06A<00`0C4`0m4`0301<C08LC00<04a<0

1Q<00`0C4`0b4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0m4`0301<C08HC00<04a<021<00`0C

4`0a4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0m4`0301<C08@C0P0;4`0301<C034C000b4`03

01<C0?lC;A<00`0C4`0H4`0301<C03dC00<04a<0Pa<00`0C4`0;4`0301<C034C000b4`0301<C0?lC

;A<00`0C4`0H4`0301<C03dC00<04a<0PQ<00`0C4`0<4`0301<C034C000b4`0301<C0?lC;A<00`0C

4`0H4`80?Q<00`0C4`204`803a<00`0C4`0a4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0m4`03

01<C07lC00<04a<041<00`0C4`0`4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07`C

0P0C4`0301<C030C000b4`0301<C0?lC;A<00`0C4`0H4`0301<C03hC00<04a<0Na<201@C00<04a<0

<1<0038C00<04a<0oa<]4`0301<C01PC00<04a<0?Q<00`0C4`1i4`805Q<00`0C4`0`4`00<Q<00`0C

4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07PC00<04a<05Q<00`0C4`0`4`00<Q<00`0C4`3o4bhC

00<04a<05a<203lC00<04a<0MQ<201TC00<04a<0<1<0038C00<04a<0oa<^4`0301<C01LC00<04a<0

?Q<00`0C4`1d4`8071<00`0C4`0_4`0071<00`0C4`024`0401<C4`<00a<00`0C4`044`0301<C0?lC

;Q<00`0C4`0G4`0301<C03hC00<04a<0La<00`0C4`0L4`0301<C02lC000K4`0301<000LC00<04a<0

0Q<00`0C00054`0301<C0?lC;Q<00`0C4`0G4`0301<C03lC00<04a<0L1<201lC00<04a<0;a<001/C

00<04`0021<00`0C4`034`0301<C00<C0P3o4c0C00<04a<05Q<00`0C4`0o4`0301<C06dC0`0Q4`03

01<C02lC000K4`0301<000PC00@04a<C0P064`0301<C0?lC;a<00`0C4`0F4`0301<C03lC00<04a<0

K1<202<C00<04a<0;a<001/C00<04`001a<00`0C00024`0301<C00DC00<04a<0oa<_4`0301<C01HC

0P104`0301<C06XC0P0U4`0301<C02lC000L4`0301<C00LC00@04a<C0`054`0301<C0?lC;a<00`0C

4`0F4`0301<C03lC00<04a<0J1<202LC00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC00<04a<0

?a<00`0C4`1V4`80:A<00`0C4`0_4`00<Q<00`0C4`3o4c0C00<04a<05A<00`0C4`0o4`0301<C06@C

0P0Z4`0301<C030C000b4`0301<C0?lC<1<00`0C4`0?4`0301<C00<C00<04a<0?a<00`0C4`1R4`80

;1<00`0C4`0`4`00<Q<00`0C4`3o4c0C00<04a<03Q<00`0C00044`0301<C040C00<04a<0GQ<302hC

00<04a<0<1<0038C00<04a<0oa<`4`0301<C010C00<04a<00Q<3040C00<04a<0G1<3030C00<04a<0

<1<0038C00<04a<0oa<a4`0301<C00dC0P054`0301<C040C00<04a<0FQ<2038C0P0b4`00<Q<00`0C

4`3o4c4C00<04a<03A<00`0C4`044`0301<C044C00<04a<0Ea<203@C00<04a<0<A<0038C00<04a<0

oa<b4`0301<C00`C0`044`0301<C044C00<04a<0E1<303HC00<04a<0<A<0038C00<04a<0oa<b4`03

01<C01<C00<04a<0@A<00`0C4`1B4`<0=a<203<C000b4`0301<C0?lC<a<00`0C4`0B4`80@Q<00`0C

4`1?4`<0>Q<00`0C4`0b4`00<Q<00`0C4`3o4c<C00<04a<04Q<00`0C4`124`0301<C04`C0`0l4`03

01<C038C000b4`0301<C0?lC=1<00`0C4`0A4`0301<C048C00<04a<0BA<303hC00<04a<0<a<0038C

00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`174`<0@1<00`0C4`0c4`008A<00`0C4`024`03

01<C008C00<04a<011<00`0C4`3o4cDC00<04a<041<00`0C4`124`0301<C04@C0`124`80=A<0020C

00<04`001a<00`0C00054`0301<C0?lC=A<00`0C4`0@4`0301<C04<C00<04a<0@1<304DC00<04a<0

=1<0020C00<04`002A<00`0C4`034`80oa<g4`0301<C00lC0P144`0301<C03dC0`174`80=Q<0020C

00<04`001a<200HC00<04a<0oa<f4`0301<C00lC00<04a<0A1<00`0C4`0i4`<0BQ<00`0C4`0e4`00

81<00`0C00074`0301<C00DC00<04a<0oa<g4`0301<C00hC00<04a<0A1<00`0C4`0f4`@0Ba<203LC

000Q4`0301<C00HC0`054`0301<C0?lC>1<00`0C4`0=4`0301<C04@C00<04a<0<a<304lC00<04a<0

=Q<0038C00<04a<0oa<i4`0301<C00`C00<04a<0AA<00`0C4`0_4`<0DA<00`0C4`0g4`00<Q<00`0C

4`3o4cTC00<04a<031<00`0C4`154`0301<C02/C101C4`80>A<0038C00<04a<0oa<j4`0301<C00/C

0P174`0301<C02LC101F4`0301<C03PC000b4`0301<C0?lC>Q<00`0C4`0;4`0301<C04HC00<04a<0

8a<505PC0P0j4`00<Q<00`0C4`3o4c/C0P0;4`0301<C04HC00<04a<081<405/C0P0k4`00<Q<00`0C

4`3o4cdC00<04a<021<00`0C4`174`0301<C01/C101O4`0301<C03XC000b4`0301<C0?lC?Q<00`0C

4`074`0301<C04LC0P0H4`D0HA<00`0C4`0k4`00<Q<00`0C4`3o4chC00<04a<01a<00`0C4`184`03

01<C01<C101T4`80?A<0038C00<04a<0oa<o4`0301<C00HC0P1:4`0301<C00hC101W4`80?Q<0038C

00<04a<0oa=04`801Q<00`0C4`194`0301<C00XC101Z4`80?a<0038C00<04a<0oa=24`0301<C00<C

00<04a<0BQ<00`0C4`054`D0K1<2040C000b4`0301<C0?lC@a<200<C00<04a<0BQ<200034`0000<0

L1<2044C000b4`0301<C0?lC>a<5008C00@04a<00Q<00`0C4`194`D0La<2048C000L4`0301<C008C

00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0oa<m4`0701<C4`0C00024`<0Aa<5008C00<04a<0

LA<204<C000K4`0301<000PC00L04a<C01<000DC00<04a<0oa<m4`0701<C4`0C00044`<0@1<500PC

00<04a<0KQ<204DC000K4`0301<000PC00<04a<00a<00`0C4`034`80oa<n4`0701<C4`0C00044`04

01<001/C00<=4a<071<500dC00<04a<0KA<204HC000K4`0301<000TC00<04a<00P064`0301<C0?lC

?A<01`0C4a<04`0011<0100C4a<301DC1PdF4`H04a<206/C0`174`006a<00`0C00074`0301<0008C

00<04a<01A<00`0C4`3o4c`C0P044`0301<C00<C00<04a<011<3014C2@d>4`L06A<206TC0P194`00

71<00`0C4`064`<00Q<300DC00<04a<0oa=84`0301<C00LC1@0<4`T=1Q<9020C00<04a<0I1<304/C

000b4`0301<C0?lCB1<00`0C4`0<4``02@d702TC0P1R4`<0CA<0038C00<04a<0oa=84`8061<;3C0C

0P1O4`<0Ca<0038C00<04a<0oa=84`0301<C01PC2@db4`80FQ<4058C000b4`0301<C0?lCB1<00`0C

4`0H4`T=<a<205HC101E4`00<Q<00`0C4`3o4dPC00<04a<061<93CDC0P1?4`D0FA<0038C00<04a<0

oa=84`0301<C01TC1Pdh4`<0B1<605dC000b4`0301<C0?lCB1<00`0C4`0L4`033A<C03XC0`104`L0

HQ<0038C00<04a<0oa=84`80G1<303PC1`1X4`00<Q<00`0C4`3o4dPC00<04a<0GQ<302hC201^4`00

<Q<00`0C4`3o4dPC00<04a<0H1<502<C201e4`00<Q<00`0C4`3o4dPC00<04a<0I1<701@C2P1l4`00

<Q<00`0C4`3o4dPC00<04a<0JQ<E08HC000b4`0301<C0?lCB1<00`0C4`3o4`HC000Y4`D011<00`0C

4`3o4dPC0P3o4`LC000[4`0301<C00@C00<04a<0oa=84`0301<C0?lC1Q<002/C00<04a<011<20?lC

BA<00`0C4`3o4`HC000[4`0301<C0?lCoa=H4`00:a<00`0C4`3o4olCF1<002XC0P3o4olCFQ<00?lC

oa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC001a4`@000<C00001`024`<00Q<00`0C

4`024`0401<C4`800a<200<C0P034`800a<200<C0P034`800a<200<C0P034`800a<200<C0P044`04

01<C4`8011<00`0C4`3o4j`C001a4`<021<00`0C4`034`0301<C00HC00L04a<C01<000@C00<04a<0

0Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`03

01<C008C00<04a<00Q<01P0C4`0C00@C00H04a<04`2R4`80oa<94`00La<00`0C4`04008C00@04a<C

10074`0701<C4`0C00034`800a<200<C0P034`800a<200<C0P034`800a<200<C0P034`800a<2008C

00<04`000a<2008C00<04`00Xa<00`0C4`3o4`LC000I4`@000<C00001P024`X00Q<2008C0`024`<0

0a<200064`0001<09a<200PC00L04a<C01<000TC00<04a<00P034`0301<0008C00<04`000Q<00`0C

00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C

00<04`000a<01`0C4a<04`000a<00`0C4`2P4`<00Q<00`0C4`3o4`@C000J4`0601<C01<00Q<00`0C

00044`0601<C01<00Q<00`0C00054`0301<C008C00D04a<C00024`0401<04`80<A<00`0C4`024`80

1a<00`0C00024`0301<C008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`03

01<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0Q<00`0C00044`0301<C09TC00P04a<04`0C0?lC1A<001XC00H04a<04`044`0301<C008C00<04a<0

0Q<00`0C4`024`0301<C00<C00<04a<00Q<01@0C4a<0008C00@04`0C0P0`4`801A<00`0C4`054`<0

0a<200<C0P034`800a<200<C0P034`800a<200<C0P034`800a<200<C0P034`800a<00`0C4`024`80

0a<00`0C4`024`0301<C09XC00P04a<04`0C0?lC1A<001XC00D04a<04`0200<C0P034`0301<C008C

0P034`0301<C00<C00<04a<00Q<01@0C4a<0008C00H04`004`3o4blC0`0011<04`3o4`DC000J4`06

01<C01<00Q<00`0C00024`0301<000@C00h04a<04`0C01<04`0C008C00D04a<C00024`0601<001<0

oa<c4`0301<00?lC1A<001TC10000a<0000;008C1@001A<0000C00D000@C00000a<200044`004`80

oa<d4`0301<C0?lC11<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olC

QQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00001\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.77084, -14.119, 0.0242408, 0.16996}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -57 0 ]

[.5 .63053 57 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -118 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(15.3299999999999903`) show

173.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .15752 m

.02499 .15753 L

.02606 .15753 L

.02729 .15755 L

.02846 .15756 L

.03053 .1576 L

.03279 .15767 L

.03527 .15776 L

.0379 .15788 L

.04262 .15815 L

.04749 .15852 L

.05205 .15894 L

.06245 .16018 L

.07305 .16182 L

.08274 .16367 L

.10458 .16899 L

.14429 .18254 L

.18248 .19957 L

.22313 .2205 L

.26226 .24127 L

.30384 .26114 L

.32471 .26934 L

.34391 .27546 L

.36265 .27998 L

.37209 .28169 L

.37741 .28248 L

.38246 .28311 L

.38734 .28363 L

.39266 .28407 L

.395 .28423 L

.39749 .28437 L

.39983 .28449 L

.40197 .28457 L

.40443 .28464 L

.40573 .28467 L

.40709 .2847 L

.40828 .28472 L

.40939 .28473 L

.41061 .28473 L

.41191 .28473 L

.41265 .28473 L

.41333 .28472 L

.41407 .28472 L

.41486 .28471 L

.41619 .28469 L

.41766 .28466 L

.42036 .28458 L

.42288 .28449 L

.42786 .28425 L

.43329 .28391 L

Mistroke

.44317 .28307 L

.4617 .28091 L

.5024 .27494 L

.52124 .27241 L

.53114 .2713 L

.54158 .27037 L

.54692 .27 L

.54974 .26983 L

.55276 .26968 L

.55555 .26956 L

.55808 .26948 L

.5593 .26944 L

.56063 .26941 L

.56179 .26939 L

.56304 .26937 L

.56429 .26935 L

.56546 .26934 L

.56614 .26934 L

.56685 .26934 L

.56813 .26934 L

.56877 .26934 L

.56946 .26934 L

.57071 .26935 L

.57147 .26936 L

.57218 .26937 L

.57353 .26939 L

.57595 .26945 L

.57818 .26952 L

.58322 .26975 L

.58791 .27003 L

.59294 .27042 L

.60202 .27135 L

.61282 .27281 L

.62267 .27447 L

.66249 .28388 L

.70078 .29528 L

.74153 .30696 L

.76176 .31166 L

.77167 .31357 L

.78077 .31508 L

.78943 .31629 L

.79891 .31734 L

.80844 .31812 L

.81364 .31842 L

.81849 .31863 L

.82111 .31872 L

.82353 .31878 L

.8249 .31881 L

.82618 .31883 L

.82752 .31884 L

Mistroke

.82823 .31885 L

.82899 .31885 L

.83026 .31886 L

.83098 .31886 L

.83165 .31886 L

.83287 .31886 L

.83418 .31885 L

.83546 .31884 L

.83666 .31882 L

.83892 .31878 L

.84118 .31873 L

.84357 .31867 L

.84785 .31851 L

.8575 .31802 L

.86699 .31736 L

.87715 .3165 L

.89549 .3147 L

.91532 .31265 L

.92577 .31164 L

.93687 .31069 L

.94658 .31 L

.95174 .3097 L

.9573 .30943 L

.96239 .30924 L

.96461 .30918 L

.96705 .30912 L

.96935 .30907 L

.9715 .30904 L

.97269 .30903 L

.97377 .30902 L

.97501 .30902 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.3509 .55103 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4gdC00<04a<0oa<64`00oa=m4`0301<C0?lC1Q<002TC1@3o4dlC0P3o4`LC

000[4`0301<C0?lCCa<00`0C4`1^4`d0RQ<002DC0`034`0301<C00@C0P3o4dTC00<04a<0IQ<800`C

3@1n4`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`1Q4`D081<807LC000[4`0301<C00@C00<04a<0

oa=84`0301<C05hC100/4`L0L1<002XC0P064`0301<C0?lCB1<00`0C4`1L4`<0=A<706XC000b4`03

01<C0?lCB1<205/C0P0o4`H0I1<0038C00<04a<0oa=84`0301<C05PC0P164`H0Ga<0038C00<04a<0

oa=84`0301<C05HC0P1>4`D0FQ<0038C00<04a<0oa=84`0301<C05DC0P1C4`D0EQ<0038C00<04a<0

oa=84`0301<C05@C00<04a<0Ea<5058C000b4`0301<C0?lCB1<205<C0P1N4`<0D1<0038C00<04a<0

oa=84`0301<C00lC5P0/4`80HA<404dC000b4`0301<C0?lCB1<00`0C4`0:4`D05Q<9028C0P1U4`<0

Ba<0038C00<04a<0oa=84`0301<C00DC1@0S4`L06a<206PC0`194`00<Q<00`0C4`3o4c/C1@024`03

01<C00<C00<04a<00a<202lC1P0D4`80Ja<204PC000b4`0301<C0?lC?A<01`0C4a<04`0011<00`0C

4`0303HC1P0>4`80KA<304HC000b4`0301<C0?lC=a<300<C00L04a<C01<000@C0`0n4`H02A<00`0C

4`1^4`80AA<0038C00<04a<0oa<m4`0701<C4`0C00034`80AA<500@C00<04a<0L1<204@C000L4`03

01<C008C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0oa<m4`0701<C4`0C00024`0301<004XC

1@1d4`80@Q<001/C00<04`0021<01`0C4a<04`001A<00`0C4`3o4c`C0P044`0401<0008C00<04a<0

Ba<6074C0P114`005Q<3008C00<04`0021<00`0C4`034`0301<C00<C0P3o4d<C0P044`0301<C04XC

00<04a<011<406hC0P104`006a<00`0C00094`0301<C00801Q<00`0C4`3o4d4C00<04a<011<00`0C

4`194`0301<C00TC101[4`0301<C03hC000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C0?lC

@1<00`0C4`054`80BQ<00`0C4`0=4`@0J1<203hC000L4`0301<C00HC0`024`<01A<00`0C4`3o4clC

00<04a<01Q<00`0C4`184`0301<C018C101U4`0301<C03`C000b4`0301<C0?lC?Q<00`0C4`074`03

01<C04PC00<04a<05A<5068C00<04a<0>a<0038C00<04a<0oa<m4`0301<C00PC00<04a<0Aa<00`0C

4`0J4`@0Ga<203`C000b4`0301<C0?lC?1<00`0C4`094`0301<C04HC00<04a<07a<405`C0P0k4`00

<Q<00`0C4`3o4c/C00<04a<02Q<00`0C4`164`0301<C028C1@1I4`0301<C03TC000b4`0301<C0?lC

>Q<00`0C4`0;4`80Aa<00`0C4`0V4`@0Ea<00`0C4`0h4`00<Q<00`0C4`3o4cTC00<04a<031<00`0C

4`154`0301<C02XC101D4`80>A<0038C00<04a<0oa<i4`0301<C00`C00<04a<0AA<00`0C4`0^4`@0

DA<00`0C4`0g4`00<Q<00`0C4`3o4cPC00<04a<03A<00`0C4`144`0301<C03<C0P1?4`80>1<0038C

00<04a<0oa<g4`0301<C00hC00<04a<0A1<00`0C4`0e4`@0C1<203LC000b4`0301<C0?lC=Q<00`0C

4`0?4`0301<C04@C00<04a<0>A<204/C00<04a<0=A<0038C00<04a<0oa<f4`0301<C00lC0P144`03

01<C03`C10174`80=Q<0038C00<04a<0oa<e4`0301<C010C00<04a<0@a<00`0C4`0o4`<0AQ<00`0C

4`0d4`00<Q<00`0C4`3o4cDC00<04a<041<00`0C4`134`0301<C048C0`134`80=A<0024C00<04a<0

0Q<00`0C4`024`0301<C00@C00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`164`<0@A<00`0C

4`0c4`0081<00`0C00074`0301<000DC00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`194`80

?a<00`0C4`0c4`006a<3008C00<04`002A<00`0C4`034`80oa<d4`0301<C018C00<04a<0@Q<00`0C

4`1;4`<0?A<00`0C4`0b4`0081<00`0C00074`801Q<83OlC;Q<00`0C4`0B4`80@a<00`0C4`1>4`80

>a<00`0C4`0b4`0081<00`0C00074`0301<C00DC00<04a<01A<53OlC:1<00`0C4`0C4`0301<C044C

00<04a<0DA<303PC00<04a<0<Q<0024C00<04a<01Q<300DC00<04a<02Q<43OlC91<00`0C4`0C4`03

01<C044C00<04a<0E1<203LC00<04a<0<A<0038C00<04a<03Q<43OlC7a<00`0C4`0D4`0301<C044C

00<04a<0EQ<303@C00<04a<0<A<0038C00<04a<04Q<33OlC71<00`0C4`0>4`0301<C00<C00<04a<0

@1<00`0C4`1I4`<0<Q<2038C000b4`0301<C01DC10go4aLC00<04a<03Q<00`0C00044`0301<C040C

00<04a<0G1<2034C00<04a<0<1<0038C00<04a<06A<33OlC51<00`0C4`094`<011<00`0C4`024`<0

@1<00`0C4`1N4`80;a<00`0C4`0`4`00<Q<00`0C4`0L4`8=oa<B4`0301<C00hC0P054`0301<C03lC

00<04a<0HA<302`C00<04a<0<1<0038C00<04a<07Q<33OlC3a<00`0C4`0>4`0301<C00@C00<04a<0

?a<00`0C4`1T4`0301<C02TC00<04a<0<1<0038C00<04a<08A<23OlC31<00`0C4`0?4`<011<00`0C

4`0o4`0301<C06DC0`0X4`80<A<0038C00<04a<08a<23OlC2Q<00`0C4`0F4`0301<C03lC00<04a<0

J1<00`0C4`0V4`0301<C02lC000b4`0301<C02DC0Pgo4`PC00<04a<05Q<00`0C4`0o4`0301<C06TC

0`0U4`0301<C02lC000b4`0301<C02LC0Pgo4`HC00<04a<05Q<2040C00<04a<0K1<202<C00<04a<0

;a<0038C00<04a<0:A<00`dC4`3o4`<C00<04a<05Q<00`0C4`0o4`0301<C06dC0P0R4`0301<C02lC

000b4`0301<C02XC0Pgo4`<C00<04a<05Q<00`0C4`0o4`0301<C06lC0P0P4`0301<C02lC000b4`03

01<C02`C0Pgo4`0301<C01LC00<04a<0?Q<00`0C4`1b4`807Q<00`0C4`0_4`0071<00`0C4`024`04

01<C4`<00a<00`0C4`044`0301<C02hC00<=4a<0o1<00`0C4`0G4`0301<C03hC00<04a<0M1<201`C

00<04a<0;a<001/C00<04`001a<00`0C4`024`0301<000DC00<04a<0;a<23O`C00<04a<05a<203lC

00<04a<0MQ<201XC00<04a<0;a<001HC0`024`0301<000PC00<04a<00a<00`0C4`034`80<Q<23OXC

00<04a<05a<00`0C4`0n4`0301<C07PC00<04a<05Q<00`0C4`0`4`006a<00`0C00084`0401<C4`80

1Q<00`0C4`0c4`8=ma<00`0C4`0H4`0301<C03hC00<04a<0NA<201HC00<04a<0<1<001/C00<04`00

1a<00`0C00024`0301<C00DC00<04a<0=A<23ODC00<04a<061<00`0C4`0n4`0301<C07/C00<04a<0

4a<00`0C4`0`4`0071<00`0C4`074`0401<C4`<01A<00`0C4`0g4`8=la<00`0C4`0H4`0301<C03hC

00<04a<0O1<00`0C4`0B4`0301<C030C000b4`0301<C03TC0Pga4`0301<C01PC00<04a<0?A<00`0C

4`1n4`804Q<00`0C4`0`4`00<Q<00`0C4`0k4`8=ka<00`0C4`0H4`80?Q<00`0C4`204`8041<00`0C

4`0`4`00<Q<00`0C4`0m4`8=kA<00`0C4`0H4`0301<C024C1@024`0301<C018C00<04a<02a<50003

4`00024C1@024`0301<C01lC1@024`0301<C01/C00@04a<C1@000a<000034`0301<C034C000b4`03

01<C03lC0Pg[4`0301<C01PC00<04a<08a<01`0C4a<04`004a<00`0C4`0=4`0701<C4`0C000R4`03

01<C008C00<04a<08A<01`0C4a<04`0071<200@C00<04a<00a<0100C4`0c4`00<Q<00`0C4`0V4`03

01<C008C00@04a<C0`0?4`<=4A<00`0C4`024`0301<C008C0`0R4`0301<C008C00@04a<C0P0T4`03

01<C008C00<04a<00Q<00`0C4`0V4`D0@A<00`0C4`0H4`0301<C02<C00<04a<00a<00`0C4`0A4`03

01<C00dC00L04a<C01<0028C00<04a<00Q<00`0C4`0Q4`0701<C4`0C000N4`0501<C4`0011<2008C

00<04a<0<A<0038C00<04a<09A<00`0C00074`0301<C018C0Pd>4`0301<000TC00<04a<081<00`0C

00074`0301<0028C00<04`001a<00`0C000Y4`0301<C044C00<04a<061<00`0C4`0S4`0401<C4`80

51<00`0C4`0=4`0401<C4`808a<00`0C4`034`0301<C020C00<04a<00Q<00`0C4`0N4`8000<C01<0

0Q<00`0C00024`0301<C034C000b4`0301<C02DC00<04`0021<00`0C4`0C4`@=2Q<00`0C00074`@0

51<G3@0301<0028C00<04`001a<00`0C000Y4`0301<C040C00<04a<06A<00`0C4`0S4`0501<C4`00

5A<00`0C4`0=4`0501<C4`0091<01`0C4a<04`008Q<01`0C4a<04`008A<200<C00D04`0C000d4`00

<Q<00`0C4`0U4`0301<000PC00<04a<05a<43@HC00<04`001a<00`0C000@4`D=3A<00`0C00074`L=

7Q<00`0C00084`0301<C02PC00<04a<0@1<00`0C4`0I4`808a<200<C0`0C4`0301<C00`C0P044`80

8A<200<C0`0Q4`8011<00`0C4`0P4`8011<200034`0C03<C000b4`0301<C02DC00<04`001a<00`0C

000L4`@=0Q<00`0C00084`802a<53A8C00<04`001a<00`0C4`044`@=6Q<00`0C00074`0301<002TC

00<04a<0@1<00`0C4`0I4`0301<C03dC00<04a<0R1<00`0C4`054`0301<C038C000b4`0301<C02HC

00<04a<01a<00`0C4`0O4aX=61<00`0C4`074`8021<43ALC00<04a<01a<00`0C4`0W4`80@Q<00`0C

4`0I4`0301<C03dC00<04a<0RA<200DC00<04a<0<Q<0038C00<04a<0W1<33H`C00<04a<06A<00`0C

4`0m4`0301<C08/C00D04a<C000e4`00<Q<00`0C4`2O4`@=R1<00`0C4`0I4`0301<C03dC00<04a<0

Ra<0100C4`0C4`@07a<0038C00<04a<0Xa<33HDC00<04a<06A<00`0C4`0m4`0301<C08`C0P0D4`<0

81<0038C00<04a<0YQ<33DhC0`0[4ol02Q<00`0C4`0N4`00<Q<00`0C4`2Y4`@=Ba<00`0C4`0[4`03

01<C008C00@04a<021<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<0

1A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`034`0301<000LC00<04a<01Q<00`0C4`054`03

01<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<0

1A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<300HC00<04a<0

31<2020C000/4kH010de00<=1P094`0301<C030C00<04a<06A<00`0C4`0V4`0301<C01@C00<04a<0

41<00`0C4`0V4`0301<C02HC00<04a<09Q<0100C4`0f4`00<Q<00`0C4`084`0301<C00TC00<04a<0

2A<00`0C4`094`0301<C00PC00<04a<02A<00`0C4`094`0301<C00TC00<04a<021<00`0C4`094`03

01<C00TC00<04a<02A<00`0C4`094`0301<C00PC00<04a<02A<0100C4a<33@DC00<04a<02A<00`0C

4`084`0301<C00@C3`d24`0301<C00`C100`4`0301<C01TC00<04a<0?A<00`0C4`2;4`0501<C4`00

=A<0038C00<04a<0;1<00`0C4`0/4`0301<C02`C00<04a<09a<73A@C20dA4`0301<C040C00<04a<0

6A<00`0C4`0m4`0301<C08XC00<04a<00Q<00`0C4`0c4`00<Q<00`0C4`2k4a@=G1<00`0C4`0I4`03

01<C03dC00<04a<0RA<00`0C4`044`0301<C038C000b4`0301<C0?lC;1<00`0C4`0I4`80?Q<00`0C

4`274`801a<00`0C4`0b4`00<Q<00`0C4`3o4b`C00<04a<06A<00`0C4`0m4`0301<C08LC00<04a<0

1Q<00`0C4`0b4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0m4`0301<C08HC00<04a<021<00`0C

4`0a4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0m4`0301<C08@C0P0;4`0301<C034C000b4`03

01<C0?lC;A<00`0C4`0H4`0301<C03dC00<04a<0Pa<00`0C4`0;4`0301<C034C000b4`0301<C0?lC

;A<00`0C4`0H4`0301<C03dC00<04a<0PQ<00`0C4`0<4`0301<C034C000b4`0301<C0?lC;A<00`0C

4`0H4`80?Q<00`0C4`204`803a<00`0C4`0a4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0m4`03

01<C07lC00<04a<041<00`0C4`0`4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07`C

0P0C4`0301<C030C000b4`0301<C0?lC;A<00`0C4`0H4`0301<C03hC00<04a<0Na<201@C00<04a<0

<1<0038C00<04a<0oa<]4`0301<C01PC00<04a<0?Q<00`0C4`1i4`805Q<00`0C4`0`4`00<Q<00`0C

4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07PC00<04a<05Q<00`0C4`0`4`00<Q<00`0C4`3o4bhC

00<04a<05a<203lC00<04a<0MQ<201TC00<04a<0<1<0038C00<04a<0oa<^4`0301<C01LC00<04a<0

?Q<00`0C4`1d4`8071<00`0C4`0_4`0071<00`0C4`024`0401<C4`<00a<00`0C4`044`0301<C0?lC

;Q<00`0C4`0G4`0301<C03hC00<04a<0La<00`0C4`0L4`0301<C02lC000K4`0301<000LC00<04a<0

0Q<00`0C00054`0301<C0?lC;Q<00`0C4`0G4`0301<C03lC00<04a<0L1<201lC00<04a<0;a<001/C

00<04`0021<00`0C4`034`0301<C00<C0P3o4c0C00<04a<05Q<00`0C4`0o4`0301<C06dC0`0Q4`03

01<C02lC000K4`0301<000PC00@04a<C0P064`0301<C0?lC;a<00`0C4`0F4`0301<C03lC00<04a<0

K1<202<C00<04a<0;a<001/C00<04`001a<00`0C00024`0301<C00DC00<04a<0oa<_4`0301<C01HC

0P104`0301<C06XC0P0U4`0301<C02lC000L4`0301<C00LC00@04a<C0`054`0301<C0?lC;a<00`0C

4`0F4`0301<C03lC00<04a<0J1<202LC00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC00<04a<0

?a<00`0C4`1V4`80:A<00`0C4`0_4`00<Q<00`0C4`3o4c0C00<04a<05A<00`0C4`0o4`0301<C06@C

0P0Z4`0301<C030C000b4`0301<C0?lC<1<00`0C4`0?4`0301<C00<C00<04a<0?a<00`0C4`1R4`80

;1<00`0C4`0`4`00<Q<00`0C4`3o4c0C00<04a<03Q<00`0C00044`0301<C040C00<04a<0GQ<302hC

00<04a<0<1<0038C00<04a<0oa<`4`0301<C010C00<04a<00Q<3040C00<04a<0G1<3030C00<04a<0

<1<0038C00<04a<0oa<a4`0301<C00dC0P054`0301<C040C00<04a<0FQ<2038C0P0b4`00<Q<00`0C

4`3o4c4C00<04a<03A<00`0C4`044`0301<C044C00<04a<0Ea<203@C00<04a<0<A<0038C00<04a<0

oa<b4`0301<C00`C0`044`0301<C044C00<04a<0E1<303HC00<04a<0<A<0038C00<04a<0oa<b4`03

01<C01<C00<04a<0@A<00`0C4`1B4`<0=a<203<C000b4`0301<C0?lC<a<00`0C4`0B4`80@Q<00`0C

4`1?4`<0>Q<00`0C4`0b4`00<Q<00`0C4`3o4c<C00<04a<04Q<00`0C4`124`0301<C04`C0`0l4`03

01<C038C000b4`0301<C0?lC=1<00`0C4`0A4`0301<C048C00<04a<0BA<303hC00<04a<0<a<0038C

00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`174`<0@1<00`0C4`0c4`008A<00`0C4`024`03

01<C008C00<04a<011<00`0C4`3o4cDC00<04a<041<00`0C4`124`0301<C04@C0`124`80=A<0020C

00<04`001a<00`0C00054`0301<C0?lC=A<00`0C4`0@4`0301<C04<C00<04a<0@1<304DC00<04a<0

=1<0020C00<04`002A<00`0C4`034`80oa<g4`0301<C00lC0P144`0301<C03dC0`174`80=Q<0020C

00<04`001a<200HC00<04a<0oa<f4`0301<C00lC00<04a<0A1<00`0C4`0i4`<0BQ<00`0C4`0e4`00

81<00`0C00074`0301<C00DC00<04a<0oa<g4`0301<C00hC00<04a<0A1<00`0C4`0f4`@0Ba<203LC

000Q4`0301<C00HC0`054`0301<C0?lC>1<00`0C4`0=4`0301<C04@C00<04a<0<a<304lC00<04a<0

=Q<0038C00<04a<0oa<i4`0301<C00`C00<04a<0AA<00`0C4`0_4`<0DA<00`0C4`0g4`00<Q<00`0C

4`3o4cTC00<04a<031<00`0C4`154`0301<C02/C101C4`80>A<0038C00<04a<0oa<j4`0301<C00/C

0P174`0301<C02LC101F4`0301<C03PC000b4`0301<C0?lC>Q<00`0C4`0;4`0301<C04HC00<04a<0

8a<505PC0P0j4`00<Q<00`0C4`3o4c/C0P0;4`0301<C04HC00<04a<081<405/C0P0k4`00<Q<00`0C

4`3o4cdC00<04a<021<00`0C4`174`0301<C01/C101O4`0301<C03XC000b4`0301<C0?lC?Q<00`0C

4`074`0301<C04LC0P0H4`D0HA<00`0C4`0k4`00<Q<00`0C4`3o4chC00<04a<01a<00`0C4`184`03

01<C01<C101T4`80?A<0038C00<04a<0oa<o4`0301<C00HC0P1:4`0301<C00hC101W4`80?Q<0038C

00<04a<0oa=04`801Q<00`0C4`194`0301<C00XC101Z4`80?a<0038C00<04a<0oa=24`0301<C00<C

00<04a<0BQ<00`0C4`054`D0K1<2040C000b4`0301<C0?lC@a<200<C00<04a<0BQ<200034`0000<0

L1<2044C000b4`0301<C0?lC>a<5008C00@04a<00Q<00`0C4`0c4`033A<C01<C1@1c4`80@Q<001`C

00<04a<00Q<00`0C4`024`0301<C008C00<04a<011<00`0C4`3o4cdC00L04a<C01<0008C0`0b4`H=

3a<5008C00<04a<0LA<204<C000K4`0301<000PC00L04a<C01<000DC00<04a<0oa<m4`0701<C4`0C

00044`<0;a<93@PC1@084`0301<C06hC0P154`006a<00`0C00084`0301<C00<C00<04a<00a<20?lC

?Q<01`0C4a<04`0011<0100C000^4`T=0a<500dC00<04a<0KA<204HC000K4`0301<000TC00<04a<0

0P064`0301<C0?lC?A<01`0C4a<04`0011<0100C4a<302/C2@d301<C0P1[4`<0Aa<001/C00<04`00

1a<00`0C00024`0301<C00DC00<04a<0oa<l4`8011<00`0C4`034`0301<C00@C0`0W4`/=5Q<206TC

0P194`0071<00`0C4`064`<00Q<300DC00<04a<0oa=84`0301<C00LC1@0K4`P02@dH4`0301<C06@C

0`1;4`00<Q<00`0C4`3o4dPC00<04a<031<L00LC2@dI4`80HQ<304dC000b4`0301<C0?lCB1<2030C

2@dJ4`80Ga<304lC000b4`0301<C0?lCB1<00`0C4`0`4`H=7A<205XC101B4`00<Q<00`0C4`3o4dPC

00<04a<0<a<00`dC4`0N4`80EQ<405DC000b4`0301<C0?lCB1<00`0C4`1F4`80Ca<505TC000b4`03

01<C0?lCB1<00`0C4`1G4`<0B1<605dC000b4`0301<C0?lCB1<00`0C4`1I4`<0@1<7068C000b4`03

01<C0?lCB1<205`C0`0h4`L0J1<0038C00<04a<0oa=84`0301<C05hC0`0^4`P0KQ<0038C00<04a<0

oa=84`0301<C060C1@0S4`P0MA<0038C00<04a<0oa=84`0301<C06@C1`0D4`X0O1<0038C00<04a<0

oa=84`0301<C06XC5@264`00<Q<00`0C4`3o4dPC00<04a<0oa<64`00:A<500@C00<04a<0oa=84`80

oa<74`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`3o4`HC000[4`0301<C00@C0P3o4dTC00<04a<0

oa<64`00:a<00`0C4`3o4olCF1<002/C00<04a<0oa?o4ePC000Z4`80oa?o4eXC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00LA<400034`0000L00Q<00`0C4`024`0401<C4`80

0a<3008C0P034`800a<200<C0P034`800a<200<C0P034`800a<200<C0P034`800a<200@C00@04a<C

0P3o4jhC001a4`<021<01`0C4a<04`002A<0100C4`064`0301<C008C00<04a<00Q<00`0C4`024`03

01<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<0

0Q<01P0C4`0C00@C00<04a<0X1<20?lC2A<007<C00<04a<010024`0301<C00<C00<04a<01Q<00`0C

4`024`0301<C008C0P034`800a<200<C0P034`800a<200<C0P034`800a<200<C0P034`800a<2008C

00<04`000a<00`0C4`2R4`0301<C0?lC1a<001TC10000a<00006008C2P024`800Q<3008C0`034`80

00HC00004`0W4`8021<0100C4a<200XC00D04a<C00034`0301<0008C00<04`000Q<00`0C00024`03

01<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0Q<00`0C00024`0301<000@C00<04a<0Wa<3008C00<04a<0oa<44`006Q<01P0C4`0C008C00<04`00

11<01P0C4`0C008C00<04`001A<00`0C4`024`0501<C4`000Q<0100C01<2034C00D04a<C00094`03

01<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`03

01<000@C00<04a<0VA<0200C4`0C01<0oa<54`006Q<01P0C4`0C00@C00<04a<00Q<00`0C4`024`03

01<C008C00<04a<00a<00`0C4`024`0501<C4`000Q<0100C01<2030C0P034`<021<00`0C4`024`03

01<C008C0P034`800a<200<C0P034`800a<200<C0P034`800a<200<C0P034`800a<200<C00<04a<0

0Q<00`0C4`024`0301<C09XC00P04a<04`0C0?lC1A<001XC00D04a<04`0200<C0P034`0301<C008C

0P034`0301<C00<C00<04a<00Q<01@0C4a<0008C00H04`004`3o4blC0`0011<04`3o4`DC000J4`06

01<C01<00Q<00`0C00024`0301<000@C00h04a<04`0C01<04`0C008C00D04a<C00024`0601<001<0

oa<c4`0301<00?lC1A<001TC10000a<0000;008C1@001A<0000C00D000@C00000a<200044`004`80

oa<d4`0301<C0?lC11<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olC

QQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00001\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.77084, -14.119, 0.0242408, 0.16996}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -57 0 ]

[.5 .63053 57 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -118 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(15.8899999999999907`) show

173.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .13647 m

.02499 .13647 L

.02606 .13648 L

.02729 .13649 L

.02846 .1365 L

.03053 .13654 L

.03279 .1366 L

.03527 .13668 L

.0379 .13679 L

.04262 .13705 L

.04749 .13739 L

.05205 .13778 L

.06245 .13892 L

.07305 .14045 L

.08274 .14217 L

.10458 .14716 L

.12357 .15274 L

.14429 .16009 L

.18493 .17801 L

.22406 .19876 L

.26565 .22267 L

.30571 .2449 L

.34426 .26279 L

.3642 .26991 L

.37437 .27288 L

.38527 .27554 L

.39554 .27754 L

.4049 .27894 L

.40941 .27946 L

.41432 .27994 L

.41895 .28028 L

.42324 .28052 L

.42566 .28062 L

.42787 .28069 L

.42913 .28072 L

.4303 .28075 L

.43153 .28077 L

.43217 .28077 L

.43287 .28078 L

.43403 .28079 L

.4353 .28079 L

.4365 .28078 L

.4376 .28077 L

.4386 .28076 L

.43969 .28074 L

.4419 .28069 L

.44458 .28061 L

.44703 .28051 L

.45255 .28022 L

.45766 .27986 L

Mistroke

.4625 .27946 L

.48235 .27723 L

.50075 .27464 L

.51958 .27187 L

.53993 .26921 L

.55111 .26806 L

.55601 .26765 L

.56138 .26727 L

.56647 .26699 L

.5712 .26679 L

.57382 .26672 L

.57506 .26669 L

.57621 .26667 L

.57753 .26665 L

.57822 .26664 L

.57896 .26664 L

.5802 .26663 L

.58091 .26663 L

.58157 .26663 L

.58275 .26664 L

.58401 .26665 L

.5852 .26666 L

.58628 .26668 L

.58893 .26674 L

.59142 .26682 L

.5964 .26705 L

.60179 .2674 L

.60647 .26779 L

.61143 .2683 L

.62031 .26943 L

.63992 .27292 L

.65825 .27728 L

.69712 .28897 L

.73845 .30222 L

.75912 .30801 L

.77826 .31242 L

.79682 .3156 L

.8062 .31677 L

.81125 .31727 L

.81656 .31771 L

.82137 .31802 L

.82392 .31815 L

.82664 .31827 L

.82914 .31836 L

.83143 .31843 L

.83252 .31845 L

.83372 .31848 L

.83476 .31849 L

.83588 .31851 L

.83718 .31852 L

Mistroke

.83839 .31852 L

.83913 .31853 L

.83983 .31853 L

.84115 .31852 L

.84182 .31852 L

.84253 .31851 L

.84382 .3185 L

.84534 .31848 L

.84673 .31845 L

.8492 .31839 L

.85188 .31831 L

.85673 .31812 L

.86625 .31758 L

.87668 .31679 L

.89775 .31476 L

.91891 .31252 L

.9382 .31071 L

.94755 .31002 L

.95248 .30972 L

.95771 .30945 L

.96228 .30927 L

.9647 .30919 L

.96731 .30912 L

.9697 .30907 L

.97075 .30906 L

.97189 .30904 L

.97298 .30903 L

.97399 .30902 L

.97505 .30902 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.44175 .53255 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4gdC00<04a<0oa<64`00oa=m4`0301<C0?lC1Q<002TC1@3o4dlC0P3o4`LC

000[4`0301<C0?lCCa<00`0C4`1^4`d0RQ<002DC0`034`0301<C00@C0P3o4dTC00<04a<0IQ<800`C

3@1n4`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`1Q4`D081<807LC000[4`0301<C00@C00<04a<0

oa=84`0301<C05hC100/4`L0L1<002XC0P064`0301<C0?lCB1<00`0C4`1L4`<0=A<706XC000b4`03

01<C0?lCB1<205/C0P0o4`H0I1<0038C00<04a<0oa=84`0301<C05PC0P164`H0Ga<0038C00<04a<0

oa=84`0301<C05HC0P1>4`D0FQ<0038C00<04a<0oa=84`0301<C05DC0P1C4`D0EQ<0038C00<04a<0

oa=84`0301<C05@C00<04a<0Ea<5058C000b4`0301<C0?lCB1<205<C0P1N4`<0D1<0038C00<04a<0

oa=84`0301<C00lC5P0/4`80HA<404dC000b4`0301<C0?lCB1<00`0C4`0:4`D05Q<9028C0P1U4`<0

Ba<0038C00<04a<0oa=84`0301<C00DC1@0S4`L06a<206PC0`194`00<Q<00`0C4`3o4c/C1@024`03

01<C00<C00<04a<00a<202lC1P0D4`80Ja<204PC000b4`0301<C0?lC?A<01`0C4a<04`0011<00`0C

4`0303HC1P0>4`80KA<304HC000b4`0301<C0?lC=a<300<C00L04a<C01<000@C0`0n4`H02A<00`0C

4`1^4`80AA<0038C00<04a<0oa<m4`0701<C4`0C00034`80AA<500@C00<04a<0L1<204@C000L4`03

01<C008C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0oa<m4`0701<C4`0C00024`0301<004XC

1@1d4`80@Q<001/C00<04`0021<01`0C4a<04`001A<00`0C4`3o4c`C0P044`0401<0008C00<04a<0

Ba<6074C0P114`005Q<3008C00<04`0021<00`0C4`034`0301<C00<C0P3o4d<C0P044`0301<C04XC

00<04a<011<406hC0P104`006a<00`0C00094`0301<C00801Q<00`0C4`3o4d4C00<04a<011<00`0C

4`194`0301<C00TC101[4`0301<C03hC000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C0?lC

@1<00`0C4`054`80BQ<00`0C4`0=4`@0J1<203hC000L4`0301<C00HC0`024`<01A<00`0C4`3o4clC

00<04a<01Q<00`0C4`184`0301<C018C101U4`0301<C03`C000b4`0301<C0?lC?Q<00`0C4`074`03

01<C04PC00<04a<05A<5068C00<04a<0>a<0038C00<04a<0oa<m4`0301<C00PC00<04a<0Aa<00`0C

4`0J4`@0Ga<203`C000b4`0301<C0?lC?1<00`0C4`094`0301<C04HC00<04a<07a<405`C0P0k4`00

<Q<00`0C4`3o4c/C00<04a<02Q<00`0C4`164`0301<C028C1@1I4`0301<C03TC000b4`0301<C0?lC

>Q<00`0C4`0;4`80Aa<00`0C4`0V4`@0Ea<00`0C4`0h4`00<Q<00`0C4`3o4cTC00<04a<031<00`0C

4`154`0301<C02XC101D4`80>A<0038C00<04a<0oa<i4`0301<C00`C00<04a<0AA<00`0C4`0^4`@0

DA<00`0C4`0g4`00<Q<00`0C4`3o4cPC00<04a<03A<00`0C4`144`0301<C03<C0P1?4`80>1<0038C

00<04a<0oa<g4`0301<C00hC00<04a<0A1<00`0C4`0e4`@0C1<203LC000b4`0301<C0?lC=Q<00`0C

4`0?4`0301<C04@C00<04a<0>A<204/C00<04a<0=A<0038C00<04a<0oa<f4`0301<C00lC0P144`03

01<C03`C10174`80=Q<0038C2`go4bdC00<04a<041<00`0C4`134`0301<C03lC0`164`0301<C03@C

000b4`0301<C00PC1Pgo4bLC00<04a<041<00`0C4`134`0301<C048C0`134`80=A<0024C00<04a<0

0Q<00`0C4`024`0301<C00@C00<04a<03Q<43OlC8Q<00`0C4`0A4`0301<C048C00<04a<0AQ<3044C

00<04a<0<a<0020C00<04`001a<00`0C00054`0301<C018C0Pgo4b0C00<04a<04A<00`0C4`124`03

01<C04TC0P0o4`0301<C03<C000K4`<00Q<00`0C00094`0301<C00<C0P0E4`<=oa<L4`0301<C018C

00<04a<0@Q<00`0C4`1;4`<0?A<00`0C4`0b4`0081<00`0C00074`801Q<00`0C4`0G4`8=oa<J4`03

01<C018C0P134`0301<C04hC0P0k4`0301<C038C000P4`0301<000LC00<04a<01A<00`0C4`0I4`<=

oa<F4`0301<C01<C00<04a<0@A<00`0C4`1A4`<0>1<00`0C4`0b4`008A<00`0C4`064`<01A<00`0C

4`0L4`8=oa<D4`0301<C01<C00<04a<0@A<00`0C4`1D4`80=a<00`0C4`0a4`00<Q<00`0C4`0N4`<=

oa<@4`0301<C01@C00<04a<0@A<00`0C4`1F4`<0=1<00`0C4`0a4`00<Q<00`0C4`0Q4`8=oa<>4`03

01<C00hC00<04a<00a<00`0C4`104`0301<C05TC0`0b4`80<Q<0038C00<04a<08a<23OlC2a<00`0C

4`0>4`0301<000@C00<04a<0@1<00`0C4`1L4`80<A<00`0C4`0`4`00<Q<00`0C4`0U4`8=oa<94`03

01<C00TC0`044`0301<C008C0`104`0301<C05hC0P0_4`0301<C030C000b4`0301<C02LC0Pgo4`LC

00<04a<03Q<200DC00<04a<0?a<00`0C4`1Q4`<0;1<00`0C4`0`4`00<Q<00`0C4`0Y4`8=oa<54`03

01<C00hC00<04a<011<00`0C4`0o4`0301<C06@C00<04a<0:A<00`0C4`0`4`00<Q<00`0C4`0[4`8=

oa<24`0301<C00lC0`044`0301<C03lC00<04a<0IA<302PC0P0a4`00<Q<00`0C4`0]4`8=oa<00`0C

4`0F4`0301<C03lC00<04a<0J1<00`0C4`0V4`0301<C02lC000b4`0301<C02lC0Pgm4`0301<C01HC

00<04a<0?a<00`0C4`1Y4`<09A<00`0C4`0_4`00<Q<00`0C4`0a4`8=na<00`0C4`0F4`80@1<00`0C

4`1/4`808a<00`0C4`0_4`00<Q<00`0C4`0c4`033A<C0?PC00<04a<05Q<00`0C4`0o4`0301<C06dC

0P0R4`0301<C02lC000b4`0301<C03@C0Pgh4`0301<C01HC00<04a<0?a<00`0C4`1_4`8081<00`0C

4`0_4`00<Q<00`0C4`0f4`8=mA<00`0C4`0G4`0301<C03hC00<04a<0LQ<201hC00<04a<0;a<001`C

00<04a<00Q<0100C4a<300<C00<04a<011<00`0C4`0h4`033A<C0?8C00<04a<05a<00`0C4`0n4`03

01<C07@C0P0L4`0301<C02lC000K4`0301<000LC00<04a<00Q<00`0C00054`0301<C03TC0Pgb4`03

01<C01LC0P0o4`0301<C07HC0P0J4`0301<C02lC000F4`<00Q<00`0C00084`0301<C00<C00<04a<0

0a<203`C0Pg`4`0301<C01LC00<04a<0?Q<00`0C4`1h4`0301<C01HC00<04a<0<1<001/C00<04`00

21<0100C4a<200HC00<04a<0?A<00`dC4`3/4`0301<C01PC00<04a<0?Q<00`0C4`1i4`805Q<00`0C

4`0`4`006a<00`0C00074`0301<0008C00<04a<01A<00`0C4`0n4`8=k1<00`0C4`0H4`0301<C03hC

00<04a<0Na<00`0C4`0C4`0301<C030C000L4`0301<C00LC00@04a<C0`054`0301<C040C0PgZ4`03

01<C01PC00<04a<0?Q<00`0C4`1l4`0301<C018C00<04a<0<1<0038C00<04a<0@Q<23NPC00<04a<0

61<00`0C4`0m4`0301<C07hC0P0B4`0301<C030C000b4`0301<C04@C0PgV4`0301<C01PC0P0n4`03

01<C080C0P0@4`0301<C030C000b4`0301<C04HC0`gS4`0301<C01PC00<04a<08A<5008C00<04a<0

4Q<00`0C4`0;4`D000<C00008A<5008C00<04a<07a<5008C00<04a<06a<0100C4a<500034`0000<C

00<04a<0<A<0038C00<04a<0BA<23N4C00<04a<061<00`0C4`0S4`0701<C4`0C000C4`0301<C00dC

00L04a<C01<0028C00<04a<00Q<00`0C4`0Q4`0701<C4`0C000L4`8011<00`0C4`034`0401<C03<C

000b4`0301<C02HC00<04a<00Q<0100C4a<301TC0`d74`0301<C008C00<04a<00Q<3028C00<04a<0

0Q<0100C4a<202@C00<04a<00Q<00`0C4`024`0301<C02HC1@114`0301<C01PC00<04a<08a<00`0C

4`034`0301<C014C00<04a<03A<01`0C4a<04`008Q<00`0C4`024`0301<C024C00L04a<C01<001hC

00D04a<C00044`800Q<00`0C4`0a4`00<Q<00`0C4`0U4`0301<000LC00<04a<071<23@@C00<04`00

2A<00`0C4`0K4a4=00<04a<081<00`0C00074`0301<002TC00<04a<0@A<00`0C4`0H4`0301<C02<C

00@04a<C0P0D4`0301<C00dC00@04a<C0P0S4`0301<C00<C00<04a<081<00`0C4`024`0301<C01hC

0P000a<04`024`0301<0008C00<04a<0<A<0038C00<04a<09A<00`0C00084`0301<C01dC0Pd24`03

01<000LC100C4`T=1A<00`0C00074`0301<=00<=7a<00`0C00074`0301<002TC00<04a<0@1<00`0C

4`0I4`0301<C02<C00D04a<C000E4`0301<C00dC00D04a<C000T4`0701<C4`0C000R4`0701<C4`0C

000Q4`800a<01@0C01<003@C000b4`0301<C02DC00<04`0021<00`0C4`0O4`D=1a<00`0C000@4`@=

3Q<00`0C00074`8011<43A/C00<04`0021<00`0C4`0X4`0301<C040C00<04a<06A<202<C0P034`<0

4a<00`0C4`0<4`8011<2024C0P034`<08A<200@C00<04a<081<200@C0P000a<04`0c4`00<Q<00`0C

4`0U4`0301<000LC00<04`008Q<00`0C000J3A8C00<04`001a<00`0C4`074`@=5a<00`0C00074`03

01<002TC00<04a<0@1<00`0C4`0I4`0301<C03dC00<04a<0R1<00`0C4`054`0301<C038C000b4`03

01<C02HC00<04a<01a<00`0C4`0R4`0301<C00PC00<04a<08A<00`0C4`074`802a<33ADC00<04a<0

1a<00`0C4`0W4`80@Q<00`0C4`0I4`0301<C03dC00<04a<0RA<200DC00<04a<0<Q<0038C00<04a<0

WQ<43HTC00<04a<06A<00`0C4`0m4`0301<C08/C00D04a<C000e4`00<Q<00`0C4`2R4`<=QQ<00`0C

4`0I4`0301<C03dC00<04a<0Ra<0100C4`0C4`@07a<0038C00<04a<0YA<33H<C00<04a<06A<00`0C

4`0m4`0301<C08`C0P0D4`<081<0038C00<04a<0Z1<43D/C0`0[4ol02Q<00`0C4`0N4`00<Q<00`0C

4`2/4`@=B1<00`0C4`0[4`0301<C008C00@04a<021<00`0C4`054`0301<C00DC00<04a<01A<00`0C

4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`034`0301<000LC

00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C

4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC

00<04a<01A<300HC00<04a<031<2020C000/4kT01@da00<=1P094`0301<C030C00<04a<06A<00`0C

4`0V4`0301<C01@C00<04a<041<00`0C4`0V4`0301<C02HC00<04a<09Q<0100C4`0f4`00<Q<00`0C

4`084`0301<C00TC00<04a<02A<00`0C4`094`0301<C00PC00<04a<02A<00`0C4`094`0301<C00TC

00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0C4`094`0301<C00PC00<04a<02A<00`0C

4`054`D=2a<00`0C4`084`0301<C00DC3Pd24`0301<C00`C100`4`0301<C01TC00<04a<0?A<00`0C

4`2;4`0501<C4`00=A<0038C00<04a<0;1<00`0C4`0/4`0301<C02`C00<04a<0;1<00`0=3@033A0C

2@d@4`0301<C040C00<04a<06A<00`0C4`0m4`0301<C08XC00<04a<00Q<00`0C4`0c4`00<Q<00`0C

4`2o4a0=G1<00`0C4`0I4`0301<C03dC00<04a<0RA<00`0C4`044`0301<C038C000b4`0301<C0?lC

;1<00`0C4`0I4`80?Q<00`0C4`274`801a<00`0C4`0b4`00<Q<00`0C4`3o4b`C00<04a<06A<00`0C

4`0m4`0301<C08LC00<04a<01Q<00`0C4`0b4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0m4`03

01<C08HC00<04a<021<00`0C4`0a4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0m4`0301<C08@C

0P0;4`0301<C034C000b4`0301<C0?lC;A<00`0C4`0H4`0301<C03dC00<04a<0Pa<00`0C4`0;4`03

01<C034C000b4`0301<C0?lC;A<00`0C4`0H4`0301<C03dC00<04a<0PQ<00`0C4`0<4`0301<C034C

000b4`0301<C0?lC;A<00`0C4`0H4`80?Q<00`0C4`204`803a<00`0C4`0a4`00<Q<00`0C4`3o4bdC

00<04a<061<00`0C4`0m4`0301<C07lC00<04a<041<00`0C4`0`4`00<Q<00`0C4`3o4bdC00<04a<0

61<00`0C4`0n4`0301<C07`C0P0C4`0301<C030C000b4`0301<C0?lC;A<00`0C4`0H4`0301<C03hC

00<04a<0Na<201@C00<04a<0<1<0038C00<04a<0oa<]4`0301<C01PC00<04a<0?Q<00`0C4`1i4`80

5Q<00`0C4`0`4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07PC00<04a<05Q<00`0C

4`0`4`00<Q<00`0C4`3o4bhC00<04a<05a<203lC00<04a<0MQ<201TC00<04a<0<1<0038C00<04a<0

oa<^4`0301<C01LC00<04a<0?Q<00`0C4`1d4`8071<00`0C4`0_4`0071<00`0C4`024`0401<C4`<0

0a<00`0C4`044`0301<C0?lC;Q<00`0C4`0G4`0301<C03hC00<04a<0La<00`0C4`0L4`0301<C02lC

000K4`0301<000LC00<04a<00Q<00`0C00054`0301<C0?lC;Q<00`0C4`0G4`0301<C03lC00<04a<0

L1<201lC00<04a<0;a<001/C00<04`0021<00`0C4`034`0301<C00<C0P3o4c0C00<04a<05Q<00`0C

4`0o4`0301<C06dC0`0Q4`0301<C02lC000K4`0301<000PC00@04a<C0P064`0301<C0?lC;a<00`0C

4`0F4`0301<C03lC00<04a<0K1<202<C00<04a<0;a<001/C00<04`001a<00`0C00024`0301<C00DC

00<04a<0oa<_4`0301<C01HC0P104`0301<C06XC0P0U4`0301<C02lC000L4`0301<C00LC00@04a<C

0`054`0301<C0?lC;a<00`0C4`0F4`0301<C03lC00<04a<0J1<202LC00<04a<0;a<0038C00<04a<0

oa<_4`0301<C01HC00<04a<0?a<00`0C4`1V4`80:A<00`0C4`0_4`00<Q<00`0C4`3o4c0C00<04a<0

5A<00`0C4`0o4`0301<C06@C0P0Z4`0301<C030C000b4`0301<C0?lC<1<00`0C4`0?4`0301<C00<C

00<04a<0?a<00`0C4`1R4`80;1<00`0C4`0`4`00<Q<00`0C4`3o4c0C00<04a<03Q<00`0C00044`03

01<C040C00<04a<0GQ<302hC00<04a<0<1<0038C00<04a<0oa<`4`0301<C010C00<04a<00Q<3040C

00<04a<0G1<3030C00<04a<0<1<0038C00<04a<0oa<a4`0301<C00dC0P054`0301<C040C00<04a<0

FQ<2038C0P0b4`00<Q<00`0C4`3o4c4C00<04a<03A<00`0C4`044`0301<C044C00<04a<0Ea<203@C

00<04a<0<A<0038C00<04a<0oa<b4`0301<C00`C0`044`0301<C044C00<04a<0E1<303HC00<04a<0

<A<0038C00<04a<0oa<b4`0301<C01<C00<04a<0@A<00`0C4`1B4`<0=a<203<C000b4`0301<C0?lC

<a<00`0C4`0B4`80@Q<00`0C4`1?4`<0>Q<00`0C4`0b4`00<Q<00`0C4`3o4c<C00<04a<04Q<00`0C

4`124`0301<C04`C0`0l4`0301<C038C000b4`0301<C0?lC=1<00`0C4`0A4`0301<C048C00<04a<0

BA<303hC00<04a<0<a<0038C00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`174`<0@1<00`0C

4`0c4`008A<00`0C4`024`0301<C008C00<04a<011<00`0C4`3o4cDC00<04a<041<00`0C4`124`03

01<C04@C0`124`80=A<0020C00<04`001a<00`0C00054`0301<C0?lC=A<00`0C4`0@4`0301<C04<C

00<04a<0@1<304DC00<04a<0=1<0020C00<04`002A<00`0C4`034`80oa<g4`0301<C00lC0P144`03

01<C03dC0`174`80=Q<0020C00<04`001a<200HC00<04a<0oa<f4`0301<C00lC00<04a<0A1<00`0C

4`0i4`<0BQ<00`0C4`0e4`0081<00`0C00074`0301<C00DC00<04a<0oa<g4`0301<C00hC00<04a<0

A1<00`0C4`0f4`@0Ba<203LC000Q4`0301<C00HC0`054`0301<C0?lC>1<00`0C4`0=4`0301<C04@C

00<04a<0<a<304lC00<04a<0=Q<0038C00<04a<0oa<i4`0301<C00`C00<04a<0AA<00`0C4`0_4`<0

DA<00`0C4`0g4`00<Q<00`0C4`3o4cTC00<04a<031<00`0C4`154`0301<C02/C101C4`80>A<0038C

00<04a<0oa<j4`0301<C00/C0P174`0301<C02LC101F4`0301<C03PC000b4`0301<C0?lC>Q<00`0C

4`0;4`0301<C04HC00<04a<08a<505PC0P0j4`00<Q<00`0C4`3o4c/C0P0;4`0301<C04HC00<04a<0

81<405/C0P0k4`00<Q<00`0C4`3o4cdC00<04a<021<00`0C4`174`0301<C01/C101O4`0301<C03XC

000b4`0301<C0?lC?Q<00`0C4`074`0301<C04LC0P0H4`D0HA<00`0C4`0k4`00<Q<00`0C4`3o4chC

00<04a<01a<00`0C4`184`0301<C01<C101T4`80?A<0038C00<04a<0oa<o4`0301<C00HC0P1:4`03

00dC00hC101W4`80?Q<0038C00<04a<0oa=04`801Q<00`0C4`174`H=2A<406XC0P0o4`00<Q<00`0C

4`3o4d8C00<04a<00a<00`0C4`164`T=0a<506`C0P104`00<Q<00`0C4`3o4d<C0P034`0301<C04HC

2@d3070C0P114`00<Q<00`0C4`3o4c/C1@024`0401<C008C00<04a<0AQ<93G8C0P124`0071<00`0C

4`024`0301<C008C00<04a<00Q<00`0C4`044`0301<C0?lC?A<01`0C4a<04`000Q<304LC2`e`4`80

@a<001/C00<04`0021<01`0C4a<04`001A<00`0C4`3o4cdC00L04a<C01<000@C0`104`D000<C3@d0

1`e_4`80AA<001/C00<04`0021<00`0C4`034`0301<C00<C0P3o4chC00L04a<C01<000@C00@04`00

>Q<500HC2@e^4`80AQ<001/C00<04`002A<00`0C4`0200HC00<04a<0oa<m4`0701<C4`0C00044`04

01<C4`<0<A<600/C2@d00`0C4`1Y4`<0Aa<001/C00<04`001a<00`0C00024`0301<C00DC00<04a<0

oa<l4`8011<00`0C4`034`0301<C00@C0`0X4`L04A<63@8C0P1Y4`80BA<001`C00<04a<01Q<3008C

0`054`0301<C0?lCB1<00`0C4`074`D06a<901XC00<=4a<00a<00`0C4`1T4`<0Ba<0038C00<04a<0

oa=84`0301<C00`C700Y4`80HQ<304dC000b4`0301<C0?lCB1<205<C0P1O4`<0Ca<0038C00<04a<0

oa=84`0301<C05<C0P1J4`@0DQ<0038C00<04a<0oa=84`0301<C05@C0P1F4`@0EA<0038C00<04a<0

oa=84`0301<C05HC0P1?4`D0FA<0038C00<04a<0oa=84`0301<C05LC0`184`H0GA<0038C00<04a<0

oa=84`0301<C05TC0`104`L0HQ<0038C00<04a<0oa=84`80G1<303PC1`1X4`00<Q<00`0C4`3o4dPC

00<04a<0GQ<302hC201^4`00<Q<00`0C4`3o4dPC00<04a<0H1<502<C201e4`00<Q<00`0C4`3o4dPC

00<04a<0I1<701@C2P1l4`00<Q<00`0C4`3o4dPC00<04a<0JQ<E08HC000b4`0301<C0?lCB1<00`0C

4`3o4`HC000Y4`D011<00`0C4`3o4dPC0P3o4`LC000[4`0301<C00@C00<04a<0oa=84`0301<C0?lC

1Q<002/C00<04a<011<20?lCBA<00`0C4`3o4`HC000[4`0301<C0?lCoa=H4`00:a<00`0C4`3o4olC

F1<002XC0P3o4olCFQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC001a4`@0

00<C00001`024`0301<C008C00<04a<00Q<00`0C4`024`0401<C4`800a<200<C0P034`800a<200<C

0P034`800a<200<C0P034`800a<200<C0P044`0301<C008C00<04a<0oa>/4`00LA<300PC00L04a<C

01<000LC00<04`000Q<00`0C00044`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<0

0Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<01P0C4`0C00<C

00<04a<0XA<20?lC2A<007<C00<04a<010024`0301<C00<C00<04a<01A<00`0C00024`0301<000<C

0P034`800a<200<C0P034`800a<200<C0P034`800a<200<C0P034`800a<2008C00<04`000a<00`0C

4`2R4`0301<C0?lC1a<001TC10000a<00006008C2P024`800Q<3008C0`034`8000HC00004`0W4`80

21<0100C4a<200TC00<04a<00Q<01`0C4a<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C

00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C

00<04`0011<00`0C4`2O4`<00Q<00`0C4`3o4`@C000J4`0601<C01<00Q<00`0C00044`0601<C01<0

0Q<00`0C00054`0301<C008C00D04a<C00024`0401<04`80<A<01@0C4a<000TC00<04`000Q<00`0C

00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C

00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`0011<00`0C

4`2I4`0801<C01<04`3o4`DC000J4`0601<C01<011<00`0C4`024`0301<C008C00<04a<00Q<00`0C

4`034`0301<C008C00D04a<C00024`0401<04`80<1<200<C0`084`0301<C008C00<04a<00Q<200<C

0P034`800a<200<C0P034`800a<200<C0P034`800a<200<C0P034`800a<0100C4a<300<C00<04a<0

VQ<0200C4`0C01<0oa<54`006Q<01@0C4`0C00800a<200<C00<04a<00Q<200<C00<04a<00a<00`0C

4`024`0501<C4`000Q<01P0C000C0?lC;a<300044`0C0?lC1A<001XC00H04a<04`024`0301<0008C

00<04`0011<03P0C4`0C01<04`0C01<00Q<01@0C4a<0008C00H04`004`3o4c<C00<04`00oa<54`00

6A<400034`0000/00Q<500054`0001<01@0011<000034`8000@C000C0P3o4c@C00<04a<0oa<44`00

oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olC

QQ<00?lCoa>64`00\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.77084, -14.119, 0.0242408, 0.16996}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -57 0 ]

[.5 .63053 57 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -118 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(16.4500000000000001`) show

173.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .11546 m

.02499 .11546 L

.02606 .11546 L

.02729 .11547 L

.02846 .11549 L

.03053 .11552 L

.03279 .11557 L

.03527 .11565 L

.0379 .11575 L

.04262 .11598 L

.04749 .11629 L

.05205 .11664 L

.06245 .11767 L

.07305 .11905 L

.08274 .12061 L

.10458 .12515 L

.12357 .13027 L

.14429 .13708 L

.18493 .15408 L

.22406 .17447 L

.26565 .19915 L

.30571 .22367 L

.34426 .24521 L

.36381 .25448 L

.38527 .26289 L

.39512 .26606 L

.40569 .26894 L

.41559 .27114 L

.42475 .27275 L

.43493 .27406 L

.44029 .27456 L

.44304 .27476 L

.44599 .27494 L

.44857 .27507 L

.45093 .27516 L

.45318 .27522 L

.45432 .27525 L

.45556 .27527 L

.45627 .27528 L

.45694 .27528 L

.4582 .27529 L

.45891 .27529 L

.45956 .27529 L

.46027 .27529 L

.46103 .27529 L

.46228 .27527 L

.46345 .27526 L

.46473 .27523 L

.46612 .2752 L

.46866 .27512 L

Mistroke

.47137 .27502 L

.47625 .27476 L

.48204 .27436 L

.48729 .27392 L

.50739 .27169 L

.5283 .26887 L

.54751 .26635 L

.55723 .26525 L

.56629 .26439 L

.57575 .26372 L

.58075 .26346 L

.58356 .26335 L

.58611 .26328 L

.58841 .26323 L

.58971 .26321 L

.59094 .26319 L

.59222 .26318 L

.5934 .26318 L

.59469 .26318 L

.59534 .26319 L

.59605 .26319 L

.59726 .26321 L

.59836 .26322 L

.59962 .26325 L

.60081 .26328 L

.60294 .26334 L

.60524 .26343 L

.61049 .26371 L

.61605 .26412 L

.62601 .26516 L

.63547 .26651 L

.64562 .26834 L

.66395 .27256 L

.70528 .28533 L

.74509 .29898 L

.76329 .30463 L

.78339 .3099 L

.80314 .31383 L

.81397 .31539 L

.81882 .31594 L

.82414 .31646 L

.82888 .31683 L

.83395 .31714 L

.83676 .31727 L

.83931 .31736 L

.84187 .31744 L

.84303 .31746 L

.8443 .31749 L

.84545 .31751 L

.84654 .31752 L

Mistroke

.84768 .31753 L

.84891 .31753 L

.85005 .31753 L

.85114 .31753 L

.85211 .31752 L

.85317 .31751 L

.85444 .3175 L

.85559 .31748 L

.85816 .31742 L

.86055 .31736 L

.86279 .31728 L

.86745 .31708 L

.87257 .3168 L

.88289 .31607 L

.90136 .31438 L

.92253 .31223 L

.93176 .31134 L

.94181 .31048 L

.95098 .30984 L

.95502 .30961 L

.95947 .30939 L

.96365 .30923 L

.96758 .30912 L

.96974 .30908 L

.97172 .30905 L

.97276 .30903 L

.9739 .30903 L

.97509 .30902 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.53261 .5099 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4gdC00<04a<0oa<64`00oa=m4`0301<C0?lC1Q<002TC1@3o4dlC0P3o4`LC

000[4`0301<C0?lCCa<00`0C4`1^4`d0RQ<002DC0`034`0301<C00@C0P3o4dTC00<04a<0IQ<800`C

3@1n4`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`1Q4`D081<807LC000[4`0301<C00@C00<04a<0

oa=84`0301<C05hC100/4`L0L1<002XC0P064`0301<C0?lCB1<00`0C4`1L4`<0=A<706XC000b4`03

01<C0?lCB1<205/C0P0o4`H0I1<0038C00<04a<0oa=84`0301<C05PC0P164`H0Ga<0038C00<04a<0

oa=84`0301<C05HC0P1>4`D0FQ<0038C00<04a<0oa=84`0301<C05DC0P1C4`D0EQ<0038C00<04a<0

oa=84`0301<C05@C00<04a<0Ea<5058C000b4`0301<C0?lCB1<205<C0P1N4`<0D1<0038C00<04a<0

oa=84`0301<C00lC5P0/4`80HA<404dC000b4`0301<C0?lCB1<00`0C4`0:4`D05Q<9028C0P1U4`<0

Ba<0038C00<04a<0oa=84`0301<C00DC1@0S4`L06a<206PC0`194`00<Q<00`0C4`3o4c/C1@024`03

01<C00<C00<04a<00a<202lC1P0D4`80Ja<204PC000b4`0301<C0?lC?A<01`0C4a<04`0011<00`0C

4`0303HC1P0>4`80KA<304HC000b4`0301<C0?lC=a<300<C00L04a<C01<000@C0`0n4`H02A<00`0C

4`1^4`80AA<0038C00<04a<0oa<m4`0701<C4`0C00034`80AA<500@C00<04a<0L1<204@C000L4`03

01<C008C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0oa<m4`0701<C4`0C00024`0301<004XC

1@1d4`80@Q<001/C00<04`0021<01`0C4a<04`001A<00`0C4`3o4c`C0P044`0401<0008C00<04a<0

Ba<6074C0P114`005Q<3008C00<04`0021<00`0C4`034`0301<C00<C0P3o4d<C0P044`0301<C04XC

00<04a<011<406hC0P104`006a<00`0C00094`0301<C00801Q<00`0C4`3o4d4C00<04a<011<00`0C

4`194`0301<C00TC101[4`0301<C03hC000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C0?lC

@1<00`0C4`054`80BQ<00`0C4`0=4`@0J1<203hC000L4`0301<C00HC0`024`<01A<00`0C4`3o4clC

00<04a<01Q<00`0C4`184`0301<C018C101U4`0301<C03`C000b4`0301<C0?lC?Q<00`0C4`074`03

01<C04PC00<04a<05A<5068C00<04a<0>a<0038C00<04a<0oa<m4`0301<C00PC00<04a<0Aa<00`0C

4`0J4`@0Ga<203`C000b4`0301<C0?lC?1<00`0C4`094`0301<C04HC00<04a<07a<405`C0P0k4`00

<Q<00`0C4`3o4c/C00<04a<02Q<00`0C4`164`0301<C028C1@1I4`0301<C03TC000b4`0301<C0?lC

>Q<00`0C4`0;4`80Aa<00`0C4`0V4`@0Ea<00`0C4`0h4`00<Q<00`0C4`3o4cTC00<04a<031<00`0C

4`154`0301<C02XC101D4`80>A<0038C3@go4blC00<04a<031<00`0C4`154`0301<C02hC101A4`03

01<C03LC000b4`0301<C00XC10go4bXC00<04a<03A<00`0C4`144`0301<C03<C0P1?4`80>1<0038C

00<04a<03Q<53OlC91<00`0C4`0>4`0301<C04@C00<04a<0=A<404`C0P0g4`00<Q<00`0C4`0C4`@=

oa<O4`0301<C00lC00<04a<0A1<00`0C4`0i4`80Ba<00`0C4`0e4`00<Q<00`0C4`0G4`8=oa<M4`03

01<C00lC0P144`0301<C03`C10174`80=Q<0038C00<04a<06A<33OlC6A<00`0C4`0@4`0301<C04<C

00<04a<0?a<304HC00<04a<0=1<0038C00<04a<071<23OlC5a<00`0C4`0@4`0301<C04<C00<04a<0

@Q<304<C0P0e4`008A<00`0C4`024`0301<C008C00<04a<011<00`0C4`0N4`<=oa<C4`0301<C014C

00<04a<0@Q<00`0C4`164`<0@A<00`0C4`0c4`0081<00`0C00074`0301<000DC00<04a<08A<23OlC

4A<00`0C4`0A4`0301<C048C00<04a<0BA<203lC00<04a<0<a<001/C0`024`0301<000TC00<04a<0

0a<202@C0Pgo4`hC00<04a<04Q<00`0C4`124`0301<C04/C0`0m4`0301<C038C000P4`0301<000LC

0P064`0301<C02DC0Pgo4``C00<04a<04Q<204<C00<04a<0CQ<203/C00<04a<0<Q<0020C00<04`00

1a<00`0C4`054`0301<C02LC0Pgo4`TC00<04a<04a<00`0C4`114`0301<C054C0`0h4`0301<C038C

000Q4`0301<C00HC0`054`0301<C02TC0Pgo4`LC00<04a<04a<00`0C4`114`0301<C05@C0P0g4`03

01<C034C000b4`0301<C02/C0Pgo4`@C00<04a<051<00`0C4`114`0301<C05HC0`0d4`0301<C034C

000b4`0301<C02dC0Pgo4`8C00<04a<03Q<00`0C4`034`0301<C040C00<04a<0FA<3038C0P0b4`00

<Q<00`0C4`0_4`8=oQ<00`0C4`0>4`0301<000@C00<04a<0@1<00`0C4`1L4`80<A<00`0C4`0`4`00

<Q<00`0C4`0a4`8=o1<00`0C4`094`<011<00`0C4`024`<0@1<00`0C4`1N4`80;a<00`0C4`0`4`00

<Q<00`0C4`0c4`033A<C0?TC00<04a<03Q<200DC00<04a<0?a<00`0C4`1Q4`<0;1<00`0C4`0`4`00

<Q<00`0C4`0d4`8=nA<00`0C4`0>4`0301<C00@C00<04a<0?a<00`0C4`1T4`0301<C02TC00<04a<0

<1<0038C00<04a<0=Q<23OHC00<04a<03a<300@C00<04a<0?a<00`0C4`1U4`<0:1<2034C000b4`03

01<C03PC00<=4a<0la<00`0C4`0F4`0301<C03lC00<04a<0J1<00`0C4`0V4`0301<C02lC000b4`03

01<C03TC0Pgc4`0301<C01HC00<04a<0?a<00`0C4`1Y4`<09A<00`0C4`0_4`00<Q<00`0C4`0k4`8=

lA<00`0C4`0F4`80@1<00`0C4`1/4`808a<00`0C4`0_4`00<Q<00`0C4`0m4`033A<C0>hC00<04a<0

5Q<00`0C4`0o4`0301<C06dC0P0R4`0301<C02lC000b4`0301<C03hC0Pg^4`0301<C01HC00<04a<0

?a<00`0C4`1_4`8081<00`0C4`0_4`00<Q<00`0C4`104`8=ja<00`0C4`0G4`0301<C03hC00<04a<0

LQ<201hC00<04a<0;a<001`C00<04a<00Q<0100C4a<300<C00<04a<011<00`0C4`124`033A<C0>PC

00<04a<05a<00`0C4`0n4`0301<C07@C0P0L4`0301<C02lC000K4`0301<000LC00<04a<00Q<00`0C

00054`0301<C04<C0PgX4`0301<C01LC0P0o4`0301<C07HC0P0J4`0301<C02lC000F4`<00Q<00`0C

00084`0301<C00<C00<04a<00a<204HC0PgV4`0301<C01LC00<04a<0?Q<00`0C4`1h4`0301<C01HC

00<04a<0<1<001/C00<04`0021<0100C4a<200HC00<04a<0Aa<00`dC4`3R4`0301<C01PC00<04a<0

?Q<00`0C4`1i4`805Q<00`0C4`0`4`006a<00`0C00074`0301<0008C00<04a<01A<00`0C4`184`8=

hQ<00`0C4`0H4`0301<C03hC00<04a<0Na<00`0C4`0C4`0301<C030C000L4`0301<C00LC00@04a<C

0`054`0301<C04XC0PgP4`0301<C01PC00<04a<0?Q<00`0C4`1l4`0301<C018C00<04a<0<1<0038C

00<04a<0C1<23MhC00<04a<061<00`0C4`0m4`0301<C07hC0P0B4`0301<C030C000b4`0301<C04hC

0PgL4`0301<C01PC0P0n4`0301<C080C0P0@4`0301<C030C000b4`0301<C050C0`gI4`0301<C01PC

00<04a<08A<5008C00<04a<04Q<00`0C4`0;4`D000<C00008A<5008C00<04a<07a<5008C00<04a<0

6a<0100C4a<500034`0000<C00<04a<0<A<0038C00<04a<0Da<23MLC00<04a<061<00`0C4`0S4`07

01<C4`0C000C4`0301<C00dC00L04a<C01<0028C00<04a<00Q<00`0C4`0Q4`0701<C4`0C000L4`80

11<00`0C4`034`0401<C03<C000b4`0301<C02HC00<04a<00Q<0100C4a<302<C0Pd34`0301<C008C

0`0P4`h=8a<00`0C4`024`0301<C008C00<04a<09Q<5044C00<04a<061<00`0C4`0S4`0301<C00<C

00<04a<04A<00`0C4`0=4`0701<C4`0C000R4`0301<C008C00<04a<08A<01`0C4a<04`007Q<01@0C

4a<000@C0P024`0301<C034C000b4`0301<C02DC00<04`001a<00`0C4`0R4`0301<000<=1Q<00`0C

4`0I4`H=00@C01<01a<00`0C00093ATC00<04`001a<00`0C000Y4`0301<C044C00<04a<061<00`0C

4`0S4`0401<C4`8051<00`0C4`0=4`0401<C4`808a<00`0C4`034`0301<C020C00<04a<00Q<00`0C

4`0N4`8000<C01<00Q<00`0C00024`0301<C034C000b4`0301<C02DC00<04`0021<00`0C4`0Q4`03

01<000<C1@d3010C2Pd74`0301<000LC00<04`002A<43ADC00<04`001a<00`0C000Y4`0301<C040C

00<04a<06A<00`0C4`0S4`0501<C4`005A<00`0C4`0=4`0501<C4`0091<01`0C4a<04`008Q<01`0C

4a<04`008A<200<C00D04`0C000d4`00<Q<00`0C4`0U4`0301<000PC00<04a<08A<00`0C00074`03

00d=014=4A<00`0C00074`803Q<23A<C00<04`0021<00`0C4`0X4`0301<C040C00<04a<06A<202<C

0P034`<04a<00`0C4`0<4`8011<2024C0P034`<08A<200@C00<04a<081<200@C0P000a<04`0c4`00

<Q<00`0C4`0U4`0301<000LC00<04`008Q<00`0C00084`808Q<00`0C00074`0301<C00lC0`d@4`03

01<000LC00<04`00:A<00`0C4`104`0301<C01TC00<04a<0?A<00`0C4`284`0301<C00DC00<04a<0

<Q<0038C00<04a<09Q<00`0C4`074`0301<C028C00<04a<021<00`0C4`0Q4`0301<C00LC0P0B4`8=

3a<00`0C4`074`0301<C02LC0P124`0301<C01TC00<04a<0?A<00`0C4`294`801A<00`0C4`0b4`00

<Q<00`0C4`2T4`<=Q1<00`0C4`0I4`0301<C03dC00<04a<0Ra<01@0C4a<003DC000b4`0301<C0:LC

0`f14`0301<C01TC00<04a<0?A<00`0C4`2;4`0401<C01<C100O4`00<Q<00`0C4`2Z4`@=OA<00`0C

4`0I4`0301<C03dC00<04a<0S1<201@C0`0P4`00<Q<00`0C4`2^4`<=AQ<302/Co`0:4`0301<C01hC

000b4`0301<C0;4C10e34`0301<C02/C00<04a<00Q<0100C4`084`0301<C00DC00<04a<01A<00`0C

4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00<C

00<04`001a<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C

4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC

00<04a<01A<00`0C4`054`<01Q<00`0C4`0<4`8081<002`C_P023Bl00`d600TC00<04a<0<1<00`0C

4`0I4`0301<C02HC00<04a<051<00`0C4`0@4`0301<C02HC00<04a<09Q<00`0C4`0V4`0401<C03HC

000b4`0301<C00PC00<04a<02A<00`0C4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC

00<04a<02A<00`0C4`084`0301<C00TC00<04a<02A<00`0C4`094`0301<C00TC00<04a<021<00`0C

4`094`0301<C00LC10d:4`0301<C00PC00<04a<01Q<=3@8C00<04a<031<4030C00<04a<06A<00`0C

4`0m4`0301<C08/C00D04a<C000e4`00<Q<00`0C4`0/4`0301<C02`C00<04a<0;1<00`0C4`0/4`03

01<=00X=1a<<3@lC00<04a<0@1<00`0C4`0I4`0301<C03dC00<04a<0RQ<00`0C4`024`0301<C03<C

000b4`0301<C0<HC1`eN4`0301<C01TC00<04a<0?A<00`0C4`294`0301<C00@C00<04a<0<Q<0038C

00<04a<0oa</4`0301<C01TC0P0n4`0301<C08LC0P074`0301<C038C000b4`0301<C0?lC;1<00`0C

4`0I4`0301<C03dC00<04a<0Qa<00`0C4`064`0301<C038C000b4`0301<C0?lC;A<00`0C4`0H4`03

01<C03dC00<04a<0QQ<00`0C4`084`0301<C034C000b4`0301<C0?lC;A<00`0C4`0H4`0301<C03dC

00<04a<0Q1<200/C00<04a<0<A<0038C00<04a<0oa<]4`0301<C01PC00<04a<0?A<00`0C4`234`03

01<C00/C00<04a<0<A<0038C00<04a<0oa<]4`0301<C01PC00<04a<0?A<00`0C4`224`0301<C00`C

00<04a<0<A<0038C00<04a<0oa<]4`0301<C01PC0P0n4`0301<C080C0P0?4`0301<C034C000b4`03

01<C0?lC;A<00`0C4`0H4`0301<C03dC00<04a<0Oa<00`0C4`0@4`0301<C030C000b4`0301<C0?lC

;A<00`0C4`0H4`0301<C03hC00<04a<0O1<201<C00<04a<0<1<0038C00<04a<0oa<]4`0301<C01PC

00<04a<0?Q<00`0C4`1k4`8051<00`0C4`0`4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`03

01<C07TC0P0F4`0301<C030C000b4`0301<C0?lC;A<00`0C4`0H4`0301<C03hC00<04a<0N1<00`0C

4`0F4`0301<C030C000b4`0301<C0?lC;Q<00`0C4`0G4`80?a<00`0C4`1f4`806A<00`0C4`0`4`00

<Q<00`0C4`3o4bhC00<04a<05a<00`0C4`0n4`0301<C07@C0P0L4`0301<C02lC000L4`0301<C008C

00@04a<C0`034`0301<C00@C00<04a<0oa<^4`0301<C01LC00<04a<0?Q<00`0C4`1c4`0301<C01`C

00<04a<0;a<001/C00<04`001a<00`0C4`024`0301<000DC00<04a<0oa<^4`0301<C01LC00<04a<0

?a<00`0C4`1`4`807a<00`0C4`0_4`006a<00`0C00084`0301<C00<C00<04a<00a<20?lC<1<00`0C

4`0F4`0301<C03lC00<04a<0KA<3024C00<04a<0;a<001/C00<04`0021<0100C4a<200HC00<04a<0

oa<_4`0301<C01HC00<04a<0?a<00`0C4`1/4`808a<00`0C4`0_4`006a<00`0C00074`0301<0008C

00<04a<01A<00`0C4`3o4blC00<04a<05Q<2040C00<04a<0JQ<202DC00<04a<0;a<001`C00<04a<0

1a<0100C4a<300DC00<04a<0oa<_4`0301<C01HC00<04a<0?a<00`0C4`1X4`809a<00`0C4`0_4`00

<Q<00`0C4`3o4blC00<04a<05Q<00`0C4`0o4`0301<C06HC0P0Y4`0301<C02lC000b4`0301<C0?lC

<1<00`0C4`0E4`0301<C03lC00<04a<0I1<202XC00<04a<0<1<0038C00<04a<0oa<`4`0301<C00lC

00<04a<00a<00`0C4`0o4`0301<C068C0P0/4`0301<C030C000b4`0301<C0?lC<1<00`0C4`0>4`03

01<000@C00<04a<0@1<00`0C4`1N4`<0;Q<00`0C4`0`4`00<Q<00`0C4`3o4c0C00<04a<041<00`0C

4`024`<0@1<00`0C4`1L4`<0<1<00`0C4`0`4`00<Q<00`0C4`3o4c4C00<04a<03A<200DC00<04a<0

@1<00`0C4`1J4`80<Q<2038C000b4`0301<C0?lC<A<00`0C4`0=4`0301<C00@C00<04a<0@A<00`0C

4`1G4`80=1<00`0C4`0a4`00<Q<00`0C4`3o4c8C00<04a<031<300@C00<04a<0@A<00`0C4`1D4`<0

=Q<00`0C4`0a4`00<Q<00`0C4`3o4c8C00<04a<04a<00`0C4`114`0301<C058C0`0g4`80<a<0038C

00<04a<0oa<c4`0301<C018C0P124`0301<C04lC0`0j4`0301<C038C000b4`0301<C0?lC<a<00`0C

4`0B4`0301<C048C00<04a<0C1<303`C00<04a<0<Q<0038C00<04a<0oa<d4`0301<C014C00<04a<0

@Q<00`0C4`194`<0?Q<00`0C4`0c4`00<Q<00`0C4`3o4c@C00<04a<04A<00`0C4`124`0301<C04LC

0`104`0301<C03<C000Q4`0301<C008C00<04a<00Q<00`0C4`044`0301<C0?lC=A<00`0C4`0@4`03

01<C048C00<04a<0A1<3048C0P0e4`0081<00`0C00074`0301<000DC00<04a<0oa<e4`0301<C010C

00<04a<0@a<00`0C4`104`<0AA<00`0C4`0d4`0081<00`0C00094`0301<C00<C0P3o4cLC00<04a<0

3a<204@C00<04a<0?A<304LC0P0f4`0081<00`0C00074`801Q<00`0C4`3o4cHC00<04a<03a<00`0C

4`144`0301<C03TC0`1:4`0301<C03DC000P4`0301<000LC00<04a<01A<00`0C4`3o4cLC00<04a<0

3Q<00`0C4`144`0301<C03HC101;4`80=a<0024C00<04a<01Q<300DC00<04a<0oa<h4`0301<C00dC

00<04a<0A1<00`0C4`0c4`<0Ca<00`0C4`0f4`00<Q<00`0C4`3o4cTC00<04a<031<00`0C4`154`03

01<C02lC0`1A4`0301<C03LC000b4`0301<C0?lC>A<00`0C4`0<4`0301<C04DC00<04a<0:a<405<C

0P0i4`00<Q<00`0C4`3o4cXC00<04a<02a<204LC00<04a<061<00`dC4`0<4`@0EQ<00`0C4`0h4`00

<Q<00`0C4`3o4cXC00<04a<02a<00`0C4`164`0301<C01DC1Pd84`D0F1<203XC000b4`0301<C0?lC

>a<200/C00<04a<0AQ<00`0C4`0D4`T=0a<405/C0P0k4`00<Q<00`0C4`3o4cdC00<04a<021<00`0C

4`174`0301<C01<C2@d305lC00<04a<0>Q<0038C00<04a<0oa<n4`0301<C00LC00<04a<0Aa<201@C

2@eQ4`0301<C03/C000b4`0301<C0?lC?Q<00`0C4`074`0301<C04PC00<04a<04A<;3ElC0P0m4`00

<Q<00`0C4`3o4clC00<04a<01Q<204XC00<04a<03Q<300T=Ga<203hC000b4`0301<C0?lC@1<200HC

00<04a<0BA<00`0C4`0:4`@00a<93EhC0P0o4`00<Q<00`0C4`3o4d8C00<04a<00a<00`0C4`1:4`03

01<C00DC1@064`T=GA<2040C000b4`0301<C0?lC@a<200<C00<04a<0BQ<200034`0000<031<63EhC

0P114`00<Q<00`0C4`3o4c/C1@024`0401<C008C00<04a<0BA<501<C00<=4a<0GA<2048C000L4`03

01<C008C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0oa<m4`0701<C4`0C00024`<0Aa<5008C

00<04a<0LA<204<C000K4`0301<000PC00L04a<C01<000DC00<04a<0oa<m4`0701<C4`0C00044`<0

@1<500PC00<04a<0KQ<204DC000K4`0301<000PC00<04a<00a<00`0C4`034`80oa<n4`0701<C4`0C

00044`0401<003XC1@0=4`0301<C06dC0P164`006a<00`0C00094`0301<C00801Q<00`0C4`3o4cdC

00L04a<C01<000@C00@04a<C0`0a4`H04a<206/C0`174`006a<00`0C00074`0301<0008C00<04a<0

1A<00`0C4`3o4c`C0P044`0301<C00<C00<04a<011<302PC1`0I4`80JA<204TC000L4`0301<C00HC

0`024`<01A<00`0C4`3o4dPC00<04a<01a<501/C2@0P4`0301<C06@C0`1;4`00<Q<00`0C4`3o4dPC

00<04a<031<L02TC0P1R4`<0CA<0038C00<04a<0oa=84`80Da<205lC0`1?4`00<Q<00`0C4`3o4dPC

00<04a<0Da<205XC101B4`00<Q<00`0C4`3o4dPC00<04a<0E1<205HC101E4`00<Q<00`0C4`3o4dPC

00<04a<0EQ<204lC1@1I4`00<Q<00`0C4`3o4dPC00<04a<0Ea<304PC1P1M4`00<Q<00`0C4`3o4dPC

00<04a<0FA<3040C1`1R4`00<Q<00`0C4`3o4dPC0P1L4`<0>1<706PC000b4`0301<C0?lCB1<00`0C

4`1N4`<0;Q<806hC000b4`0301<C0?lCB1<00`0C4`1P4`D08a<807DC000b4`0301<C0?lCB1<00`0C

4`1T4`L051<:07`C000b4`0301<C0?lCB1<00`0C4`1Z4aD0QQ<0038C00<04a<0oa=84`0301<C0?lC

1Q<002TC1@044`0301<C0?lCB1<20?lC1a<002/C00<04a<011<00`0C4`3o4dPC00<04a<0oa<64`00

:a<00`0C4`044`80oa=94`0301<C0?lC1Q<002/C00<04a<0oa?o4ePC000[4`0301<C0?lCoa=H4`00

:Q<20?lCoa=J4`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<0074C10000a<0

000700034`0000@C00<04a<00Q<3008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C

4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C

00<04a<00Q<00`0C4`050?lC[1<0074C0`084`0701<C4`0C00094`0601<C01<00Q<00`0C00024`03

01<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0Q<00`0C00024`0301<0008C00<04`000Q<00`0C00034`0301<C0:4C0P3o4`TC001c4`0301<C00@0

0Q<01`0C4a<04`001a<400<C00H04a<04`024`0301<0008C00<04`000Q<00`0C00024`0301<0008C

00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C

00034`0301<C0:8C00<04a<0oa<74`006A<400034`0000H00Q<:008C0P024`<00Q<300<C0P001Q<0

000C02LC0P084`0401<C4`8021<00`0C00024`800a<00`0C00024`0301<0008C00<04`000Q<00`0C

00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C

00<04`000Q<00`0C00034`0301<C0:0C0`024`0301<C0?lC11<001XC00H04a<04`024`0301<000@C

00H04a<04`024`0301<000DC00<04a<00Q<01@0C4a<0008C00@04`0C0P0a4`0501<C4`002Q<2008C

00<04a<00Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C

00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00034`0301<C00<C

00<04a<0VA<0200C4`0C01<0oa<54`006Q<01P0C4`0C00@C00<04a<00Q<00`0C4`024`0301<C008C

00<04a<00a<00`0C4`024`0501<C4`000Q<0100C01<2030C0P044`802A<00`0C4`0300<C00<04a<0

0Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`03

01<C008C00<04a<00Q<00`0C4`024`0301<C008C00@04a<C0P044`0301<C09XC00P04a<04`0C0?lC

1A<001XC00D04a<04`0200<C0P034`0301<C008C0P034`0301<C00<C00<04a<00Q<01@0C4a<0008C

00H04`004`3o4blC0`0011<04`3o4`DC000J4`0601<C01<00Q<00`0C00024`0301<000@C00h04a<0

4`0C01<04`0C008C00D04a<C00024`0601<001<0oa<c4`0301<00?lC1A<001TC10000a<0000;008C

1@001A<0000C00D000@C00000a<200044`004`80oa<d4`0301<C0?lC11<00?lCoa>64`00oa?o4hHC

003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00001

\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.77084, -14.119, 0.0242408, 0.16996}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -57 0 ]

[.5 .63053 57 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -118 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(17.0399999999999884`) show

173.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .08997 m

.02499 .08997 L

.02606 .08998 L

.02729 .08998 L

.02846 .09 L

.03053 .09003 L

.03279 .09007 L

.03527 .09014 L

.0379 .09022 L

.04262 .09042 L

.04749 .09068 L

.05205 .09099 L

.06245 .09188 L

.07305 .09307 L

.08274 .09443 L

.10458 .09839 L

.12357 .10289 L

.14429 .10895 L

.18493 .12437 L

.22406 .14353 L

.26565 .16781 L

.30571 .19349 L

.34426 .21796 L

.38527 .24061 L

.40569 .2496 L

.42475 .25626 L

.44308 .26096 L

.45336 .26285 L

.46273 .26413 L

.46753 .26462 L

.47264 .26503 L

.477 .26529 L

.47948 .2654 L

.48181 .26548 L

.48313 .26551 L

.48435 .26554 L

.48563 .26556 L

.4863 .26557 L

.48702 .26558 L

.48831 .26559 L

.48953 .26559 L

.49062 .26559 L

.4918 .26558 L

.4931 .26556 L

.49383 .26555 L

.49452 .26554 L

.4974 .26548 L

.4999 .2654 L

.50257 .26529 L

.50783 .26502 L

Mistroke

.5127 .26471 L

.52375 .2638 L

.54385 .26171 L

.56268 .25967 L

.57258 .25873 L

.58303 .25792 L

.58836 .2576 L

.59119 .25747 L

.59421 .25735 L

.59699 .25726 L

.59953 .2572 L

.60075 .25718 L

.60139 .25717 L

.60207 .25716 L

.60332 .25715 L

.60448 .25714 L

.60573 .25714 L

.60687 .25714 L

.60812 .25715 L

.60944 .25717 L

.61059 .25718 L

.61166 .25721 L

.61408 .25727 L

.61677 .25736 L

.6192 .25748 L

.62466 .25781 L

.62953 .2582 L

.63467 .25872 L

.64389 .25991 L

.6538 .26158 L

.6647 .26386 L

.70509 .27571 L

.74397 .28988 L

.76375 .29693 L

.7853 .30374 L

.80597 .30899 L

.81584 .31096 L

.82511 .31248 L

.83408 .31363 L

.83869 .3141 L

.84375 .31452 L

.84898 .31486 L

.85164 .315 L

.85449 .31511 L

.85716 .3152 L

.85959 .31525 L

.86076 .31527 L

.86203 .31529 L

.86323 .3153 L

.86434 .31531 L

Mistroke

.86559 .31531 L

.86678 .31531 L

.86784 .31531 L

.86901 .3153 L

.87027 .31528 L

.87161 .31526 L

.87402 .31521 L

.87647 .31515 L

.87877 .31507 L

.88308 .3149 L

.893 .31435 L

.90371 .31357 L

.92327 .31192 L

.93364 .31104 L

.94474 .31021 L

.95325 .30968 L

.96101 .30932 L

.96474 .30919 L

.96671 .30914 L

.96881 .30909 L

.97063 .30906 L

.9716 .30905 L

.97264 .30903 L

.9736 .30903 L

.97447 .30902 L

.97531 .30902 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.62834 .48214 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4gdC00<04a<0oa<64`00oa=m4`0301<C0?lC1Q<002TC1@3o4dlC0P3o4`LC

000[4`0301<C0?lCCa<00`0C4`1^4`d0RQ<002DC0`034`0301<C00@C0P3o4dTC00<04a<0IQ<800`C

3@1n4`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`1Q4`D081<807LC000[4`0301<C00@C00<04a<0

oa=84`0301<C05hC100/4`L0L1<002XC0P064`0301<C0?lCB1<00`0C4`1L4`<0=A<706XC000b4`03

01<C0?lCB1<205/C0P0o4`H0I1<0038C00<04a<0oa=84`0301<C05PC0P164`H0Ga<0038C00<04a<0

oa=84`0301<C05HC0P1>4`D0FQ<0038C00<04a<0oa=84`0301<C05DC0P1C4`D0EQ<0038C00<04a<0

oa=84`0301<C05@C00<04a<0Ea<5058C000b4`0301<C0?lCB1<205<C0P1N4`<0D1<0038C00<04a<0

oa=84`0301<C00lC5P0/4`80HA<404dC000b4`0301<C0?lCB1<00`0C4`0:4`D05Q<9028C0P1U4`<0

Ba<0038C00<04a<0oa=84`0301<C00DC1@0S4`L06a<206PC0`194`00<Q<00`0C4`3o4c/C1@024`03

01<C00<C00<04a<00a<202lC1P0D4`80Ja<204PC000b4`0301<C0?lC?A<01`0C4a<04`0011<00`0C

4`0303HC1P0>4`80KA<304HC000b4`0301<C0?lC=a<300<C00L04a<C01<000@C0`0n4`H02A<00`0C

4`1^4`80AA<0038C00<04a<0oa<m4`0701<C4`0C00034`80AA<500@C00<04a<0L1<204@C000L4`03

01<C008C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0oa<m4`0701<C4`0C00024`0301<004XC

1@1d4`80@Q<001/C00<04`0021<01`0C4a<04`001A<00`0C4`3o4c`C0P044`0401<0008C00<04a<0

Ba<6074C0P114`005Q<3008C00<04`0021<00`0C4`034`0301<C00<C0P3o4d<C0P044`0301<C04XC

00<04a<011<406hC0P104`006a<00`0C00094`0301<C00801Q<00`0C4`3o4d4C00<04a<011<00`0C

4`194`0301<C00TC101[4`0301<C03hC000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C0?lC

@1<00`0C4`054`80BQ<00`0C4`0=4`@0J1<203hC000L4`0301<C00HC0`024`<01A<63OlC?1<00`0C

4`064`0301<C04PC00<04a<04Q<406DC00<04a<0?1<0038C00<04a<00a<;3OlC<1<00`0C4`074`03

01<C04PC00<04a<05A<5068C00<04a<0>a<0038C00<04a<03Q<43OlC:a<00`0C4`084`0301<C04LC

00<04a<06Q<405lC0P0l4`00<Q<00`0C4`0B4`8=oa<X4`0301<C00TC00<04a<0AQ<00`0C4`0O4`@0

G1<203/C000b4`0301<C01@C10go4b<C00<04a<02Q<00`0C4`164`0301<C028C1@1I4`0301<C03TC

000b4`0301<C01PC10go4ahC00<04a<02a<204LC00<04a<09Q<405LC00<04a<0>1<0038C00<04a<0

71<23OlC6a<00`0C4`0<4`0301<C04DC00<04a<0:Q<405@C0P0i4`00<Q<00`0C4`0N4`<=oa<H4`03

01<C00`C00<04a<0AA<00`0C4`0^4`@0DA<00`0C4`0g4`00<Q<00`0C4`0Q4`8=oa<E4`0301<C00dC

00<04a<0A1<00`0C4`0c4`80Ca<203PC000b4`0301<C02<C0Pgo4a8C00<04a<03Q<00`0C4`144`03

01<C03DC101<4`80=a<0038C00<04a<09A<23OlC3a<00`0C4`0?4`0301<C04@C00<04a<0>A<204/C

00<04a<0=A<0038C00<04a<09a<23OlC3A<00`0C4`0?4`80A1<00`0C4`0l4`@0Aa<203HC000b4`03

01<C02TC0Pgo4`XC00<04a<041<00`0C4`134`0301<C03lC0`164`0301<C03@C000b4`0301<C02/C

0Pgo4`PC00<04a<041<00`0C4`134`0301<C048C0`134`80=A<0024C00<04a<00Q<00`0C4`024`03

01<C00@C00<04a<0;A<23OlC1A<00`0C4`0A4`0301<C048C00<04a<0AQ<3044C00<04a<0<a<0020C

00<04`001a<00`0C00054`0301<C02lC0Pgo4`<C00<04a<04A<00`0C4`124`0301<C04TC0P0o4`03

01<C03<C000K4`<00Q<00`0C00094`0301<C00<C0P0b4`8=oa<00`0C4`0B4`0301<C048C00<04a<0

Ba<303dC00<04a<0<Q<0020C00<04`001a<200HC00<04a<0<a<00`dC4`3l4`0301<C018C0P134`03

01<C04hC0P0k4`0301<C038C000P4`0301<000LC00<04a<01A<00`0C4`0d4`8=na<00`0C4`0C4`03

01<C044C00<04a<0DA<303PC00<04a<0<Q<0024C00<04a<01Q<300DC00<04a<0=Q<23OTC00<04a<0

4a<00`0C4`114`0301<C05@C0P0g4`0301<C034C000b4`0301<C03PC00<=4a<0mA<00`0C4`0D4`03

01<C044C00<04a<0EQ<303@C00<04a<0<A<0038C00<04a<0>A<23ODC00<04a<03Q<00`0C4`034`03

01<C040C00<04a<0FA<3038C0P0b4`00<Q<00`0C4`0k4`8=lQ<00`0C4`0>4`0301<000@C00<04a<0

@1<00`0C4`1L4`80<A<00`0C4`0`4`00<Q<00`0C4`0m4`033A<C0>lC00<04a<02A<300@C00<04a<0

0Q<3040C00<04a<0GQ<202lC00<04a<0<1<0038C00<04a<0?Q<23NlC00<04a<03Q<200DC00<04a<0

?a<00`0C4`1Q4`<0;1<00`0C4`0`4`00<Q<00`0C4`104`8=kA<00`0C4`0>4`0301<C00@C00<04a<0

?a<00`0C4`1T4`0301<C02TC00<04a<0<1<0038C00<04a<0@Q<00`dC4`3Y4`0301<C00lC0`044`03

01<C03lC00<04a<0IA<302PC0P0a4`00<Q<00`0C4`134`8=jA<00`0C4`0F4`0301<C03lC00<04a<0

J1<00`0C4`0V4`0301<C02lC000b4`0301<C04DC0PgW4`0301<C01HC00<04a<0?a<00`0C4`1Y4`<0

9A<00`0C4`0_4`00<Q<00`0C4`174`033A<C0>@C00<04a<05Q<2040C00<04a<0K1<202<C00<04a<0

;a<0038C00<04a<0B1<23N@C00<04a<05Q<00`0C4`0o4`0301<C06dC0P0R4`0301<C02lC000b4`03

01<C04XC0PgR4`0301<C01HC00<04a<0?a<00`0C4`1_4`8081<00`0C4`0_4`00<Q<00`0C4`1<4`03

3A<C0=hC00<04a<05a<00`0C4`0n4`0301<C078C0P0N4`0301<C02lC000L4`0301<C008C00@04a<C

0`034`0301<C00@C00<04a<0CA<23MhC00<04a<05a<00`0C4`0n4`0301<C07@C0P0L4`0301<C02lC

000K4`0301<000LC00<04a<00Q<00`0C00054`0301<C04lC0PgL4`0301<C01LC0P0o4`0301<C07HC

0P0J4`0301<C02lC000F4`<00Q<00`0C00084`0301<C00<C00<04a<00a<2058C00<=4a<0fA<00`0C

4`0G4`0301<C03hC00<04a<0N1<00`0C4`0F4`0301<C030C000K4`0301<000PC00@04a<C0P064`03

01<C058C0PgH4`0301<C01PC00<04a<0?Q<00`0C4`1i4`805Q<00`0C4`0`4`006a<00`0C00074`03

01<0008C00<04a<01A<00`0C4`1D4`8=eQ<00`0C4`0H4`0301<C03hC00<04a<0Na<00`0C4`0C4`03

01<C030C000L4`0301<C00LC00@04a<C0`054`0301<C05HC0PgD4`0301<C01PC00<04a<0?Q<00`0C

4`1l4`0301<C018C00<04a<0<1<0038C00<04a<0F1<23M8C00<04a<061<00`0C4`0m4`0301<C07hC

0P0B4`0301<C030C000b4`0301<C05XC10g>4`0301<C01PC0P0n4`0301<C080C0P0@4`0301<C030C

000b4`0301<C05hC0`g;4`0301<C01PC00<04a<08A<5008C00<04a<04Q<00`0C4`0;4`D000<C0000

8A<5008C00<04a<07a<5008C00<04a<06a<0100C4a<500034`0000<C00<04a<0<A<0038C00<04a<0

HA<23AdC5`fE4`0301<C01PC00<04a<08a<01`0C4a<04`004a<00`0C4`0=4`0701<C4`0C000R4`03

01<C008C00<04a<08A<01`0C4a<04`0071<200@C00<04a<00a<0100C4`0c4`00<Q<00`0C4`0V4`03

01<C008C00@04a<C0`0S4`0301<C008C00<04a<00Q<300034`d=00H=31<93@@C00<04a<00Q<0100C

4a<200PC1PdF4`0301<C008C00<04a<00Q<00`0C4`0V4`D0@A<00`0C4`0H4`0301<C02<C00<04a<0

0a<00`0C4`0A4`0301<C00dC00L04a<C01<0028C00<04a<00Q<00`0C4`0Q4`0701<C4`0C000N4`05

01<C4`0011<2008C00<04a<0<A<0038C00<04a<09A<00`0C00074`0301<C028C00<04`002A<00`0C

4`084``=31<00`0C00074`0301<000dC0`dB4`0301<000LC00<04`00:A<00`0C4`114`0301<C01PC

00<04a<08a<0100C4a<201@C00<04a<03A<0100C4a<202<C00<04a<00a<00`0C4`0P4`0301<C008C

00<04a<07Q<200034`0C008C00<04`000Q<00`0C4`0a4`00<Q<00`0C4`0U4`0301<000PC00<04a<0

8A<00`0C00074`@08A<00`0C00074`0301<0010C10d>4`0301<000LC00<04`00:A<00`0C4`104`03

01<C01TC00<04a<08a<01@0C4a<001DC00<04a<03A<01@0C4a<002@C00L04a<C01<0028C00L04a<C

01<0024C0P034`0501<04`00=1<0038C00<04a<09A<00`0C00084`0301<C024C00<04`001a<00`0C

000R4`0301<000LC0P0E4`<=2a<00`0C00084`0301<C02PC00<04a<0@1<00`0C4`0I4`808a<200<C

0`0C4`0301<C00`C0P044`808A<200<C0`0Q4`8011<00`0C4`0P4`8011<200034`0C03<C000b4`03

01<C02DC00<04`001a<00`0C000R4`0301<000PC0P0R4`0301<000LC00<04a<05a<23@TC00<04`00

1a<00`0C000Y4`0301<C040C00<04a<06A<00`0C4`0m4`0301<C08PC00<04a<01A<00`0C4`0b4`00

<Q<00`0C4`0V4`0301<C00LC00<04a<08Q<00`0C4`084`0301<C024C00<04a<01a<201TC0`d74`03

01<C00LC00<04a<09a<2048C00<04a<06A<00`0C4`0m4`0301<C08TC0P054`0301<C038C000b4`03

01<C0:`C0Pem4`0301<C01TC00<04a<0?A<00`0C4`2;4`0501<C4`00=A<0038C00<04a<0[Q<33GXC

00<04a<06A<00`0C4`0m4`0301<C08/C00@04a<04a<401lC000b4`0301<C0;4C10ef4`0301<C01TC

00<04a<0?A<00`0C4`2<4`8051<3020C000b4`0301<C0;DC0`do4`<0:a?o00XC00<04a<07Q<0038C

00<04a<0^1<43C`C00<04a<0:a<00`0C4`024`0401<C00PC00<04a<01A<00`0C4`054`0301<C00DC

00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<00a<00`0C

00074`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC

00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C

4`054`0301<C00DC0`064`0301<C00`C0P0P4`00;1?500<=9`033@H02A<00`0C4`0`4`0301<C01TC

00<04a<09Q<00`0C4`0D4`0301<C010C00<04a<09Q<00`0C4`0V4`0301<C02HC00@04a<0=Q<0038C

00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0C4`084`0301<C00TC00<04a<02A<00`0C

4`094`0301<C00PC00<04a<02A<00`0C4`094`0301<C00TC00<04a<02A<00`0C4`084`0301<C00TC

00<04a<02A<00`0C4`034`D=00<C01<02A<00`0C4`064`h=00<C01<03A<4030C00<04a<06A<00`0C

4`0m4`0301<C08/C00D04a<C000e4`00<Q<00`0C4`0/4`0301<C02`C00<04a<0;1<00`0C4`0/4`03

01<C00PC5@d?4`0301<C040C00<04a<06A<00`0C4`0m4`0301<C08XC00<04a<00Q<00`0C4`0c4`00

<Q<00`0C4`3o4b`C00<04a<06A<00`0C4`0m4`0301<C08TC00<04a<011<00`0C4`0b4`00<Q<00`0C

4`3o4b`C00<04a<06A<203hC00<04a<0Qa<200LC00<04a<0<Q<0038C00<04a<0oa</4`0301<C01TC

00<04a<0?A<00`0C4`274`0301<C00HC00<04a<0<Q<0038C00<04a<0oa<]4`0301<C01PC00<04a<0

?A<00`0C4`264`0301<C00PC00<04a<0<A<0038C00<04a<0oa<]4`0301<C01PC00<04a<0?A<00`0C

4`244`802a<00`0C4`0a4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0m4`0301<C08<C00<04a<0

2a<00`0C4`0a4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0m4`0301<C088C00<04a<031<00`0C

4`0a4`00<Q<00`0C4`3o4bdC00<04a<061<203hC00<04a<0P1<200lC00<04a<0<A<0038C00<04a<0

oa<]4`0301<C01PC00<04a<0?A<00`0C4`1o4`0301<C010C00<04a<0<1<0038C00<04a<0oa<]4`03

01<C01PC00<04a<0?Q<00`0C4`1l4`804a<00`0C4`0`4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C

4`0n4`0301<C07/C0P0D4`0301<C030C000b4`0301<C0?lC;A<00`0C4`0H4`0301<C03hC00<04a<0

NA<201HC00<04a<0<1<0038C00<04a<0oa<]4`0301<C01PC00<04a<0?Q<00`0C4`1h4`0301<C01HC

00<04a<0<1<0038C00<04a<0oa<^4`0301<C01LC0P0o4`0301<C07HC0P0I4`0301<C030C000b4`03

01<C0?lC;Q<00`0C4`0G4`0301<C03hC00<04a<0M1<201`C00<04a<0;a<001`C00<04a<00Q<0100C

4a<300<C00<04a<011<00`0C4`3o4bhC00<04a<05a<00`0C4`0n4`0301<C07<C00<04a<071<00`0C

4`0_4`006a<00`0C00074`0301<C008C00<04`001A<00`0C4`3o4bhC00<04a<05a<00`0C4`0o4`03

01<C070C0P0O4`0301<C02lC000K4`0301<000PC00<04a<00a<00`0C4`034`80oa<`4`0301<C01HC

00<04a<0?a<00`0C4`1]4`<08A<00`0C4`0_4`006a<00`0C00084`0401<C4`801Q<00`0C4`3o4blC

00<04a<05Q<00`0C4`0o4`0301<C06`C0P0S4`0301<C02lC000K4`0301<000LC00<04`000Q<00`0C

4`054`0301<C0?lC;a<00`0C4`0F4`80@1<00`0C4`1Z4`809A<00`0C4`0_4`0071<00`0C4`074`04

01<C4`<01A<00`0C4`3o4blC00<04a<05Q<00`0C4`0o4`0301<C06PC0P0W4`0301<C02lC000b4`03

01<C0?lC;a<00`0C4`0F4`0301<C03lC00<04a<0IQ<202TC00<04a<0;a<0038C00<04a<0oa<`4`03

01<C01DC00<04a<0?a<00`0C4`1T4`80:Q<00`0C4`0`4`00<Q<00`0C4`3o4c0C00<04a<03a<00`0C

4`034`0301<C03lC00<04a<0HQ<202`C00<04a<0<1<0038C00<04a<0oa<`4`0301<C00hC00<04`00

11<00`0C4`104`0301<C05hC0`0^4`0301<C030C000b4`0301<C0?lC<1<00`0C4`0@4`0301<C008C

0`104`0301<C05`C0`0`4`0301<C030C000b4`0301<C0?lC<A<00`0C4`0=4`801A<00`0C4`104`03

01<C05XC0P0b4`80<Q<0038C00<04a<0oa<a4`0301<C00dC00<04a<011<00`0C4`114`0301<C05LC

0P0d4`0301<C034C000b4`0301<C0?lC<Q<00`0C4`0<4`<011<00`0C4`114`0301<C05@C0`0f4`03

01<C034C000b4`0301<C0?lC<Q<00`0C4`0C4`0301<C044C00<04a<0DQ<303LC0P0c4`00<Q<00`0C

4`3o4c<C00<04a<04Q<2048C00<04a<0Ca<303XC00<04a<0<Q<0038C00<04a<0oa<c4`0301<C018C

00<04a<0@Q<00`0C4`1<4`<0?1<00`0C4`0b4`00<Q<00`0C4`3o4c@C00<04a<04A<00`0C4`124`03

01<C04TC0`0n4`0301<C03<C000b4`0301<C0?lC=1<00`0C4`0A4`0301<C048C00<04a<0Aa<3040C

00<04a<0<a<0024C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0oa<e4`0301<C010C00<04a<0

@Q<00`0C4`144`<0@Q<203DC000P4`0301<000LC00<04`001A<00`0C4`3o4cDC00<04a<041<00`0C

4`134`0301<C03@C00<=4a<02A<304DC00<04a<0=1<0020C00<04`002A<00`0C4`034`80oa<g4`03

01<C00lC0P144`0301<C034C1Pd64`<0Aa<203HC000P4`0301<000LC0P064`0301<C0?lC=Q<00`0C

4`0?4`0301<C04@C00<04a<0;a<93@044`0004XC00<04a<0=A<0020C00<04`001a<00`0C4`054`03

01<C0?lC=a<00`0C4`0>4`0301<C04@C00<04a<0;a<93@80Ba<203LC000Q4`0301<C00HC0`054`03

01<C0?lC>1<00`0C4`0=4`0301<C04@C00<04a<0;a<93DdC00<04a<0=Q<0038C00<04a<0oa<i4`03

01<C00`C00<04a<0AA<00`0C4`0]4`/=Ba<00`0C4`0g4`00<Q<00`0C4`3o4cTC00<04a<031<00`0C

4`154`0301<C02/C0`093D/C0P0i4`00<Q<00`0C4`3o4cXC00<04a<02a<204LC00<04a<09a<4008C

2@e;4`0301<C03PC000b4`0301<C0?lC>Q<00`0C4`0;4`0301<C04HC00<04a<08a<500DC2@e:4`80

>Q<0038C00<04a<0oa<k4`802a<00`0C4`164`0301<C020C100:4`H=Ba<203/C000b4`0301<C0?lC

?A<00`0C4`084`0301<C04LC00<04a<06a<4014C00<=4a<0Ba<00`0C4`0j4`00<Q<00`0C4`3o4chC

00<04a<01a<00`0C4`174`8061<5064C00<04a<0>a<0038C00<04a<0oa<n4`0301<C00LC00<04a<0

B1<00`0C4`0C4`@0I1<203dC000b4`0301<C0?lC?a<00`0C4`064`80BQ<00`0C4`0>4`@0Ia<203hC

000b4`0301<C0?lC@1<200HC00<04a<0BA<00`0C4`0:4`@0JQ<203lC000b4`0301<C0?lC@Q<00`0C

4`034`0301<C04XC00<04a<01A<506`C0P104`00<Q<00`0C4`3o4d<C0P034`0301<C04XC0P000a<0

0003070C0P114`00<Q<00`0C4`3o4c/C1@024`0401<C008C00<04a<0BA<507<C0P124`0071<00`0C

4`024`0301<C008C00<04a<00Q<00`0C4`044`0301<C0?lC?A<01`0C4a<04`000Q<304LC1@024`03

01<C074C0P134`006a<00`0C00084`0701<C4`0C00054`0301<C0?lC?A<01`0C4a<04`0011<3040C

1@084`0301<C06hC0P154`006a<00`0C00084`0301<C00<C00<04a<00a<20?lC?Q<01`0C4a<04`00

11<0100C000j4`D03A<00`0C4`1]4`80AQ<001/C00<04`002A<00`0C4`0200HC00<04a<0oa<m4`07

01<C4`0C00044`0401<C4`<0<A<601<C0P1[4`<0Aa<001/C00<04`001a<00`0C00024`0301<C00DC

00<04a<0oa<l4`8011<00`0C4`034`0301<C00@C0`0X4`L06A<206TC0P194`0071<00`0C4`064`<0

0Q<300DC00<04a<0oa=84`0301<C00LC1@0K4`T081<00`0C4`1T4`<0Ba<0038C00<04a<0oa=84`03

01<C00`C700Y4`80HQ<304dC000b4`0301<C0?lCB1<205<C0P1O4`<0Ca<0038C00<04a<0oa=84`03

01<C05<C0P1J4`@0DQ<0038C00<04a<0oa=84`0301<C05@C0P1F4`@0EA<0038C00<04a<0oa=84`03

01<C05HC0P1?4`D0FA<0038C00<04a<0oa=84`0301<C05LC0`184`H0GA<0038C00<04a<0oa=84`03

01<C05TC0`104`L0HQ<0038C00<04a<0oa=84`80G1<303PC1`1X4`00<Q<00`0C4`3o4dPC00<04a<0

GQ<302hC201^4`00<Q<00`0C4`3o4dPC00<04a<0H1<502<C201e4`00<Q<00`0C4`3o4dPC00<04a<0

I1<701@C2P1l4`00<Q<00`0C4`3o4dPC00<04a<0JQ<E08HC000b4`0301<C0?lCB1<00`0C4`3o4`HC

000Y4`D011<00`0C4`3o4dPC0P3o4`LC000[4`0301<C00@C00<04a<0oa=84`0301<C0?lC1Q<002/C

00<04a<011<20?lCBA<00`0C4`3o4`HC000[4`0301<C0?lCoa=H4`00:a<00`0C4`3o4olCF1<002XC

0P3o4olCFQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC001a4`@000<C0000

1`024`0301<C008C00<04a<00Q<0100C4a<200<C0P034`800a<200<C0P034`800a<200<C0P034`80

0a<200<C0P034`8011<00`0C4`024`0301<C008C0`3o4j`C001a4`<021<00`0C4`024`0301<C00HC

00<04`0011<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C

4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00H04a<04`024`0301<000@C00<04a<0

X1<20?lC2A<007<C00<04a<010024`0301<C008C00<04a<01Q<00`0C00034`0301<C008C0P034`80

0a<200<C0P034`800a<200<C0P034`800a<200<C0P034`800Q<00`0C00024`0301<0008C102R4`03

01<C0?lC1a<001TC10000a<00006008C2P024`800Q<3008C0`034`8000HC00004`0W4`8021<00`0C

4`034`0301<C00DC00<04`0011<01P0C4`0C008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000a<00`0C4`024`07

01<C4`0C002Q4`<00Q<00`0C4`3o4`@C000J4`0601<C01<00Q<00`0C00044`0601<C01<00Q<00`0C

00054`0301<C008C00D04a<C00024`0401<04`80<A<01`0C4a<04`001a<00`0C00024`0301<0008C

00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C

00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000a<200@C00<04a<0VA<0200C

4`0C01<0oa<54`006Q<01P0C4`0C00@C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00a<00`0C

4`024`0501<C4`000Q<0100C01<2030C0P034`<021<00`0C4`024`0301<C008C0P034`800a<200<C

0P034`800a<200<C0P034`800a<200<C0P034`800a<00`0C4`024`0301<C00<C00D04a<C002L4`08

01<C01<04`3o4`DC000J4`0501<C01<00P034`800a<00`0C4`024`800a<00`0C4`034`0301<C008C

00D04a<C00024`0601<001<0oa<_4`<000@C01<0oa<54`006Q<01P0C4`0C008C00<04`000Q<00`0C

00044`0>01<C01<04`0C01<04`024`0501<C4`000Q<01P0C000C0?lC<a<00`0C003o4`DC000I4`@0

00<C00002`024`D000DC00004`0500044`0000<C0P0011<001<20?lC=1<00`0C4`3o4`@C003o4olC

QQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00

oa?o4hHC0000\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.77084, -14.119, 0.0242408, 0.16996}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -57 0 ]

[.5 .63053 57 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -118 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(18.1600000000000001`) show

173.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .02891 m

.02499 .02891 L

.02606 .02892 L

.02729 .02892 L

.02846 .02893 L

.03053 .02895 L

.03279 .02897 L

.03527 .02901 L

.0379 .02906 L

.04262 .02918 L

.04749 .02933 L

.05205 .02951 L

.06245 .03003 L

.07305 .03074 L

.08274 .03155 L

.10458 .03395 L

.12357 .03674 L

.14429 .04059 L

.18493 .05092 L

.22406 .06477 L

.26565 .0841 L

.30571 .10714 L

.34426 .1326 L

.38527 .16135 L

.42475 .18794 L

.46273 .20959 L

.48387 .21911 L

.50315 .22593 L

.51272 .22864 L

.52313 .23109 L

.53289 .23294 L

.54206 .2343 L

.55146 .23536 L

.55645 .23579 L

.56183 .23617 L

.56717 .23646 L

.57279 .23669 L

.57759 .23683 L

.58031 .23689 L

.58284 .23693 L

.58547 .23697 L

.58789 .23699 L

.58916 .237 L

.59055 .23701 L

.592 .23701 L

.59265 .23702 L

.59336 .23702 L

.59465 .23702 L

.59587 .23702 L

.59705 .23702 L

Mistroke

.59815 .23703 L

.59946 .23702 L

.60064 .23702 L

.6013 .23702 L

.60201 .23702 L

.6033 .23702 L

.60574 .23702 L

.60693 .23702 L

.60801 .23701 L

.60916 .23701 L

.61038 .23701 L

.61102 .23701 L

.61172 .23701 L

.61299 .23701 L

.61405 .23702 L

.61523 .23702 L

.61646 .23702 L

.61761 .23703 L

.61967 .23704 L

.62189 .23706 L

.62429 .23709 L

.62686 .23712 L

.63148 .23722 L

.63431 .23729 L

.63698 .23738 L

.64197 .23758 L

.64724 .23786 L

.6521 .23819 L

.66308 .23919 L

.6728 .24041 L

.68188 .24186 L

.70253 .24631 L

.72286 .25223 L

.74141 .25878 L

.78122 .275 L

.81952 .2903 L

.83888 .29677 L

.84917 .2997 L

.86027 .30242 L

.87082 .30456 L

.8805 .30615 L

.88975 .30735 L

.89486 .30787 L

.8995 .30828 L

.90407 .30861 L

.90903 .30889 L

.91427 .30912 L

.91663 .30921 L

.91922 .30928 L

.92145 .30933 L

Mistroke

.92386 .30937 L

.92518 .30939 L

.92639 .30941 L

.92763 .30942 L

.92877 .30943 L

.92981 .30944 L

.93093 .30944 L

.93217 .30944 L

.93329 .30944 L

.93435 .30944 L

.9355 .30944 L

.93658 .30944 L

.93758 .30943 L

.93999 .30942 L

.94218 .3094 L

.9471 .30934 L

.95599 .30921 L

.96096 .30914 L

.96358 .3091 L

.96637 .30907 L

.96879 .30905 L

.97008 .30904 L

.97147 .30903 L

.97274 .30902 L

.97391 .30902 L

.97502 .30902 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.81005 .4101 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4gdC00<04a<0oa<64`00oa=m4`0301<C0?lC1Q<002TC1@3o4dlC0P3o4`LC

000[4`0301<C0?lCCa<00`0C4`1^4`d0RQ<002DC0`034`0301<C00@C0P3o4dTC00<04a<0IQ<800`C

3@1n4`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`1Q4`D081<807LC000[4`0301<C00@C00<04a<0

oa=84`0301<C05hC100/4`L0L1<002XC0P064`0301<C0?lCB1<00`0C4`1L4`<0=A<706XC000b4`03

01<C0?lCB1<205/C0P0o4`H0I1<0038C00<04a<0oa=84`0301<C05PC0P164`H0Ga<0038C00<04a<0

oa=84`0301<C05HC0P1>4`D0FQ<0038C2`go4d0C00<04a<0EA<205<C1@1F4`00<Q<00`0C4`084`/=

oa<e4`0301<C05@C00<04a<0Ea<5058C000b4`0301<C01<C1@go4c0C0P1C4`80GQ<3050C000b4`03

01<C01PC10go4b`C00<04a<03a<F02`C0P1Q4`@0CA<0038C00<04a<071<33OlC:A<00`0C4`0:4`D0

5Q<9028C0P1U4`<0Ba<0038C00<04a<07a<43OlC9A<00`0C4`054`D08a<701/C0P1X4`<0BA<0038C

00<04a<08a<33OlC5A<5008C00<04a<00a<00`0C4`034`80;a<601@C0P1[4`80B1<0038C00<04a<0

9Q<33OlC51<01`0C4a<04`0011<00`0C4`0303HC1P0>4`80KA<304HC000b4`0301<C02TC10go4`XC

0`034`0701<C4`0C00044`<0?Q<600TC00<04a<0KQ<204DC000b4`0301<C02dC0Pgo4`hC00L04a<C

01<000<C0P154`D011<00`0C4`1`4`80A1<001`C00<04a<00Q<00`0C4`024`0301<C008C00<04a<0

11<00`0C4`0_4`8=oa<<4`0701<C4`0C00024`0301<004XC1@1d4`80@Q<001/C00<04`0021<01`0C

4a<04`001A<00`0C4`0a4`8=oa<94`8011<0100C00024`0301<C04/C1P1a4`80@A<001HC0`024`03

01<000PC00<04a<00a<00`0C4`034`80=1<23OlC3A<200@C00<04a<0BQ<00`0C4`044`@0KQ<2040C

000K4`0301<000TC00<04a<00P064`0301<C03DC0Pgo4`XC00<04a<011<00`0C4`194`0301<C00TC

101[4`0301<C03hC000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C03LC0Pgo4`LC00<04a<0

1A<204XC00<04a<03A<406PC0P0n4`0071<00`0C4`064`<00Q<300DC00<04a<0>A<23OlC11<00`0C

4`064`0301<C04PC00<04a<04Q<406DC00<04a<0?1<0038C00<04a<0>a<23OlC0A<00`0C4`074`03

01<C04PC00<04a<05A<5068C00<04a<0>a<0038C00<04a<0?A<00`dC4`3l4`0301<C00PC00<04a<0

Aa<00`0C4`0J4`@0Ga<203`C000b4`0301<C03hC0Pgk4`0301<C00TC00<04a<0AQ<00`0C4`0O4`@0

G1<203/C000b4`0301<C040C0Pgh4`0301<C00XC00<04a<0AQ<00`0C4`0R4`D0FA<00`0C4`0i4`00

<Q<00`0C4`124`033A<C0?@C00<04a<02a<204LC00<04a<09Q<405LC00<04a<0>1<0038C00<04a<0

@a<23O<C00<04a<031<00`0C4`154`0301<C02XC101D4`80>A<0038C00<04a<0AA<23O4C00<04a<0

31<00`0C4`154`0301<C02hC101A4`0301<C03LC000b4`0301<C04LC00<=4a<0kA<00`0C4`0=4`03

01<C04@C00<04a<0<a<204lC0P0h4`00<Q<00`0C4`184`8=k1<00`0C4`0>4`0301<C04@C00<04a<0

=A<404`C0P0g4`00<Q<00`0C4`1:4`8=jA<00`0C4`0?4`0301<C04@C00<04a<0>A<204/C00<04a<0

=A<0038C00<04a<0C1<00`dC4`3V4`0301<C00lC0P144`0301<C03`C10174`80=Q<0038C00<04a<0

CA<23NDC00<04a<041<00`0C4`134`0301<C03lC0`164`0301<C03@C000b4`0301<C04lC00<=4a<0

hQ<00`0C4`0@4`0301<C04<C00<04a<0@Q<304<C0P0e4`008A<00`0C4`024`0301<C008C00<04a<0

11<00`0C4`1@4`033A<C0>0C00<04a<04A<00`0C4`124`0301<C04HC0`114`0301<C03<C000P4`03

01<000LC00<04`001A<00`0C4`1A4`8=h1<00`0C4`0A4`0301<C048C00<04a<0BA<203lC00<04a<0

<a<001/C0`024`0301<000TC00<04a<00a<205@C00<=4a<0g1<00`0C4`0B4`0301<C048C00<04a<0

Ba<303dC00<04a<0<Q<0020C00<04`001a<200HC00<04a<0E1<23M`C00<04a<04Q<204<C00<04a<0

CQ<203/C00<04a<0<Q<0020C00<04`001a<00`0C4`054`0301<C05HC00<=4a<0f1<00`0C4`0C4`03

01<C044C00<04a<0DA<303PC00<04a<0<Q<0024C00<04a<01Q<300DC00<04a<0Ea<23MPC00<04a<0

4a<00`0C4`114`0301<C05@C0P0g4`0301<C034C000b4`0301<C05TC00<=4a<0e1<00`0C4`0D4`03

01<C044C00<04a<0EQ<303@C00<04a<0<A<0038C00<04a<0FQ<00`dC4`3C4`0301<C00hC00<04a<0

0a<00`0C4`104`0301<C05TC0`0b4`80<Q<0038C00<04a<0Fa<23M8C00<04a<03Q<00`0C00044`03

01<C040C00<04a<0G1<2034C00<04a<0<1<0038C00<04a<0GA<00`dC4`3?4`0301<C00TC0`044`03

01<C008C0`104`0301<C05hC0P0_4`0301<C030C000b4`0301<C05hC0Pg?4`0301<C00hC0P054`03

01<C03lC00<04a<0HA<302`C00<04a<0<1<0038C00<04a<0H1<00`dC4`3<4`0301<C00hC00<04a<0

11<00`0C4`0o4`0301<C06@C00<04a<0:A<00`0C4`0`4`00<Q<00`0C4`1Q4`8=ba<00`0C4`0?4`<0

11<00`0C4`0o4`0301<C06DC0`0X4`80<A<0038C00<04a<0Ha<23LTC00<04a<05Q<00`0C4`0o4`03

01<C06PC00<04a<09Q<00`0C4`0_4`00<Q<00`0C4`1U4`8=aa<00`0C4`0F4`0301<C03lC00<04a<0

JA<302DC00<04a<0;a<0038C00<04a<0Ia<23LDC00<04a<05Q<2040C00<04a<0K1<202<C00<04a<0

;a<0038C00<04a<0JA<23L<C00<04a<05Q<00`0C4`0o4`0301<C06dC0P0R4`0301<C02lC000b4`03

01<C06/C0Pg14`0301<C01HC00<04a<0?a<00`0C4`1_4`8081<00`0C4`0_4`00<Q<00`0C4`1]4`<=

_A<00`0C4`0G4`0301<C03hC00<04a<0LQ<201hC00<04a<0;a<001`C00<04a<00Q<0100C4a<300<C

00<04a<011<00`0C4`1`4`8=^a<00`0C4`0G4`0301<C03hC00<04a<0M1<201`C00<04a<0;a<001/C

00<04`001a<00`0C4`024`0301<000DC00<04a<0LQ<23KTC00<04a<05a<203lC00<04a<0MQ<201XC

00<04a<0;a<001HC0`024`0301<000PC00<04a<00a<00`0C4`034`80MA<53K@C00<04a<05a<00`0C

4`0n4`0301<C07PC00<04a<05Q<00`0C4`0`4`006a<00`0C00084`0401<C4`801Q<00`0C4`1i4`X=

ZA<00`0C4`0H4`0301<C03hC00<04a<0NA<201HC00<04a<0<1<001/C00<04`001a<00`0C00024`03

01<C00DC00<04a<0Pa<I3I0C00<04a<061<00`0C4`0n4`0301<C07/C00<04a<04a<00`0C4`0`4`00

71<00`0C4`074`0401<C4`<01A<00`0C4`2L4`H=RQ<00`0C4`0H4`0301<C03hC00<04a<0O1<00`0C

4`0B4`0301<C030C000b4`0301<C0:8C1@f54`0301<C01PC00<04a<0?A<00`0C4`1n4`804Q<00`0C

4`0`4`00<Q<00`0C4`2W4`@=PA<00`0C4`0H4`80?Q<00`0C4`204`8041<00`0C4`0`4`00<Q<00`0C

4`2[4`8=Oa<00`0C4`0H4`0301<C024C1@024`0301<C018C00<04a<02a<500034`00024C1@024`03

01<C01lC1@024`0301<C01/C00@04a<C1@000a<000034`0301<C034C000b4`0301<C0:dC0`el4`03

01<C01PC00<04a<08a<01`0C4a<04`004a<00`0C4`0=4`0701<C4`0C000R4`0301<C008C00<04a<0

8A<01`0C4a<04`0071<200@C00<04a<00a<0100C4`0c4`00<Q<00`0C4`0V4`0301<C008C00@04a<C

0`0S4`0301<C008C00<04a<00Q<3028C00<04a<00Q<0100C4a<2024C0Pd00a<04`034`0301<C008C

00<04a<09Q<5044C00<04a<061<00`0C4`0S4`0301<C00<C00<04a<04A<00`0C4`0=4`0701<C4`0C

000R4`0301<C008C00<04a<08A<01`0C4a<04`007Q<01@0C4a<000@C0P024`0301<C034C000b4`03

01<C02DC00<04`001a<00`0C4`0R4`0301<000TC00<04a<081<00`0C00074`0301<0028C0`d74`03

01<002TC00<04a<0@A<00`0C4`0H4`0301<C02<C00@04a<C0P0D4`0301<C00dC00@04a<C0P0S4`03

01<C00<C00<04a<081<00`0C4`024`0301<C01hC0P000a<04`024`0301<0008C00<04a<0<A<0038C

00<04a<09A<00`0C00084`0301<C024C00<04`001a<4024C00<04`001a<00`0C000R4`0301<0008=

1A<00`0C000Y4`0301<C040C00<04a<06A<00`0C4`0S4`0501<C4`005A<00`0C4`0=4`0501<C4`00

91<01`0C4a<04`008Q<01`0C4a<04`008A<200<C00D04`0C000d4`00<Q<00`0C4`0U4`0301<000PC

00<04a<08A<00`0C00074`0301<0028C00<04`001a<202<C00<04`000Q<33@<C00<04a<0:1<00`0C

4`104`0301<C01TC0P0S4`800a<301<C00<04a<031<200@C0P0Q4`800a<3024C0P044`0301<C020C

0P044`8000<C01<0<a<0038C00<04a<09A<00`0C00074`0301<0028C00<04`0021<2028C00<04`00

1a<00`0C4`0R4`0301<000DC0Pd00`0C000Y4`0301<C040C00<04a<06A<00`0C4`0m4`0301<C08PC

00<04a<01A<00`0C4`0b4`00<Q<00`0C4`0V4`0301<C00LC00<04a<08Q<00`0C4`084`0301<C024C

00<04a<01a<202<C00<04a<01Q<23BTC0P124`0301<C01TC00<04a<0?A<00`0C4`294`801A<00`0C

4`0b4`00<Q<00`0C4`2n4`8=Ja<00`0C4`0I4`0301<C03dC00<04a<0Ra<01@0C4a<003DC000b4`03

01<C0<0C10eW4`0301<C01TC00<04a<0?A<00`0C4`2;4`0401<C01<C100O4`00<Q<00`0C4`344`@=

Ha<00`0C4`0I4`0301<C03dC00<04a<0S1<201@C0`0P4`00<Q<00`0C4`384`8=;A<302/Co`0:4`03

01<C01hC000b4`0301<C0<XC1@dY4`0301<C02/C00<04a<00Q<0100C4`084`0301<C00DC00<04a<0

1A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`03

01<C00<C00<04`001a<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<0

1A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`03

01<C00DC00<04a<01A<00`0C4`054`<01Q<00`0C4`0<4`8081<002`Cf00;3@/010d600TC00<04a<0

<1<00`0C4`0I4`0301<C02HC00<04a<051<00`0C4`0@4`0301<C02HC00<04a<09Q<00`0C4`0V4`04

01<C03HC000b4`0301<C00PC00<04a<02A<00`0C4`094`0301<C00TC00<04a<021<00`0C4`094`03

01<C00TC00<04a<02A<00`0C4`084`0301<C00TC00<04a<02A<00`0C4`094`0301<C00TC00<04a<0

21<00`0C4`094`0301<C00TC00<04a<02A<00`0C4`084`0301<C00HC30d34`0301<C00`C100`4`03

01<C01TC00<04a<0?A<00`0C4`2;4`0501<C4`00=A<0038C00<04a<0;1<00`0C4`0/4`0301<C02`C

00<04a<0;1<00`0C4`0/4`0301<C040C00<04a<06A<00`0C4`0m4`0301<C08XC00<04a<00Q<00`0C

4`0c4`00<Q<00`0C4`3o4b`C00<04a<06A<00`0C4`0m4`0301<C08TC00<04a<011<00`0C4`0b4`00

<Q<00`0C4`3o4b`C00<04a<06A<203hC00<04a<0Qa<200LC00<04a<0<Q<0038C00<04a<0oa</4`03

01<C01TC00<04a<0?A<00`0C4`274`0301<C00HC00<04a<0<Q<0038C00<04a<0oa<]4`0301<C01PC

00<04a<0?A<00`0C4`264`0301<C00PC00<04a<0<A<0038C00<04a<0oa<]4`0301<C01PC00<04a<0

?A<00`0C4`244`802a<00`0C4`0a4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0m4`0301<C08<C

00<04a<02a<00`0C4`0a4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0m4`0301<C088C00<04a<0

31<00`0C4`0a4`00<Q<00`0C4`3o4bdC00<04a<061<203hC00<04a<0P1<200lC00<04a<0<A<0038C

00<04a<0oa<]4`0301<C01PC00<04a<0?A<00`0C4`1o4`0301<C010C00<04a<0<1<0038C00<04a<0

oa<]4`0301<C01PC00<04a<0?Q<00`0C4`1l4`804a<00`0C4`0`4`00<Q<00`0C4`3o4bdC00<04a<0

61<00`0C4`0n4`0301<C07/C0P0D4`0301<C030C000b4`0301<C0?lC;A<00`0C4`0H4`0301<C03hC

00<04a<0NA<201HC00<04a<0<1<0038C00<04a<0oa<]4`0301<C01PC00<04a<0?Q<00`0C4`1h4`03

01<C01HC00<04a<0<1<0038C00<04a<0oa<^4`0301<C01LC0P0o4`0301<C07HC0P0I4`0301<C030C

000b4`0301<C0?lC;Q<00`0C4`0G4`0301<C03hC00<04a<0M1<201`C00<04a<0;a<001`C00<04a<0

0Q<0100C4a<300<C00<04a<011<00`0C4`3o4bhC00<04a<05a<00`0C4`0n4`0301<C07<C00<04a<0

71<00`0C4`0_4`006a<00`0C00074`0301<C008C00<04`001A<00`0C4`3o4bhC00<04a<05a<00`0C

4`0o4`0301<C070C0P0O4`0301<C02lC000K4`0301<000PC00<04a<00a<00`0C4`034`80oa<`4`03

01<C01HC00<04a<0?a<00`0C4`1V4`033A<C00@C0`0Q4`0301<C02lC000K4`0301<000PC00@04a<C

0P064`0301<C0?lC;a<00`0C4`0F4`0301<C03lC00<04a<0Ha<63@<C0P0S4`0301<C02lC000K4`03

01<000LC00<04`000Q<00`0C4`054`0301<C0?lC;a<00`0C4`0F4`80@1<00`0C4`1R4`T=00<04a<0

8a<00`0C4`0_4`0071<00`0C4`074`0401<C4`<01A<00`0C4`3o4blC00<04a<05Q<00`0C4`0o4`03

01<C068C2@dV4`0301<C02lC000b4`0301<C0?lC;a<00`0C4`0F4`0301<C03lC00<04a<0HQ<93BHC

00<04a<0;a<0038C00<04a<0oa<`4`0301<C01DC00<04a<0?a<00`0C4`1Q4`/=91<00`0C4`0`4`00

<Q<00`0C4`3o4c0C00<04a<03a<00`0C4`034`0301<C03lC00<04a<0HQ<93BDC00<04a<0<1<0038C

00<04a<0oa<`4`0301<C00hC00<04`0011<00`0C4`104`0301<C05hC0`093BDC00<04a<0<1<0038C

00<04a<0oa<`4`0301<C010C00<04a<00Q<3040C00<04a<0G1<3008C2@dU4`0301<C030C000b4`03

01<C0?lC<A<00`0C4`0=4`801A<00`0C4`104`0301<C05XC0P064`H=9Q<2038C000b4`0301<C0?lC

<A<00`0C4`0=4`0301<C00@C00<04a<0@A<00`0C4`1G4`802a<00`dC4`0V4`0301<C034C000b4`03

01<C0?lC<Q<00`0C4`0<4`<011<00`0C4`114`0301<C05@C0`0f4`0301<C034C000b4`0301<C0?lC

<Q<00`0C4`0C4`0301<C044C00<04a<0DQ<303LC0P0c4`00<Q<00`0C4`3o4c<C00<04a<04Q<2048C

00<04a<0Ca<303XC00<04a<0<Q<0038C00<04a<0oa<c4`0301<C018C00<04a<0@Q<00`0C4`1<4`<0

?1<00`0C4`0b4`00<Q<00`0C4`3o4c@C00<04a<04A<00`0C4`124`0301<C04TC0`0n4`0301<C03<C

000b4`0301<C0?lC=1<00`0C4`0A4`0301<C048C00<04a<0Aa<3040C00<04a<0<a<0024C00<04a<0

0Q<00`0C4`024`0301<C00@C00<04a<0oa<e4`0301<C010C00<04a<0@Q<00`0C4`144`<0@Q<203DC

000P4`0301<000LC00<04`001A<00`0C4`3o4cDC00<04a<041<00`0C4`134`0301<C040C0`154`03

01<C03@C000P4`0301<000TC00<04a<00a<20?lC=a<00`0C4`0?4`80A1<00`0C4`0m4`<0Aa<203HC

000P4`0301<000LC0P064`0301<C0?lC=Q<00`0C4`0?4`0301<C04@C00<04a<0>A<304XC00<04a<0

=A<0020C00<04`001a<00`0C4`054`0301<C0?lC=a<00`0C4`0>4`0301<C04@C00<04a<0=Q<404/C

0P0g4`008A<00`0C4`064`<01A<00`0C4`3o4cPC00<04a<03A<00`0C4`144`0301<C03<C0`1?4`03

01<C03HC000b4`0301<C0?lC>A<00`0C4`0<4`0301<C04DC00<04a<0;a<3054C00<04a<0=a<0038C

00<04a<0oa<i4`0301<C00`C00<04a<0AA<00`0C4`0[4`@0Da<203TC000b4`0301<C0?lC>Q<00`0C

4`0;4`80Aa<00`0C4`0W4`@0EQ<00`0C4`0h4`00<Q<00`0C4`3o4cXC00<04a<02a<00`0C4`164`03

01<C02<C1@1H4`80>Q<0038C00<04a<0oa<k4`802a<00`0C4`164`0301<C020C101K4`80>a<0038C

00<04a<0oa<m4`0301<C00PC00<04a<0Aa<00`0C4`0K4`@0Ga<00`0C4`0j4`00<Q<00`0C4`3o4chC

00<04a<01a<00`0C4`174`8061<5064C00<04a<0>a<0038C00<04a<0oa<n4`0301<C00LC00<04a<0

B1<00`0C4`0C4`@0I1<203dC000b4`0301<C0?lC?a<00`0C4`064`80BQ<00`0C4`0>4`@0Ia<203hC

000b4`0301<C0?lC@1<200HC00<04a<0BA<00`0C4`0:4`@0JQ<203lC000b4`0301<C0?lC@Q<00`0C

4`034`0301<C04XC00<04a<01A<506`C0P104`00<Q<00`0C4`3o4d<C0P034`0301<C04XC0P000a<0

0003070C0P114`00<Q<00`0C4`3o4c/C1@024`0401<C008C00<04a<0BA<507<C0P124`0071<00`0C

4`024`0301<C008C00<04a<00Q<00`0C4`044`0301<C0?lC?A<01`0C4a<04`000Q<304LC1@024`03

01<C074C0P134`006a<00`0C00084`0701<C4`0C00054`0301<C0?lC?A<01`0C4a<04`0011<3040C

1@084`0301<C06hC0P154`006a<00`0C00084`0301<C00<C00<04a<00a<20?lC?Q<01`0C4a<04`00

11<0100C000j4`D03A<00`0C4`1]4`80AQ<001/C00<04`002A<00`0C4`0200HC00<04a<0oa<m4`07

01<C4`0C00044`0401<C4`<0<A<601<C0P1[4`<0Aa<001/C00<04`001a<00`0C00024`0301<C00DC

00<04a<0oa<l4`8011<00`0C4`034`0301<C00@C0`0X4`L06A<206TC0P194`0071<00`0C4`064`<0

0Q<300DC00<04a<0oa=84`0301<C00LC1@0K4`T081<00`0C4`1T4`<0Ba<0038C00<04a<0oa=84`03

01<C00`C700Y4`80HQ<304dC000b4`0301<C0?lCB1<205<C0P1O4`<0Ca<0038C00<04a<0oa=84`03

01<C05<C0P1J4`@0DQ<0038C00<04a<0oa=84`0301<C05@C0P1F4`@0EA<0038C00<04a<0oa=84`03

01<C05HC0P1?4`D0FA<0038C00<04a<0oa=84`0301<C05LC0`184`H0GA<0038C00<04a<0oa=84`03

01<C05TC0`104`L0HQ<0038C00<04a<0oa=84`80G1<303PC1`1X4`00<Q<00`0C4`3o4dPC00<04a<0

GQ<302hC201^4`00<Q<00`0C4`3o4dPC00<04a<0H1<502<C201e4`00<Q<00`0C4`3o4dPC00<04a<0

I1<701@C2P1l4`00<Q<00`0C4`3o4dPC00<04a<0JQ<E08HC000b4`0301<C0?lCB1<00`0C4`3o4`HC

000Y4`D011<00`0C4`3o4dPC0P3o4`LC000[4`0301<C00@C00<04a<0oa=84`0301<C0?lC1Q<002/C

00<04a<011<20?lCBA<00`0C4`3o4`HC000[4`0301<C0?lCoa=H4`00:a<00`0C4`3o4olCF1<002XC

0P3o4olCFQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC001a4`@000<C0000

1`024`0301<C008C00<04a<01@000a<000044`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C

00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C

4`024`0301<C00D0oa>/4`00LA<300PC00L04a<C01<000PC00L04a<C01<0008C00<04`000Q<00`0C

00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C

00<04`000Q<00`0C00024`0301<0008C00<04`000a<00`0C4`2Q4`80oa<94`00La<00`0C4`04008C

00L04a<C01<000PC00L04a<C01<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C

00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C

00<04`000a<00`0C4`2R4`0301<C0?lC1a<001TC10000a<00006008C2P024`800Q<3008C0`034`80

00HC00004`0W4`8021<00`0C4`024`0301<C00LC00@04a<C0P034`0301<0008C00<04`000Q<00`0C

00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C

00<04`000Q<00`0C00024`0301<000<C00<04a<0X1<3008C00<04a<0oa<44`006Q<01P0C4`0C008C

00<04`0011<01P0C4`0C008C00<04`001A<00`0C4`024`0501<C4`000Q<0100C01<2034C00L04a<C

01<000PC00D04a<C00044`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C

00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<000<C

00<04a<00a<00`0C4`2I4`0801<C01<04`3o4`DC000J4`0601<C01<011<00`0C4`024`0301<C008C

00<04a<00Q<00`0C4`034`0301<C008C00D04a<C00024`0401<04`80<1<200@C00<04a<01Q<200@C

0P034`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C

00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0401<C4`8011<00`0C4`2J4`08

01<C01<04`3o4`DC000J4`0501<C01<00P034`800a<00`0C4`024`800a<00`0C4`034`0301<C008C

00D04a<C00024`0601<001<0oa<_4`<000@C01<0oa<54`006Q<01P0C4`0C008C00<04`000Q<00`0C

00044`0>01<C01<04`0C01<04`024`0501<C4`000Q<01P0C000C0?lC<a<00`0C003o4`DC000I4`@0

00<C00002`024`D000DC00004`0500044`0000<C0P0011<001<20?lC=1<00`0C4`3o4`@C003o4olC

QQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00

oa?o4hHC0000\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.77084, -14.119, 0.0242408, 0.16996}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -57 0 ]

[.5 .63053 57 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -118 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(19.1780000000000008`) show

173.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .0297 m

.02499 .0297 L

.02606 .0297 L

.02729 .02969 L

.02846 .02968 L

.03053 .02967 L

.03279 .02964 L

.03527 .02961 L

.0379 .02956 L

.04262 .02946 L

.05205 .02915 L

.06245 .02869 L

.0842 .02735 L

.10458 .02574 L

.14335 .02241 L

.15346 .02164 L

.16449 .02091 L

.16953 .02063 L

.1749 .02037 L

.17961 .02018 L

.18458 .02002 L

.18713 .01996 L

.18993 .0199 L

.19116 .01988 L

.19248 .01987 L

.19373 .01986 L

.19486 .01985 L

.19555 .01985 L

.19628 .01984 L

.1976 .01984 L

.19833 .01984 L

.19901 .01985 L

.19977 .01985 L

.20058 .01986 L

.20195 .01987 L

.2034 .01989 L

.20599 .01993 L

.2084 .01999 L

.21098 .02007 L

.21562 .02026 L

.22114 .02057 L

.22616 .02093 L

.23614 .02188 L

.24534 .02305 L

.25545 .02469 L

.26614 .02685 L

.28572 .03201 L

.30403 .03831 L

.34285 .05651 L

.38413 .08271 L

Mistroke

.42389 .11306 L

.46213 .14438 L

.50283 .1761 L

.54201 .20107 L

.56347 .2113 L

.57329 .21508 L

.58365 .21845 L

.59325 .22102 L

.60377 .22326 L

.61333 .22481 L

.62225 .22589 L

.62727 .22636 L

.63273 .22677 L

.63788 .22707 L

.64264 .22728 L

.64693 .22744 L

.65165 .22756 L

.65659 .22766 L

.66121 .22773 L

.67107 .22785 L

.67644 .22792 L

.68143 .22801 L

.68572 .22812 L

.69028 .22826 L

.69535 .22846 L

.69995 .22871 L

.70482 .22902 L

.70996 .22944 L

.71917 .23042 L

.72909 .23184 L

.73999 .2339 L

.75947 .23893 L

.78038 .24622 L

.82171 .26492 L

.86152 .28418 L

.87972 .29189 L

.89982 .2989 L

.91957 .30395 L

.93039 .30592 L

.93525 .30663 L

.94057 .30729 L

.94961 .30813 L

.95455 .30846 L

.95914 .30869 L

.96136 .30877 L

.96346 .30884 L

.96536 .30889 L

.96738 .30894 L

.96843 .30896 L

.96958 .30897 L

Mistroke

.97064 .30899 L

.97161 .309 L

.97275 .30901 L

.97397 .30901 L

.97511 .30902 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1.00022 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.97522 .21477 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4gdC00<04a<0oa<64`00oa=m4`0301<C0?lC1Q<002TC1@3o4dlC0P3o4`LC

000[4`0301<C0?lCCa<00`0C4`1^4`d0RQ<002DC0`034`0301<C00@C0P3o4dTC00<04a<0IQ<800`C

3@1n4`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`1Q4`D081<807LC000[4`0301<C00@C00<04a<0

oa=84`0301<C05hC100/4`L0L1<002XC0P064`0301<C0?lCB1<00`0C4`1L4`<0=A<706XC000b4`03

01<C0?lCB1<205/C0P0o4`H0I1<0038C00<04a<071<F3OlC5Q<00`0C4`1H4`80AQ<605lC000b4`03

01<C00hC3PdF4`D=oa<A4`0301<C05HC0P1>4`D0FQ<0038C4@dY4`@=oa<=4`0301<C05DC0P1C4`D0

EQ<0038C00<04a<0>a<43OlC2A<00`0C4`1D4`0301<C05LC1@1B4`00<Q<00`0C4`0o4`8=oa<74`80

Da<205hC0`1@4`00<Q<00`0C4`114`<=oa<44`0301<C00lC5P0/4`80HA<404dC000b4`0301<C04@C

0Pgo4`8C00<04a<02Q<501HC2@0R4`80IA<304/C000b4`0301<C04HC0Pgo4`0301<C00DC1@0S4`L0

6a<206PC0`194`00<Q<00`0C4`184`8=l1<5008C00<04a<00a<00`0C4`034`80;a<601@C0P1[4`80

B1<0038C00<04a<0BQ<23O0C00L04a<C01<000@C00<04a<00`0f4`H03Q<206dC0`164`00<Q<00`0C

4`1<4`8=j1<300<C00L04a<C01<000@C0`0n4`H02A<00`0C4`1^4`80AA<0038C00<04a<0CQ<00`dC

4`3[4`0701<C4`0C00034`80AA<500@C00<04a<0L1<204@C000L4`0301<C008C00<04a<00Q<00`0C

4`024`0301<C00@C00<04a<0Ca<23N/C00L04a<C01<0008C00<04`00BQ<507@C0P124`006a<00`0C

00084`0701<C4`0C00054`0301<C054C0PgX4`8011<0100C00024`0301<C04/C1P1a4`80@A<001HC

0`024`0301<000PC00<04a<00a<00`0C4`034`80E1<00`dC4`3[4`8011<00`0C4`1:4`0301<C00@C

101^4`80@1<001/C00<04`002A<00`0C4`0200HC00<04a<0E1<23NXC00<04a<011<00`0C4`194`03

01<C00TC101[4`0301<C03hC000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C05HC00<=4a<0

iQ<00`0C4`054`80BQ<00`0C4`0=4`@0J1<203hC000L4`0301<C00HC0`024`<01A<00`0C4`1G4`03

3A<C0>@C00<04a<01Q<00`0C4`184`0301<C018C101U4`0301<C03`C000b4`0301<C05PC0PgS4`03

01<C00LC00<04a<0B1<00`0C4`0E4`D0HQ<00`0C4`0k4`00<Q<00`0C4`1J4`033A<C0=lC00<04a<0

21<00`0C4`174`0301<C01XC101O4`80?1<0038C00<04a<0Fa<00`dC4`3M4`0301<C00TC00<04a<0

AQ<00`0C4`0O4`@0G1<203/C000b4`0301<C05`C0PgL4`0301<C00XC00<04a<0AQ<00`0C4`0R4`D0

FA<00`0C4`0i4`00<Q<00`0C4`1N4`033A<C0=PC00<04a<02a<204LC00<04a<09Q<405LC00<04a<0

>1<0038C00<04a<0Ga<00`dC4`3F4`0301<C00`C00<04a<0AA<00`0C4`0Z4`@0E1<203TC000b4`03

01<C060C00<=4a<0eA<00`0C4`0<4`0301<C04DC00<04a<0;Q<4054C00<04a<0=a<0038C00<04a<0

HA<23M@C00<04a<03A<00`0C4`144`0301<C03<C0P1?4`80>1<0038C00<04a<0Ha<00`dC4`3@4`03

01<C00hC00<04a<0A1<00`0C4`0e4`@0C1<203LC000b4`0301<C06@C00<=4a<0cQ<00`0C4`0?4`03

01<C04@C00<04a<0>A<204/C00<04a<0=A<0038C00<04a<0IA<00`dC4`3=4`0301<C00lC0P144`03

01<C03`C10174`80=Q<0038C00<04a<0IQ<23L`C00<04a<041<00`0C4`134`0301<C03lC0`164`03

01<C03@C000b4`0301<C06PC00<=4a<0bA<00`0C4`0@4`0301<C04<C00<04a<0@Q<304<C0P0e4`00

8A<00`0C4`024`0301<C008C00<04a<011<00`0C4`1Y4`033A<C0<LC00<04a<04A<00`0C4`124`03

01<C04HC0`114`0301<C03<C000P4`0301<000LC00<04`001A<00`0C4`1Z4`033A<C0<HC00<04a<0

4A<00`0C4`124`0301<C04TC0P0o4`0301<C03<C000K4`<00Q<00`0C00094`0301<C00<C0P1/4`8=

aA<00`0C4`0B4`0301<C048C00<04a<0Ba<303dC00<04a<0<Q<0020C00<04`001a<200HC00<04a<0

KA<00`dC4`324`0301<C018C0P134`0301<C04hC0P0k4`0301<C038C000P4`0301<000LC00<04a<0

1A<00`0C4`1^4`033A<C0<0C00<04a<04a<00`0C4`114`0301<C054C0`0h4`0301<C038C000Q4`03

01<C00HC0`054`0301<C06lC00<=4a<0_a<00`0C4`0C4`0301<C044C00<04a<0E1<203LC00<04a<0

<A<0038C00<04a<0L1<23KhC00<04a<051<00`0C4`114`0301<C05HC0`0d4`0301<C034C000b4`03

01<C078C00<=4a<0^a<00`0C4`0>4`0301<C00<C00<04a<0@1<00`0C4`1I4`<0<Q<2038C000b4`03

01<C07<C00<=4a<0^A<00`0C4`0>4`0301<000@C00<04a<0@1<00`0C4`1L4`80<A<00`0C4`0`4`00

<Q<00`0C4`1d4`8=^A<00`0C4`094`<011<00`0C4`024`<0@1<00`0C4`1N4`80;a<00`0C4`0`4`00

<Q<00`0C4`1f4`8=]a<00`0C4`0>4`801A<00`0C4`0o4`0301<C064C0`0/4`033A<C030C000b4`03

01<C07PC00<=4a<0]1<00`0C4`0>4`0301<C00@C00<04a<0?a<00`0C4`1T4`0301<C02HC1Pd`4`00

<Q<00`0C4`1i4`8=/a<00`0C4`0?4`<011<00`0C4`0o4`0301<C06DC0`0T4`T=;Q<0038C00<04a<0

Na<23K4C00<04a<05Q<00`0C4`0o4`0301<C06PC00<04a<08A<93BhC000b4`0301<C07dC0Pf_4`03

01<C01HC00<04a<0?a<00`0C4`1Y4`<081<93BhC000b4`0301<C07lC0Pf]4`0301<C01HC0P104`03

01<C06`C0P0M4`/=;A<0038C00<04a<0PA<23J/C00<04a<05Q<00`0C4`0o4`0301<C06dC0P0M4`T=

;Q<0038C00<04a<0Pa<33JPC00<04a<05Q<00`0C4`0o4`0301<C06lC0P0K4`T=;Q<0038C00<04a<0

QQ<23JDC00<04a<05a<00`0C4`0n4`0301<C078C0P0I4`T=;Q<001`C00<04a<00Q<0100C4a<300<C

00<04a<011<00`0C4`284`D=X1<00`0C4`0G4`0301<C03hC00<04a<0M1<201PC1Pd`4`006a<00`0C

00074`0301<C008C00<04`001A<00`0C4`2=4a@=S1<00`0C4`0G4`80?a<00`0C4`1f4`806A<00`d0

4`0`4`005Q<3008C00<04`0021<00`0C4`034`0301<C00<C0P2R4``=P1<00`0C4`0G4`0301<C03hC

00<04a<0N1<00`0C4`0F4`0301<C030C000K4`0301<000PC00@04a<C0P064`0301<C0:dC0`el4`03

01<C01PC00<04a<0?Q<00`0C4`1i4`805Q<00`0C4`0`4`006a<00`0C00074`0301<0008C00<04a<0

1A<00`0C4`2`4`@=N1<00`0C4`0H4`0301<C03hC00<04a<0Na<00`0C4`0C4`0301<C030C000L4`03

01<C00LC00@04a<C0`054`0301<C0;@C0`ee4`0301<C01PC00<04a<0?Q<00`0C4`1l4`0301<C018C

00<04a<0<1<0038C00<04a<0]a<23G<C00<04a<061<00`0C4`0m4`0301<C07hC0P0B4`0301<C030C

000b4`0301<C0;TC0Pea4`0301<C01PC0P0n4`0301<C080C0P0@4`0301<C030C000b4`0301<C0;/C

0Pe_4`0301<C01PC00<04a<08A<5008C00<04a<04Q<00`0C4`0;4`D000<C00008A<5008C00<04a<0

7a<5008C00<04a<06a<0100C4a<500034`0000<C00<04a<0<A<0038C00<04a<0_A<23FdC00<04a<0

61<00`0C4`0S4`0701<C4`0C000C4`0301<C00dC00L04a<C01<0028C00<04a<00Q<00`0C4`0Q4`07

01<C4`0C000L4`8011<00`0C4`034`0401<C03<C000b4`0301<C02HC00<04a<00Q<0100C4a<302<C

00<04a<00Q<00`0C4`024`<08Q<00`0C4`024`0401<C4`8091<00`0C4`024`0301<C008C00@04`d=

9A<5044C00<04a<061<00`0C4`0S4`0301<C00<C00<04a<04A<00`0C4`0=4`0701<C4`0C000R4`03

01<C008C00<04a<08A<01`0C4a<04`007Q<01@0C4a<000@C0P024`0301<C034C000b4`0301<C02DC

00<04`001a<00`0C4`0R4`0301<000TC00<04a<081<00`0C00074`0301<0028C00<04`001a<00`0C

00024`<=91<00`0C4`114`0301<C01PC00<04a<08a<0100C4a<201@C00<04a<03A<0100C4a<202<C

00<04a<00a<00`0C4`0P4`0301<C008C00<04a<07Q<200034`0C008C00<04`000Q<00`0C4`0a4`00

<Q<00`0C4`0U4`0301<000PC00<04a<08A<00`0C00074`@08A<00`0C00074`0301<0028C00<04`00

1a<00`0C00054`8=8Q<00`0C4`104`0301<C01TC00<04a<08a<01@0C4a<001DC00<04a<03A<01@0C

4a<002@C00L04a<C01<0028C00L04a<C01<0024C0P034`0501<04`00=1<0038C00<04a<09A<00`0C

00084`0301<C024C00<04`001a<00`0C000R4`0301<000LC0P0S4`0301<000PC00<04a<01Q<33AlC

00<04a<0@1<00`0C4`0I4`808a<200<C0`0C4`0301<C00`C0P044`808A<200<C0`0Q4`8011<00`0C

4`0P4`8011<200034`0C03<C000b4`0301<C02DC00<04`001a<00`0C000R4`0301<000PC0P0R4`03

01<000LC00<04a<08Q<00`0C00074`0301<000XC0PdM4`0301<C040C00<04a<06A<00`0C4`0m4`03

01<C08PC00<04a<01A<00`0C4`0b4`00<Q<00`0C4`0V4`0301<C00LC00<04a<08Q<00`0C4`084`03

01<C024C00<04a<01a<202<C00<04a<01a<00`0C4`0;4`8=6Q<2048C00<04a<06A<00`0C4`0m4`03

01<C08TC0P054`0301<C038C000b4`0301<C0<dC0PeL4`0301<C01TC00<04a<0?A<00`0C4`2;4`05

01<C4`00=A<0038C00<04a<0ca<33ETC00<04a<06A<00`0C4`0m4`0301<C08/C00@04a<04a<401lC

000b4`0301<C0=8C0PeG4`0301<C01TC00<04a<0?A<00`0C4`2<4`8051<3020C000b4`0301<C0=@C

10dO4`<0:a?o00XC00<04a<07Q<0038C00<04a<0f1<43A`C00<04a<0:a<00`0C4`024`0401<C00PC

00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C

4`064`0301<C00DC00<04a<00a<00`0C00074`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC

00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C

4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC0`064`0301<C00`C0P0P4`00;1?U00d=

1P094`0301<C030C00<04a<06A<00`0C4`0V4`0301<C01@C00<04a<041<00`0C4`0V4`0301<C02HC

00<04a<09Q<0100C4`0f4`00<Q<00`0C4`084`0301<C00TC00<04a<02A<00`0C4`094`0301<C00PC

00<04a<02A<00`0C4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0C

4`094`0301<C00PC00<04a<02A<00`0C4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC

00<04a<031<4030C00<04a<06A<00`0C4`0m4`0301<C08/C00D04a<C000e4`00<Q<00`0C4`0/4`03

01<C02`C00<04a<0;1<00`0C4`0/4`0301<C02`C00<04a<0@1<00`0C4`0I4`0301<C03dC00<04a<0

RQ<00`0C4`024`0301<C03<C000b4`0301<C0?lC;1<00`0C4`0I4`0301<C03dC00<04a<0RA<00`0C

4`044`0301<C038C000b4`0301<C0?lC;1<00`0C4`0I4`80?Q<00`0C4`274`801a<00`0C4`0b4`00

<Q<00`0C4`3o4b`C00<04a<06A<00`0C4`0m4`0301<C08LC00<04a<01Q<00`0C4`0b4`00<Q<00`0C

4`3o4bdC00<04a<061<00`0C4`0m4`0301<C08HC00<04a<021<00`0C4`0a4`00<Q<00`0C4`3o4bdC

00<04a<061<00`0C4`0m4`0301<C08@C0P0;4`0301<C034C000b4`0301<C0?lC;A<00`0C4`0H4`03

01<C03dC00<04a<0Pa<00`0C4`0;4`0301<C034C000b4`0301<C0?lC;A<00`0C4`0H4`0301<C03dC

00<04a<0PQ<00`0C4`0<4`0301<C034C000b4`0301<C0?lC;A<00`0C4`0H4`80?Q<00`0C4`204`80

3a<00`0C4`0a4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0m4`0301<C07lC00<04a<041<00`0C

4`0`4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07`C0P0C4`0301<C030C000b4`03

01<C0?lC;A<00`0C4`0H4`0301<C03hC00<04a<0Na<201@C00<04a<0<1<0038C00<04a<0oa<]4`03

01<C01PC00<04a<0?Q<00`0C4`1i4`805Q<00`0C4`0`4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C

4`0n4`0301<C07PC00<04a<05Q<00`0C4`0`4`00<Q<00`0C4`3o4bhC00<04a<05a<203lC00<04a<0

MQ<201TC00<04a<0<1<0038C00<04a<0oa<^4`0301<C01LC00<04a<0?Q<00`0C4`1d4`8071<00`0C

4`0_4`0071<00`0C4`024`0401<C4`<00a<00`0C4`044`0301<C0?lC;Q<00`0C4`0G4`0301<C03hC

00<04a<0La<00`0C4`0L4`0301<C02lC000K4`0301<000LC00<04a<00Q<00`0C00054`0301<C0?lC

;Q<00`0C4`0G4`0301<C03lC00<04a<0L1<201lC00<04a<0;a<001/C00<04`0021<00`0C4`034`03

01<C00<C0P3o4c0C00<04a<05Q<00`0C4`0o4`0301<C06dC0`0Q4`0301<C02lC000K4`0301<000PC

00@04a<C0P064`0301<C0?lC;a<00`0C4`0F4`0301<C03lC00<04a<0K1<202<C00<04a<0;a<001/C

00<04`001a<00`0C00024`0301<C00DC00<04a<0oa<_4`0301<C01HC0P104`0301<C06XC0P0U4`03

01<C02lC000L4`0301<C00LC00@04a<C0`054`0301<C0?lC;a<00`0C4`0F4`0301<C03lC00<04a<0

J1<202LC00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC00<04a<0?a<00`0C4`1V4`80:A<00`0C

4`0_4`00<Q<00`0C4`3o4c0C00<04a<05A<00`0C4`0o4`0301<C06@C0P0Z4`0301<C030C000b4`03

01<C0?lC<1<00`0C4`0?4`0301<C00<C00<04a<0?a<00`0C4`1R4`80;1<00`0C4`0`4`00<Q<00`0C

4`3o4c0C00<04a<03Q<00`0C00044`0301<C040C00<04a<0GQ<302hC00<04a<0<1<0038C00<04a<0

oa<`4`0301<C010C00<04a<00Q<3040C00<04a<0G1<3030C00<04a<0<1<0038C00<04a<0oa<a4`03

01<C00dC0P054`0301<C040C00<04a<0FQ<2038C0P0b4`00<Q<00`0C4`3o4c4C00<04a<03A<00`0C

4`044`0301<C044C00<04a<0Ea<203@C00<04a<0<A<0038C00<04a<0oa<b4`0301<C00`C0`044`03

01<C044C00<04a<0E1<303HC00<04a<0<A<0038C00<04a<0oa<b4`0301<C01<C00<04a<0@A<00`0C

4`1B4`<0=a<203<C000b4`0301<C0?lC<a<00`0C4`0B4`80@Q<00`0C4`1?4`<0>Q<00`0C4`0b4`00

<Q<00`0C4`3o4c<C00<04a<04Q<00`0C4`124`0301<C04`C0`0l4`0301<C038C000b4`0301<C0?lC

=1<00`0C4`0A4`0301<C048C00<04a<0BA<303hC00<04a<0<a<0038C00<04a<0oa<d4`0301<C014C

00<04a<0@Q<00`0C4`174`<0@1<00`0C4`0c4`008A<00`0C4`024`0301<C008C00<04a<011<00`0C

4`3o4cDC00<04a<041<00`0C4`124`0301<C04@C0`124`80=A<0020C00<04`001a<00`0C00054`03

01<C0?lC=A<00`0C4`0@4`0301<C04<C00<04a<0@1<304DC00<04a<0=1<0020C00<04`002A<00`0C

4`034`80oa<g4`0301<C00lC0P144`0301<C03dC0`174`80=Q<0020C00<04`001a<200HC00<04a<0

oa<f4`0301<C00lC00<04a<0A1<00`0C4`0i4`<0BQ<00`0C4`0e4`0081<00`0C00074`0301<C00DC

00<04a<0oa<g4`0301<C00hC00<04a<0A1<00`0C4`0f4`@0Ba<203LC000Q4`0301<C00HC0`054`03

01<C0?lC>1<00`0C4`0=4`0301<C04@C00<04a<0<a<304lC00<04a<0=Q<0038C00<04a<0oa<i4`03

01<C00`C00<04a<0AA<00`0C4`0_4`<0DA<00`0C4`0g4`00<Q<00`0C4`3o4cTC00<04a<031<00`0C

4`154`0301<C02/C101C4`80>A<0038C00<04a<0oa<j4`0301<C00/C0P174`0301<C02LC101F4`03

01<C03PC000b4`0301<C0?lC>Q<00`0C4`0;4`0301<C04HC00<04a<08a<505PC0P0j4`00<Q<00`0C

4`3o4c/C0P0;4`0301<C04HC00<04a<081<405/C0P0k4`00<Q<00`0C4`3o4cdC00<04a<021<00`0C

4`174`0301<C01/C101O4`0301<C03XC000b4`0301<C0?lC?Q<00`0C4`074`0301<C04LC0P0H4`D0

HA<00`0C4`0k4`00<Q<00`0C4`3o4chC00<04a<01a<00`0C4`184`0301<C01<C101T4`80?A<0038C

00<04a<0oa<o4`0301<C00HC0P1:4`0301<C00hC101W4`80?Q<0038C00<04a<0oa=04`801Q<00`0C

4`194`0301<C00XC101Z4`80?a<0038C00<04a<0oa=24`0301<C00<C00<04a<0BQ<00`0C4`054`D0

K1<2040C000b4`0301<C0?lC@a<200<C00<04a<0BQ<200034`0000<0L1<2044C000b4`0301<C0?lC

>a<5008C00@04a<00Q<00`0C4`194`D0La<2048C000L4`0301<C008C00<04a<00Q<00`0C4`024`03

01<C00@C00<04a<0oa<m4`0701<C4`0C00024`<0Aa<5008C00<04a<0LA<204<C000K4`0301<000PC

00L04a<C01<000DC00<04a<0oa<m4`0701<C4`0C00044`<0@1<500PC00<04a<0KQ<204DC000K4`03

01<000PC00<04a<00a<00`0C4`034`80oa<n4`0701<C4`0C00044`0401<003XC1@0=4`0301<C06dC

0P164`006a<00`0C00094`0301<C00801Q<00`0C4`3o4cdC00L04a<C01<000@C00@04a<C0`0a4`H0

4a<206/C0`174`006a<00`0C00074`0301<0008C00<04a<01A<00`0C4`3o4c`C0P044`0301<C00<C

00<04a<011<302PC1`0I4`80JA<204TC000L4`0301<C00HC0`024`<01A<00`0C4`3o4dPC00<04a<0

1a<501/C2@0P4`0301<C06@C0`1;4`00<Q<00`0C4`3o4dPC00<04a<031<L02TC0P1R4`<0CA<0038C

00<04a<0oa=84`80Da<205lC0`1?4`00<Q<00`0C4`3o4dPC00<04a<0Da<205XC101B4`00<Q<00`0C

4`3o4dPC00<04a<0E1<205HC101E4`00<Q<00`0C4`3o4dPC00<04a<0EQ<204lC1@1I4`00<Q<00`0C

4`3o4dPC00<04a<0Ea<304PC1P1M4`00<Q<00`0C4`3o4dPC00<04a<0FA<3040C1`1R4`00<Q<00`0C

4`3o4dPC0P1L4`<0>1<706PC000b4`0301<C0?lCB1<00`0C4`1N4`<0;Q<806hC000b4`0301<C0?lC

B1<00`0C4`1P4`D08a<807DC000b4`0301<C0?lCB1<00`0C4`1T4`L051<:07`C000b4`0301<C0?lC

B1<00`0C4`1Z4aD0QQ<0038C00<04a<0oa=84`0301<C0?lC1Q<002TC1@044`0301<C0?lCB1<20?lC

1a<002/C00<04a<011<00`0C4`3o4dPC00<04a<0oa<64`00:a<00`0C4`044`80oa=94`0301<C0?lC

1Q<002/C00<04a<0oa?o4ePC000[4`0301<C0?lCoa=H4`00:Q<20?lCoa=J4`00oa?o4hHC003o4olC

QQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<0074C10000a<0000700034`0000@C00<04a<01@024`03

01<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<0

0Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`3o4j`C

001a4`<021<00`0C4`034`0301<C00HC00<04a<00Q<01`0C4a<04`000Q<00`0C00024`0301<0008C

00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C

00024`0301<0008C00<04`000Q<00`0C002R4`80oa<94`00La<00`0C4`04008C00<04a<00Q<200PC

00<04a<00Q<01`0C4a<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C

00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C

002S4`0301<C0?lC1a<001TC10000a<00006008C2P024`800Q<3008C0`034`8000HC00004`0W4`80

21<01`0C4a<04`0021<00`0C4`034`0501<C4`000a<00`0C00024`0301<0008C00<04`000Q<00`0C

00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C

00<04`000a<00`0C4`2P4`<00Q<00`0C4`3o4`@C000J4`0601<C01<00Q<00`0C00044`0601<C01<0

0Q<00`0C00054`0301<C008C00D04a<C00024`0401<04`80<A<01`0C4a<04`0021<01`0C4a<04`00

0Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`03

01<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<000@C00<04a<0

VA<0200C4`0C01<0oa<54`006Q<01P0C4`0C00@C00<04a<00Q<00`0C4`024`0301<C008C00<04a<0

0a<00`0C4`024`0501<C4`000Q<0100C01<2030C0P044`801a<200<C0`034`0301<C008C00<04a<0

0Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`03

01<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`2J4`0801<C01<04`3o4`DC

000J4`0501<C01<00P034`800a<00`0C4`024`800a<00`0C4`034`0301<C008C00D04a<C00024`06

01<001<0oa<_4`<000@C01<0oa<54`006Q<01P0C4`0C008C00<04`000Q<00`0C00044`0>01<C01<0

4`0C01<04`024`0501<C4`000Q<01P0C000C0?lC<a<00`0C003o4`DC000I4`@000<C00002`024`D0

00DC00004`0500044`0000<C0P0011<001<20?lC=1<00`0C4`3o4`@C003o4olCQQ<00?lCoa>64`00

oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC0000\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.77084, -14.119, 0.0242408, 0.16996}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -57 0 ]

[.5 .63053 57 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -118 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(19.0700000000000002`) show

173.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .05106 m

.02499 .05106 L

.02606 .05105 L

.02729 .05105 L

.02846 .05104 L

.03053 .05101 L

.03279 .05097 L

.03527 .05091 L

.0379 .05084 L

.04262 .05066 L

.05205 .05017 L

.06245 .0494 L

.0842 .04714 L

.10458 .04434 L

.14335 .03801 L

.16306 .0348 L

.18458 .03174 L

.19454 .03059 L

.20517 .02961 L

.21033 .02924 L

.21519 .02896 L

.21956 .02877 L

.22202 .02869 L

.22429 .02863 L

.22555 .0286 L

.22674 .02858 L

.22782 .02857 L

.22898 .02856 L

.23025 .02856 L

.23089 .02856 L

.2316 .02856 L

.23285 .02857 L

.23402 .02858 L

.23513 .02859 L

.2363 .02862 L

.23839 .02867 L

.24065 .02874 L

.24311 .02885 L

.24829 .02914 L

.25381 .02958 L

.26377 .03069 L

.27402 .0323 L

.28512 .03459 L

.30527 .04027 L

.32515 .04786 L

.34619 .05801 L

.38408 .08138 L

.42442 .11188 L

.46324 .14377 L

.50452 .17609 L

Mistroke

.52515 .19015 L

.54428 .20131 L

.56398 .21064 L

.58252 .21727 L

.59241 .21997 L

.60309 .22227 L

.61279 .22385 L

.6217 .22492 L

.62642 .22535 L

.63147 .22572 L

.63623 .226 L

.64057 .22619 L

.64566 .22635 L

.64854 .22642 L

.65119 .22647 L

.65371 .22651 L

.65607 .22654 L

.65853 .22656 L

.66124 .22658 L

.6711 .22662 L

.6735 .22663 L

.67606 .22665 L

.67886 .22667 L

.68147 .2267 L

.68387 .22674 L

.68646 .22678 L

.69117 .2269 L

.69576 .22706 L

.69998 .22725 L

.70467 .22752 L

.7097 .22788 L

.71879 .22877 L

.72958 .23026 L

.73944 .23206 L

.7585 .23685 L

.77925 .24399 L

.82 .2625 L

.85924 .28199 L

.87891 .29068 L

.89695 .29738 L

.91628 .30286 L

.92643 .30499 L

.93713 .30671 L

.94665 .30779 L

.95199 .30823 L

.95684 .30854 L

.96137 .30875 L

.96392 .30884 L

.96628 .3089 L

.96834 .30895 L

Mistroke

.97061 .30898 L

.97175 .309 L

.97298 .30901 L

.97414 .30901 L

.9752 .30902 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.95769 .15508 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4gdC00<04a<0oa<64`00oa=m4`0301<C0?lC1Q<002TC1@3o4dlC0P3o4`LC

000[4`0301<C0?lCCa<00`0C4`1^4`d0RQ<002DC0`034`0301<C00@C0P3o4dTC00<04a<0IQ<800`C

3@1n4`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`1Q4`D081<807LC000[4`0301<C00@C00<04a<0

oa=84`0301<C05hC100/4`L0L1<002XC0P064`0301<C0?lCB1<00`0C4`1L4`<0=A<706XC000b4`03

01<C0?lCB1<205/C0P0o4`H0I1<0038C00<04a<0oa=84`0301<C05PC0P164`H0Ga<0038C00<04a<0

oa=84`0301<C05HC0P1>4`D0FQ<0038C00<04a<0:A<>3OlC4A<00`0C4`1E4`80Da<505HC000b4`03

01<C028C1`d>4`D=oa<<4`0301<C05@C00<04a<0Ea<5058C000b4`0301<C01PC2PdJ4`@=oa<84`80

Da<205hC0`1@4`00<Q<00`0C4`0C4`D=:1<43OlC11<00`0C4`0?4aH0;1<2064C101=4`00<Q<00`0C

4`0>4`D=<A<23OlC0Q<00`0C4`0:4`D05Q<9028C0P1U4`<0Ba<0038C00<04a<00a<;3CPC0`gn4`03

01<C00DC1@0S4`L06a<206PC0`194`00<Q<63DHC0Pg_4`D00Q<00`0C4`034`0301<C00<C0P0_4`H0

51<206/C0P184`00<Q<00`0C4`1;4`8=ka<01`0C4a<04`0011<00`0C4`0303HC1P0>4`80KA<304HC

000b4`0301<C04dC0PgW4`<00a<01`0C4a<04`0011<303hC1P094`0301<C06hC0P154`00<Q<00`0C

4`1?4`8=ja<01`0C4a<04`000a<204DC1@044`0301<C070C0P144`0071<00`0C4`024`0301<C008C

00<04a<00Q<00`0C4`044`0301<C054C00<=4a<0j1<01`0C4a<04`000Q<00`0C001:4`D0M1<2048C

000K4`0301<000PC00L04a<C01<000DC00<04a<0DQ<23NLC0P044`0401<0008C00<04a<0Ba<6074C

0P114`005Q<3008C00<04`0021<00`0C4`034`0301<C00<C0P1E4`8=ja<200@C00<04a<0BQ<00`0C

4`044`@0KQ<2040C000K4`0301<000TC00<04a<00P064`0301<C05HC00<=4a<0ia<00`0C4`044`03

01<C04TC00<04a<02A<406/C00<04a<0?Q<001/C00<04`001a<00`0C00024`0301<C00DC00<04a<0

Ea<00`dC4`3U4`0301<C00DC0P1:4`0301<C00dC101X4`80?Q<001`C00<04a<01Q<3008C0`054`03

01<C05PC0PgT4`0301<C00HC00<04a<0B1<00`0C4`0B4`@0IA<00`0C4`0l4`00<Q<00`0C4`1J4`03

3A<C0>0C00<04a<01a<00`0C4`184`0301<C01DC1@1R4`0301<C03/C000b4`0301<C05/C00<=4a<0

gQ<00`0C4`084`0301<C04LC00<04a<06Q<405lC0P0l4`00<Q<00`0C4`1L4`033A<C0=`C00<04a<0

2A<00`0C4`164`0301<C01lC101L4`80>a<0038C00<04a<0GA<23M/C00<04a<02Q<00`0C4`164`03

01<C028C1@1I4`0301<C03TC000b4`0301<C05lC00<=4a<0ea<00`0C4`0;4`80Aa<00`0C4`0V4`@0

Ea<00`0C4`0h4`00<Q<00`0C4`1P4`033A<C0=DC00<04a<031<00`0C4`154`0301<C02XC101D4`80

>A<0038C00<04a<0HA<00`dC4`3D4`0301<C00`C00<04a<0AA<00`0C4`0^4`@0DA<00`0C4`0g4`00

<Q<00`0C4`1R4`033A<C0=8C00<04a<03A<00`0C4`144`0301<C03<C0P1?4`80>1<0038C00<04a<0

Ha<00`dC4`3@4`0301<C00hC00<04a<0A1<00`0C4`0e4`@0C1<200033A<C03@C000b4`0301<C06@C

0Pg?4`0301<C00lC00<04a<0A1<00`0C4`0i4`80BA<63C@C000b4`0301<C06HC00<=4a<0c1<00`0C

4`0?4`80A1<00`0C4`0l4`@0A1<93C8C000b4`0301<C06LC00<=4a<0bQ<00`0C4`0@4`0301<C04<C

00<04a<0?a<3048C2@db4`00<Q<00`0C4`1X4`033A<C0<TC00<04a<041<00`0C4`134`0301<C048C

0`0o4`T=<Q<0024C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0JA<00`dC4`374`0301<C014C

00<04a<0@Q<00`0C4`164`<0>a<;3C4C000P4`0301<000LC00<04`001A<00`0C4`1Z4`033A<C0<HC

00<04a<04A<00`0C4`124`0301<C04TC0P0j4`T=<Q<001/C0`024`0301<000TC00<04a<00a<206`C

0Pg54`0301<C018C00<04a<0@Q<00`0C4`1;4`<0=a<93C8C000P4`0301<000LC0P064`0301<C06dC

00<=4a<0`Q<00`0C4`0B4`80@a<00`0C4`1>4`80=A<93C8C000P4`0301<000LC00<04a<01A<00`0C

4`1^4`033A<C0<0C00<04a<04a<00`0C4`114`0301<C054C0`0c4`H==1<0024C00<04a<01Q<300DC

00<04a<0Ka<00`dC4`2o4`0301<C01<C00<04a<0@A<00`0C4`1D4`80=1<010dC4`0c4`00<Q<00`0C

4`1`4`8=_Q<00`0C4`0D4`0301<C044C00<04a<0EQ<303@C00<04a<0<A<0038C00<04a<0LQ<00`dC

4`2k4`0301<C00hC00<04a<00a<00`0C4`104`0301<C05TC0`0b4`80<Q<0038C00<04a<0La<00`dC

4`2i4`0301<C00hC00<04`0011<00`0C4`104`0301<C05`C0P0a4`0301<C030C000b4`0301<C07@C

0Pfi4`0301<C00TC0`044`0301<C008C0`104`0301<C05hC0P0_4`0301<C030C000b4`0301<C07HC

0Pfg4`0301<C00hC0P054`0301<C03lC00<04a<0HA<302`C00<04a<0<1<0038C00<04a<0N1<00`dC

4`2d4`0301<C00hC00<04a<011<00`0C4`0o4`0301<C06@C00<04a<0:A<00`0C4`0`4`00<Q<00`0C

4`1i4`8=/a<00`0C4`0?4`<011<00`0C4`0o4`0301<C06DC0`0X4`80<A<0038C00<04a<0Na<23K4C

00<04a<05Q<00`0C4`0o4`0301<C06PC00<04a<09Q<00`0C4`0_4`00<Q<00`0C4`1m4`8=[a<00`0C

4`0F4`0301<C03lC00<04a<0JA<302DC00<04a<0;a<0038C00<04a<0Oa<23JdC00<04a<05Q<2040C

00<04a<0K1<202<C00<04a<0;a<0038C00<04a<0PA<33JXC00<04a<05Q<00`0C4`0o4`0301<C06dC

0P0R4`0301<C02lC000b4`0301<C08@C0PfX4`0301<C01HC00<04a<0?a<00`0C4`1_4`8081<00`0C

4`0_4`00<Q<00`0C4`264`D=XQ<00`0C4`0G4`0301<C03hC00<04a<0LQ<201hC00<04a<0;a<001`C

00<04a<00Q<0100C4a<300<C00<04a<011<00`0C4`2;4`@=WQ<00`0C4`0G4`0301<C03hC00<04a<0

M1<201`C00<04a<0;a<001/C00<04`001a<00`0C4`024`0301<000DC00<04a<0Sa<H3HHC00<04a<0

5a<203lC00<04a<0MQ<201XC00<04a<0;a<001HC0`024`0301<000PC00<04a<00a<00`0C4`034`80

Z1<83GhC00<04a<05a<00`0C4`0n4`0301<C07PC00<04a<05Q<00`0C4`0`4`006a<00`0C00084`04

01<C4`801Q<00`0C4`2_4`8=Na<00`0C4`0H4`0301<C03hC00<04a<0NA<201HC00<04a<0<1<001/C

00<04`001a<00`0C00024`0301<C00DC00<04a<0/A<43GLC00<04a<061<00`0C4`0n4`0301<C07/C

00<04a<04a<00`0C4`0`4`0071<00`0C4`074`0401<C4`<01A<00`0C4`2e4`<=M1<00`0C4`0H4`03

01<C03hC00<04a<0O1<00`0C4`0B4`0301<C030C000b4`0301<C0;PC0Peb4`0301<C01PC00<04a<0

?A<00`0C4`1n4`804Q<00`0C4`0`4`00<Q<00`0C4`2j4`8=L1<00`0C4`0H4`80?Q<00`0C4`204`80

41<00`0C4`0`4`00<Q<00`0C4`2l4`8=KQ<00`0C4`0H4`0301<C024C1@024`0301<C018C00<04a<0

2a<500034`00024C1@024`0301<C01lC1@024`0301<C01/C00@04a<C1@000a<000034`0301<C034C

000b4`0301<C0;hC0Pe/4`0301<C01PC00<04a<08a<01`0C4a<04`004a<00`0C4`0=4`0701<C4`0C

000R4`0301<C008C00<04a<08A<01`0C4a<04`0071<200@C00<04a<00a<0100C4`0c4`00<Q<00`0C

4`0V4`0301<C008C00@04a<C0`0S4`0301<C008C00<04a<00Q<3028C00<04a<00Q<0100C4a<202@C

00<04a<00Q<00`0C4`024`0301<C008=91<5044C00<04a<061<00`0C4`0S4`0301<C00<C00<04a<0

4A<00`0C4`0=4`0701<C4`0C000R4`0301<C008C00<04a<08A<01`0C4a<04`007Q<01@0C4a<000@C

0P024`0301<C034C000b4`0301<C02DC00<04`001a<00`0C4`0R4`0301<000TC00<04a<081<00`0C

00074`0301<0028C00<04`001a<00`0C00034`8=91<00`0C4`114`0301<C01PC00<04a<08a<0100C

4a<201@C00<04a<03A<0100C4a<202<C00<04a<00a<00`0C4`0P4`0301<C008C00<04a<07Q<20003

4`0C008C00<04`000Q<00`0C4`0a4`00<Q<00`0C4`0U4`0301<000PC00<04a<08A<00`0C00074`@0

8A<00`0C00074`0301<0028C00<04`001a<00`0C00054`8=8Q<00`0C4`104`0301<C01TC00<04a<0

8a<01@0C4a<001DC00<04a<03A<01@0C4a<002@C00L04a<C01<0028C00L04a<C01<0024C0P034`05

01<04`00=1<0038C00<04a<09A<00`0C00084`0301<C024C00<04`001a<00`0C000R4`0301<000LC

0P0S4`0301<000PC00<04a<01Q<23B0C00<04a<0@1<00`0C4`0I4`808a<200<C0`0C4`0301<C00`C

0P044`808A<200<C0`0Q4`8011<00`0C4`0P4`8011<200034`0C03<C000b4`0301<C02DC00<04`00

1a<00`0C000R4`0301<000PC0P0R4`0301<000LC00<04a<08Q<00`0C00074`0301<000TC0PdN4`03

01<C040C00<04a<06A<00`0C4`0m4`0301<C08PC00<04a<01A<00`0C4`0b4`00<Q<00`0C4`0V4`03

01<C00LC00<04a<08Q<00`0C4`084`0301<C024C00<04a<01a<202<C00<04a<01a<00`0C4`0:4`<=

6Q<2048C00<04a<06A<00`0C4`0m4`0301<C08TC0P054`0301<C038C000b4`0301<C0<dC0PeL4`03

01<C01TC00<04a<0?A<00`0C4`2;4`0501<C4`00=A<0038C00<04a<0ca<23EXC00<04a<06A<00`0C

4`0m4`0301<C08/C00@04a<04a<401lC000b4`0301<C0=4C0PeH4`0301<C01TC00<04a<0?A<00`0C

4`2<4`8051<3020C000b4`0301<C0=<C10dP4`<0:a?o00XC00<04a<07Q<0038C00<04a<0ea<63A/C

00<04a<0:a<00`0C4`024`0401<C00PC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C

4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<00a<00`0C00074`0301<C00HC

00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C

4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC

0`064`0301<C00`C0P0P4`00;1?V00`=1P094`0301<C030C00<04a<06A<00`0C4`0V4`0301<C01@C

00<04a<041<00`0C4`0V4`0301<C02HC00<04a<09Q<0100C4`0f4`00<Q<00`0C4`084`0301<C00TC

00<04a<02A<00`0C4`094`0301<C00PC00<04a<02A<00`0C4`094`0301<C00TC00<04a<021<00`0C

4`094`0301<C00TC00<04a<02A<00`0C4`094`0301<C00PC00<04a<02A<00`0C4`094`0301<C00TC

00<04a<021<00`0C4`094`0301<C00TC00<04a<031<4030C00<04a<06A<00`0C4`0m4`0301<C08/C

00D04a<C000e4`00<Q<00`0C4`0/4`0301<C02`C00<04a<0;1<00`0C4`0/4`0301<C02`C00<04a<0

@1<00`0C4`0I4`0301<C03dC00<04a<0RQ<00`0C4`024`0301<C03<C000b4`0301<C0?lC;1<00`0C

4`0I4`0301<C03dC00<04a<0RA<00`0C4`044`0301<C038C000b4`0301<C0?lC;1<00`0C4`0I4`80

?Q<00`0C4`274`801a<00`0C4`0b4`00<Q<00`0C4`3o4b`C00<04a<06A<00`0C4`0m4`0301<C08LC

00<04a<01Q<00`0C4`0b4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0m4`0301<C08HC00<04a<0

21<00`0C4`0a4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0m4`0301<C08@C0P0;4`0301<C034C

000b4`0301<C0?lC;A<00`0C4`0H4`0301<C03dC00<04a<0Pa<00`0C4`0;4`0301<C034C000b4`03

01<C0?lC;A<00`0C4`0H4`0301<C03dC00<04a<0PQ<00`0C4`0<4`0301<C034C000b4`0301<C0?lC

;A<00`0C4`0H4`80?Q<00`0C4`204`803a<00`0C4`0a4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C

4`0m4`0301<C07lC00<04a<041<00`0C4`0`4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`03

01<C07`C0P0C4`0301<C030C000b4`0301<C0?lC;A<00`0C4`0H4`0301<C03hC00<04a<0Na<201@C

00<04a<0<1<0038C00<04a<0oa<]4`0301<C01PC00<04a<0?Q<00`0C4`1i4`805Q<00`0C4`0`4`00

<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07PC00<04a<05Q<00`0C4`0`4`00<Q<00`0C

4`3o4bhC00<04a<05a<203lC00<04a<0MQ<201TC00<04a<0<1<0038C00<04a<0oa<^4`0301<C01LC

00<04a<0?Q<00`0C4`1d4`8071<00`0C4`0_4`0071<00`0C4`024`0401<C4`<00a<00`0C4`044`03

01<C0?lC;Q<00`0C4`0G4`0301<C03hC00<04a<0La<00`0C4`0L4`0301<C02lC000K4`0301<000LC

00<04a<00Q<00`0C00054`0301<C0?lC;Q<00`0C4`0G4`0301<C03lC00<04a<0L1<201lC00<04a<0

;a<001/C00<04`0021<00`0C4`034`0301<C00<C0P3o4c0C00<04a<05Q<00`0C4`0o4`0301<C06dC

0`0Q4`0301<C02lC000K4`0301<000PC00@04a<C0P064`0301<C0?lC;a<00`0C4`0F4`0301<C03lC

00<04a<0K1<202<C00<04a<0;a<001/C00<04`001a<00`0C00024`0301<C00DC00<04a<0oa<_4`03

01<C01HC0P104`0301<C06XC0P0U4`0301<C02lC000L4`0301<C00LC00@04a<C0`054`0301<C0?lC

;a<00`0C4`0F4`0301<C03lC00<04a<0J1<202LC00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC

00<04a<0?a<00`0C4`1V4`80:A<00`0C4`0_4`00<Q<00`0C4`3o4c0C00<04a<05A<00`0C4`0o4`03

01<C06@C0P0Z4`0301<C030C000b4`0301<C0?lC<1<00`0C4`0?4`0301<C00<C00<04a<0?a<00`0C

4`1R4`80;1<00`0C4`0`4`00<Q<00`0C4`3o4c0C00<04a<03Q<00`0C00044`0301<C040C00<04a<0

GQ<302hC00<04a<0<1<0038C00<04a<0oa<`4`0301<C010C00<04a<00Q<3040C00<04a<0G1<3030C

00<04a<0<1<0038C00<04a<0oa<a4`0301<C00dC0P054`0301<C040C00<04a<0FQ<2038C0P0b4`00

<Q<00`0C4`3o4c4C00<04a<03A<00`0C4`044`0301<C044C00<04a<0Ea<203@C00<04a<0<A<0038C

00<04a<0oa<b4`0301<C00`C0`044`0301<C044C00<04a<0E1<303HC00<04a<0<A<0038C00<04a<0

oa<b4`0301<C01<C00<04a<0@A<00`0C4`1B4`<0=a<203<C000b4`0301<C0?lC<a<00`0C4`0B4`80

@Q<00`0C4`1?4`<0>Q<00`0C4`0b4`00<Q<00`0C4`3o4c<C00<04a<04Q<00`0C4`124`0301<C04`C

0`0l4`0301<C038C000b4`0301<C0?lC=1<00`0C4`0A4`0301<C048C00<04a<0BA<303hC00<04a<0

<a<0038C00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`174`<0@1<00`0C4`0c4`008A<00`0C

4`024`0301<C008C00<04a<011<00`0C4`3o4cDC00<04a<041<00`0C4`124`0301<C04@C0`124`80

=A<0020C00<04`001a<00`0C00054`0301<C0?lC=A<00`0C4`0@4`0301<C04<C00<04a<0@1<304DC

00<04a<0=1<0020C00<04`002A<00`0C4`034`80oa<g4`0301<C00lC0P144`0301<C03dC0`174`80

=Q<0020C00<04`001a<200HC00<04a<0oa<f4`0301<C00lC00<04a<0A1<00`0C4`0i4`<0BQ<00`0C

4`0e4`0081<00`0C00074`0301<C00DC00<04a<0oa<g4`0301<C00hC00<04a<0A1<00`0C4`0f4`@0

Ba<203LC000Q4`0301<C00HC0`054`0301<C0?lC>1<00`0C4`0=4`0301<C04@C00<04a<0<a<304lC

00<04a<0=Q<0038C00<04a<0oa<i4`0301<C00`C00<04a<0AA<00`0C4`0_4`<0DA<00`0C4`0g4`00

<Q<00`0C4`3o4cTC00<04a<031<00`0C4`154`0301<C02/C101C4`80>A<0038C00<04a<0oa<j4`03

01<C00/C0P174`0301<C02LC101F4`0301<C03PC000b4`0301<C0?lC>Q<00`0C4`0;4`0301<C04HC

00<04a<08a<505PC0P0j4`00<Q<00`0C4`3o4c/C0P0;4`0301<C04HC00<04a<081<405/C0P0k4`00

<Q<00`0C4`3o4cdC00<04a<021<00`0C4`174`0301<C01/C101O4`0301<C03XC000b4`0301<C0?lC

?Q<00`0C4`074`0301<C04LC0P0H4`D0HA<00`0C4`0k4`00<Q<00`0C4`3o4chC00<04a<01a<00`0C

4`184`0301<C01<C101T4`80?A<0038C00<04a<0oa<o4`0301<C00HC0P1:4`0301<C00hC101W4`80

?Q<0038C00<04a<0oa=04`801Q<00`0C4`194`0301<C00XC101Z4`80?a<0038C00<04a<0oa=24`03

01<C00<C00<04a<0BQ<00`0C4`054`D0K1<2040C000b4`0301<C0?lC@a<200<C00<04a<0BQ<20003

4`0000<0L1<2044C000b4`0301<C0?lC>a<5008C00@04a<00Q<00`0C4`194`D0La<2048C000L4`03

01<C008C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0oa<m4`0701<C4`0C00024`<0Aa<5008C

00<04a<0LA<204<C000K4`0301<000PC00L04a<C01<000DC00<04a<0oa<m4`0701<C4`0C00044`<0

@1<500PC00<04a<0KQ<204DC000K4`0301<000PC00<04a<00a<00`0C4`034`80oa<n4`0701<C4`0C

00044`0401<003XC1@0=4`0301<C06dC0P164`006a<00`0C00094`0301<C00801Q<00`0C4`3o4cdC

00L04a<C01<000@C00@04a<C0`0a4`H04a<206/C0`174`006a<00`0C00074`0301<0008C00<04a<0

1A<00`0C4`3o4c`C0P044`0301<C00<C00<04a<011<302PC1`0I4`80JA<204TC000L4`0301<C00HC

0`024`<01A<00`0C4`3o4dPC00<04a<01a<501/C2@0P4`0301<C06@C0`1;4`00<Q<00`0C4`3o4dPC

00<04a<031<L02TC0P1R4`<0CA<0038C00<04a<0oa=84`80Da<205lC0`1?4`00<Q<00`0C4`3o4dPC

00<04a<0Da<205XC101B4`00<Q<00`0C4`3o4dPC00<04a<0E1<205HC101E4`00<Q<00`0C4`3o4dPC

00<04a<0EQ<204lC1@1I4`00<Q<00`0C4`3o4dPC00<04a<0Ea<304PC1P1M4`00<Q<00`0C4`3o4dPC

00<04a<0FA<3040C1`1R4`00<Q<00`0C4`3o4dPC0P1L4`<0>1<706PC000b4`0301<C0?lCB1<00`0C

4`1N4`<0;Q<806hC000b4`0301<C0?lCB1<00`0C4`1P4`D08a<807DC000b4`0301<C0?lCB1<00`0C

4`1T4`L051<:07`C000b4`0301<C0?lCB1<00`0C4`1Z4aD0QQ<0038C00<04a<0oa=84`0301<C0?lC

1Q<002TC1@044`0301<C0?lCB1<20?lC1a<002/C00<04a<011<00`0C4`3o4dPC00<04a<0oa<64`00

:a<00`0C4`044`80oa=94`0301<C0?lC1Q<002/C00<04a<0oa?o4ePC000[4`0301<C0?lCoa=H4`00

:Q<20?lCoa=J4`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<0074C10000a<0

000700034`0000@C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C

00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C

4`024`0301<C008C00@04a<C0`3o4jdC001a4`<021<00`0C4`034`0301<C00DC00<04`000a<01`0C

4a<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C

00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C4`2R4`80oa<94`00

La<00`0C4`04008C00<04a<00Q<200LC00<04`000a<01`0C4a<04`000Q<00`0C00024`0301<0008C

00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C

00024`0301<0008C00<04`000a<00`0C4`2R4`0301<C0?lC1a<001TC10000a<00006008C2P024`80

0Q<3008C0`034`8000HC00004`0W4`8021<01`0C4a<04`001a<00`0C00044`0601<C01<00Q<00`0C

00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C

00<04`000Q<00`0C00024`0301<0008C00<04`000a<00`0C4`2P4`<00Q<00`0C4`3o4`@C000J4`06

01<C01<00Q<00`0C00044`0601<C01<00Q<00`0C00054`0301<C008C00D04a<C00024`0401<04`80

<A<01`0C4a<04`001a<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`03

01<0008C00<04`000Q<00`0C00044`0301<C09TC00P04a<04`0C0?lC1A<001XC00H04a<04`044`03

01<C008C00<04a<00Q<00`0C4`024`0301<C00<C00<04a<00Q<01@0C4a<0008C00@04`0C0P0`4`80

11<200PC00@04a<C0`034`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C

4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C

00<04a<00Q<00`0C4`2J4`0801<C01<04`3o4`DC000J4`0501<C01<00P034`800a<00`0C4`024`80

0a<00`0C4`034`0301<C008C00D04a<C00024`0601<001<0oa<_4`<000@C01<0oa<54`006Q<01P0C

4`0C008C00<04`000Q<00`0C00044`0>01<C01<04`0C01<04`024`0501<C4`000Q<01P0C000C0?lC

<a<00`0C003o4`DC000I4`@000<C00002`024`D000DC00004`0500044`0000<C0P0011<001<20?lC

=1<00`0C4`3o4`@C003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC

003o4olCQQ<00?lCoa>64`00oa?o4hHC0000\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.77084, -14.119, 0.0242408, 0.16996}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -57 0 ]

[.5 .63053 57 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -118 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(18.7899999999999884`) show

173.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .08707 m

.02499 .08707 L

.02606 .08707 L

.02729 .08706 L

.02846 .08704 L

.03053 .087 L

.03279 .08695 L

.03527 .08686 L

.0379 .08676 L

.04262 .08651 L

.04749 .08618 L

.05205 .0858 L

.06245 .08471 L

.08274 .08168 L

.10458 .07726 L

.14581 .06666 L

.18551 .05579 L

.20554 .05102 L

.22371 .04754 L

.23384 .04608 L

.24338 .04505 L

.24863 .04465 L

.25112 .04451 L

.25345 .04439 L

.25598 .0443 L

.25732 .04426 L

.25875 .04423 L

.25947 .04422 L

.26026 .04421 L

.261 .04421 L

.26168 .0442 L

.26298 .0442 L

.26363 .0442 L

.26435 .04421 L

.26557 .04423 L

.2667 .04425 L

.26794 .04428 L

.26927 .04432 L

.27198 .04443 L

.27444 .04457 L

.2792 .04493 L

.2837 .04537 L

.29371 .04677 L

.29935 .04781 L

.30455 .04893 L

.32332 .05426 L

.34396 .06249 L

.3843 .08515 L

.42312 .11342 L

.4644 .14671 L

Mistroke

.50416 .17732 L

.5424 .20115 L

.56212 .21029 L

.5831 .21741 L

.59341 .21995 L

.60455 .22202 L

.60967 .22276 L

.61507 .22341 L

.62013 .2239 L

.62474 .22425 L

.62962 .22455 L

.63424 .22475 L

.63677 .22483 L

.63912 .2249 L

.64169 .22495 L

.64311 .22498 L

.64441 .22499 L

.64658 .22502 L

.64772 .22502 L

.64892 .22503 L

.64996 .22503 L

.65094 .22504 L

.652 .22504 L

.65314 .22504 L

.65439 .22503 L

.65509 .22503 L

.65574 .22503 L

.65818 .22501 L

.66276 .22498 L

.66745 .22494 L

.67003 .22492 L

.67248 .2249 L

.67475 .22489 L

.67604 .22488 L

.67723 .22488 L

.67823 .22488 L

.67933 .22488 L

.68048 .22488 L

.68156 .22488 L

.68277 .22489 L

.68408 .2249 L

.68546 .22491 L

.68674 .22492 L

.68904 .22496 L

.6915 .22501 L

.69438 .22508 L

.69711 .22517 L

.70222 .2254 L

.70683 .22568 L

.71192 .22607 L

Mistroke

.7222 .22717 L

.73173 .22859 L

.74065 .23031 L

.76091 .23566 L

.77944 .24225 L

.81917 .26063 L

.85738 .28008 L

.87872 .28983 L

.89805 .29719 L

.90774 .30022 L

.91821 .30297 L

.92726 .30491 L

.9372 .30656 L

.94193 .30718 L

.94701 .30773 L

.95139 .30812 L

.95616 .30846 L

.95896 .30861 L

.96155 .30873 L

.96397 .30882 L

.96664 .3089 L

.96779 .30893 L

.96903 .30895 L

.9701 .30897 L

.97127 .30899 L

.97252 .309 L

.97384 .30901 L

.97506 .30902 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.91227 .09073 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4gdC00<04a<0oa<64`00oa=m4`0301<C0?lC1Q<002TC1@3o4dlC0P3o4`LC

000[4`0301<C0?lCCa<00`0C4`1^4`d0RQ<002DC0`034`0301<C00@C0P3o4dTC00<04a<0IQ<800`C

3@1n4`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`1Q4`D081<807LC000[4`0301<C00@C00<04a<0

oa=84`0301<C05hC100/4`L0L1<002XC0P064`0301<C0?lCB1<00`0C4`1L4`<0=A<706XC000b4`03

01<C0?lCB1<205/C0P0o4`H0I1<0038C00<04a<0oa=84`0301<C05PC0P164`H0Ga<0038C00<04a<0

oa=84`0301<C05HC0P1>4`D0FQ<0038C00<04a<0oa=84`0301<C05DC0P1C4`D0EQ<0038C00<04a<0

oa=84`0301<C05@C00<04a<0Ea<5058C000b4`0301<C0?lCB1<205<C0P1N4`<0D1<0038C00<04a<0

oa=84`0301<C00lC5P0/4`80HA<404dC000b4`0301<C030C3Pgo4`XC00<04a<02Q<501HC2@0R4`80

IA<304/C000b4`0301<C02`C10d>4`L=oa<34`0301<C00DC1@0S4`L06a<206PC0`194`00<Q<00`0C

4`0X4`@=6A<33O8C1@024`0301<C00<C00<04a<00a<202lC1P0D4`80Ja<204PC000b4`0301<C02@C

10dP4`8=lQ<01`0C4a<04`0011<00`0C4`0303HC1P0>4`80KA<300<C00<=4a<0@1<0038C00<04a<0

8A<33BHC0PgZ4`<00a<01`0C4a<04`0011<303hC1P094`0301<C06hC00<03@d010e04`00<Q<00`0C

4`0M4`@=:a<00`dC4`3]4`0701<C4`0C00034`80AA<500@C00<04a<0Ka<93ChC000L4`0301<C008C

00<04a<00Q<00`0C4`024`0301<C00@C00<04a<06A<43C0C0Pg]4`0701<C4`0C00024`0301<004XC

1@1a4`T=?Q<001/C00<04`0021<01`0C4a<04`001A<00`0C4`0C4`H==Q<23NXC0P044`0401<0008C

00<04a<0Ba<606dC2@dn4`005Q<3008C00<04`0021<00`0C4`034`0301<C00<C0P0?4`D=?Q<23NhC

0P044`0301<C04XC00<04a<011<406PC2`dm4`006a<00`0C00094`0301<C00801Q<00`0C4`094`D=

AA<23N/C00<04a<011<00`0C4`194`0301<C00TC101U4`T=?Q<001/C00<04`001a<00`0C00024`03

01<C00DC00@04a<C20e<4`8=j1<00`0C4`054`80BQ<00`0C4`0=4`@0HA<93ChC000L4`0301<C00HC

0`024`<01A<43EHC00<=4a<0i1<00`0C4`064`0301<C04PC00<04a<04Q<405dC2@dn4`00<Q<00`0C

4`1H4`8=ha<00`0C4`074`0301<C04PC00<04a<05A<505XC1Pd24`0301<C03/C000b4`0301<C05XC

00<=4a<0ga<00`0C4`084`0301<C04LC00<04a<06Q<405XC00<=4a<00Q<203`C000b4`0301<C05/C

00<=4a<0gA<00`0C4`094`0301<C04HC00<04a<07a<405`C0P0k4`00<Q<00`0C4`1L4`8=g1<00`0C

4`0:4`0301<C04HC00<04a<08Q<505TC00<04a<0>A<0038C00<04a<0GQ<00`dC4`3H4`0301<C00/C

0P174`0301<C02HC101G4`0301<C03PC000b4`0301<C05lC00<=4a<0eQ<00`0C4`0<4`0301<C04DC

00<04a<0:Q<405@C0P0i4`00<Q<00`0C4`1P4`033A<C0=DC00<04a<031<00`0C4`154`0301<C02hC

101A4`0301<C03LC000b4`0301<C064C0PgD4`0301<C00dC00<04a<0A1<00`0C4`0c4`80Ca<203PC

000b4`0301<C06<C00<=4a<0d1<00`0C4`0>4`0301<C04@C00<04a<0=A<404`C0P0g4`00<Q<00`0C

4`1T4`033A<C0<hC00<04a<03a<00`0C4`144`0301<C03TC0P1;4`0301<C03DC000b4`0301<C06DC

00<=4a<0cA<00`0C4`0?4`80A1<00`0C4`0l4`@0Aa<203HC000b4`0301<C06HC0Pg<4`0301<C010C

00<04a<0@a<00`0C4`0o4`<0AQ<00`0C4`0d4`00<Q<00`0C4`1X4`033A<C0<TC00<04a<041<00`0C

4`134`0301<C048C0`134`80=A<0024C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0JA<00`dC

4`374`0301<C014C00<04a<0@Q<00`0C4`164`<0@A<00`0C4`0c4`0081<00`0C00074`0301<000DC

00<04a<0JQ<00`dC4`364`0301<C014C00<04a<0@Q<00`0C4`194`80?a<00`0C4`0c4`006a<3008C

00<04`002A<00`0C4`034`80K1<23LDC00<04a<04Q<00`0C4`124`0301<C04/C0`0m4`0301<C038C

000P4`0301<000LC0P064`0301<C06dC00<=4a<0`Q<00`0C4`0B4`80@a<00`0C4`1>4`80>a<00`0C

4`0b4`0081<00`0C00074`0301<C00DC00<04a<0KQ<00`dC4`304`0301<C01<C00<04a<0@A<00`0C

4`1A4`<0>1<00`0C4`0b4`008A<00`0C4`064`<01A<00`0C4`1_4`033A<C0;lC00<04a<04a<00`0C

4`114`0301<C05@C0P0g4`0301<C034C000b4`0301<C070C0Pfn4`0301<C01@C00<04a<0@A<00`0C

4`1F4`<0=1<00`0C4`0a4`00<Q<00`0C4`1b4`033A<C0;/C00<04a<03Q<00`0C4`034`0301<C040C

00<04a<0FA<3038C0P0b4`00<Q<00`0C4`1c4`033A<C0;TC00<04a<03Q<00`0C00044`0301<C040C

00<04a<0G1<2034C00<04a<0<1<0038C00<04a<0M1<23KTC00<04a<02A<300@C00<04a<00Q<3040C

00<04a<0GQ<202lC00<04a<0<1<0038C00<04a<0MQ<23KLC00<04a<03Q<200DC00<04a<0?a<00`0C

4`1Q4`<0;1<00`0C4`0`4`00<Q<00`0C4`1h4`033A<C0;@C00<04a<03Q<00`0C4`044`0301<C03lC

00<04a<0I1<00`0C4`0Y4`0301<C030C000b4`0301<C07TC0Pfc4`0301<C00lC0`044`0301<C03lC

00<04a<0IA<302PC0P0a4`00<Q<00`0C4`1k4`8=/A<00`0C4`0F4`0301<C03lC00<04a<0J1<00`0C

4`0V4`0301<C02lC000b4`0301<C07dC0Pf_4`0301<C01HC00<04a<0?a<00`0C4`1Y4`<09A<00`0C

4`0_4`00<Q<00`0C4`1o4`8=[A<00`0C4`0F4`80@1<00`0C4`1/4`808a<00`0C4`0_4`00<Q<00`0C

4`214`<=ZQ<00`0C4`0F4`0301<C03lC00<04a<0KA<2028C00<04a<0;a<0038C00<04a<0Q1<23JPC

00<04a<05Q<00`0C4`0o4`0301<C06lC0P0P4`0301<C02lC000b4`0301<C08HC1@fR4`0301<C01LC

00<04a<0?Q<00`0C4`1b4`807Q<00`0C4`0_4`0071<00`0C4`024`0401<C4`<00a<00`0C4`044`03

01<C08/C1PfL4`0301<C01LC00<04a<0?Q<00`0C4`1d4`8071<00`0C4`0_4`006a<00`0C00074`03

01<C008C00<04`001A<00`0C4`2A4aX=PQ<00`0C4`0G4`80?a<00`0C4`1f4`806Q<00`0C4`0_4`00

5Q<3008C00<04`0021<00`0C4`034`0301<C00<C0P2/4`H=O1<00`0C4`0G4`0301<C03hC00<04a<0

N1<00`0C4`0F4`0301<C030C000K4`0301<000PC00@04a<C0P064`0301<C0;4C0`eh4`0301<C01PC

00<04a<0?Q<00`0C4`1i4`805Q<00`0C4`0`4`006a<00`0C00074`0301<0008C00<04a<01A<00`0C

4`2d4`8=MQ<00`0C4`0H4`0301<C03hC00<04a<0Na<00`0C4`0C4`0301<C030C000L4`0301<C00LC

00@04a<C0`054`0301<C0;HC0Ped4`0301<C01PC00<04a<0?Q<00`0C4`1l4`0301<C018C00<04a<0

<1<0038C00<04a<0^1<23G8C00<04a<061<00`0C4`0m4`0301<C07hC0P0B4`0301<C030C000b4`03

01<C0;XC0Pe`4`0301<C01PC0P0n4`0301<C080C0P0@4`0301<C030C000b4`0301<C0;`C0Pe^4`03

01<C01PC00<04a<08A<5008C00<04a<04Q<00`0C4`0;4`D000<C00008A<5008C00<04a<07a<5008C

00<04a<06a<0100C4a<500034`0000<C00<04a<0<A<0038C00<04a<0_Q<23F`C00<04a<061<00`0C

4`0S4`0701<C4`0C000C4`0301<C00dC00L04a<C01<0028C00<04a<00Q<00`0C4`0Q4`0701<C4`0C

000L4`8011<00`0C4`034`0401<C03<C000b4`0301<C02HC00<04a<00Q<0100C4a<302<C00<04a<0

0Q<00`0C4`024`<08Q<00`0C4`024`0401<C4`8091<00`0C4`024`0301<C008C00<04a<00`dS4`D0

@A<00`0C4`0H4`0301<C02<C00<04a<00a<00`0C4`0A4`0301<C00dC00L04a<C01<0028C00<04a<0

0Q<00`0C4`0Q4`0701<C4`0C000N4`0501<C4`0011<2008C00<04a<0<A<0038C00<04a<09A<00`0C

00074`0301<C028C00<04`002A<00`0C4`0P4`0301<000LC00<04`008Q<00`0C00074`0301<000@C

0PdS4`0301<C044C00<04a<061<00`0C4`0S4`0401<C4`8051<00`0C4`0=4`0401<C4`808a<00`0C

4`034`0301<C020C00<04a<00Q<00`0C4`0N4`8000<C01<00Q<00`0C00024`0301<C034C000b4`03

01<C02DC00<04`0021<00`0C4`0Q4`0301<000LC100Q4`0301<000LC00<04`008Q<00`0C00074`03

01<000HC0`dP4`0301<C040C00<04a<06A<00`0C4`0S4`0501<C4`005A<00`0C4`0=4`0501<C4`00

91<01`0C4a<04`008Q<01`0C4a<04`008A<200<C00D04`0C000d4`00<Q<00`0C4`0U4`0301<000PC

00<04a<08A<00`0C00074`0301<0028C00<04`001a<202<C00<04`0021<00`0C4`084`8=7Q<00`0C

4`104`0301<C01TC0P0S4`800a<301<C00<04a<031<200@C0P0Q4`800a<3024C0P044`0301<C020C

0P044`8000<C01<0<a<0038C00<04a<09A<00`0C00074`0301<0028C00<04`0021<2028C00<04`00

1a<00`0C4`0R4`0301<000LC00<04`002a<23A`C00<04a<0@1<00`0C4`0I4`0301<C03dC00<04a<0

R1<00`0C4`054`0301<C038C000b4`0301<C02HC00<04a<01a<00`0C4`0R4`0301<C00PC00<04a<0

8A<00`0C4`074`808a<00`0C4`074`0301<C00`C0PdI4`80@Q<00`0C4`0I4`0301<C03dC00<04a<0

RA<200DC00<04a<0<Q<0038C00<04a<0cQ<23E/C00<04a<06A<00`0C4`0m4`0301<C08/C00D04a<C

000e4`00<Q<00`0C4`3@4`8=FA<00`0C4`0I4`0301<C03dC00<04a<0Ra<0100C4`0C4`@07a<0038C

00<04a<0dQ<23ELC00<04a<06A<00`0C4`0m4`0301<C08`C0P0D4`<081<0038C00<04a<0e1<53AhC

0`0[4ol02Q<00`0C4`0N4`00<Q<00`0C4`3I4`@=6a<00`0C4`0[4`0301<C008C00@04a<021<00`0C

4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC

00<04a<01A<00`0C4`034`0301<000LC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C

4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC

00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<300HC00<04a<031<2020C000/4nH030d600TC

00<04a<0<1<00`0C4`0I4`0301<C02HC00<04a<051<00`0C4`0@4`0301<C02HC00<04a<09Q<00`0C

4`0V4`0401<C03HC000b4`0301<C00PC00<04a<02A<00`0C4`094`0301<C00TC00<04a<021<00`0C

4`094`0301<C00TC00<04a<02A<00`0C4`084`0301<C00TC00<04a<02A<00`0C4`094`0301<C00TC

00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0C4`084`0301<C00TC00<04a<02A<00`0C

4`0<4`@0<1<00`0C4`0I4`0301<C03dC00<04a<0Ra<01@0C4a<003DC000b4`0301<C02`C00<04a<0

;1<00`0C4`0/4`0301<C02`C00<04a<0;1<00`0C4`104`0301<C01TC00<04a<0?A<00`0C4`2:4`03

01<C008C00<04a<0<a<0038C00<04a<0oa</4`0301<C01TC00<04a<0?A<00`0C4`294`0301<C00@C

00<04a<0<Q<0038C00<04a<0oa</4`0301<C01TC0P0n4`0301<C08LC0P074`0301<C038C000b4`03

01<C0?lC;1<00`0C4`0I4`0301<C03dC00<04a<0Qa<00`0C4`064`0301<C038C000b4`0301<C0?lC

;A<00`0C4`0H4`0301<C03dC00<04a<0QQ<00`0C4`084`0301<C034C000b4`0301<C0?lC;A<00`0C

4`0H4`0301<C03dC00<04a<0Q1<200/C00<04a<0<A<0038C00<04a<0oa<]4`0301<C01PC00<04a<0

?A<00`0C4`234`0301<C00/C00<04a<0<A<0038C00<04a<0oa<]4`0301<C01PC00<04a<0?A<00`0C

4`224`0301<C00`C00<04a<0<A<0038C00<04a<0oa<]4`0301<C01PC0P0n4`0301<C080C0P0?4`03

01<C034C000b4`0301<C0?lC;A<00`0C4`0H4`0301<C03dC00<04a<0Oa<00`0C4`0@4`0301<C030C

000b4`0301<C0?lC;A<00`0C4`0H4`0301<C03hC00<04a<0O1<201<C00<04a<0<1<0038C00<04a<0

oa<]4`0301<C01PC00<04a<0?Q<00`0C4`1k4`8051<00`0C4`0`4`00<Q<00`0C4`3o4bdC00<04a<0

61<00`0C4`0n4`0301<C07TC0P0F4`0301<C030C000b4`0301<C0?lC;A<00`0C4`0H4`0301<C03hC

00<04a<0N1<00`0C4`0F4`0301<C030C000b4`0301<C0?lC;Q<00`0C4`0G4`80?a<00`0C4`1f4`80

6A<00`0C4`0`4`00<Q<00`0C4`3o4bhC00<04a<05a<00`0C4`0n4`0301<C07@C0P0L4`0301<C02lC

000L4`0301<C008C00@04a<C0`034`0301<C00@C00<04a<0oa<^4`0301<C01LC00<04a<0?Q<00`0C

4`1c4`0301<C01`C00<04a<0;a<001/C00<04`001a<00`0C4`024`0301<000DC00<04a<0oa<^4`03

01<C01LC00<04a<0?a<00`0C4`1`4`807a<00`0C4`0_4`006a<00`0C00084`0301<C00<C00<04a<0

0a<20?lC<1<00`0C4`0F4`0301<C03lC00<04a<0KA<3024C00<04a<0;a<001/C00<04`0021<0100C

4a<200HC00<04a<0oa<_4`0301<C01HC00<04a<0?a<00`0C4`1/4`808a<00`0C4`0_4`006a<00`0C

00074`0301<0008C00<04a<01A<00`0C4`3o4blC00<04a<05Q<2040C00<04a<0JQ<202DC00<04a<0

;a<001`C00<04a<01a<0100C4a<300DC00<04a<0oa<_4`0301<C01HC00<04a<0?a<00`0C4`1X4`80

9a<00`0C4`0_4`00<Q<00`0C4`3o4blC00<04a<05Q<00`0C4`0o4`0301<C06HC0P0Y4`0301<C02lC

000b4`0301<C0?lC<1<00`0C4`0E4`0301<C03lC00<04a<0I1<202XC00<04a<0<1<0038C00<04a<0

oa<`4`0301<C00lC00<04a<00a<00`0C4`0o4`0301<C068C0P0/4`0301<C030C000b4`0301<C0?lC

<1<00`0C4`0>4`0301<000@C00<04a<0@1<00`0C4`1N4`<0;Q<00`0C4`0`4`00<Q<00`0C4`3o4c0C

00<04a<041<00`0C4`024`<0@1<00`0C4`1L4`<0<1<00`0C4`0`4`00<Q<00`0C4`3o4c4C00<04a<0

3A<200DC00<04a<0@1<00`0C4`1J4`80<Q<2038C000b4`0301<C0?lC<A<00`0C4`0=4`0301<C00@C

00<04a<0@A<00`0C4`1G4`80=1<00`0C4`0a4`00<Q<00`0C4`3o4c8C00<04a<031<300@C00<04a<0

@A<00`0C4`1D4`<0=Q<00`0C4`0a4`00<Q<00`0C4`3o4c8C00<04a<04a<00`0C4`114`0301<C058C

0`0g4`80<a<0038C00<04a<0oa<c4`0301<C018C0P124`0301<C04lC0`0j4`0301<C038C000b4`03

01<C0?lC<a<00`0C4`0B4`0301<C048C00<04a<0C1<303`C00<04a<0<Q<0038C00<04a<0oa<d4`03

01<C014C00<04a<0@Q<00`0C4`194`<0?Q<00`0C4`0c4`00<Q<00`0C4`3o4c@C00<04a<04A<00`0C

4`124`0301<C04LC0`104`0301<C03<C000Q4`0301<C008C00<04a<00Q<00`0C4`044`0301<C0?lC

=A<00`0C4`0@4`0301<C048C00<04a<0A1<3048C0P0e4`0081<00`0C00074`0301<000DC00<04a<0

oa<e4`0301<C010C00<04a<0@a<00`0C4`104`<0AA<00`0C4`0d4`0081<00`0C00094`0301<C00<C

0P3o4cLC00<04a<03a<204@C00<04a<0?A<304LC0P0f4`0081<00`0C00074`801Q<00`0C4`3o4cHC

00<04a<03a<00`0C4`144`0301<C03TC0`1:4`0301<C03DC000P4`0301<000LC00<04a<01A<00`0C

4`3o4cLC00<04a<03Q<00`0C4`144`0301<C03HC101;4`80=a<0024C00<04a<01Q<300DC00<04a<0

oa<h4`0301<C00dC00<04a<0A1<00`0C4`0c4`<0Ca<00`0C4`0f4`00<Q<00`0C4`3o4cTC00<04a<0

31<00`0C4`154`0301<C02lC0`1A4`0301<C03LC000b4`0301<C0?lC>A<00`0C4`0<4`0301<C04DC

00<04a<0:a<405<C0P0i4`00<Q<00`0C4`3o4cXC00<04a<02a<204LC00<04a<09a<405HC00<04a<0

>1<0038C00<04a<0oa<j4`0301<C00/C00<04a<0AQ<00`0C4`0S4`D0F1<203XC000b4`0301<C0?lC

>a<200/C00<04a<0AQ<00`0C4`0P4`@0Fa<203/C000b4`0301<C0?lC?A<00`0C4`084`0301<C04LC

00<04a<06a<405lC00<04a<0>Q<0038C00<04a<0oa<n4`0301<C00LC00<04a<0Aa<201PC1@1Q4`03

01<C03/C000b4`0301<C0?lC?Q<00`0C4`074`0301<C04PC00<04a<04a<406@C0P0m4`00<Q<00`0C

4`3o4clC00<04a<01Q<204XC00<04a<03Q<406LC0P0n4`00<Q<00`0C4`3o4d0C0P064`0301<C04TC

00<04a<02Q<406XC0P0o4`00<Q<00`0C4`3o4d8C00<04a<00a<00`0C4`1:4`0301<C00DC1@1/4`80

@1<0038C00<04a<0oa=34`800a<00`0C4`1:4`8000<C00000`1`4`80@A<0038C00<04a<0oa<k4`D0

0Q<0100C4`024`0301<C04TC1@1c4`80@Q<001`C00<04a<00Q<00`0C4`024`0301<C008C00<04a<0

11<00`0C4`3o4cdC00L04a<C01<0008C0`174`D00Q<00`0C4`1a4`80@a<001/C00<04`0021<01`0C

4a<04`001A<00`0C4`3o4cdC00L04a<C01<000@C0`104`D021<00`0C4`1^4`80AA<001/C00<04`00

21<00`0C4`034`0301<C00<C0P3o4chC00L04a<C01<000@C00@04`00>Q<500dC00<04a<0KA<204HC

000K4`0301<000TC00<04a<00P064`0301<C0?lC?A<01`0C4a<04`0011<0100C4a<3034C1P0C4`80

Ja<304LC000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C0?lC?1<200@C00<04a<00a<00`0C

4`044`<0:1<701TC0P1Y4`80BA<001`C00<04a<01Q<3008C0`054`0301<C0?lCB1<00`0C4`074`D0

6a<9020C00<04a<0I1<304/C000b4`0301<C0?lCB1<00`0C4`0<4a`0:A<2068C0`1=4`00<Q<00`0C

4`3o4dPC0P1C4`80Ga<304lC000b4`0301<C0?lCB1<00`0C4`1C4`80FQ<4058C000b4`0301<C0?lC

B1<00`0C4`1D4`80EQ<405DC000b4`0301<C0?lCB1<00`0C4`1F4`80Ca<505TC000b4`0301<C0?lC

B1<00`0C4`1G4`<0B1<605dC000b4`0301<C0?lCB1<00`0C4`1I4`<0@1<7068C000b4`0301<C0?lC

B1<205`C0`0h4`L0J1<0038C00<04a<0oa=84`0301<C05hC0`0^4`P0KQ<0038C00<04a<0oa=84`03

01<C060C1@0S4`P0MA<0038C00<04a<0oa=84`0301<C06@C1`0D4`X0O1<0038C00<04a<0oa=84`03

01<C06XC5@264`00<Q<00`0C4`3o4dPC00<04a<0oa<64`00:A<500@C00<04a<0oa=84`80oa<74`00

:a<00`0C4`044`0301<C0?lCB1<00`0C4`3o4`HC000[4`0301<C00@C0P3o4dTC00<04a<0oa<64`00

:a<00`0C4`3o4olCF1<002/C00<04a<0oa?o4ePC000Z4`80oa?o4eXC003o4olCQQ<00?lCoa>64`00

oa?o4hHC003o4olCQQ<00?lCoa>64`00LA<400034`0000L00Q<00`0C4`024`0301<C008C00<04a<0

0Q<0100C4a<200<C0P034`800a<200<C0P034`800a<200<C0P034`800a<200<C0P044`0301<C008C

00<04a<00Q<30?lC[1<0074C0`084`0701<C4`0C00084`0701<C4`0C00044`0301<C008C00<04a<0

0Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`03

01<C008C00H04a<04`024`0301<000@C00<04a<0X1<20?lC2A<007<C00<04a<010024`0701<C4`0C

00084`0701<C4`0C00034`800a<200<C0P034`800a<200<C0P034`800a<200<C0P034`800a<2008C

00<04`000Q<00`0C00024`@0XQ<00`0C4`3o4`LC000I4`@000<C00001P024`X00Q<2008C0`024`<0

0a<200064`0001<09a<200PC00<04a<00Q<00`0C4`084`0501<C4`000a<00`0C00024`0301<0008C

00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C

00024`0301<000<C00<04a<00Q<01`0C4a<04`00XA<3008C00<04a<0oa<44`006Q<01P0C4`0C008C

00<04`0011<01P0C4`0C008C00<04`001A<00`0C4`024`0501<C4`000Q<0100C01<2034C00L04a<C

01<000LC00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`03

01<000<C0P044`0301<C09TC00P04a<04`0C0?lC1A<001XC00H04a<04`044`0301<C008C00<04a<0

0Q<00`0C4`024`0301<C00<C00<04a<00Q<01@0C4a<0008C00@04`0C0P0`4`8011<00`0C4`064`<0

0a<00`0C4`024`800a<200<C0P034`800a<200<C0P034`800a<200<C0P034`800a<200<C00<04a<0

0Q<00`0C4`034`0501<C4`00W1<0200C4`0C01<0oa<54`006Q<01@0C4`0C00800a<200<C00<04a<0

0Q<200<C00<04a<00a<00`0C4`024`0501<C4`000Q<01P0C000C0?lC;a<300044`0C0?lC1A<001XC

00H04a<04`024`0301<0008C00<04`0011<03P0C4`0C01<04`0C01<00Q<01@0C4a<0008C00H04`00

4`3o4c<C00<04`00oa<54`006A<400034`0000/00Q<500054`0001<01@0011<000034`8000@C000C

0P3o4c@C00<04a<0oa<44`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.77084, -14.119, 0.0242408, 0.16996}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -57 0 ]

[.5 .63053 57 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -118 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(18.5100000000000015`) show

173.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .11865 m

.02499 .11865 L

.02606 .11865 L

.02729 .11863 L

.02846 .11861 L

.03053 .11857 L

.03279 .11851 L

.03527 .11841 L

.0379 .11829 L

.04262 .11801 L

.04749 .11763 L

.05205 .1172 L

.06245 .11594 L

.07305 .11428 L

.08274 .11244 L

.10458 .10726 L

.14429 .09496 L

.18248 .0815 L

.2038 .07431 L

.22313 .06858 L

.23281 .06612 L

.24328 .06384 L

.25309 .06213 L

.26226 .06094 L

.26684 .0605 L

.2692 .06032 L

.27176 .06015 L

.27322 .06007 L

.27456 .06001 L

.27583 .05996 L

.27722 .05992 L

.27846 .05989 L

.27963 .05987 L

.28087 .05986 L

.28156 .05986 L

.2822 .05986 L

.28342 .05986 L

.28473 .05988 L

.28597 .0599 L

.2871 .05993 L

.28842 .05998 L

.28985 .06004 L

.29246 .06018 L

.29519 .06038 L

.29808 .06063 L

.30326 .06122 L

.3127 .06271 L

.32283 .06496 L

.34115 .07067 L

.36232 .07985 L

Mistroke

.38242 .09092 L

.42067 .11701 L

.46137 .14865 L

.50055 .17817 L

.52056 .19135 L

.54218 .20336 L

.56309 .21241 L

.57303 .21577 L

.5823 .21836 L

.59217 .22058 L

.60116 .22212 L

.61115 .22336 L

.61664 .22384 L

.62184 .22419 L

.62645 .22441 L

.62906 .22451 L

.63152 .22457 L

.63278 .2246 L

.6341 .22463 L

.63525 .22465 L

.63647 .22466 L

.63779 .22467 L

.63901 .22468 L

.63976 .22469 L

.64047 .22469 L

.64179 .22469 L

.64286 .22469 L

.64403 .22468 L

.64525 .22467 L

.6464 .22467 L

.64845 .22464 L

.65064 .22461 L

.66022 .22443 L

.67038 .22422 L

.67316 .22417 L

.67612 .22412 L

.67865 .22409 L

.68009 .22408 L

.68079 .22408 L

.68144 .22407 L

.68261 .22407 L

.68389 .22406 L

.68515 .22406 L

.68585 .22406 L

.68648 .22407 L

.68763 .22407 L

.68886 .22408 L

.69003 .2241 L

.69111 .22411 L

.69353 .22415 L

Mistroke

.69618 .22422 L

.69895 .22431 L

.70155 .22442 L

.70652 .22469 L

.71194 .22509 L

.71706 .22557 L

.72181 .22611 L

.73079 .22742 L

.74034 .22924 L

.76177 .23497 L

.78195 .24237 L

.82052 .26058 L

.86154 .28155 L

.88198 .29076 L

.90105 .29787 L

.91939 .30305 L

.92967 .3052 L

.93904 .30671 L

.94352 .30728 L

.94829 .30779 L

.9524 .30815 L

.95684 .30847 L

.95932 .30861 L

.96159 .30872 L

.96389 .30881 L

.96604 .30888 L

.9684 .30894 L

.96965 .30896 L

.97099 .30898 L

.97166 .30899 L

.97239 .309 L

.97303 .309 L

.97371 .30901 L

.975 .30902 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.86684 .05967 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4gdC00<04a<0oa<64`00oa=m4`0301<C0?lC1Q<002TC1@3o4dlC0P3o4`LC

000[4`0301<C0?lCCa<00`0C4`1^4`d0RQ<002DC0`034`0301<C00@C0P3o4dTC00<04a<0IQ<800`C

3@1n4`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`1Q4`D081<807LC000[4`0301<C00@C00<04a<0

oa=84`0301<C05hC100/4`L0L1<002XC0P064`0301<C0?lCB1<00`0C4`1L4`<0=A<706XC000b4`03

01<C0?lCB1<205/C0P0o4`H0I1<0038C00<04a<0oa=84`0301<C05PC0P164`H0Ga<0038C00<04a<0

oa=84`0301<C05HC0P1>4`D0FQ<0038C00<04a<0oa=84`0301<C05DC0P1C4`D01a<00`dC4`1<4`00

<Q<00`0C4`3o4dPC00<04a<0E1<00`0C4`1G4`D01Pe<4`00<Q<00`0C4`3o4dPC0P1C4`80GQ<93DXC

000b4`0301<C0?lCB1<00`0C4`0?4aH0;1<205lC2@e:4`00<Q<00`0C4`3o4dPC00<04a<02Q<501HC

2@0R4`80H1<93DXC000b4`0301<C0?lCB1<00`0C4`054`D08a<701/C0P1P4`/=BA<0038C00<04a<0

oa<k4`D00Q<00`0C4`034`0301<C00<C0P0_4`H051<2068C2@d204PC000b4`0301<C0?lC?A<01`0C

4a<04`0011<00`0C4`0303HC1P0>4`80Ha<93@044`0004HC000b4`0301<C03DC3Pgc4`<00a<01`0C

4a<04`0011<303hC1P094`0301<C068C2@d34`80AA<0038C00<04a<0<1<53@hC1@gd4`0701<C4`0C

00034`80AA<500@C00<04a<0I1<63@HC0P144`0071<00`0C4`024`0301<C008C00<04a<00Q<00`0C

4`044`0301<C02`C10dH4`8=lQ<01`0C4a<04`000Q<00`0C001:4`D0JA<00`dC4`084`80@Q<001/C

00<04`0021<01`0C4a<04`001A<00`0C4`0X4`@=7Q<33NhC0P044`0401<0008C00<04a<0Ba<6074C

0P114`005Q<3008C00<04`0021<00`0C4`034`0301<C00<C0P0W4`8=9A<23O8C0P044`0301<C04XC

00<04a<011<406hC0P104`006a<00`0C00094`0301<C00801Q<00`0C4`0S4`<=:A<23NlC00<04a<0

11<00`0C4`194`0301<C00TC101[4`0301<C03hC000K4`0301<000LC00<04`000Q<00`0C4`054`03

01<C024C0Pd^4`8=k1<00`0C4`054`80BQ<00`0C4`0=4`@0J1<203hC000L4`0301<C00HC0`024`<0

1A<00`0C4`0N4`<=<Q<23NTC00<04a<01Q<00`0C4`184`0301<C018C101U4`0301<C03`C000b4`03

01<C01`C0Pdg4`033A<C0>DC00<04a<01a<00`0C4`184`0301<C01DC1@1R4`0301<C03/C000b4`03

01<C01TC0`dj4`8=i1<00`0C4`084`0301<C04LC00<04a<06Q<405lC0P0l4`00<Q<00`0C4`0F4`<=

?a<23N4C00<04a<02A<00`0C4`164`0301<C01lC101L4`80>a<0038C00<04a<04Q<43D@C00<=4a<0

gA<00`0C4`0:4`0301<C04HC00<04a<08Q<505TC00<04a<0>A<0038C00<04a<03Q<43DTC0PgL4`03

01<C00/C0P174`0301<C02HC101G4`0301<C03PC000b4`0301<C00PC1Pe?4`8=fA<00`0C4`0<4`03

01<C04DC00<04a<0:Q<405@C0P0i4`00<Q<;3ELC00<=4a<0eQ<00`0C4`0<4`0301<C04DC00<04a<0

;Q<4054C00<04a<0=a<0038C00<04a<0H1<00`dC4`3D4`0301<C00dC00<04a<0A1<00`0C4`0c4`80

Ca<203PC000b4`0301<C064C0PgC4`0301<C00hC00<04a<0A1<00`0C4`0e4`@0C1<203LC000b4`03

01<C06<C00<=4a<0ca<00`0C4`0?4`0301<C04@C00<04a<0>A<204/C00<04a<0=A<0038C00<04a<0

I1<00`dC4`3>4`0301<C00lC0P144`0301<C03`C10174`80=Q<0038C00<04a<0IA<00`dC4`3<4`03

01<C010C00<04a<0@a<00`0C4`0o4`<0AQ<00`0C4`0d4`00<Q<00`0C4`1V4`8=c1<00`0C4`0@4`03

01<C04<C00<04a<0@Q<304<C0P0e4`008A<00`0C4`024`0301<C008C00<04a<011<00`0C4`1X4`03

3A<C0<PC00<04a<04A<00`0C4`124`0301<C04HC0`114`0301<C03<C000P4`0301<000LC00<04`00

1A<00`0C4`1Y4`033A<C0<LC00<04a<04A<00`0C4`124`0301<C04TC0P0o4`0301<C03<C000K4`<0

0Q<00`0C00094`0301<C00<C0P1[4`033A<C0<DC00<04a<04Q<00`0C4`124`0301<C04/C0`0m4`03

01<C038C000P4`0301<000LC0P064`0301<C06/C0Pg54`0301<C018C0P134`0301<C04hC0P0k4`03

01<C038C000P4`0301<000LC00<04a<01A<00`0C4`1]4`033A<C0<4C00<04a<04a<00`0C4`114`03

01<C054C0`0h4`0301<C038C000Q4`0301<C00HC0`054`0301<C06hC00<=4a<0`1<00`0C4`0C4`03

01<C044C00<04a<0E1<203LC00<04a<0<A<0038C00<04a<0Ka<23KlC00<04a<051<00`0C4`114`03

01<C05HC0`0d4`0301<C034C000b4`0301<C074C00<=4a<0_1<00`0C4`0>4`0301<C00<C00<04a<0

@1<00`0C4`1I4`<0<Q<2038C000b4`0301<C078C00<=4a<0^Q<00`0C4`0>4`0301<000@C00<04a<0

@1<00`0C4`1L4`80<A<00`0C4`0`4`00<Q<00`0C4`1c4`8=^Q<00`0C4`094`<011<00`0C4`024`<0

@1<00`0C4`1N4`80;a<00`0C4`0`4`00<Q<00`0C4`1e4`8=^1<00`0C4`0>4`801A<00`0C4`0o4`03

01<C064C0`0/4`0301<C030C000b4`0301<C07LC00<=4a<0]A<00`0C4`0>4`0301<C00@C00<04a<0

?a<00`0C4`1T4`0301<C02TC00<04a<0<1<0038C00<04a<0N1<23K@C00<04a<03a<300@C00<04a<0

?a<00`0C4`1U4`<0:1<2034C000b4`0301<C07XC0Pfb4`0301<C01HC00<04a<0?a<00`0C4`1X4`03

01<C02HC00<04a<0;a<0038C00<04a<0O1<23K0C00<04a<05Q<00`0C4`0o4`0301<C06TC0`0U4`03

01<C02lC000b4`0301<C07hC0Pf^4`0301<C01HC0P104`0301<C06`C0P0S4`0301<C02lC000b4`03

01<C080C0Pf/4`0301<C01HC00<04a<0?a<00`0C4`1]4`808Q<00`0C4`0_4`00<Q<00`0C4`224`@=

Z1<00`0C4`0F4`0301<C03lC00<04a<0Ka<2020C00<04a<0;a<0038C00<04a<0QQ<23JDC00<04a<0

5a<00`0C4`0n4`0301<C078C0P0N4`0301<C02lC000L4`0301<C008C00@04a<C0`034`0301<C00@C

00<04a<0R1<93@`C1Pf:4`0301<C01LC00<04a<0?Q<00`0C4`1d4`8071<00`0C4`0_4`006a<00`0C

00074`0301<C008C00<04`001A<00`0C4`2A4``=1Q<:3H0C00<04a<05a<203lC00<04a<0MQ<201XC

00<04a<0;a<001HC0`024`0301<000PC00<04a<00a<00`0C4`034`80[Q<43G`C00<04a<05a<00`0C

4`0n4`0301<C07PC00<04a<05Q<00`0C4`0`4`006a<00`0C00084`0401<C4`801Q<00`0C4`2a4`@=

Ma<00`0C4`0H4`0301<C03hC00<04a<0NA<201HC00<04a<0<1<001/C00<04`001a<00`0C00024`03

01<C00DC00<04a<0]A<23GDC00<04a<061<00`0C4`0n4`0301<C07/C00<04a<04a<00`0C4`0`4`00

71<00`0C4`074`0401<C4`<01A<00`0C4`2g4`<=LQ<00`0C4`0H4`0301<C03hC00<04a<0O1<00`0C

4`0B4`0301<C030C000b4`0301<C0;XC0Pe`4`0301<C01PC00<04a<0?A<00`0C4`1n4`804Q<00`0C

4`0`4`00<Q<00`0C4`2l4`<=KA<00`0C4`0H4`80?Q<00`0C4`204`8041<00`0C4`0`4`00<Q<00`0C

4`2o4`8=Ja<00`0C4`0H4`0301<C024C1@024`0301<C018C00<04a<02a<500034`00024C1@024`03

01<C01lC1@024`0301<C01/C00@04a<C1@000a<000034`0301<C034C000b4`0301<C0<4C0PeY4`03

01<C01PC00<04a<08a<01`0C4a<04`004a<00`0C4`0=4`0701<C4`0C000R4`0301<C008C00<04a<0

8A<01`0C4a<04`0071<200@C00<04a<00a<0100C4`0c4`00<Q<00`0C4`0V4`0301<C008C00@04a<C

0`0S4`0301<C008C00<04a<00Q<3028C00<04a<00Q<0100C4a<202@C00<04a<00Q<00`0C4`024`03

01<C00<C0PdQ4`D0@A<00`0C4`0H4`0301<C02<C00<04a<00a<00`0C4`0A4`0301<C00dC00L04a<C

01<0028C00<04a<00Q<00`0C4`0Q4`0701<C4`0C000N4`0501<C4`0011<2008C00<04a<0<A<0038C

00<04a<09A<00`0C00074`0301<C028C00<04`002A<00`0C4`0P4`0301<000LC00<04`008Q<00`0C

00074`0301<000HC0PdQ4`0301<C044C00<04a<061<00`0C4`0S4`0401<C4`8051<00`0C4`0=4`04

01<C4`808a<00`0C4`034`0301<C020C00<04a<00Q<00`0C4`0N4`8000<C01<00Q<00`0C00024`03

01<C034C000b4`0301<C02DC00<04`0021<00`0C4`0Q4`0301<000LC100Q4`0301<000LC00<04`00

8Q<00`0C00074`0301<000PC00<=4a<07Q<00`0C4`104`0301<C01TC00<04a<08a<01@0C4a<001DC

00<04a<03A<01@0C4a<002@C00L04a<C01<0028C00L04a<C01<0024C0P034`0501<04`00=1<0038C

00<04a<09A<00`0C00084`0301<C024C00<04`001a<00`0C000R4`0301<000LC0P0S4`0301<000PC

00<04a<021<23AhC00<04a<0@1<00`0C4`0I4`808a<200<C0`0C4`0301<C00`C0P044`808A<200<C

0`0Q4`8011<00`0C4`0P4`8011<200034`0C03<C000b4`0301<C02DC00<04`001a<00`0C000R4`03

01<000PC0P0R4`0301<000LC00<04a<08Q<00`0C00074`0301<000/C0PdL4`0301<C040C00<04a<0

6A<00`0C4`0m4`0301<C08PC00<04a<01A<00`0C4`0b4`00<Q<00`0C4`0V4`0301<C00LC00<04a<0

8Q<00`0C4`084`0301<C024C00<04a<01a<202<C00<04a<01a<00`0C4`0<4`8=6A<2048C00<04a<0

6A<00`0C4`0m4`0301<C08TC0P054`0301<C038C000b4`0301<C0<hC0PeK4`0301<C01TC00<04a<0

?A<00`0C4`2;4`0501<C4`00=A<0038C00<04a<0d1<23ETC00<04a<06A<00`0C4`0m4`0301<C08/C

00@04a<04a<401lC000b4`0301<C0=8C0PeG4`0301<C01TC00<04a<0?A<00`0C4`2<4`8051<3020C

000b4`0301<C0=@C10dO4`<0:a?o00XC00<04a<07Q<0038C00<04a<0f1<43A`C00<04a<0:a<00`0C

4`024`0401<C00PC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC

00<04a<01A<00`0C4`064`0301<C00DC00<04a<00a<00`0C00074`0301<C00HC00<04a<01A<00`0C

4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC

00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC0`064`0301<C00`C

0P0P4`00;1?U00d=1P094`0301<C030C00<04a<06A<00`0C4`0V4`0301<C01@C00<04a<041<00`0C

4`0V4`0301<C02HC00<04a<09Q<0100C4`0f4`00<Q<00`0C4`084`0301<C00TC00<04a<02A<00`0C

4`094`0301<C00PC00<04a<02A<00`0C4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC

00<04a<02A<00`0C4`094`0301<C00PC00<04a<02A<00`0C4`094`0301<C00TC00<04a<021<00`0C

4`094`0301<C00TC00<04a<031<4030C00<04a<06A<00`0C4`0m4`0301<C08/C00D04a<C000e4`00

<Q<00`0C4`0/4`0301<C02`C00<04a<0;1<00`0C4`0/4`0301<C02`C00<04a<0@1<00`0C4`0I4`03

01<C03dC00<04a<0RQ<00`0C4`024`0301<C03<C000b4`0301<C0?lC;1<00`0C4`0I4`0301<C03dC

00<04a<0RA<00`0C4`044`0301<C038C000b4`0301<C0?lC;1<00`0C4`0I4`80?Q<00`0C4`274`80

1a<00`0C4`0b4`00<Q<00`0C4`3o4b`C00<04a<06A<00`0C4`0m4`0301<C08LC00<04a<01Q<00`0C

4`0b4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0m4`0301<C08HC00<04a<021<00`0C4`0a4`00

<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0m4`0301<C08@C0P0;4`0301<C034C000b4`0301<C0?lC

;A<00`0C4`0H4`0301<C03dC00<04a<0Pa<00`0C4`0;4`0301<C034C000b4`0301<C0?lC;A<00`0C

4`0H4`0301<C03dC00<04a<0PQ<00`0C4`0<4`0301<C034C000b4`0301<C0?lC;A<00`0C4`0H4`80

?Q<00`0C4`204`803a<00`0C4`0a4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0m4`0301<C07lC

00<04a<041<00`0C4`0`4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07`C0P0C4`03

01<C030C000b4`0301<C0?lC;A<00`0C4`0H4`0301<C03hC00<04a<0Na<201@C00<04a<0<1<0038C

00<04a<0oa<]4`0301<C01PC00<04a<0?Q<00`0C4`1i4`805Q<00`0C4`0`4`00<Q<00`0C4`3o4bdC

00<04a<061<00`0C4`0n4`0301<C07PC00<04a<05Q<00`0C4`0`4`00<Q<00`0C4`3o4bhC00<04a<0

5a<203lC00<04a<0MQ<201TC00<04a<0<1<0038C00<04a<0oa<^4`0301<C01LC00<04a<0?Q<00`0C

4`1d4`8071<00`0C4`0_4`0071<00`0C4`024`0401<C4`<00a<00`0C4`044`0301<C0?lC;Q<00`0C

4`0G4`0301<C03hC00<04a<0La<00`0C4`0L4`0301<C02lC000K4`0301<000LC00<04a<00Q<00`0C

00054`0301<C0?lC;Q<00`0C4`0G4`0301<C03lC00<04a<0L1<201lC00<04a<0;a<001/C00<04`00

21<00`0C4`034`0301<C00<C0P3o4c0C00<04a<05Q<00`0C4`0o4`0301<C06dC0`0Q4`0301<C02lC

000K4`0301<000PC00@04a<C0P064`0301<C0?lC;a<00`0C4`0F4`0301<C03lC00<04a<0K1<202<C

00<04a<0;a<001/C00<04`001a<00`0C00024`0301<C00DC00<04a<0oa<_4`0301<C01HC0P104`03

01<C06XC0P0U4`0301<C02lC000L4`0301<C00LC00@04a<C0`054`0301<C0?lC;a<00`0C4`0F4`03

01<C03lC00<04a<0J1<202LC00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC00<04a<0?a<00`0C

4`1V4`80:A<00`0C4`0_4`00<Q<00`0C4`3o4c0C00<04a<05A<00`0C4`0o4`0301<C06@C0P0Z4`03

01<C030C000b4`0301<C0?lC<1<00`0C4`0?4`0301<C00<C00<04a<0?a<00`0C4`1R4`80;1<00`0C

4`0`4`00<Q<00`0C4`3o4c0C00<04a<03Q<00`0C00044`0301<C040C00<04a<0GQ<302hC00<04a<0

<1<0038C00<04a<0oa<`4`0301<C010C00<04a<00Q<3040C00<04a<0G1<3030C00<04a<0<1<0038C

00<04a<0oa<a4`0301<C00dC0P054`0301<C040C00<04a<0FQ<2038C0P0b4`00<Q<00`0C4`3o4c4C

00<04a<03A<00`0C4`044`0301<C044C00<04a<0Ea<203@C00<04a<0<A<0038C00<04a<0oa<b4`03

01<C00`C0`044`0301<C044C00<04a<0E1<303HC00<04a<0<A<0038C00<04a<0oa<b4`0301<C01<C

00<04a<0@A<00`0C4`1B4`<0=a<203<C000b4`0301<C0?lC<a<00`0C4`0B4`80@Q<00`0C4`1?4`<0

>Q<00`0C4`0b4`00<Q<00`0C4`3o4c<C00<04a<04Q<00`0C4`124`0301<C04`C0`0l4`0301<C038C

000b4`0301<C0?lC=1<00`0C4`0A4`0301<C048C00<04a<0BA<303hC00<04a<0<a<0038C00<04a<0

oa<d4`0301<C014C00<04a<0@Q<00`0C4`174`<0@1<00`0C4`0c4`008A<00`0C4`024`0301<C008C

00<04a<011<00`0C4`3o4cDC00<04a<041<00`0C4`124`0301<C04@C0`124`80=A<0020C00<04`00

1a<00`0C00054`0301<C0?lC=A<00`0C4`0@4`0301<C04<C00<04a<0@1<304DC00<04a<0=1<0020C

00<04`002A<00`0C4`034`80oa<g4`0301<C00lC0P144`0301<C03dC0`174`80=Q<0020C00<04`00

1a<200HC00<04a<0oa<f4`0301<C00lC00<04a<0A1<00`0C4`0i4`<0BQ<00`0C4`0e4`0081<00`0C

00074`0301<C00DC00<04a<0oa<g4`0301<C00hC00<04a<0A1<00`0C4`0f4`@0Ba<203LC000Q4`03

01<C00HC0`054`0301<C0?lC>1<00`0C4`0=4`0301<C04@C00<04a<0<a<304lC00<04a<0=Q<0038C

00<04a<0oa<i4`0301<C00`C00<04a<0AA<00`0C4`0_4`<0DA<00`0C4`0g4`00<Q<00`0C4`3o4cTC

00<04a<031<00`0C4`154`0301<C02/C101C4`80>A<0038C00<04a<0oa<j4`0301<C00/C0P174`03

01<C02LC101F4`0301<C03PC000b4`0301<C0?lC>Q<00`0C4`0;4`0301<C04HC00<04a<08a<505PC

0P0j4`00<Q<00`0C4`3o4c/C0P0;4`0301<C04HC00<04a<081<405/C0P0k4`00<Q<00`0C4`3o4cdC

00<04a<021<00`0C4`174`0301<C01/C101O4`0301<C03XC000b4`0301<C0?lC?Q<00`0C4`074`03

01<C04LC0P0H4`D0HA<00`0C4`0k4`00<Q<00`0C4`3o4chC00<04a<01a<00`0C4`184`0301<C01<C

101T4`80?A<0038C00<04a<0oa<o4`0301<C00HC0P1:4`0301<C00hC101W4`80?Q<0038C00<04a<0

oa=04`801Q<00`0C4`194`0301<C00XC101Z4`80?a<0038C00<04a<0oa=24`0301<C00<C00<04a<0

BQ<00`0C4`054`D0K1<2040C000b4`0301<C0?lC@a<200<C00<04a<0BQ<200034`0000<0L1<2044C

000b4`0301<C0?lC>a<5008C00@04a<00Q<00`0C4`194`D0La<2048C000L4`0301<C008C00<04a<0

0Q<00`0C4`024`0301<C00@C00<04a<0oa<m4`0701<C4`0C00024`<0Aa<5008C00<04a<0LA<204<C

000K4`0301<000PC00L04a<C01<000DC00<04a<0oa<m4`0701<C4`0C00044`<0@1<500PC00<04a<0

KQ<204DC000K4`0301<000PC00<04a<00a<00`0C4`034`80oa<n4`0701<C4`0C00044`0401<003XC

1@0=4`0301<C06dC0P164`006a<00`0C00094`0301<C00801Q<00`0C4`3o4cdC00L04a<C01<000@C

00@04a<C0`0a4`H04a<206/C0`174`006a<00`0C00074`0301<0008C00<04a<01A<00`0C4`3o4c`C

0P044`0301<C00<C00<04a<011<302PC1`0I4`80JA<204TC000L4`0301<C00HC0`024`<01A<00`0C

4`3o4dPC00<04a<01a<501/C2@0P4`0301<C06@C0`1;4`00<Q<00`0C4`3o4dPC00<04a<031<L02TC

0P1R4`<0CA<0038C00<04a<0oa=84`80Da<205lC0`1?4`00<Q<00`0C4`3o4dPC00<04a<0Da<205XC

101B4`00<Q<00`0C4`3o4dPC00<04a<0E1<205HC101E4`00<Q<00`0C4`3o4dPC00<04a<0EQ<204lC

1@1I4`00<Q<00`0C4`3o4dPC00<04a<0Ea<304PC1P1M4`00<Q<00`0C4`3o4dPC00<04a<0FA<3040C

1`1R4`00<Q<00`0C4`3o4dPC0P1L4`<0>1<706PC000b4`0301<C0?lCB1<00`0C4`1N4`<0;Q<806hC

000b4`0301<C0?lCB1<00`0C4`1P4`D08a<807DC000b4`0301<C0?lCB1<00`0C4`1T4`L051<:07`C

000b4`0301<C0?lCB1<00`0C4`1Z4aD0QQ<0038C00<04a<0oa=84`0301<C0?lC1Q<002TC1@044`03

01<C0?lCB1<20?lC1a<002/C00<04a<011<00`0C4`3o4dPC00<04a<0oa<64`00:a<00`0C4`044`80

oa=94`0301<C0?lC1Q<002/C00<04a<0oa?o4ePC000[4`0301<C0?lCoa=H4`00:Q<20?lCoa=J4`00

oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<0074C10000a<00007008C00<04a<0

0Q<00`0C4`024`0301<C00D00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C

00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<01@024`03

01<C0?lC[1<0074C0`084`0701<C4`0C00074`0301<000<C00L04a<C01<0008C00<04`000Q<00`0C

00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C

00<04`000Q<00`0C00034`0701<C4`0C002R4`80oa<94`00La<00`0C4`04008C00L04a<C01<000TC

00D04a<C00034`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`03

01<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00034`0301<C00<C00<04a<0

XA<00`0C4`3o4`LC000I4`@000<C00001P024`X00Q<2008C0`024`<00a<200064`0001<09a<200PC

00<04a<00Q<00`0C4`064`8011<01`0C4a<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C

00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<000<C

00@04a<C0P2R4`<00Q<00`0C4`3o4`@C000J4`0601<C01<00Q<00`0C00044`0601<C01<00Q<00`0C

00054`0301<C008C00D04a<C00024`0401<04`80<A<01`0C4a<04`001a<00`0C4`034`0701<C4`0C

00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C

00<04`000Q<00`0C00024`0301<0008C00<04`000a<01@0C4a<000HC00<04a<0VA<0200C4`0C01<0

oa<54`006Q<01P0C4`0C00@C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00a<00`0C4`024`05

01<C4`000Q<0100C01<2030C0P044`0301<C00HC0`024`8011<00`0C4`024`0301<C008C00<04a<0

0Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`03

01<C008C00@04a<C0P034`<00a<00`0C4`2J4`0801<C01<04`3o4`DC000J4`0501<C01<00P034`80

0a<00`0C4`024`800a<00`0C4`034`0301<C008C00D04a<C00024`0601<001<0oa<_4`<000@C01<0

oa<54`006Q<01P0C4`0C008C00<04`000Q<00`0C00044`0>01<C01<04`0C01<04`024`0501<C4`00

0Q<01P0C000C0?lC<a<00`0C003o4`DC000I4`@000<C00002`024`D000DC00004`0500044`0000<C

0P0011<001<20?lC=1<00`0C4`3o4`@C003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC0000\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.77084, -14.119, 0.0242408, 0.16996}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -57 0 ]

[.5 .63053 57 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -118 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(18.2300000000000004`) show

173.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .14384 m

.02499 .14384 L

.02606 .14383 L

.02729 .14382 L

.02846 .1438 L

.03053 .14375 L

.03279 .14368 L

.03527 .14359 L

.0379 .14346 L

.04262 .14315 L

.04749 .14275 L

.05205 .1423 L

.06245 .14096 L

.07305 .13919 L

.08274 .13722 L

.10458 .13165 L

.14429 .11822 L

.18248 .10309 L

.2038 .09474 L

.22313 .08781 L

.24351 .08169 L

.25245 .07951 L

.26226 .07754 L

.27162 .07612 L

.27673 .07554 L

.2815 .07514 L

.2842 .07497 L

.28553 .0749 L

.28676 .07485 L

.28785 .07481 L

.28906 .07478 L

.29027 .07475 L

.29155 .07474 L

.29223 .07473 L

.29295 .07473 L

.29423 .07473 L

.29494 .07474 L

.2956 .07475 L

.29633 .07476 L

.29711 .07478 L

.29851 .07482 L

.29984 .07488 L

.30232 .075 L

.30472 .07516 L

.30695 .07535 L

.31204 .07589 L

.31701 .07658 L

.32234 .0775 L

.33198 .07966 L

.34079 .08217 L

Mistroke

.35981 .0893 L

.38055 .09955 L

.42125 .12564 L

.46043 .15474 L

.50206 .18447 L

.52297 .19719 L

.54218 .20693 L

.56097 .21439 L

.57054 .21738 L

.58079 .21998 L

.59109 .22199 L

.60046 .22334 L

.60498 .22383 L

.60989 .22427 L

.61453 .22458 L

.61881 .2248 L

.62124 .22489 L

.62346 .22496 L

.6259 .22502 L

.62712 .22504 L

.62846 .22506 L

.62965 .22507 L

.63073 .22508 L

.63198 .22509 L

.63315 .22509 L

.63424 .22509 L

.63525 .22508 L

.63635 .22508 L

.63751 .22507 L

.63879 .22505 L

.63996 .22504 L

.64259 .225 L

.64734 .2249 L

.65813 .22459 L

.66737 .22432 L

.67243 .22419 L

.67491 .22414 L

.67719 .2241 L

.67965 .22407 L

.68095 .22406 L

.68166 .22405 L

.68231 .22405 L

.68298 .22405 L

.68371 .22404 L

.68501 .22404 L

.68574 .22404 L

.68653 .22404 L

.68728 .22405 L

.68796 .22405 L

.68916 .22406 L

Mistroke

.69027 .22408 L

.6916 .2241 L

.69281 .22412 L

.69528 .22418 L

.69794 .22427 L

.70271 .22448 L

.7078 .2248 L

.71259 .2252 L

.71694 .22563 L

.72762 .22707 L

.73767 .22891 L

.75776 .23409 L

.77624 .24057 L

.81575 .25869 L

.85374 .27813 L

.8749 .28802 L

.89418 .29568 L

.90376 .29887 L

.91418 .30183 L

.92395 .30412 L

.93311 .30584 L

.94252 .30718 L

.94752 .30773 L

.9529 .3082 L

.95824 .30855 L

.96093 .30869 L

.96387 .30881 L

.96638 .30889 L

.96777 .30892 L

.96907 .30895 L

.97029 .30897 L

.97161 .30899 L

.97281 .309 L

.97391 .30901 L

.975 .30902 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.82141 .04446 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4gdC00<04a<0oa<64`00oa=m4`0301<C0?lC1Q<002TC1@3o4dlC0P3o4`LC

000[4`0301<C0?lCCa<00`0C4`1^4`d0RQ<002DC0`034`0301<C00@C0P3o4dTC00<04a<0IQ<800`C

3@1n4`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`1Q4`D081<807LC000[4`0301<C00@C00<04a<0

oa=84`0301<C05hC100/4`L0L1<002XC0P064`0301<C0?lCB1<00`0C4`1L4`<0=A<7010C00<=4a<0

Ea<0038C00<04a<0oa=84`80Fa<203lC1P074`H=Ea<0038C00<04a<0oa=84`0301<C05PC0P164`H0

00<C3@d01`eE4`00<Q<00`0C4`3o4dPC00<04a<0EQ<204hC00<03@d01`eE4`00<Q<00`0C4`3o4dPC

00<04a<0EA<2050C2@eE4`00<Q<00`0C4`3o4dPC00<04a<0E1<00`0C4`1?4`/=0P1B4`00<Q<00`0C

4`3o4dPC0P1C4`80Da<93@8C0`1@4`00<Q<00`0C4`3o4dPC00<04a<03a<F02`C0P1D4`T=11<404dC

000b4`0301<C0?lCB1<00`0C4`0:4`D05Q<9028C0P1E4`T=1a<304/C000b4`0301<C0?lCB1<00`0C

4`054`D08a<701/C0P1G4`H=2a<304TC000b4`0301<C0?lC>a<5008C00<04a<00a<00`0C4`034`80

;a<601@C0P1K4`033A<C00dC0P184`00<Q<00`0C4`3o4cdC00L04a<C01<000@C00<04a<00`0f4`H0

3Q<206dC0`164`00<Q<00`0C4`3o4cLC0`034`0701<C4`0C00044`<0?Q<600TC00<04a<0KQ<204DC

000b4`0301<C0?lC?A<01`0C4a<04`000a<204DC1@044`0301<C070C0P144`0071<00`0C4`024`03

01<C008C00<04a<00Q<00`0C4`044`0301<C0?lC?A<01`0C4a<04`000Q<00`0C001:4`D0M1<2048C

000K4`0301<000PC00L04a<C01<000DC00<04a<0oa<l4`8011<0100C00024`0301<C04/C1P1a4`80

@A<001HC0`024`0301<000PC00<04a<00a<00`0C4`034`80>1<A3OTC0P044`0301<C04XC00<04a<0

11<406hC0P104`006a<00`0C00094`0301<C00801Q<00`0C4`0b4`D=4A<53O<C00<04a<011<00`0C

4`194`0301<C00TC101[4`0301<C03hC000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C030C

0PdK4`8=l1<00`0C4`054`80BQ<00`0C4`0=4`@0J1<203hC000L4`0301<C00HC0`024`<01A<00`0C

4`0/4`@=7a<23NdC00<04a<01Q<00`0C4`184`0301<C018C101U4`0301<C03`C000b4`0301<C02TC

0`dU4`8=jQ<00`0C4`074`0301<C04PC00<04a<05A<5068C00<04a<0>a<0038C00<04a<09a<23BXC

0PgW4`0301<C00PC00<04a<0Aa<00`0C4`0J4`@0Ga<203`C000b4`0301<C02DC0Pd^4`033A<C0><C

00<04a<02A<00`0C4`164`0301<C01lC101L4`80>a<0038C00<04a<08a<23C4C0PgR4`0301<C00XC

00<04a<0AQ<00`0C4`0R4`D0FA<00`0C4`0i4`00<Q<00`0C4`0P4`<==A<23MlC00<04a<02a<204LC

00<04a<09Q<405LC00<04a<0>1<0038C00<04a<071<43CXC00<=4a<0fa<00`0C4`0<4`0301<C04DC

00<04a<0:Q<405@C0P0i4`00<Q<00`0C4`0I4`<=?a<23M/C00<04a<031<00`0C4`154`0301<C02hC

101A4`0301<C03LC000b4`0301<C01LC0Pe44`8=f1<00`0C4`0=4`0301<C04@C00<04a<0<a<204lC

0P0h4`00<Q<00`0C4`0D4`<=B1<00`dC4`3D4`0301<C00hC00<04a<0A1<00`0C4`0e4`@0C1<203LC

000b4`0301<C018C0Pe<4`033A<C0=8C00<04a<03a<00`0C4`144`0301<C03TC0P1;4`0301<C03DC

000b4`0301<C00hC10e?4`8=dQ<00`0C4`0?4`80A1<00`0C4`0l4`@0Aa<203HC000b4`0301<C00PC

1PeE4`033A<C0<hC00<04a<041<00`0C4`134`0301<C03lC0`164`0301<C03@C000b4`0401<C4`L=

G1<00`dC4`3=4`0301<C010C00<04a<0@a<00`0C4`124`<0@a<203DC000Q4`0301<C008C00<04a<0

0Q<00`0C4`044`@=I1<23L`C00<04a<04A<00`0C4`124`0301<C04HC0`114`0301<C03<C000P4`03

01<000LC00<04`001A<00`0C4`1W4`033A<C0<TC00<04a<04A<00`0C4`124`0301<C04TC0P0o4`03

01<C03<C000K4`<00Q<00`0C00094`0301<C00<C0P1Y4`033A<C0<LC00<04a<04Q<00`0C4`124`03

01<C04/C0`0m4`0301<C038C000P4`0301<000LC0P064`0301<C06TC0Pg74`0301<C018C0P134`03

01<C04hC0P0k4`0301<C038C000P4`0301<000LC00<04a<01A<00`0C4`1[4`033A<C0<<C00<04a<0

4a<00`0C4`114`0301<C054C0`0h4`0301<C038C000Q4`0301<C00HC0`054`0301<C06`C00<=4a<0

`Q<00`0C4`0C4`0301<C044C00<04a<0E1<203LC00<04a<0<A<0038C00<04a<0KA<23L4C00<04a<0

51<00`0C4`114`0301<C05HC0`0d4`0301<C034C000b4`0301<C06lC00<=4a<0_Q<00`0C4`0>4`03

01<C00<C00<04a<0@1<00`0C4`1I4`<0<Q<2038C000b4`0301<C070C00<=4a<0_1<00`0C4`0>4`03

01<000@C00<04a<0@1<00`0C4`1L4`80<A<00`0C4`0`4`00<Q<00`0C4`1a4`8=_1<00`0C4`094`<0

11<00`0C4`024`<0@1<00`0C4`1N4`80;a<00`0C4`0`4`00<Q<00`0C4`1c4`033A<C0;TC00<04a<0

3Q<200DC00<04a<0?a<00`0C4`1Q4`<0;1<00`0C4`0`4`00<Q<00`0C4`1d4`8=^A<00`0C4`0>4`03

01<C00@C00<04a<0?a<00`0C4`1T4`0301<C02TC00<04a<0<1<0038C00<04a<0MQ<23KHC00<04a<0

3a<300@C00<04a<0?a<00`0C4`1U4`<0:1<2034C000b4`0301<C07PC0Pfd4`0301<C01HC00<04a<0

?a<00`0C4`1X4`0301<C02HC00<04a<0;a<0038C00<04a<0NQ<23K8C00<04a<05Q<00`0C4`0o4`03

01<C06TC0`0U4`0301<C02lC000b4`0301<C07`C0Pf`4`0301<C01HC0P104`0301<C06`C0P0S4`03

01<C02lC000b4`0301<C07hC0Pf^4`0301<C01HC00<04a<0?a<00`0C4`1]4`808Q<00`0C4`0_4`00

<Q<00`0C4`204`<=Za<00`0C4`0F4`0301<C03lC00<04a<0Ka<2020C00<04a<0;a<0038C00<04a<0

Pa<53JDC00<04a<05a<00`0C4`0n4`0301<C078C0P0N4`0301<C02lC000L4`0301<C008C00@04a<C

0`034`0301<C00@C00<04a<0R1<53A0C1`f94`0301<C01LC00<04a<0?Q<00`0C4`1d4`8071<00`0C

4`0_4`006a<00`0C00074`0301<C008C00<04`001A<00`0C4`2=4a0=1Q<93H4C00<04a<05a<203lC

00<04a<0MQ<201XC00<04a<0;a<001HC0`024`0301<000PC00<04a<00a<00`0C4`034`80[A<43GdC

00<04a<05a<00`0C4`0n4`0301<C07PC00<04a<05Q<00`0C4`0`4`006a<00`0C00084`0401<C4`80

1Q<00`0C4`2`4`@=N1<00`0C4`0H4`0301<C03hC00<04a<0NA<201HC00<04a<0<1<001/C00<04`00

1a<00`0C00024`0301<C00DC00<04a<0]1<23GHC00<04a<061<00`0C4`0n4`0301<C07/C00<04a<0

4a<00`0C4`0`4`0071<00`0C4`074`0401<C4`<01A<00`0C4`2f4`<=La<00`0C4`0H4`0301<C03hC

00<04a<0O1<00`0C4`0B4`0301<C030C000b4`0301<C0;TC0Pea4`0301<C01PC00<04a<0?A<00`0C

4`1n4`804Q<00`0C4`0`4`00<Q<00`0C4`2k4`8=Ka<00`0C4`0H4`80?Q<00`0C4`204`8041<00`0C

4`0`4`00<Q<00`0C4`2m4`8=KA<00`0C4`0H4`0301<C024C1@024`0301<C018C00<04a<02a<50003

4`00024C1@024`0301<C01lC1@024`0301<C01/C00@04a<C1@000a<000034`0301<C034C000b4`03

01<C0;lC0Pe[4`0301<C01PC00<04a<08a<01`0C4a<04`004a<00`0C4`0=4`0701<C4`0C000R4`03

01<C008C00<04a<08A<01`0C4a<04`0071<200@C00<04a<00a<0100C4`0c4`00<Q<00`0C4`0V4`03

01<C008C00@04a<C0`0S4`0301<C008C00<04a<00Q<3028C00<04a<00Q<0100C4a<202@C00<04a<0

0Q<00`0C4`024`0401<C4`8=8a<5044C00<04a<061<00`0C4`0S4`0301<C00<C00<04a<04A<00`0C

4`0=4`0701<C4`0C000R4`0301<C008C00<04a<08A<01`0C4a<04`007Q<01@0C4a<000@C0P024`03

01<C034C000b4`0301<C02DC00<04`001a<00`0C4`0R4`0301<000TC00<04a<081<00`0C00074`03

01<0028C00<04`001a<00`0C00044`8=8a<00`0C4`114`0301<C01PC00<04a<08a<0100C4a<201@C

00<04a<03A<0100C4a<202<C00<04a<00a<00`0C4`0P4`0301<C008C00<04a<07Q<200034`0C008C

00<04`000Q<00`0C4`0a4`00<Q<00`0C4`0U4`0301<000PC00<04a<08A<00`0C00074`@08A<00`0C

00074`0301<0028C00<04`001a<00`0C00064`8=8A<00`0C4`104`0301<C01TC00<04a<08a<01@0C

4a<001DC00<04a<03A<01@0C4a<002@C00L04a<C01<0028C00L04a<C01<0024C0P034`0501<04`00

=1<0038C00<04a<09A<00`0C00084`0301<C024C00<04`001a<00`0C000R4`0301<000LC0P0S4`03

01<000PC00<04a<01a<23AlC00<04a<0@1<00`0C4`0I4`808a<200<C0`0C4`0301<C00`C0P044`80

8A<200<C0`0Q4`8011<00`0C4`0P4`8011<200034`0C03<C000b4`0301<C02DC00<04`001a<00`0C

000R4`0301<000PC0P0R4`0301<000LC00<04a<08Q<00`0C00074`0301<000XC0`dL4`0301<C040C

00<04a<06A<00`0C4`0m4`0301<C08PC00<04a<01A<00`0C4`0b4`00<Q<00`0C4`0V4`0301<C00LC

00<04a<08Q<00`0C4`084`0301<C024C00<04a<01a<202<C00<04a<01a<00`0C4`0<4`8=6A<2048C

00<04a<06A<00`0C4`0m4`0301<C08TC0P054`0301<C038C000b4`0301<C0<hC0`eJ4`0301<C01TC

00<04a<0?A<00`0C4`2;4`0501<C4`00=A<0038C00<04a<0dA<23EPC00<04a<06A<00`0C4`0m4`03

01<C08/C00@04a<04a<401lC000b4`0301<C0=<C0PeF4`0301<C01TC00<04a<0?A<00`0C4`2<4`80

51<3020C000b4`0301<C0=DC0`dO4`<0:a?o00XC00<04a<07Q<0038C00<04a<0f1<43A`C00<04a<0

:a<00`0C4`024`0401<C00PC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`03

01<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<00a<00`0C00074`0301<C00HC00<04a<0

1A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`03

01<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC0`064`03

01<C00`C0P0P4`00;1?U00d=1P094`0301<C030C00<04a<06A<00`0C4`0V4`0301<C01@C00<04a<0

41<00`0C4`0V4`0301<C02HC00<04a<09Q<0100C4`0f4`00<Q<00`0C4`084`0301<C00TC00<04a<0

2A<00`0C4`094`0301<C00PC00<04a<02A<00`0C4`094`0301<C00TC00<04a<021<00`0C4`094`03

01<C00TC00<04a<02A<00`0C4`094`0301<C00PC00<04a<02A<00`0C4`094`0301<C00TC00<04a<0

21<00`0C4`094`0301<C00TC00<04a<031<4030C00<04a<06A<00`0C4`0m4`0301<C08/C00D04a<C

000e4`00<Q<00`0C4`0/4`0301<C02`C00<04a<0;1<00`0C4`0/4`0301<C02`C00<04a<0@1<00`0C

4`0I4`0301<C03dC00<04a<0RQ<00`0C4`024`0301<C03<C000b4`0301<C0?lC;1<00`0C4`0I4`03

01<C03dC00<04a<0RA<00`0C4`044`0301<C038C000b4`0301<C0?lC;1<00`0C4`0I4`80?Q<00`0C

4`274`801a<00`0C4`0b4`00<Q<00`0C4`3o4b`C00<04a<06A<00`0C4`0m4`0301<C08LC00<04a<0

1Q<00`0C4`0b4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0m4`0301<C08HC00<04a<021<00`0C

4`0a4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0m4`0301<C08@C0P0;4`0301<C034C000b4`03

01<C0?lC;A<00`0C4`0H4`0301<C03dC00<04a<0Pa<00`0C4`0;4`0301<C034C000b4`0301<C0?lC

;A<00`0C4`0H4`0301<C03dC00<04a<0PQ<00`0C4`0<4`0301<C034C000b4`0301<C0?lC;A<00`0C

4`0H4`80?Q<00`0C4`204`803a<00`0C4`0a4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0m4`03

01<C07lC00<04a<041<00`0C4`0`4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07`C

0P0C4`0301<C030C000b4`0301<C0?lC;A<00`0C4`0H4`0301<C03hC00<04a<0Na<201@C00<04a<0

<1<0038C00<04a<0oa<]4`0301<C01PC00<04a<0?Q<00`0C4`1i4`805Q<00`0C4`0`4`00<Q<00`0C

4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07PC00<04a<05Q<00`0C4`0`4`00<Q<00`0C4`3o4bhC

00<04a<05a<203lC00<04a<0MQ<201TC00<04a<0<1<0038C00<04a<0oa<^4`0301<C01LC00<04a<0

?Q<00`0C4`1d4`8071<00`0C4`0_4`0071<00`0C4`024`0401<C4`<00a<00`0C4`044`0301<C0?lC

;Q<00`0C4`0G4`0301<C03hC00<04a<0La<00`0C4`0L4`0301<C02lC000K4`0301<000LC00<04a<0

0Q<00`0C00054`0301<C0?lC;Q<00`0C4`0G4`0301<C03lC00<04a<0L1<201lC00<04a<0;a<001/C

00<04`0021<00`0C4`034`0301<C00<C0P3o4c0C00<04a<05Q<00`0C4`0o4`0301<C06dC0`0Q4`03

01<C02lC000K4`0301<000PC00@04a<C0P064`0301<C0?lC;a<00`0C4`0F4`0301<C03lC00<04a<0

K1<202<C00<04a<0;a<001/C00<04`001a<00`0C00024`0301<C00DC00<04a<0oa<_4`0301<C01HC

0P104`0301<C06XC0P0U4`0301<C02lC000L4`0301<C00LC00@04a<C0`054`0301<C0?lC;a<00`0C

4`0F4`0301<C03lC00<04a<0J1<202LC00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC00<04a<0

?a<00`0C4`1V4`80:A<00`0C4`0_4`00<Q<00`0C4`3o4c0C00<04a<05A<00`0C4`0o4`0301<C06@C

0P0Z4`0301<C030C000b4`0301<C0?lC<1<00`0C4`0?4`0301<C00<C00<04a<0?a<00`0C4`1R4`80

;1<00`0C4`0`4`00<Q<00`0C4`3o4c0C00<04a<03Q<00`0C00044`0301<C040C00<04a<0GQ<302hC

00<04a<0<1<0038C00<04a<0oa<`4`0301<C010C00<04a<00Q<3040C00<04a<0G1<3030C00<04a<0

<1<0038C00<04a<0oa<a4`0301<C00dC0P054`0301<C040C00<04a<0FQ<2038C0P0b4`00<Q<00`0C

4`3o4c4C00<04a<03A<00`0C4`044`0301<C044C00<04a<0Ea<203@C00<04a<0<A<0038C00<04a<0

oa<b4`0301<C00`C0`044`0301<C044C00<04a<0E1<303HC00<04a<0<A<0038C00<04a<0oa<b4`03

01<C01<C00<04a<0@A<00`0C4`1B4`<0=a<203<C000b4`0301<C0?lC<a<00`0C4`0B4`80@Q<00`0C

4`1?4`<0>Q<00`0C4`0b4`00<Q<00`0C4`3o4c<C00<04a<04Q<00`0C4`124`0301<C04`C0`0l4`03

01<C038C000b4`0301<C0?lC=1<00`0C4`0A4`0301<C048C00<04a<0BA<303hC00<04a<0<a<0038C

00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`174`<0@1<00`0C4`0c4`008A<00`0C4`024`03

01<C008C00<04a<011<00`0C4`3o4cDC00<04a<041<00`0C4`124`0301<C04@C0`124`80=A<0020C

00<04`001a<00`0C00054`0301<C0?lC=A<00`0C4`0@4`0301<C04<C00<04a<0@1<304DC00<04a<0

=1<0020C00<04`002A<00`0C4`034`80oa<g4`0301<C00lC0P144`0301<C03dC0`174`80=Q<0020C

00<04`001a<200HC00<04a<0oa<f4`0301<C00lC00<04a<0A1<00`0C4`0i4`<0BQ<00`0C4`0e4`00

81<00`0C00074`0301<C00DC00<04a<0oa<g4`0301<C00hC00<04a<0A1<00`0C4`0f4`@0Ba<203LC

000Q4`0301<C00HC0`054`0301<C0?lC>1<00`0C4`0=4`0301<C04@C00<04a<0<a<304lC00<04a<0

=Q<0038C00<04a<0oa<i4`0301<C00`C00<04a<0AA<00`0C4`0_4`<0DA<00`0C4`0g4`00<Q<00`0C

4`3o4cTC00<04a<031<00`0C4`154`0301<C02/C101C4`80>A<0038C00<04a<0oa<j4`0301<C00/C

0P174`0301<C02LC101F4`0301<C03PC000b4`0301<C0?lC>Q<00`0C4`0;4`0301<C04HC00<04a<0

8a<505PC0P0j4`00<Q<00`0C4`3o4c/C0P0;4`0301<C04HC00<04a<081<405/C0P0k4`00<Q<00`0C

4`3o4cdC00<04a<021<00`0C4`174`0301<C01/C101O4`0301<C03XC000b4`0301<C0?lC?Q<00`0C

4`074`0301<C04LC0P0H4`D0HA<00`0C4`0k4`00<Q<00`0C4`3o4chC00<04a<01a<00`0C4`184`03

01<C01<C101T4`80?A<0038C00<04a<0oa<o4`0301<C00HC0P1:4`0301<C00hC101W4`80?Q<0038C

00<04a<0oa=04`801Q<00`0C4`194`0301<C00XC101Z4`80?a<0038C00<04a<0oa=24`0301<C00<C

00<04a<0BQ<00`0C4`054`D0K1<2040C000b4`0301<C0?lC@a<200<C00<04a<0BQ<200034`0000<0

L1<2044C000b4`0301<C0?lC>a<5008C00@04a<00Q<00`0C4`194`D0La<2048C000L4`0301<C008C

00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0oa<m4`0701<C4`0C00024`<0Aa<5008C00<04a<0

LA<204<C000K4`0301<000PC00L04a<C01<000DC00<04a<0oa<m4`0701<C4`0C00044`<0@1<500PC

00<04a<0KQ<204DC000K4`0301<000PC00<04a<00a<00`0C4`034`80oa<n4`0701<C4`0C00044`04

01<003XC1@0=4`0301<C06dC0P164`006a<00`0C00094`0301<C00801Q<00`0C4`3o4cdC00L04a<C

01<000@C00@04a<C0`0a4`H04a<206/C0`174`006a<00`0C00074`0301<0008C00<04a<01A<00`0C

4`3o4c`C0P044`0301<C00<C00<04a<011<302PC1`0I4`80JA<204TC000L4`0301<C00HC0`024`<0

1A<00`0C4`3o4dPC00<04a<01a<501/C2@0P4`0301<C06@C0`1;4`00<Q<00`0C4`3o4dPC00<04a<0

31<L02TC0P1R4`<0CA<0038C00<04a<0oa=84`80Da<205lC0`1?4`00<Q<00`0C4`3o4dPC00<04a<0

Da<205XC101B4`00<Q<00`0C4`3o4dPC00<04a<0E1<205HC101E4`00<Q<00`0C4`3o4dPC00<04a<0

EQ<204lC1@1I4`00<Q<00`0C4`3o4dPC00<04a<0Ea<304PC1P1M4`00<Q<00`0C4`3o4dPC00<04a<0

FA<3040C1`1R4`00<Q<00`0C4`3o4dPC0P1L4`<0>1<706PC000b4`0301<C0?lCB1<00`0C4`1N4`<0

;Q<806hC000b4`0301<C0?lCB1<00`0C4`1P4`D08a<807DC000b4`0301<C0?lCB1<00`0C4`1T4`L0

51<:07`C000b4`0301<C0?lCB1<00`0C4`1Z4aD0QQ<0038C00<04a<0oa=84`0301<C0?lC1Q<002TC

1@044`0301<C0?lCB1<20?lC1a<002/C00<04a<011<00`0C4`3o4dPC00<04a<0oa<64`00:a<00`0C

4`044`80oa=94`0301<C0?lC1Q<002/C00<04a<0oa?o4ePC000[4`0301<C0?lCoa=H4`00:Q<20?lC

oa=J4`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<0074C10000a<00007008C

00<04a<00Q<0100C4a<3008C0P044`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<0

0Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`03

01<C008C0`3o4j`C001a4`<021<01`0C4a<04`001a<00`0C4`044`0601<C01<00Q<00`0C00024`03

01<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0Q<00`0C00024`0301<0008C00<04`0011<00`0C4`2P4`80oa<94`00La<00`0C4`04008C00L04a<C

01<000PC00<04a<00Q<01`0C4a<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`03

01<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0Q<40:8C00<04a<0oa<74`006A<400034`0000H00Q<:008C0P024`<00Q<300<C0P001Q<0000C02LC

0P084`0301<C008C00<04a<01a<00`0C4`034`0601<C01<00Q<00`0C00024`0301<0008C00<04`00

0Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`03

01<0008C00<04`000Q<00`0C002Q4`<00Q<00`0C4`3o4`@C000J4`0601<C01<00Q<00`0C00044`06

01<C01<00Q<00`0C00054`0301<C008C00D04a<C00024`0401<04`80<A<01`0C4a<04`001a<00`0C

00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C

00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000a<200@C

00<04a<0VA<0200C4`0C01<0oa<54`006Q<01P0C4`0C00@C00<04a<00Q<00`0C4`024`0301<C008C

00<04a<00a<00`0C4`024`0501<C4`000Q<0100C01<2030C0P044`0301<C00LC00<04a<00Q<00`0C

4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C

00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C00<C00D04a<C002L4`08

01<C01<04`3o4`DC000J4`0501<C01<00P034`800a<00`0C4`024`800a<00`0C4`034`0301<C008C

00D04a<C00024`0601<001<0oa<_4`<000@C01<0oa<54`006Q<01P0C4`0C008C00<04`000Q<00`0C

00044`0>01<C01<04`0C01<04`024`0501<C4`000Q<01P0C000C0?lC<a<00`0C003o4`DC000I4`@0

00<C00002`024`D000DC00004`0500044`0000<C0P0011<001<20?lC=1<00`0C4`3o4`@C003o4olC

QQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00

oa?o4hHC0000\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.77084, -14.119, 0.0242408, 0.16996}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -57 0 ]

[.5 .63053 57 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -118 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(17.9499999999999886`) show

173.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .16061 m

.02499 .16061 L

.02606 .1606 L

.02729 .16058 L

.02846 .16057 L

.03053 .16052 L

.03279 .16045 L

.03527 .16034 L

.0379 .16021 L

.04262 .1599 L

.04749 .15948 L

.05205 .15901 L

.06245 .15763 L

.07305 .15579 L

.08274 .15375 L

.10458 .14797 L

.14429 .13398 L

.18248 .11814 L

.22313 .10198 L

.24192 .09586 L

.25181 .09318 L

.26226 .09085 L

.26757 .08987 L

.27341 .08898 L

.27871 .08833 L

.28367 .08787 L

.28628 .08769 L

.28876 .08756 L

.29098 .08747 L

.29224 .08744 L

.2934 .08741 L

.29464 .0874 L

.29581 .08739 L

.29709 .08739 L

.2978 .0874 L

.29846 .08741 L

.29971 .08743 L

.30042 .08745 L

.30108 .08747 L

.30242 .08752 L

.30384 .08759 L

.30647 .08774 L

.30889 .08793 L

.31436 .08849 L

.31909 .08913 L

.3243 .09001 L

.3339 .09212 L

.34288 .09464 L

.36317 .10223 L

.38171 .11127 L

Mistroke

.42147 .13586 L

.45971 .16281 L

.50041 .1899 L

.51925 .20048 L

.53959 .20993 L

.55077 .21415 L

.56105 .21739 L

.57149 .22006 L

.58123 .22202 L

.59034 .22341 L

.59501 .22396 L

.60009 .22445 L

.60565 .22487 L

.6082 .22502 L

.61091 .22515 L

.61335 .22525 L

.61604 .22533 L

.61721 .22536 L

.61848 .22539 L

.61966 .22541 L

.62077 .22542 L

.62203 .22544 L

.62317 .22545 L

.62441 .22546 L

.6251 .22546 L

.62574 .22546 L

.62681 .22546 L

.62799 .22545 L

.62922 .22545 L

.63036 .22544 L

.63172 .22542 L

.63301 .22541 L

.63542 .22537 L

.64085 .22525 L

.65108 .22496 L

.66196 .22463 L

.6665 .22452 L

.66889 .22447 L

.67141 .22443 L

.67275 .22441 L

.67421 .2244 L

.67555 .22438 L

.67679 .22438 L

.67807 .22437 L

.67923 .22437 L

.67988 .22437 L

.68058 .22437 L

.68184 .22438 L

.68299 .22439 L

.68406 .2244 L

Mistroke

.68523 .22442 L

.68649 .22444 L

.68907 .2245 L

.69142 .22457 L

.69595 .22475 L

.70026 .22499 L

.70529 .22536 L

.70985 .22578 L

.72008 .22704 L

.72955 .22863 L

.73847 .23051 L

.75856 .23615 L

.77704 .24294 L

.81655 .26122 L

.85454 .28017 L

.8757 .28961 L

.89498 .29682 L

.90456 .2998 L

.91498 .30254 L

.92475 .30464 L

.93391 .30621 L

.94332 .30742 L

.94832 .30791 L

.9537 .30832 L

.95904 .30863 L

.96173 .30875 L

.96467 .30885 L

.96718 .30892 L

.96857 .30895 L

.96987 .30897 L

.97109 .30899 L

.97241 .309 L

.97361 .30901 L

.97471 .30902 L

.97542 .30902 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.77598 .03516 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4gdC00<04a<0oa<64`00oa=m4`0301<C0?lC1Q<002TC1@3o4dlC0P3o4`LC

000[4`0301<C0?lCCa<00`0C4`1^4`d0RQ<002DC0`034`0301<C00@C0P3o4dTC00<04a<0IQ<800`C

3@0H4`033A<C06<C000[4`0301<C00@C00<04a<0oa=84`0301<C064C1@0P4`P03Q<63F<C000[4`03

01<C00@C00<04a<0oa=84`0301<C05hC100/4`L01Q<93F4C000Z4`801Q<00`0C4`3o4dPC00<04a<0

G1<303DC1`093F4C000b4`0301<C0?lCB1<205/C0P0o4`T=HA<0038C00<04a<0oa=84`0301<C05PC

0P104`/=00<04a<0GA<0038C00<04a<0oa=84`0301<C05HC0P134`T=0Q<505XC000b4`0301<C0?lC

B1<00`0C4`1E4`80A1<93@HC1@1F4`00<Q<00`0C4`3o4dPC00<04a<0E1<00`0C4`144`T=2Q<5058C

000b4`0301<C0?lCB1<205<C0P184`H=41<3050C000b4`0301<C0?lCB1<00`0C4`0?4aH0;1<204`C

00<=4a<04Q<404dC000b4`0301<C0?lCB1<00`0C4`0:4`D05Q<9028C0P1U4`<0Ba<0038C00<04a<0

oa=84`0301<C00DC1@0S4`L06a<206PC0`194`00<Q<00`0C4`3o4c/C1@024`0301<C00<C00<04a<0

0a<202lC1P0D4`80Ja<204PC000b4`0301<C0?lC?A<01`0C4a<04`0011<00`0C4`0303HC1P0>4`80

KA<304HC000b4`0301<C0?lC=a<300<C00L04a<C01<000@C0`0n4`H02A<00`0C4`1^4`80AA<0038C

00<04a<0oa<m4`0701<C4`0C00034`80AA<500@C00<04a<0L1<204@C000L4`0301<C008C00<04a<0

0Q<00`0C4`024`0301<C00@C00<04a<0oa<m4`0701<C4`0C00024`0301<004XC1@1d4`80@Q<001/C

00<04`0021<01`0C4a<04`001A<00`0C4`3o4c`C0P044`0401<0008C00<04a<0Ba<6074C0P114`00

5Q<3008C00<04`0021<00`0C4`034`0301<C00<C0P3o4d<C0P044`0301<C04XC00<04a<011<406hC

0P104`006a<00`0C00094`0301<C00801Q<00`0C4`3o4d4C00<04a<011<00`0C4`194`0301<C00TC

101[4`0301<C03hC000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C0?lC@1<00`0C4`054`80

BQ<00`0C4`0=4`@0J1<203hC000L4`0301<C00HC0`024`<01A<00`0C4`0i4`l=mQ<00`0C4`064`03

01<C04PC00<04a<04Q<406DC00<04a<0?1<0038C00<04a<0=1<53@lC1@g`4`0301<C00LC00<04a<0

B1<00`0C4`0E4`D0HQ<00`0C4`0k4`00<Q<00`0C4`0a4`<=6A<23NdC00<04a<021<00`0C4`174`03

01<C01XC101O4`80?1<0038C00<04a<0;A<43AhC0PgZ4`0301<C00TC00<04a<0AQ<00`0C4`0O4`@0

G1<203/C000b4`0301<C02/C0PdT4`8=ia<00`0C4`0:4`0301<C04HC00<04a<08Q<505TC00<04a<0

>A<0038C00<04a<0:1<33BPC0PgT4`0301<C00/C0P174`0301<C02HC101G4`0301<C03PC000b4`03

01<C02HC0Pd]4`033A<C0>0C00<04a<031<00`0C4`154`0301<C02XC101D4`80>A<0038C00<04a<0

8a<33C0C0PgP4`0301<C00`C00<04a<0AA<00`0C4`0^4`@0DA<00`0C4`0g4`00<Q<00`0C4`0Q4`8=

=A<23MdC00<04a<03A<00`0C4`144`0301<C03<C0P1?4`80>1<0038C00<04a<07Q<33CTC00<=4a<0

fA<00`0C4`0>4`0301<C04@C00<04a<0=A<404`C0P0g4`00<Q<00`0C4`0L4`8=?A<23MPC00<04a<0

3a<00`0C4`144`0301<C03TC0P1;4`0301<C03DC000b4`0301<C01TC0`e14`8=eQ<00`0C4`0?4`80

A1<00`0C4`0l4`@0Aa<203HC000b4`0301<C01LC0Pe64`033A<C0=8C00<04a<041<00`0C4`134`03

01<C03lC0`164`0301<C03@C000b4`0301<C01@C0`e94`8=dQ<00`0C4`0@4`0301<C04<C00<04a<0

@Q<304<C0P0e4`008A<00`0C4`024`0301<C008C00<04a<011<00`0C4`0B4`8=CQ<00`dC4`3>4`03

01<C014C00<04a<0@Q<00`0C4`164`<0@A<00`0C4`0c4`0081<00`0C00074`0301<000DC00<04a<0

3Q<43E4C0Pg>4`0301<C014C00<04a<0@Q<00`0C4`194`80?a<00`0C4`0c4`006a<3008C00<04`00

2A<00`0C4`034`8031<33ELC00<=4a<0bQ<00`0C4`0B4`0301<C048C00<04a<0Ba<303dC00<04a<0

<Q<0020C00<04`001a<200HC00<04a<00Q<93E/C0Pg:4`0301<C018C0P134`0301<C04hC0P0k4`03

01<C038C000P4`0301<000LC00<04a<01A<53FHC00<=4a<0aQ<00`0C4`0C4`0301<C044C00<04a<0

DA<303PC00<04a<0<Q<0024C00<04a<01Q<300DC00<04a<0JA<23LHC00<04a<04a<00`0C4`114`03

01<C05@C0P0g4`0301<C034C000b4`0301<C06/C00<=4a<0`Q<00`0C4`0D4`0301<C044C00<04a<0

EQ<303@C00<04a<0<A<0038C00<04a<0K1<00`dC4`314`0301<C00hC00<04a<00a<00`0C4`104`03

01<C05TC0`0b4`80<Q<0038C00<04a<0KA<23L0C00<04a<03Q<00`0C00044`0301<C040C00<04a<0

G1<2034C00<04a<0<1<0038C00<04a<0Ka<00`dC4`2m4`0301<C00TC0`044`0301<C008C0`104`03

01<C05hC0P0_4`0301<C030C000b4`0301<C070C0Pfm4`0301<C00hC0P054`0301<C03lC00<04a<0

HA<302`C00<04a<0<1<0038C00<04a<0LQ<00`dC4`2j4`0301<C00hC00<04a<011<00`0C4`0o4`03

01<C06@C00<04a<0:A<00`0C4`0`4`00<Q<00`0C4`1c4`8=^A<00`0C4`0?4`<011<00`0C4`0o4`03

01<C06DC0`0X4`80<A<0038C00<04a<0MA<23KLC00<04a<05Q<00`0C4`0o4`0301<C06PC00<04a<0

9Q<00`0C4`0_4`00<Q<00`0C4`1g4`8=]A<00`0C4`0F4`0301<C03lC00<04a<0JA<302DC00<04a<0

;a<0038C00<04a<0NA<23K<C00<04a<05Q<2040C00<04a<0K1<202<C00<04a<0;a<0038C00<04a<0

Na<33K0C00<04a<05Q<00`0C4`0o4`0301<C06dC0P0R4`0301<C02lC000b4`0301<C07hC0Pf^4`03

01<C01HC00<04a<0?a<00`0C4`1_4`8081<00`0C4`0_4`00<Q<00`0C4`204`D=Z1<00`0C4`0G4`03

01<C03hC00<04a<0LQ<201hC00<04a<0;a<001`C00<04a<00Q<0100C4a<300<C00<04a<011<00`0C

4`254`H=XQ<00`0C4`0G4`0301<C03hC00<04a<0M1<201`C00<04a<0;a<001/C00<04`001a<00`0C

4`024`0301<000DC00<04a<0Ra<O3H<C00<04a<05a<203lC00<04a<0MQ<201XC00<04a<0;a<001HC

0`024`0301<000PC00<04a<00a<00`0C4`034`80Za<63GdC00<04a<05a<00`0C4`0n4`0301<C07PC

00<04a<05Q<00`0C4`0`4`006a<00`0C00084`0401<C4`801Q<00`0C4`2`4`@=N1<00`0C4`0H4`03

01<C03hC00<04a<0NA<201HC00<04a<0<1<001/C00<04`001a<00`0C00024`0301<C00DC00<04a<0

]1<23GHC00<04a<061<00`0C4`0n4`0301<C07/C00<04a<04a<00`0C4`0`4`0071<00`0C4`074`04

01<C4`<01A<00`0C4`2f4`8=M1<00`0C4`0H4`0301<C03hC00<04a<0O1<00`0C4`0B4`0301<C030C

000b4`0301<C0;PC0Peb4`0301<C01PC00<04a<0?A<00`0C4`1n4`804Q<00`0C4`0`4`00<Q<00`0C

4`2j4`8=L1<00`0C4`0H4`80?Q<00`0C4`204`8041<00`0C4`0`4`00<Q<00`0C4`2l4`8=KQ<00`0C

4`0H4`0301<C024C1@024`0301<C018C00<04a<02a<500034`00024C1@024`0301<C01lC1@024`03

01<C01/C00@04a<C1@000a<000034`0301<C034C000b4`0301<C0;hC0Pe/4`0301<C01PC00<04a<0

8a<01`0C4a<04`004a<00`0C4`0=4`0701<C4`0C000R4`0301<C008C00<04a<08A<01`0C4a<04`00

71<200@C00<04a<00a<0100C4`0c4`00<Q<00`0C4`0V4`0301<C008C00@04a<C0`0S4`0301<C008C

00<04a<00Q<3028C00<04a<00Q<0100C4a<202@C00<04a<00Q<00`0C4`024`0301<C00<=8a<5044C

00<04a<061<00`0C4`0S4`0301<C00<C00<04a<04A<00`0C4`0=4`0701<C4`0C000R4`0301<C008C

00<04a<08A<01`0C4a<04`007Q<01@0C4a<000@C0P024`0301<C034C000b4`0301<C02DC00<04`00

1a<00`0C4`0R4`0301<000TC00<04a<081<00`0C00074`0301<0028C00<04`001a<00`0C00044`8=

8a<00`0C4`114`0301<C01PC00<04a<08a<0100C4a<201@C00<04a<03A<0100C4a<202<C00<04a<0

0a<00`0C4`0P4`0301<C008C00<04a<07Q<200034`0C008C00<04`000Q<00`0C4`0a4`00<Q<00`0C

4`0U4`0301<000PC00<04a<08A<00`0C00074`@08A<00`0C00074`0301<0028C00<04`001a<00`0C

00064`8=8A<00`0C4`104`0301<C01TC00<04a<08a<01@0C4a<001DC00<04a<03A<01@0C4a<002@C

00L04a<C01<0028C00L04a<C01<0024C0P034`0501<04`00=1<0038C00<04a<09A<00`0C00084`03

01<C024C00<04`001a<00`0C000R4`0301<000LC0P0S4`0301<000PC00<04a<01a<23AlC00<04a<0

@1<00`0C4`0I4`808a<200<C0`0C4`0301<C00`C0P044`808A<200<C0`0Q4`8011<00`0C4`0P4`80

11<200034`0C03<C000b4`0301<C02DC00<04`001a<00`0C000R4`0301<000PC0P0R4`0301<000LC

00<04a<08Q<00`0C00074`0301<000XC0PdM4`0301<C040C00<04a<06A<00`0C4`0m4`0301<C08PC

00<04a<01A<00`0C4`0b4`00<Q<00`0C4`0V4`0301<C00LC00<04a<08Q<00`0C4`084`0301<C024C

00<04a<01a<202<C00<04a<01a<00`0C4`0;4`8=6Q<2048C00<04a<06A<00`0C4`0m4`0301<C08TC

0P054`0301<C038C000b4`0301<C0<dC0PeL4`0301<C01TC00<04a<0?A<00`0C4`2;4`0501<C4`00

=A<0038C00<04a<0ca<33ETC00<04a<06A<00`0C4`0m4`0301<C08/C00@04a<04a<401lC000b4`03

01<C0=8C0`eF4`0301<C01TC00<04a<0?A<00`0C4`2<4`8051<3020C000b4`0301<C0=DC0`dO4`<0

:a?o00XC00<04a<07Q<0038C00<04a<0f1<53A/C00<04a<0:a<00`0C4`024`0401<C00PC00<04a<0

1A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`03

01<C00DC00<04a<00a<00`0C00074`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC00<04a<0

1Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`03

01<C00HC00<04a<01A<00`0C4`054`0301<C00DC0`064`0301<C00`C0P0P4`00;1?V00`=1P094`03

01<C030C00<04a<06A<00`0C4`0V4`0301<C01@C00<04a<041<00`0C4`0V4`0301<C02HC00<04a<0

9Q<0100C4`0f4`00<Q<00`0C4`084`0301<C00TC00<04a<02A<00`0C4`094`0301<C00PC00<04a<0

2A<00`0C4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0C4`094`03

01<C00PC00<04a<02A<00`0C4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC00<04a<0

31<4030C00<04a<06A<00`0C4`0m4`0301<C08/C00D04a<C000e4`00<Q<00`0C4`0/4`0301<C02`C

00<04a<0;1<00`0C4`0/4`0301<C02`C00<04a<0@1<00`0C4`0I4`0301<C03dC00<04a<0RQ<00`0C

4`024`0301<C03<C000b4`0301<C0?lC;1<00`0C4`0I4`0301<C03dC00<04a<0RA<00`0C4`044`03

01<C038C000b4`0301<C0?lC;1<00`0C4`0I4`80?Q<00`0C4`274`801a<00`0C4`0b4`00<Q<00`0C

4`3o4b`C00<04a<06A<00`0C4`0m4`0301<C08LC00<04a<01Q<00`0C4`0b4`00<Q<00`0C4`3o4bdC

00<04a<061<00`0C4`0m4`0301<C08HC00<04a<021<00`0C4`0a4`00<Q<00`0C4`3o4bdC00<04a<0

61<00`0C4`0m4`0301<C08@C0P0;4`0301<C034C000b4`0301<C0?lC;A<00`0C4`0H4`0301<C03dC

00<04a<0Pa<00`0C4`0;4`0301<C034C000b4`0301<C0?lC;A<00`0C4`0H4`0301<C03dC00<04a<0

PQ<00`0C4`0<4`0301<C034C000b4`0301<C0?lC;A<00`0C4`0H4`80?Q<00`0C4`204`803a<00`0C

4`0a4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0m4`0301<C07lC00<04a<041<00`0C4`0`4`00

<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07`C0P0C4`0301<C030C000b4`0301<C0?lC

;A<00`0C4`0H4`0301<C03hC00<04a<0Na<201@C00<04a<0<1<0038C00<04a<0oa<]4`0301<C01PC

00<04a<0?Q<00`0C4`1i4`805Q<00`0C4`0`4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`03

01<C07PC00<04a<05Q<00`0C4`0`4`00<Q<00`0C4`3o4bhC00<04a<05a<203lC00<04a<0MQ<201TC

00<04a<0<1<0038C00<04a<0oa<^4`0301<C01LC00<04a<0?Q<00`0C4`1d4`8071<00`0C4`0_4`00

71<00`0C4`024`0401<C4`<00a<00`0C4`044`0301<C0?lC;Q<00`0C4`0G4`0301<C03hC00<04a<0

La<00`0C4`0L4`0301<C02lC000K4`0301<000LC00<04a<00Q<00`0C00054`0301<C0?lC;Q<00`0C

4`0G4`0301<C03lC00<04a<0L1<201lC00<04a<0;a<001/C00<04`0021<00`0C4`034`0301<C00<C

0P3o4c0C00<04a<05Q<00`0C4`0o4`0301<C06dC0`0Q4`0301<C02lC000K4`0301<000PC00@04a<C

0P064`0301<C0?lC;a<00`0C4`0F4`0301<C03lC00<04a<0K1<202<C00<04a<0;a<001/C00<04`00

1a<00`0C00024`0301<C00DC00<04a<0oa<_4`0301<C01HC0P104`0301<C06XC0P0U4`0301<C02lC

000L4`0301<C00LC00@04a<C0`054`0301<C0?lC;a<00`0C4`0F4`0301<C03lC00<04a<0J1<202LC

00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC00<04a<0?a<00`0C4`1V4`80:A<00`0C4`0_4`00

<Q<00`0C4`3o4c0C00<04a<05A<00`0C4`0o4`0301<C06@C0P0Z4`0301<C030C000b4`0301<C0?lC

<1<00`0C4`0?4`0301<C00<C00<04a<0?a<00`0C4`1R4`80;1<00`0C4`0`4`00<Q<00`0C4`3o4c0C

00<04a<03Q<00`0C00044`0301<C040C00<04a<0GQ<302hC00<04a<0<1<0038C00<04a<0oa<`4`03

01<C010C00<04a<00Q<3040C00<04a<0G1<3030C00<04a<0<1<0038C00<04a<0oa<a4`0301<C00dC

0P054`0301<C040C00<04a<0FQ<2038C0P0b4`00<Q<00`0C4`3o4c4C00<04a<03A<00`0C4`044`03

01<C044C00<04a<0Ea<203@C00<04a<0<A<0038C00<04a<0oa<b4`0301<C00`C0`044`0301<C044C

00<04a<0E1<303HC00<04a<0<A<0038C00<04a<0oa<b4`0301<C01<C00<04a<0@A<00`0C4`1B4`<0

=a<203<C000b4`0301<C0?lC<a<00`0C4`0B4`80@Q<00`0C4`1?4`<0>Q<00`0C4`0b4`00<Q<00`0C

4`3o4c<C00<04a<04Q<00`0C4`124`0301<C04`C0`0l4`0301<C038C000b4`0301<C0?lC=1<00`0C

4`0A4`0301<C048C00<04a<0BA<303hC00<04a<0<a<0038C00<04a<0oa<d4`0301<C014C00<04a<0

@Q<00`0C4`174`<0@1<00`0C4`0c4`008A<00`0C4`024`0301<C008C00<04a<011<00`0C4`3o4cDC

00<04a<041<00`0C4`124`0301<C04@C0`124`80=A<0020C00<04`001a<00`0C00054`0301<C0?lC

=A<00`0C4`0@4`0301<C04<C00<04a<0@1<304DC00<04a<0=1<0020C00<04`002A<00`0C4`034`80

oa<g4`0301<C00lC0P144`0301<C03dC0`174`80=Q<0020C00<04`001a<200HC00<04a<0oa<f4`03

01<C00lC00<04a<0A1<00`0C4`0i4`<0BQ<00`0C4`0e4`0081<00`0C00074`0301<C00DC00<04a<0

oa<g4`0301<C00hC00<04a<0A1<00`0C4`0f4`@0Ba<203LC000Q4`0301<C00HC0`054`0301<C0?lC

>1<00`0C4`0=4`0301<C04@C00<04a<0<a<304lC00<04a<0=Q<0038C00<04a<0oa<i4`0301<C00`C

00<04a<0AA<00`0C4`0_4`<0DA<00`0C4`0g4`00<Q<00`0C4`3o4cTC00<04a<031<00`0C4`154`03

01<C02/C101C4`80>A<0038C00<04a<0oa<j4`0301<C00/C0P174`0301<C02LC101F4`0301<C03PC

000b4`0301<C0?lC>Q<00`0C4`0;4`0301<C04HC00<04a<08a<505PC0P0j4`00<Q<00`0C4`3o4c/C

0P0;4`0301<C04HC00<04a<081<405/C0P0k4`00<Q<00`0C4`3o4cdC00<04a<021<00`0C4`174`03

01<C01/C101O4`0301<C03XC000b4`0301<C0?lC?Q<00`0C4`074`0301<C04LC0P0H4`D0HA<00`0C

4`0k4`00<Q<00`0C4`3o4chC00<04a<01a<00`0C4`184`0301<C01<C101T4`80?A<0038C00<04a<0

oa<o4`0301<C00HC0P1:4`0301<C00hC101W4`80?Q<0038C00<04a<0oa=04`801Q<00`0C4`194`03

01<C00XC101Z4`80?a<0038C00<04a<0oa=24`0301<C00<C00<04a<0BQ<00`0C4`054`D0K1<2040C

000b4`0301<C0?lC@a<200<C00<04a<0BQ<200034`0000<0L1<2044C000b4`0301<C0?lC>a<5008C

00@04a<00Q<00`0C4`194`D0La<2048C000L4`0301<C008C00<04a<00Q<00`0C4`024`0301<C00@C

00<04a<0oa<m4`0701<C4`0C00024`<0Aa<5008C00<04a<0LA<204<C000K4`0301<000PC00L04a<C

01<000DC00<04a<0oa<m4`0701<C4`0C00044`<0@1<500PC00<04a<0KQ<204DC000K4`0301<000PC

00<04a<00a<00`0C4`034`80oa<n4`0701<C4`0C00044`0401<003XC1@0=4`0301<C06dC0P164`00

6a<00`0C00094`0301<C00801Q<00`0C4`3o4cdC00L04a<C01<000@C00@04a<C0`0a4`H04a<206/C

0`174`006a<00`0C00074`0301<0008C00<04a<01A<00`0C4`3o4c`C0P044`0301<C00<C00<04a<0

11<302PC1`0I4`80JA<204TC000L4`0301<C00HC0`024`<01A<00`0C4`3o4dPC00<04a<01a<501/C

2@0P4`0301<C06@C0`1;4`00<Q<00`0C4`3o4dPC00<04a<031<L02TC0P1R4`<0CA<0038C00<04a<0

oa=84`80Da<205lC0`1?4`00<Q<00`0C4`3o4dPC00<04a<0Da<205XC101B4`00<Q<00`0C4`3o4dPC

00<04a<0E1<205HC101E4`00<Q<00`0C4`3o4dPC00<04a<0EQ<204lC1@1I4`00<Q<00`0C4`3o4dPC

00<04a<0Ea<304PC1P1M4`00<Q<00`0C4`3o4dPC00<04a<0FA<3040C1`1R4`00<Q<00`0C4`3o4dPC

0P1L4`<0>1<706PC000b4`0301<C0?lCB1<00`0C4`1N4`<0;Q<806hC000b4`0301<C0?lCB1<00`0C

4`1P4`D08a<807DC000b4`0301<C0?lCB1<00`0C4`1T4`L051<:07`C000b4`0301<C0?lCB1<00`0C

4`1Z4aD0QQ<0038C00<04a<0oa=84`0301<C0?lC1Q<002TC1@044`0301<C0?lCB1<20?lC1a<002/C

00<04a<011<00`0C4`3o4dPC00<04a<0oa<64`00:a<00`0C4`044`80oa=94`0301<C0?lC1Q<002/C

00<04a<0oa?o4ePC000[4`0301<C0?lCoa=H4`00:Q<20?lCoa=J4`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4olCQQ<0074C10000a<00007008C00<04a<00Q<0100C4a<200@C0`000a<0

00034`800a<200<C0P034`800a<200<C0P034`800a<200<C0P034`8011<00`0C4`024`0401<C4`80

oa>^4`00LA<300PC00<04a<00Q<00`0C4`084`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C

00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C

4`024`0601<C01<00Q<00`0C00024`0301<00:8C0P3o4`TC001c4`0301<C00@00Q<00`0C4`024`03

01<C00LC0P024`@00Q<200<C0P034`800a<200<C0P034`800a<200<C0P034`800a<200<C0P024`03

01<0008C00<04`000Q<00`0C002S4`0301<C0?lC1a<001TC10000a<00006008C2P024`800Q<3008C

0`034`8000HC00004`0W4`8021<00`0C4`034`0301<C00DC00<04`000Q<00`0C00024`0301<0008C

00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C

00024`0301<0008C00<04`000a<00`0C4`024`0401<C4`80XQ<3008C00<04a<0oa<44`006Q<01P0C

4`0C008C00<04`0011<01P0C4`0C008C00<04`001A<00`0C4`024`0501<C4`000Q<0100C01<2034C

00L04a<C01<000LC00<04`000a<2008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C

00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C

00<04`000Q<00`0C4`044`0301<C09TC00P04a<04`0C0?lC1A<001XC00H04a<04`044`0301<C008C

00<04a<00Q<00`0C4`024`0301<C00<C00<04a<00Q<01@0C4a<0008C00@04`0C0P0`4`800a<300PC

0P044`0401<C4`800a<200<C0P034`800a<200<C0P034`800a<200<C0P034`800a<200<C00<04a<0

0Q<00`0C4`024`800a<00`0C4`2J4`0801<C01<04`3o4`DC000J4`0501<C01<00P034`800a<00`0C

4`024`800a<00`0C4`034`0301<C008C00D04a<C00024`0601<001<0oa<_4`<000@C01<0oa<54`00

6Q<01P0C4`0C008C00<04`000Q<00`0C00044`0>01<C01<04`0C01<04`024`0501<C4`000Q<01P0C

000C0?lC<a<00`0C003o4`DC000I4`@000<C00002`024`D000DC00004`0500044`0000<C0P0011<0

01<20?lC=1<00`0C4`3o4`@C003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00

oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC0000\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.77084, -14.119, 0.0242408, 0.16996}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -57 0 ]

[.5 .63053 57 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -118 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(17.6700000000000017`) show

173.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .17274 m

.02499 .17273 L

.02606 .17273 L

.02729 .17271 L

.02846 .17269 L

.03053 .17264 L

.03279 .17257 L

.03527 .17246 L

.0379 .17233 L

.04262 .172 L

.04749 .17158 L

.05205 .17109 L

.06245 .16967 L

.07305 .16779 L

.08274 .16569 L

.10458 .15977 L

.14429 .14549 L

.18248 .12943 L

.2038 .12057 L

.22313 .11323 L

.24351 .10674 L

.25245 .10442 L

.26226 .10231 L

.27162 .10078 L

.27673 .10015 L

.2815 .0997 L

.2842 .0995 L

.28676 .09936 L

.28906 .09927 L

.29035 .09923 L

.29155 .0992 L

.29283 .09918 L

.29403 .09918 L

.29535 .09918 L

.29609 .09919 L

.29677 .0992 L

.29807 .09922 L

.2988 .09924 L

.29948 .09926 L

.30086 .09931 L

.30232 .09938 L

.30495 .09954 L

.30737 .09972 L

.31285 .10028 L

.31758 .10092 L

.32278 .1018 L

.33238 .10388 L

.34137 .10637 L

.36166 .11381 L

.38019 .1226 L

Mistroke

.41995 .14619 L

.4582 .17151 L

.4989 .19624 L

.51773 .20563 L

.53808 .21381 L

.54926 .21736 L

.55953 .22003 L

.56935 .22207 L

.57971 .2237 L

.58922 .22477 L

.59454 .2252 L

.59939 .2255 L

.60391 .22571 L

.60646 .22579 L

.60882 .22586 L

.61088 .2259 L

.61314 .22593 L

.61429 .22595 L

.61551 .22596 L

.61667 .22596 L

.61774 .22597 L

.61902 .22597 L

.62023 .22596 L

.62132 .22596 L

.62249 .22595 L

.62378 .22594 L

.62513 .22592 L

.62757 .22589 L

.63192 .22581 L

.6367 .2257 L

.64753 .22542 L

.65266 .22529 L

.65741 .22519 L

.65969 .22515 L

.6622 .22511 L

.66342 .2251 L

.66473 .22508 L

.66545 .22508 L

.66611 .22507 L

.66742 .22507 L

.66856 .22506 L

.66962 .22506 L

.67079 .22506 L

.67203 .22507 L

.67334 .22508 L

.67458 .22509 L

.67569 .2251 L

.6769 .22512 L

.67941 .22517 L

.68218 .22525 L

Mistroke

.68507 .22535 L

.68777 .22547 L

.69261 .22575 L

.6978 .22614 L

.70792 .22718 L

.71364 .22796 L

.71895 .22881 L

.73905 .23318 L

.75959 .23951 L

.7782 .24671 L

.81828 .26533 L

.85686 .28369 L

.87642 .29176 L

.89788 .29898 L

.90774 .30164 L

.91832 .304 L

.92822 .30575 L

.93739 .30701 L

.94694 .30795 L

.95197 .30832 L

.95732 .30861 L

.95955 .30871 L

.96195 .3088 L

.96402 .30886 L

.96629 .30892 L

.96881 .30896 L

.97018 .30898 L

.97146 .309 L

.97266 .309 L

.97375 .30901 L

.975 .30902 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.73055 .02754 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4gdC00<04a<0oa<64`00oa=m4`0301<C0?lC1Q<002TC1@3o4dlC0P2E4`03

3A<C06hC000[4`0301<C0?lCCa<00`0C4`1^4`d05Q<63FhC000U4`<00a<00`0C4`044`80oa=94`03

01<C06HC200<4`d02A<93F`C000[4`0301<C00@C00<04a<0oa=84`0301<C064C1@0P4`P00Q<93F`C

000[4`0301<C00@C00<04a<0oa=84`0301<C05hC100/4`802@e/4`00:Q<200HC00<04a<0oa=84`03

01<C05`C0`0`4`/=00<04a<0J1<0038C00<04a<0oa=84`80Fa<203@C2@d24`H0I1<0038C00<04a<0

oa=84`0301<C05PC0P0f4`T=1a<605lC000b4`0301<C0?lCB1<00`0C4`1F4`80>1<93@dC1@1J4`00

<Q<00`0C4`3o4dPC00<04a<0EA<203XC1PdC4`D0EQ<0038C00<04a<0oa=84`0301<C05@C00<04a<0

?A<00`dC4`0G4`D0DQ<0038C00<04a<0oa=84`80Da<205hC0`1@4`00<Q<00`0C4`3o4dPC00<04a<0

3a<F02`C0P1Q4`@0CA<0038C00<04a<0oa=84`0301<C00XC1@0F4`T08Q<206DC0`1;4`00<Q<00`0C

4`3o4dPC00<04a<01A<502<C1`0K4`80J1<304TC000b4`0301<C0?lC>a<5008C00<04a<00a<00`0C

4`034`80;a<601@C0P1[4`80B1<0038C00<04a<0oa<m4`0701<C4`0C00044`0301<C00<0=Q<600hC

0P1]4`<0AQ<0038C00<04a<0oa<g4`<00a<01`0C4a<04`0011<303hC1P094`0301<C06hC0P154`00

<Q<00`0C4`3o4cdC00L04a<C01<000<C0P154`D011<00`0C4`1`4`80A1<001`C00<04a<00Q<00`0C

4`024`0301<C008C00<04a<011<00`0C4`3o4cdC00L04a<C01<0008C00<04`00BQ<507@C0P124`00

6a<00`0C00084`0701<C4`0C00054`0301<C0?lC?1<200@C00@04`000Q<00`0C4`1;4`H0LA<2044C

000F4`<00Q<00`0C00084`0301<C00<C00<04a<00a<20?lC@a<200@C00<04a<0BQ<00`0C4`044`@0

KQ<2040C000K4`0301<000TC00<04a<00P064`0301<C0?lC@A<00`0C4`044`0301<C04TC00<04a<0

2A<406/C00<04a<0?Q<001/C00<04`001a<00`0C00024`0301<C00DC00<04a<0oa=04`0301<C00DC

0P1:4`0301<C00dC101X4`80?Q<001`C00<04a<01Q<3008C0`054`0301<C0?lC?a<00`0C4`064`03

01<C04PC00<04a<04Q<406DC00<04a<0?1<0038C00<04a<0oa<n4`0301<C00LC00<04a<0B1<00`0C

4`0E4`D0HQ<00`0C4`0k4`00<Q<00`0C4`3o4cdC00<04a<021<00`0C4`174`0301<C01XC101O4`80

?1<0038C00<04a<0=a<A3O<C00<04a<02A<00`0C4`164`0301<C01lC101L4`80>a<0038C00<04a<0

<Q<53A4C1@g]4`0301<C00XC00<04a<0AQ<00`0C4`0R4`D0FA<00`0C4`0i4`00<Q<00`0C4`0`4`8=

6a<23NXC00<04a<02a<204LC00<04a<09Q<405LC00<04a<0>1<0038C00<04a<0;A<33AlC0`gV4`03

01<C00`C00<04a<0AA<00`0C4`0Z4`@0E1<203TC000b4`0301<C02/C0PdU4`8=i1<00`0C4`0<4`03

01<C04DC00<04a<0;Q<4054C00<04a<0=a<0038C00<04a<0:1<33BTC0PgQ4`0301<C00dC00<04a<0

A1<00`0C4`0c4`80Ca<203PC000b4`0301<C02HC0Pd^4`8=gQ<00`0C4`0>4`0301<C04@C00<04a<0

=A<404`C0P0g4`00<Q<00`0C4`0S4`<=<Q<00`dC4`3J4`0301<C00lC00<04a<0A1<00`0C4`0i4`80

Ba<00`0C4`0e4`00<Q<00`0C4`0Q4`8==Q<23MXC00<04a<03a<204@C00<04a<0?1<404LC0P0f4`00

<Q<00`0C4`0N4`<=>Q<00`dC4`3F4`0301<C010C00<04a<0@a<00`0C4`0o4`<0AQ<00`0C4`0d4`00

<Q<00`0C4`0L4`8=?Q<23MHC00<04a<041<00`0C4`134`0301<C048C0`134`80=A<0024C00<04a<0

0Q<00`0C4`024`0301<C00@C00<04a<06A<33D8C00<=4a<0dQ<00`0C4`0A4`0301<C048C00<04a<0

AQ<3044C00<04a<0<a<0020C00<04`001a<00`0C00054`0301<C01LC0Pe64`8=dQ<00`0C4`0A4`03

01<C048C00<04a<0BA<203lC00<04a<0<a<001/C0`024`0301<000TC00<04a<00a<201DC0`e:4`8=

ca<00`0C4`0B4`0301<C048C00<04a<0Ba<303dC00<04a<0<Q<0020C00<04`001a<200HC00<04a<0

4Q<23DlC00<=4a<0c1<00`0C4`0B4`80@a<00`0C4`1>4`80>a<00`0C4`0b4`0081<00`0C00074`03

01<C00DC00<04a<03Q<43E8C0Pg;4`0301<C01<C00<04a<0@A<00`0C4`1A4`<0>1<00`0C4`0b4`00

8A<00`0C4`064`<01A<00`0C4`0;4`<=F1<23LTC00<04a<04a<00`0C4`114`0301<C05@C0P0g4`03

01<C034C000b4`0301<C008C2@eM4`033A<C0<DC00<04a<051<00`0C4`114`0301<C05HC0`0d4`03

01<C034C000b4`D=Ia<23LDC00<04a<03Q<00`0C4`034`0301<C040C00<04a<0FA<3038C0P0b4`00

<Q<00`0C4`1[4`033A<C0<4C00<04a<03Q<00`0C00044`0301<C040C00<04a<0G1<2034C00<04a<0

<1<0038C00<04a<0K1<00`dC4`304`0301<C00TC0`044`0301<C008C0`104`0301<C05hC0P0_4`03

01<C030C000b4`0301<C06dC0Pg04`0301<C00hC0P054`0301<C03lC00<04a<0HA<302`C00<04a<0

<1<0038C00<04a<0Ka<00`dC4`2m4`0301<C00hC00<04a<011<00`0C4`0o4`0301<C06@C00<04a<0

:A<00`0C4`0`4`00<Q<00`0C4`1`4`8=_1<00`0C4`0?4`<011<00`0C4`0o4`0301<C06DC0`0X4`80

<A<0038C00<04a<0LQ<23KXC00<04a<05Q<00`0C4`0o4`0301<C06PC00<04a<09Q<00`0C4`0_4`00

<Q<00`0C4`1d4`8=^1<00`0C4`0F4`0301<C03lC00<04a<0JA<302DC00<04a<0;a<0038C00<04a<0

MQ<33KDC00<04a<05Q<2040C00<04a<0K1<202<C00<04a<0;a<0038C00<04a<0NA<23K<C00<04a<0

5Q<00`0C4`0o4`0301<C06dC0P0R4`0301<C02lC000b4`0301<C07/C0Pfa4`0301<C01HC00<04a<0

?a<00`0C4`1_4`8081<00`0C4`0_4`00<Q<00`0C4`1m4`D=Za<00`0C4`0G4`0301<C03hC00<04a<0

LQ<201hC00<04a<0;a<001`C00<04a<00Q<0100C4a<300<C00<04a<011<00`0C4`224`D=YQ<00`0C

4`0G4`0301<C03hC00<04a<0M1<201`C00<04a<0;a<001/C00<04`001a<00`0C4`024`0301<000DC

00<04a<0Qa<Q3HDC00<04a<05a<203lC00<04a<0MQ<201XC00<04a<0;a<001HC0`024`0301<000PC

00<04a<00a<00`0C4`034`80ZA<33H8C00<04a<05a<00`0C4`0n4`0301<C07PC00<04a<05Q<00`0C

4`0`4`006a<00`0C00084`0401<C4`801Q<00`0C4`2[4`D=O1<00`0C4`0H4`0301<C03hC00<04a<0

NA<201HC00<04a<0<1<001/C00<04`001a<00`0C00024`0301<C00DC00<04a<0/1<43GPC00<04a<0

61<00`0C4`0n4`0301<C07/C00<04a<04a<00`0C4`0`4`0071<00`0C4`074`0401<C4`<01A<00`0C

4`2d4`8=MQ<00`0C4`0H4`0301<C03hC00<04a<0O1<00`0C4`0B4`0301<C030C000b4`0301<C0;HC

0Ped4`0301<C01PC00<04a<0?A<00`0C4`1n4`804Q<00`0C4`0`4`00<Q<00`0C4`2h4`8=LQ<00`0C

4`0H4`80?Q<00`0C4`204`8041<00`0C4`0`4`00<Q<00`0C4`2j4`8=L1<00`0C4`0H4`0301<C024C

1@024`0301<C018C00<04a<02a<500034`00024C1@024`0301<C01lC1@024`0301<C01/C00@04a<C

1@000a<000034`0301<C034C000b4`0301<C0;`C0Pe^4`0301<C01PC00<04a<08a<01`0C4a<04`00

4a<00`0C4`0=4`0701<C4`0C000R4`0301<C008C00<04a<08A<01`0C4a<04`0071<200@C00<04a<0

0a<0100C4`0c4`00<Q<00`0C4`0V4`0301<C008C00@04a<C0`0S4`0301<C008C00<04a<00Q<3028C

00<04a<00Q<0100C4a<202@C00<04a<00Q<00`0C4`024`0300d=02HC1@114`0301<C01PC00<04a<0

8a<00`0C4`034`0301<C014C00<04a<03A<01`0C4a<04`008Q<00`0C4`024`0301<C024C00L04a<C

01<001hC00D04a<C00044`800Q<00`0C4`0a4`00<Q<00`0C4`0U4`0301<000LC00<04a<08Q<00`0C

00094`0301<C020C00<04`001a<00`0C000R4`0301<000LC00@04`0C0`dU4`0301<C044C00<04a<0

61<00`0C4`0S4`0401<C4`8051<00`0C4`0=4`0401<C4`808a<00`0C4`034`0301<C020C00<04a<0

0Q<00`0C4`0N4`8000<C01<00Q<00`0C00024`0301<C034C000b4`0301<C02DC00<04`0021<00`0C

4`0Q4`0301<000LC100Q4`0301<000LC00<04`008Q<00`0C00074`0301<000@C0PdS4`0301<C040C

00<04a<06A<00`0C4`0S4`0501<C4`005A<00`0C4`0=4`0501<C4`0091<01`0C4a<04`008Q<01`0C

4a<04`008A<200<C00D04`0C000d4`00<Q<00`0C4`0U4`0301<000PC00<04a<08A<00`0C00074`03

01<0028C00<04`001a<202<C00<04`0021<00`0C4`054`<=81<00`0C4`104`0301<C01TC0P0S4`80

0a<301<C00<04a<031<200@C0P0Q4`800a<3024C0P044`0301<C020C0P044`8000<C01<0<a<0038C

00<04a<09A<00`0C00074`0301<0028C00<04`0021<2028C00<04`001a<00`0C4`0R4`0301<000LC

00<04`002A<23AhC00<04a<0@1<00`0C4`0I4`0301<C03dC00<04a<0R1<00`0C4`054`0301<C038C

000b4`0301<C02HC00<04a<01a<00`0C4`0R4`0301<C00PC00<04a<08A<00`0C4`074`808a<00`0C

4`074`0301<C00XC0PdK4`80@Q<00`0C4`0I4`0301<C03dC00<04a<0RA<200DC00<04a<0<Q<0038C

00<04a<0c1<23EdC00<04a<06A<00`0C4`0m4`0301<C08/C00D04a<C000e4`00<Q<00`0C4`3>4`<=

FQ<00`0C4`0I4`0301<C03dC00<04a<0Ra<0100C4`0C4`@07a<0038C00<04a<0dA<33ELC00<04a<0

6A<00`0C4`0m4`0301<C08`C0P0D4`<081<0038C00<04a<0e1<23B4C0`0[4ol02Q<00`0C4`0N4`00

<Q<00`0C4`3F4`D=7A<00`0C4`0[4`0301<C008C00@04a<021<00`0C4`054`0301<C00DC00<04a<0

1A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`034`03

01<000LC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<0

1A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`03

01<C00DC00<04a<01A<300HC00<04a<031<2020C000/4n@03Pd600TC00<04a<0<1<00`0C4`0I4`03

01<C02HC00<04a<051<00`0C4`0@4`0301<C02HC00<04a<09Q<00`0C4`0V4`0401<C03HC000b4`03

01<C00PC00<04a<02A<00`0C4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC00<04a<0

2A<00`0C4`084`0301<C00TC00<04a<02A<00`0C4`094`0301<C00TC00<04a<021<00`0C4`094`03

01<C00TC00<04a<02A<00`0C4`084`0301<C00TC00<04a<02A<00`0C4`0<4`@0<1<00`0C4`0I4`03

01<C03dC00<04a<0Ra<01@0C4a<003DC000b4`0301<C02`C00<04a<0;1<00`0C4`0/4`0301<C02`C

00<04a<0;1<00`0C4`104`0301<C01TC00<04a<0?A<00`0C4`2:4`0301<C008C00<04a<0<a<0038C

00<04a<0oa</4`0301<C01TC00<04a<0?A<00`0C4`294`0301<C00@C00<04a<0<Q<0038C00<04a<0

oa</4`0301<C01TC0P0n4`0301<C08LC0P074`0301<C038C000b4`0301<C0?lC;1<00`0C4`0I4`03

01<C03dC00<04a<0Qa<00`0C4`064`0301<C038C000b4`0301<C0?lC;A<00`0C4`0H4`0301<C03dC

00<04a<0QQ<00`0C4`084`0301<C034C000b4`0301<C0?lC;A<00`0C4`0H4`0301<C03dC00<04a<0

Q1<200/C00<04a<0<A<0038C00<04a<0oa<]4`0301<C01PC00<04a<0?A<00`0C4`234`0301<C00/C

00<04a<0<A<0038C00<04a<0oa<]4`0301<C01PC00<04a<0?A<00`0C4`224`0301<C00`C00<04a<0

<A<0038C00<04a<0oa<]4`0301<C01PC0P0n4`0301<C080C0P0?4`0301<C034C000b4`0301<C0?lC

;A<00`0C4`0H4`0301<C03dC00<04a<0Oa<00`0C4`0@4`0301<C030C000b4`0301<C0?lC;A<00`0C

4`0H4`0301<C03hC00<04a<0O1<201<C00<04a<0<1<0038C00<04a<0oa<]4`0301<C01PC00<04a<0

?Q<00`0C4`1k4`8051<00`0C4`0`4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07TC

0P0F4`0301<C030C000b4`0301<C0?lC;A<00`0C4`0H4`0301<C03hC00<04a<0N1<00`0C4`0F4`03

01<C030C000b4`0301<C0?lC;Q<00`0C4`0G4`80?a<00`0C4`1f4`806A<00`0C4`0`4`00<Q<00`0C

4`3o4bhC00<04a<05a<00`0C4`0n4`0301<C07@C0P0L4`0301<C02lC000L4`0301<C008C00@04a<C

0`034`0301<C00@C00<04a<0oa<^4`0301<C01LC00<04a<0?Q<00`0C4`1c4`0301<C01`C00<04a<0

;a<001/C00<04`001a<00`0C4`024`0301<000DC00<04a<0oa<^4`0301<C01LC00<04a<0?a<00`0C

4`1`4`807a<00`0C4`0_4`006a<00`0C00084`0301<C00<C00<04a<00a<20?lC<1<00`0C4`0F4`03

01<C03lC00<04a<0KA<3024C00<04a<0;a<001/C00<04`0021<0100C4a<200HC00<04a<0oa<_4`03

01<C01HC00<04a<0?a<00`0C4`1/4`808a<00`0C4`0_4`006a<00`0C00074`0301<0008C00<04a<0

1A<00`0C4`3o4blC00<04a<05Q<2040C00<04a<0JQ<202DC00<04a<0;a<001`C00<04a<01a<0100C

4a<300DC00<04a<0oa<_4`0301<C01HC00<04a<0?a<00`0C4`1X4`809a<00`0C4`0_4`00<Q<00`0C

4`3o4blC00<04a<05Q<00`0C4`0o4`0301<C06HC0P0Y4`0301<C02lC000b4`0301<C0?lC<1<00`0C

4`0E4`0301<C03lC00<04a<0I1<202XC00<04a<0<1<0038C00<04a<0oa<`4`0301<C00lC00<04a<0

0a<00`0C4`0o4`0301<C068C0P0/4`0301<C030C000b4`0301<C0?lC<1<00`0C4`0>4`0301<000@C

00<04a<0@1<00`0C4`1N4`<0;Q<00`0C4`0`4`00<Q<00`0C4`3o4c0C00<04a<041<00`0C4`024`<0

@1<00`0C4`1L4`<0<1<00`0C4`0`4`00<Q<00`0C4`3o4c4C00<04a<03A<200DC00<04a<0@1<00`0C

4`1J4`80<Q<2038C000b4`0301<C0?lC<A<00`0C4`0=4`0301<C00@C00<04a<0@A<00`0C4`1G4`80

=1<00`0C4`0a4`00<Q<00`0C4`3o4c8C00<04a<031<300@C00<04a<0@A<00`0C4`1D4`<0=Q<00`0C

4`0a4`00<Q<00`0C4`3o4c8C00<04a<04a<00`0C4`114`0301<C058C0`0g4`80<a<0038C00<04a<0

oa<c4`0301<C018C0P124`0301<C04lC0`0j4`0301<C038C000b4`0301<C0?lC<a<00`0C4`0B4`03

01<C048C00<04a<0C1<303`C00<04a<0<Q<0038C00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C

4`194`<0?Q<00`0C4`0c4`00<Q<00`0C4`3o4c@C00<04a<04A<00`0C4`124`0301<C04LC0`104`03

01<C03<C000Q4`0301<C008C00<04a<00Q<00`0C4`044`0301<C0?lC=A<00`0C4`0@4`0301<C048C

00<04a<0A1<3048C0P0e4`0081<00`0C00074`0301<000DC00<04a<0oa<e4`0301<C010C00<04a<0

@a<00`0C4`104`<0AA<00`0C4`0d4`0081<00`0C00094`0301<C00<C0P3o4cLC00<04a<03a<204@C

00<04a<0?A<304LC0P0f4`0081<00`0C00074`801Q<00`0C4`3o4cHC00<04a<03a<00`0C4`144`03

01<C03TC0`1:4`0301<C03DC000P4`0301<000LC00<04a<01A<00`0C4`3o4cLC00<04a<03Q<00`0C

4`144`0301<C03HC101;4`80=a<0024C00<04a<01Q<300DC00<04a<0oa<h4`0301<C00dC00<04a<0

A1<00`0C4`0c4`<0Ca<00`0C4`0f4`00<Q<00`0C4`3o4cTC00<04a<031<00`0C4`154`0301<C02lC

0`1A4`0301<C03LC000b4`0301<C0?lC>A<00`0C4`0<4`0301<C04DC00<04a<0:a<405<C0P0i4`00

<Q<00`0C4`3o4cXC00<04a<02a<204LC00<04a<09a<405HC00<04a<0>1<0038C00<04a<0oa<j4`03

01<C00/C00<04a<0AQ<00`0C4`0S4`D0F1<203XC000b4`0301<C0?lC>a<200/C00<04a<0AQ<00`0C

4`0P4`@0Fa<203/C000b4`0301<C0?lC?A<00`0C4`084`0301<C04LC00<04a<06a<405lC00<04a<0

>Q<0038C00<04a<0oa<n4`0301<C00LC00<04a<0Aa<201PC1@1Q4`0301<C03/C000b4`0301<C0?lC

?Q<00`0C4`074`0301<C04PC00<04a<04a<406@C0P0m4`00<Q<00`0C4`3o4clC00<04a<01Q<204XC

00<04a<03Q<406LC0P0n4`00<Q<00`0C4`3o4d0C0P064`0301<C04TC00<04a<02Q<406XC0P0o4`00

<Q<00`0C4`3o4d8C00<04a<00a<00`0C4`1:4`0301<C00DC1@1/4`80@1<0038C00<04a<0oa=34`80

0a<00`0C4`1:4`8000<C00000`1`4`80@A<0038C00<04a<0oa<k4`D00Q<0100C4`024`0301<C04TC

1@1c4`80@Q<001`C00<04a<00Q<00`0C4`024`0301<C008C00<04a<011<00`0C4`3o4cdC00L04a<C

01<0008C0`174`D00Q<00`0C4`1a4`80@a<001/C00<04`0021<01`0C4a<04`001A<00`0C4`3o4cdC

00L04a<C01<000@C0`104`D021<00`0C4`1^4`80AA<001/C00<04`0021<00`0C4`034`0301<C00<C

0P3o4chC00L04a<C01<000@C00@04`00>Q<500dC00<04a<0KA<204HC000K4`0301<000TC00<04a<0

0P064`0301<C0?lC?A<01`0C4a<04`0011<0100C4a<3034C1P0C4`80Ja<304LC000K4`0301<000LC

00<04`000Q<00`0C4`054`0301<C0?lC?1<200@C00<04a<00a<00`0C4`044`<0:1<701TC0P1Y4`80

BA<001`C00<04a<01Q<3008C0`054`0301<C0?lCB1<00`0C4`074`D06a<9020C00<04a<0I1<304/C

000b4`0301<C0?lCB1<00`0C4`0<4a`0:A<2068C0`1=4`00<Q<00`0C4`3o4dPC0P1C4`80Ga<304lC

000b4`0301<C0?lCB1<00`0C4`1C4`80FQ<4058C000b4`0301<C0?lCB1<00`0C4`1D4`80EQ<405DC

000b4`0301<C0?lCB1<00`0C4`1F4`80Ca<505TC000b4`0301<C0?lCB1<00`0C4`1G4`<0B1<605dC

000b4`0301<C0?lCB1<00`0C4`1I4`<0@1<7068C000b4`0301<C0?lCB1<205`C0`0h4`L0J1<0038C

00<04a<0oa=84`0301<C05hC0`0^4`P0KQ<0038C00<04a<0oa=84`0301<C060C1@0S4`P0MA<0038C

00<04a<0oa=84`0301<C06@C1`0D4`X0O1<0038C00<04a<0oa=84`0301<C06XC5@264`00<Q<00`0C

4`3o4dPC00<04a<0oa<64`00:A<500@C00<04a<0oa=84`80oa<74`00:a<00`0C4`044`0301<C0?lC

B1<00`0C4`3o4`HC000[4`0301<C00@C0P3o4dTC00<04a<0oa<64`00:a<00`0C4`3o4olCF1<002/C

00<04a<0oa?o4ePC000Z4`80oa?o4eXC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00LA<400034`0000L00Q<00`0C4`024`0401<C4`8011<00`0C4`024`0301<C008C00<04a<0

0Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`03

01<C008C00<04a<00Q<00`0C4`05008C00<04a<0oa>/4`00LA<300PC00<04a<00Q<00`0C4`064`03

01<000<C00L04a<C01<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`03

01<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00034`0301<C008C00<04a<0

XA<20?lC2A<007<C00<04a<010024`0301<C008C00<04a<01Q<00`0C00034`0701<C4`0C00024`03

01<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0Q<00`0C00024`0301<0008C00<04`000a<00`0C4`024`0301<C0:8C00<04a<0oa<74`006A<40003

4`0000H00Q<:008C0P024`<00Q<300<C0P001Q<0000C02LC0P084`0301<C00<C00<04a<01A<200DC

00H04a<04`024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`03

01<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000a<00`0C4`034`0301<C09lC0`024`03

01<C0?lC11<001XC00H04a<04`024`0301<000@C00H04a<04`024`0301<000DC00<04a<00Q<01@0C

4a<0008C00@04`0C0P0a4`0701<C4`0C00074`0301<C008C00<04`000Q<00`0C00024`0301<0008C

00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C

00024`0301<0008C00<04`000a<01`0C4a<04`0011<00`0C4`2I4`0801<C01<04`3o4`DC000J4`06

01<C01<011<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`034`0301<C008C00D04a<C00024`04

01<04`80<1<200<C0`084`800Q<300<C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C

4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0401<C4`80

0a<300<C00<04a<0VQ<0200C4`0C01<0oa<54`006Q<01@0C4`0C00800a<200<C00<04a<00Q<200<C

00<04a<00a<00`0C4`024`0501<C4`000Q<01P0C000C0?lC;a<300044`0C0?lC1A<001XC00H04a<0

4`024`0301<0008C00<04`0011<03P0C4`0C01<04`0C01<00Q<01@0C4a<0008C00H04`004`3o4c<C

00<04`00oa<54`006A<400034`0000/00Q<500054`0001<01@0011<000034`8000@C000C0P3o4c@C

00<04a<0oa<44`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00

oa?o4hHC003o4olCQQ<00?lCoa>64`00\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.77084, -14.119, 0.0242408, 0.16996}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -57 0 ]

[.5 .63053 57 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -118 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(17.3900000000000005`) show

173.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .18368 m

.02499 .18368 L

.02606 .18367 L

.02729 .18366 L

.02846 .18364 L

.03053 .18359 L

.03279 .18351 L

.03527 .18341 L

.0379 .18326 L

.04262 .18294 L

.04749 .1825 L

.05205 .182 L

.06245 .18055 L

.07305 .17863 L

.08274 .17649 L

.10458 .17047 L

.14429 .15606 L

.18248 .14008 L

.2038 .13139 L

.22313 .12431 L

.24351 .11818 L

.25245 .11605 L

.26226 .11417 L

.27162 .11285 L

.27673 .11235 L

.27902 .11217 L

.2815 .11201 L

.28291 .11194 L

.2842 .11188 L

.28542 .11184 L

.28676 .1118 L

.28796 .11178 L

.28908 .11176 L

.29027 .11176 L

.29155 .11176 L

.29286 .11177 L

.2936 .11178 L

.29429 .1118 L

.29568 .11184 L

.29717 .11189 L

.29987 .11203 L

.30232 .11219 L

.30717 .11262 L

.31231 .11325 L

.32151 .11478 L

.33141 .11703 L

.34231 .1202 L

.36175 .12753 L

.38265 .13749 L

.42392 .16136 L

Mistroke

.46368 .18556 L

.50193 .20556 L

.52164 .21353 L

.54263 .21993 L

.55294 .22228 L

.56408 .22424 L

.5692 .22495 L

.5746 .22558 L

.57965 .22606 L

.58426 .22642 L

.58914 .22672 L

.59376 .22693 L

.5963 .22701 L

.59864 .22708 L

.60121 .22714 L

.60251 .22716 L

.60394 .22718 L

.6051 .22719 L

.60632 .2272 L

.60736 .2272 L

.6085 .22721 L

.60973 .22721 L

.61104 .22721 L

.61228 .2272 L

.61341 .2272 L

.61455 .22719 L

.6156 .22718 L

.61798 .22716 L

.62228 .22709 L

.63212 .22689 L

.63754 .22677 L

.64268 .22667 L

.64745 .22658 L

.65015 .22655 L

.65144 .22653 L

.65265 .22652 L

.65374 .22651 L

.65474 .2265 L

.65585 .2265 L

.65705 .2265 L

.65814 .22649 L

.65933 .2265 L

.66058 .2265 L

.66174 .22651 L

.66297 .22652 L

.66411 .22653 L

.66668 .22657 L

.66894 .22661 L

.67134 .22668 L

.6755 .22682 L

Mistroke

.68007 .22704 L

.68495 .22734 L

.6902 .22776 L

.69968 .22877 L

.70979 .23023 L

.72083 .23232 L

.74092 .23744 L

.76061 .24404 L

.78159 .25252 L

.82319 .27166 L

.86328 .28915 L

.88167 .29571 L

.90185 .3014 L

.91148 .30353 L

.9218 .30537 L

.9327 .30686 L

.93798 .30743 L

.94287 .30786 L

.95107 .30841 L

.95539 .30862 L

.95999 .30879 L

.9619 .30884 L

.96396 .30889 L

.96574 .30893 L

.96769 .30896 L

.96985 .30899 L

.97103 .309 L

.97213 .30901 L

.97316 .30901 L

.97409 .30901 L

.97517 .30902 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 -0.00394 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.68512 .02106 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4olCQQ<00?lCOQ<00`0C4`3o4`DC000Y4`D0oa=@4`0301<C08LC00<=4a<0

NQ<002/C00<04a<0oa=@4`80QA<63GXC000U4`<00a<00`0C4`044`80oa=:4`0301<C06`C3P094`T=

N1<002/C00<04a<011<00`0C4`3o4dTC00<04a<0I1<900dC2@093GPC000[4`0301<C00@C00<04a<0

oa=94`0301<C060C1@0N4`T=00<04a<0MA<002XC0P064`0301<C0?lCBA<00`0C4`1M4`@08A<;3@L0

L1<0038C00<04a<0oa=94`80G1<302DC2@d74`L0JQ<0038C00<04a<0oa=94`0301<C05PC100W4`T=

3A<706@C000b4`0301<C0?lCBA<00`0C4`1G4`80:Q<93A<C1P1O4`00<Q<00`0C4`3o4dTC00<04a<0

EA<202dC1PdK4`D0FQ<0038C00<04a<0oa=94`0301<C05@C0P0a4`033A<C01lC1@1F4`00<Q<00`0C

4`3o4dTC00<04a<0DQ<305PC101C4`00<Q<00`0C4`3o4dTC0P1B4`80GA<4050C000b4`0301<C0?lC

BA<00`0C4`0>4aP0:Q<2064C0`1>4`00<Q<00`0C4`3o4dTC00<04a<02A<501LC2@0Q4`80IA<204`C

000b4`0301<C0?lCBA<00`0C4`044`D091<701XC0P1X4`80BQ<0038C00<04a<0oa<l4`D00Q<00`0C

4`034`0401<C4`<0<1<601<C0P1Z4`<0B1<0038C00<04a<0oa<n4`0701<C4`0C00044`0401<003PC

1P0>4`0301<C06/C0P174`00<Q<00`0C4`3o4cPC0`034`0701<C4`0C00044`80?a<600PC00<04a<0

KQ<204DC000L4`0301<C008C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0oa<n4`0701<C4`0C

00034`80AA<500<C00<04a<0L1<204@C000K4`0301<000PC00L04a<C01<000DC00<04a<0oa<n4`08

01<C4`0C01<200034`0C04PC1P1b4`80@a<001HC0`024`0301<000PC00<04a<00a<00`0C4`034`80

oa<n4`8011<00`0C00034`0301<C04XC00<04`00101_4`80@Q<001/C00<04`002A<00`0C4`0200HC

00<04a<0oa=34`8011<00`0C4`194`0301<C00@C1@1/4`80@A<001/C00<04`001a<00`0C00024`03

01<C00DC00<04a<0oa=14`801Q<00`0C4`184`0301<C00TC1@1Y4`80@1<001`C00<04a<01Q<3008C

0`054`0301<C0?lC@1<00`0C4`064`80BA<00`0C4`0=4`D0IQ<203lC000b4`0301<C0?lC?a<00`0C

4`074`0301<C04LC00<04a<04Q<506<C0P0n4`00<Q<00`0C4`3o4chC00<04a<021<00`0C4`164`80

61<4064C0P0m4`00<Q<00`0C4`3o4cdC00<04a<02A<00`0C4`164`0301<C01/C101N4`80?1<0038C

00<04a<0oa<m4`0301<C00TC00<04a<0AQ<00`0C4`0N4`D0Fa<00`0C4`0j4`00<Q<00`0C4`3o4c`C

00<04a<02Q<00`0C4`154`0301<C02<C101H4`80>a<0038C00<04a<0=a<A3O8C00<04a<02a<204HC

00<04a<09Q<405HC0P0j4`00<Q<00`0C4`0b4`D=4A<23NlC00<04a<031<00`0C4`144`0301<C02/C

101C4`0301<C03PC000b4`0301<C030C0PdH4`<=ja<00`0C4`0=4`0301<C04@C00<04a<0;Q<3054C

0P0i4`00<Q<00`0C4`0]4`<=7A<23NPC00<04a<03Q<00`0C4`144`0301<C034C101>4`0301<C03LC

000b4`0301<C02/C0PdR4`<=iA<00`0C4`0>4`0301<C04<C00<04a<0=Q<304`C00<04a<0=Q<0038C

00<04a<0:1<33BLC0PgR4`0301<C00lC00<04a<0@a<00`0C4`0i4`<0BA<00`0C4`0f4`00<Q<00`0C

4`0V4`8=;1<23N0C00<04a<03a<204<C00<04a<0?A<304LC00<04a<0=A<0038C00<04a<08a<33C0C

0PgM4`0301<C010C00<04a<0@Q<00`0C4`104`<0A1<00`0C4`0e4`008A<00`0C4`024`0301<C008C

00<04a<011<00`0C4`0Q4`8==A<23MXC00<04a<04A<00`0C4`114`0301<C04<C0`134`0301<C03@C

000P4`0301<000LC00<04`001A<00`0C4`0N4`<=>A<00`dC4`3G4`0301<C014C00<04a<0@A<00`0C

4`164`<0@1<00`0C4`0d4`006a<3008C00<04`002A<00`0C4`034`807A<23CdC0PgF4`0301<C018C

00<04a<0@A<00`0C4`194`<0?Q<00`0C4`0c4`0081<00`0C00074`801Q<00`0C4`0I4`<=@A<23M@C

00<04a<04Q<00`0C4`114`0301<C04`C0P0l4`0301<C03<C000P4`0301<000LC00<04a<01A<00`0C

4`0F4`<=AQ<00`dC4`3@4`0301<C01<C0P114`0301<C04lC0`0i4`80=1<0024C00<04a<01Q<300DC

00<04a<04Q<43DXC0Pg@4`0301<C01<C00<04a<0@1<00`0C4`1B4`80>1<00`0C4`0b4`00<Q<00`0C

4`0?4`<=D1<23LhC00<04a<04a<00`0C4`104`0301<C05@C0`0e4`0301<C038C000b4`0301<C00dC

0PeE4`033A<C0<XC00<04a<03Q<00`0C4`034`0301<C03lC00<04a<0Ea<303<C0P0c4`00<Q<00`0C

4`084`D=F1<23LXC00<04a<03A<00`0C00044`0301<C03lC00<04a<0FQ<2038C00<04a<0<A<0038C

2`eO4`8=aa<00`0C4`094`<011<00`0C4`024`80@1<00`0C4`1L4`80<1<00`0C4`0a4`00<Q<00`0C

4`1Y4`033A<C0<@C00<04a<03Q<200DC00<04a<0?a<00`0C4`1N4`<0;A<00`0C4`0a4`00<Q<00`0C

4`1Z4`8=a1<00`0C4`0>4`0301<C00@C00<04a<0?a<00`0C4`1P4`80;1<2038C000b4`0301<C06`C

0Pg14`0301<C00lC0`044`0301<C03lC00<04a<0HQ<302XC00<04a<0<1<0038C00<04a<0KQ<23KlC

00<04a<05Q<00`0C4`0n4`0301<C06HC00<04a<09a<00`0C4`0`4`00<Q<00`0C4`1`4`8=_A<00`0C

4`0F4`0301<C03hC00<04a<0Ia<302HC00<04a<0<1<0038C00<04a<0LQ<33KTC00<04a<05a<203lC

00<04a<0JQ<00`0C4`0S4`0301<C030C000b4`0301<C07DC0Pfg4`0301<C01LC00<04a<0?Q<00`0C

4`1[4`<08Q<00`0C4`0`4`00<Q<00`0C4`1g4`@=/a<00`0C4`0G4`0301<C03hC00<04a<0KQ<2020C

00<04a<0<1<0038C00<04a<0Na<33K0C00<04a<05a<00`0C4`0n4`0301<C06lC0P0O4`0301<C030C

000L4`0301<C008C00@04a<C0`034`0301<C00@C00<04a<0OQ<33JdC00<04a<05a<00`0C4`0m4`03

01<C078C0P0M4`0301<C030C000K4`0301<000LC00<04a<00Q<00`0C00054`0301<C084C8Pf:4`03

01<C01PC00<04a<0?A<00`0C4`1d4`806a<00`0C4`0`4`005Q<3008C00<04`0021<00`0C4`034`03

01<C00<C0P2T4`D=QA<00`0C4`0H4`80?Q<00`0C4`1e4`806Q<00`0C4`0`4`006a<00`0C00084`04

01<C4`801Q<00`0C4`2X4`@=PA<00`0C4`0H4`0301<C03dC00<04a<0Ma<201PC00<04a<0<1<001/C

00<04`001a<00`0C00024`0301<C00DC00<04a<0[1<53G`C00<04a<061<00`0C4`0m4`0301<C07TC

00<04a<05A<00`0C4`0`4`0071<00`0C4`074`0401<C4`<01A<00`0C4`2a4`<=NA<00`0C4`0H4`03

01<C03dC00<04a<0NQ<201@C00<04a<0<A<0038C00<04a<0]1<23GLC00<04a<061<00`0C4`0m4`03

01<C07`C0P0B4`0301<C034C000b4`0301<C0;HC0Pee4`0301<C01PC00<04a<0?A<00`0C4`1n4`03

01<C00lC00<04a<0<A<0038C00<04a<0^1<23G<C00<04a<061<2028C1@024`0301<C018C00<04a<0

2Q<500034`00024C1@024`0301<C01lC1@024`0301<C01TC00<04a<00a<500034`0000<C00<04a<0

<A<0038C00<04a<0^Q<23G4C00<04a<061<00`0C4`0S4`0701<C4`0C000C4`0301<C00`C00L04a<C

01<0028C00<04a<00Q<00`0C4`0Q4`0701<C4`0C000K4`801A<00`0C4`034`0401<C03<C000b4`03

01<C02HC00<04a<00Q<0100C4a<302<C00<04a<00Q<00`0C4`024`<08Q<00`0C4`024`0401<C4`80

91<00`0C4`024`0401<C4`<=9a<5048C00<04a<061<00`0C4`0S4`0301<C00<C00<04a<04A<00`0C

4`0<4`0701<C4`0C000R4`0301<C008C00<04a<08A<01`0C4a<04`007A<00`0C4`024`0301<C008C

0P024`0301<C034C000b4`0301<C02DC00<04`001a<00`0C4`0R4`0301<000TC00<04a<081<00`0C

00074`0301<0028C00<04`001a<00`0C00023BLC00<04a<0@Q<00`0C4`0H4`0301<C02<C00@04a<C

0P0D4`0301<C00`C00@04a<C0P0S4`0301<C00<C00<04a<081<00`0C4`024`0301<C01`C0P034`07

01<C4`0C00024`0301<C034C000b4`0301<C02DC00<04`0021<00`0C4`0Q4`0301<000LC100Q4`03

01<000LC00<04`008Q<00`0C00074`0301<0008C0PdU4`0301<C048C00<04a<061<00`0C4`0S4`05

01<C4`005A<00`0C4`0<4`0501<C4`0091<01`0C4a<04`008Q<01`0C4a<04`007a<0100C4`034`05

01<04`00=1<0038C00<04a<09A<00`0C00084`0301<C024C00<04`001a<00`0C000R4`0301<000LC

0P0S4`0301<000PC00<04a<00a<23B<C00<04a<0@A<00`0C4`0I4`0301<C028C0P034`<04a<00`0C

4`0;4`8011<2024C0P034`<08A<200@C00<04a<07a<300@C0P000a<04`0c4`00<Q<00`0C4`0U4`03

01<000LC00<04`008Q<00`0C00084`808Q<00`0C00074`0301<C028C00<04`001a<00`0C00064`8=

8A<00`0C4`114`0301<C01TC0P0n4`0301<C08LC00<04a<011<00`0C4`0c4`00<Q<00`0C4`0V4`03

01<C00LC00<04a<08Q<00`0C4`084`0301<C024C00<04a<01a<202<C00<04a<01a<00`0C4`074`8=

7Q<204<C00<04a<06A<00`0C4`0m4`0301<C08LC00<04a<011<00`0C4`0c4`00<Q<00`0C4`394`8=

HA<00`0C4`0I4`0301<C03dC00<04a<0R1<00`0C4`024`0301<C03@C000b4`0301<C0</C10eM4`03

01<C01TC00<04a<0?A<00`0C4`294`0501<C4`00=Q<0038C00<04a<0ca<43ETC00<04a<06A<00`0C

4`0m4`0301<C08XC00<04`0051<401lC000b4`0301<C0=<C0PdR4`<0<Q<00`0C4`0I4`0301<C03dC

00<04a<0Ra<00`0C4`0C4`<081<0038C00<04a<0eA<53AhC00<04a<0:a?m00/C00<04a<07Q<002`C

h`0?3@H02A<00`0C4`0/4`0301<C008C00@04a<01a<00`0C4`064`0301<C00DC00<04a<01A<00`0C

4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`044`8021<00`0C

4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC

00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C

4`054`0301<000DC00<04a<03A<2020C000b4`0301<C00PC00<04a<02A<00`0C4`094`0301<C00TC

00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0C4`084`0301<C00TC00<04a<02A<00`0C

4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0C4`084`0301<C00TC

00<04a<02A<00`0C4`0<4`@0<A<00`0C4`0I4`0301<C03dC00<04a<0RA<0100C4`0g4`00<Q<00`0C

4`0/4`0301<C02`C00<04a<0;1<00`0C4`0/4`0301<C02`C00<04a<0@A<00`0C4`0I4`0301<C03dC

00<04a<0R1<00`0C4`024`0301<C03@C000b4`0301<C0?lC;A<00`0C4`0I4`0301<C03dC00<04a<0

Qa<00`0C4`044`0301<C03<C000b4`0301<C0?lC;A<00`0C4`0I4`80?Q<00`0C4`274`0301<C00@C

00<04a<0<a<0038C00<04a<0oa<]4`0301<C01TC00<04a<0?A<00`0C4`264`0301<C00HC00<04a<0

<Q<0038C00<04a<0oa<]4`0301<C01TC00<04a<0?A<00`0C4`244`802A<00`0C4`0b4`00<Q<00`0C

4`3o4bhC00<04a<061<00`0C4`0m4`0301<C08<C00<04a<02Q<00`0C4`0a4`00<Q<00`0C4`3o4bhC

00<04a<061<00`0C4`0m4`0301<C088C00<04a<02a<00`0C4`0a4`00<Q<00`0C4`3o4bhC00<04a<0

61<00`0C4`0m4`0301<C084C00<04a<031<00`0C4`0a4`00<Q<00`0C4`3o4bhC00<04a<061<203hC

00<04a<0Oa<200lC00<04a<0<A<0038C00<04a<0oa<^4`0301<C01PC00<04a<0?A<00`0C4`1n4`03

01<C00lC00<04a<0<A<0038C00<04a<0oa<^4`0301<C01PC00<04a<0?A<00`0C4`1m4`0301<C010C

00<04a<0<A<0038C00<04a<0oa<^4`0301<C01PC00<04a<0?A<00`0C4`1k4`804a<00`0C4`0a4`00

<Q<00`0C4`3o4bhC00<04a<061<00`0C4`0m4`0301<C07TC0P0F4`0301<C030C000b4`0301<C0?lC

;Q<00`0C4`0H4`0301<C03dC00<04a<0N1<201LC00<04a<0<1<0038C00<04a<0oa<^4`0301<C01PC

0P0n4`0301<C07HC0P0I4`0301<C030C000b4`0301<C0?lC;Q<00`0C4`0H4`0301<C03dC00<04a<0

MA<00`0C4`0I4`0301<C030C000L4`0301<C008C00@04a<C0`034`0301<C00@C00<04a<0oa<_4`03

01<C01LC00<04a<0?A<00`0C4`1c4`8071<00`0C4`0`4`006a<00`0C00074`0301<C008C00<04`00

1A<00`0C4`3o4blC00<04a<05a<00`0C4`0m4`0301<C074C0P0N4`0301<C030C000K4`0301<000PC

00<04a<00a<00`0C4`034`80oa<`4`0301<C01LC00<04a<0?Q<00`0C4`1^4`8081<00`0C4`0`4`00

6a<00`0C00084`0401<C4`801Q<00`0C4`3o4blC00<04a<05a<00`0C4`0n4`0301<C06`C0P0R4`03

01<C030C000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C0?lC;a<00`0C4`0G4`80?a<00`0C

4`1Z4`8091<00`0C4`0`4`0071<00`0C4`074`0401<C4`<01A<00`0C4`3o4c0C00<04a<05Q<00`0C

4`0n4`0301<C06PC0`0U4`0301<C030C000b4`0301<C0?lC<1<00`0C4`0F4`0301<C03hC00<04a<0

IQ<202PC00<04a<0<1<0038C00<04a<0oa<`4`0301<C01HC00<04a<0?a<00`0C4`1S4`<0:A<00`0C

4`0`4`00<Q<00`0C4`3o4c4C00<04a<03a<00`0C4`034`0301<C03lC00<04a<0HA<202/C0P0b4`00

<Q<00`0C4`3o4c4C00<04a<03Q<00`0C00044`0301<C03lC00<04a<0Ga<202dC00<04a<0<A<0038C

00<04a<0oa<a4`0301<C010C00<04a<00Q<2040C00<04a<0G1<302lC00<04a<0<A<0038C00<04a<0

oa<b4`0301<C00dC0P054`0301<C03lC00<04a<0Fa<2034C00<04a<0<A<0038C00<04a<0oa<b4`03

01<C00dC00<04a<011<00`0C4`0o4`0301<C05PC0`0b4`80<a<0038C00<04a<0oa<c4`0301<C00`C

0`044`0301<C040C00<04a<0EA<203DC00<04a<0<Q<0038C00<04a<0oa<c4`0301<C01<C00<04a<0

@1<00`0C4`1B4`<0=a<00`0C4`0b4`00<Q<00`0C4`3o4c<C00<04a<04a<00`0C4`104`0301<C050C

0`0i4`0301<C038C000b4`0301<C0?lC=1<00`0C4`0B4`80@Q<00`0C4`1<4`<0>a<00`0C4`0c4`00

<Q<00`0C4`3o4c@C00<04a<04Q<00`0C4`114`0301<C04XC0`0m4`0301<C03<C000b4`0301<C0?lC

=A<00`0C4`0A4`0301<C044C00<04a<0Aa<303lC0P0e4`008A<00`0C4`024`0301<C008C00<04a<0

11<00`0C4`3o4cDC00<04a<04A<00`0C4`114`0301<C04@C0`124`0301<C03@C000P4`0301<000LC

00<04`001A<00`0C4`3o4cHC00<04a<041<00`0C4`124`0301<C044C0P144`80=Q<0020C00<04`00

2A<00`0C4`034`80oa<h4`0301<C00lC00<04a<0@Q<00`0C4`0m4`@0AQ<00`0C4`0e4`0081<00`0C

00074`801Q<00`0C4`3o4cLC00<04a<03a<204@C00<04a<0>Q<304PC0P0g4`0081<00`0C00074`03

01<C00DC00<04a<0oa<h4`0301<C00hC00<04a<0@a<00`0C4`0g4`<0Ba<00`0C4`0f4`008A<00`0C

4`064`<01A<00`0C4`3o4cPC00<04a<03Q<00`0C4`144`0301<C038C101=4`80>1<0038C00<04a<0

oa<i4`0301<C00dC00<04a<0A1<00`0C4`0_4`@0D1<00`0C4`0g4`00<Q<00`0C4`3o4cTC00<04a<0

3A<00`0C4`144`0301<C02`C101B4`0301<C03PC000b4`0301<C0?lC>Q<00`0C4`0<4`80AQ<00`0C

4`0X4`<0EA<203XC000b4`0301<C0?lC>a<00`0C4`0;4`0301<C04DC00<04a<091<405PC00<04a<0

>A<0038C00<04a<0oa<l4`0301<C00XC00<04a<0AQ<00`0C4`0P4`@0FQ<00`0C4`0j4`00<Q<00`0C

4`3o4cdC00<04a<02A<00`0C4`164`0301<C01`C101M4`80?1<0038C00<04a<0oa<n4`0301<C00PC

00<04a<0AQ<00`0C4`0H4`D0Ga<203dC000b4`0301<C0?lC?a<00`0C4`074`0301<C04LC00<04a<0

4a<5068C0P0n4`00<Q<00`0C4`3o4d0C00<04a<01Q<204TC00<04a<03Q<506HC00<04a<0?A<0038C

00<04a<0oa=14`0301<C00DC00<04a<0B1<00`0C4`0:4`D0JA<00`0C4`0n4`00<Q<00`0C4`3o4d8C

00<04a<011<00`0C4`194`0301<C00DC1@1/4`0301<C03lC000b4`0301<C0?lC@a<00`0C4`034`03

01<C04TC0P024`D0Ka<00`0C4`104`00<Q<00`0C4`3o4c`C1@024`<00a<00`0C4`194`D0LA<204<C

000L4`0301<C008C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0oa<n4`0901<C4`0C01<0008C

00<04a<0AA<500034`0C074C0P144`006a<00`0C00084`0701<C4`0C00054`0301<C0?lC?Q<01`0C

4a<04`000Q<4044C1@064`80L1<204DC000K4`0301<000PC00<04a<00a<00`0C4`034`80oa<o4`07

01<C4`0C00044`0301<003/C1@0<4`80KA<304HC000K4`0301<000TC00<04a<00P064`0301<C0?lC

?Q<01`0C4a<04`0011<00`0C4`04034C1P0B4`0301<C06XC0P184`006a<00`0C00074`0301<0008C

00<04a<01A<00`0C4`3o4cdC0P044`0301<C00<C00<04a<011<302PC1`0H4`80J1<304TC000L4`03

01<C00HC0`024`<01A<00`0C4`3o4dTC00<04a<01a<501`C200O4`0301<C06@C0`1;4`00<Q<00`0C

4`3o4dTC00<04a<031<<00034`0000d0:1<2068C0`1=4`00<Q<00`0C4`3o4dTC0P0H4`<0=a<205hC

101?4`00<Q<00`0C4`3o4dTC00<04a<0DQ<205XC101B4`00<Q<00`0C4`3o4dTC00<04a<0E1<00`0C

4`1C4`D0EA<0038C00<04a<0oa=94`0301<C05DC0P1?4`D0FA<0038C00<04a<0oa=94`0301<C05HC

0`184`H0GA<0038C00<04a<0oa=94`0301<C05PC0`104`L0HQ<0038C00<04a<0oa=94`80Fa<303PC

1`1X4`00<Q<00`0C4`3o4dTC00<04a<0GA<302lC1`1^4`00<Q<00`0C4`3o4dTC00<04a<0Ga<502<C

201e4`00<Q<00`0C4`3o4dTC00<04a<0Ha<601DC2P1l4`00<Q<00`0C4`3o4dTC00<04a<0JA<F08DC

000b4`0301<C0?lCBA<00`0C4`3o4`DC000Y4`D011<00`0C4`3o4dTC0P3o4`HC000[4`0301<C00@C

00<04a<0oa=94`0301<C0?lC1A<002/C00<04a<011<20?lCBQ<00`0C4`3o4`DC000[4`0301<C0?lC

oa=H4`00:a<00`0C4`3o4olCF1<002XC0P3o4olCFQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC001a4`@000<C00001`024`0301<C008C00@04a<C0P034`8011<00`0C4`024`03

01<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<0

0Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C0?lC[1<0074C0`084`0301<C008C

00<04a<021<00`0C4`024`0601<C01<00Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`03

01<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0Q<00`0C002S4`80oa<84`00La<00`0C4`04008C00<04a<00Q<00`0C4`074`0301<C008C0P024`03

01<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<000@C00<04a<0XQ<00`0C4`3o4`HC

000I4`@000<C00001P024`X00Q<2008C0`024`<00a<200064`0001<09a<200PC00<04a<00a<00`0C

4`074`0601<C01<00Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`80

Xa<3008C00<04a<0oa<34`006Q<01P0C4`0C008C00<04`0011<01P0C4`0C008C00<04`001A<00`0C

4`024`0501<C4`000Q<0100C01<2034C00L04a<C01<000LC00<04`000Q<00`0C00024`0301<0008C

00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C

00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04a<011<00`0C4`2J4`0801<C01<0

4`3o4`@C000J4`0601<C01<011<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`034`0301<C008C

00D04a<C00024`0401<04`80<1<200<C0`084`0301<C008C0P034`0301<C008C00<04a<00Q<00`0C

4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C

00<04a<00Q<00`0C4`024`0401<C4`<00a<00`0C4`2K4`0801<C01<04`3o4`@C000J4`0501<C01<0

0P034`800a<00`0C4`024`800a<00`0C4`034`0301<C008C00D04a<C00024`0601<001<0oa<`4`<0

00@C01<0oa<44`006Q<01P0C4`0C008C00<04`000Q<00`0C00044`0>01<C01<04`0C01<04`024`05

01<C4`000Q<01P0C000C0?lC=1<00`0C003o4`@C000I4`@000<C00002`024`D000DC00004`050004

4`0000<C0P0011<001<20?lC=A<00`0C4`3o4`<C003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olC

QQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC0000\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.70004, -14.2939, 0.0243893, 0.171001}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -57 0 ]

[.5 .63053 57 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -118 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(17.0850000000000008`) show

173.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .19623 m

.02499 .19622 L

.02606 .19622 L

.02729 .1962 L

.02846 .19618 L

.03053 .19613 L

.03279 .19605 L

.03527 .19594 L

.0379 .1958 L

.04262 .19547 L

.04749 .19502 L

.05205 .19452 L

.06245 .19304 L

.07305 .19109 L

.08274 .18893 L

.10458 .18286 L

.14429 .1685 L

.18248 .15288 L

.2038 .1446 L

.22313 .138 L

.23281 .13517 L

.24328 .13254 L

.25309 .13053 L

.26226 .1291 L

.26684 .12856 L

.27176 .1281 L

.27456 .1279 L

.27722 .12776 L

.2796 .12766 L

.28095 .12762 L

.2822 .1276 L

.2834 .12758 L

.2847 .12757 L

.28593 .12757 L

.28705 .12758 L

.2883 .1276 L

.289 .12762 L

.28966 .12763 L

.29241 .12773 L

.29382 .1278 L

.29516 .12787 L

.29766 .12804 L

.30326 .12856 L

.30789 .12913 L

.31298 .12991 L

.32327 .13196 L

.34173 .13715 L

.36117 .14451 L

.38207 .1542 L

.42334 .17649 L

Mistroke

.4631 .19797 L

.50135 .21471 L

.52106 .22099 L

.532 .22371 L

.54205 .22573 L

.55236 .22736 L

.55767 .22803 L

.5635 .22863 L

.56824 .22903 L

.57332 .22938 L

.57868 .22966 L

.58368 .22984 L

.58625 .22991 L

.58898 .22997 L

.59131 .23001 L

.59264 .23002 L

.59388 .23003 L

.59458 .23004 L

.59524 .23004 L

.59592 .23004 L

.59667 .23004 L

.5979 .23005 L

.59922 .23005 L

.59996 .23004 L

.60077 .23004 L

.60153 .23004 L

.60223 .23003 L

.60496 .23001 L

.60737 .22999 L

.60962 .22996 L

.61475 .22987 L

.62509 .22967 L

.63009 .22958 L

.63273 .22954 L

.63553 .2295 L

.63797 .22947 L

.63927 .22946 L

.64066 .22945 L

.64194 .22944 L

.64312 .22943 L

.64424 .22943 L

.64542 .22943 L

.64658 .22943 L

.64764 .22943 L

.64886 .22944 L

.65001 .22944 L

.65107 .22945 L

.65205 .22946 L

.65428 .22949 L

.65652 .22954 L

Mistroke

.65898 .2296 L

.66397 .22976 L

.66917 .23 L

.67412 .2303 L

.68339 .23108 L

.69338 .23225 L

.70428 .23395 L

.72397 .23821 L

.74494 .24437 L

.78655 .26054 L

.82663 .27811 L

.8652 .29306 L

.88516 .29905 L

.89533 .30154 L

.90623 .30378 L

.91651 .30547 L

.92588 .30669 L

.9353 .30761 L

.93954 .30794 L

.94422 .30824 L

.9481 .30845 L

.95227 .30863 L

.95669 .30877 L

.96083 .30888 L

.96473 .30894 L

.9667 .30897 L

.96884 .30899 L

.97069 .309 L

.97172 .30901 L

.97265 .30901 L

.97353 .30901 L

.97447 .30902 L

.97537 .30902 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 -0.00895 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.63564 .01605 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00:A<50?lCDA<00`0C4`1i4`033A<C08LC000[4`03

01<C0?lCDA<00`0C4`1f4`H=Qa<002DC0`034`0301<C00@C0P3o4d/C00<04a<0MA<93HDC000[4`03

01<C00@C00<04a<0oa=:4`0301<C070C0`024`T=QA<002/C00<04a<011<00`0C4`3o4dXC00<04a<0

IA<<00044`0000T=10214`00:Q<200HC00<04a<0oa=:4`0301<C060C1@0?4`/=0a<907PC000b4`03

01<C0?lCBQ<00`0C4`1M4`@051<93@`C1`1b4`00<Q<00`0C4`3o4dXC00<04a<0FQ<301PC2@dC4`L0

Ja<0038C00<04a<0oa=:4`0301<C05PC0`0J4`T=6A<606HC000b4`0301<C0?lCBQ<00`0C4`1F4`80

7Q<63B4C1P1P4`00<Q<00`0C4`3o4dXC00<04a<0EA<2028C00<=4a<09Q<605/C000b4`0301<C0?lC

BQ<00`0C4`1C4`80DQ<505LC000b4`0301<C0?lCBQ<00`0C4`1B4`80Ea<405@C000b4`0301<C0?lC

BQ<00`0C4`1A4`0301<C05XC101A4`00<Q<00`0C4`3o4dXC00<04a<03Q<F02/C0P1P4`<0Ca<0038C

00<04a<0oa=:4`0301<C00TC1@0E4`T08a<00`0C4`1R4`80CA<0038C00<04a<0oa=:4`0301<C00@C

1@0S4`L06Q<206LC0P1;4`00<Q<00`0C4`3o4c`C1@024`0301<C00@C00<04a<00Q<202hC1`0C4`80

JQ<204TC000b4`0301<C0?lC?Q<01`0C4a<04`001A<00`0C000203HC1@0?4`0301<C06XC0P184`00

71<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`044`0301<C0?lC>1<300<C00L04a<C01<000DC

0P0n4`D02A<00`0C4`1]4`80AQ<001/C00<04`0021<01`0C4a<04`001A<00`0C4`3o4chC00L04a<C

01<000@C0P144`D00a<00`0C4`1_4`80AA<001HC0`024`0301<000PC00<04a<00a<00`0C4`034`80

oa<o4`0701<C4`0C00024`8000<C01<0Aa<5078C0P144`006a<00`0C00094`0301<C00801Q<00`0C

4`3o4cdC0P044`0401<000<C00<04a<0BA<00`0C000406hC0P134`006a<00`0C00074`0301<0008C

00<04a<01A<00`0C4`3o4d@C00<04a<00a<00`0C4`184`0301<C00@C1@1[4`80@Q<001`C00<04a<0

1Q<3008C0`054`0301<C0?lC@Q<200HC00<04a<0B1<00`0C4`084`D0J1<2044C000b4`0301<C0?lC

@A<00`0C4`064`0301<C04LC00<04a<03A<506DC0P104`00<Q<00`0C4`3o4d0C00<04a<01a<00`0C

4`164`0301<C018C1@1R4`80?a<0038C00<04a<0oa<o4`0301<C00PC00<04a<0AQ<00`0C4`0F4`@0

H1<203hC000b4`0301<C0?lC?Q<00`0C4`094`0301<C04DC0P0L4`@0GA<203dC000b4`0301<C0?lC

?A<00`0C4`0:4`0301<C04DC00<04a<07Q<505XC00<04a<0>a<0038C00<04a<0oa<l4`0301<C00/C

00<04a<0A1<00`0C4`0S4`@0F1<00`0C4`0j4`00<Q<00`0C4`3o4c`C00<04a<02a<00`0C4`144`03

01<C02HC101E4`80>a<0038C00<04a<0oa<k4`0301<C00`C00<04a<0A1<00`0C4`0Z4`@0DQ<00`0C

4`0i4`00<Q<00`0C4`3o4cXC00<04a<03A<00`0C4`134`0301<C02hC0`1A4`0301<C03PC000b4`03

01<C03DC4@gb4`0301<C00hC00<04a<0@a<00`0C4`0a4`@0CA<203TC000b4`0301<C030C1@dA4`<=

kQ<00`0C4`0?4`0301<C048C00<04a<0=Q<304/C00<04a<0=a<0038C00<04a<0;A<33ATC10gZ4`03

01<C00lC00<04a<0@Q<00`0C4`0i4`<0B1<203PC000b4`0301<C02/C0PdP4`8=ia<00`0C4`0@4`03

01<C048C00<04a<0>a<404HC00<04a<0=Q<0024C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0

:1<33B@C0`gT4`0301<C010C00<04a<0@A<00`0C4`104`80A1<203LC000P4`0301<000LC00<04`00

1A<00`0C4`0V4`8=:Q<23N4C00<04a<04A<00`0C4`114`0301<C048C10114`0301<C03DC000K4`<0

0Q<00`0C00094`0301<C00<C0P0T4`<=;Q<23MlC00<04a<04A<00`0C4`114`0301<C04DC0`0o4`03

01<C03DC000P4`0301<000LC0P064`0301<C024C0Pdc4`8=g1<00`0C4`0B4`0301<C040C00<04a<0

BA<203hC00<04a<0=1<0020C00<04`001a<00`0C4`054`0301<C01hC0`dg4`8=fQ<00`0C4`0B4`03

01<C040C00<04a<0Ba<303/C00<04a<0=1<0024C00<04a<01Q<300DC00<04a<071<23C`C00<=4a<0

eQ<00`0C4`0C4`0301<C03lC00<04a<0Ca<203TC0P0e4`00<Q<00`0C4`0I4`<=?a<23MHC00<04a<0

4a<00`0C4`0o4`0301<C054C0`0g4`0301<C03<C000b4`0301<C01HC0`e44`8=e1<00`0C4`0C4`03

01<C03lC00<04a<0E1<203DC00<04a<0<a<0038C00<04a<04Q<43DTC00<=4a<0d1<00`0C4`0=4`03

01<C00@C00<04a<0?a<00`0C4`1F4`<0<Q<203@C000b4`0301<C00lC0`e>4`8=d1<00`0C4`0<4`03

01<000DC00<04a<0?a<00`0C4`1H4`<0<A<00`0C4`0b4`00<Q<00`0C4`0=4`8=Da<23LdC00<04a<0

21<300@C00<04a<00a<203lC00<04a<0G1<202lC00<04a<0<Q<0038C00<04a<021<53ELC0Pg;4`03

01<C00dC0P064`0301<C03hC00<04a<0GQ<202dC00<04a<0<Q<0038C00<04a<020eN4`8=bA<00`0C

4`0=4`0301<C00DC00<04a<0?Q<00`0C4`1P4`<0:a<00`0C4`0a4`00<Q<33FPC0`g54`0301<C00hC

0`054`0301<C03hC00<04a<0HQ<202XC00<04a<0<A<0038C00<04a<0Ja<23L<C00<04a<05Q<00`0C

4`0m4`0301<C06DC0`0W4`0301<C034C000b4`0301<C06dC0`g04`0301<C01HC00<04a<0?A<00`0C

4`1W4`809Q<00`0C4`0a4`00<Q<00`0C4`1`4`8=_A<00`0C4`0G4`0301<C03dC00<04a<0JA<302<C

00<04a<0<A<0038C00<04a<0LQ<23K/C00<04a<05a<00`0C4`0m4`0301<C06`C00<04a<081<00`0C

4`0a4`00<Q<00`0C4`1d4`8=^A<00`0C4`0G4`0301<C03dC00<04a<0KA<2020C00<04a<0<A<001`C

00<04a<00Q<0100C4a<300<C00<04a<011<00`0C4`1f4`H=/a<00`0C4`0G4`0301<C03dC00<04a<0

Ka<201hC00<04a<0<A<001/C00<04`001a<00`0C4`024`0301<000DC00<04a<0O1<63JdC00<04a<0

5a<00`0C4`0m4`0301<C074C0P0L4`0301<C034C000F4`<00Q<00`0C00084`0301<C00<C00<04a<0

0a<208<C8Pf:4`0301<C01PC00<04a<0?A<00`0C4`1c4`806Q<00`0C4`0a4`006a<00`0C00084`04

01<C4`801Q<00`0C4`2T4`@=QQ<00`0C4`0H4`0301<C03dC00<04a<0M1<201TC00<04a<0<A<001/C

00<04`001a<00`0C00024`0301<C00DC00<04a<0Z1<53H4C00<04a<061<00`0C4`0l4`0301<C07LC

0P0G4`0301<C034C000L4`0301<C00LC00@04a<C0`054`0301<C0:dC10em4`0301<C01PC00<04a<0

?1<00`0C4`1i4`805A<00`0C4`0a4`00<Q<00`0C4`2a4`8=Na<00`0C4`0H4`0301<C03`C00<04a<0

NQ<201<C00<04a<0<Q<0038C00<04a<0/a<33GPC00<04a<061<00`0C4`0l4`0301<C07`C00<04a<0

41<00`0C4`0b4`00<Q<00`0C4`2f4`8=MQ<00`0C4`0H4`0301<C03`C00<04a<0OA<2010C00<04a<0

<Q<0038C00<04a<0^1<23G@C00<04a<061<00`0C4`0P4`D00Q<00`0C4`0B4`0301<C00XC1@000a<0

000Q4`D00Q<00`0C4`0N4`D00Q<00`0C4`0I4`8011<500034`0000<C00<04a<0<Q<0038C00<04a<0

9Q<00`0C4`024`0401<C4`<08a<00`0C4`024`0301<C008C0`0R4`0301<C008C00@04a<C0P0T4`03

01<C008C00H04`d=4`0X4`D0@a<00`0C4`0H4`0301<C028C00L04a<C01<001<C00<04a<031<01`0C

4a<04`008Q<00`0C4`024`0301<C020C00L04a<C01<001`C00<04a<00a<00`0C4`034`0401<C03@C

000b4`0301<C02DC00<04`001a<00`0C4`0R4`0301<000TC00<04a<081<00`0C00074`0301<0028C

00<04`001a<23@0301<C02LC00<04a<0@a<00`0C4`0H4`0301<C028C00<04a<00a<00`0C4`0A4`03

01<C00`C00L04a<C01<0028C00<04a<00Q<00`0C4`0P4`0701<C4`0C000M4`800a<00`0C4`024`80

0Q<00`0C4`0b4`00<Q<00`0C4`0U4`0301<000PC00<04a<08A<00`0C00074`@08A<00`0C00074`03

01<0028C00<04`001a<0100C3@dX4`0301<C04<C00<04a<061<00`0C4`0R4`0401<C4`8051<00`0C

4`0<4`0401<C4`808a<00`0C4`034`0301<C01lC00<04a<00Q<00`0C4`0M4`0501<C4`000a<00`0C

00024`0301<C038C000b4`0301<C02DC00<04`0021<00`0C4`0Q4`0301<000LC00<04`008Q<00`0C

00074`808a<00`0C00084`0301<C008=9Q<00`0C4`124`0301<C01TC00<04a<08Q<01@0C4a<001DC

00<04a<031<01@0C4a<002@C00L04a<C01<0024C00L04a<C01<001lC0P000a<04`024`0501<04`00

=A<0038C00<04a<09A<00`0C00074`0301<0028C00<04`0021<2028C00<04`001a<00`0C4`0R4`03

01<000LC00<04`000a<33B<C00<04a<0@Q<00`0C4`0I4`0301<C024C0P034`<04a<00`0C4`0;4`80

11<2024C0P034`<081<200@C00<04a<081<200@C0P000a<04`0d4`00<Q<00`0C4`0V4`0301<C00LC

00<04a<08Q<00`0C4`084`0301<C024C00<04a<01a<202<C00<04a<01a<00`0C4`054`8=81<204@C

00<04a<06A<00`0C4`0l4`0301<C08HC00<04a<011<00`0C4`0d4`00<Q<00`0C4`374`<=Ha<00`0C

4`0I4`0301<C03`C00<04a<0Qa<00`0C4`034`0301<C03@C000b4`0301<C0<XC0PeQ4`0301<C01TC

00<04a<0?1<00`0C4`274`0301<C008C00<04a<0=A<0038C00<04a<0c1<33EhC00<04a<06A<00`0C

4`0l4`0301<C08PC00@04a<051<4020C000b4`0301<C0<lC10dT4`<0<a<00`0C4`0I4`0301<C03`C

00<04a<0RA<00`0C000D4`<08A<0038C00<04a<0da<53B0C00<04a<0;1?k00/C00<04a<07a<002`C

h@0A3@H02A<00`0C4`0]4`0301<C008C00@04a<01a<00`0C4`054`0301<C00HC00<04a<01A<00`0C

4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`034`0301<000LC

00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C

4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC

00<04a<01A<300DC00<04a<03A<2024C000b4`0301<C00PC00<04a<02A<00`0C4`094`0301<C00TC

00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0C4`084`0301<C00TC00<04a<02A<00`0C

4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0C4`084`0301<C00TC

00<04a<02A<00`0C4`0<4`@0<Q<00`0C4`0I4`0301<C02DC00<04a<051<00`0C4`0?4`0301<C02HC

00<04a<09A<00`0C4`0V4`0301<003PC000b4`0301<C02`C00<04a<0;1<00`0C4`0/4`0301<C02`C

00<04a<0;1<00`0C4`124`0301<C01TC00<04a<0?1<00`0C4`284`0501<C4`00=a<0038C00<04a<0

oa<^4`0301<C01TC00<04a<0?1<00`0C4`274`0301<C008C00<04a<0=A<0038C00<04a<0oa<^4`03

01<C01TC00<04a<0?1<00`0C4`274`0301<C00<C00<04a<0=1<0038C00<04a<0oa<^4`0301<C01TC

00<04a<0?1<00`0C4`254`801Q<00`0C4`0d4`00<Q<00`0C4`3o4bhC00<04a<06A<00`0C4`0l4`03

01<C08@C00<04a<01a<00`0C4`0c4`00<Q<00`0C4`3o4blC00<04a<061<00`0C4`0l4`0301<C08<C

00<04a<021<00`0C4`0c4`00<Q<00`0C4`3o4blC00<04a<061<00`0C4`0l4`0301<C088C00<04a<0

2Q<00`0C4`0b4`00<Q<00`0C4`3o4blC00<04a<061<00`0C4`0l4`0301<C084C00<04a<02a<00`0C

4`0b4`00<Q<00`0C4`3o4blC00<04a<061<00`0C4`0l4`0301<C07lC0P0>4`0301<C038C000b4`03

01<C0?lC;a<00`0C4`0H4`0301<C03`C00<04a<0OQ<00`0C4`0>4`0301<C038C000b4`0301<C0?lC

;a<00`0C4`0H4`0301<C03`C00<04a<0OA<00`0C4`0?4`0301<C038C000b4`0301<C0?lC;a<00`0C

4`0H4`0301<C03`C00<04a<0Na<2018C00<04a<0<Q<0038C00<04a<0oa<_4`0301<C01PC00<04a<0

?1<00`0C4`1j4`0301<C018C00<04a<0<Q<0038C00<04a<0oa<_4`0301<C01PC00<04a<0?1<00`0C

4`1h4`805Q<00`0C4`0a4`00<Q<00`0C4`3o4blC00<04a<061<00`0C4`0l4`0301<C07HC0P0H4`03

01<C034C000b4`0301<C0?lC;a<00`0C4`0H4`0301<C03dC00<04a<0M1<00`0C4`0H4`0301<C034C

000L4`0301<C008C00@04a<C0`034`0301<C00@C00<04a<0oa<_4`0301<C01PC00<04a<0?A<00`0C

4`1b4`806a<00`0C4`0a4`006a<00`0C00074`0301<C008C00<04`001A<00`0C4`3o4c0C00<04a<0

5a<00`0C4`0m4`0301<C070C0P0M4`0301<C034C000K4`0301<000PC00<04a<00a<00`0C4`034`80

oa<a4`0301<C01LC00<04a<0?A<00`0C4`1^4`<07Q<00`0C4`0a4`006a<00`0C00084`0401<C4`80

1Q<00`0C4`3o4c0C00<04a<05a<00`0C4`0m4`0301<C06`C0P0Q4`0301<C034C000K4`0301<000LC

00<04`000Q<00`0C4`054`0301<C0?lC<1<00`0C4`0G4`0301<C03dC00<04a<0Ja<2028C00<04a<0

<A<001`C00<04a<01a<0100C4a<300DC00<04a<0oa<`4`0301<C01LC00<04a<0?A<00`0C4`1X4`<0

91<00`0C4`0a4`00<Q<00`0C4`3o4c4C00<04a<05Q<00`0C4`0m4`0301<C06LC00<04a<09A<00`0C

4`0a4`00<Q<00`0C4`3o4c4C00<04a<05Q<00`0C4`0n4`0301<C06<C0`0X4`0301<C034C000b4`03

01<C0?lC<A<00`0C4`0?4`0301<C00@C00<04a<0?Q<00`0C4`1R4`0301<C02TC00<04a<0<A<0038C

00<04a<0oa<b4`0301<C00dC00<04`001A<00`0C4`0n4`0301<C05lC0`0[4`80<a<0038C00<04a<0

oa<b4`0301<C00lC00<04a<00a<203lC00<04a<0GA<202hC00<04a<0<Q<0038C00<04a<0oa<b4`03

01<C00dC0P064`0301<C03hC00<04a<0Fa<2030C00<04a<0<Q<0038C00<04a<0oa<c4`0301<C00`C

00<04a<01A<00`0C4`0o4`0301<C05PC0P0b4`0301<C038C000b4`0301<C0?lC<a<00`0C4`0<4`<0

1A<00`0C4`0o4`0301<C05DC0`0c4`80=1<0038C00<04a<0oa<d4`0301<C01<C00<04a<0?a<00`0C

4`1C4`80=Q<00`0C4`0c4`00<Q<00`0C4`3o4c@C00<04a<04a<00`0C4`0o4`0301<C050C0`0h4`03

01<C03<C000b4`0301<C0?lC=1<00`0C4`0C4`0301<C040C00<04a<0CA<203XC00<04a<0=1<0038C

00<04a<0oa<e4`0301<C018C00<04a<0@1<00`0C4`1:4`<0?1<00`0C4`0d4`00<Q<00`0C4`3o4cDC

00<04a<04Q<00`0C4`104`0301<C04PC0`0n4`0301<C03@C000Q4`0301<C008C00<04a<00Q<00`0C

4`044`0301<C0?lC=Q<00`0C4`0A4`0301<C044C00<04a<0A1<3040C00<04a<0=A<0020C00<04`00

1a<00`0C00054`0301<C0?lC=Q<00`0C4`0A4`0301<C044C00<04a<0@A<304<C00<04a<0=A<0020C

00<04`002A<00`0C4`034`80oa<h4`0301<C010C00<04a<0@A<00`0C4`0n4`<0AA<00`0C4`0f4`00

81<00`0C00074`801Q<00`0C4`3o4cLC00<04a<041<00`0C4`124`0301<C03/C0P184`0301<C03HC

000P4`0301<000LC00<04a<01A<00`0C4`3o4cPC00<04a<03a<00`0C4`124`0301<C03LC10194`03

01<C03LC000Q4`0301<C00HC0`054`0301<C0?lC>1<00`0C4`0?4`0301<C048C00<04a<0=1<304dC

00<04a<0=a<0038C00<04a<0oa<i4`0301<C00hC00<04a<0@a<00`0C4`0`4`<0Ca<00`0C4`0h4`00

<Q<00`0C4`3o4cXC00<04a<03A<00`0C4`134`0301<C02dC0`1A4`80>Q<0038C00<04a<0oa<k4`03

01<C00`C00<04a<0A1<00`0C4`0X4`@0E1<00`0C4`0i4`00<Q<00`0C4`3o4c`C00<04a<02a<00`0C

4`144`0301<C02DC101F4`80>a<0038C00<04a<0oa<l4`0301<C00/C00<04a<0A1<2028C1@1H4`80

?1<0038C00<04a<0oa<m4`0301<C00XC00<04a<0AA<00`0C4`0M4`@0G1<00`0C4`0k4`00<Q<00`0C

4`3o4chC00<04a<02A<00`0C4`164`0301<C01PC101O4`0301<C03`C000b4`0301<C0?lC?a<00`0C

4`084`0301<C04HC00<04a<051<5064C0P0n4`00<Q<00`0C4`3o4d0C0P084`0301<C04HC0P0A4`D0

I1<203lC000b4`0301<C0?lC@A<00`0C4`064`0301<C04LC00<04a<031<406LC0P104`00<Q<00`0C

4`3o4d8C00<04a<01A<00`0C4`184`0301<C00LC101Z4`80@A<0038C00<04a<0oa=34`801A<00`0C

4`184`0301<C008C1@1]4`80@Q<0038C00<04a<0oa<l4`D00Q<00`0C00044`0301<C04TC1@1`4`80

@a<001`C00<04a<00Q<00`0C4`024`0301<C008C00<04a<011<00`0C4`3o4chC00P04a<C01<04`80

0Q<00`0C4`154`H0LQ<204@C000K4`0301<000PC00L04a<C01<000DC00<04a<0oa<n4`0701<C4`0C

00034`@0@A<500DC0P1_4`<0AA<001/C00<04`0021<00`0C4`034`0301<C00<C0P3o4clC00L04a<C

01<000DC0`0k4`H02Q<206dC0P174`006a<00`0C00094`0301<C00801Q<00`0C4`3o4chC00L04a<C

01<000DC00<04a<00P0d4`D04A<00`0C4`1Z4`80B1<001/C00<04`001a<00`0C00024`0301<C00DC

00<04a<0oa<m4`8011<00`0C4`044`0301<C008C0`0[4`H05a<00`0C4`1W4`80BQ<001`C00<04a<0

1Q<3008C0`054`0301<C0?lCBQ<00`0C4`054`D07Q<801hC0P1U4`80C1<0038C00<04a<0oa=:4`03

01<C00XC2@0;4`/09Q<00`0C4`1Q4`<0CA<0038C00<04a<0oa=:4`0301<C018C300b4`80GQ<3050C

000b4`0301<C0?lCBQ<00`0C4`1A4`80FQ<4058C000b4`0301<C0?lCBQ<00`0C4`1B4`80EA<505DC

000b4`0301<C0?lCBQ<00`0C4`1D4`80Ca<505TC000b4`0301<C0?lCBQ<00`0C4`1E4`<0B1<605dC

000b4`0301<C0?lCBQ<00`0C4`1G4`80@A<7068C000b4`0301<C0?lCBQ<00`0C4`1I4`<0>1<706PC

000b4`0301<C0?lCBQ<00`0C4`1K4`@0;a<706hC000b4`0301<C0?lCBQ<00`0C4`1N4`@09A<807@C

000b4`0301<C0?lCBQ<00`0C4`1R4`H05Q<907`C000b4`0301<C0?lCBQ<00`0C4`1W4aL0QA<0038C

00<04a<0oa=:4`0301<C0?lC11<002TC1@044`0301<C0?lCBQ<00`0C4`3o4`@C000[4`0301<C00@C

00<04a<0oa=:4`0301<C0?lC11<002/C00<04a<011<20?lCBa<00`0C4`3o4`@C000[4`0301<C0?lC

oa=H4`00:a<00`0C4`3o4olCF1<002XC0P3o4olCFQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC001a4`@000<C00001`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C

00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C

4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`3o4j`C001a4`<0

21<00`0C4`024`0301<C00HC00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`03

01<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0Q<00`0C00024`0301<0008C00<04`00Y1<20?lC1a<007<C00<04a<010024`0301<C008C00<04a<0

1Q<00`0C00024`0301<000@C00H04a<04`024`0301<0008C00<04`000Q<00`0C00024`0301<0008C

00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C

002U4`0301<C0?lC1A<001TC10000a<00006008C2P024`800Q<3008C0`034`8000HC00004`0W4`80

21<00`0C4`034`0301<C00DC00<04`000a<0100C4a<200<C00<04`000Q<00`0C00024`0301<0008C

00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C

00024`0301<000<C00<04a<0XQ<3008C00<04a<0oa<24`006Q<01P0C4`0C008C00<04`0011<01P0C

4`0C008C00<04`001A<00`0C4`024`0501<C4`000Q<0100C01<2034C00L04a<C01<000LC00<04`00

0Q<00`0C00024`0301<C008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`03

01<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`00

11<00`0C4`2K4`0801<C01<04`3o4`<C000J4`0601<C01<011<00`0C4`024`0301<C008C00<04a<0

0Q<00`0C4`034`0301<C008C00D04a<C00024`0401<04`80<1<200<C0`084`0301<C008C00@04a<C

0`034`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C

00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<0W1<0200C

4`0C01<0oa<34`006Q<01@0C4`0C00800a<200<C00<04a<00Q<200<C00<04a<00a<00`0C4`024`05

01<C4`000Q<01P0C000C0?lC<A<300044`0C0?lC0a<001XC00H04a<04`024`0301<0008C00<04`00

11<03P0C4`0C01<04`0C01<00Q<01@0C4a<0008C00H04`004`3o4cDC00<04`00oa<34`006A<40003

4`0000/00Q<500054`0001<01@0011<000034`8000@C000C0P3o4cHC00<04a<0oa<24`00oa?o4hHC

003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.61001, -14.5164, 0.0245782, 0.172326}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -57 0 ]

[.5 .63053 57 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -118 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(16.5249999999999914`) show

173.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .22389 m

.02499 .22389 L

.02606 .22388 L

.02729 .22386 L

.02846 .22384 L

.03053 .22379 L

.03279 .22372 L

.03527 .22361 L

.0379 .22347 L

.04262 .22314 L

.04749 .2227 L

.05205 .2222 L

.06245 .22076 L

.08274 .21674 L

.10458 .21089 L

.14581 .19685 L

.18551 .18245 L

.20554 .17603 L

.22371 .17122 L

.23316 .1692 L

.24338 .16745 L

.249 .1667 L

.25418 .16613 L

.25913 .16572 L

.26162 .16555 L

.26435 .16541 L

.26686 .16532 L

.26828 .16528 L

.26959 .16525 L

.27074 .16523 L

.272 .16522 L

.27332 .16522 L

.27456 .16522 L

.27569 .16524 L

.27689 .16526 L

.27792 .16528 L

.27903 .16531 L

.28154 .16541 L

.28386 .16553 L

.28916 .1659 L

.29397 .16637 L

.30478 .16785 L

.31476 .16974 L

.32396 .17189 L

.34476 .17807 L

.38416 .19343 L

.42205 .20985 L

.44313 .21841 L

.46239 .22534 L

.48253 .23136 L

Mistroke

.50121 .23565 L

.51043 .2373 L

.52024 .23872 L

.52584 .23938 L

.53112 .23991 L

.53582 .2403 L

.54097 .24066 L

.54604 .24094 L

.55076 .24114 L

.55575 .24129 L

.55855 .24135 L

.55978 .24137 L

.56109 .24139 L

.56222 .24141 L

.56346 .24142 L

.56459 .24143 L

.56564 .24143 L

.56689 .24144 L

.56803 .24144 L

.56928 .24144 L

.57059 .24144 L

.57167 .24144 L

.57282 .24143 L

.5739 .24142 L

.57488 .24142 L

.57958 .24136 L

.58444 .24128 L

.58958 .24118 L

.5988 .24098 L

.60884 .24077 L

.61173 .24072 L

.61447 .24068 L

.61696 .24065 L

.61833 .24063 L

.61961 .24062 L

.62082 .24061 L

.62193 .2406 L

.62316 .2406 L

.6238 .2406 L

.62449 .24059 L

.6256 .24059 L

.62664 .24059 L

.62778 .2406 L

.629 .2406 L

.63032 .24061 L

.63175 .24062 L

.63311 .24064 L

.63435 .24065 L

.63672 .24069 L

.63922 .24075 L

Mistroke

.64373 .24088 L

.64795 .24105 L

.65257 .24128 L

.65755 .2416 L

.66766 .24245 L

.6787 .24373 L

.68912 .2453 L

.69879 .24706 L

.73794 .25713 L

.77955 .27151 L

.81963 .28599 L

.8582 .29759 L

.87816 .30205 L

.88833 .30385 L

.89923 .30545 L

.90951 .30663 L

.91888 .30747 L

.92339 .30779 L

.9283 .30809 L

.93722 .3085 L

.94185 .30866 L

.9462 .30877 L

.95098 .30887 L

.95366 .30891 L

.95612 .30894 L

.95838 .30896 L

.96079 .30898 L

.96218 .30899 L

.96344 .30899 L

.9659 .309 L

.96722 .30901 L

.96844 .30901 L

.96978 .30901 L

.97045 .30901 L

.97119 .30902 L

.97244 .30902 L

.97314 .30902 L

.97378 .30902 L

.97501 .30902 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 -0.00555 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.54478 .01945 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4olCQQ<00?lCOQ<00`0C4`3o4`DC000Y4`D0oa=@4`0301<C06@C00<=4a<0

WA<002/C00<04a<0oa=@4`80HQ<63IdC000U4`<00a<00`0C4`044`80oa=:4`0301<C060C2@fK4`00

:a<00`0C4`044`0301<C0?lCBA<00`0C4`1P4`T=6@224`00:a<00`0C4`044`0301<C0?lCBA<00`0C

4`1P4`T=61<907XC000Z4`801Q<00`0C4`3o4dTC00<04a<0GQ<00`0=3@093B0C1`1c4`00<Q<00`0C

4`3o4dTC00<04a<0G1<300034`d=00L=:1<706`C000b4`0301<C0?lCBA<205XC0`044`T=;Q<706HC

000b4`0301<C0?lCBA<00`0C4`1H4`801Q<93C@C1P1Q4`00<Q<00`0C4`3o4dTC00<04a<0EQ<200TC

1Pdk4`H0G1<0038C00<04a<0oa=94`0301<C05@C0`0=4`033A<C040C1@1H4`00<Q<00`0C4`3o4dTC

00<04a<0Da<205HC1@1D4`00<Q<00`0C4`3o4dTC00<04a<0DQ<205/C101A4`00<Q<00`0C4`3o4dTC

0P0C4a00;a<205lC0`1?4`00<Q<00`0C4`3o4dTC00<04a<02a<700lC2P0T4`80Ha<404`C000b4`03

01<C0?lCBA<00`0C4`064`D081<701dC00<04a<0IA<204/C000b4`0301<C0?lCBA<00`0C4`034`<0

:a<701HC00<04a<0J1<204TC000b4`0301<C0?lC?1<5008C00<04a<00a<0100C4a<203@C1P0@4`03

01<C06XC0P184`00<Q<00`0C4`3o4chC00L04a<C01<000@C100k4`H02Q<00`0C4`1]4`80AQ<001`C

00<04a<00Q<00`0C4`024`0301<C008C00<04a<011<00`0C4`3o4cPC0`034`0701<C4`0C00034`@0

@A<600@C00<04a<0Ka<204DC000K4`0301<000PC00L04a<C01<000DC00<04a<0oa<n4`0701<C4`0C

00024`0301<004PC1P1c4`0301<C048C000F4`<00Q<00`0C00084`0301<C00<C00<04a<00a<20?lC

?a<01P0C4a<04`<00Q<00`0C4`1:4`D0LA<2048C000K4`0301<000TC00<04a<00P064`0301<C0?lC

?A<200@C0P044`0301<C04TC00<04a<00a<506dC0P114`006a<00`0C00074`0301<0008C00<04a<0

1A<00`0C4`3o4d8C00<04a<011<00`0C4`194`0301<C00LC1@1Z4`80@1<001`C00<04a<01Q<3008C

0`054`0301<C0?lC@A<00`0C4`054`80BA<00`0C4`0<4`@0J1<00`0C4`0n4`00<Q<00`0C4`3o4d0C

00<04a<01Q<00`0C4`174`804Q<406DC00<04a<0?A<0038C00<04a<0oa<n4`802A<00`0C4`174`03

01<C01DC101Q4`80?Q<0038C00<04a<0oa<m4`0301<C00TC00<04a<0AQ<00`0C4`0I4`D0GQ<203dC

000b4`0301<C0?lC?A<00`0C4`094`0301<C04HC00<04a<07A<405`C0P0l4`00<Q<00`0C4`3o4c`C

00<04a<02Q<00`0C4`154`0301<C028C101I4`0301<C03XC000b4`0301<C0?lC>a<00`0C4`0;4`80

AQ<00`0C4`0U4`@0Ea<00`0C4`0i4`00<Q<00`0C4`3o4cXC00<04a<031<00`0C4`144`0301<C02XC

101C4`80>Q<0038C00<04a<0oa<j4`0301<C00`C00<04a<0A1<00`0C4`0]4`@0DA<00`0C4`0h4`00

<Q<00`0C4`3o4cTC00<04a<03A<00`0C4`144`0301<C030C101?4`0301<C03LC000b4`0301<C0?lC

>1<00`0C4`0>4`0301<C04<C00<04a<0=A<304`C0P0h4`00<Q<00`0C4`3o4cLC00<04a<03a<00`0C

4`134`0301<C03LC101:4`0301<C03HC000b4`0301<C0?lC=a<00`0C4`0?4`80@a<00`0C4`0l4`<0

Aa<203LC000b4`0301<C0?lC=Q<00`0C4`0@4`0301<C048C00<04a<0?a<304DC00<04a<0=A<0024C

00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0oa<f4`0301<C010C00<04a<0@Q<00`0C4`114`<0

@a<203HC000P4`0301<000LC00<04`001A<00`0C4`3o4cDC00<04a<04A<00`0C4`124`0301<C04@C

0`114`0301<C03@C000K4`<00Q<00`0C00094`0301<C00<C0P3o4cHC00<04a<04A<00`0C4`114`03

01<C04PC0`0n4`0301<C03@C000P4`0301<000LC0P064`0301<C0?lC=1<00`0C4`0B4`0301<C044C

00<04a<0Ba<203dC00<04a<0<a<0020C00<04`001a<00`0C4`054`0301<C0?lC=1<00`0C4`0B4`80

@Q<00`0C4`1=4`<0>Q<00`0C4`0c4`008A<00`0C4`064`<01A<00`0C4`0b4`l=lA<00`0C4`0C4`03

01<C040C00<04a<0DA<203PC00<04a<0<a<0038C00<04a<0;A<53@lC1@g/4`0301<C01<C00<04a<0

@1<00`0C4`1C4`<0=Q<00`0C4`0b4`00<Q<00`0C4`0[4`8=6A<43NLC00<04a<051<00`0C4`104`03

01<C05DC0`0d4`0301<C038C000b4`0301<C02PC0`dO4`@=ha<00`0C4`0>4`0301<C00<C00<04a<0

@1<00`0C4`1H4`<0<A<203<C000b4`0301<C02@C10dV4`8=h1<00`0C4`0>4`0301<000@C00<04a<0

?a<00`0C4`1K4`80<A<00`0C4`0a4`00<Q<00`0C4`0R4`8=;1<33MdC00<04a<02A<300@C00<04a<0

0Q<303lC00<04a<0GA<302hC00<04a<0<A<0038C00<04a<07a<33C4C0PgK4`0301<C00hC0P054`03

01<C03lC00<04a<0Ga<302`C00<04a<0<A<0038C00<04a<07A<23CHC0`gH4`0301<C00hC00<04a<0

11<00`0C4`0o4`0301<C068C0P0Z4`0301<C034C000b4`0301<C01XC0`dk4`8=eA<00`0C4`0?4`<0

11<00`0C4`0o4`0301<C06@C0P0X4`80<Q<0038C00<04a<05Q<43D0C0PgC4`0301<C01HC00<04a<0

?Q<00`0C4`1W4`809a<00`0C4`0`4`00<Q<00`0C4`0B4`@=AQ<23M4C00<04a<05Q<00`0C4`0n4`03

01<C06TC0P0U4`0301<C030C000b4`0301<C00lC0`e<4`<=cQ<00`0C4`0F4`80?a<00`0C4`1[4`80

8a<00`0C4`0`4`00<Q<00`0C4`0=4`8=DQ<23L`C00<04a<05Q<00`0C4`0n4`0301<C06dC0P0Q4`03

01<C030C000b4`0301<C00TC10eF4`<=b1<00`0C4`0G4`0301<C03hC00<04a<0KQ<301lC00<04a<0

<1<001`C00<04a<00Q<0100C4a<300<C00<04a<011<<3EdC0Pg64`0301<C01LC00<04a<0?A<00`0C

4`1b4`807A<00`0C4`0`4`006a<00`0C00074`0301<C008C00<04`001A<00`0C4`1X4`@=`Q<00`0C

4`0G4`0301<C03dC00<04a<0La<201`C00<04a<0<1<001HC0`024`0301<000PC00<04a<00a<00`0C

4`034`80KA<53KdC00<04a<05a<203hC00<04a<0MA<201XC00<04a<0<1<001/C00<04`0021<0100C

4a<200HC00<04a<0LA<33KTC00<04a<061<00`0C4`0m4`0301<C07LC0P0G4`0301<C034C000K4`03

01<000LC00<04`000Q<00`0C4`054`0301<C07@C20fa4`0301<C01PC00<04a<0?A<00`0C4`1h4`80

5Q<00`0C4`0a4`0071<00`0C4`074`0401<C4`<01A<00`0C4`1l4b@=SA<00`0C4`0H4`0301<C03dC

00<04a<0NQ<201@C00<04a<0<A<0038C00<04a<0X1<53HPC00<04a<061<00`0C4`0m4`0301<C07`C

00<04a<04A<00`0C4`0a4`00<Q<00`0C4`2U4`<=QA<00`0C4`0H4`0301<C03dC00<04a<0OA<00`0C

4`0@4`0301<C034C000b4`0301<C0:PC10f14`0301<C01PC0P0n4`0301<C07hC0P0@4`0301<C034C

000b4`0301<C0:`C0`en4`0301<C01PC00<04a<08A<5008C00<04a<04Q<00`0C4`0:4`D000<C0000

8A<5008C00<04a<07a<5008C00<04a<06Q<200<C1@000a<000024`0301<C038C000b4`0301<C02HC

00<04a<00Q<0100C4a<302<C00<04a<00Q<00`0C4`024`<08Q<00`0C4`024`0401<C4`8081<33@03

4`0C00<C00<04a<00Q<00`0C4`0V4`D0@Q<00`0C4`0H4`0301<C02<C00L04a<C01<001<C00<04a<0

31<01`0C4a<04`008Q<00`0C4`024`0301<C024C00L04a<C01<001`C00<04a<00a<00`0C4`034`03

01<003@C000b4`0301<C02DC00<04`001a<00`0C4`0R4`0301<000TC00<04a<081<00`0C00074`03

01<0028C10d64`0301<002TC00<04a<0@Q<00`0C4`0H4`0301<C02<C00<04a<00a<00`0C4`0A4`03

01<C00`C00L04a<C01<0028C00<04a<00Q<00`0C4`0Q4`0701<C4`0C000M4`800a<00`0C4`024`80

00<C01<0<a<0038C00<04a<09A<00`0C00084`0301<C024C00<04`001a<4024C00<04`001a<00`0C

000R4`0401<04`<=0a<00`0C000Y4`0301<C048C00<04a<061<00`0C4`0S4`0401<C4`8051<00`0C

4`0<4`0401<C4`808a<00`0C4`034`0301<C020C00<04a<00Q<00`0C4`0N4`0401<C00<C00D04`0C

000d4`00<Q<00`0C4`0U4`0301<000PC00<04a<08A<00`0C00074`0301<0028C00<04`001a<202<C

00<04`0011<23@8C00<04a<0:1<00`0C4`114`0301<C01TC00<04a<08a<01@0C4a<001DC00<04a<0

31<01@0C4a<002@C00L04a<C01<0028C00L04a<C01<0020C00<04`000a<0100C000e4`00<Q<00`0C

4`0U4`0301<000LC00<04`008Q<00`0C00084`808Q<00`0C00074`0301<C028C00<04`001Q<33@03

01<C02LC00<04a<0@A<00`0C4`0I4`808a<200<C0`0C4`0301<C00/C0P044`808A<200<C0`0Q4`80

11<00`0C4`0O4`<011<303DC000b4`0301<C02HC00<04a<01a<00`0C4`0R4`0301<C00PC00<04a<0

8A<00`0C4`074`808a<00`0C4`074`0300d=02LC0P134`0301<C01TC00<04a<0?A<00`0C4`264`80

1Q<00`0C4`0c4`00<Q<00`0C4`304`<=JA<00`0C4`0I4`0301<C03dC00<04a<0R1<00`0C4`024`03

01<C03@C000b4`0301<C0<<C0`eV4`0301<C01TC00<04a<0?A<00`0C4`294`0501<C4`00=Q<0038C

00<04a<0aQ<43F8C00<04a<06A<00`0C4`0m4`0301<C08XC00<04`004a<4020C000b4`0301<C0<XC

10dY4`<0<Q<00`0C4`0I4`0301<C03dC00<04a<0RQ<201@C0`0Q4`00<Q<00`0C4`3>4`H=91<00`0C

4`0[4od02Q<00`0C4`0O4`00;1?M01D=1P094`0301<C02`C00<04a<00Q<01@0C4a<000LC00<04a<0

1A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`03

01<C00DC00<04a<011<200PC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`03

01<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<0

1A<00`0C4`054`0301<C00DC00<04a<01Q<200HC00<04a<031<2024C000b4`0301<C00PC00<04a<0

2A<00`0C4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0C4`084`03

01<C00TC00<04a<02A<00`0C4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC00<04a<0

2A<00`0C4`084`0301<C00TC00<04a<02A<00`0C4`0<4`@0<A<00`0C4`0I4`0301<C03dC00<04a<0

RQ<00`0C000g4`00<Q<00`0C4`0/4`0301<C02`C00<04a<0;1<00`0C4`0/4`0301<C02`C00<04a<0

@A<00`0C4`0I4`0301<C03dC00<04a<0R1<200<C00<04a<0=1<0038C00<04a<0oa<]4`0301<C01TC

00<04a<0?A<00`0C4`274`0301<C00@C00<04a<0<a<0038C00<04a<0oa<]4`0301<C01TC00<04a<0

?A<00`0C4`264`0301<C00DC00<04a<0<a<0038C00<04a<0oa<]4`0301<C01TC0P0n4`0301<C08DC

00<04a<01Q<00`0C4`0c4`00<Q<00`0C4`3o4bdC00<04a<06A<00`0C4`0m4`0301<C08DC00<04a<0

1Q<00`0C4`0c4`00<Q<00`0C4`3o4bhC00<04a<061<00`0C4`0m4`0301<C08<C0P0:4`0301<C038C

000b4`0301<C0?lC;Q<00`0C4`0H4`0301<C03dC00<04a<0PQ<00`0C4`0:4`0301<C038C000b4`03

01<C0?lC;Q<00`0C4`0H4`0301<C03dC00<04a<0PA<00`0C4`0;4`0301<C038C000b4`0301<C0?lC

;Q<00`0C4`0H4`0301<C03dC00<04a<0Oa<200hC00<04a<0<Q<0038C00<04a<0oa<^4`0301<C01PC

0P0n4`0301<C07hC00<04a<03a<00`0C4`0a4`00<Q<00`0C4`3o4bhC00<04a<061<00`0C4`0m4`03

01<C07`C0P0B4`0301<C034C000b4`0301<C0?lC;Q<00`0C4`0H4`0301<C03dC00<04a<0Na<201<C

00<04a<0<A<0038C00<04a<0oa<^4`0301<C01PC00<04a<0?A<00`0C4`1i4`805A<00`0C4`0a4`00

<Q<00`0C4`3o4bhC00<04a<061<00`0C4`0m4`0301<C07PC00<04a<05A<00`0C4`0a4`00<Q<00`0C

4`3o4blC00<04a<05a<203hC00<04a<0MQ<201PC00<04a<0<A<0038C00<04a<0oa<_4`0301<C01LC

00<04a<0?A<00`0C4`1d4`806a<00`0C4`0`4`0071<00`0C4`024`0401<C4`<00a<00`0C4`044`03

01<C0?lC;a<00`0C4`0G4`0301<C03dC00<04a<0La<00`0C4`0K4`0301<C030C000K4`0301<000LC

00<04a<00Q<00`0C00054`0301<C0?lC;a<00`0C4`0G4`0301<C03dC00<04a<0LA<201hC00<04a<0

<1<001/C00<04`0021<00`0C4`034`0301<C00<C0P3o4c4C00<04a<05Q<00`0C4`0n4`0301<C06hC

0P0P4`0301<C030C000K4`0301<000PC00@04a<C0P064`0301<C0?lC<1<00`0C4`0F4`0301<C03hC

00<04a<0K1<3024C00<04a<0<1<001/C00<04`001a<00`0C00024`0301<C00DC00<04a<0oa<`4`03

01<C01HC0P0o4`0301<C06XC0P0T4`0301<C030C000L4`0301<C00LC00@04a<C0`054`0301<C0?lC

<1<00`0C4`0F4`0301<C03hC00<04a<0JA<00`0C4`0T4`0301<C030C000b4`0301<C0?lC<1<00`0C

4`0F4`0301<C03hC00<04a<0IQ<302LC00<04a<0<1<0038C00<04a<0oa<a4`0301<C01DC00<04a<0

?a<00`0C4`1T4`0301<C02LC0P0b4`00<Q<00`0C4`3o4c4C00<04a<03a<00`0C4`034`0301<C03lC

00<04a<0HA<302XC00<04a<0<A<0038C00<04a<0oa<a4`0301<C00hC00<04`0011<00`0C4`0o4`03

01<C05lC0P0]4`0301<C034C000b4`0301<C0?lC<A<00`0C4`0@4`0301<C008C0`0o4`0301<C05dC

0P0_4`0301<C034C000b4`0301<C0?lC<Q<00`0C4`0=4`801A<00`0C4`104`0301<C05XC0P0`4`80

<a<0038C00<04a<0oa<b4`0301<C00dC00<04a<011<00`0C4`104`0301<C05LC0`0b4`0301<C038C

000b4`0301<C0?lC<a<00`0C4`0<4`<011<00`0C4`104`0301<C05DC0P0e4`0301<C038C000b4`03

01<C0?lC<a<00`0C4`0C4`0301<C040C00<04a<0DQ<303LC00<04a<0<Q<0038C00<04a<0oa<d4`03

01<C018C00<04a<0@1<00`0C4`1@4`80>A<00`0C4`0c4`00<Q<00`0C4`3o4c@C00<04a<04Q<2048C

00<04a<0C1<303/C00<04a<0<a<0038C00<04a<0oa<e4`0301<C014C00<04a<0@A<00`0C4`1:4`80

?A<203DC000b4`0301<C0?lC=A<00`0C4`0A4`0301<C044C00<04a<0Aa<303lC00<04a<0=1<0024C

00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0oa<e4`0301<C014C00<04a<0@Q<00`0C4`144`<0

@A<00`0C4`0d4`0081<00`0C00074`0301<000DC00<04a<0oa<f4`0301<C010C00<04a<0@Q<00`0C

4`114`<0@a<00`0C4`0e4`0081<00`0C00094`0301<C00<C0P3o4cLC00<04a<041<00`0C4`124`03

01<C03hC0`164`0301<C03DC000P4`0301<000LC0P064`0301<C0?lC=a<00`0C4`0?4`80A1<00`0C

4`0j4`<0B1<00`0C4`0f4`0081<00`0C00074`0301<C00DC00<04a<0oa<h4`0301<C00hC00<04a<0

@a<00`0C4`0g4`<0Ba<00`0C4`0f4`008A<00`0C4`064`<01A<00`0C4`3o4cTC00<04a<03A<00`0C

4`134`0301<C03@C0`1=4`0301<C03LC000b4`0301<C0?lC>A<00`0C4`0=4`0301<C04@C00<04a<0

<1<304lC0P0i4`00<Q<00`0C4`3o4cXC00<04a<031<00`0C4`144`0301<C02`C101B4`0301<C03PC

000b4`0301<C0?lC>Q<00`0C4`0<4`0301<C04@C00<04a<0:A<405@C0P0j4`00<Q<00`0C4`3o4c/C

00<04a<02a<204HC00<04a<091<405PC00<04a<0>A<0038C00<04a<0oa<l4`0301<C00XC00<04a<0

AQ<00`0C4`0P4`@0FQ<00`0C4`0j4`00<Q<00`0C4`3o4cdC00<04a<02A<00`0C4`164`0301<C01`C

101M4`0301<C03/C000b4`0301<C0?lC?Q<00`0C4`084`0301<C04HC00<04a<061<505lC0P0m4`00

<Q<00`0C4`3o4clC00<04a<01a<00`0C4`174`0301<C01@C101R4`80?Q<0038C00<04a<0oa=04`03

01<C00HC0P194`0301<C00lC101U4`80?a<0038C00<04a<0oa=14`801Q<00`0C4`184`0301<C00/C

101X4`80@1<0038C00<04a<0oa=24`0301<C00@C00<04a<0BA<00`0C4`064`@0Ja<2044C000b4`03

01<C0?lC@a<00`0C4`034`0301<C04TC0P034`@0KQ<2048C000b4`0301<C0?lC?1<5008C0`034`03

01<C04TC1@1a4`80@a<001`C00<04a<00Q<00`0C4`024`0301<C008C00<04a<011<00`0C4`3o4chC

00P04a<C01<04`8000<C01<0AQ<500034`0C074C0P144`006a<00`0C00084`0701<C4`0C00054`03

01<C0?lC?Q<01`0C4a<04`000a<4040C1@064`80L1<204DC000K4`0301<000PC00<04a<00a<00`0C

4`034`80oa<o4`0701<C4`0C00044`0401<003XC1P0;4`80KA<204LC000K4`0301<000TC00<04a<0

0P064`0301<C0?lC?Q<01`0C4a<04`0011<0100C4a<3038C1P0A4`0301<C06XC0P184`006a<00`0C

00074`0301<0008C00<04a<01A<00`0C4`3o4cdC0P044`0301<C00<C00<04a<011<302TC1P0H4`03

01<C06LC0`194`0071<00`0C4`064`<00Q<300DC00<04a<0oa=94`0301<C00LC0`0N4`P07a<00`0C

4`1T4`<0Ba<0038C00<04a<0oa=94`0301<C00XC30064`d09a<2068C0`1=4`00<Q<00`0C4`3o4dTC

0P0F4`L0=A<205hC101?4`00<Q<00`0C4`3o4dTC00<04a<0DQ<205XC101B4`00<Q<00`0C4`3o4dTC

00<04a<0E1<00`0C4`1C4`D0EA<0038C00<04a<0oa=94`0301<C05DC0P1?4`D0FA<0038C00<04a<0

oa=94`0301<C05HC0`184`H0GA<0038C00<04a<0oa=94`0301<C05PC0`104`L0HQ<0038C00<04a<0

oa=94`80Fa<303PC1`1X4`00<Q<00`0C4`3o4dTC00<04a<0G1<402lC1`1^4`00<Q<00`0C4`3o4dTC

00<04a<0Ga<402DC1`1e4`00<Q<00`0C4`3o4dTC00<04a<0Ha<601DC2P1l4`00<Q<00`0C4`3o4dTC

00<04a<0JA<F08DC000b4`0301<C0?lCBA<00`0C4`3o4`DC000Y4`D011<00`0C4`3o4dTC0P3o4`HC

000[4`0301<C00@C00<04a<0oa=94`0301<C0?lC1A<002/C00<04a<011<20?lCBQ<00`0C4`3o4`DC

000[4`0301<C0?lCoa=H4`00:a<00`0C4`3o4olCF1<002XC0P3o4olCFQ<00?lCoa>64`00oa?o4hHC

003o4olCQQ<00?lCoa>64`00oa?o4hHC001a4`@000<C00001`000a<000044`0301<C008C00@04a<C

0`034`<000<C00000a<200<C0P034`800a<200<C0P034`800a<200<C0P034`800a<2008C1@024`<0

oa>/4`00LA<300PC00L04a<C01<000LC00<04`000Q<00`0C4`044`0301<C008C00<04a<00Q<00`0C

4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C

00<04a<00Q<01@0C4a<000DC00<04a<0XA<20?lC21<007<C00<04a<010024`0701<C4`0C00094`05

01<C4`000a<4008C0P034`800a<200<C0P034`800a<200<C0P034`800a<200<C0P034`800a<0100C

4a<40:<C00<04a<0oa<64`006A<400034`0000H00Q<:008C0P024`<00Q<300<C0P001Q<0000C02LC

0P084`0401<C4`8021<200@C00L04a<C01<0008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00034`07

01<C4`0C002R4`<00Q<00`0C4`3o4`<C000J4`0601<C01<00Q<00`0C00044`0601<C01<00Q<00`0C

00054`0301<C008C00D04a<C00024`0401<04`80<A<01@0C4a<000TC00<04a<00Q<00`0C00034`80

0Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`03

01<0008C00<04`000Q<00`0C00024`0301<000<C00<04a<00Q<200@C00<04a<0VQ<0200C4`0C01<0

oa<44`006Q<01P0C4`0C00@C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00a<00`0C4`024`05

01<C4`000Q<0100C01<2030C0P044`801a<300<C00<04a<00a<0100C4a<200<C0P034`800a<200<C

0P034`800a<200<C0P034`800a<200<C0P024`801A<01@0C4a<009dC00P04a<04`0C0?lC11<001XC

00D04a<04`0200<C0P034`0301<C008C0P034`0301<C00<C00<04a<00Q<01@0C4a<0008C00H04`00

4`3o4c0C0`0011<04`3o4`@C000J4`0601<C01<00Q<00`0C00024`0301<000@C00h04a<04`0C01<0

4`0C008C00D04a<C00024`0601<001<0oa<d4`0301<00?lC11<001TC10000a<0000;008C1@001A<0

000C00D000@C00000a<200044`004`80oa<e4`0301<C0?lC0a<00?lCoa>64`00oa?o4hHC003o4olC

QQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00001\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.6711, -14.3654, 0.02445, 0.171427}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -57 0 ]

[.5 .63053 57 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -118 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(15.9649999999999891`) show

173.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .25938 m

.02499 .25938 L

.02606 .25937 L

.02729 .25936 L

.02846 .25934 L

.03053 .2593 L

.03279 .25924 L

.03527 .25915 L

.0379 .25903 L

.04262 .25876 L

.05205 .25799 L

.06245 .25681 L

.07293 .25527 L

.0842 .25327 L

.10458 .24888 L

.14581 .23815 L

.18551 .22798 L

.20554 .22386 L

.21427 .22239 L

.22371 .22107 L

.22898 .22046 L

.23384 .21998 L

.23877 .21957 L

.24338 .21928 L

.24824 .21905 L

.25082 .21896 L

.25225 .21892 L

.25358 .2189 L

.25496 .21887 L

.2557 .21887 L

.25647 .21886 L

.25778 .21885 L

.25852 .21885 L

.25921 .21885 L

.2605 .21886 L

.26169 .21887 L

.26298 .21889 L

.26435 .21891 L

.26692 .21898 L

.26935 .21907 L

.2739 .21929 L

.27879 .21961 L

.28409 .22006 L

.29365 .22111 L

.30246 .22235 L

.32122 .22576 L

.34186 .23049 L

.3822 .24136 L

.42103 .25157 L

.44078 .25592 L

Mistroke

.4623 .2597 L

.4723 .26107 L

.48294 .26226 L

.49297 .26313 L

.50206 .26371 L

.50695 .26395 L

.51211 .26415 L

.51652 .26428 L

.519 .26434 L

.52135 .26438 L

.52266 .2644 L

.52407 .26442 L

.52526 .26443 L

.52656 .26444 L

.52796 .26445 L

.52873 .26446 L

.52945 .26446 L

.53074 .26446 L

.53147 .26446 L

.53213 .26446 L

.53334 .26446 L

.53447 .26446 L

.53571 .26446 L

.53703 .26445 L

.53973 .26442 L

.54218 .2644 L

.54705 .26432 L

.55219 .26422 L

.56141 .264 L

.57145 .26373 L

.58222 .26343 L

.58748 .26331 L

.59247 .2632 L

.59733 .26312 L

.59947 .26309 L

.60183 .26306 L

.60402 .26304 L

.60608 .26303 L

.60722 .26302 L

.60826 .26302 L

.6094 .26302 L

.6106 .26302 L

.61175 .26302 L

.61297 .26302 L

.61412 .26303 L

.61516 .26303 L

.6164 .26304 L

.61773 .26306 L

.62016 .26309 L

.62251 .26313 L

Mistroke

.62504 .26318 L

.62961 .2633 L

.63504 .2635 L

.64001 .26373 L

.65079 .2644 L

.66104 .26527 L

.68086 .26761 L

.69926 .27053 L

.73841 .27871 L

.78001 .28886 L

.82009 .29792 L

.83849 .30134 L

.85866 .30436 L

.87862 .30655 L

.88952 .30742 L

.89969 .30804 L

.9047 .30829 L

.91015 .3085 L

.91495 .30866 L

.92006 .3088 L

.92464 .30889 L

.92708 .30893 L

.9297 .30897 L

.9321 .309 L

.9343 .30902 L

.93652 .30903 L

.93862 .30905 L

.93975 .30905 L

.94097 .30906 L

.94199 .30906 L

.94311 .30906 L

.94433 .30907 L

.94561 .30907 L

.9468 .30907 L

.94792 .30907 L

.94904 .30907 L

.9501 .30907 L

.95105 .30907 L

.95209 .30907 L

.95441 .30906 L

.95657 .30906 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.45392 .06974 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4gdC00<04a<0oa<64`00oa=m4`0301<C0?lC1Q<002TC1@3o4dlC0P3o4`LC

000[4`0301<C0?lCCa<00`0C4`1^4`d0RQ<002DC0`034`0301<C00@C0P3o4dTC00<04a<0IQ<800`C

3@1n4`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`1Q4`D081<807LC000[4`0301<C00@C00<04a<0

oa=84`0301<C05hC100/4`L0L1<002XC0P064`0301<C0?lCB1<00`0C4`1L4`<0=A<706XC000b4`03

01<C0?lCB1<205/C0P0o4`H0I1<0038C00<04a<0oa=84`0301<C05PC0P164`H0Ga<0038C00<04a<0

oa=84`0301<C05HC0P1>4`D0FQ<0038C00<04a<0oa=84`0301<C05DC0P1C4`D0EQ<0038C00<04a<0

oa=84`0301<C05@C00<04a<0Ea<5058C000b4`0301<C0?lCB1<204hC00<=4a<00Q<205hC0`1@4`00

<Q<00`0C4`3o4dPC00<04a<03a<F02DC1Pd00a<0001Q4`@0CA<0038C00<04a<0oa=84`0301<C00XC

1@0F4`T06a<93FDC0`1;4`00<Q<00`0C4`3o4dPC00<04a<01A<502<C1`0E4`T=Ia<304TC000b4`03

01<C0?lC>a<5008C00<04a<00a<00`0C4`034`80;a<600lC2@eY4`80B1<0038C00<04a<0oa<m4`07

01<C4`0C00044`0301<C00<0=Q<600TC2`eY4`<0AQ<0038C00<04a<0oa<g4`<00a<01`0C4a<04`00

11<303hC1P054`T=K1<204DC000b4`0301<C0?lC?A<01`0C4a<04`000a<204DC1@000a<=3@073FdC

0P144`0071<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`044`0301<C0?lC?A<01`0C4a<04`00

0Q<00`0C001:4`0300d=00L=Ka<2048C000K4`0301<000PC00L04a<C01<000DC00<04a<0oa<l4`80

11<0100C00024`0301<C04XC1Pd00`0C4`1_4`80@A<001HC0`024`0301<000PC00<04a<00a<00`0C

4`034`80oa=34`8011<00`0C4`1:4`0401<C3@<C101^4`80@1<001/C00<04`002A<00`0C4`0200HC

00<04a<0oa=14`0301<C00@C00<04a<0BA<00`0C4`094`@0Ja<00`0C4`0n4`006a<00`0C00074`03

01<0008C00<04a<01A<00`0C4`3o4d0C00<04a<01A<204XC00<04a<03A<406PC0P0n4`0071<00`0C

4`064`<00Q<300DC00<04a<0oa<o4`0301<C00HC00<04a<0B1<00`0C4`0B4`@0IA<00`0C4`0l4`00

<Q<00`0C4`3o4chC00<04a<01a<00`0C4`184`0301<C01DC1@1R4`0301<C03/C000b4`0301<C0?lC

?A<00`0C4`084`0301<C04LC00<04a<06Q<405lC0P0l4`00<Q<00`0C4`3o4c`C00<04a<02A<00`0C

4`164`0301<C01lC101L4`80>a<0038C00<04a<0oa<k4`0301<C00XC00<04a<0AQ<00`0C4`0R4`D0

FA<00`0C4`0i4`00<Q<00`0C4`3o4cXC00<04a<02a<204LC00<04a<09Q<405LC00<04a<0>1<0038C

00<04a<0oa<i4`0301<C00`C00<04a<0AA<00`0C4`0Z4`@0E1<203TC000b4`0301<C0?lC>A<00`0C

4`0<4`0301<C04DC00<04a<0;Q<4054C00<04a<0=a<0038C00<04a<0oa<h4`0301<C00dC00<04a<0

A1<00`0C4`0c4`80Ca<203PC000b4`0301<C0?lC=a<00`0C4`0>4`0301<C04@C00<04a<0=A<404`C

0P0g4`00<Q<00`0C4`3o4cHC00<04a<03a<00`0C4`144`0301<C03TC0P1;4`0301<C03DC000b4`03

01<C0?lC=Q<00`0C4`0?4`80A1<00`0C4`0l4`@0Aa<203HC000b4`0301<C0?lC=A<00`0C4`0@4`03

01<C04<C00<04a<0?a<304HC00<04a<0=1<0038C00<04a<0oa<e4`0301<C010C00<04a<0@a<00`0C

4`124`<0@a<203DC000Q4`0301<C008C00<04a<00Q<00`0C4`044`0301<C0?lC=1<00`0C4`0A4`03

01<C048C00<04a<0AQ<3044C00<04a<0<a<0020C00<04`001a<00`0C00054`0301<C0?lC=1<00`0C

4`0A4`0301<C048C00<04a<0BA<203lC00<04a<0<a<001/C0`024`0301<000TC00<04a<00a<20?lC

=1<00`0C4`0B4`0301<C048C00<04a<0Ba<303dC00<04a<0<Q<0020C00<04`001a<200HC00<04a<0

oa<c4`0301<C018C0P134`0301<C04hC0P0k4`0301<C038C000P4`0301<000LC00<04a<01A<00`0C

4`3o4c8C00<04a<04a<00`0C4`114`0301<C054C0`0h4`0301<C038C000Q4`0301<C00HC0`054`03

01<C0?lC<Q<00`0C4`0C4`0301<C044C00<04a<0E1<203LC00<04a<0<A<0038C00<04a<0oa<a4`03

01<C01@C00<04a<0@A<00`0C4`1F4`<0=1<00`0C4`0a4`00<Q<00`0C4`3o4c4C00<04a<03Q<00`0C

4`034`0301<C040C00<04a<0FA<3038C0P0b4`00<Q<00`0C4`3o4c0C00<04a<03Q<00`0C00044`03

01<C040C00<04a<0G1<2034C00<04a<0<1<0038C00<04a<0oa<`4`0301<C00TC0`044`0301<C008C

0`104`0301<C05hC0P0_4`0301<C030C000b4`0301<C0?lC<1<00`0C4`0>4`801A<00`0C4`0o4`03

01<C064C0`0/4`0301<C030C000b4`0301<C0?lC<1<00`0C4`0>4`0301<C00@C00<04a<0?a<00`0C

4`1T4`0301<C02TC00<04a<0<1<0038C00<04a<0oa<_4`0301<C00lC0`044`0301<C03lC00<04a<0

IA<302PC0P0a4`00<Q<00`0C4`3o4blC00<04a<05Q<00`0C4`0o4`0301<C06PC00<04a<09Q<00`0C

4`0_4`00<Q<00`0C4`3o4blC00<04a<05Q<00`0C4`0o4`0301<C06TC0`0U4`0301<C02lC000b4`03

01<C0?lC;a<00`0C4`0F4`80@1<00`0C4`1/4`808a<00`0C4`0_4`00<Q<00`0C4`3o4blC00<04a<0

5Q<00`0C4`0o4`0301<C06dC0P0R4`0301<C02lC000b4`0301<C0?lC;a<00`0C4`0F4`0301<C03lC

00<04a<0Ka<2020C00<04a<0;a<0038C00<04a<0<1<>3NlC00<04a<05a<00`0C4`0n4`0301<C078C

0P0N4`0301<C02lC000L4`0301<C008C00@04a<C0`034`0301<C00@C00<04a<0:1<83@hC1PgY4`03

01<C01LC00<04a<0?Q<00`0C4`1d4`8071<00`0C4`0_4`006a<00`0C00074`0301<C008C00<04`00

1A<00`0C4`0T4`@=71<53N@C00<04a<05a<203lC00<04a<0MQ<201XC00<04a<0;a<001HC0`024`03

01<000PC00<04a<00a<00`0C4`034`808Q<33BDC10gP4`0301<C01LC00<04a<0?Q<00`0C4`1h4`03

01<C01HC00<04a<0<1<001/C00<04`0021<0100C4a<200HC00<04a<07A<43B`C0`gL4`0301<C01PC

00<04a<0?Q<00`0C4`1i4`805Q<00`0C4`0`4`006a<00`0C00074`0301<0008C00<04a<01A<00`0C

4`0J4`<=<a<43MPC00<04a<061<00`0C4`0n4`0301<C07/C00<04a<04a<00`0C4`0`4`0071<00`0C

4`074`0401<C4`<01A<00`0C4`0F4`@=>Q<43M@C00<04a<061<00`0C4`0n4`0301<C07`C00<04a<0

4Q<00`0C4`0`4`00<Q<00`0C4`0B4`@=@Q<53LlC00<04a<061<00`0C4`0m4`0301<C07hC0P0B4`03

01<C030C000b4`0301<C00hC10e;4`D=bQ<00`0C4`0H4`80?Q<00`0C4`204`8041<00`0C4`0`4`00

<Q<00`0C4`084`H=E1<53LDC00<04a<061<00`0C4`0Q4`D00Q<00`0C4`0B4`0301<C00/C1@000a<0

000Q4`D00Q<00`0C4`0O4`D00Q<00`0C4`0K4`0401<C4`D000<C00000a<00`0C4`0a4`00<Q<;3ElC

0`g24`0301<C01PC00<04a<08a<01`0C4a<04`004a<00`0C4`0=4`0701<C4`0C000R4`0301<C008C

00<04a<08A<01`0C4a<04`0071<200@C00<04a<00a<0100C4`0c4`00<Q<00`0C4`0V4`0301<C008C

00@04a<C0`0S4`0301<C008C00<04a<00Q<300PC;`dJ4`0301<C008C00<04a<00Q<00`0C4`0V4`D0

@A<00`0C4`0H4`0301<C02<C00<04a<00a<00`0C4`0A4`0301<C00dC00L04a<C01<0028C00<04a<0

0Q<00`0C4`0Q4`0701<C4`0C000N4`0501<C4`0011<2008C00<04a<0<A<0038C00<04a<09A<00`0C

00074`0301<C028C00<04`002A<00`0C4`0P4`0301<000LC00<04`002A<93A0C00<04`001a<00`0C

000Y4`0301<C044C00<04a<061<00`0C4`0S4`0401<C4`8051<00`0C4`0=4`0401<C4`808a<00`0C

4`034`0301<C020C00<04a<00Q<00`0C4`0N4`8000<C01<00Q<00`0C00024`0301<C034C000b4`03

01<C02DC00<04`0021<00`0C4`0Q4`0301<000LC100Q4`0301<000LC00<04`004Q<53@/C00<04`00

1a<00`0C000Y4`0301<C040C00<04a<06A<00`0C4`0S4`0501<C4`005A<00`0C4`0=4`0501<C4`00

91<01`0C4a<04`008Q<01`0C4a<04`008A<200<C00D04`0C000d4`00<Q<00`0C4`0U4`0301<000PC

00<04a<08A<00`0C00074`0301<0028C00<04`001a<201PC10d74`0301<000PC00<04a<0:1<00`0C

4`104`0301<C01TC0P0S4`800a<301<C00<04a<031<200@C0P0Q4`800a<3024C0P044`0301<C020C

0P044`8000<C01<0<a<0038C00<04a<09A<00`0C00074`0301<0028C00<04`0021<2028C00<04`00

1a<00`0C4`0K4`D=0Q<00`0C00074`0301<002TC00<04a<0@1<00`0C4`0I4`0301<C03dC00<04a<0

R1<00`0C4`054`0301<C038C000b4`0301<C02HC00<04a<01a<00`0C4`0R4`0301<C00PC00<04a<0

8A<00`0C4`074`8081<53@PC00<04a<09a<2048C00<04a<06A<00`0C4`0m4`0301<C08TC0P054`03

01<C038C000b4`0301<C0;DC10eb4`0301<C01TC00<04a<0?A<00`0C4`2;4`0501<C4`00=A<0038C

00<04a<0^A<33FlC00<04a<06A<00`0C4`0m4`0301<C08/C00@04a<04a<401lC000b4`0301<C0;`C

10e[4`0301<C01TC00<04a<0?A<00`0C4`2<4`8051<3020C000b4`0301<C0<0C10dc4`<0:a?o00XC

00<04a<07Q<0038C00<04a<0a1<:3BXC00<04a<0:a<00`0C4`024`0401<C00PC00<04a<01A<00`0C

4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC

00<04a<00a<00`0C00074`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C

4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC

00<04a<01A<00`0C4`054`0301<C00DC0`064`0301<C00`C0P0P4`00;1?G01/=1P094`0301<C030C

00<04a<06A<00`0C4`0V4`0301<C01@C00<04a<041<00`0C4`0V4`0301<C02HC00<04a<09Q<0100C

4`0f4`00<Q<00`0C4`084`0301<C00TC00<04a<02A<00`0C4`094`0301<C00PC00<04a<02A<00`0C

4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0C4`094`0301<C00PC

00<04a<02A<00`0C4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC00<04a<031<4030C

00<04a<06A<00`0C4`0m4`0301<C08/C00D04a<C000e4`00<Q<00`0C4`0/4`0301<C02`C00<04a<0

;1<00`0C4`0/4`0301<C02`C00<04a<0@1<00`0C4`0I4`0301<C03dC00<04a<0RQ<00`0C4`024`03

01<C03<C000b4`0301<C0?lC;1<00`0C4`0I4`0301<C03dC00<04a<0RA<00`0C4`044`0301<C038C

000b4`0301<C0?lC;1<00`0C4`0I4`80?Q<00`0C4`274`801a<00`0C4`0b4`00<Q<00`0C4`3o4b`C

00<04a<06A<00`0C4`0m4`0301<C08LC00<04a<01Q<00`0C4`0b4`00<Q<00`0C4`3o4bdC00<04a<0

61<00`0C4`0m4`0301<C08HC00<04a<021<00`0C4`0a4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C

4`0m4`0301<C08@C0P0;4`0301<C034C000b4`0301<C0?lC;A<00`0C4`0H4`0301<C03dC00<04a<0

Pa<00`0C4`0;4`0301<C034C000b4`0301<C0?lC;A<00`0C4`0H4`0301<C03dC00<04a<0PQ<00`0C

4`0<4`0301<C034C000b4`0301<C0?lC;A<00`0C4`0H4`80?Q<00`0C4`204`803a<00`0C4`0a4`00

<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0m4`0301<C07lC00<04a<041<00`0C4`0`4`00<Q<00`0C

4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07`C0P0C4`0301<C030C000b4`0301<C0?lC;A<00`0C

4`0H4`0301<C03hC00<04a<0Na<201@C00<04a<0<1<0038C00<04a<0oa<]4`0301<C01PC00<04a<0

?Q<00`0C4`1i4`805Q<00`0C4`0`4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07PC

00<04a<05Q<00`0C4`0`4`00<Q<00`0C4`3o4bhC00<04a<05a<203lC00<04a<0MQ<201TC00<04a<0

<1<0038C00<04a<0oa<^4`0301<C01LC00<04a<0?Q<00`0C4`1d4`8071<00`0C4`0_4`0071<00`0C

4`024`0401<C4`<00a<00`0C4`044`0301<C0?lC;Q<00`0C4`0G4`0301<C03hC00<04a<0La<00`0C

4`0L4`0301<C02lC000K4`0301<000LC00<04a<00Q<00`0C00054`0301<C0?lC;Q<00`0C4`0G4`03

01<C03lC00<04a<0L1<201lC00<04a<0;a<001/C00<04`0021<00`0C4`034`0301<C00<C0P3o4c0C

00<04a<05Q<00`0C4`0o4`0301<C06dC0`0Q4`0301<C02lC000K4`0301<000PC00@04a<C0P064`03

01<C0?lC;a<00`0C4`0F4`0301<C03lC00<04a<0K1<202<C00<04a<0;a<001/C00<04`001a<00`0C

00024`0301<C00DC00<04a<0oa<_4`0301<C01HC0P104`0301<C06XC0P0U4`0301<C02lC000L4`03

01<C00LC00@04a<C0`054`0301<C0?lC;a<00`0C4`0F4`0301<C03lC00<04a<0J1<202LC00<04a<0

;a<0038C00<04a<0oa<_4`0301<C01HC00<04a<0?a<00`0C4`1V4`80:A<00`0C4`0_4`00<Q<00`0C

4`3o4c0C00<04a<05A<00`0C4`0o4`0301<C06@C0P0Z4`0301<C030C000b4`0301<C0?lC<1<00`0C

4`0?4`0301<C00<C00<04a<0?a<00`0C4`1R4`80;1<00`0C4`0`4`00<Q<00`0C4`3o4c0C00<04a<0

3Q<00`0C00044`0301<C040C00<04a<0GQ<302hC00<04a<0<1<0038C00<04a<0oa<`4`0301<C010C

00<04a<00Q<3040C00<04a<0G1<3030C00<04a<0<1<0038C00<04a<0oa<a4`0301<C00dC0P054`03

01<C040C00<04a<0FQ<2038C0P0b4`00<Q<00`0C4`3o4c4C00<04a<03A<00`0C4`044`0301<C044C

00<04a<0Ea<203@C00<04a<0<A<0038C00<04a<0oa<b4`0301<C00`C0`044`0301<C044C00<04a<0

E1<303HC00<04a<0<A<0038C00<04a<0oa<b4`0301<C01<C00<04a<0@A<00`0C4`1B4`<0=a<203<C

000b4`0301<C0?lC<a<00`0C4`0B4`80@Q<00`0C4`1?4`<0>Q<00`0C4`0b4`00<Q<00`0C4`3o4c<C

00<04a<04Q<00`0C4`124`0301<C04`C0`0l4`0301<C038C000b4`0301<C0?lC=1<00`0C4`0A4`03

01<C048C00<04a<0BA<303hC00<04a<0<a<0038C00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C

4`174`<0@1<00`0C4`0c4`008A<00`0C4`024`0301<C008C00<04a<011<00`0C4`3o4cDC00<04a<0

41<00`0C4`124`0301<C04@C0`124`80=A<0020C00<04`001a<00`0C00054`0301<C0?lC=A<00`0C

4`0@4`0301<C04<C00<04a<0@1<304DC00<04a<0=1<0020C00<04`002A<00`0C4`034`80oa<g4`03

01<C00lC0P144`0301<C03dC0`174`80=Q<0020C00<04`001a<200HC00<04a<0oa<f4`0301<C00lC

00<04a<0A1<00`0C4`0i4`<0BQ<00`0C4`0e4`0081<00`0C00074`0301<C00DC00<04a<0oa<g4`03

01<C00hC00<04a<0A1<00`0C4`0f4`@0Ba<203LC000Q4`0301<C00HC0`054`0301<C0?lC>1<00`0C

4`0=4`0301<C04@C00<04a<0<a<304lC00<04a<0=Q<0038C00<04a<0oa<i4`0301<C00`C00<04a<0

AA<00`0C4`0_4`<0DA<00`0C4`0g4`00<Q<00`0C4`3o4cTC00<04a<031<00`0C4`154`0301<C02/C

101C4`80>A<0038C00<04a<0oa<j4`0301<C00/C0P174`0301<C02LC101F4`0301<C03PC000b4`03

01<C0?lC>Q<00`0C4`0;4`0301<C04HC00<04a<08a<505PC0P0j4`00<Q<00`0C4`3o4c/C0P0;4`03

01<C04HC00<04a<081<405/C0P0k4`00<Q<00`0C4`3o4cdC00<04a<021<00`0C4`174`0301<C01/C

101O4`0301<C03XC000b4`0301<C0?lC?Q<00`0C4`074`0301<C04LC0P0H4`D0HA<00`0C4`0k4`00

<Q<00`0C4`3o4chC00<04a<01a<00`0C4`184`0301<C01<C101T4`80?A<0038C00<04a<0oa<o4`03

01<C00HC0P1:4`0301<C00hC101W4`80?Q<0038C00<04a<0oa=04`801Q<00`0C4`194`0301<C00XC

101Z4`80?a<0038C00<04a<0oa=24`0301<C00<C00<04a<0BQ<00`0C4`054`D0K1<2040C000b4`03

01<C0?lC@a<200<C00<04a<0BQ<200034`0000<0L1<2044C000b4`0301<C0?lC>a<5008C00@04a<0

0Q<00`0C4`194`D0La<2048C000L4`0301<C008C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0

oa<m4`0701<C4`0C00024`<0Aa<5008C00<04a<0LA<204<C000K4`0301<000PC00L04a<C01<000DC

00<04a<0oa<m4`0701<C4`0C00044`<0@1<500PC00<04a<0KQ<204DC000K4`0301<000PC00<04a<0

0a<00`0C4`034`80oa<n4`0701<C4`0C00044`0401<003XC1@0=4`0301<C06dC0P164`006a<00`0C

00094`0301<C00801Q<00`0C4`3o4cdC00L04a<C01<000@C00@04a<C0`0a4`H04a<206/C0`174`00

6a<00`0C00074`0301<0008C00<04a<01A<00`0C4`3o4c`C0P044`0301<C00<C00<04a<011<302PC

1`0I4`80JA<204TC000L4`0301<C00HC0`024`<01A<00`0C4`3o4dPC00<04a<01a<501/C2@0P4`03

01<C06@C0`1;4`00<Q<00`0C4`3o4dPC00<04a<031<L02TC0P1R4`<0CA<0038C00<04a<0oa=84`80

Da<205lC0`1?4`00<Q<00`0C4`3o4dPC00<04a<0Da<205XC101B4`00<Q<00`0C4`3o4dPC00<04a<0

E1<205HC101E4`00<Q<00`0C4`3o4dPC00<04a<0EQ<204lC1@1I4`00<Q<00`0C4`3o4dPC00<04a<0

Ea<304PC1P1M4`00<Q<00`0C4`3o4dPC00<04a<0FA<3040C1`1R4`00<Q<00`0C4`3o4dPC0P1L4`<0

>1<706PC000b4`0301<C0?lCB1<00`0C4`1N4`<0;Q<806hC000b4`0301<C0?lCB1<00`0C4`1P4`D0

8a<807DC000b4`0301<C0?lCB1<00`0C4`1T4`L051<:07`C000b4`0301<C0?lCB1<00`0C4`1Z4aD0

QQ<0038C00<04a<0oa=84`0301<C0?lC1Q<002TC1@044`0301<C0?lCB1<20?lC1a<002/C00<04a<0

11<00`0C4`3o4dPC00<04a<0oa<64`00:a<00`0C4`044`80oa=94`0301<C0?lC1Q<002/C00<04a<0

oa?o4ePC000[4`0301<C0?lCoa=H4`00:Q<20?lCoa=J4`00oa?o4hHC003o4olCQQ<00?lCoa>64`00

oa?o4hHC003o4olCQQ<0074C10000a<00007008C00<04a<00Q<0100C4a<200<C0P044`<000<C0000

0a<200<C0P034`800a<200<C0P034`800a<200<C0P034`8011<0100C4a<2008C1@3o4j`C001a4`<0

21<01`0C4a<04`002A<01P0C4`0C00@C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C

4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<01P0C4`0C00@C00D04a<C

002S4`80oa<94`00La<00`0C4`04008C00<04a<00a<00`0C4`064`800Q<00`0C00024`@00Q<200<C

0P034`800a<200<C0P034`800a<200<C0P034`800a<2008C00<04`000a<200<C00<04a<0XQ<00`0C

4`3o4`LC000I4`@000<C00001P024`X00Q<2008C0`024`<00a<200064`0001<09a<200PC00@04a<C

0P084`0301<0008C0P034`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C

00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000a<01`0C4a<04`000a<00`0C

4`2P4`<00Q<00`0C4`3o4`@C000J4`0601<C01<00Q<00`0C00044`0601<C01<00Q<00`0C00054`03

01<C008C00D04a<C00024`0401<04`80<A<01@0C4a<000TC00<04`000Q<00`0C4`034`800Q<00`0C

00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C

00<04`000Q<00`0C00024`0301<0008C00<04`000a<00`0C4`034`0301<C09TC00P04a<04`0C0?lC

1A<001XC00H04a<04`044`0301<C008C00<04a<00Q<00`0C4`024`0301<C00<C00<04a<00Q<01@0C

4a<0008C00@04`0C0P0`4`800a<300PC0P034`8011<0100C4a<200<C0P034`800a<200<C0P034`80

0a<200<C0P034`800a<200<C00<04a<00Q<2008C0P044`0301<C09XC00P04a<04`0C0?lC1A<001XC

00D04a<04`0200<C0P034`0301<C008C0P034`0301<C00<C00<04a<00Q<01@0C4a<0008C00H04`00

4`3o4blC0`0011<04`3o4`DC000J4`0601<C01<00Q<00`0C00024`0301<000@C00h04a<04`0C01<0

4`0C008C00D04a<C00024`0601<001<0oa<c4`0301<00?lC1A<001TC10000a<0000;008C1@001A<0

000C00D000@C00000a<200044`004`80oa<d4`0301<C0?lC11<00?lCoa>64`00oa?o4hHC003o4olC

QQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00001\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.77084, -14.119, 0.0242408, 0.16996}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -57 0 ]

[.5 .63053 57 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -118 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(15.6950000000000011`) show

173.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .33637 m

.02499 .33637 L

.02606 .33637 L

.02729 .33638 L

.02846 .33639 L

.03053 .33642 L

.03279 .33646 L

.03527 .33652 L

.0379 .3366 L

.04262 .33678 L

.05205 .3373 L

.06245 .33809 L

.0842 .34043 L

.10458 .34331 L

.14335 .34974 L

.16306 .35301 L

.18458 .35621 L

.19454 .35748 L

.20517 .35865 L

.21512 .35955 L

.22429 .36019 L

.22929 .36047 L

.23457 .3607 L

.23713 .36079 L

.23987 .36087 L

.24145 .3609 L

.24289 .36093 L

.24425 .36096 L

.2457 .36098 L

.24692 .36099 L

.24757 .36099 L

.24827 .361 L

.2495 .361 L

.25066 .36101 L

.25131 .36101 L

.25203 .361 L

.25278 .361 L

.25347 .361 L

.25472 .36099 L

.25606 .36097 L

.25732 .36096 L

.2587 .36093 L

.2612 .36088 L

.26587 .36074 L

.27076 .36055 L

.27533 .36032 L

.28574 .35962 L

.29589 .35874 L

.30679 .35758 L

.34806 .35175 L

Mistroke

.38782 .34532 L

.42607 .33995 L

.44578 .33787 L

.45672 .33696 L

.46677 .33629 L

.47708 .33575 L

.48239 .33553 L

.48822 .33534 L

.4933 .33521 L

.49804 .33512 L

.50066 .33508 L

.50304 .33505 L

.50436 .33504 L

.5058 .33502 L

.50716 .33501 L

.5084 .33501 L

.50954 .335 L

.51074 .335 L

.51195 .335 L

.51326 .33499 L

.51441 .335 L

.51563 .335 L

.51678 .335 L

.51782 .335 L

.52039 .33502 L

.52317 .33504 L

.52821 .33509 L

.53353 .33517 L

.53916 .33526 L

.54923 .33546 L

.56907 .33589 L

.57774 .33606 L

.58717 .33621 L

.58969 .33624 L

.59237 .33627 L

.59485 .33629 L

.59718 .3363 L

.59823 .33631 L

.59934 .33631 L

.60056 .33632 L

.60168 .33632 L

.60291 .33632 L

.60406 .33632 L

.60532 .33632 L

.60602 .33632 L

.60666 .33631 L

.60796 .33631 L

.60934 .3363 L

.61182 .33629 L

.61448 .33626 L

Mistroke

.61741 .33622 L

.62266 .33613 L

.62757 .33602 L

.63796 .33568 L

.64783 .33522 L

.66636 .33402 L

.68618 .33223 L

.70457 .33015 L

.74372 .32479 L

.78532 .31873 L

.80621 .31598 L

.82541 .31378 L

.84536 .31192 L

.86398 .31061 L

.87307 .31012 L

.88282 .3097 L

.88837 .30951 L

.89363 .30935 L

.89832 .30924 L

.90349 .30913 L

.90847 .30905 L

.91315 .30899 L

.91809 .30895 L

.92087 .30893 L

.92341 .30892 L

.92563 .30891 L

.9277 .30891 L

.92889 .3089 L

.92997 .3089 L

.93121 .3089 L

.93239 .3089 L

.93354 .3089 L

.93475 .3089 L

.93578 .3089 L

.93692 .3089 L

.93815 .3089 L

.93946 .30891 L

.94184 .30891 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.41012 .46938 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4gdC00<04a<0oa<64`00oa=m4`0301<C0?lC1Q<002TC1@3o4dlC0P3o4`LC

000[4`0301<C0?lCCa<00`0C4`1^4`d0RQ<002DC0`034`0301<C00@C0P3o4dTC00<04a<0IQ<800`C

3@1n4`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`1Q4`D081<807LC000[4`0301<C00@C00<04a<0

oa=84`0301<C05hC100/4`L0L1<002XC0P064`0301<C0?lCB1<00`0C4`1L4`<0=A<706XC000b4`03

01<C0?lCB1<205/C0P0o4`H0I1<0038C00<04a<0oa=84`0301<C05PC0P164`H0Ga<0038C00<04a<0

oa=84`0301<C05HC0P1>4`D0FQ<0038C00<04a<0oa=84`0301<C05DC0P1C4`D0EQ<0038C00<04a<0

oa=84`0301<C05@C00<04a<0Ea<5058C000b4`0301<C0?lCB1<205<C0P1N4`<0D1<0038C00<04a<0

oa=84`0301<C00lC5P0/4`80HA<404dC000b4`0301<C0?lCB1<00`0C4`0:4`D05Q<9028C0P1U4`<0

Ba<0038C00<04a<0oa=84`0301<C00DC1@0S4`L06a<206PC0`194`00<Q<00`0C4`3o4c/C1@024`03

01<C00<C00<04a<00a<202lC1P0D4`80Ja<204PC000b4`0301<C0?lC?A<01`0C4a<04`0011<00`0C

4`0303HC1P0>4`80KA<304HC000b4`0301<C0?lC=a<300<C00L04a<C01<000@C0`0n4`H02A<00`0C

4`1^4`80AA<0038C00<04a<0oa<m4`0701<C4`0C00034`80AA<500@C00<04a<0L1<204@C000L4`03

01<C008C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0oa<m4`0701<C4`0C00024`0301<004XC

1@1d4`80@Q<001/C00<04`0021<01`0C4a<04`001A<00`0C4`3o4c`C0P044`0401<0008C00<04a<0

Ba<6074C0P114`005Q<3008C00<04`0021<00`0C4`034`0301<C00<C0P3o4d<C0P044`0301<C04XC

00<04a<011<406hC0P104`006a<00`0C00094`0301<C00801Q<00`0C4`3o4d4C00<04a<011<00`0C

4`194`0301<C00TC101[4`0301<C03hC000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C0?lC

@1<00`0C4`054`80BQ<00`0C4`0=4`@0J1<203hC000L4`0301<C00HC0`024`<01A<00`0C4`3o4clC

00<04a<01Q<00`0C4`184`0301<C018C101U4`0301<C03`C000b4`0301<C0?lC?Q<00`0C4`074`03

01<C04PC00<04a<05A<5068C00<04a<0>a<0038C00<04a<0oa<m4`0301<C00PC00<04a<0Aa<00`0C

4`0J4`@0Ga<203`C000b4`0301<C0?lC?1<00`0C4`094`0301<C04HC00<04a<07a<405`C0P0k4`00

<Q<00`0C4`3o4c/C00<04a<02Q<00`0C4`164`0301<C028C1@1I4`0301<C03TC000b4`0301<C0?lC

>Q<00`0C4`0;4`80Aa<00`0C4`0V4`@0Ea<00`0C4`0h4`00<Q<00`0C4`3o4cTC00<04a<031<00`0C

4`154`0301<C02XC101D4`80>A<0038C00<04a<0oa<i4`0301<C00`C00<04a<0AA<00`0C4`0^4`@0

DA<00`0C4`0g4`00<Q<00`0C4`3o4cPC00<04a<03A<00`0C4`144`0301<C03<C0P1?4`80>1<0038C

00<04a<0oa<g4`0301<C00hC00<04a<0A1<00`0C4`0e4`@0C1<203LC000b4`0301<C0?lC=Q<00`0C

4`0?4`0301<C04@C00<04a<0>A<204/C00<04a<0=A<0038C00<04a<0oa<f4`0301<C00lC0P144`03

01<C03`C10174`80=Q<0038C00<04a<0oa<e4`0301<C010C00<04a<0@a<00`0C4`0o4`<0AQ<00`0C

4`0d4`00<Q<00`0C4`3o4cDC00<04a<041<00`0C4`134`0301<C048C0`134`80=A<0024C00<04a<0

0Q<00`0C4`024`0301<C00@C00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`164`<0@A<00`0C

4`0c4`0081<00`0C00074`0301<000DC00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`194`80

?a<00`0C4`0c4`006a<3008C00<04`002A<00`0C4`034`80oa<d4`0301<C018C00<04a<0@Q<00`0C

4`1;4`<0?A<00`0C4`0b4`0081<00`0C00074`801Q<00`0C4`3o4c<C00<04a<04Q<204<C00<04a<0

CQ<203/C00<04a<0<Q<0020C00<04`001a<00`0C4`054`0301<C0?lC<Q<00`0C4`0C4`0301<C044C

00<04a<0DA<303PC00<04a<0<Q<0024C00<04a<01Q<300DC00<04a<0oa<b4`0301<C01<C00<04a<0

@A<00`0C4`1D4`80=a<00`0C4`0a4`00<Q<00`0C4`3o4c4C00<04a<051<00`0C4`114`0301<C05HC

0`0d4`0301<C034C000b4`0301<C0?lC<A<00`0C4`0>4`0301<C00<C00<04a<0@1<00`0C4`1I4`<0

<Q<2038C000b4`0301<C0?lC<1<00`0C4`0>4`0301<000@C00<04a<0@1<00`0C4`1L4`80<A<00`0C

4`0`4`00<Q<00`0C4`3o4c0C00<04a<02A<300@C00<04a<00Q<3040C00<04a<0GQ<202lC00<04a<0

<1<0038C00<04a<0oa<`4`0301<C00hC0P054`0301<C03lC00<04a<0HA<302`C00<04a<0<1<0038C

00<04a<0oa<`4`0301<C00hC00<04a<011<00`0C4`0o4`0301<C06@C00<04a<0:A<00`0C4`0`4`00

<Q<00`0C4`3o4blC00<04a<03a<300@C00<04a<0?a<00`0C4`1U4`<0:1<2034C000b4`0301<C0?lC

;a<00`0C4`0F4`0301<C03lC00<04a<0J1<00`0C4`0V4`0301<C02lC000b4`0301<C0?lC;a<00`0C

4`0F4`0301<C03lC00<04a<0JA<302DC00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC0P104`03

01<C06`C0P0S4`0301<C02lC000b4`0301<C0?lC;a<00`0C4`0F4`0301<C03lC00<04a<0KA<2028C

00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC00<04a<0?a<00`0C4`1_4`8081<00`0C4`0_4`00

<Q<00`0C4`3o4bhC00<04a<05a<00`0C4`0n4`0301<C078C0P0N4`0301<C02lC000L4`0301<C008C

00@04a<C0`034`0301<C00@C00<04a<0oa<^4`0301<C01LC00<04a<0?Q<00`0C4`1d4`8071<00`0C

4`0_4`006a<00`0C00074`0301<C008C00<04`001A<00`0C4`3o4bhC00<04a<05a<203lC00<04a<0

MQ<201XC00<04a<0;a<001HC0`024`0301<000PC00<04a<00a<00`0C4`034`80oa<_4`0301<C01LC

00<04a<0?Q<00`0C4`1h4`0301<C01HC00<04a<0<1<001/C00<04`0021<0100C4a<200HC00<04a<0

oa<]4`0301<C01PC00<04a<0?Q<00`0C4`1i4`805Q<00`0C4`0`4`006a<00`0C00074`0301<0008C

00<04a<01A<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07/C00<04a<04a<00`0C4`0`4`00

71<00`0C4`074`0401<C4`<01A<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07`C00<04a<0

4Q<00`0C4`0`4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0m4`0301<C07hC0P0B4`0301<C030C

000b4`0301<C0?lC;A<00`0C4`0H4`80?Q<00`0C4`204`8041<00`0C4`0`4`00<Q<00`0C4`3o4bdC

00<04a<061<00`0C4`0Q4`D00Q<00`0C4`0B4`0301<C00/C1@000a<0000Q4`D00Q<00`0C4`0O4`D0

0Q<00`0C4`0K4`0401<C4`D000<C00000a<00`0C4`0a4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C

4`0S4`0701<C4`0C000C4`0301<C00dC00L04a<C01<0028C00<04a<00Q<00`0C4`0Q4`0701<C4`0C

000L4`8011<00`0C4`034`0401<C03<C000b4`0301<C02HC00<04a<00Q<0100C4a<302<C00<04a<0

0Q<00`0C4`024`<08Q<00`0C4`024`0401<C4`8091<00`0C4`024`0301<C008C00<04a<09Q<5044C

00<04a<061<00`0C4`0S4`0301<C00<C00<04a<04A<00`0C4`0=4`0701<C4`0C000R4`0301<C008C

00<04a<08A<01`0C4a<04`007Q<01@0C4a<000@C0P024`0301<C034C000b4`0301<C02DC00<04`00

1a<00`0C4`0R4`0301<000TC00<04a<081<00`0C00074`0301<0028C00<04`001a<00`0C000Y4`03

01<C044C00<04a<061<00`0C4`0S4`0401<C4`8051<00`0C4`0=4`0401<C4`808a<00`0C4`034`03

01<C020C00<04a<00Q<00`0C4`0N4`8000<C01<00Q<00`0C00024`0301<C034C000b4`0301<C02DC

00<04`0021<00`0C4`0Q4`0301<000LC100Q4`0301<000LC00<04`008Q<00`0C00074`0301<002TC

00<04a<0@1<00`0C4`0I4`0301<C02<C00D04a<C000E4`0301<C00dC00D04a<C000T4`0701<C4`0C

000R4`0701<C4`0C000Q4`800a<01@0C01<003@C000b4`0301<C02DC00<04`0021<00`0C4`0Q4`03

01<000LC00<04`008Q<00`0C00074`808a<00`0C00084`0301<C02PC00<04a<0@1<00`0C4`0I4`80

8a<200<C0`0C4`0301<C00`C0P044`808A<200<C0`0Q4`8011<00`0C4`0P4`8011<200034`0C03<C

000b4`0301<C02DC00<04`001a<00`0C000R4`0301<000PC0P0R4`0301<000LC00<04a<08Q<00`0C

00074`0301<002TC00<04a<0@1<00`0C4`0I4`0301<C03dC00<04a<0R1<00`0C4`054`0301<C038C

000b4`0301<C02HC00<04a<01a<00`0C4`0R4`0301<C00PC00<04a<08A<00`0C4`074`808a<00`0C

4`074`0301<C02LC0P124`0301<C01TC00<04a<0?A<00`0C4`294`801A<00`0C4`0b4`00<Q<00`0C

4`3o4b`C00<04a<06A<00`0C4`0m4`0301<C08/C00D04a<C000e4`00<Q<00`0C4`3o4b`C00<04a<0

6A<00`0C4`0m4`0301<C08/C00@04a<04a<401lC000b4`0301<C0?lC;1<00`0C4`0I4`0301<C03dC

00<04a<0S1<201@C0`0P4`00<Q<00`0C4`3g4`<0:a?o00XC00<04a<07Q<0038C00<04a<0n1<00`0C

4`0[4`0301<C008C00@04a<021<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC

00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`034`0301<000LC00<04a<01Q<00`0C

4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC

00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<300HC

00<04a<031<2020C000/4ml04`d600TC00<04a<0<1<00`0C4`0I4`0301<C02HC00<04a<051<00`0C

4`0@4`0301<C02HC00<04a<09Q<00`0C4`0V4`0401<C03HC000b4`0301<C00PC00<04a<02A<00`0C

4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0C4`084`0301<C00TC

00<04a<02A<00`0C4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0=

3@0>3@HC00<04a<02A<00`0C4`0<4`@0<1<00`0C4`0I4`0301<C03dC00<04a<0Ra<01@0C4a<003DC

000b4`0301<C02`C00<04a<0;1<00`0C4`0/4`0301<C02`C00<04a<02PdR4`0301<C040C00<04a<0

6A<00`0C4`0m4`0301<C08XC00<04a<00Q<00`0C4`0c4`00<Q<00`0C4`2e4`L=Ka<00`0C4`0I4`03

01<C03dC00<04a<0RA<00`0C4`044`0301<C038C000b4`0301<C0:dC20ef4`0301<C01TC0P0n4`03

01<C08LC0P074`0301<C038C000b4`0301<C0:PC1@en4`0301<C01TC00<04a<0?A<00`0C4`274`03

01<C00HC00<04a<0<Q<0038C00<04a<0WQ<:3H@C00<04a<061<00`0C4`0m4`0301<C08HC00<04a<0

21<00`0C4`0a4`00<Q<83F8C=`f>4`0301<C01PC00<04a<0?A<00`0C4`244`802a<00`0C4`0a4`00

<Q<00`0C4`054`T=CQ<;3LDC00<04a<061<00`0C4`0m4`0301<C08<C00<04a<02a<00`0C4`0a4`00

<Q<00`0C4`0>4`D=@Q<73M0C00<04a<061<00`0C4`0m4`0301<C088C00<04a<031<00`0C4`0a4`00

<Q<00`0C4`0C4`D=>1<53MLC00<04a<061<203hC00<04a<0P1<200lC00<04a<0<A<0038C00<04a<0

61<:3BHC20gL4`0301<C01PC00<04a<0?A<00`0C4`1o4`0301<C010C00<04a<0<1<0038C00<04a<0

8Q<63AXC1PgT4`0301<C01PC00<04a<0?Q<00`0C4`1l4`804a<00`0C4`0`4`00<Q<00`0C4`0X4aX=

jQ<00`0C4`0H4`0301<C03hC00<04a<0Na<201@C00<04a<0<1<0038C00<04a<0oa<]4`0301<C01PC

00<04a<0?Q<00`0C4`1i4`805Q<00`0C4`0`4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`03

01<C07PC00<04a<05Q<00`0C4`0`4`00<Q<00`0C4`3o4bhC00<04a<05a<203lC00<04a<0MQ<201TC

00<04a<0<1<0038C00<04a<0oa<^4`0301<C01LC00<04a<0?Q<00`0C4`1d4`8071<00`0C4`0_4`00

71<00`0C4`024`0401<C4`<00a<00`0C4`044`0301<C0?lC;Q<00`0C4`0G4`0301<C03hC00<04a<0

La<00`0C4`0L4`0301<C02lC000K4`0301<000LC00<04a<00Q<00`0C00054`0301<C0?lC;Q<00`0C

4`0G4`0301<C03lC00<04a<0L1<201lC00<04a<0;a<001/C00<04`0021<00`0C4`034`0301<C00<C

0P3o4c0C00<04a<05Q<00`0C4`0o4`0301<C06dC0`0Q4`0301<C02lC000K4`0301<000PC00@04a<C

0P064`0301<C0?lC;a<00`0C4`0F4`0301<C03lC00<04a<0K1<202<C00<04a<0;a<001/C00<04`00

1a<00`0C00024`0301<C00DC00<04a<0oa<_4`0301<C01HC0P104`0301<C06XC0P0U4`0301<C02lC

000L4`0301<C00LC00@04a<C0`054`0301<C0?lC;a<00`0C4`0F4`0301<C03lC00<04a<0J1<202LC

00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC00<04a<0?a<00`0C4`1V4`80:A<00`0C4`0_4`00

<Q<00`0C4`3o4c0C00<04a<05A<00`0C4`0o4`0301<C06@C0P0Z4`0301<C030C000b4`0301<C0?lC

<1<00`0C4`0?4`0301<C00<C00<04a<0?a<00`0C4`1R4`80;1<00`0C4`0`4`00<Q<00`0C4`3o4c0C

00<04a<03Q<00`0C00044`0301<C040C00<04a<0GQ<302hC00<04a<0<1<0038C00<04a<0oa<`4`03

01<C010C00<04a<00Q<3040C00<04a<0G1<3030C00<04a<0<1<0038C00<04a<0oa<a4`0301<C00dC

0P054`0301<C040C00<04a<0FQ<2038C0P0b4`00<Q<00`0C4`3o4c4C00<04a<03A<00`0C4`044`03

01<C044C00<04a<0Ea<203@C00<04a<0<A<0038C00<04a<0oa<b4`0301<C00`C0`044`0301<C044C

00<04a<0E1<303HC00<04a<0<A<0038C00<04a<0oa<b4`0301<C01<C00<04a<0@A<00`0C4`1B4`<0

=a<203<C000b4`0301<C0?lC<a<00`0C4`0B4`80@Q<00`0C4`1?4`<0>Q<00`0C4`0b4`00<Q<00`0C

4`3o4c<C00<04a<04Q<00`0C4`124`0301<C04`C0`0l4`0301<C038C000b4`0301<C0?lC=1<00`0C

4`0A4`0301<C048C00<=4a<0BA<303hC00<04a<0<a<0038C00<04a<0oa<d4`0301<C014C00<04a<0

?a<63DLC0`104`0301<C03<C000Q4`0301<C008C00<04a<00Q<00`0C4`044`0301<C0?lC=A<00`0C

4`0@4`0301<C03hC2@e24`<0@Q<203DC000P4`0301<000LC00<04`001A<00`0C4`3o4cDC00<04a<0

41<00`0C4`0n4`T=?a<304DC00<04a<0=1<0020C00<04`002A<00`0C4`034`80oa<g4`0301<C00lC

0P0o4`T=?1<304LC0P0f4`0081<00`0C00074`801Q<00`0C4`3o4cHC00<04a<03a<00`0C4`0m4`/=

>1<304XC00<04a<0=A<0020C00<04`001a<00`0C4`054`0301<C0?lC=a<00`0C4`0>4`0301<C03hC

2@df4`@0Ba<203LC000Q4`0301<C00HC0`054`0301<C0?lC>1<00`0C4`0=4`0301<C03hC2@dc4`<0

Ca<00`0C4`0f4`00<Q<00`0C4`3o4cTC00<04a<031<00`0C4`0n4`T=<1<3054C00<04a<0=a<0038C

00<04a<0oa<i4`0301<C00`C00<04a<0?a<63@0301<C02/C101C4`80>A<0038C00<04a<0oa<j4`03

01<C00/C0P134`053A<C4`00:A<405HC00<04a<0>1<0038C00<04a<0oa<j4`0301<C00/C00<04a<0

AQ<00`0C4`0S4`D0F1<203XC000b4`0301<C0?lC>a<200/C00<04a<0AQ<00`0C4`0P4`@0Fa<203/C

000b4`0301<C0?lC?A<00`0C4`084`0301<C04LC00<04a<06a<405lC00<04a<0>Q<0038C00<04a<0

oa<n4`0301<C00LC00<04a<0Aa<201PC1@1Q4`0301<C03/C000b4`0301<C0?lC?Q<00`0C4`074`03

01<C04PC00<04a<04a<406@C0P0m4`00<Q<00`0C4`3o4clC00<04a<01Q<204XC00<04a<03Q<406LC

0P0n4`00<Q<00`0C4`3o4d0C0P064`0301<C04TC00<04a<02Q<406XC0P0o4`00<Q<00`0C4`3o4d8C

00<04a<00a<00`0C4`1:4`0301<C00DC1@1/4`80@1<0038C00<04a<0oa=34`800a<00`0C4`1:4`80

00<C00000`1`4`80@A<0038C00<04a<0oa<k4`D00Q<0100C4`024`0301<C04TC1@1c4`80@Q<001`C

00<04a<00Q<00`0C4`024`0301<C008C00<04a<011<00`0C4`3o4cdC00L04a<C01<0008C0`174`D0

0Q<00`0C4`1a4`80@a<001/C00<04`0021<01`0C4a<04`001A<00`0C4`3o4cdC00L04a<C01<000@C

0`104`D021<00`0C4`1^4`80AA<001/C00<04`0021<00`0C4`034`0301<C00<C0P3o4chC00L04a<C

01<000@C00@04`00>Q<500dC00<04a<0KA<204HC000K4`0301<000TC00<04a<00P064`0301<C0?lC

?A<01`0C4a<04`0011<0100C4a<3034C1P0C4`80Ja<304LC000K4`0301<000LC00<04`000Q<00`0C

4`054`0301<C0?lC?1<200@C00<04a<00a<00`0C4`044`<0:1<701TC0P1Y4`80BA<001`C00<04a<0

1Q<3008C0`054`0301<C0?lCB1<00`0C4`074`D06a<9020C00<04a<0I1<304/C000b4`0301<C0?lC

B1<00`0C4`0<4a`0:A<2068C0`1=4`00<Q<00`0C4`3o4dPC0P1C4`80Ga<304lC000b4`0301<C0?lC

B1<00`0C4`1C4`80FQ<4058C000b4`0301<C0?lCB1<00`0C4`1D4`80EQ<405DC000b4`0301<C0?lC

B1<00`0C4`1F4`80Ca<505TC000b4`0301<C0?lCB1<00`0C4`1G4`<0B1<605dC000b4`0301<C0?lC

B1<00`0C4`1I4`<0@1<7068C000b4`0301<C0?lCB1<205`C0`0h4`L0J1<0038C00<04a<0oa=84`03

01<C05hC0`0^4`P0KQ<0038C00<04a<0oa=84`0301<C060C1@0S4`P0MA<0038C00<04a<0oa=84`03

01<C06@C1`0D4`X0O1<0038C00<04a<0oa=84`0301<C06XC5@264`00<Q<00`0C4`3o4dPC00<04a<0

oa<64`00:A<500@C00<04a<0oa=84`80oa<74`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`3o4`HC

000[4`0301<C00@C0P3o4dTC00<04a<0oa<64`00:a<00`0C4`3o4olCF1<002/C00<04a<0oa?o4ePC

000Z4`80oa?o4eXC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00LA<40003

4`0000L00Q<00`0C4`024`0401<C4`800a<200@C00<04a<00Q<00`0C4`024`0301<C008C00<04a<0

0Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`03

01<C00X0oa>/4`00LA<300PC00L04a<C01<000LC00<04`0011<01P0C4`0C008C00<04`000Q<00`0C

00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C

00<04`000Q<00`0C00034`0301<C008C00<04a<0XA<20?lC2A<007<C00<04a<010024`0301<C00<C

00<04a<01A<00`0C00034`8011<01P0C4`0C008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000a<00`0C4`024`03

01<C0:8C00<04a<0oa<74`006A<400034`0000H00Q<:008C0P024`<00Q<300<C0P001Q<0000C02LC

0P084`0401<C4`8021<200<C00<04`000Q<200<C00<04`000Q<00`0C00024`0301<0008C00<04`00

0Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00034`03

01<C008C00<04a<0X1<3008C00<04a<0oa<44`006Q<01P0C4`0C008C00<04`0011<01P0C4`0C008C

00<04`001A<00`0C4`024`0501<C4`000Q<0100C01<2034C00D04a<C00094`0301<C008C00<04`00

0Q<00`0C4`024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`03

01<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000a<00`0C4`024`0301<C00<C00<04a<0

VA<0200C4`0C01<0oa<54`006Q<01P0C4`0C00@C00<04a<00Q<00`0C4`024`0301<C008C00<04a<0

0a<00`0C4`024`0501<C4`000Q<0100C01<2030C0P034`<021<200<C0P024`<00a<00`0C4`024`03

01<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<0

0Q<00`0C4`024`0401<C4`800a<200@C00<04a<0VQ<0200C4`0C01<0oa<54`006Q<01@0C4`0C0080

0a<200<C00<04a<00Q<200<C00<04a<00a<00`0C4`024`0501<C4`000Q<01P0C000C0?lC;a<30004

4`0C0?lC1A<001XC00H04a<04`024`0301<0008C00<04`0011<03P0C4`0C01<04`0C01<00Q<01@0C

4a<0008C00H04`004`3o4c<C00<04`00oa<54`006A<400034`0000/00Q<500054`0001<01@0011<0

00034`8000@C000C0P3o4c@C00<04a<0oa<44`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC

003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.77084, -14.119, 0.0242408, 0.16996}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -57 0 ]

[.5 .63053 57 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -118 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(16.2549999999999883`) show

173.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .37813 m

.02499 .37814 L

.02606 .37815 L

.02729 .37816 L

.02846 .37818 L

.03053 .37823 L

.03279 .3783 L

.03527 .3784 L

.0379 .37854 L

.04262 .37885 L

.05205 .37974 L

.06245 .38111 L

.07293 .38289 L

.0842 .38522 L

.10458 .39037 L

.14581 .40327 L

.18551 .41605 L

.20554 .42152 L

.22371 .42545 L

.23384 .42712 L

.24338 .42831 L

.24863 .42879 L

.25345 .42913 L

.25598 .42926 L

.25875 .42938 L

.26015 .42942 L

.26165 .42946 L

.26237 .42947 L

.26306 .42948 L

.26435 .4295 L

.26549 .42951 L

.26672 .42951 L

.26788 .4295 L

.26894 .42949 L

.27012 .42948 L

.27141 .42945 L

.27275 .42941 L

.27401 .42937 L

.2766 .42926 L

.27896 .42914 L

.28426 .42876 L

.28881 .42834 L

.29374 .42777 L

.30268 .42647 L

.32256 .42242 L

.3436 .41662 L

.38149 .40365 L

.42183 .38914 L

.46065 .37755 L

.47078 .37519 L

Mistroke

.48183 .37298 L

.49238 .37122 L

.50193 .36994 L

.51208 .36887 L

.52164 .36814 L

.5269 .36784 L

.53173 .36762 L

.53703 .36745 L

.5397 .36739 L

.54263 .36733 L

.54515 .3673 L

.54657 .36729 L

.54788 .36728 L

.54903 .36727 L

.5503 .36727 L

.55162 .36727 L

.55286 .36727 L

.554 .36727 L

.5552 .36728 L

.55622 .36728 L

.55734 .36729 L

.55985 .36732 L

.56217 .36734 L

.56748 .36743 L

.5723 .36753 L

.5831 .3678 L

.59245 .36804 L

.60232 .36825 L

.60749 .36833 L

.61042 .36837 L

.61183 .36838 L

.61316 .36839 L

.61436 .3684 L

.61568 .36841 L

.61687 .36841 L

.61797 .36841 L

.61916 .36841 L

.62047 .3684 L

.62113 .3684 L

.62185 .3684 L

.62314 .36839 L

.62439 .36838 L

.62553 .36836 L

.62808 .36833 L

.63045 .36828 L

.63269 .36823 L

.63771 .36807 L

.64315 .36783 L

.64848 .36754 L

.65412 .36715 L

Mistroke

.66424 .36624 L

.67366 .36515 L

.68379 .36369 L

.7021 .36034 L

.74334 .34982 L

.78307 .33744 L

.82128 .3259 L

.84262 .32043 L

.86195 .31638 L

.87164 .3147 L

.88211 .31316 L

.89193 .31197 L

.9011 .31107 L

.91061 .31034 L

.91608 .31001 L

.92105 .30976 L

.92593 .30956 L

.93122 .30938 L

.93682 .30924 L

.94212 .30915 L

.94618 .30909 L

.94998 .30906 L

.95216 .30904 L

.95415 .30903 L

.95634 .30902 L

.95744 .30902 L

.95865 .30902 L

.95983 .30902 L

.96095 .30901 L

.96195 .30901 L

.96304 .30901 L

.96423 .30901 L

.96549 .30901 L

.96656 .30901 L

.96774 .30901 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.50097 .58429 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4gdC00<04a<0oa<64`00oa=m4`0301<C0?lC1Q<002TC1@3o4dlC0P3o4`LC

000[4`0301<C0?lCCa<00`0C4`1^4`d0RQ<002DC0`034`0301<C00@C0P3o4dTC00<04a<0IQ<800`C

3@1n4`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`1Q4`D081<807LC000[4`0301<C00@C00<04a<0

oa=84`0301<C05hC100/4`L0L1<002XC0P064`0301<C0?lCB1<00`0C4`1L4`<0=A<706XC000b4`03

01<C0?lCB1<205/C0P0o4`H0I1<0038C00<04a<0oa=84`0301<C05PC0P164`H0Ga<0038C00<04a<0

oa=84`0301<C05HC0P1>4`D0FQ<0038C00<04a<0oa=84`0301<C05DC0P1C4`D0EQ<0038C00<04a<0

oa=84`0301<C05@C00<04a<0Ea<5058C000b4`0301<C0?lCB1<205<C0P1N4`<0D1<0038C00<04a<0

oa=84`0301<C00lC5P0/4`80HA<404dC000b4`0301<C0?lCB1<00`0C4`0:4`D05Q<9028C0P1U4`<0

Ba<0038C00<04a<0oa=84`0301<C00DC1@0S4`L06a<206PC0`194`00<Q<00`0C4`3o4c/C1@024`03

01<C00<C00<04a<00a<202lC1P0D4`80Ja<204PC000b4`0301<C0?lC?A<01`0C4a<04`0011<00`0C

4`0303HC1P0>4`80KA<304HC000b4`0301<C0?lC=a<300<C00L04a<C01<000@C0`0n4`H02A<00`0C

4`1^4`80AA<0038C00<04a<0oa<m4`0701<C4`0C00034`80AA<500@C00<04a<0L1<204@C000L4`03

01<C008C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0oa<m4`0701<C4`0C00024`0301<004XC

1@1d4`80@Q<001/C00<04`0021<01`0C4a<04`001A<00`0C4`3o4c`C0P044`0401<0008C00<04a<0

Ba<6074C0P114`005Q<3008C00<04`0021<00`0C4`034`0301<C00<C0P3o4d<C0P044`0301<C04XC

00<04a<011<406hC0P104`006a<00`0C00094`0301<C00801Q<00`0C4`3o4d4C00<04a<011<00`0C

4`194`0301<C00TC101[4`0301<C03hC000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C0?lC

@1<00`0C4`054`80BQ<00`0C4`0=4`@0J1<203hC000L4`0301<C00HC0`024`<01A<00`0C4`3o4clC

00<04a<01Q<00`0C4`184`0301<C018C101U4`0301<C03`C000b4`0301<C0?lC?Q<00`0C4`074`03

01<C04PC00<04a<05A<5068C00<04a<0>a<0038C00<04a<0oa<m4`0301<C00PC00<04a<0Aa<00`0C

4`0J4`@0Ga<203`C000b4`0301<C0?lC?1<00`0C4`094`0301<C04HC00<04a<07a<405`C0P0k4`00

<Q<00`0C4`3o4c/C00<04a<02Q<00`0C4`164`0301<C028C1@1I4`0301<C03TC000b4`0301<C0?lC

>Q<00`0C4`0;4`80Aa<00`0C4`0V4`@0Ea<00`0C4`0h4`00<Q<00`0C4`3o4cTC00<04a<031<00`0C

4`154`0301<C02XC101D4`80>A<0038C00<04a<0oa<i4`0301<C00`C00<04a<0AA<00`0C4`0^4`@0

DA<00`0C4`0g4`00<Q<00`0C4`3o4cPC00<04a<03A<00`0C4`144`0301<C03<C0P1?4`80>1<0038C

00<04a<0oa<g4`0301<C00hC00<04a<0A1<00`0C4`0e4`@0C1<203LC000b4`0301<C0?lC=Q<00`0C

4`0?4`0301<C04@C00<04a<0>A<204/C00<04a<0=A<0038C00<04a<0oa<f4`0301<C00lC0P144`03

01<C03`C10174`80=Q<0038C00<04a<0oa<e4`0301<C010C00<04a<0@a<00`0C4`0o4`<0AQ<00`0C

4`0d4`00<Q<00`0C4`3o4cDC00<04a<041<00`0C4`134`0301<C048C0`134`80=A<0024C00<04a<0

0Q<00`0C4`024`0301<C00@C00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`164`<0@A<00`0C

4`0c4`0081<00`0C00074`0301<000DC00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`194`80

?a<00`0C4`0c4`006a<3008C00<04`002A<00`0C4`034`80oa<d4`0301<C018C00<04a<0@Q<00`0C

4`1;4`<0?A<00`0C4`0b4`0081<00`0C00074`801Q<00`0C4`3o4c<C00<04a<04Q<204<C00<04a<0

CQ<203/C00<04a<0<Q<0020C00<04`001a<00`0C4`054`0301<C0?lC<Q<00`0C4`0C4`0301<C044C

00<04a<0DA<303PC00<04a<0<Q<0024C00<04a<01Q<300DC00<04a<0oa<b4`0301<C01<C00<04a<0

@A<00`0C4`1D4`80=a<00`0C4`0a4`00<Q<00`0C4`3o4c4C00<04a<051<00`0C4`114`0301<C05HC

0`0d4`0301<C034C000b4`0301<C0?lC<A<00`0C4`0>4`0301<C00<C00<04a<0@1<00`0C4`1I4`<0

<Q<2038C000b4`0301<C0?lC<1<00`0C4`0>4`0301<000@C00<04a<0@1<00`0C4`1L4`80<A<00`0C

4`0`4`00<Q<00`0C4`3o4c0C00<04a<02A<300@C00<04a<00Q<3040C00<04a<0GQ<202lC00<04a<0

<1<0038C00<04a<0oa<`4`0301<C00hC0P054`0301<C03lC00<04a<0HA<302`C00<04a<0<1<0038C

00<04a<0oa<`4`0301<C00hC00<04a<011<00`0C4`0o4`0301<C06@C00<04a<0:A<00`0C4`0`4`00

<Q<00`0C4`3o4blC00<04a<03a<300@C00<04a<0?a<00`0C4`1U4`<0:1<2034C000b4`0301<C0?lC

;a<00`0C4`0F4`0301<C03lC00<04a<0J1<00`0C4`0V4`0301<C02lC000b4`0301<C0?lC;a<00`0C

4`0F4`0301<C03lC00<04a<0JA<302DC00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC0P104`03

01<C06`C0P0S4`0301<C02lC000b4`0301<C0?lC;a<00`0C4`0F4`0301<C03lC00<04a<0KA<2028C

00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC00<04a<0?a<00`0C4`1_4`8081<00`0C4`0_4`00

<Q<00`0C4`3o4bhC00<04a<05a<00`0C4`0n4`0301<C078C0P0N4`0301<C02lC000L4`0301<C008C

00@04a<C0`034`0301<C00@C00<04a<0oa<^4`0301<C01LC00<04a<0?Q<00`0C4`1d4`8071<00`0C

4`0_4`006a<00`0C00074`0301<C008C00<04`001A<00`0C4`3o4bhC00<04a<05a<203lC00<04a<0

MQ<201XC00<04a<0;a<001HC0`024`0301<000PC00<04a<00a<00`0C4`034`80oa<_4`0301<C01LC

00<04a<0?Q<00`0C4`1h4`0301<C01HC00<04a<0<1<001/C00<04`0021<0100C4a<200HC00<04a<0

oa<]4`0301<C01PC00<04a<0?Q<00`0C4`1i4`805Q<00`0C4`0`4`006a<00`0C00074`0301<0008C

00<04a<01A<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07/C00<04a<04a<00`0C4`0`4`00

71<00`0C4`074`0401<C4`<01A<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07`C00<04a<0

4Q<00`0C4`0`4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0m4`0301<C07hC0P0B4`0301<C030C

000b4`0301<C0?lC;A<00`0C4`0H4`80?Q<00`0C4`204`8041<00`0C4`0`4`00<Q<00`0C4`3o4bdC

00<04a<061<00`0C4`0Q4`D00Q<00`0C4`0B4`0301<C00/C1@000a<0000Q4`D00Q<00`0C4`0O4`D0

0Q<00`0C4`0K4`0401<C4`D000<C00000a<00`0C4`0a4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C

4`0S4`0701<C4`0C000C4`0301<C00dC00L04a<C01<0028C00<04a<00Q<00`0C4`0Q4`0701<C4`0C

000L4`8011<00`0C4`034`0401<C03<C000b4`0301<C02HC00<04a<00Q<0100C4a<302<C00<04a<0

0Q<00`0C4`024`<08Q<00`0C4`024`0401<C4`8091<00`0C4`024`0301<C008C00<04a<09Q<5044C

00<04a<061<00`0C4`0S4`0301<C00<C00<04a<04A<00`0C4`0=4`0701<C4`0C000R4`0301<C008C

00<04a<08A<01`0C4a<04`007Q<01@0C4a<000@C0P024`0301<C034C000b4`0301<C02DC00<04`00

1a<00`0C4`0R4`0301<000TC00<04a<081<00`0C00074`0301<0028C00<04`001a<00`0C000Y4`03

01<C044C00<04a<061<00`0C4`0S4`0401<C4`8051<00`0C4`0=4`0401<C4`808a<00`0C4`034`03

01<C020C00<04a<00Q<00`0C4`0N4`8000<C01<00Q<00`0C00024`0301<C034C000b4`0301<C02DC

00<04`0021<00`0C4`0Q4`0301<000LC100Q4`0301<000LC00<04`008Q<00`0C00074`0301<002TC

00<04a<0@1<00`0C4`0I4`0301<C02<C00D04a<C000E4`0301<C00dC00D04a<C000T4`0701<C4`0C

000R4`0701<C4`0C000Q4`800a<01@0C01<003@C000b4`0301<C02DC00<04`0021<00`0C4`0Q4`03

01<000LC00<04`008Q<00`0C00074`808a<00`0C00084`0301<C02PC00<04a<0@1<00`0C4`0I4`80

8a<200<C0`0C4`0301<C00`C0P044`808A<200<C0`0Q4`8011<00`0C4`0P4`8011<200034`0C03<C

000b4`0301<C02DC00<04`001a<00`0C000R4`0301<000PC0P0R4`0301<000LC00<04a<08Q<00`0C

00074`0301<002TC00<04a<0@1<00`0C4`0I4`0301<C03dC00<04a<0R1<00`0C4`054`0301<C038C

000b4`0301<C02HC00<04a<01a<00`0C4`0R4`0301<C00PC00<04a<08A<00`0C4`074`808a<00`0C

4`074`0301<C02LC0P124`0301<C01TC00<04a<0?A<00`0C4`294`801A<00`0C4`0b4`00<Q<00`0C

4`3o4b`C00<04a<06A<00`0C4`0m4`0301<C08/C00D04a<C000e4`00<Q<00`0C4`3o4b`C00<04a<0

6A<00`0C4`0m4`0301<C08/C00@04a<04a<401lC000b4`0301<C0?lC;1<00`0C4`0I4`0301<C03dC

00<04a<0S1<201@C0`0P4`00<Q<00`0C4`3g4`<0:a?o00XC00<04a<07Q<0038C00<04a<0n1<00`0C

4`0[4`0301<C008C00@04a<021<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC

00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`034`0301<000LC00<04a<01Q<00`0C

4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC

00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<300HC

00<04a<031<2020C000/4nX020d600TC00<04a<0<1<00`0C4`0I4`0301<C02HC00<04a<051<00`0C

4`0@4`0301<C02HC00<04a<09Q<00`0C4`0V4`0401<C03HC000b4`0301<C00PC00<04a<02A<00`0C

4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0C4`084`0301<C00TC

00<04a<02A<00`0C4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0C

4`084a4=1a<00`0C4`0<4`@0<1<00`0C4`0I4`0301<C03dC00<04a<0Ra<01@0C4a<003DC000b4`03

01<C02`C00<04a<0;1<00`0C4`0/4`0301<C02`C00<04a<03Q<63APC00<04a<0@1<00`0C4`0I4`03

01<C03dC00<04a<0RQ<00`0C4`024`0301<C03<C000b4`0301<C0<HC10eQ4`0301<C01TC00<04a<0

?A<00`0C4`294`0301<C00@C00<04a<0<Q<0038C00<04a<0a1<23FDC00<04a<06A<203hC00<04a<0

Qa<200LC00<04a<0<Q<0038C00<04a<0`1<43FLC00<04a<06A<00`0C4`0m4`0301<C08LC00<04a<0

1Q<00`0C4`0b4`00<Q<00`0C4`2k4`D=K1<00`0C4`0H4`0301<C03dC00<04a<0QQ<00`0C4`084`03

01<C034C000b4`0301<C0;LC10ea4`0301<C01PC00<04a<0?A<00`0C4`244`802a<00`0C4`0a4`00

<Q<00`0C4`2e4`8=MA<00`0C4`0H4`0301<C03dC00<04a<0Pa<00`0C4`0;4`0301<C034C000b4`03

01<C0;8C0`eg4`0301<C01PC00<04a<0?A<00`0C4`224`0301<C00`C00<04a<0<A<0038C00<04a<0

/1<23GXC00<04a<061<203hC00<04a<0P1<200lC00<04a<0<A<0038C00<04a<0[1<43G`C00<04a<0

61<00`0C4`0m4`0301<C07lC00<04a<041<00`0C4`0`4`00<Q<00`0C4`2W4`D=P1<00`0C4`0H4`03

01<C03hC00<04a<0O1<201<C00<04a<0<1<0038C00<04a<0Xa<43HDC00<04a<061<00`0C4`0n4`03

01<C07/C0P0D4`0301<C030C000b4`0301<C09dC1Pf94`0301<C01PC00<04a<0?Q<00`0C4`1i4`80

5Q<00`0C4`0`4`00<Q<00`0C4`1e4bP=Sa<00`0C4`0H4`0301<C03hC00<04a<0N1<00`0C4`0F4`03

01<C030C000b4`0301<C06dC20fh4`0301<C01LC0P0o4`0301<C07HC0P0I4`0301<C030C000b4`03

01<C06PC1@g04`0301<C01LC00<04a<0?Q<00`0C4`1d4`8071<00`0C4`0_4`0071<00`0C4`024`04

01<C4`<00a<00`0C4`044`/=GA<33LDC00<04a<05a<00`0C4`0n4`0301<C07<C00<04a<071<00`0C

4`0_4`006a<00`0C00074`0301<C008C00<04`001A<00`0C4`084`D=E1<43LPC00<04a<05a<00`0C

4`0o4`0301<C070C0P0O4`0301<C02lC000K4`0301<000PC00<04a<00a<00`0C4`034`803Q<23DlC

0`g=4`0301<C01HC00<04a<0?a<00`0C4`1]4`<08A<00`0C4`0_4`006a<00`0C00084`0401<C4`80

1Q<00`0C4`0?4`<=BQ<23M0C00<04a<05Q<00`0C4`0o4`0301<C06`C0P0S4`0301<C02lC000K4`03

01<000LC00<04`000Q<00`0C4`054`0301<C018C10e34`<=dQ<00`0C4`0F4`80@1<00`0C4`1Z4`80

9A<00`0C4`0_4`0071<00`0C4`074`0401<C4`<01A<00`0C4`0F4`@=?A<23MDC00<04a<05Q<00`0C

4`0o4`0301<C06PC0P0W4`0301<C02lC000b4`0301<C01XC0`dg4`<=ea<00`0C4`0F4`0301<C03lC

00<04a<0IQ<202TC00<04a<0;a<0038C00<04a<07A<33C4C0`gK4`0301<C01DC00<04a<0?a<00`0C

4`1T4`80:Q<00`0C4`0`4`00<Q<00`0C4`0P4`@=:Q<33MhC00<04a<03a<00`0C4`034`0301<C03lC

00<04a<0HQ<202`C00<04a<0<1<0038C00<04a<091<33B@C0`gQ4`0301<C00hC00<04`0011<00`0C

4`104`0301<C05hC0`0^4`0301<C030C000b4`0301<C02LC1@dL4`<=i1<00`0C4`0@4`0301<C008C

0`104`0301<C05`C0`0`4`0301<C030C000b4`0301<C02`C0`dE4`@=j1<00`0C4`0=4`801A<00`0C

4`104`0301<C05XC0P0b4`80<Q<0038C00<04a<0;a<E3N`C00<04a<03A<00`0C4`044`0301<C044C

00<04a<0Ea<203@C00<04a<0<A<0038C00<04a<0oa<b4`0301<C00`C0`044`0301<C044C00<04a<0

E1<303HC00<04a<0<A<0038C00<04a<0oa<b4`0301<C01<C00<04a<0@A<00`0C4`1B4`<0=a<203<C

000b4`0301<C0?lC<a<00`0C4`0B4`80@Q<00`0C4`1?4`<0>Q<00`0C4`0b4`00<Q<00`0C4`3o4c<C

00<04a<04Q<00`0C4`124`0301<C04`C0`0l4`0301<C038C000b4`0301<C0?lC=1<00`0C4`0A4`03

01<C048C00<04a<0BA<303hC00<04a<0<a<0038C00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C

4`174`<0@1<00`0C4`0c4`008A<00`0C4`024`0301<C008C00<04a<011<00`0C4`3o4cDC00<04a<0

41<00`0C4`124`0301<C04@C0`124`80=A<0020C00<04`001a<00`0C00054`0301<C0?lC=A<00`0C

4`0@4`0301<C04<C00<04a<0@1<304DC00<04a<0=1<0020C00<04`002A<00`0C4`034`80oa<g4`03

01<C00lC0P144`0301<C03dC0`174`80=Q<0020C00<04`001a<200HC00<04a<0oa<f4`0301<C00lC

00<04a<0A1<00`0C4`0i4`<0BQ<00`0C4`0e4`0081<00`0C00074`0301<C00DC00<04a<0oa<g4`03

01<C00hC00<04a<0A1<00`0C4`0f4`@0Ba<203LC000Q4`0301<C00HC0`054`0301<C0?lC>1<00`0C

4`0=4`0301<C04@C00<04a<0<a<304lC00<04a<0=Q<0038C00<04a<0oa<i4`0301<C00`C00<04a<0

AA<00`0C4`0_4`<0DA<00`0C4`0g4`00<Q<00`0C4`3o4cTC00<04a<031<00`0C4`154`0301<C02/C

101C4`80>A<0038C00<04a<0oa<j4`0301<C00/C0P174`0301<C02LC101F4`0301<C03PC000b4`03

01<C0?lC>Q<00`0C4`0;4`0301<C04HC00<04a<08a<505PC0P0j4`00<Q<00`0C4`3o4c/C0P0;4`03

01<C04HC00<04a<081<405/C0P0k4`00<Q<00`0C4`3o4cdC00<04a<021<00`0C4`174`0301<C01/C

101O4`0301<C03XC000b4`0301<C0?lC?Q<00`0C4`074`0301<C04LC0P0H4`D0HA<00`0C4`0k4`00

<Q<00`0C4`3o4chC00<04a<01a<00`0C4`184`0301<C01<C101T4`80?A<0038C00<04a<0oa<o4`03

01<C00HC0P1:4`0301<C00hC101W4`80?Q<0038C00<04a<0oa=04`801Q<00`0C4`194`0301<C00XC

101Z4`80?a<0038C00<04a<0oa=24`0301<C00<C00<04a<0BQ<00`0C4`054`D0K1<2040C000b4`03

01<C0?lC@a<200<C00<04a<0BQ<200034`0000<0L1<2044C000b4`0301<C0?lC>a<5008C00@04a<0

0Q<00`0C4`194`D0La<2048C000L4`0301<C008C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0

oa<m4`0701<C4`0C00024`<0Aa<5008C00<04a<0LA<204<C000K4`0301<000PC00L04a<C01<000DC

00<04a<0oa<m4`0701<C4`0C00044`<0@1<500PC00<04a<0KQ<204DC000K4`0301<000PC00<04a<0

0a<00`0C4`034`80oa<n4`0701<C4`0C00044`0401<003XC1@0=4`0301<C06dC0P164`006a<00`0C

00094`0301<C00801Q<00`0C4`3o4cdC00L04a<C01<000@C00@04a<C0`0a4`H04a<206/C0`174`00

6a<00`0C00074`0301<0008C00<04a<01A<00`0C4`3o4c`C0P044`0301<C00<C00<04a<011<302PC

1`0I4`80JA<204TC000L4`0301<C00HC0`024`<01A<00`0C4`3o4dPC00<04a<01a<501/C2@0P4`03

01<C06@C0`1;4`00<Q<00`0C4`3o4dPC00<04a<031<L02TC0P1R4`<0CA<0038C00<04a<0oa=84`80

Da<205lC0`1?4`00<Q<00`0C4`3o4dPC00<04a<0Da<200@C00<=4a<0Da<4058C000b4`0301<C0?lC

B1<00`0C4`1D4`801Pe@4`@0EA<0038C00<04a<0oa=84`0301<C05DC2@e94`D0FA<0038C00<04a<0

oa=84`0301<C05DC2@e44`H0GA<0038C00<04a<0oa=84`0301<C05DC2@dn4`L0HQ<0038C00<04a<0

oa=84`80EA<;3CLC1`1X4`00<Q<00`0C4`3o4dPC00<04a<0EA<93@<0;Q<806hC000b4`0301<C0?lC

B1<00`0C4`1E4`T=0Q<502<C201e4`00<Q<00`0C4`3o4dPC00<04a<0EA<93@HC1`0D4`X0O1<0038C

00<04a<0oa=84`0301<C05HC1Pd>4aD0QQ<0038C00<04a<0oa=84`0301<C05TC00<=4a<0ZA<002TC

1@044`0301<C0?lCB1<20?lC1a<002/C00<04a<011<00`0C4`3o4dPC00<04a<0oa<64`00:a<00`0C

4`044`80oa=94`0301<C0?lC1Q<002/C00<04a<0oa?o4ePC000[4`0301<C0?lCoa=H4`00:Q<20?lC

oa=J4`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<0074C10000a<000070003

4`0000@C00@04a<C0`034`0301<C008C0`000a<000034`800a<200<C0P034`800a<200<C0P034`80

0a<200<C0P044`0301<C008C00@04a<C0P3o4jhC001a4`<021<01`0C4a<04`001a<00`0C4`024`03

01<000@C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<0

0Q<00`0C4`024`0301<C008C00<04a<00Q<01P0C4`0C008C00<04`0011<00`0C4`2P4`80oa<94`00

La<00`0C4`04008C00L04a<C01<000PC00<04a<00a<00`0C4`04008C0P034`800a<200<C0P034`80

0a<200<C0P034`800a<200<C0P024`0301<0008C00<04`000a<00`0C4`2R4`0301<C0?lC1a<001TC

10000a<00006008C2P024`800Q<3008C0`034`8000HC00004`0W4`8021<0100C4a<200TC00@04a<C

0P034`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C

00<04`000Q<00`0C00024`0301<0008C00<04`000a<00`0C4`024`0301<C00<C00<04a<0Wa<3008C

00<04a<0oa<44`006Q<01P0C4`0C008C00<04`0011<01P0C4`0C008C00<04`001A<00`0C4`024`05

01<C4`000Q<0100C01<2034C00D04a<C00094`0301<0008C00<04a<00a<2008C00<04`000Q<00`0C

00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C

00<04`000Q<00`0C00024`0301<0008C00<04`0011<00`0C4`2I4`0801<C01<04`3o4`DC000J4`06

01<C01<011<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`034`0301<C008C00D04a<C00024`04

01<04`80<1<200@C0P084`0401<C4`<011<0100C4a<200<C0P034`800a<200<C0P034`800a<200<C

0P034`800a<200<C00<04a<00Q<00`0C4`024`0301<C008C00<04a<0VQ<0200C4`0C01<0oa<54`00

6Q<01@0C4`0C00800a<200<C00<04a<00Q<200<C00<04a<00a<00`0C4`024`0501<C4`000Q<01P0C

000C0?lC;a<300044`0C0?lC1A<001XC00H04a<04`024`0301<0008C00<04`0011<03P0C4`0C01<0

4`0C01<00Q<01@0C4a<0008C00H04`004`3o4c<C00<04`00oa<54`006A<400034`0000/00Q<50005

4`0001<01@0011<000034`8000@C000C0P3o4c@C00<04a<0oa<44`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.77084, -14.119, 0.0242408, 0.16996}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -57 0 ]

[.5 .63053 57 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -118 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(16.8150000000000021`) show

173.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .40935 m

.02499 .40935 L

.02606 .40936 L

.02729 .40937 L

.02846 .4094 L

.03053 .40945 L

.03279 .40952 L

.03527 .40963 L

.0379 .40978 L

.04262 .41011 L

.04749 .41056 L

.05205 .41106 L

.06245 .41254 L

.07305 .41449 L

.08274 .41665 L

.10458 .42268 L

.14429 .43678 L

.18248 .45177 L

.2038 .45952 L

.22313 .46553 L

.23281 .46804 L

.24328 .4703 L

.25316 .47197 L

.25792 .47259 L

.26226 .47306 L

.26696 .47345 L

.26954 .47361 L

.27199 .47374 L

.27309 .47378 L

.27425 .47382 L

.27526 .47385 L

.27635 .47387 L

.27751 .47389 L

.2786 .4739 L

.27989 .4739 L

.28108 .47389 L

.28229 .47388 L

.28357 .47386 L

.28479 .47382 L

.28589 .47379 L

.28859 .47367 L

.29115 .47352 L

.29623 .47311 L

.30174 .4725 L

.31121 .47105 L

.32162 .46889 L

.34266 .46281 L

.36211 .45545 L

.383 .44612 L

.42428 .42564 L

Mistroke

.46404 .40708 L

.48411 .39934 L

.50229 .39364 L

.522 .38898 L

.53281 .38711 L

.54298 .38576 L

.55277 .38482 L

.5577 .38446 L

.5631 .38416 L

.56772 .38396 L

.57026 .38387 L

.57267 .38381 L

.5749 .38376 L

.57734 .38372 L

.57841 .38371 L

.57954 .38369 L

.5806 .38368 L

.58159 .38368 L

.58273 .38367 L

.58398 .38367 L

.58519 .38367 L

.58649 .38367 L

.5877 .38367 L

.58884 .38367 L

.58987 .38368 L

.59098 .38369 L

.59354 .38371 L

.59625 .38375 L

.6011 .38382 L

.61939 .38417 L

.62425 .38424 L

.62664 .38427 L

.62885 .38429 L

.63006 .3843 L

.63139 .38431 L

.63273 .38432 L

.63347 .38432 L

.63416 .38432 L

.63537 .38432 L

.63649 .38432 L

.63771 .38432 L

.639 .38431 L

.64015 .38431 L

.64119 .3843 L

.64353 .38427 L

.6457 .38423 L

.64775 .38419 L

.65234 .38406 L

.65733 .38386 L

.66221 .3836 L

Mistroke

.66678 .3833 L

.67718 .38238 L

.68732 .38113 L

.69821 .37939 L

.71936 .37479 L

.73946 .36899 L

.77767 .35498 L

.81834 .33842 L

.85749 .32431 L

.87891 .31836 L

.88873 .31615 L

.89909 .31418 L

.90867 .31268 L

.91918 .31137 L

.92874 .31048 L

.93766 .30987 L

.94262 .30962 L

.94801 .30941 L

.95311 .30925 L

.95554 .3092 L

.95782 .30915 L

.96206 .30909 L

.96431 .30907 L

.96673 .30905 L

.96913 .30903 L

.97034 .30903 L

.97167 .30902 L

.9728 .30902 L

.97401 .30902 L

.97515 .30902 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1 .62823 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.59183 .60323 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4gdC00<04a<0oa<64`00oa=m4`0301<C0?lC1Q<002TC1@3o4dlC0P3o4`LC

000[4`0301<C0?lCCa<00`0C4`1^4`d0RQ<002DC0`034`0301<C00@C0P3o4dTC00<04a<0IQ<800`C

3@1n4`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`1Q4`D081<807LC000[4`0301<C00@C00<04a<0

oa=84`0301<C05hC100/4`L0L1<002XC0P064`0301<C0?lCB1<00`0C4`1L4`<0=A<706XC000b4`03

01<C0?lCB1<205/C0P0o4`H0I1<0038C00<04a<0oa=84`0301<C05PC0P164`H0Ga<0038C00<04a<0

oa=84`0301<C05HC0P1>4`D0FQ<0038C00<04a<0oa=84`0301<C05DC0P1C4`D0EQ<0038C00<04a<0

oa=84`0301<C05@C00<04a<0Ea<5058C000b4`0301<C0?lCB1<205<C0P1N4`<0D1<0038C00<04a<0

oa=84`0301<C00lC5P0/4`80HA<404dC000b4`0301<C0?lCB1<00`0C4`0:4`D05Q<9028C0P1U4`<0

Ba<0038C00<04a<0oa=84`0301<C00DC1@0S4`L06a<206PC0`194`00<Q<00`0C4`3o4c/C1@024`03

01<C00<C00<04a<00a<202lC1P0D4`80Ja<204PC000b4`0301<C0?lC?A<01`0C4a<04`0011<00`0C

4`0303HC1P0>4`80KA<304HC000b4`0301<C0?lC=a<300<C00L04a<C01<000@C0`0n4`H02A<00`0C

4`1^4`80AA<0038C00<04a<0oa<m4`0701<C4`0C00034`80AA<500@C00<04a<0L1<204@C000L4`03

01<C008C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0oa<m4`0701<C4`0C00024`0301<004XC

1@1d4`80@Q<001/C00<04`0021<01`0C4a<04`001A<00`0C4`3o4c`C0P044`0401<0008C00<04a<0

Ba<6074C0P114`005Q<3008C00<04`0021<00`0C4`034`0301<C00<C0P3o4d<C0P044`0301<C04XC

00<04a<011<406hC0P104`006a<00`0C00094`0301<C00801Q<00`0C4`3o4d4C00<04a<011<00`0C

4`194`0301<C00TC101[4`0301<C03hC000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C0?lC

@1<00`0C4`054`80BQ<00`0C4`0=4`@0J1<203hC000L4`0301<C00HC0`024`<01A<00`0C4`3o4clC

00<04a<01Q<00`0C4`184`0301<C018C101U4`0301<C03`C000b4`0301<C0?lC?Q<00`0C4`074`03

01<C04PC00<04a<05A<5068C00<04a<0>a<0038C00<04a<0oa<m4`0301<C00PC00<04a<0Aa<00`0C

4`0J4`@0Ga<203`C000b4`0301<C0?lC?1<00`0C4`094`0301<C04HC00<04a<07a<405`C0P0k4`00

<Q<00`0C4`3o4c/C00<04a<02Q<00`0C4`164`0301<C028C1@1I4`0301<C03TC000b4`0301<C0?lC

>Q<00`0C4`0;4`80Aa<00`0C4`0V4`@0Ea<00`0C4`0h4`00<Q<00`0C4`3o4cTC00<04a<031<00`0C

4`154`0301<C02XC101D4`80>A<0038C00<04a<0oa<i4`0301<C00`C00<04a<0AA<00`0C4`0^4`@0

DA<00`0C4`0g4`00<Q<00`0C4`3o4cPC00<04a<03A<00`0C4`144`0301<C03<C0P1?4`80>1<0038C

00<04a<0oa<g4`0301<C00hC00<04a<0A1<00`0C4`0e4`@0C1<203LC000b4`0301<C0?lC=Q<00`0C

4`0?4`0301<C04@C00<04a<0>A<204/C00<04a<0=A<0038C00<04a<0oa<f4`0301<C00lC0P144`03

01<C03`C10174`80=Q<0038C00<04a<0oa<e4`0301<C010C00<04a<0@a<00`0C4`0o4`<0AQ<00`0C

4`0d4`00<Q<00`0C4`3o4cDC00<04a<041<00`0C4`134`0301<C048C0`134`80=A<0024C00<04a<0

0Q<00`0C4`024`0301<C00@C00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`164`<0@A<00`0C

4`0c4`0081<00`0C00074`0301<000DC00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`194`80

?a<00`0C4`0c4`006a<3008C00<04`002A<00`0C4`034`80oa<d4`0301<C018C00<04a<0@Q<00`0C

4`1;4`<0?A<00`0C4`0b4`0081<00`0C00074`801Q<00`0C4`3o4c<C00<04a<04Q<204<C00<04a<0

CQ<203/C00<04a<0<Q<0020C00<04`001a<00`0C4`054`0301<C0?lC<Q<00`0C4`0C4`0301<C044C

00<04a<0DA<303PC00<04a<0<Q<0024C00<04a<01Q<300DC00<04a<0oa<b4`0301<C01<C00<04a<0

@A<00`0C4`1D4`80=a<00`0C4`0a4`00<Q<00`0C4`3o4c4C00<04a<051<00`0C4`114`0301<C05HC

0`0d4`0301<C034C000b4`0301<C0?lC<A<00`0C4`0>4`0301<C00<C00<04a<0@1<00`0C4`1I4`<0

<Q<2038C000b4`0301<C0?lC<1<00`0C4`0>4`0301<000@C00<04a<0@1<00`0C4`1L4`80<A<00`0C

4`0`4`00<Q<00`0C4`3o4c0C00<04a<02A<300@C00<04a<00Q<3040C00<04a<0GQ<202lC00<04a<0

<1<0038C00<04a<0oa<`4`0301<C00hC0P054`0301<C03lC00<04a<0HA<302`C00<04a<0<1<0038C

00<04a<0oa<`4`0301<C00hC00<04a<011<00`0C4`0o4`0301<C06@C00<04a<0:A<00`0C4`0`4`00

<Q<00`0C4`3o4blC00<04a<03a<300@C00<04a<0?a<00`0C4`1U4`<0:1<2034C000b4`0301<C0?lC

;a<00`0C4`0F4`0301<C03lC00<04a<0J1<00`0C4`0V4`0301<C02lC000b4`0301<C0?lC;a<00`0C

4`0F4`0301<C03lC00<04a<0JA<302DC00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC0P104`03

01<C06`C0P0S4`0301<C02lC000b4`0301<C0?lC;a<00`0C4`0F4`0301<C03lC00<04a<0KA<2028C

00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC00<04a<0?a<00`0C4`1_4`8081<00`0C4`0_4`00

<Q<00`0C4`3o4bhC00<04a<05a<00`0C4`0n4`0301<C078C0P0N4`0301<C02lC000L4`0301<C008C

00@04a<C0`034`0301<C00@C00<04a<0oa<^4`0301<C01LC00<04a<0?Q<00`0C4`1d4`8071<00`0C

4`0_4`006a<00`0C00074`0301<C008C00<04`001A<00`0C4`3o4bhC00<04a<05a<203lC00<04a<0

MQ<201XC00<04a<0;a<001HC0`024`0301<000PC00<04a<00a<00`0C4`034`80oa<_4`0301<C01LC

00<04a<0?Q<00`0C4`1h4`0301<C01HC00<04a<0<1<001/C00<04`0021<0100C4a<200HC00<04a<0

oa<]4`0301<C01PC00<04a<0?Q<00`0C4`1i4`805Q<00`0C4`0`4`006a<00`0C00074`0301<0008C

00<04a<01A<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07/C00<04a<04a<00`0C4`0`4`00

71<00`0C4`074`0401<C4`<01A<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07`C00<04a<0

4Q<00`0C4`0`4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0m4`0301<C07hC0P0B4`0301<C030C

000b4`0301<C0?lC;A<00`0C4`0H4`80?Q<00`0C4`204`8041<00`0C4`0`4`00<Q<00`0C4`3o4bdC

00<04a<061<00`0C4`0Q4`D00Q<00`0C4`0B4`0301<C00/C1@000a<0000Q4`D00Q<00`0C4`0O4`D0

0Q<00`0C4`0K4`0401<C4`D000<C00000a<00`0C4`0a4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C

4`0S4`0701<C4`0C000C4`0301<C00dC00L04a<C01<0028C00<04a<00Q<00`0C4`0Q4`0701<C4`0C

000L4`8011<00`0C4`034`0401<C03<C000b4`0301<C02HC00<04a<00Q<0100C4a<302<C00<04a<0

0Q<00`0C4`024`<08Q<00`0C4`024`0401<C4`8091<00`0C4`024`0301<C008C00<04a<09Q<5044C

00<04a<061<00`0C4`0S4`0301<C00<C00<04a<04A<00`0C4`0=4`0701<C4`0C000R4`0301<C008C

00<04a<08A<01`0C4a<04`007Q<01@0C4a<000@C0P024`0301<C034C000b4`0301<C02DC00<04`00

1a<00`0C4`0R4`0301<000TC00<04a<081<00`0C00074`0301<0028C00<04`001a<00`0C000Y4`03

01<C044C00<04a<061<00`0C4`0S4`0401<C4`8051<00`0C4`0=4`0401<C4`808a<00`0C4`034`03

01<C020C00<04a<00Q<00`0C4`0N4`8000<C01<00Q<00`0C00024`0301<C034C000b4`0301<C02DC

00<04`0021<00`0C4`0Q4`0301<000LC100Q4`0301<000LC00<04`008Q<00`0C00074`0301<002TC

00<04a<0@1<00`0C4`0I4`0301<C02<C00D04a<C000E4`0301<C00dC00D04a<C000T4`0701<C4`0C

000R4`0701<C4`0C000Q4`800a<01@0C01<003@C000b4`0301<C02DC00<04`0021<00`0C4`0Q4`03

01<000LC00<04`008Q<00`0C00074`808a<00`0C00084`0301<C02PC00<04a<0@1<00`0C4`0I4`80

8a<200<C0`0C4`0301<C00`C0P044`808A<200<C0`0Q4`8011<00`0C4`0P4`8011<200034`0C03<C

000b4`0301<C02DC00<04`001a<00`0C000R4`0301<000PC0P0R4`0301<000LC00<04a<08Q<00`0C

00074`0301<002TC00<04a<0@1<00`0C4`0I4`0301<C03dC00<04a<0R1<00`0C4`054`0301<C038C

000b4`0301<C02HC00<04a<01a<00`0C4`0R4`0301<C00PC00<04a<08A<00`0C4`074`808a<00`0C

4`074`0301<C02LC0P124`0301<C01TC00<04a<0?A<00`0C4`294`801A<00`0C4`0b4`00<Q<00`0C

4`3o4b`C00<04a<06A<00`0C4`0m4`0301<C08/C00D04a<C000e4`00<Q<00`0C4`3o4b`C00<04a<0

6A<00`0C4`0m4`0301<C08/C00@04a<04a<401lC000b4`0301<C0?lC;1<00`0C4`0I4`0301<C03dC

00<04a<0S1<201@C0`0P4`00<Q<00`0C4`3g4`<0:a?o00XC00<04a<07Q<0038C00<04a<0n1<00`0C

4`0[4`0301<C008C00@04a<021<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC

00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`034`0301<000LC00<04a<01Q<00`0C

4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC

00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<300HC

00<04a<031<2020C000/4nh010d600TC00<04a<0<1<00`0C4`0I4`0301<C02HC00<04a<051<00`0C

4`0@4`0301<C02HC00<04a<09Q<00`0C4`0V4`0401<C03HC000b4`0301<C00PC00<04a<02A<00`0C

4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0C4`084`0301<C00TC

00<04a<02A<00`0C4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0C

4`084`0301<C00@C3Pd34`0301<C00`C100`4`0301<C01TC00<04a<0?A<00`0C4`2;4`0501<C4`00

=A<0038C00<04a<0;1<00`0C4`0/4`0301<C02`C00<04a<0;1<00`0C4`0F4`D=4A<00`0C4`104`03

01<C01TC00<04a<0?A<00`0C4`2:4`0301<C008C00<04a<0<a<0038C00<04a<0cQ<43ETC00<04a<0

6A<00`0C4`0m4`0301<C08TC00<04a<011<00`0C4`0b4`00<Q<00`0C4`3:4`@=GA<00`0C4`0I4`80

?Q<00`0C4`274`801a<00`0C4`0b4`00<Q<00`0C4`384`8=HA<00`0C4`0I4`0301<C03dC00<04a<0

Qa<00`0C4`064`0301<C038C000b4`0301<C0<DC0`eT4`0301<C01PC00<04a<0?A<00`0C4`264`03

01<C00PC00<04a<0<A<0038C00<04a<0`a<23FLC00<04a<061<00`0C4`0m4`0301<C08@C0P0;4`03

01<C034C000b4`0301<C0<0C0`eY4`0301<C01PC00<04a<0?A<00`0C4`234`0301<C00/C00<04a<0

<A<0038C00<04a<0_Q<23F`C00<04a<061<00`0C4`0m4`0301<C088C00<04a<031<00`0C4`0a4`00

<Q<00`0C4`2k4`<=KQ<00`0C4`0H4`80?Q<00`0C4`204`803a<00`0C4`0a4`00<Q<00`0C4`2i4`8=

LA<00`0C4`0H4`0301<C03dC00<04a<0Oa<00`0C4`0@4`0301<C030C000b4`0301<C0;HC0`ec4`03

01<C01PC00<04a<0?Q<00`0C4`1l4`804a<00`0C4`0`4`00<Q<00`0C4`2c4`<=MQ<00`0C4`0H4`03

01<C03hC00<04a<0Na<201@C00<04a<0<1<0038C00<04a<0[a<43GTC00<04a<061<00`0C4`0n4`03

01<C07TC0P0F4`0301<C030C000b4`0301<C0:dC0Pem4`0301<C01PC00<04a<0?Q<00`0C4`1h4`03

01<C01HC00<04a<0<1<0038C00<04a<0Za<23H0C00<04a<05a<203lC00<04a<0MQ<201TC00<04a<0

<1<0038C00<04a<0Ya<43H8C00<04a<05a<00`0C4`0n4`0301<C07@C0P0L4`0301<C02lC000L4`03

01<C008C00@04a<C0`034`0301<C00@C00<04a<0X1<73HHC00<04a<05a<00`0C4`0n4`0301<C07<C

00<04a<071<00`0C4`0_4`006a<00`0C00074`0301<C008C00<04`001A<00`0C4`1l4b@=SA<00`0C

4`0G4`0301<C03lC00<04a<0L1<201lC00<04a<0;a<001/C00<04`0021<00`0C4`034`0301<C00<C

0P1g4`H=/Q<00`0C4`0F4`0301<C03lC00<04a<0KA<3024C00<04a<0;a<001/C00<04`0021<0100C

4a<200HC00<04a<0LQ<43KPC00<04a<05Q<00`0C4`0o4`0301<C06`C0P0S4`0301<C02lC000K4`03

01<000LC00<04`000Q<00`0C4`054`0301<C070C0Pfl4`0301<C01HC0P104`0301<C06XC0P0U4`03

01<C02lC000L4`0301<C00LC00@04a<C0`054`0301<C06dC0`fn4`0301<C01HC00<04a<0?a<00`0C

4`1X4`809a<00`0C4`0_4`00<Q<00`0C4`1[4`8=`A<00`0C4`0F4`0301<C03lC00<04a<0IQ<202TC

00<04a<0;a<0038C1@eV4`<=a1<00`0C4`0E4`0301<C03lC00<04a<0I1<202XC00<04a<0<1<0038C

00<04a<00Q<63EhC0Pg74`0301<C00lC00<04a<00a<00`0C4`0o4`0301<C068C0P0/4`0301<C030C

000b4`0301<C00PC1@eG4`8=bA<00`0C4`0>4`0301<000@C00<04a<0@1<00`0C4`1N4`<0;Q<00`0C

4`0`4`00<Q<00`0C4`0=4`8=Da<23L/C00<04a<041<00`0C4`024`<0@1<00`0C4`1L4`<0<1<00`0C

4`0`4`00<Q<00`0C4`0?4`<=CA<33LhC00<04a<03A<200DC00<04a<0@1<00`0C4`1J4`80<Q<2038C

000b4`0301<C018C0`e84`8=dA<00`0C4`0=4`0301<C00@C00<04a<0@A<00`0C4`1G4`80=1<00`0C

4`0a4`00<Q<00`0C4`0E4`@=@Q<23M@C00<04a<031<300@C00<04a<0@A<00`0C4`1D4`<0=Q<00`0C

4`0a4`00<Q<00`0C4`0I4`<=?A<23MHC00<04a<04a<00`0C4`114`0301<C058C0`0g4`80<a<0038C

00<04a<071<23CTC0PgI4`0301<C018C0P124`0301<C04lC0`0j4`0301<C038C000b4`0301<C01hC

0`dd4`8=fa<00`0C4`0B4`0301<C048C00<04a<0C1<303`C00<04a<0<Q<0038C00<04a<08A<23C0C

0PgN4`0301<C014C00<04a<0@Q<00`0C4`194`<0?Q<00`0C4`0c4`00<Q<00`0C4`0S4`<=:a<23N0C

00<04a<04A<00`0C4`124`0301<C04LC0`104`0301<C03<C000Q4`0301<C008C00<04a<00Q<00`0C

4`044`0301<C02HC0PdV4`<=ha<00`0C4`0@4`0301<C048C00<04a<0A1<3048C0P0e4`0081<00`0C

00074`0301<000DC00<04a<0:1<43AhC10gV4`0301<C010C00<04a<0@a<00`0C4`104`<0AA<00`0C

4`0d4`0081<00`0C00094`0301<C00<C0P0]4`<=6A<23N/C00<04a<03a<204@C00<04a<0?A<304LC

0P0f4`0081<00`0C00074`801Q<00`0C4`0_4`D=4Q<23NdC00<04a<03a<00`0C4`144`0301<C03TC

0`1:4`0301<C03DC000P4`0301<000LC00<04a<01A<00`0C4`0d4a8=l1<00`0C4`0>4`0301<C04@C

00<04a<0=Q<404/C0P0g4`008A<00`0C4`064`<01A<00`0C4`3o4cPC00<04a<03A<00`0C4`144`03

01<C03<C0`1?4`0301<C03HC000b4`0301<C0?lC>A<00`0C4`0<4`0301<C04DC00<04a<0;a<3054C

00<04a<0=a<0038C00<04a<0oa<i4`0301<C00`C00<04a<0AA<00`0C4`0[4`@0Da<203TC000b4`03

01<C0?lC>Q<00`0C4`0;4`80Aa<00`0C4`0W4`@0EQ<00`0C4`0h4`00<Q<00`0C4`3o4cXC00<04a<0

2a<00`0C4`164`0301<C02<C1@1H4`80>Q<0038C00<04a<0oa<k4`802a<00`0C4`164`0301<C020C

101K4`80>a<0038C00<04a<0oa<m4`0301<C00PC00<04a<0Aa<00`0C4`0K4`@0Ga<00`0C4`0j4`00

<Q<00`0C4`3o4chC00<04a<01a<00`0C4`174`8061<5064C00<04a<0>a<0038C00<04a<0oa<n4`03

01<C00LC00<04a<0B1<00`0C4`0C4`@0I1<203dC000b4`0301<C0?lC?a<00`0C4`064`80BQ<00`0C

4`0>4`@0Ia<203hC000b4`0301<C0?lC@1<200HC00<04a<0BA<00`0C4`0:4`@0JQ<203lC000b4`03

01<C0?lC@Q<00`0C4`034`0301<C04XC00<04a<01A<506`C0P104`00<Q<00`0C4`3o4d<C0P034`03

01<C04XC0P000a<00003070C0P114`00<Q<00`0C4`3o4c/C1@024`0401<C008C00<04a<0BA<507<C

0P124`0071<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`044`0301<C0?lC?A<01`0C4a<04`00

0Q<304LC1@024`0301<C074C0P134`006a<00`0C00084`0701<C4`0C00054`0301<C0?lC?A<01`0C

4a<04`0011<3040C1@084`0301<C06hC0P154`006a<00`0C00084`0301<C00<C00<04a<00a<20?lC

?Q<01`0C4a<04`0011<0100C000j4`D03A<00`0C4`1]4`80AQ<001/C00<04`002A<00`0C4`0200HC

00<04a<0oa<m4`0701<C4`0C00044`0401<C4`<0<A<601<C0P1[4`<0Aa<001/C00<04`001a<00`0C

00024`0301<C00DC00<04a<0oa<l4`8011<00`0C4`034`0301<C00@C0`0X4`L06A<206TC0P194`00

71<00`0C4`064`<00Q<300DC00<04a<0oa=84`0301<C00LC1@0K4`T081<00`0C4`1T4`<0Ba<0038C

00<04a<0oa=84`0301<C00`C700Y4`80HQ<304dC000b4`0301<C0?lCB1<205<C0P1O4`<0Ca<0038C

00<04a<0oa=84`0301<C05<C0P1J4`@0DQ<0038C00<04a<0oa=84`0301<C05@C0P1F4`@0EA<0038C

00<04a<0oa=84`0301<C05HC0P1?4`D0FA<0038C00<04a<0oa=84`0301<C05LC0`184`H0GA<0038C

00<04a<0oa=84`0301<C05TC0`104`L0HQ<0038C00<04a<0oa=84`80G1<301<C00<=4a<08Q<706PC

000b4`0301<C0?lCB1<00`0C4`1N4`<03A<63A/C201^4`00<Q<00`0C4`3o4dPC00<04a<0H1<500PC

2@dB4`P0MA<0038C00<04a<0oa=84`0301<C06@C1`024`T=2A<:07`C000b4`0301<C0?lCB1<00`0C

4`1Z4`<02@d908HC000b4`0301<C0?lCB1<00`0C4`1/4`/=SQ<002TC1@044`0301<C0?lCB1<206hC

2@f?4`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`1]4`T=Sa<002/C00<04a<011<20?lCBA<00`0C

4`1]4`T=Sa<002/C00<04a<0oa?04`H=TA<002/C00<04a<0oa?34`033A<C094C000Z4`80oa?o4eXC

003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00LA<400034`0000L000<C0000

11<00`0C4`024`0301<C00D00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C

00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00@04a<C0`000a<0

00030?lC[1<0074C0`084`0701<C4`0C00074`0301<000<C00L04a<C01<0008C00<04`000Q<00`0C

00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C

00<04`000Q<00`0C00024`0301<C00<C00<04a<0XA<20?lC2A<007<C00<04a<010024`0701<C4`0C

00074`0301<000<C00<04a<00a<01P0C4`0C008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000a<00`0C4`024`03

01<C0:8C00<04a<0oa<74`006A<400034`0000H00Q<:008C0P024`<00Q<300<C0P001Q<0000C02LC

0P084`0401<C4`802A<00`0C4`024`0401<C4`800a<00`0C00024`0301<0008C00<04`000Q<00`0C

00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<000<C

00<04a<00Q<00`0C4`2P4`<00Q<00`0C4`3o4`@C000J4`0601<C01<00Q<00`0C00044`0601<C01<0

0Q<00`0C00054`0301<C008C00D04a<C00024`0401<04`80<A<01@0C4a<000TC00<04`000a<01@0C

4a<000@C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<000<C00<04a<00a<00`0C4`2I4`08

01<C01<04`3o4`DC000J4`0601<C01<011<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`034`03

01<C008C00D04a<C00024`0401<04`80<1<200@C0P084`0401<C4`800a<300<C00<04a<00Q<00`0C

4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C

00<04a<00Q<00`0C4`024`0401<C4`8011<00`0C4`2J4`0801<C01<04`3o4`DC000J4`0501<C01<0

0P034`800a<00`0C4`024`800a<00`0C4`034`0301<C008C00D04a<C00024`0601<001<0oa<_4`<0

00@C01<0oa<54`006Q<01P0C4`0C008C00<04`000Q<00`0C00044`0>01<C01<04`0C01<04`024`05

01<C4`000Q<01P0C000C0?lC<a<00`0C003o4`DC000I4`@000<C00002`024`D000DC00004`050004

4`0000<C0P0011<001<20?lC=1<00`0C4`3o4`@C003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olC

QQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC0000\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.77084, -14.119, 0.0242408, 0.16996}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -57 0 ]

[.5 .63053 57 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -118 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(17.2549999999999892`) show

173.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .42895 m

.02499 .42895 L

.02606 .42896 L

.02729 .42898 L

.02846 .429 L

.03053 .42905 L

.03279 .42912 L

.03527 .42923 L

.0379 .42938 L

.04262 .42971 L

.04749 .43015 L

.05205 .43065 L

.06245 .43211 L

.07305 .43405 L

.08274 .4362 L

.10458 .44225 L

.14429 .45667 L

.18248 .47253 L

.2038 .48106 L

.22313 .48795 L

.23281 .49095 L

.24328 .49378 L

.25309 .49597 L

.26226 .49759 L

.26723 .49827 L

.27176 .49878 L

.2768 .4992 L

.27957 .49937 L

.28082 .49944 L

.2822 .49949 L

.28342 .49953 L

.28474 .49957 L

.28546 .49958 L

.28613 .49959 L

.28744 .4996 L

.28856 .49961 L

.2898 .4996 L

.29109 .49958 L

.29229 .49956 L

.29372 .49952 L

.29507 .49947 L

.29759 .49934 L

.30031 .49916 L

.30326 .49891 L

.30815 .49839 L

.31273 .49775 L

.32314 .49584 L

.33328 .49333 L

.34418 .48997 L

.38546 .47187 L

Mistroke

.42522 .44931 L

.46346 .42715 L

.48482 .41612 L

.50416 .40757 L

.52435 .40042 L

.54334 .39547 L

.55313 .39359 L

.56346 .39206 L

.57228 .39111 L

.57728 .3907 L

.58194 .39039 L

.58697 .39014 L

.5898 .39004 L

.59242 .38996 L

.59471 .3899 L

.59723 .38985 L

.5985 .38984 L

.59987 .38982 L

.60116 .38981 L

.60234 .3898 L

.60342 .3898 L

.60458 .3898 L

.60567 .3898 L

.60666 .3898 L

.60783 .3898 L

.60909 .38981 L

.61029 .38982 L

.61139 .38983 L

.61601 .38989 L

.6209 .38997 L

.63109 .39017 L

.6361 .39027 L

.64074 .39035 L

.64494 .39041 L

.64706 .39043 L

.64827 .39044 L

.64941 .39044 L

.65056 .39045 L

.65178 .39045 L

.65281 .39045 L

.65395 .39045 L

.65517 .39045 L

.65648 .39044 L

.65772 .39043 L

.65884 .39042 L

.66134 .39038 L

.66365 .39033 L

.66618 .39027 L

.66886 .39018 L

.67337 .38999 L

Mistroke

.67833 .38971 L

.68353 .38933 L

.68913 .38883 L

.69924 .38762 L

.70935 .38601 L

.72039 .38379 L

.74048 .37845 L

.78115 .36324 L

.8203 .34557 L

.8619 .32799 L

.88278 .32095 L

.90198 .31593 L

.92074 .31245 L

.93019 .31122 L

.93551 .31066 L

.94055 .31022 L

.94487 .30991 L

.94956 .30963 L

.95346 .30944 L

.95776 .30928 L

.9624 .30916 L

.96495 .30911 L

.96733 .30907 L

.96842 .30906 L

.96956 .30905 L

.97054 .30904 L

.9716 .30903 L

.97273 .30902 L

.97379 .30902 L

.97505 .30902 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1 .62453 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.66322 .59953 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4gdC00<04a<0oa<64`00oa=m4`0301<C0?lC1Q<002TC1@3o4dlC0P3o4`LC

000[4`0301<C0?lCCa<00`0C4`1^4`d0RQ<002DC0`034`0301<C00@C0P3o4dTC00<04a<0IQ<800`C

3@1n4`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`1Q4`D081<807LC000[4`0301<C00@C00<04a<0

oa=84`0301<C05hC100/4`L0L1<002XC0P064`0301<C0?lCB1<00`0C4`1L4`<0=A<706XC000b4`03

01<C0?lCB1<205/C0P0o4`H0I1<0038C00<04a<0oa=84`0301<C05PC0P164`H0Ga<0038C00<04a<0

oa=84`0301<C05HC0P1>4`D0FQ<0038C00<04a<0oa=84`0301<C05DC0P1C4`D0EQ<0038C00<04a<0

oa=84`0301<C05@C00<04a<0Ea<5058C000b4`0301<C0?lCB1<205<C0P1N4`<0D1<0038C00<04a<0

oa=84`0301<C00lC5P0/4`80HA<404dC000b4`0301<C0?lCB1<00`0C4`0:4`D05Q<9028C0P1U4`<0

Ba<0038C00<04a<0oa=84`0301<C00DC1@0S4`L06a<206PC0`194`00<Q<00`0C4`3o4c/C1@024`03

01<C00<C00<04a<00a<202lC1P0D4`80Ja<204PC000b4`0301<C0?lC?A<01`0C4a<04`0011<00`0C

4`0303HC1P0>4`80KA<304HC000b4`0301<C0?lC=a<300<C00L04a<C01<000@C0`0n4`H02A<00`0C

4`1^4`80AA<0038C00<04a<0oa<m4`0701<C4`0C00034`80AA<500@C00<04a<0L1<204@C000L4`03

01<C008C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0oa<m4`0701<C4`0C00024`0301<004XC

1@1d4`80@Q<001/C00<04`0021<01`0C4a<04`001A<00`0C4`3o4c`C0P044`0401<0008C00<04a<0

Ba<6074C0P114`005Q<3008C00<04`0021<00`0C4`034`0301<C00<C0P3o4d<C0P044`0301<C04XC

00<04a<011<406hC0P104`006a<00`0C00094`0301<C00801Q<00`0C4`3o4d4C00<04a<011<00`0C

4`194`0301<C00TC101[4`0301<C03hC000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C0?lC

@1<00`0C4`054`80BQ<00`0C4`0=4`@0J1<203hC000L4`0301<C00HC0`024`<01A<00`0C4`3o4clC

00<04a<01Q<00`0C4`184`0301<C018C101U4`0301<C03`C000b4`0301<C0?lC?Q<00`0C4`074`03

01<C04PC00<04a<05A<5068C00<04a<0>a<0038C00<04a<0oa<m4`0301<C00PC00<04a<0Aa<00`0C

4`0J4`@0Ga<203`C000b4`0301<C0?lC?1<00`0C4`094`0301<C04HC00<04a<07a<405`C0P0k4`00

<Q<00`0C4`3o4c/C00<04a<02Q<00`0C4`164`0301<C028C1@1I4`0301<C03TC000b4`0301<C0?lC

>Q<00`0C4`0;4`80Aa<00`0C4`0V4`@0Ea<00`0C4`0h4`00<Q<00`0C4`3o4cTC00<04a<031<00`0C

4`154`0301<C02XC101D4`80>A<0038C00<04a<0oa<i4`0301<C00`C00<04a<0AA<00`0C4`0^4`@0

DA<00`0C4`0g4`00<Q<00`0C4`3o4cPC00<04a<03A<00`0C4`144`0301<C03<C0P1?4`80>1<0038C

00<04a<0oa<g4`0301<C00hC00<04a<0A1<00`0C4`0e4`@0C1<203LC000b4`0301<C0?lC=Q<00`0C

4`0?4`0301<C04@C00<04a<0>A<204/C00<04a<0=A<0038C00<04a<0oa<f4`0301<C00lC0P144`03

01<C03`C10174`80=Q<0038C00<04a<0oa<e4`0301<C010C00<04a<0@a<00`0C4`0o4`<0AQ<00`0C

4`0d4`00<Q<00`0C4`3o4cDC00<04a<041<00`0C4`134`0301<C048C0`134`80=A<0024C00<04a<0

0Q<00`0C4`024`0301<C00@C00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`164`<0@A<00`0C

4`0c4`0081<00`0C00074`0301<000DC00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`194`80

?a<00`0C4`0c4`006a<3008C00<04`002A<00`0C4`034`80oa<d4`0301<C018C00<04a<0@Q<00`0C

4`1;4`<0?A<00`0C4`0b4`0081<00`0C00074`801Q<00`0C4`3o4c<C00<04a<04Q<204<C00<04a<0

CQ<203/C00<04a<0<Q<0020C00<04`001a<00`0C4`054`0301<C0?lC<Q<00`0C4`0C4`0301<C044C

00<04a<0DA<303PC00<04a<0<Q<0024C00<04a<01Q<300DC00<04a<0oa<b4`0301<C01<C00<04a<0

@A<00`0C4`1D4`80=a<00`0C4`0a4`00<Q<00`0C4`3o4c4C00<04a<051<00`0C4`114`0301<C05HC

0`0d4`0301<C034C000b4`0301<C0?lC<A<00`0C4`0>4`0301<C00<C00<04a<0@1<00`0C4`1I4`<0

<Q<2038C000b4`0301<C0?lC<1<00`0C4`0>4`0301<000@C00<04a<0@1<00`0C4`1L4`80<A<00`0C

4`0`4`00<Q<00`0C4`3o4c0C00<04a<02A<300@C00<04a<00Q<3040C00<04a<0GQ<202lC00<04a<0

<1<0038C00<04a<0oa<`4`0301<C00hC0P054`0301<C03lC00<04a<0HA<302`C00<04a<0<1<0038C

00<04a<0oa<`4`0301<C00hC00<04a<011<00`0C4`0o4`0301<C06@C00<04a<0:A<00`0C4`0`4`00

<Q<00`0C4`3o4blC00<04a<03a<300@C00<04a<0?a<00`0C4`1U4`<0:1<2034C000b4`0301<C0?lC

;a<00`0C4`0F4`0301<C03lC00<04a<0J1<00`0C4`0V4`0301<C02lC000b4`0301<C0?lC;a<00`0C

4`0F4`0301<C03lC00<04a<0JA<302DC00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC0P104`03

01<C06`C0P0S4`0301<C02lC000b4`0301<C0?lC;a<00`0C4`0F4`0301<C03lC00<04a<0KA<2028C

00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC00<04a<0?a<00`0C4`1_4`8081<00`0C4`0_4`00

<Q<00`0C4`3o4bhC00<04a<05a<00`0C4`0n4`0301<C078C0P0N4`0301<C02lC000L4`0301<C008C

00@04a<C0`034`0301<C00@C00<04a<0oa<^4`0301<C01LC00<04a<0?Q<00`0C4`1d4`8071<00`0C

4`0_4`006a<00`0C00074`0301<C008C00<04`001A<00`0C4`3o4bhC00<04a<05a<203lC00<04a<0

MQ<201XC00<04a<0;a<001HC0`024`0301<000PC00<04a<00a<00`0C4`034`80oa<_4`0301<C01LC

00<04a<0?Q<00`0C4`1h4`0301<C01HC00<04a<0<1<001/C00<04`0021<0100C4a<200HC00<04a<0

oa<]4`0301<C01PC00<04a<0?Q<00`0C4`1i4`805Q<00`0C4`0`4`006a<00`0C00074`0301<0008C

00<04a<01A<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07/C00<04a<04a<00`0C4`0`4`00

71<00`0C4`074`0401<C4`<01A<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07`C00<04a<0

4Q<00`0C4`0`4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0m4`0301<C07hC0P0B4`0301<C030C

000b4`0301<C0?lC;A<00`0C4`0H4`80?Q<00`0C4`204`8041<00`0C4`0`4`00<Q<00`0C4`3o4bdC

00<04a<061<00`0C4`0Q4`D00Q<00`0C4`0B4`0301<C00/C1@000a<0000Q4`D00Q<00`0C4`0O4`D0

0Q<00`0C4`0K4`0401<C4`D000<C00000a<00`0C4`0a4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C

4`0S4`0701<C4`0C000C4`0301<C00dC00L04a<C01<0028C00<04a<00Q<00`0C4`0Q4`0701<C4`0C

000L4`8011<00`0C4`034`0401<C03<C000b4`0301<C02HC00<04a<00Q<0100C4a<302<C00<04a<0

0Q<00`0C4`024`<08Q<00`0C4`024`0401<C4`8091<00`0C4`024`0301<C008C00<04a<09Q<5044C

00<04a<061<00`0C4`0S4`0301<C00<C00<04a<04A<00`0C4`0=4`0701<C4`0C000R4`0301<C008C

00<04a<08A<01`0C4a<04`007Q<01@0C4a<000@C0P024`0301<C034C000b4`0301<C02DC00<04`00

1a<00`0C4`0R4`0301<000TC00<04a<081<00`0C00074`0301<0028C00<04`001a<00`0C000Y4`03

01<C044C00<04a<061<00`0C4`0S4`0401<C4`8051<00`0C4`0=4`0401<C4`808a<00`0C4`034`03

01<C020C00<04a<00Q<00`0C4`0N4`8000<C01<00Q<00`0C00024`0301<C034C000b4`0301<C02DC

00<04`0021<00`0C4`0Q4`0301<000LC100Q4`0301<000LC00<04`008Q<00`0C00074`0301<002TC

00<04a<0@1<00`0C4`0I4`0301<C02<C00D04a<C000E4`0301<C00dC00D04a<C000T4`0701<C4`0C

000R4`0701<C4`0C000Q4`800a<01@0C01<003@C000b4`0301<C02DC00<04`0021<00`0C4`0Q4`03

01<000LC00<04`008Q<00`0C00074`808a<00`0C00084`0301<C02PC00<04a<0@1<00`0C4`0I4`80

8a<200<C0`0C4`0301<C00`C0P044`808A<200<C0`0Q4`8011<00`0C4`0P4`8011<200034`0C03<C

000b4`0301<C02DC00<04`001a<00`0C000R4`0301<000PC0P0R4`0301<000LC00<04a<08Q<00`0C

00074`0301<002TC00<04a<0@1<00`0C4`0I4`0301<C03dC00<04a<0R1<00`0C4`054`0301<C038C

000b4`0301<C02HC00<04a<01a<00`0C4`0R4`0301<C00PC00<04a<08A<00`0C4`074`808a<00`0C

4`074`0301<C02LC0P124`0301<C01TC00<04a<0?A<00`0C4`294`801A<00`0C4`0b4`00<Q<00`0C

4`3o4b`C00<04a<06A<00`0C4`0m4`0301<C08/C00D04a<C000e4`00<Q<00`0C4`3o4b`C00<04a<0

6A<00`0C4`0m4`0301<C08/C00@04a<04a<401lC000b4`0301<C0?lC;1<00`0C4`0I4`0301<C03dC

00<04a<0S1<201@C0`0P4`00<Q<00`0C4`3g4`<0:a?o00XC00<04a<07Q<0038C00<04a<0n1<00`0C

4`0[4`0301<C008C00@04a<021<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC

00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`034`0301<000LC00<04a<01Q<00`0C

4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC

00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<300HC

00<04a<031<2020C000/4nh010d600TC00<04a<0<1<00`0C4`0I4`0301<C02HC00<04a<051<00`0C

4`0@4`0301<C02HC00<04a<09Q<00`0C4`0V4`0401<C03HC000b4`0301<C00PC00<04a<02A<00`0C

4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0C4`084`0301<C00TC

00<04a<02A<00`0C4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0C

4`084`0301<C00HC3@d24`0301<C00`C100`4`0301<C01TC00<04a<0?A<00`0C4`2;4`0501<C4`00

=A<0038C00<04a<0;1<00`0C4`0/4`0301<C02`C00<04a<0;1<00`0C4`0H4`D=3a<00`0C4`104`03

01<C01TC00<04a<0?A<00`0C4`2:4`0301<C008C00<04a<0<a<0038C00<04a<0d1<43ELC00<04a<0

6A<00`0C4`0m4`0301<C08TC00<04a<011<00`0C4`0b4`00<Q<00`0C4`3>4`8=Fa<00`0C4`0I4`80

?Q<00`0C4`274`801a<00`0C4`0b4`00<Q<00`0C4`3;4`<=GA<00`0C4`0I4`0301<C03dC00<04a<0

Qa<00`0C4`064`0301<C038C000b4`0301<C0<TC0PeQ4`0301<C01PC00<04a<0?A<00`0C4`264`03

01<C00PC00<04a<0<A<0038C00<04a<0aa<23F<C00<04a<061<00`0C4`0m4`0301<C08@C0P0;4`03

01<C034C000b4`0301<C0<DC0PeU4`0301<C01PC00<04a<0?A<00`0C4`234`0301<C00/C00<04a<0

<A<0038C00<04a<0`a<23FLC00<04a<061<00`0C4`0m4`0301<C088C00<04a<031<00`0C4`0a4`00

<Q<00`0C4`304`<=JA<00`0C4`0H4`80?Q<00`0C4`204`803a<00`0C4`0a4`00<Q<00`0C4`2n4`8=

K1<00`0C4`0H4`0301<C03dC00<04a<0Oa<00`0C4`0@4`0301<C030C000b4`0301<C0;`C0Pe^4`03

01<C01PC00<04a<0?Q<00`0C4`1l4`804a<00`0C4`0`4`00<Q<00`0C4`2j4`8=L1<00`0C4`0H4`03

01<C03hC00<04a<0Na<201@C00<04a<0<1<0038C00<04a<0]a<33G8C00<04a<061<00`0C4`0n4`03

01<C07TC0P0F4`0301<C030C000b4`0301<C0;DC0Pee4`0301<C01PC00<04a<0?Q<00`0C4`1h4`03

01<C01HC00<04a<0<1<0038C00<04a<0/Q<33GPC00<04a<05a<203lC00<04a<0MQ<201TC00<04a<0

<1<0038C00<04a<0/1<23G/C00<04a<05a<00`0C4`0n4`0301<C07@C0P0L4`0301<C02lC000L4`03

01<C008C00@04a<C0`034`0301<C00@C00<04a<0[1<43GdC00<04a<05a<00`0C4`0n4`0301<C07<C

00<04a<071<00`0C4`0_4`006a<00`0C00074`0301<C008C00<04`001A<00`0C4`2X4`@=PA<00`0C

4`0G4`0301<C03lC00<04a<0L1<201lC00<04a<0;a<001/C00<04`0021<00`0C4`034`0301<C00<C

0P2:4`T=2a<;3HHC00<04a<05Q<00`0C4`0o4`0301<C06dC0`0Q4`0301<C02lC000K4`0301<000PC

00@04a<C0P064`0301<C07lC2Pd94`/=TA<00`0C4`0F4`0301<C03lC00<04a<0K1<202<C00<04a<0

;a<001/C00<04`001a<00`0C00024`0301<C00DC00<04a<0Na<43JlC00<04a<05Q<2040C00<04a<0

JQ<202DC00<04a<0;a<001`C00<04a<01a<0100C4a<300DC00<04a<0Ma<43K<C00<04a<05Q<00`0C

4`0o4`0301<C06PC0P0W4`0301<C02lC000b4`0301<C07DC0Pfg4`0301<C01HC00<04a<0?a<00`0C

4`1V4`80:A<00`0C4`0_4`00<Q<00`0C4`1c4`8=^Q<00`0C4`0E4`0301<C03lC00<04a<0I1<202XC

00<04a<0<1<0038C00<04a<0LA<23K`C00<04a<03a<00`0C4`034`0301<C03lC00<04a<0HQ<202`C

00<04a<0<1<0038C00<04a<0Ka<23KhC00<04a<03Q<00`0C00044`0301<C040C00<04a<0GQ<302hC

00<04a<0<1<0038C00<04a<0KA<23L0C00<04a<041<00`0C4`024`<0@1<00`0C4`1L4`<0<1<00`0C

4`0`4`00<Q<00`0C4`1[4`8=`a<00`0C4`0=4`801A<00`0C4`104`0301<C05XC0P0b4`80<Q<0038C

1PeV4`8=aA<00`0C4`0=4`0301<C00@C00<04a<0@A<00`0C4`1G4`80=1<00`0C4`0a4`00<Q<00`0C

4`034`L=GA<23LPC00<04a<031<300@C00<04a<0@A<00`0C4`1D4`<0=Q<00`0C4`0a4`00<Q<00`0C

4`0:4`@=Ea<23LXC00<04a<04a<00`0C4`114`0301<C058C0`0g4`80<a<0038C00<04a<03Q<43E4C

0Pg=4`0301<C018C0P124`0301<C04lC0`0j4`0301<C038C000b4`0301<C018C0Pe=4`8=ca<00`0C

4`0B4`0301<C048C00<04a<0C1<303`C00<04a<0<Q<0038C00<04a<051<33DTC00<=4a<0d1<00`0C

4`0A4`0301<C048C00<04a<0BA<303hC00<04a<0<a<0038C00<04a<05a<23DDC0PgC4`0301<C014C

00<04a<0@Q<00`0C4`174`<0@1<00`0C4`0c4`008A<00`0C4`024`0301<C008C00<04a<011<00`0C

4`0I4`<=@1<23MHC00<04a<041<00`0C4`124`0301<C04@C0`124`80=A<0020C00<04`001a<00`0C

00054`0301<C01`C0Pdm4`033A<C0=HC00<04a<041<00`0C4`134`0301<C040C0`154`0301<C03@C

000P4`0301<000TC00<04a<00a<201lC0`dh4`8=fQ<00`0C4`0?4`80A1<00`0C4`0m4`<0Aa<203HC

000P4`0301<000LC0P064`0301<C024C0Pdd4`8=g1<00`0C4`0?4`0301<C04@C00<04a<0>A<304XC

00<04a<0=A<0020C00<04`001a<00`0C4`054`0301<C02<C0`d_4`8=ga<00`0C4`0>4`0301<C04@C

00<04a<0=Q<404/C0P0g4`008A<00`0C4`064`<01A<00`0C4`0V4`8=:a<23N8C00<04a<03A<00`0C

4`144`0301<C03<C0`1?4`0301<C03HC000b4`0301<C02PC0`dU4`<=iA<00`0C4`0<4`0301<C04DC

00<04a<0;a<3054C00<04a<0=a<0038C00<04a<0:a<23B4C0PgX4`0301<C00`C00<04a<0AA<00`0C

4`0[4`@0Da<203TC000b4`0301<C02dC1@dI4`<=ja<00`0C4`0;4`80Aa<00`0C4`0W4`@0EQ<00`0C

4`0h4`00<Q<00`0C4`0b4`8=5A<23NhC00<04a<02a<00`0C4`164`0301<C02<C1@1H4`80>Q<0038C

00<04a<0=1<83@DC20ga4`802a<00`0C4`164`0301<C020C101K4`80>a<0038C00<04a<0?1<53O/C

00<04a<021<00`0C4`174`0301<C01/C101O4`0301<C03XC000b4`0301<C0?lC?Q<00`0C4`074`03

01<C04LC0P0H4`D0HA<00`0C4`0k4`00<Q<00`0C4`3o4chC00<04a<01a<00`0C4`184`0301<C01<C

101T4`80?A<0038C00<04a<0oa<o4`0301<C00HC0P1:4`0301<C00hC101W4`80?Q<0038C00<04a<0

oa=04`801Q<00`0C4`194`0301<C00XC101Z4`80?a<0038C00<04a<0oa=24`0301<C00<C00<04a<0

BQ<00`0C4`054`D0K1<2040C000b4`0301<C0?lC@a<200<C00<04a<0BQ<200034`0000<0L1<2044C

000b4`0301<C0?lC>a<5008C00@04a<00Q<00`0C4`194`D0La<2048C000L4`0301<C008C00<04a<0

0Q<00`0C4`024`0301<C00@C00<04a<0oa<m4`0701<C4`0C00024`<0Aa<5008C00<04a<0LA<204<C

000K4`0301<000PC00L04a<C01<000DC00<04a<0oa<m4`0701<C4`0C00044`<0@1<500PC00<04a<0

KQ<204DC000K4`0301<000PC00<04a<00a<00`0C4`034`80oa<n4`0701<C4`0C00044`0401<003XC

1@0=4`0301<C06dC0P164`006a<00`0C00094`0301<C00801Q<00`0C4`3o4cdC00L04a<C01<000@C

00@04a<C0`0a4`H04a<206/C0`174`006a<00`0C00074`0301<0008C00<04a<01A<00`0C4`3o4c`C

0P044`0301<C00<C00<04a<011<302PC1`0I4`80JA<204TC000L4`0301<C00HC0`024`<01A<00`0C

4`3o4dPC00<04a<01a<501/C2@0P4`0301<C06@C0`1;4`00<Q<00`0C4`3o4dPC00<04a<031<L02TC

0P1R4`<0CA<0038C00<04a<0oa=84`80Da<205lC0`1?4`00<Q<00`0C4`3o4dPC00<04a<0Da<205XC

101B4`00<Q<00`0C4`3o4dPC00<04a<0E1<205HC101E4`00<Q<00`0C4`3o4dPC00<04a<0EQ<204lC

1@1I4`00<Q<00`0C4`3o4dPC00<04a<0Ea<304PC1P1M4`00<Q<00`0C4`3o4dPC00<04a<0FA<302LC

00<=4a<05Q<7068C000b4`0301<C0?lCB1<205`C0`0R4`H=41<706PC000b4`0301<C0?lCB1<00`0C

4`1N4`<07Q<93@LC201^4`00<Q<00`0C4`3o4dPC00<04a<0H1<501XC2@d807DC000b4`0301<C0?lC

B1<00`0C4`1T4`L051<93@0301<C07XC000b4`0301<C0?lCB1<00`0C4`1Z4a@02`el4`00<Q<00`0C

4`3o4dPC00<04a<0Oa<93GdC000Y4`D011<00`0C4`3o4dPC0P204`T=OA<002/C00<04a<011<00`0C

4`3o4dPC00<04a<0Oa<93GdC000[4`0301<C00@C0P3o4dTC00<04a<0P1<63GlC000[4`0301<C0?lC

eA<00`dC4`1o4`00:a<00`0C4`3o4olCF1<002XC0P3o4olCFQ<00?lCoa>64`00oa?o4hHC003o4olC

QQ<00?lCoa>64`00oa?o4hHC001a4`@000<C00001`024`0301<C008C00@04a<C0`034`0301<C008C

0`000a<000034`800a<200<C0P034`800a<200<C0P034`800a<200<C0P044`0401<C4`800a<30?lC

[A<0074C0`084`0301<C008C00<04a<01Q<00`0C4`024`0301<000@C00<04a<00Q<00`0C4`024`03

01<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<0

0Q<01P0C4`0C00@C00@04a<0Y1<20?lC2A<007<C00<04a<010024`0301<C008C00<04a<01a<00`0C

4`034`0301<C00@00Q<200<C0P034`800a<200<C0P034`800a<200<C0P034`800a<2008C00<04`00

0a<200<C00<04a<0XQ<00`0C4`3o4`LC000I4`@000<C00001P024`X00Q<2008C0`024`<00a<20006

4`0001<09a<200PC00<04a<00a<00`0C4`064`0401<C4`800a<00`0C00024`0301<0008C00<04`00

0Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`03

01<000<C00L04a<C01<000<C00<04a<0X1<3008C00<04a<0oa<44`006Q<01P0C4`0C008C00<04`00

11<01P0C4`0C008C00<04`001A<00`0C4`024`0501<C4`000Q<0100C01<2034C00L04a<C01<000LC

00<04`000Q<00`0C4`034`800Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C

00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C

00044`0301<C09TC00P04a<04`0C0?lC1A<001XC00H04a<04`044`0301<C008C00<04a<00Q<00`0C

4`024`0301<C00<C00<04a<00Q<01@0C4a<0008C00@04`0C0P0`4`800a<300PC00@04a<C0`044`04

01<C4`800a<200<C0P034`800a<200<C0P034`800a<200<C0P034`800a<00`0C4`024`800a<00`0C

4`024`0301<C09XC00P04a<04`0C0?lC1A<001XC00D04a<04`0200<C0P034`0301<C008C0P034`03

01<C00<C00<04a<00Q<01@0C4a<0008C00H04`004`3o4blC0`0011<04`3o4`DC000J4`0601<C01<0

0Q<00`0C00024`0301<000@C00h04a<04`0C01<04`0C008C00D04a<C00024`0601<001<0oa<c4`03

01<00?lC1A<001TC10000a<0000;008C1@001A<0000C00D000@C00000a<200044`004`80oa<d4`03

01<C0?lC11<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4olCQQ<00001\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.77084, -14.119, 0.0242408, 0.16996}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -57 0 ]

[.5 .63053 57 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -118 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(17.5350000000000001`) show

173.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .44001 m

.02499 .44001 L

.02606 .44002 L

.02729 .44003 L

.02846 .44005 L

.03053 .4401 L

.03279 .44018 L

.03527 .44028 L

.0379 .44042 L

.04262 .44075 L

.04749 .44118 L

.05205 .44167 L

.06245 .44311 L

.07305 .44501 L

.08274 .44713 L

.10458 .4531 L

.14429 .46746 L

.18248 .48352 L

.2038 .49232 L

.22313 .49956 L

.24351 .5059 L

.25245 .50814 L

.26226 .51015 L

.27162 .51159 L

.27673 .51217 L

.2815 .51257 L

.2842 .51274 L

.28553 .5128 L

.28676 .51285 L

.28785 .51289 L

.28906 .51292 L

.29027 .51295 L

.29155 .51296 L

.29223 .51297 L

.29295 .51297 L

.29423 .51296 L

.29494 .51295 L

.2956 .51294 L

.29633 .51293 L

.29711 .51291 L

.29851 .51286 L

.29984 .51281 L

.30232 .51268 L

.30472 .51251 L

.30695 .51232 L

.31204 .51177 L

.31701 .51108 L

.32234 .51015 L

.33198 .50801 L

.34079 .50554 L

Mistroke

.35981 .49863 L

.38055 .4889 L

.42125 .46507 L

.46043 .44005 L

.48044 .42803 L

.50206 .41649 L

.5212 .40795 L

.53206 .4039 L

.54218 .40068 L

.55264 .39792 L

.56216 .39589 L

.57234 .3942 L

.57763 .39351 L

.58324 .39291 L

.58797 .39251 L

.59318 .39216 L

.59792 .39192 L

.60236 .39176 L

.60491 .3917 L

.60629 .39167 L

.60758 .39165 L

.60878 .39163 L

.60987 .39162 L

.61108 .39161 L

.61237 .3916 L

.61304 .3916 L

.61375 .3916 L

.61503 .3916 L

.61574 .3916 L

.6164 .3916 L

.61713 .3916 L

.61791 .39161 L

.61931 .39162 L

.62064 .39163 L

.62314 .39166 L

.62772 .39174 L

.63277 .39184 L

.64302 .39209 L

.64759 .39219 L

.65251 .39229 L

.65478 .39233 L

.65717 .39236 L

.6592 .39238 L

.66036 .39239 L

.66143 .39239 L

.66271 .3924 L

.66335 .3924 L

.66405 .3924 L

.6653 .3924 L

.66647 .3924 L

Mistroke

.66718 .39239 L

.66785 .39239 L

.66911 .39238 L

.67046 .39236 L

.67194 .39234 L

.67443 .39229 L

.67709 .39221 L

.68187 .39204 L

.68689 .39177 L

.69161 .39145 L

.70045 .39062 L

.71022 .38936 L

.72054 .38758 L

.73902 .38323 L

.75867 .377 L

.77701 .36985 L

.81594 .35198 L

.85732 .3328 L

.87803 .32467 L

.89718 .31857 L

.91578 .31415 L

.92517 .31248 L

.93553 .31107 L

.94046 .31054 L

.94564 .31008 L

.95011 .30976 L

.95489 .30949 L

.9576 .30937 L

.96006 .30927 L

.96256 .3092 L

.96486 .30914 L

.96755 .30908 L

.96897 .30906 L

.97047 .30905 L

.97177 .30903 L

.97299 .30902 L

.97368 .30902 L

.97432 .30902 L

.97506 .30902 L

.97576 .30902 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1 .61878 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.70865 .59378 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4gdC00<04a<0oa<64`00oa=m4`0301<C0?lC1Q<002TC1@3o4dlC0P3o4`LC

000[4`0301<C0?lCCa<00`0C4`1^4`d0RQ<002DC0`034`0301<C00@C0P3o4dTC00<04a<0IQ<800`C

3@1n4`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`1Q4`D081<807LC000[4`0301<C00@C00<04a<0

oa=84`0301<C05hC100/4`L0L1<002XC0P064`0301<C0?lCB1<00`0C4`1L4`<0=A<706XC000b4`03

01<C0?lCB1<205/C0P0o4`H0I1<0038C00<04a<0oa=84`0301<C05PC0P164`H0Ga<0038C00<04a<0

oa=84`0301<C05HC0P1>4`D0FQ<0038C00<04a<0oa=84`0301<C05DC0P1C4`D0EQ<0038C00<04a<0

oa=84`0301<C05@C00<04a<0Ea<5058C000b4`0301<C0?lCB1<205<C0P1N4`<0D1<0038C00<04a<0

oa=84`0301<C00lC5P0/4`80HA<404dC000b4`0301<C0?lCB1<00`0C4`0:4`D05Q<9028C0P1U4`<0

Ba<0038C00<04a<0oa=84`0301<C00DC1@0S4`L06a<206PC0`194`00<Q<00`0C4`3o4c/C1@024`03

01<C00<C00<04a<00a<202lC1P0D4`80Ja<204PC000b4`0301<C0?lC?A<01`0C4a<04`0011<00`0C

4`0303HC1P0>4`80KA<304HC000b4`0301<C0?lC=a<300<C00L04a<C01<000@C0`0n4`H02A<00`0C

4`1^4`80AA<0038C00<04a<0oa<m4`0701<C4`0C00034`80AA<500@C00<04a<0L1<204@C000L4`03

01<C008C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0oa<m4`0701<C4`0C00024`0301<004XC

1@1d4`80@Q<001/C00<04`0021<01`0C4a<04`001A<00`0C4`3o4c`C0P044`0401<0008C00<04a<0

Ba<6074C0P114`005Q<3008C00<04`0021<00`0C4`034`0301<C00<C0P3o4d<C0P044`0301<C04XC

00<04a<011<406hC0P104`006a<00`0C00094`0301<C00801Q<00`0C4`3o4d4C00<04a<011<00`0C

4`194`0301<C00TC101[4`0301<C03hC000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C0?lC

@1<00`0C4`054`80BQ<00`0C4`0=4`@0J1<203hC000L4`0301<C00HC0`024`<01A<00`0C4`3o4clC

00<04a<01Q<00`0C4`184`0301<C018C101U4`0301<C03`C000b4`0301<C0?lC?Q<00`0C4`074`03

01<C04PC00<04a<05A<5068C00<04a<0>a<0038C00<04a<0oa<m4`0301<C00PC00<04a<0Aa<00`0C

4`0J4`@0Ga<203`C000b4`0301<C0?lC?1<00`0C4`094`0301<C04HC00<04a<07a<405`C0P0k4`00

<Q<00`0C4`3o4c/C00<04a<02Q<00`0C4`164`0301<C028C1@1I4`0301<C03TC000b4`0301<C0?lC

>Q<00`0C4`0;4`80Aa<00`0C4`0V4`@0Ea<00`0C4`0h4`00<Q<00`0C4`3o4cTC00<04a<031<00`0C

4`154`0301<C02XC101D4`80>A<0038C00<04a<0oa<i4`0301<C00`C00<04a<0AA<00`0C4`0^4`@0

DA<00`0C4`0g4`00<Q<00`0C4`3o4cPC00<04a<03A<00`0C4`144`0301<C03<C0P1?4`80>1<0038C

00<04a<0oa<g4`0301<C00hC00<04a<0A1<00`0C4`0e4`@0C1<203LC000b4`0301<C0?lC=Q<00`0C

4`0?4`0301<C04@C00<04a<0>A<204/C00<04a<0=A<0038C00<04a<0oa<f4`0301<C00lC0P144`03

01<C03`C10174`80=Q<0038C00<04a<0oa<e4`0301<C010C00<04a<0@a<00`0C4`0o4`<0AQ<00`0C

4`0d4`00<Q<00`0C4`3o4cDC00<04a<041<00`0C4`134`0301<C048C0`134`80=A<0024C00<04a<0

0Q<00`0C4`024`0301<C00@C00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`164`<0@A<00`0C

4`0c4`0081<00`0C00074`0301<000DC00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`194`80

?a<00`0C4`0c4`006a<3008C00<04`002A<00`0C4`034`80oa<d4`0301<C018C00<04a<0@Q<00`0C

4`1;4`<0?A<00`0C4`0b4`0081<00`0C00074`801Q<00`0C4`3o4c<C00<04a<04Q<204<C00<04a<0

CQ<203/C00<04a<0<Q<0020C00<04`001a<00`0C4`054`0301<C0?lC<Q<00`0C4`0C4`0301<C044C

00<04a<0DA<303PC00<04a<0<Q<0024C00<04a<01Q<300DC00<04a<0oa<b4`0301<C01<C00<04a<0

@A<00`0C4`1D4`80=a<00`0C4`0a4`00<Q<00`0C4`3o4c4C00<04a<051<00`0C4`114`0301<C05HC

0`0d4`0301<C034C000b4`0301<C0?lC<A<00`0C4`0>4`0301<C00<C00<04a<0@1<00`0C4`1I4`<0

<Q<2038C000b4`0301<C0?lC<1<00`0C4`0>4`0301<000@C00<04a<0@1<00`0C4`1L4`80<A<00`0C

4`0`4`00<Q<00`0C4`3o4c0C00<04a<02A<300@C00<04a<00Q<3040C00<04a<0GQ<202lC00<04a<0

<1<0038C00<04a<0oa<`4`0301<C00hC0P054`0301<C03lC00<04a<0HA<302`C00<04a<0<1<0038C

00<04a<0oa<`4`0301<C00hC00<04a<011<00`0C4`0o4`0301<C06@C00<04a<0:A<00`0C4`0`4`00

<Q<00`0C4`3o4blC00<04a<03a<300@C00<04a<0?a<00`0C4`1U4`<0:1<2034C000b4`0301<C0?lC

;a<00`0C4`0F4`0301<C03lC00<04a<0J1<00`0C4`0V4`0301<C02lC000b4`0301<C0?lC;a<00`0C

4`0F4`0301<C03lC00<04a<0JA<302DC00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC0P104`03

01<C06`C0P0S4`0301<C02lC000b4`0301<C0?lC;a<00`0C4`0F4`0301<C03lC00<04a<0KA<2028C

00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC00<04a<0?a<00`0C4`1_4`8081<00`0C4`0_4`00

<Q<00`0C4`3o4bhC00<04a<05a<00`0C4`0n4`0301<C078C0P0N4`0301<C02lC000L4`0301<C008C

00@04a<C0`034`0301<C00@C00<04a<0oa<^4`0301<C01LC00<04a<0?Q<00`0C4`1d4`8071<00`0C

4`0_4`006a<00`0C00074`0301<C008C00<04`001A<00`0C4`3o4bhC00<04a<05a<203lC00<04a<0

MQ<201XC00<04a<0;a<001HC0`024`0301<000PC00<04a<00a<00`0C4`034`80oa<_4`0301<C01LC

00<04a<0?Q<00`0C4`1h4`0301<C01HC00<04a<0<1<001/C00<04`0021<0100C4a<200HC00<04a<0

oa<]4`0301<C01PC00<04a<0?Q<00`0C4`1i4`805Q<00`0C4`0`4`006a<00`0C00074`0301<0008C

00<04a<01A<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07/C00<04a<04a<00`0C4`0`4`00

71<00`0C4`074`0401<C4`<01A<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07`C00<04a<0

4Q<00`0C4`0`4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0m4`0301<C07hC0P0B4`0301<C030C

000b4`0301<C0?lC;A<00`0C4`0H4`80?Q<00`0C4`204`8041<00`0C4`0`4`00<Q<00`0C4`3o4bdC

00<04a<061<00`0C4`0Q4`D00Q<00`0C4`0B4`0301<C00/C1@000a<0000Q4`D00Q<00`0C4`0O4`D0

0Q<00`0C4`0K4`0401<C4`D000<C00000a<00`0C4`0a4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C

4`0S4`0701<C4`0C000C4`0301<C00dC00L04a<C01<0028C00<04a<00Q<00`0C4`0Q4`0701<C4`0C

000L4`8011<00`0C4`034`0401<C03<C000b4`0301<C02HC00<04a<00Q<0100C4a<302<C00<04a<0

0Q<00`0C4`024`<08Q<00`0C4`024`0401<C4`8091<00`0C4`024`0301<C008C00<04a<09Q<5044C

00<04a<061<00`0C4`0S4`0301<C00<C00<04a<04A<00`0C4`0=4`0701<C4`0C000R4`0301<C008C

00<04a<08A<01`0C4a<04`007Q<01@0C4a<000@C0P024`0301<C034C000b4`0301<C02DC00<04`00

1a<00`0C4`0R4`0301<000TC00<04a<081<00`0C00074`0301<0028C00<04`001a<00`0C000Y4`03

01<C044C00<04a<061<00`0C4`0S4`0401<C4`8051<00`0C4`0=4`0401<C4`808a<00`0C4`034`03

01<C020C00<04a<00Q<00`0C4`0N4`8000<C01<00Q<00`0C00024`0301<C034C000b4`0301<C02DC

00<04`0021<00`0C4`0Q4`0301<000LC100Q4`0301<000LC00<04`008Q<00`0C00074`0301<002TC

00<04a<0@1<00`0C4`0I4`0301<C02<C00D04a<C000E4`0301<C00dC00D04a<C000T4`0701<C4`0C

000R4`0701<C4`0C000Q4`800a<01@0C01<003@C000b4`0301<C02DC00<04`0021<00`0C4`0Q4`03

01<000LC00<04`008Q<00`0C00074`808a<00`0C00084`0301<C02PC00<04a<0@1<00`0C4`0I4`80

8a<200<C0`0C4`0301<C00`C0P044`808A<200<C0`0Q4`8011<00`0C4`0P4`8011<200034`0C03<C

000b4`0301<C02DC00<04`001a<00`0C000R4`0301<000PC0P0R4`0301<000LC00<04a<08Q<00`0C

00074`0301<002TC00<04a<0@1<00`0C4`0I4`0301<C03dC00<04a<0R1<00`0C4`054`0301<C038C

000b4`0301<C02HC00<04a<01a<00`0C4`0R4`0301<C00PC00<04a<08A<00`0C4`074`808a<00`0C

4`074`0301<C02LC0P124`0301<C01TC00<04a<0?A<00`0C4`294`801A<00`0C4`0b4`00<Q<00`0C

4`3o4b`C00<04a<06A<00`0C4`0m4`0301<C08/C00D04a<C000e4`00<Q<00`0C4`3o4b`C00<04a<0

6A<00`0C4`0m4`0301<C08/C00@04a<04a<401lC000b4`0301<C0?lC;1<00`0C4`0I4`0301<C03dC

00<04a<0S1<201@C0`0P4`00<Q<00`0C4`3g4`<0:a?o00XC00<04a<07Q<0038C00<04a<0n1<00`0C

4`0[4`0301<C008C00@04a<021<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC

00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`034`0301<000LC00<04a<01Q<00`0C

4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC

00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<300HC

00<04a<031<2020C000/4nl00`d600TC00<04a<0<1<00`0C4`0I4`0301<C02HC00<04a<051<00`0C

4`0@4`0301<C02HC00<04a<09Q<00`0C4`0V4`0401<C03HC000b4`0301<C00PC00<04a<02A<00`0C

4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0C4`084`0301<C00TC

00<04a<02A<00`0C4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0C

4`084`0301<C00PC2`d24`0301<C00`C100`4`0301<C01TC00<04a<0?A<00`0C4`2;4`0501<C4`00

=A<0038C00<04a<0;1<00`0C4`0/4`0301<C02`C00<04a<0;1<00`0C4`0K4`@=3A<00`0C4`104`03

01<C01TC00<04a<0?A<00`0C4`2:4`0301<C008C00<04a<0<a<0038C00<04a<0da<43E@C00<04a<0

6A<00`0C4`0m4`0301<C08TC00<04a<011<00`0C4`0b4`00<Q<00`0C4`3?4`@=F1<00`0C4`0I4`80

?Q<00`0C4`274`801a<00`0C4`0b4`00<Q<00`0C4`3=4`8=G1<00`0C4`0I4`0301<C03dC00<04a<0

Qa<00`0C4`064`0301<C038C000b4`0301<C0<XC0`eO4`0301<C01PC00<04a<0?A<00`0C4`264`03

01<C00PC00<04a<0<A<0038C00<04a<0b1<23F8C00<04a<061<00`0C4`0m4`0301<C08@C0P0;4`03

01<C034C000b4`0301<C0<HC0PeT4`0301<C01PC00<04a<0?A<00`0C4`234`0301<C00/C00<04a<0

<A<0038C00<04a<0a1<23FHC00<04a<061<00`0C4`0m4`0301<C088C00<04a<031<00`0C4`0a4`00

<Q<00`0C4`324`8=J1<00`0C4`0H4`80?Q<00`0C4`204`803a<00`0C4`0a4`00<Q<00`0C4`304`8=

JQ<00`0C4`0H4`0301<C03dC00<04a<0Oa<00`0C4`0@4`0301<C030C000b4`0301<C0;hC0Pe/4`03

01<C01PC00<04a<0?Q<00`0C4`1l4`804a<00`0C4`0`4`00<Q<00`0C4`2l4`8=KQ<00`0C4`0H4`03

01<C03hC00<04a<0Na<201@C00<04a<0<1<0038C00<04a<0^Q<23G0C00<04a<061<00`0C4`0n4`03

01<C07TC0P0F4`0301<C030C000b4`0301<C0;PC0Peb4`0301<C01PC00<04a<0?Q<00`0C4`1h4`03

01<C01HC00<04a<0<1<0038C00<04a<0]A<33GDC00<04a<05a<203lC00<04a<0MQ<201TC00<04a<0

<1<0038C00<04a<0/A<43GPC00<04a<05a<00`0C4`0n4`0301<C07@C0P0L4`0301<C02lC000L4`03

01<C008C00@04a<C0`034`0301<C00@C00<04a<0[a<23G`C00<04a<05a<00`0C4`0n4`0301<C07<C

00<04a<071<00`0C4`0_4`006a<00`0C00074`0301<C008C00<04`001A<00`0C4`2/4`<=OQ<00`0C

4`0G4`0301<C03lC00<04a<0L1<201lC00<04a<0;a<001/C00<04`0021<00`0C4`034`0301<C00<C

0P2W4`H=PQ<00`0C4`0F4`0301<C03lC00<04a<0KA<3024C00<04a<0;a<001/C00<04`0021<0100C

4a<200HC00<04a<0QA<Q3HPC00<04a<05Q<00`0C4`0o4`0301<C06`C0P0S4`0301<C02lC000K4`03

01<000LC00<04`000Q<00`0C4`054`0301<C07lC1PfY4`0301<C01HC0P104`0301<C06XC0P0U4`03

01<C02lC000L4`0301<C00LC00@04a<C0`054`0301<C07`C0`f_4`0301<C01HC00<04a<0?a<00`0C

4`1X4`809a<00`0C4`0_4`00<Q<00`0C4`1j4`8=/Q<00`0C4`0F4`0301<C03lC00<04a<0IQ<202TC

00<04a<0;a<0038C00<04a<0Ma<33KDC00<04a<05A<00`0C4`0o4`0301<C06@C0P0Z4`0301<C030C

000b4`0301<C07DC0Pfh4`0301<C00lC00<04a<00a<00`0C4`0o4`0301<C068C0P0/4`0301<C030C

000b4`0301<C07<C0Pfj4`0301<C00hC00<04`0011<00`0C4`104`0301<C05hC0`0^4`0301<C030C

000b4`0301<C074C0Pfl4`0301<C010C00<04a<00Q<3040C00<04a<0G1<3030C00<04a<0<1<0038C

00<04a<0Ka<23KlC00<04a<03A<200DC00<04a<0@1<00`0C4`1J4`80<Q<2038C000b4`0301<C06dC

0Pg14`0301<C00dC00<04a<011<00`0C4`114`0301<C05LC0P0d4`0301<C034C000b4`0301<C06/C

0Pg44`0301<C00`C0`044`0301<C044C00<04a<0E1<303HC00<04a<0<A<0038C00<04a<0JA<23LHC

00<04a<04a<00`0C4`114`0301<C058C0`0g4`80<a<0038C20eS4`033A<C0<LC00<04a<04Q<2048C

00<04a<0Ca<303XC00<04a<0<Q<0038C00<04a<01A<53E`C0Pg:4`0301<C018C00<04a<0@Q<00`0C

4`1<4`<0?1<00`0C4`0b4`00<Q<00`0C4`0:4`@=Ea<00`dC4`3;4`0301<C014C00<04a<0@Q<00`0C

4`194`<0?Q<00`0C4`0c4`00<Q<00`0C4`0>4`@=DA<23LhC00<04a<04A<00`0C4`124`0301<C04LC

0`104`0301<C03<C000Q4`0301<C008C00<04a<00Q<00`0C4`044`0301<C018C0Pe>4`033A<C0<lC

00<04a<041<00`0C4`124`0301<C04@C0`124`80=A<0020C00<04`001a<00`0C00054`0301<C01@C

0`e94`8=dQ<00`0C4`0@4`0301<C04<C00<04a<0@1<304DC00<04a<0=1<0020C00<04`002A<00`0C

4`034`8061<23DHC00<=4a<0da<00`0C4`0?4`80A1<00`0C4`0m4`<0Aa<203HC000P4`0301<000LC

0P064`0301<C01TC0`e14`8=eQ<00`0C4`0?4`0301<C04@C00<04a<0>A<304XC00<04a<0=A<0020C

00<04`001a<00`0C4`054`0301<C01`C0Pdm4`8=fA<00`0C4`0>4`0301<C04@C00<04a<0=Q<404/C

0P0g4`008A<00`0C4`064`<01A<00`0C4`0N4`<=>A<00`dC4`3J4`0301<C00dC00<04a<0A1<00`0C

4`0c4`<0Ca<00`0C4`0f4`00<Q<00`0C4`0Q4`8==A<23MhC00<04a<031<00`0C4`154`0301<C02lC

0`1A4`0301<C03LC000b4`0301<C02<C0`d`4`8=h1<00`0C4`0<4`0301<C04DC00<04a<0:a<405<C

0P0i4`00<Q<00`0C4`0V4`8=;1<23N<C00<04a<02a<204LC00<04a<09a<405HC00<04a<0>1<0038C

00<04a<0:1<33BLC0PgU4`0301<C00/C00<04a<0AQ<00`0C4`0S4`D0F1<203XC000b4`0301<C02/C

0PdR4`<=j1<200/C00<04a<0AQ<00`0C4`0P4`@0Fa<203/C000b4`0301<C02dC10dL4`8=kA<00`0C

4`084`0301<C04LC00<04a<06a<405lC00<04a<0>Q<0038C00<04a<0<A<33ALC0Pg`4`0301<C00LC

00<04a<0Aa<201PC1@1Q4`0301<C03/C000b4`0301<C03@C1@d<4`H=lQ<00`0C4`074`0301<C04PC

00<04a<04a<406@C0P0m4`00<Q<00`0C4`0i4``=nA<00`0C4`064`80BQ<00`0C4`0>4`@0Ia<203hC

000b4`0301<C0?lC@1<200HC00<04a<0BA<00`0C4`0:4`@0JQ<203lC000b4`0301<C0?lC@Q<00`0C

4`034`0301<C04XC00<04a<01A<506`C0P104`00<Q<00`0C4`3o4d<C0P034`0301<C04XC0P000a<0

0003070C0P114`00<Q<00`0C4`3o4c/C1@024`0401<C008C00<04a<0BA<507<C0P124`0071<00`0C

4`024`0301<C008C00<04a<00Q<00`0C4`044`0301<C0?lC?A<01`0C4a<04`000Q<304LC1@024`03

01<C074C0P134`006a<00`0C00084`0701<C4`0C00054`0301<C0?lC?A<01`0C4a<04`0011<3040C

1@084`0301<C06hC0P154`006a<00`0C00084`0301<C00<C00<04a<00a<20?lC?Q<01`0C4a<04`00

11<0100C000j4`D03A<00`0C4`1]4`80AQ<001/C00<04`002A<00`0C4`0200HC00<04a<0oa<m4`07

01<C4`0C00044`0401<C4`<0<A<601<C0P1[4`<0Aa<001/C00<04`001a<00`0C00024`0301<C00DC

00<04a<0oa<l4`8011<00`0C4`034`0301<C00@C0`0X4`L06A<206TC0P194`0071<00`0C4`064`<0

0Q<300DC00<04a<0oa=84`0301<C00LC1@0K4`T081<00`0C4`1T4`<0Ba<0038C00<04a<0oa=84`03

01<C00`C700Y4`80HQ<304dC000b4`0301<C0?lCB1<205<C0P1O4`<0Ca<0038C00<04a<0oa=84`03

01<C05<C0P1J4`@0DQ<0038C00<04a<0oa=84`0301<C05@C0P1F4`@0EA<0038C00<04a<0oa=84`03

01<C05HC0P0f4`033A<C01HC1@1I4`00<Q<00`0C4`3o4dPC00<04a<0Ea<3034C1PdA4`H0GA<0038C

00<04a<0oa=84`0301<C05TC0`0^4`T=2A<7068C000b4`0301<C0?lCB1<205`C0`0/4`T=0a<706PC

000b4`0301<C0?lCB1<00`0C4`1N4`<0:A<93@@0KQ<0038C00<04a<0oa=84`0301<C060C1@0S4`03

00d=00T=LA<0038C00<04a<0oa=84`0301<C06@C1`0D4`X000<C3@d01`eb4`00<Q<00`0C4`3o4dPC

00<04a<0JQ<E00/C2@eb4`00<Q<00`0C4`3o4dPC00<04a<0RQ<93G8C000Y4`D011<00`0C4`3o4dPC

0P2<4`H=M1<002/C00<04a<011<00`0C4`3o4dPC00<04a<0SQ<00`dC4`1d4`00:a<00`0C4`044`80

oa=94`0301<C0?lC1Q<002/C00<04a<0oa?o4ePC000[4`0301<C0?lCoa=H4`00:Q<20?lCoa=J4`00

oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<0074C10000a<00007008C00<04a<0

0Q<00`0C4`024`0401<C4`8011<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C

00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C

4`050?lC[1<0074C0`084`0301<C008C00<04a<01Q<00`0C00044`0601<C01<00Q<00`0C00024`03

01<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0Q<00`0C00024`0301<0008C00<04`000a<00`0C4`2Q4`80oa<94`00La<00`0C4`04008C00<04a<0

0Q<00`0C4`084`0501<C4`001A<01P0C4`0C008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00034`03

01<C0:8C00<04a<0oa<74`006A<400034`0000H00Q<:008C0P024`<00Q<300<C0P001Q<0000C02LC

0P084`0301<C00<C00<04a<01A<200DC00<04a<00P034`0301<0008C00<04`000Q<00`0C00024`03

01<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0Q<00`0C00034`0301<C0:0C0`024`0301<C0?lC11<001XC00H04a<04`024`0301<000@C00H04a<0

4`024`0301<000DC00<04a<00Q<01@0C4a<0008C00@04`0C0P0a4`0701<C4`0C00074`0301<C008C

00<04`000Q<00`0C4`024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C

00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00034`0301<C00<C

00<04a<0VA<0200C4`0C01<0oa<54`006Q<01P0C4`0C00@C00<04a<00Q<00`0C4`024`0301<C008C

00<04a<00a<00`0C4`024`0501<C4`000Q<0100C01<2030C0P034`<01a<300<C00@04a<C0`034`03

01<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<0

0Q<00`0C4`024`0301<C008C00<04a<00Q<0100C4a<200@C00<04a<0VQ<0200C4`0C01<0oa<54`00

6Q<01@0C4`0C00800a<200<C00<04a<00Q<200<C00<04a<00a<00`0C4`024`0501<C4`000Q<01P0C

000C0?lC;a<300044`0C0?lC1A<001XC00H04a<04`024`0301<0008C00<04`0011<03P0C4`0C01<0

4`0C01<00Q<01@0C4a<0008C00H04`004`3o4c<C00<04`00oa<54`006A<400034`0000/00Q<50005

4`0001<01@0011<000034`8000@C000C0P3o4c@C00<04a<0oa<44`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.77084, -14.119, 0.0242408, 0.16996}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -57 0 ]

[.5 .63053 57 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -118 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(17.8150000000000012`) show

173.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .45126 m

.02499 .45127 L

.02606 .45127 L

.02729 .45129 L

.02846 .45131 L

.03053 .45136 L

.03279 .45143 L

.03527 .45153 L

.0379 .45167 L

.04262 .45199 L

.04749 .45241 L

.05205 .45289 L

.06245 .45429 L

.07305 .45615 L

.08274 .45822 L

.10458 .46407 L

.14429 .47822 L

.18248 .49421 L

.22313 .51047 L

.24192 .5166 L

.25181 .51926 L

.26226 .52159 L

.26757 .52255 L

.27341 .52344 L

.27871 .52408 L

.28367 .52452 L

.28628 .52469 L

.28876 .52482 L

.28984 .52486 L

.29098 .5249 L

.29224 .52493 L

.2934 .52496 L

.29463 .52497 L

.29533 .52497 L

.29596 .52497 L

.29713 .52496 L

.29836 .52495 L

.29902 .52493 L

.29972 .52492 L

.30098 .52488 L

.30248 .52482 L

.30384 .52475 L

.30869 .52442 L

.31113 .52419 L

.31382 .52389 L

.32302 .52251 L

.3282 .52149 L

.33377 .52019 L

.34382 .51733 L

.365 .50925 L

Mistroke

.3851 .49925 L

.42334 .47562 L

.46404 .44773 L

.50322 .42317 L

.52324 .4129 L

.54486 .40411 L

.55503 .40087 L

.56576 .39808 L

.57493 .39618 L

.58498 .39459 L

.59023 .39396 L

.59521 .39346 L

.59973 .39311 L

.60452 .39282 L

.607 .3927 L

.60974 .39259 L

.61222 .39252 L

.61455 .39246 L

.61589 .39244 L

.61729 .39242 L

.61849 .3924 L

.6198 .39239 L

.62055 .39239 L

.62122 .39239 L

.622 .39239 L

.62273 .39239 L

.62404 .39239 L

.62477 .39239 L

.62545 .39239 L

.62671 .3924 L

.6279 .39242 L

.63014 .39244 L

.63255 .39248 L

.63517 .39254 L

.64425 .39277 L

.65407 .39305 L

.65928 .39318 L

.66202 .39325 L

.66491 .3933 L

.66744 .39334 L

.66878 .39336 L

.67022 .39337 L

.67154 .39339 L

.67274 .39339 L

.67395 .3934 L

.67509 .3934 L

.67625 .39339 L

.67748 .39339 L

.67852 .39338 L

.67968 .39337 L

Mistroke

.68092 .39335 L

.68225 .39333 L

.68466 .39328 L

.68735 .3932 L

.69028 .39309 L

.69563 .39282 L

.70083 .39246 L

.70566 .39203 L

.71623 .39076 L

.72619 .38911 L

.74481 .3848 L

.7649 .37836 L

.78338 .37098 L

.82288 .3522 L

.86088 .33386 L

.88204 .32512 L

.90132 .31869 L

.9109 .31611 L

.92132 .3138 L

.93115 .31207 L

.94025 .31085 L

.94449 .3104 L

.94906 .31 L

.95302 .30971 L

.95734 .30946 L

.96213 .30925 L

.96474 .30917 L

.96718 .30911 L

.96835 .30909 L

.96946 .30907 L

.97047 .30905 L

.97154 .30904 L

.9727 .30903 L

.97377 .30902 L

.97492 .30902 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.75408 .58668 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4gdC00<04a<0oa<64`00oa=m4`0301<C0?lC1Q<002TC1@3o4dlC0P3o4`LC

000[4`0301<C0?lCCa<00`0C4`1^4`d0RQ<002DC0`034`0301<C00@C0P3o4dTC00<04a<0IQ<800`C

3@1n4`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`1Q4`D081<807LC000[4`0301<C00@C00<04a<0

oa=84`0301<C05hC100/4`L0L1<002XC0P064`0301<C0?lCB1<00`0C4`1L4`<0=A<706XC000b4`03

01<C0?lCB1<205/C0P0o4`H0I1<0038C00<04a<0oa=84`0301<C05PC0P164`H0Ga<0038C00<04a<0

oa=84`0301<C05HC0P1>4`D0FQ<0038C00<04a<0oa=84`0301<C05DC0P1C4`D0EQ<0038C00<04a<0

oa=84`0301<C05@C00<04a<0Ea<5058C000b4`0301<C0?lCB1<205<C0P1N4`<0D1<0038C00<04a<0

oa=84`0301<C00lC5P0/4`80HA<404dC000b4`0301<C0?lCB1<00`0C4`0:4`D05Q<9028C0P1U4`<0

Ba<0038C00<04a<0oa=84`0301<C00DC1@0S4`L06a<206PC0`194`00<Q<00`0C4`3o4c/C1@024`03

01<C00<C00<04a<00a<202lC1P0D4`80Ja<204PC000b4`0301<C0?lC?A<01`0C4a<04`0011<00`0C

4`0303HC1P0>4`80KA<304HC000b4`0301<C0?lC=a<300<C00L04a<C01<000@C0`0n4`H02A<00`0C

4`1^4`80AA<0038C00<04a<0oa<m4`0701<C4`0C00034`80AA<500@C00<04a<0L1<204@C000L4`03

01<C008C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0oa<m4`0701<C4`0C00024`0301<004XC

1@1d4`80@Q<001/C00<04`0021<01`0C4a<04`001A<00`0C4`3o4c`C0P044`0401<0008C00<04a<0

Ba<6074C0P114`005Q<3008C00<04`0021<00`0C4`034`0301<C00<C0P3o4d<C0P044`0301<C04XC

00<04a<011<406hC0P104`006a<00`0C00094`0301<C00801Q<00`0C4`3o4d4C00<04a<011<00`0C

4`194`0301<C00TC101[4`0301<C03hC000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C0?lC

@1<00`0C4`054`80BQ<00`0C4`0=4`@0J1<203hC000L4`0301<C00HC0`024`<01A<00`0C4`3o4clC

00<04a<01Q<00`0C4`184`0301<C018C101U4`0301<C03`C000b4`0301<C0?lC?Q<00`0C4`074`03

01<C04PC00<04a<05A<5068C00<04a<0>a<0038C00<04a<0oa<m4`0301<C00PC00<04a<0Aa<00`0C

4`0J4`@0Ga<203`C000b4`0301<C0?lC?1<00`0C4`094`0301<C04HC00<04a<07a<405`C0P0k4`00

<Q<00`0C4`3o4c/C00<04a<02Q<00`0C4`164`0301<C028C1@1I4`0301<C03TC000b4`0301<C0?lC

>Q<00`0C4`0;4`80Aa<00`0C4`0V4`@0Ea<00`0C4`0h4`00<Q<00`0C4`3o4cTC00<04a<031<00`0C

4`154`0301<C02XC101D4`80>A<0038C00<04a<0oa<i4`0301<C00`C00<04a<0AA<00`0C4`0^4`@0

DA<00`0C4`0g4`00<Q<00`0C4`3o4cPC00<04a<03A<00`0C4`144`0301<C03<C0P1?4`80>1<0038C

00<04a<0oa<g4`0301<C00hC00<04a<0A1<00`0C4`0e4`@0C1<203LC000b4`0301<C0?lC=Q<00`0C

4`0?4`0301<C04@C00<04a<0>A<204/C00<04a<0=A<0038C00<04a<0oa<f4`0301<C00lC0P144`03

01<C03`C10174`80=Q<0038C00<04a<0oa<e4`0301<C010C00<04a<0@a<00`0C4`0o4`<0AQ<00`0C

4`0d4`00<Q<00`0C4`3o4cDC00<04a<041<00`0C4`134`0301<C048C0`134`80=A<0024C00<04a<0

0Q<00`0C4`024`0301<C00@C00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`164`<0@A<00`0C

4`0c4`0081<00`0C00074`0301<000DC00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`194`80

?a<00`0C4`0c4`006a<3008C00<04`002A<00`0C4`034`80oa<d4`0301<C018C00<04a<0@Q<00`0C

4`1;4`<0?A<00`0C4`0b4`0081<00`0C00074`801Q<00`0C4`3o4c<C00<04a<04Q<204<C00<04a<0

CQ<203/C00<04a<0<Q<0020C00<04`001a<00`0C4`054`0301<C0?lC<Q<00`0C4`0C4`0301<C044C

00<04a<0DA<303PC00<04a<0<Q<0024C00<04a<01Q<300DC00<04a<0oa<b4`0301<C01<C00<04a<0

@A<00`0C4`1D4`80=a<00`0C4`0a4`00<Q<00`0C4`3o4c4C00<04a<051<00`0C4`114`0301<C05HC

0`0d4`0301<C034C000b4`0301<C0?lC<A<00`0C4`0>4`0301<C00<C00<04a<0@1<00`0C4`1I4`<0

<Q<2038C000b4`0301<C0?lC<1<00`0C4`0>4`0301<000@C00<04a<0@1<00`0C4`1L4`80<A<00`0C

4`0`4`00<Q<00`0C4`3o4c0C00<04a<02A<300@C00<04a<00Q<3040C00<04a<0GQ<202lC00<04a<0

<1<0038C00<04a<0oa<`4`0301<C00hC0P054`0301<C03lC00<04a<0HA<302`C00<04a<0<1<0038C

00<04a<0oa<`4`0301<C00hC00<04a<011<00`0C4`0o4`0301<C06@C00<04a<0:A<00`0C4`0`4`00

<Q<00`0C4`3o4blC00<04a<03a<300@C00<04a<0?a<00`0C4`1U4`<0:1<2034C000b4`0301<C0?lC

;a<00`0C4`0F4`0301<C03lC00<04a<0J1<00`0C4`0V4`0301<C02lC000b4`0301<C0?lC;a<00`0C

4`0F4`0301<C03lC00<04a<0JA<302DC00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC0P104`03

01<C06`C0P0S4`0301<C02lC000b4`0301<C0?lC;a<00`0C4`0F4`0301<C03lC00<04a<0KA<2028C

00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC00<04a<0?a<00`0C4`1_4`8081<00`0C4`0_4`00

<Q<00`0C4`3o4bhC00<04a<05a<00`0C4`0n4`0301<C078C0P0N4`0301<C02lC000L4`0301<C008C

00@04a<C0`034`0301<C00@C00<04a<0oa<^4`0301<C01LC00<04a<0?Q<00`0C4`1d4`8071<00`0C

4`0_4`006a<00`0C00074`0301<C008C00<04`001A<00`0C4`3o4bhC00<04a<05a<203lC00<04a<0

MQ<201XC00<04a<0;a<001HC0`024`0301<000PC00<04a<00a<00`0C4`034`80oa<_4`0301<C01LC

00<04a<0?Q<00`0C4`1h4`0301<C01HC00<04a<0<1<001/C00<04`0021<0100C4a<200HC00<04a<0

oa<]4`0301<C01PC00<04a<0?Q<00`0C4`1i4`805Q<00`0C4`0`4`006a<00`0C00074`0301<0008C

00<04a<01A<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07/C00<04a<04a<00`0C4`0`4`00

71<00`0C4`074`0401<C4`<01A<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07`C00<04a<0

4Q<00`0C4`0`4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0m4`0301<C07hC0P0B4`0301<C030C

000b4`0301<C0?lC;A<00`0C4`0H4`80?Q<00`0C4`204`8041<00`0C4`0`4`00<Q<00`0C4`3o4bdC

00<04a<061<00`0C4`0Q4`D00Q<00`0C4`0B4`0301<C00/C1@000a<0000Q4`D00Q<00`0C4`0O4`D0

0Q<00`0C4`0K4`0401<C4`D000<C00000a<00`0C4`0a4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C

4`0S4`0701<C4`0C000C4`0301<C00dC00L04a<C01<0028C00<04a<00Q<00`0C4`0Q4`0701<C4`0C

000L4`8011<00`0C4`034`0401<C03<C000b4`0301<C02HC00<04a<00Q<0100C4a<302<C00<04a<0

0Q<00`0C4`024`<08Q<00`0C4`024`0401<C4`8091<00`0C4`024`0301<C008C00<04a<09Q<5044C

00<04a<061<00`0C4`0S4`0301<C00<C00<04a<04A<00`0C4`0=4`0701<C4`0C000R4`0301<C008C

00<04a<08A<01`0C4a<04`007Q<01@0C4a<000@C0P024`0301<C034C000b4`0301<C02DC00<04`00

1a<00`0C4`0R4`0301<000TC00<04a<081<00`0C00074`0301<0028C00<04`001a<00`0C000Y4`03

01<C044C00<04a<061<00`0C4`0S4`0401<C4`8051<00`0C4`0=4`0401<C4`808a<00`0C4`034`03

01<C020C00<04a<00Q<00`0C4`0N4`8000<C01<00Q<00`0C00024`0301<C034C000b4`0301<C02DC

00<04`0021<00`0C4`0Q4`0301<000LC100Q4`0301<000LC00<04`008Q<00`0C00074`0301<002TC

00<04a<0@1<00`0C4`0I4`0301<C02<C00D04a<C000E4`0301<C00dC00D04a<C000T4`0701<C4`0C

000R4`0701<C4`0C000Q4`800a<01@0C01<003@C000b4`0301<C02DC00<04`0021<00`0C4`0Q4`03

01<000LC00<04`008Q<00`0C00074`808a<00`0C00084`0301<C02PC00<04a<0@1<00`0C4`0I4`80

8a<200<C0`0C4`0301<C00`C0P044`808A<200<C0`0Q4`8011<00`0C4`0P4`8011<200034`0C03<C

000b4`0301<C02DC00<04`001a<00`0C000R4`0301<000PC0P0R4`0301<000LC00<04a<08Q<00`0C

00074`0301<002TC00<04a<0@1<00`0C4`0I4`0301<C03dC00<04a<0R1<00`0C4`054`0301<C038C

000b4`0301<C02HC00<04a<01a<00`0C4`0R4`0301<C00PC00<04a<08A<00`0C4`074`808a<00`0C

4`074`0301<C02LC0P124`0301<C01TC00<04a<0?A<00`0C4`294`801A<00`0C4`0b4`00<Q<00`0C

4`3o4b`C00<04a<06A<00`0C4`0m4`0301<C08/C00D04a<C000e4`00<Q<00`0C4`3o4b`C00<04a<0

6A<00`0C4`0m4`0301<C08/C00@04a<04a<401lC000b4`0301<C0?lC;1<00`0C4`0I4`0301<C03dC

00<04a<0S1<201@C0`0P4`00<Q<00`0C4`3g4`<0:a?o00XC00<04a<07Q<0038C00<04a<0n1<00`0C

4`0[4`0301<C008C00@04a<021<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC

00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`034`0301<000LC00<04a<01Q<00`0C

4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC

00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<300HC

00<04a<031<2020C000/4nl00`d600TC00<04a<0<1<00`0C4`0I4`0301<C02HC00<04a<051<00`0C

4`0@4`0301<C02HC00<04a<09Q<00`0C4`0V4`0401<C03HC000b4`0301<C00PC00<04a<02A<00`0C

4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0C4`084`0301<C00TC

00<04a<02A<00`0C4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0C

4`084`0301<C00TC2Pd24`0301<C00`C100`4`0301<C01TC00<04a<0?A<00`0C4`2;4`0501<C4`00

=A<0038C00<04a<0;1<00`0C4`0/4`0301<C02`C00<04a<0;1<00`0C4`0K4`D=31<00`0C4`104`03

01<C01TC00<04a<0?A<00`0C4`2:4`0301<C008C00<04a<0<a<0038C00<04a<0e1<33E@C00<04a<0

6A<00`0C4`0m4`0301<C08TC00<04a<011<00`0C4`0b4`00<Q<00`0C4`3A4`<=Ea<00`0C4`0I4`80

?Q<00`0C4`274`801a<00`0C4`0b4`00<Q<00`0C4`3?4`8=FQ<00`0C4`0I4`0301<C03dC00<04a<0

Qa<00`0C4`064`0301<C038C000b4`0301<C0<dC0PeM4`0301<C01PC00<04a<0?A<00`0C4`264`03

01<C00PC00<04a<0<A<0038C00<04a<0bQ<33ElC00<04a<061<00`0C4`0m4`0301<C08@C0P0;4`03

01<C034C000b4`0301<C0<PC0PeR4`0301<C01PC00<04a<0?A<00`0C4`234`0301<C00/C00<04a<0

<A<0038C00<04a<0aQ<23F@C00<04a<061<00`0C4`0m4`0301<C088C00<04a<031<00`0C4`0a4`00

<Q<00`0C4`344`8=IQ<00`0C4`0H4`80?Q<00`0C4`204`803a<00`0C4`0a4`00<Q<00`0C4`324`8=

J1<00`0C4`0H4`0301<C03dC00<04a<0Oa<00`0C4`0@4`0301<C030C000b4`0301<C0<0C0PeZ4`03

01<C01PC00<04a<0?Q<00`0C4`1l4`804a<00`0C4`0`4`00<Q<00`0C4`2n4`8=K1<00`0C4`0H4`03

01<C03hC00<04a<0Na<201@C00<04a<0<1<0038C00<04a<0_1<23FhC00<04a<061<00`0C4`0n4`03

01<C07TC0P0F4`0301<C030C000b4`0301<C0;XC0Pe`4`0301<C01PC00<04a<0?Q<00`0C4`1h4`03

01<C01HC00<04a<0<1<0038C00<04a<0^1<23G<C00<04a<05a<203lC00<04a<0MQ<201TC00<04a<0

<1<0038C00<04a<0]Q<23GDC00<04a<05a<00`0C4`0n4`0301<C07@C0P0L4`0301<C02lC000L4`03

01<C008C00@04a<C0`034`0301<C00@C00<04a<0/Q<43GLC00<04a<05a<00`0C4`0n4`0301<C07<C

00<04a<071<00`0C4`0_4`006a<00`0C00074`0301<C008C00<04`001A<00`0C4`2]4`D=Na<00`0C

4`0G4`0301<C03lC00<04a<0L1<201lC00<04a<0;a<001/C00<04`0021<00`0C4`034`0301<C00<C

0P2[4`<=PA<00`0C4`0F4`0301<C03lC00<04a<0KA<3024C00<04a<0;a<001/C00<04`0021<0100C

4a<200HC00<04a<0RA<Q3H@C00<04a<05Q<00`0C4`0o4`0301<C06`C0P0S4`0301<C02lC000K4`03

01<000LC00<04`000Q<00`0C4`054`0301<C088C1`fU4`0301<C01HC0P104`0301<C06XC0P0U4`03

01<C02lC000L4`0301<C00LC00@04a<C0`054`0301<C07lC0`f/4`0301<C01HC00<04a<0?a<00`0C

4`1X4`809a<00`0C4`0_4`00<Q<00`0C4`1l4`<=[a<00`0C4`0F4`0301<C03lC00<04a<0IQ<202TC

00<04a<0;a<0038C00<04a<0NQ<23K<C00<04a<05A<00`0C4`0o4`0301<C06@C0P0Z4`0301<C030C

000b4`0301<C07PC0Pfe4`0301<C00lC00<04a<00a<00`0C4`0o4`0301<C068C0P0/4`0301<C030C

000b4`0301<C07HC0Pfg4`0301<C00hC00<04`0011<00`0C4`104`0301<C05hC0`0^4`0301<C030C

000b4`0301<C07@C0Pfi4`0301<C010C00<04a<00Q<3040C00<04a<0G1<3030C00<04a<0<1<0038C

00<04a<0La<00`dC4`2j4`0301<C00dC0P054`0301<C040C00<04a<0FQ<2038C0P0b4`00<Q<00`0C

4`1a4`8=_A<00`0C4`0=4`0301<C00@C00<04a<0@A<00`0C4`1G4`80=1<00`0C4`0a4`00<Q<00`0C

4`1_4`8=`1<00`0C4`0<4`<011<00`0C4`114`0301<C05@C0`0f4`0301<C034C000b4`0301<C06hC

00<=4a<0`1<00`0C4`0C4`0301<C044C00<04a<0DQ<303LC0P0c4`00<Q<00`0C4`1/4`8=a1<00`0C

4`0B4`80@Q<00`0C4`1?4`<0>Q<00`0C4`0b4`00<Q<00`0C4`1Z4`8=aQ<00`0C4`0B4`0301<C048C

00<04a<0C1<303`C00<04a<0<Q<0038C00<04a<0JA<00`dC4`374`0301<C014C00<04a<0@Q<00`0C

4`194`<0?Q<00`0C4`0c4`00<Q<;3ElC0Pg:4`0301<C014C00<04a<0@Q<00`0C4`174`<0@1<00`0C

4`0c4`008A<00`0C4`024`0301<C008C00<04a<011<00`0C4`084`D=FA<00`dC4`3;4`0301<C010C

00<04a<0@Q<00`0C4`144`<0@Q<203DC000P4`0301<000LC00<04`001A<00`0C4`0=4`8=EQ<00`dC

4`3<4`0301<C010C00<04a<0@a<00`0C4`104`<0AA<00`0C4`0d4`0081<00`0C00094`0301<C00<C

0P0@4`<=DA<23M0C00<04a<03a<204@C00<04a<0?A<304LC0P0f4`0081<00`0C00074`801Q<00`0C

4`0B4`<=CA<00`dC4`3@4`0301<C00lC00<04a<0A1<00`0C4`0i4`<0BQ<00`0C4`0e4`0081<00`0C

00074`0301<C00DC00<04a<05A<43DLC0PgD4`0301<C00hC00<04a<0A1<00`0C4`0f4`@0Ba<203LC

000Q4`0301<C00HC0`054`0301<C01TC0`e34`033A<C0=DC00<04a<03A<00`0C4`144`0301<C03<C

0`1?4`0301<C03HC000b4`0301<C01`C0Pdo4`8=fA<00`0C4`0<4`0301<C04DC00<04a<0;a<3054C

00<04a<0=a<0038C00<04a<07Q<33C/C00<=4a<0fA<00`0C4`0<4`0301<C04DC00<04a<0:a<405<C

0P0i4`00<Q<00`0C4`0Q4`8==a<23MdC00<04a<02a<204LC00<04a<09a<405HC00<04a<0>1<0038C

00<04a<08a<33C<C00<=4a<0gA<00`0C4`0;4`0301<C04HC00<04a<08a<505PC0P0j4`00<Q<00`0C

4`0V4`8=;a<23N4C0P0;4`0301<C04HC00<04a<081<405/C0P0k4`00<Q<00`0C4`0X4`<=:Q<23NDC

00<04a<021<00`0C4`174`0301<C01/C101O4`0301<C03XC000b4`0301<C02/C0PdV4`8=j1<00`0C

4`074`0301<C04LC0P0H4`D0HA<00`0C4`0k4`00<Q<00`0C4`0]4`8=8A<33NXC00<04a<01a<00`0C

4`184`0301<C01<C101T4`80?A<0038C00<04a<0;a<23AdC0Pg^4`0301<C00HC0P1:4`0301<C00hC

101W4`80?Q<0038C00<04a<0<A<53ADC0`ga4`801Q<00`0C4`194`0301<C00XC101Z4`80?a<0038C

00<04a<0=Q<53@/C1@gf4`0301<C00<C00<04a<0BQ<00`0C4`054`D0K1<2040C000b4`0301<C03/C

2`gl4`800a<00`0C4`1:4`8000<C00000`1`4`80@A<0038C00<04a<0oa<k4`D00Q<0100C4`024`03

01<C04TC1@1c4`80@Q<001`C00<04a<00Q<00`0C4`024`0301<C008C00<04a<011<00`0C4`3o4cdC

00L04a<C01<0008C0`174`D00Q<00`0C4`1a4`80@a<001/C00<04`0021<01`0C4a<04`001A<00`0C

4`3o4cdC00L04a<C01<000@C0`104`D021<00`0C4`1^4`80AA<001/C00<04`0021<00`0C4`034`03

01<C00<C0P3o4chC00L04a<C01<000@C00@04`00>Q<500dC00<04a<0KA<204HC000K4`0301<000TC

00<04a<00P064`0301<C0?lC?A<01`0C4a<04`0011<0100C4a<3034C1P0C4`80Ja<304LC000K4`03

01<000LC00<04`000Q<00`0C4`054`0301<C0?lC?1<200@C00<04a<00a<00`0C4`044`<0:1<701TC

0P1Y4`80BA<001`C00<04a<01Q<3008C0`054`0301<C0?lCB1<00`0C4`074`D06a<9020C00<04a<0

I1<304/C000b4`0301<C0?lCB1<00`0C4`0<4a`0:A<2068C0`1=4`00<Q<00`0C4`3o4dPC0P1C4`80

Ga<304lC000b4`0301<C0?lCB1<00`0C4`1C4`80FQ<4058C000b4`0301<C0?lCB1<00`0C4`1D4`80

A1<00`dC4`0?4`@0EA<0038C00<04a<0oa=84`0301<C05HC0P0o4`H=2Q<505TC000b4`0301<C0?lC

B1<00`0C4`1G4`<0?1<93@<C1P1M4`00<Q<00`0C4`3o4dPC00<04a<0FA<303XC2@d4068C000b4`03

01<C0?lCB1<205`C0`0h4`T=IQ<0038C00<04a<0oa=84`0301<C05hC0`0^4`H02`eU4`00<Q<00`0C

4`3o4dPC00<04a<0H1<502<C20064`T=IQ<0038C00<04a<0oa=84`0301<C06@C1`0D4`X03A<93FHC

000b4`0301<C0?lCB1<00`0C4`1Z4aD05a<93FHC000b4`0301<C0?lCB1<00`0C4`2G4`H=J1<002TC

1@044`0301<C0?lCB1<209/C00<=4a<0J1<002/C00<04a<011<00`0C4`3o4dPC00<04a<0oa<64`00

:a<00`0C4`044`80oa=94`0301<C0?lC1Q<002/C00<04a<0oa?o4ePC000[4`0301<C0?lCoa=H4`00

:Q<20?lCoa=J4`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<0074C10000a<0

0007008C00<04a<00Q<00`0C4`024`0301<C00D00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C

4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C

00<04a<01@0011<0003o4jdC001a4`<021<00`0C4`024`0301<C00HC00<04`000a<01`0C4a<04`00

0Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`03

01<0008C00<04`000Q<00`0C00024`0301<000<C00D04a<C002T4`80oa<94`00La<00`0C4`04008C

00<04a<00Q<00`0C4`064`0301<000<C00<04a<00a<01P0C4`0C008C00<04`000Q<00`0C00024`03

01<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0a<00`0C4`024`0301<C0:8C00<04a<0oa<74`006A<400034`0000H00Q<:008C0P024`<00Q<300<C

0P001Q<0000C02LC0P084`0301<C00<C00<04a<01Q<00`0C4`024`0401<C4`800a<00`0C00024`03

01<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0Q<00`0C00024`0301<000<C00<04a<00Q<00`0C4`2P4`<00Q<00`0C4`3o4`@C000J4`0601<C01<0

0Q<00`0C00044`0601<C01<00Q<00`0C00054`0301<C008C00D04a<C00024`0401<04`80<A<01`0C

4a<04`001a<00`0C00034`0501<C4`0011<00`0C00024`0301<0008C00<04`000Q<00`0C00024`03

01<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<000<C00L04a<C

01<000@C00<04a<0VA<0200C4`0C01<0oa<54`006Q<01P0C4`0C00@C00<04a<00Q<00`0C4`024`03

01<C008C00<04a<00a<00`0C4`024`0501<C4`000Q<0100C01<2030C0P034`<021<0100C4a<200<C

0`034`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C

00<04a<00Q<00`0C4`024`0301<C008C00@04a<C0P044`0301<C008C00<04a<0VQ<0200C4`0C01<0

oa<54`006Q<01@0C4`0C00800a<200<C00<04a<00Q<200<C00<04a<00a<00`0C4`024`0501<C4`00

0Q<01P0C000C0?lC;a<300044`0C0?lC1A<001XC00H04a<04`024`0301<0008C00<04`0011<03P0C

4`0C01<04`0C01<00Q<01@0C4a<0008C00H04`004`3o4c<C00<04`00oa<54`006A<400034`0000/0

0Q<500054`0001<01@0011<000034`8000@C000C0P3o4c@C00<04a<0oa<44`00oa?o4hHC003o4olC

QQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00

\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.77084, -14.119, 0.0242408, 0.16996}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -57 0 ]

[.5 .63053 57 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -118 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(18.0949999999999917`) show

173.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .46523 m

.02499 .46523 L

.02606 .46524 L

.02729 .46525 L

.02846 .46527 L

.03053 .46532 L

.03279 .46539 L

.03527 .46549 L

.0379 .46562 L

.04262 .46593 L

.04749 .46634 L

.05205 .4668 L

.06245 .46816 L

.07305 .46997 L

.08274 .47198 L

.10458 .47766 L

.14429 .4914 L

.18248 .50696 L

.22313 .52281 L

.24192 .5288 L

.25181 .53141 L

.26226 .53368 L

.26757 .53463 L

.27341 .53549 L

.27871 .53611 L

.28367 .53654 L

.28628 .53671 L

.28757 .53678 L

.28876 .53683 L

.28982 .53687 L

.29098 .53691 L

.29216 .53693 L

.2934 .53695 L

.29406 .53696 L

.29475 .53696 L

.29599 .53696 L

.29668 .53696 L

.29733 .53695 L

.29803 .53694 L

.29879 .53693 L

.30015 .53689 L

.30143 .53684 L

.30384 .53673 L

.30623 .53658 L

.30847 .5364 L

.31356 .53588 L

.31852 .53521 L

.32385 .5343 L

.3335 .53217 L

.34231 .52968 L

Mistroke

.36133 .5226 L

.38207 .51242 L

.42276 .48665 L

.46195 .45821 L

.50358 .42962 L

.52449 .4176 L

.5437 .40854 L

.56248 .40173 L

.57194 .39909 L

.5823 .39678 L

.59253 .39507 L

.60185 .39397 L

.607 .39352 L

.60972 .39334 L

.6126 .39317 L

.61512 .39305 L

.61789 .39294 L

.62041 .39287 L

.62278 .39281 L

.62396 .39279 L

.62522 .39278 L

.62641 .39277 L

.62749 .39276 L

.62876 .39275 L

.62948 .39275 L

.63014 .39275 L

.63135 .39276 L

.63264 .39276 L

.63387 .39277 L

.63519 .39279 L

.63757 .39282 L

.64041 .39287 L

.643 .39293 L

.66152 .39348 L

.66631 .39361 L

.67141 .39374 L

.67351 .39378 L

.67577 .39381 L

.67706 .39383 L

.67825 .39384 L

.67938 .39385 L

.68058 .39386 L

.68188 .39386 L

.68306 .39386 L

.68371 .39386 L

.68442 .39386 L

.68571 .39385 L

.68692 .39384 L

.68819 .39383 L

.69049 .39379 L

Mistroke

.69177 .39376 L

.69315 .39372 L

.69565 .39364 L

.69862 .39352 L

.70133 .39338 L

.7061 .39307 L

.71119 .39265 L

.72033 .39161 L

.7312 .38987 L

.74106 .38781 L

.76032 .38242 L

.78115 .37466 L

.82217 .35523 L

.86168 .33544 L

.88155 .32675 L

.89967 .32017 L

.91919 .3148 L

.92994 .31263 L

.94011 .31109 L

.9492 .31011 L

.95379 .30974 L

.95886 .30944 L

.96316 .30925 L

.96558 .30917 L

.9678 .30911 L

.96975 .30907 L

.97086 .30905 L

.97189 .30904 L

.97298 .30903 L

.97397 .30902 L

.97511 .30902 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.79951 .57841 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4gdC00<04a<0oa<64`00oa=m4`0301<C0?lC1Q<002TC1@3o4dlC0P3o4`LC

000[4`0301<C0?lCCa<00`0C4`1^4`d0RQ<002DC0`034`0301<C00@C0P3o4dTC00<04a<0IQ<800`C

3@1n4`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`1Q4`D081<807LC000[4`0301<C00@C00<04a<0

oa=84`0301<C05hC100/4`L0L1<002XC0P064`0301<C0?lCB1<00`0C4`1L4`<0=A<706XC000b4`03

01<C0?lCB1<205/C0P0o4`H0I1<0038C00<04a<0oa=84`0301<C05PC0P164`H0Ga<0038C00<04a<0

oa=84`0301<C05HC0P1>4`D0FQ<0038C00<04a<0oa=84`0301<C05DC0P1C4`D0EQ<0038C00<04a<0

oa=84`0301<C05@C00<04a<0Ea<5058C000b4`0301<C0?lCB1<205<C0P1N4`<0D1<0038C00<04a<0

oa=84`0301<C00lC5P0/4`80HA<404dC000b4`0301<C0?lCB1<00`0C4`0:4`D05Q<9028C0P1U4`<0

Ba<0038C00<04a<0oa=84`0301<C00DC1@0S4`L06a<206PC0`194`00<Q<00`0C4`3o4c/C1@024`03

01<C00<C00<04a<00a<202lC1P0D4`80Ja<204PC000b4`0301<C0?lC?A<01`0C4a<04`0011<00`0C

4`0303HC1P0>4`80KA<304HC000b4`0301<C0?lC=a<300<C00L04a<C01<000@C0`0n4`H02A<00`0C

4`1^4`80AA<0038C00<04a<0oa<m4`0701<C4`0C00034`80AA<500@C00<04a<0L1<204@C000L4`03

01<C008C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0oa<m4`0701<C4`0C00024`0301<004XC

1@1d4`80@Q<001/C00<04`0021<01`0C4a<04`001A<00`0C4`3o4c`C0P044`0401<0008C00<04a<0

Ba<6074C0P114`005Q<3008C00<04`0021<00`0C4`034`0301<C00<C0P3o4d<C0P044`0301<C04XC

00<04a<011<406hC0P104`006a<00`0C00094`0301<C00801Q<00`0C4`3o4d4C00<04a<011<00`0C

4`194`0301<C00TC101[4`0301<C03hC000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C0?lC

@1<00`0C4`054`80BQ<00`0C4`0=4`@0J1<203hC000L4`0301<C00HC0`024`<01A<00`0C4`3o4clC

00<04a<01Q<00`0C4`184`0301<C018C101U4`0301<C03`C000b4`0301<C0?lC?Q<00`0C4`074`03

01<C04PC00<04a<05A<5068C00<04a<0>a<0038C00<04a<0oa<m4`0301<C00PC00<04a<0Aa<00`0C

4`0J4`@0Ga<203`C000b4`0301<C0?lC?1<00`0C4`094`0301<C04HC00<04a<07a<405`C0P0k4`00

<Q<00`0C4`3o4c/C00<04a<02Q<00`0C4`164`0301<C028C1@1I4`0301<C03TC000b4`0301<C0?lC

>Q<00`0C4`0;4`80Aa<00`0C4`0V4`@0Ea<00`0C4`0h4`00<Q<00`0C4`3o4cTC00<04a<031<00`0C

4`154`0301<C02XC101D4`80>A<0038C00<04a<0oa<i4`0301<C00`C00<04a<0AA<00`0C4`0^4`@0

DA<00`0C4`0g4`00<Q<00`0C4`3o4cPC00<04a<03A<00`0C4`144`0301<C03<C0P1?4`80>1<0038C

00<04a<0oa<g4`0301<C00hC00<04a<0A1<00`0C4`0e4`@0C1<203LC000b4`0301<C0?lC=Q<00`0C

4`0?4`0301<C04@C00<04a<0>A<204/C00<04a<0=A<0038C00<04a<0oa<f4`0301<C00lC0P144`03

01<C03`C10174`80=Q<0038C00<04a<0oa<e4`0301<C010C00<04a<0@a<00`0C4`0o4`<0AQ<00`0C

4`0d4`00<Q<00`0C4`3o4cDC00<04a<041<00`0C4`134`0301<C048C0`134`80=A<0024C00<04a<0

0Q<00`0C4`024`0301<C00@C00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`164`<0@A<00`0C

4`0c4`0081<00`0C00074`0301<000DC00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`194`80

?a<00`0C4`0c4`006a<3008C00<04`002A<00`0C4`034`80oa<d4`0301<C018C00<04a<0@Q<00`0C

4`1;4`<0?A<00`0C4`0b4`0081<00`0C00074`801Q<00`0C4`3o4c<C00<04a<04Q<204<C00<04a<0

CQ<203/C00<04a<0<Q<0020C00<04`001a<00`0C4`054`0301<C0?lC<Q<00`0C4`0C4`0301<C044C

00<04a<0DA<303PC00<04a<0<Q<0024C00<04a<01Q<300DC00<04a<0oa<b4`0301<C01<C00<04a<0

@A<00`0C4`1D4`80=a<00`0C4`0a4`00<Q<00`0C4`3o4c4C00<04a<051<00`0C4`114`0301<C05HC

0`0d4`0301<C034C000b4`0301<C0?lC<A<00`0C4`0>4`0301<C00<C00<04a<0@1<00`0C4`1I4`<0

<Q<2038C000b4`0301<C0?lC<1<00`0C4`0>4`0301<000@C00<04a<0@1<00`0C4`1L4`80<A<00`0C

4`0`4`00<Q<00`0C4`3o4c0C00<04a<02A<300@C00<04a<00Q<3040C00<04a<0GQ<202lC00<04a<0

<1<0038C00<04a<0oa<`4`0301<C00hC0P054`0301<C03lC00<04a<0HA<302`C00<04a<0<1<0038C

00<04a<0oa<`4`0301<C00hC00<04a<011<00`0C4`0o4`0301<C06@C00<04a<0:A<00`0C4`0`4`00

<Q<00`0C4`3o4blC00<04a<03a<300@C00<04a<0?a<00`0C4`1U4`<0:1<2034C000b4`0301<C0?lC

;a<00`0C4`0F4`0301<C03lC00<04a<0J1<00`0C4`0V4`0301<C02lC000b4`0301<C0?lC;a<00`0C

4`0F4`0301<C03lC00<04a<0JA<302DC00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC0P104`03

01<C06`C0P0S4`0301<C02lC000b4`0301<C0?lC;a<00`0C4`0F4`0301<C03lC00<04a<0KA<2028C

00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC00<04a<0?a<00`0C4`1_4`8081<00`0C4`0_4`00

<Q<00`0C4`3o4bhC00<04a<05a<00`0C4`0n4`0301<C078C0P0N4`0301<C02lC000L4`0301<C008C

00@04a<C0`034`0301<C00@C00<04a<0oa<^4`0301<C01LC00<04a<0?Q<00`0C4`1d4`8071<00`0C

4`0_4`006a<00`0C00074`0301<C008C00<04`001A<00`0C4`3o4bhC00<04a<05a<203lC00<04a<0

MQ<201XC00<04a<0;a<001HC0`024`0301<000PC00<04a<00a<00`0C4`034`80oa<_4`0301<C01LC

00<04a<0?Q<00`0C4`1h4`0301<C01HC00<04a<0<1<001/C00<04`0021<0100C4a<200HC00<04a<0

oa<]4`0301<C01PC00<04a<0?Q<00`0C4`1i4`805Q<00`0C4`0`4`006a<00`0C00074`0301<0008C

00<04a<01A<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07/C00<04a<04a<00`0C4`0`4`00

71<00`0C4`074`0401<C4`<01A<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07`C00<04a<0

4Q<00`0C4`0`4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0m4`0301<C07hC0P0B4`0301<C030C

000b4`0301<C0?lC;A<00`0C4`0H4`80?Q<00`0C4`204`8041<00`0C4`0`4`00<Q<00`0C4`3o4bdC

00<04a<061<00`0C4`0Q4`D00Q<00`0C4`0B4`0301<C00/C1@000a<0000Q4`D00Q<00`0C4`0O4`D0

0Q<00`0C4`0K4`0401<C4`D000<C00000a<00`0C4`0a4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C

4`0S4`0701<C4`0C000C4`0301<C00dC00L04a<C01<0028C00<04a<00Q<00`0C4`0Q4`0701<C4`0C

000L4`8011<00`0C4`034`0401<C03<C000b4`0301<C02HC00<04a<00Q<0100C4a<302<C00<04a<0

0Q<00`0C4`024`<08Q<00`0C4`024`0401<C4`8091<00`0C4`024`0301<C008C00<04a<09Q<5044C

00<04a<061<00`0C4`0S4`0301<C00<C00<04a<04A<00`0C4`0=4`0701<C4`0C000R4`0301<C008C

00<04a<08A<01`0C4a<04`007Q<01@0C4a<000@C0P024`0301<C034C000b4`0301<C02DC00<04`00

1a<00`0C4`0R4`0301<000TC00<04a<081<00`0C00074`0301<0028C00<04`001a<00`0C000Y4`03

01<C044C00<04a<061<00`0C4`0S4`0401<C4`8051<00`0C4`0=4`0401<C4`808a<00`0C4`034`03

01<C020C00<04a<00Q<00`0C4`0N4`8000<C01<00Q<00`0C00024`0301<C034C000b4`0301<C02DC

00<04`0021<00`0C4`0Q4`0301<000LC100Q4`0301<000LC00<04`008Q<00`0C00074`0301<002TC

00<04a<0@1<00`0C4`0I4`0301<C02<C00D04a<C000E4`0301<C00dC00D04a<C000T4`0701<C4`0C

000R4`0701<C4`0C000Q4`800a<01@0C01<003@C000b4`0301<C02DC00<04`0021<00`0C4`0Q4`03

01<000LC00<04`008Q<00`0C00074`808a<00`0C00084`0301<C02PC00<04a<0@1<00`0C4`0I4`80

8a<200<C0`0C4`0301<C00`C0P044`808A<200<C0`0Q4`8011<00`0C4`0P4`8011<200034`0C03<C

000b4`0301<C02DC00<04`001a<00`0C000R4`0301<000PC0P0R4`0301<000LC00<04a<08Q<00`0C

00074`0301<002TC00<04a<0@1<00`0C4`0I4`0301<C03dC00<04a<0R1<00`0C4`054`0301<C038C

000b4`0301<C02HC00<04a<01a<00`0C4`0R4`0301<C00PC00<04a<08A<00`0C4`074`808a<00`0C

4`074`0301<C02LC0P124`0301<C01TC00<04a<0?A<00`0C4`294`801A<00`0C4`0b4`00<Q<00`0C

4`3o4b`C00<04a<06A<00`0C4`0m4`0301<C08/C00D04a<C000e4`00<Q<00`0C4`3o4b`C00<04a<0

6A<00`0C4`0m4`0301<C08/C00@04a<04a<401lC000b4`0301<C0?lC;1<00`0C4`0I4`0301<C03dC

00<04a<0S1<201@C0`0P4`00<Q<00`0C4`3g4`<0:a?o00XC00<04a<07Q<0038C00<04a<0n1<00`0C

4`0[4`0301<C008C00@04a<021<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC

00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`034`0301<000LC00<04a<01Q<00`0C

4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC

00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<300HC

00<04a<031<2020C000/4nl00`d600TC00<04a<0<1<00`0C4`0I4`0301<C02HC00<04a<051<00`0C

4`0@4`0301<C02HC00<04a<09Q<00`0C4`0V4`0401<C03HC000b4`0301<C00PC00<04a<02A<00`0C

4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0C4`084`0301<C00TC

00<04a<02A<00`0C4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0C

4`084`0301<C00TC2Pd24`0301<C00`C100`4`0301<C01TC00<04a<0?A<00`0C4`2;4`0501<C4`00

=A<0038C00<04a<0;1<00`0C4`0/4`0301<C02`C00<04a<0;1<00`0C4`0L4`@=31<00`0C4`104`03

01<C01TC00<04a<0?A<00`0C4`2:4`0301<C008C00<04a<0<a<0038C00<04a<0eA<33E<C00<04a<0

6A<00`0C4`0m4`0301<C08TC00<04a<011<00`0C4`0b4`00<Q<00`0C4`3C4`8=EQ<00`0C4`0I4`80

?Q<00`0C4`274`801a<00`0C4`0b4`00<Q<00`0C4`3@4`<=F1<00`0C4`0I4`0301<C03dC00<04a<0

Qa<00`0C4`064`0301<C038C000b4`0301<C0<hC0PeL4`0301<C01PC00<04a<0?A<00`0C4`264`03

01<C00PC00<04a<0<A<0038C00<04a<0c1<23EhC00<04a<061<00`0C4`0m4`0301<C08@C0P0;4`03

01<C034C000b4`0301<C0<XC0PeP4`0301<C01PC00<04a<0?A<00`0C4`234`0301<C00/C00<04a<0

<A<0038C00<04a<0b1<23F8C00<04a<061<00`0C4`0m4`0301<C088C00<04a<031<00`0C4`0a4`00

<Q<00`0C4`364`8=I1<00`0C4`0H4`80?Q<00`0C4`204`803a<00`0C4`0a4`00<Q<00`0C4`344`8=

IQ<00`0C4`0H4`0301<C03dC00<04a<0Oa<00`0C4`0@4`0301<C030C000b4`0301<C0<8C0PeX4`03

01<C01PC00<04a<0?Q<00`0C4`1l4`804a<00`0C4`0`4`00<Q<00`0C4`304`8=JQ<00`0C4`0H4`03

01<C03hC00<04a<0Na<201@C00<04a<0<1<0038C00<04a<0_Q<23F`C00<04a<061<00`0C4`0n4`03

01<C07TC0P0F4`0301<C030C000b4`0301<C0;`C0Pe^4`0301<C01PC00<04a<0?Q<00`0C4`1h4`03

01<C01HC00<04a<0<1<0038C00<04a<0^Q<23G4C00<04a<05a<203lC00<04a<0MQ<201TC00<04a<0

<1<0038C00<04a<0]a<33G<C00<04a<05a<00`0C4`0n4`0301<C07@C0P0L4`0301<C02lC000L4`03

01<C008C00@04a<C0`034`0301<C00@C00<04a<0]A<23GHC00<04a<05a<00`0C4`0n4`0301<C07<C

00<04a<071<00`0C4`0_4`006a<00`0C00074`0301<C008C00<04`001A<00`0C4`2a4`@=N1<00`0C

4`0G4`0301<C03lC00<04a<0L1<201lC00<04a<0;a<001/C00<04`0021<00`0C4`034`0301<C00<C

0P2/4`H=OA<00`0C4`0F4`0301<C03lC00<04a<0KA<3024C00<04a<0;a<001/C00<04`0021<0100C

4a<200HC00<04a<0Ra<P3H<C00<04a<05Q<00`0C4`0o4`0301<C06`C0P0S4`0301<C02lC000K4`03

01<000LC00<04`000Q<00`0C4`054`0301<C08HC1@fS4`0301<C01HC0P104`0301<C06XC0P0U4`03

01<C02lC000L4`0301<C00LC00@04a<C0`054`0301<C084C1@fX4`0301<C01HC00<04a<0?a<00`0C

4`1X4`809a<00`0C4`0_4`00<Q<00`0C4`1o4`8=[A<00`0C4`0F4`0301<C03lC00<04a<0IQ<202TC

00<04a<0;a<0038C00<04a<0O1<33K0C00<04a<05A<00`0C4`0o4`0301<C06@C0P0Z4`0301<C030C

000b4`0301<C07XC0Pfc4`0301<C00lC00<04a<00a<00`0C4`0o4`0301<C068C0P0/4`0301<C030C

000b4`0301<C07PC0Pfe4`0301<C00hC00<04`0011<00`0C4`104`0301<C05hC0`0^4`0301<C030C

000b4`0301<C07HC0Pfg4`0301<C010C00<04a<00Q<3040C00<04a<0G1<3030C00<04a<0<1<0038C

00<04a<0M1<23KXC00<04a<03A<200DC00<04a<0@1<00`0C4`1J4`80<Q<2038C000b4`0301<C07<C

00<=4a<0^Q<00`0C4`0=4`0301<C00@C00<04a<0@A<00`0C4`1G4`80=1<00`0C4`0a4`00<Q<00`0C

4`1a4`8=_Q<00`0C4`0<4`<011<00`0C4`114`0301<C05@C0`0f4`0301<C034C000b4`0301<C070C

00<=4a<0_Q<00`0C4`0C4`0301<C044C00<04a<0DQ<303LC0P0c4`00<Q<00`0C4`1_4`033A<C0<0C

00<04a<04Q<2048C00<04a<0Ca<303XC00<04a<0<Q<0038C00<04a<0KA<23L<C00<04a<04Q<00`0C

4`124`0301<C04`C0`0l4`0301<C038C000b4`0301<C06`C00<=4a<0a1<00`0C4`0A4`0301<C048C

00<04a<0BA<303hC00<04a<0<a<0038C00<04a<0JQ<23LLC00<04a<04A<00`0C4`124`0301<C04LC

0`104`0301<C03<C000Q4`0301<C008C00<04a<00Q<00`0C4`044`0301<C06TC00<=4a<0b1<00`0C

4`0@4`0301<C048C00<04a<0A1<3048C0P0e4`0081<00`0C00074`0301<000DC00<04a<0Ia<23L/C

00<04a<041<00`0C4`134`0301<C040C0`154`0301<C03@C000P4`0301<000TC00<04a<00a<83F4C

00<=4a<0c1<00`0C4`0?4`80A1<00`0C4`0m4`<0Aa<203HC000P4`0301<000LC0P064`0301<C00DC

1@eK4`033A<C0<dC00<04a<03a<00`0C4`144`0301<C03TC0`1:4`0301<C03DC000P4`0301<000LC

00<04a<01A<00`0C4`0:4`@=EA<23M4C00<04a<03Q<00`0C4`144`0301<C03HC101;4`80=a<0024C

00<04a<01Q<300DC00<04a<03Q<43E0C00<=4a<0dQ<00`0C4`0=4`0301<C04@C00<04a<0<a<304lC

00<04a<0=Q<0038C00<04a<04Q<23D`C0PgF4`0301<C00`C00<04a<0AA<00`0C4`0_4`<0DA<00`0C

4`0g4`00<Q<00`0C4`0D4`<=B1<00`dC4`3F4`0301<C00`C00<04a<0AA<00`0C4`0[4`@0Da<203TC

000b4`0301<C01LC0Pe44`8=fQ<00`0C4`0;4`80Aa<00`0C4`0W4`@0EQ<00`0C4`0h4`00<Q<00`0C

4`0I4`<=@1<00`dC4`3J4`0301<C00/C00<04a<0AQ<00`0C4`0S4`D0F1<203XC000b4`0301<C01`C

0`dl4`033A<C0=`C0P0;4`0301<C04HC00<04a<081<405/C0P0k4`00<Q<00`0C4`0O4`@==Q<23N4C

00<04a<021<00`0C4`174`0301<C01/C101O4`0301<C03XC000b4`0301<C02<C0`db4`033A<C0>8C

00<04a<01a<00`0C4`174`8061<5064C00<04a<0>a<0038C00<04a<09Q<23BhC0PgU4`0301<C00LC

00<04a<0B1<00`0C4`0C4`@0I1<203dC000b4`0301<C02PC0`dY4`8=j1<00`0C4`064`80BQ<00`0C

4`0>4`@0Ia<203hC000b4`0301<C02/C0PdU4`8=ja<200HC00<04a<0BA<00`0C4`0:4`@0JQ<203lC

000b4`0301<C02dC0PdP4`<=ka<00`0C4`034`0301<C04XC00<04a<01A<506`C0P104`00<Q<00`0C

4`0_4`8=71<23O<C0P034`0301<C04XC0P000a<00003070C0P114`00<Q<00`0C4`0a4`D=5A<23NdC

1@024`0401<C008C00<04a<0BA<507<C0P124`0071<00`0C4`024`0301<C008C00<04a<00Q<00`0C

4`044`0301<C03HC1@d:4`H=lA<01`0C4a<04`000Q<304LC1@024`0301<C074C0P134`006a<00`0C

00084`0701<C4`0C00054`0301<C03/C2Pgg4`0701<C4`0C00044`<0@1<500PC00<04a<0KQ<204DC

000K4`0301<000PC00<04a<00a<00`0C4`034`80oa<n4`0701<C4`0C00044`0401<003XC1@0=4`03

01<C06dC0P164`006a<00`0C00094`0301<C00801Q<00`0C4`3o4cdC00L04a<C01<000@C00@04a<C

0`0a4`H04a<206/C0`174`006a<00`0C00074`0301<0008C00<04a<01A<00`0C4`3o4c`C0P044`03

01<C00<C00<04a<011<302PC1`0I4`80JA<204TC000L4`0301<C00HC0`024`<01A<00`0C4`3o4dPC

00<04a<01a<501/C2@0P4`0301<C06@C0`1;4`00<Q<00`0C4`3o4dPC00<04a<031<L02TC0P1B4`03

3A<C00dC0`1=4`00<Q<00`0C4`3o4dPC0P1C4`80CQ<63@/C0`1?4`00<Q<00`0C4`3o4dPC00<04a<0

Da<204`C2@d54`@0DQ<0038C00<04a<0oa=84`0301<C05@C0P1;4`T=0Q<405DC000b4`0301<C0?lC

B1<00`0C4`1F4`80BA<93@80FA<0038C00<04a<0oa=84`0301<C05LC0`164`/=FQ<0038C00<04a<0

oa=84`0301<C05TC0`104`D02@eK4`00<Q<00`0C4`3o4dPC0P1L4`<0>1<700@C2@eK4`00<Q<00`0C

4`3o4dPC00<04a<0GQ<302hC200:4`T=Fa<0038C00<04a<0oa=84`0301<C060C1@0S4`P04Q<63EdC

000b4`0301<C0?lCB1<00`0C4`1T4`L051<:01`C00<=4a<0GA<0038C00<04a<0oa=84`0301<C06XC

5@264`00<Q<00`0C4`3o4dPC00<04a<0oa<64`00:A<500@C00<04a<0oa=84`80oa<74`00:a<00`0C

4`044`0301<C0?lCB1<00`0C4`3o4`HC000[4`0301<C00@C0P3o4dTC00<04a<0oa<64`00:a<00`0C

4`3o4olCF1<002/C00<04a<0oa?o4ePC000Z4`80oa?o4eXC003o4olCQQ<00?lCoa>64`00oa?o4hHC

003o4olCQQ<00?lCoa>64`00LA<400034`0000L00Q<00`0C4`024`0301<C008C00@04a<C0P044`<0

00<C00000a<200<C0P034`800a<200<C0P034`800a<200<C0P034`800a<2008C1@024`0301<C0?lC

[1<0074C0`084`0701<C4`0C00074`0301<000@C00<04a<00Q<00`0C4`024`0301<C008C00<04a<0

0Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`03

01<C008C00D04a<C00044`0301<C0:4C0P3o4`TC001c4`0301<C00@00Q<01`0C4a<04`001a<00`0C

00034`800Q<4008C0P034`800a<200<C0P034`800a<200<C0P034`800a<200<C0P034`800a<00`0C

4`024`0301<C0:8C00<04a<0oa<74`006A<400034`0000H00Q<:008C0P024`<00Q<300<C0P001Q<0

000C02LC0P084`0301<C008C00<04a<01Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`03

01<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0Q<00`0C00024`0301<000<C00<04a<00a<00`0C4`2O4`<00Q<00`0C4`3o4`@C000J4`0601<C01<0

0Q<00`0C00044`0601<C01<00Q<00`0C00054`0301<C008C00D04a<C00024`0401<04`80<A<01`0C

4a<04`001a<00`0C00024`0301<000<C0P024`0301<0008C00<04`000Q<00`0C00024`0301<0008C

00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000a<01`0C

4a<04`0011<00`0C4`2I4`0801<C01<04`3o4`DC000J4`0601<C01<011<00`0C4`024`0301<C008C

00<04a<00Q<00`0C4`034`0301<C008C00D04a<C00024`0401<04`80<1<200@C00<04a<01a<00`0C

4`024`8011<0100C4a<200<C0P034`800a<200<C0P034`800a<200<C0P034`800a<200<C0P024`80

0a<300<C00<04a<0VQ<0200C4`0C01<0oa<54`006Q<01@0C4`0C00800a<200<C00<04a<00Q<200<C

00<04a<00a<00`0C4`024`0501<C4`000Q<01P0C000C0?lC;a<300044`0C0?lC1A<001XC00H04a<0

4`024`0301<0008C00<04`0011<03P0C4`0C01<04`0C01<00Q<01@0C4a<0008C00H04`004`3o4c<C

00<04`00oa<54`006A<400034`0000/00Q<500054`0001<01@0011<000034`8000@C000C0P3o4c@C

00<04a<0oa<44`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00

oa?o4hHC003o4olCQQ<00?lCoa>64`00\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.77084, -14.119, 0.0242408, 0.16996}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -24.5 0 ]

[.5 .63053 24.5 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -85.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(18.375`) show

108.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .48614 m

.02499 .48615 L

.02606 .48615 L

.02729 .48617 L

.02846 .48618 L

.03053 .48623 L

.03279 .4863 L

.03527 .48639 L

.0379 .48652 L

.04262 .48681 L

.04749 .4872 L

.05205 .48765 L

.06245 .48895 L

.07305 .49067 L

.08274 .49259 L

.10458 .49799 L

.14429 .51094 L

.18248 .52535 L

.2038 .53321 L

.22313 .53963 L

.24351 .54518 L

.25245 .54709 L

.26226 .54878 L

.26677 .54939 L

.27162 .54992 L

.27429 .55016 L

.27673 .55035 L

.27904 .55049 L

.2815 .55061 L

.28277 .55066 L

.28416 .5507 L

.28543 .55073 L

.28662 .55075 L

.28731 .55075 L

.28802 .55076 L

.28931 .55075 L

.29002 .55075 L

.29069 .55074 L

.29142 .55073 L

.2922 .55071 L

.29351 .55068 L

.29492 .55063 L

.2975 .5505 L

.30001 .55034 L

.30232 .55016 L

.307 .54968 L

.31202 .54902 L

.32109 .54739 L

.33187 .54476 L

.34173 .54169 L

Mistroke

.36075 .53403 L

.38149 .52325 L

.42218 .49626 L

.46137 .46639 L

.503 .43585 L

.52391 .42272 L

.54312 .41262 L

.5619 .40482 L

.57148 .40167 L

.58172 .3989 L

.59202 .39674 L

.6014 .39527 L

.60592 .39472 L

.61083 .39423 L

.61512 .39389 L

.61975 .39361 L

.62229 .39349 L

.62461 .39339 L

.62697 .39332 L

.62917 .39327 L

.63159 .39322 L

.63287 .39321 L

.63424 .3932 L

.63492 .39319 L

.63567 .39319 L

.63638 .39319 L

.63703 .39318 L

.63826 .39319 L

.63956 .39319 L

.64087 .3932 L

.64206 .39321 L

.64474 .39324 L

.64722 .39328 L

.64958 .39333 L

.66058 .3936 L

.67022 .39385 L

.67509 .39395 L

.67786 .39399 L

.6791 .39401 L

.68047 .39403 L

.68155 .39404 L

.68271 .39404 L

.68394 .39405 L

.68508 .39405 L

.68623 .39405 L

.6873 .39405 L

.68827 .39404 L

.68932 .39403 L

.69047 .39402 L

.69174 .394 L

Mistroke

.69429 .39396 L

.69666 .39389 L

.69888 .39382 L

.70385 .3936 L

.70927 .39325 L

.71439 .39282 L

.71914 .39232 L

.72811 .39111 L

.73767 .3894 L

.74797 .38705 L

.7591 .38391 L

.77927 .37672 L

.8203 .35751 L

.8598 .33729 L

.87968 .32822 L

.89779 .32127 L

.91732 .3155 L

.92806 .31315 L

.93824 .31145 L

.9478 .31029 L

.95263 .30987 L

.95796 .3095 L

.96248 .30928 L

.96503 .30919 L

.96736 .30912 L

.96942 .30908 L

.97058 .30906 L

.97166 .30904 L

.97281 .30903 L

.97385 .30902 L

.97506 .30902 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.84493 .56695 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4gdC00<04a<0oa<64`00oa=m4`0301<C0?lC1Q<002TC1@3o4dlC0P3o4`LC

000[4`0301<C0?lCCa<00`0C4`1^4`d0RQ<002DC0`034`0301<C00@C0P3o4dTC00<04a<0IQ<800`C

3@1n4`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`1Q4`D081<807LC000[4`0301<C00@C00<04a<0

oa=84`0301<C05hC100/4`L0L1<002XC0P064`0301<C0?lCB1<00`0C4`1L4`<0=A<706XC000b4`03

01<C0?lCB1<205/C0P0o4`H0I1<0038C00<04a<0oa=84`0301<C05PC0P164`H0Ga<0038C00<04a<0

oa=84`0301<C05HC0P1>4`D0FQ<0038C00<04a<0oa=84`0301<C05DC0P1C4`D0EQ<0038C00<04a<0

oa=84`0301<C05@C00<04a<0Ea<5058C000b4`0301<C0?lCB1<205<C0P1N4`<0D1<0038C00<04a<0

oa=84`0301<C00lC5P0/4`80HA<404dC000b4`0301<C0?lCB1<00`0C4`0:4`D05Q<9028C0P1U4`<0

Ba<0038C00<04a<0oa=84`0301<C00DC1@0S4`L06a<206PC0`194`00<Q<00`0C4`3o4c/C1@024`03

01<C00<C00<04a<00a<202lC1P0D4`80Ja<204PC000b4`0301<C0?lC?A<01`0C4a<04`0011<00`0C

4`0303HC1P0>4`80KA<304HC000b4`0301<C0?lC=a<300<C00L04a<C01<000@C0`0n4`H02A<00`0C

4`1^4`80AA<0038C00<04a<0oa<m4`0701<C4`0C00034`80AA<500@C00<04a<0L1<204@C000L4`03

01<C008C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0oa<m4`0701<C4`0C00024`0301<004XC

1@1d4`80@Q<001/C00<04`0021<01`0C4a<04`001A<00`0C4`3o4c`C0P044`0401<0008C00<04a<0

Ba<6074C0P114`005Q<3008C00<04`0021<00`0C4`034`0301<C00<C0P3o4d<C0P044`0301<C04XC

00<04a<011<406hC0P104`006a<00`0C00094`0301<C00801Q<00`0C4`3o4d4C00<04a<011<00`0C

4`194`0301<C00TC101[4`0301<C03hC000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C0?lC

@1<00`0C4`054`80BQ<00`0C4`0=4`@0J1<203hC000L4`0301<C00HC0`024`<01A<00`0C4`3o4clC

00<04a<01Q<00`0C4`184`0301<C018C101U4`0301<C03`C000b4`0301<C0?lC?Q<00`0C4`074`03

01<C04PC00<04a<05A<5068C00<04a<0>a<0038C00<04a<0oa<m4`0301<C00PC00<04a<0Aa<00`0C

4`0J4`@0Ga<203`C000b4`0301<C0?lC?1<00`0C4`094`0301<C04HC00<04a<07a<405`C0P0k4`00

<Q<00`0C4`3o4c/C00<04a<02Q<00`0C4`164`0301<C028C1@1I4`0301<C03TC000b4`0301<C0?lC

>Q<00`0C4`0;4`80Aa<00`0C4`0V4`@0Ea<00`0C4`0h4`00<Q<00`0C4`3o4cTC00<04a<031<00`0C

4`154`0301<C02XC101D4`80>A<0038C00<04a<0oa<i4`0301<C00`C00<04a<0AA<00`0C4`0^4`@0

DA<00`0C4`0g4`00<Q<00`0C4`3o4cPC00<04a<03A<00`0C4`144`0301<C03<C0P1?4`80>1<0038C

00<04a<0oa<g4`0301<C00hC00<04a<0A1<00`0C4`0e4`@0C1<203LC000b4`0301<C0?lC=Q<00`0C

4`0?4`0301<C04@C00<04a<0>A<204/C00<04a<0=A<0038C00<04a<0oa<f4`0301<C00lC0P144`03

01<C03`C10174`80=Q<0038C00<04a<0oa<e4`0301<C010C00<04a<0@a<00`0C4`0o4`<0AQ<00`0C

4`0d4`00<Q<00`0C4`3o4cDC00<04a<041<00`0C4`134`0301<C048C0`134`80=A<0024C00<04a<0

0Q<00`0C4`024`0301<C00@C00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`164`<0@A<00`0C

4`0c4`0081<00`0C00074`0301<000DC00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`194`80

?a<00`0C4`0c4`006a<3008C00<04`002A<00`0C4`034`80oa<d4`0301<C018C00<04a<0@Q<00`0C

4`1;4`<0?A<00`0C4`0b4`0081<00`0C00074`801Q<00`0C4`3o4c<C00<04a<04Q<204<C00<04a<0

CQ<203/C00<04a<0<Q<0020C00<04`001a<00`0C4`054`0301<C0?lC<Q<00`0C4`0C4`0301<C044C

00<04a<0DA<303PC00<04a<0<Q<0024C00<04a<01Q<300DC00<04a<0oa<b4`0301<C01<C00<04a<0

@A<00`0C4`1D4`80=a<00`0C4`0a4`00<Q<00`0C4`3o4c4C00<04a<051<00`0C4`114`0301<C05HC

0`0d4`0301<C034C000b4`0301<C0?lC<A<00`0C4`0>4`0301<C00<C00<04a<0@1<00`0C4`1I4`<0

<Q<2038C000b4`0301<C0?lC<1<00`0C4`0>4`0301<000@C00<04a<0@1<00`0C4`1L4`80<A<00`0C

4`0`4`00<Q<00`0C4`3o4c0C00<04a<02A<300@C00<04a<00Q<3040C00<04a<0GQ<202lC00<04a<0

<1<0038C00<04a<0oa<`4`0301<C00hC0P054`0301<C03lC00<04a<0HA<302`C00<04a<0<1<0038C

00<04a<0oa<`4`0301<C00hC00<04a<011<00`0C4`0o4`0301<C06@C00<04a<0:A<00`0C4`0`4`00

<Q<00`0C4`3o4blC00<04a<03a<300@C00<04a<0?a<00`0C4`1U4`<0:1<2034C000b4`0301<C0?lC

;a<00`0C4`0F4`0301<C03lC00<04a<0J1<00`0C4`0V4`0301<C02lC000b4`0301<C0?lC;a<00`0C

4`0F4`0301<C03lC00<04a<0JA<302DC00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC0P104`03

01<C06`C0P0S4`0301<C02lC000b4`0301<C0?lC;a<00`0C4`0F4`0301<C03lC00<04a<0KA<2028C

00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC00<04a<0?a<00`0C4`1_4`8081<00`0C4`0_4`00

<Q<00`0C4`3o4bhC00<04a<05a<00`0C4`0n4`0301<C078C0P0N4`0301<C02lC000L4`0301<C008C

00@04a<C0`034`0301<C00@C00<04a<0oa<^4`0301<C01LC00<04a<0?Q<00`0C4`1d4`8071<00`0C

4`0_4`006a<00`0C00074`0301<C008C00<04`001A<00`0C4`3o4bhC00<04a<05a<203lC00<04a<0

MQ<201XC00<04a<0;a<001HC0`024`0301<000PC00<04a<00a<00`0C4`034`80oa<_4`0301<C01LC

00<04a<0?Q<00`0C4`1h4`0301<C01HC00<04a<0<1<001/C00<04`0021<0100C4a<200HC00<04a<0

oa<]4`0301<C01PC00<04a<0?Q<00`0C4`1i4`805Q<00`0C4`0`4`006a<00`0C00074`0301<0008C

00<04a<01A<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07/C00<04a<04a<00`0C4`0`4`00

71<00`0C4`074`0401<C4`<01A<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07`C00<04a<0

4Q<00`0C4`0`4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0m4`0301<C07hC0P0B4`0301<C030C

000b4`0301<C0?lC;A<00`0C4`0H4`80?Q<00`0C4`204`8041<00`0C4`0`4`00<Q<00`0C4`3o4bdC

00<04a<061<00`0C4`0Q4`D00Q<00`0C4`0B4`0301<C00/C1@000a<0000Q4`D00Q<00`0C4`0O4`D0

0Q<00`0C4`0K4`0401<C4`D000<C00000a<00`0C4`0a4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C

4`0S4`0701<C4`0C000C4`0301<C00dC00L04a<C01<0028C00<04a<00Q<00`0C4`0Q4`0701<C4`0C

000L4`8011<00`0C4`034`0401<C03<C000b4`0301<C02HC00<04a<00Q<0100C4a<302<C00<04a<0

0Q<00`0C4`024`<08Q<00`0C4`024`0401<C4`8091<00`0C4`024`0301<C008C00<04a<09Q<5044C

00<04a<061<00`0C4`0S4`0301<C00<C00<04a<04A<00`0C4`0=4`0701<C4`0C000R4`0301<C008C

00<04a<08A<01`0C4a<04`007Q<01@0C4a<000@C0P024`0301<C034C000b4`0301<C02DC00<04`00

1a<00`0C4`0R4`0301<000TC00<04a<081<00`0C00074`0301<0028C00<04`001a<00`0C000Y4`03

01<C044C00<04a<061<00`0C4`0S4`0401<C4`8051<00`0C4`0=4`0401<C4`808a<00`0C4`034`03

01<C020C00<04a<00Q<00`0C4`0N4`8000<C01<00Q<00`0C00024`0301<C034C000b4`0301<C02DC

00<04`0021<00`0C4`0Q4`0301<000LC100Q4`0301<000LC00<04`008Q<00`0C00074`0301<002TC

00<04a<0@1<00`0C4`0I4`0301<C02<C00D04a<C000E4`0301<C00dC00D04a<C000T4`0701<C4`0C

000R4`0701<C4`0C000Q4`800a<01@0C01<003@C000b4`0301<C02DC00<04`0021<00`0C4`0Q4`03

01<000LC00<04`008Q<00`0C00074`808a<00`0C00084`0301<C02PC00<04a<0@1<00`0C4`0I4`80

8a<200<C0`0C4`0301<C00`C0P044`808A<200<C0`0Q4`8011<00`0C4`0P4`8011<200034`0C03<C

000b4`0301<C02DC00<04`001a<00`0C000R4`0301<000PC0P0R4`0301<000LC00<04a<08Q<00`0C

00074`0301<002TC00<04a<0@1<00`0C4`0I4`0301<C03dC00<04a<0R1<00`0C4`054`0301<C038C

000b4`0301<C02HC00<04a<01a<00`0C4`0R4`0301<C00PC00<04a<08A<00`0C4`074`808a<00`0C

4`074`0301<C02LC0P124`0301<C01TC00<04a<0?A<00`0C4`294`801A<00`0C4`0b4`00<Q<00`0C

4`3o4b`C00<04a<06A<00`0C4`0m4`0301<C08/C00D04a<C000e4`00<Q<00`0C4`3o4b`C00<04a<0

6A<00`0C4`0m4`0301<C08/C00@04a<04a<401lC000b4`0301<C0?lC;1<00`0C4`0I4`0301<C03dC

00<04a<0S1<201@C0`0P4`00<Q<00`0C4`3g4`<0:a?o00XC00<04a<07Q<0038C00<04a<0n1<00`0C

4`0[4`0301<C008C00@04a<021<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC

00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`034`0301<000LC00<04a<01Q<00`0C

4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC

00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<300HC

00<04a<031<2020C000/4nl00`d600TC00<04a<0<1<00`0C4`0I4`0301<C02HC00<04a<051<00`0C

4`0@4`0301<C02HC00<04a<09Q<00`0C4`0V4`0401<C03HC000b4`0301<C00PC00<04a<02A<00`0C

4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0C4`084`0301<C00TC

00<04a<02A<00`0C4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0C

4`084`0301<C00PC2`d24`0301<C00`C100`4`0301<C01TC00<04a<0?A<00`0C4`2;4`0501<C4`00

=A<0038C00<04a<0;1<00`0C4`0/4`0301<C02`C00<04a<0;1<00`0C4`0L4`<=3A<00`0C4`104`03

01<C01TC00<04a<0?A<00`0C4`2:4`0301<C008C00<04a<0<a<0038C00<04a<0e1<43E<C00<04a<0

6A<00`0C4`0m4`0301<C08TC00<04a<011<00`0C4`0b4`00<Q<00`0C4`3B4`8=Ea<00`0C4`0I4`80

?Q<00`0C4`274`801a<00`0C4`0b4`00<Q<00`0C4`3?4`<=FA<00`0C4`0I4`0301<C03dC00<04a<0

Qa<00`0C4`064`0301<C038C000b4`0301<C0<dC0PeM4`0301<C01PC00<04a<0?A<00`0C4`264`03

01<C00PC00<04a<0<A<0038C00<04a<0ba<23ElC00<04a<061<00`0C4`0m4`0301<C08@C0P0;4`03

01<C034C000b4`0301<C0<TC0PeQ4`0301<C01PC00<04a<0?A<00`0C4`234`0301<C00/C00<04a<0

<A<0038C00<04a<0aa<23F<C00<04a<061<00`0C4`0m4`0301<C088C00<04a<031<00`0C4`0a4`00

<Q<00`0C4`354`8=IA<00`0C4`0H4`80?Q<00`0C4`204`803a<00`0C4`0a4`00<Q<00`0C4`334`8=

Ia<00`0C4`0H4`0301<C03dC00<04a<0Oa<00`0C4`0@4`0301<C030C000b4`0301<C0<4C0PeY4`03

01<C01PC00<04a<0?Q<00`0C4`1l4`804a<00`0C4`0`4`00<Q<00`0C4`2o4`8=Ja<00`0C4`0H4`03

01<C03hC00<04a<0Na<201@C00<04a<0<1<0038C00<04a<0_A<23FdC00<04a<061<00`0C4`0n4`03

01<C07TC0P0F4`0301<C030C000b4`0301<C0;/C0Pe_4`0301<C01PC00<04a<0?Q<00`0C4`1h4`03

01<C01HC00<04a<0<1<0038C00<04a<0^A<23G8C00<04a<05a<203lC00<04a<0MQ<201TC00<04a<0

<1<0038C00<04a<0]Q<33G@C00<04a<05a<00`0C4`0n4`0301<C07@C0P0L4`0301<C02lC000L4`03

01<C008C00@04a<C0`034`0301<C00@C00<04a<0]1<23GLC00<04a<05a<00`0C4`0n4`0301<C07<C

00<04a<071<00`0C4`0_4`006a<00`0C00074`0301<C008C00<04`001A<00`0C4`2b4`8=NA<00`0C

4`0G4`0301<C03lC00<04a<0L1<201lC00<04a<0;a<001/C00<04`0021<00`0C4`034`0301<C00<C

0P2^4`D=O1<00`0C4`0F4`0301<C03lC00<04a<0KA<3024C00<04a<0;a<001/C00<04`0021<0100C

4a<200HC00<04a<0Sa<N3H4C00<04a<05Q<00`0C4`0o4`0301<C06`C0P0S4`0301<C02lC000K4`03

01<000LC00<04`000Q<00`0C4`054`0301<C08PC1`fO4`0301<C01HC0P104`0301<C06XC0P0U4`03

01<C02lC000L4`0301<C00LC00@04a<C0`054`0301<C08@C10fV4`0301<C01HC00<04a<0?a<00`0C

4`1X4`809a<00`0C4`0_4`00<Q<00`0C4`214`<=ZQ<00`0C4`0F4`0301<C03lC00<04a<0IQ<202TC

00<04a<0;a<0038C00<04a<0Oa<23JhC00<04a<05A<00`0C4`0o4`0301<C06@C0P0Z4`0301<C030C

000b4`0301<C07dC0Pf`4`0301<C00lC00<04a<00a<00`0C4`0o4`0301<C068C0P0/4`0301<C030C

000b4`0301<C07/C0Pfb4`0301<C00hC00<04`0011<00`0C4`104`0301<C05hC0`0^4`0301<C030C

000b4`0301<C07TC0Pfd4`0301<C010C00<04a<00Q<3040C00<04a<0G1<3030C00<04a<0<1<0038C

00<04a<0N1<00`dC4`2e4`0301<C00dC0P054`0301<C040C00<04a<0FQ<2038C0P0b4`00<Q<00`0C

4`1f4`8=^1<00`0C4`0=4`0301<C00@C00<04a<0@A<00`0C4`1G4`80=1<00`0C4`0a4`00<Q<00`0C

4`1d4`8=^a<00`0C4`0<4`<011<00`0C4`114`0301<C05@C0`0f4`0301<C034C000b4`0301<C07<C

00<=4a<0^a<00`0C4`0C4`0301<C044C00<04a<0DQ<303LC0P0c4`00<Q<00`0C4`1a4`8=_a<00`0C

4`0B4`80@Q<00`0C4`1?4`<0>Q<00`0C4`0b4`00<Q<00`0C4`1`4`033A<C0;lC00<04a<04Q<00`0C

4`124`0301<C04`C0`0l4`0301<C038C000b4`0301<C06lC00<=4a<0`A<00`0C4`0A4`0301<C048C

00<04a<0BA<303hC00<04a<0<a<0038C00<04a<0KA<23L@C00<04a<04A<00`0C4`124`0301<C04LC

0`104`0301<C03<C000Q4`0301<C008C00<04a<00Q<00`0C4`044`0301<C06`C00<=4a<0aA<00`0C

4`0@4`0301<C048C00<04a<0A1<3048C0P0e4`0081<00`0C00074`0301<000DC00<04a<0JQ<23LPC

00<04a<041<00`0C4`134`0301<C040C0`154`0301<C03@C000P4`0301<000TC00<04a<00a<206XC

00<=4a<0bA<00`0C4`0?4`80A1<00`0C4`0m4`<0Aa<203HC000P4`0301<000LC0P064`0301<C06PC

00<=4a<0bQ<00`0C4`0?4`0301<C04@C00<04a<0>A<304XC00<04a<0=A<0020C00<04`001a<00`0C

4`054`0301<C06HC0Pg>4`0301<C00hC00<04a<0A1<00`0C4`0f4`@0Ba<203LC000Q4`0301<C00HC

0`054`0301<C06DC00<=4a<0ca<00`0C4`0=4`0301<C04@C00<04a<0<a<304lC00<04a<0=Q<0038C

00<04a<0I1<00`dC4`3A4`0301<C00`C00<04a<0AA<00`0C4`0_4`<0DA<00`0C4`0g4`00<Q<53F4C

00<=4a<0dQ<00`0C4`0<4`0301<C04DC00<04a<0:a<405<C0P0i4`00<Q<00`0C4`024`P=Ea<23MHC

00<04a<02a<204LC00<04a<09a<405HC00<04a<0>1<0038C00<04a<02Q<43E8C00<=4a<0eQ<00`0C

4`0;4`0301<C04HC00<04a<08a<505PC0P0j4`00<Q<00`0C4`0>4`@=CA<00`dC4`3H4`802a<00`0C

4`164`0301<C020C101K4`80>a<0038C00<04a<04Q<33DPC0PgM4`0301<C00PC00<04a<0Aa<00`0C

4`0K4`@0Ga<00`0C4`0j4`00<Q<00`0C4`0E4`@=@Q<23N0C00<04a<01a<00`0C4`174`8061<5064C

00<04a<0>a<0038C00<04a<06A<33ChC00<=4a<0h1<00`0C4`074`0301<C04PC00<04a<04a<406@C

0P0m4`00<Q<00`0C4`0L4`8=>Q<23N@C00<04a<01Q<204XC00<04a<03Q<406LC0P0n4`00<Q<00`0C

4`0N4`<==A<23NLC0P064`0301<C04TC00<04a<02Q<406XC0P0o4`00<Q<00`0C4`0Q4`8=<Q<00`dC

4`3Y4`0301<C00<C00<04a<0BQ<00`0C4`054`D0K1<2040C000b4`0301<C02<C0`d]4`8=kA<200<C

00<04a<0BQ<200034`0000<0L1<2044C000b4`0301<C02HC0PdY4`8=ia<5008C00@04a<00Q<00`0C

4`194`D0La<2048C000L4`0301<C008C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0:1<43B<C

0Pg[4`0701<C4`0C00024`<0Aa<5008C00<04a<0LA<204<C000K4`0301<000PC00L04a<C01<000DC

00<04a<0;1<43AdC0Pg]4`0701<C4`0C00044`<0@1<500PC00<04a<0KQ<204DC000K4`0301<000PC

00<04a<00a<00`0C4`034`80<A<23ATC0Pg_4`0701<C4`0C00044`0401<003XC1@0=4`0301<C06dC

0P164`006a<00`0C00094`0301<C00801Q<00`0C4`0b4`@=41<53O4C00L04a<C01<000@C00@04a<C

0`0a4`H04a<206/C0`174`006a<00`0C00074`0301<0008C00<04a<01A<00`0C4`0f4a0=mA<200@C

00<04a<00a<00`0C4`044`<0:1<701TC0P1P4`033A<C00HC0P194`0071<00`0C4`064`<00Q<300DC

00<04a<0oa=84`0301<C00LC1@0K4`T081<00`0C4`1K4`H=0a<304/C000b4`0301<C0?lCB1<00`0C

4`0<4a`0:A<205XC2@d204dC000b4`0301<C0?lCB1<205<C0P1I4`T=Ca<0038C00<04a<0oa=84`03

01<C05<C0P1H4`T=Ca<0038C00<04a<0oa=84`0301<C05@C0P1F4`/=CQ<0038C00<04a<0oa=84`03

01<C05HC0P1?4`D000<C3@d01`e?4`00<Q<00`0C4`3o4dPC00<04a<0Ea<304PC1P054`T=Ca<0038C

00<04a<0oa=84`0301<C05TC0`104`L02Q<93DlC000b4`0301<C0?lCB1<205`C0`0h4`L04A<63E4C

000b4`0301<C0?lCB1<00`0C4`1N4`<0;Q<801XC00<=4a<0DA<0038C00<04a<0oa=84`0301<C060C

1@0S4`P0MA<0038C00<04a<0oa=84`0301<C06@C1`0D4`X0O1<0038C00<04a<0oa=84`0301<C06XC

5@264`00<Q<00`0C4`3o4dPC00<04a<0oa<64`00:A<500@C00<04a<0oa=84`80oa<74`00:a<00`0C

4`044`0301<C0?lCB1<00`0C4`3o4`HC000[4`0301<C00@C0P3o4dTC00<04a<0oa<64`00:a<00`0C

4`3o4olCF1<002/C00<04a<0oa?o4ePC000Z4`80oa?o4eXC003o4olCQQ<00?lCoa>64`00oa?o4hHC

003o4olCQQ<00?lCoa>64`00TQ<400034`0000L00Q<00`0C4`024`0401<C4`8011<00`0C4`024`03

01<C0?lCc1<0098C0`084`0701<C4`0C00094`0501<C4`000a<00`0C00324`80oa<94`00U1<00`0C

4`04008C00L04a<C01<000PC00<04a<00Q<00`0C4`034`0301<C0<4C00<04a<0oa<74`006A<40003

4`0000H00Q<:008C0P024`<00Q<300<C0P001Q<0000C04PC0P084`0301<C008C00<04a<021<00`0C

4`024`0301<C0080`Q<3008C00<04a<0oa<44`006Q<01P0C4`0C008C00<04`0011<01P0C4`0C008C

00<04`001A<00`0C4`024`0501<C4`000Q<0100C01<2058C00L04a<C01<000LC00<04`000Q<00`0C

00024`0301<C00@C00<04a<0^A<0200C4`0C01<0oa<54`006Q<01P0C4`0C00@C00<04a<00Q<00`0C

4`024`0301<C008C00<04a<00a<00`0C4`024`0501<C4`000Q<0100C01<2054C0P044`0301<C00LC

00@04a<C0`024`<00a<00`0C4`2j4`0801<C01<04`3o4`DC000J4`0501<C01<00P034`800a<00`0C

4`024`800a<00`0C4`034`0301<C008C00D04a<C00024`0601<001<0oa<_4`<000@C01<0oa<54`00

6Q<01P0C4`0C008C00<04`000Q<00`0C00044`0>01<C01<04`0C01<04`024`0501<C4`000Q<01P0C

000C0?lC<a<00`0C003o4`DC000I4`@000<C00002`024`D000DC00004`0500044`0000<C0P0011<0

01<20?lC=1<00`0C4`3o4`@C003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00

oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC0000\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.77084, -14.119, 0.0242408, 0.16996}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -57 0 ]

[.5 .63053 57 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -118 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(18.6550000000000011`) show

173.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .51524 m

.02499 .51524 L

.02606 .51525 L

.02729 .51526 L

.02846 .51528 L

.03053 .51532 L

.03279 .51538 L

.03527 .51547 L

.0379 .51558 L

.04262 .51585 L

.04749 .51621 L

.05205 .51662 L

.06245 .5178 L

.07305 .51937 L

.08274 .5211 L

.10458 .52594 L

.14429 .5373 L

.18248 .54939 L

.2038 .55564 L

.22313 .56043 L

.23281 .5624 L

.24328 .56413 L

.24808 .56477 L

.25316 .56533 L

.2575 .56572 L

.26226 .56604 L

.26477 .56616 L

.26609 .56621 L

.2675 .56626 L

.26872 .56629 L

.26937 .5663 L

.27008 .56631 L

.27131 .56632 L

.27246 .56633 L

.27359 .56633 L

.27483 .56632 L

.27612 .5663 L

.27732 .56627 L

.27844 .56624 L

.27947 .56621 L

.28177 .56611 L

.28445 .56596 L

.28693 .56578 L

.29253 .56524 L

.29746 .56462 L

.30268 .5638 L

.31212 .5619 L

.32226 .55926 L

.34057 .55289 L

.36174 .54306 L

Mistroke

.38185 .53149 L

.42009 .50467 L

.46079 .47242 L

.49997 .44229 L

.51998 .42877 L

.5416 .41635 L

.56251 .4069 L

.57245 .40335 L

.58172 .40058 L

.5916 .39818 L

.60059 .39648 L

.61057 .39508 L

.61606 .39451 L

.62126 .39409 L

.62587 .3938 L

.63094 .39357 L

.63349 .39348 L

.63624 .39341 L

.63751 .39339 L

.63884 .39336 L

.64008 .39335 L

.64121 .39333 L

.64235 .39332 L

.64342 .39332 L

.64455 .39331 L

.64578 .39331 L

.64685 .39331 L

.64799 .39331 L

.64896 .39331 L

.65002 .39332 L

.65128 .39333 L

.65242 .39333 L

.655 .39336 L

.65964 .39342 L

.66888 .39356 L

.67132 .39359 L

.67395 .39362 L

.67643 .39364 L

.67761 .39365 L

.67871 .39366 L

.6799 .39366 L

.6812 .39367 L

.68247 .39367 L

.68318 .39367 L

.68382 .39367 L

.68455 .39366 L

.68522 .39366 L

.68595 .39366 L

.68673 .39365 L

.68804 .39364 L

Mistroke

.68948 .39362 L

.69196 .39357 L

.69463 .39351 L

.69715 .39343 L

.69946 .39335 L

.70423 .39311 L

.70931 .39278 L

.71846 .39193 L

.72406 .39124 L

.72933 .39046 L

.73919 .38865 L

.75928 .38348 L

.77776 .37701 L

.81726 .35884 L

.85526 .33934 L

.87642 .32945 L

.8957 .32185 L

.90528 .3187 L

.9157 .3158 L

.92546 .31358 L

.93463 .31193 L

.94404 .31066 L

.94903 .31014 L

.95442 .30971 L

.95976 .30939 L

.96245 .30928 L

.96538 .30917 L

.9679 .30911 L

.96931 .30908 L

.97059 .30906 L

.97178 .30904 L

.97308 .30903 L

.9743 .30902 L

.97543 .30902 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.89036 .54503 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4gdC00<04a<0oa<64`00oa=m4`0301<C0?lC1Q<002TC1@3o4dlC0P3o4`LC

000[4`0301<C0?lCCa<00`0C4`1^4`d0RQ<002DC0`034`0301<C00@C0P3o4dTC00<04a<0IQ<800`C

3@1n4`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`1Q4`D081<807LC000[4`0301<C00@C00<04a<0

oa=84`0301<C05hC100/4`L0L1<002XC0P064`0301<C0?lCB1<00`0C4`1L4`<0=A<706XC000b4`03

01<C0?lCB1<205/C0P0o4`H0I1<0038C00<04a<0oa=84`0301<C05PC0P164`H0Ga<0038C00<04a<0

oa=84`0301<C05HC0P1>4`D0FQ<0038C00<04a<0oa=84`0301<C05DC0P1C4`D0EQ<0038C00<04a<0

oa=84`0301<C05@C00<04a<0Ea<5058C000b4`0301<C0?lCB1<205<C0P1N4`<0D1<0038C00<04a<0

oa=84`0301<C00lC5P0/4`80HA<404dC000b4`0301<C0?lCB1<00`0C4`0:4`D05Q<9028C0P1U4`<0

Ba<0038C00<04a<0oa=84`0301<C00DC1@0S4`L06a<206PC0`194`00<Q<00`0C4`3o4c/C1@024`03

01<C00<C00<04a<00a<202lC1P0D4`80Ja<204PC000b4`0301<C0?lC?A<01`0C4a<04`0011<00`0C

4`0303HC1P0>4`80KA<304HC000b4`0301<C0?lC=a<300<C00L04a<C01<000@C0`0n4`H02A<00`0C

4`1^4`80AA<0038C00<04a<0oa<m4`0701<C4`0C00034`80AA<500@C00<04a<0L1<204@C000L4`03

01<C008C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0oa<m4`0701<C4`0C00024`0301<004XC

1@1d4`80@Q<001/C00<04`0021<01`0C4a<04`001A<00`0C4`3o4c`C0P044`0401<0008C00<04a<0

Ba<6074C0P114`005Q<3008C00<04`0021<00`0C4`034`0301<C00<C0P3o4d<C0P044`0301<C04XC

00<04a<011<406hC0P104`006a<00`0C00094`0301<C00801Q<00`0C4`3o4d4C00<04a<011<00`0C

4`194`0301<C00TC101[4`0301<C03hC000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C0?lC

@1<00`0C4`054`80BQ<00`0C4`0=4`@0J1<203hC000L4`0301<C00HC0`024`<01A<00`0C4`3o4clC

00<04a<01Q<00`0C4`184`0301<C018C101U4`0301<C03`C000b4`0301<C0?lC?Q<00`0C4`074`03

01<C04PC00<04a<05A<5068C00<04a<0>a<0038C00<04a<0oa<m4`0301<C00PC00<04a<0Aa<00`0C

4`0J4`@0Ga<203`C000b4`0301<C0?lC?1<00`0C4`094`0301<C04HC00<04a<07a<405`C0P0k4`00

<Q<00`0C4`3o4c/C00<04a<02Q<00`0C4`164`0301<C028C1@1I4`0301<C03TC000b4`0301<C0?lC

>Q<00`0C4`0;4`80Aa<00`0C4`0V4`@0Ea<00`0C4`0h4`00<Q<00`0C4`3o4cTC00<04a<031<00`0C

4`154`0301<C02XC101D4`80>A<0038C00<04a<0oa<i4`0301<C00`C00<04a<0AA<00`0C4`0^4`@0

DA<00`0C4`0g4`00<Q<00`0C4`3o4cPC00<04a<03A<00`0C4`144`0301<C03<C0P1?4`80>1<0038C

00<04a<0oa<g4`0301<C00hC00<04a<0A1<00`0C4`0e4`@0C1<203LC000b4`0301<C0?lC=Q<00`0C

4`0?4`0301<C04@C00<04a<0>A<204/C00<04a<0=A<0038C00<04a<0oa<f4`0301<C00lC0P144`03

01<C03`C10174`80=Q<0038C00<04a<0oa<e4`0301<C010C00<04a<0@a<00`0C4`0o4`<0AQ<00`0C

4`0d4`00<Q<00`0C4`3o4cDC00<04a<041<00`0C4`134`0301<C048C0`134`80=A<0024C00<04a<0

0Q<00`0C4`024`0301<C00@C00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`164`<0@A<00`0C

4`0c4`0081<00`0C00074`0301<000DC00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`194`80

?a<00`0C4`0c4`006a<3008C00<04`002A<00`0C4`034`80oa<d4`0301<C018C00<04a<0@Q<00`0C

4`1;4`<0?A<00`0C4`0b4`0081<00`0C00074`801Q<00`0C4`3o4c<C00<04a<04Q<204<C00<04a<0

CQ<203/C00<04a<0<Q<0020C00<04`001a<00`0C4`054`0301<C0?lC<Q<00`0C4`0C4`0301<C044C

00<04a<0DA<303PC00<04a<0<Q<0024C00<04a<01Q<300DC00<04a<0oa<b4`0301<C01<C00<04a<0

@A<00`0C4`1D4`80=a<00`0C4`0a4`00<Q<00`0C4`3o4c4C00<04a<051<00`0C4`114`0301<C05HC

0`0d4`0301<C034C000b4`0301<C0?lC<A<00`0C4`0>4`0301<C00<C00<04a<0@1<00`0C4`1I4`<0

<Q<2038C000b4`0301<C0?lC<1<00`0C4`0>4`0301<000@C00<04a<0@1<00`0C4`1L4`80<A<00`0C

4`0`4`00<Q<00`0C4`3o4c0C00<04a<02A<300@C00<04a<00Q<3040C00<04a<0GQ<202lC00<04a<0

<1<0038C00<04a<0oa<`4`0301<C00hC0P054`0301<C03lC00<04a<0HA<302`C00<04a<0<1<0038C

00<04a<0oa<`4`0301<C00hC00<04a<011<00`0C4`0o4`0301<C06@C00<04a<0:A<00`0C4`0`4`00

<Q<00`0C4`3o4blC00<04a<03a<300@C00<04a<0?a<00`0C4`1U4`<0:1<2034C000b4`0301<C0?lC

;a<00`0C4`0F4`0301<C03lC00<04a<0J1<00`0C4`0V4`0301<C02lC000b4`0301<C0?lC;a<00`0C

4`0F4`0301<C03lC00<04a<0JA<302DC00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC0P104`03

01<C06`C0P0S4`0301<C02lC000b4`0301<C0?lC;a<00`0C4`0F4`0301<C03lC00<04a<0KA<2028C

00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC00<04a<0?a<00`0C4`1_4`8081<00`0C4`0_4`00

<Q<00`0C4`3o4bhC00<04a<05a<00`0C4`0n4`0301<C078C0P0N4`0301<C02lC000L4`0301<C008C

00@04a<C0`034`0301<C00@C00<04a<0oa<^4`0301<C01LC00<04a<0?Q<00`0C4`1d4`8071<00`0C

4`0_4`006a<00`0C00074`0301<C008C00<04`001A<00`0C4`3o4bhC00<04a<05a<203lC00<04a<0

MQ<201XC00<04a<0;a<001HC0`024`0301<000PC00<04a<00a<00`0C4`034`80oa<_4`0301<C01LC

00<04a<0?Q<00`0C4`1h4`0301<C01HC00<04a<0<1<001/C00<04`0021<0100C4a<200HC00<04a<0

oa<]4`0301<C01PC00<04a<0?Q<00`0C4`1i4`805Q<00`0C4`0`4`006a<00`0C00074`0301<0008C

00<04a<01A<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07/C00<04a<04a<00`0C4`0`4`00

71<00`0C4`074`0401<C4`<01A<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07`C00<04a<0

4Q<00`0C4`0`4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0m4`0301<C07hC0P0B4`0301<C030C

000b4`0301<C0?lC;A<00`0C4`0H4`80?Q<00`0C4`204`8041<00`0C4`0`4`00<Q<00`0C4`3o4bdC

00<04a<061<00`0C4`0Q4`D00Q<00`0C4`0B4`0301<C00/C1@000a<0000Q4`D00Q<00`0C4`0O4`D0

0Q<00`0C4`0K4`0401<C4`D000<C00000a<00`0C4`0a4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C

4`0S4`0701<C4`0C000C4`0301<C00dC00L04a<C01<0028C00<04a<00Q<00`0C4`0Q4`0701<C4`0C

000L4`8011<00`0C4`034`0401<C03<C000b4`0301<C02HC00<04a<00Q<0100C4a<302<C00<04a<0

0Q<00`0C4`024`<08Q<00`0C4`024`0401<C4`8091<00`0C4`024`0301<C008C00<04a<09Q<5044C

00<04a<061<00`0C4`0S4`0301<C00<C00<04a<04A<00`0C4`0=4`0701<C4`0C000R4`0301<C008C

00<04a<08A<01`0C4a<04`007Q<01@0C4a<000@C0P024`0301<C034C000b4`0301<C02DC00<04`00

1a<00`0C4`0R4`0301<000TC00<04a<081<00`0C00074`0301<0028C00<04`001a<00`0C000Y4`03

01<C044C00<04a<061<00`0C4`0S4`0401<C4`8051<00`0C4`0=4`0401<C4`808a<00`0C4`034`03

01<C020C00<04a<00Q<00`0C4`0N4`8000<C01<00Q<00`0C00024`0301<C034C000b4`0301<C02DC

00<04`0021<00`0C4`0Q4`0301<000LC100Q4`0301<000LC00<04`008Q<00`0C00074`0301<002TC

00<04a<0@1<00`0C4`0I4`0301<C02<C00D04a<C000E4`0301<C00dC00D04a<C000T4`0701<C4`0C

000R4`0701<C4`0C000Q4`800a<01@0C01<003@C000b4`0301<C02DC00<04`0021<00`0C4`0Q4`03

01<000LC00<04`008Q<00`0C00074`808a<00`0C00084`0301<C02PC00<04a<0@1<00`0C4`0I4`80

8a<200<C0`0C4`0301<C00`C0P044`808A<200<C0`0Q4`8011<00`0C4`0P4`8011<200034`0C03<C

000b4`0301<C02DC00<04`001a<00`0C000R4`0301<000PC0P0R4`0301<000LC00<04a<08Q<00`0C

00074`0301<002TC00<04a<0@1<00`0C4`0I4`0301<C03dC00<04a<0R1<00`0C4`054`0301<C038C

000b4`0301<C02HC00<04a<01a<00`0C4`0R4`0301<C00PC00<04a<08A<00`0C4`074`808a<00`0C

4`074`0301<C02LC0P124`0301<C01TC00<04a<0?A<00`0C4`294`801A<00`0C4`0b4`00<Q<00`0C

4`3o4b`C00<04a<06A<00`0C4`0m4`0301<C08/C00D04a<C000e4`00<Q<00`0C4`3o4b`C00<04a<0

6A<00`0C4`0m4`0301<C08/C00@04a<04a<401lC000b4`0301<C0?lC;1<00`0C4`0I4`0301<C03dC

00<04a<0S1<201@C0`0P4`00<Q<00`0C4`3g4`<0:a?o00XC00<04a<07Q<0038C00<04a<0n1<00`0C

4`0[4`0301<C008C00@04a<021<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC

00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`034`0301<000LC00<04a<01Q<00`0C

4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC

00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<300HC

00<04a<031<2020C000/4nl00`d600TC00<04a<0<1<00`0C4`0I4`0301<C02HC00<04a<051<00`0C

4`0@4`0301<C02HC00<04a<09Q<00`0C4`0V4`0401<C03HC000b4`0301<C00PC00<04a<02A<00`0C

4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0C4`084`0301<C00TC

00<04a<02A<00`0C4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0C

4`084`0301<C00TC00<03@d01`d24`0301<C00`C100`4`0301<C01TC00<04a<0?A<00`0C4`2;4`05

01<C4`00=A<0038C00<04a<0;1<00`0C4`0/4`0301<C02`C00<04a<0;1<00`0C4`0L4`D=2a<00`0C

4`104`0301<C01TC00<04a<0?A<00`0C4`2:4`0301<C008C00<04a<0<a<0038C00<04a<0eQ<23E<C

00<04a<06A<00`0C4`0m4`0301<C08TC00<04a<011<00`0C4`0b4`00<Q<00`0C4`3C4`<=EA<00`0C

4`0I4`80?Q<00`0C4`274`801a<00`0C4`0b4`00<Q<00`0C4`3A4`8=F1<00`0C4`0I4`0301<C03dC

00<04a<0Qa<00`0C4`064`0301<C038C000b4`0301<C0<hC0`eK4`0301<C01PC00<04a<0?A<00`0C

4`264`0301<C00PC00<04a<0<A<0038C00<04a<0c1<23EhC00<04a<061<00`0C4`0m4`0301<C08@C

0P0;4`0301<C034C000b4`0301<C0<XC0PeP4`0301<C01PC00<04a<0?A<00`0C4`234`0301<C00/C

00<04a<0<A<0038C00<04a<0b1<23F8C00<04a<061<00`0C4`0m4`0301<C088C00<04a<031<00`0C

4`0a4`00<Q<00`0C4`364`8=I1<00`0C4`0H4`80?Q<00`0C4`204`803a<00`0C4`0a4`00<Q<00`0C

4`344`8=IQ<00`0C4`0H4`0301<C03dC00<04a<0Oa<00`0C4`0@4`0301<C030C000b4`0301<C0<8C

0PeX4`0301<C01PC00<04a<0?Q<00`0C4`1l4`804a<00`0C4`0`4`00<Q<00`0C4`304`8=JQ<00`0C

4`0H4`0301<C03hC00<04a<0Na<201@C00<04a<0<1<0038C00<04a<0_Q<23F`C00<04a<061<00`0C

4`0n4`0301<C07TC0P0F4`0301<C030C000b4`0301<C0;/C0`e^4`0301<C01PC00<04a<0?Q<00`0C

4`1h4`0301<C01HC00<04a<0<1<0038C00<04a<0^A<23G8C00<04a<05a<203lC00<04a<0MQ<201TC

00<04a<0<1<0038C00<04a<0]Q<33G@C00<04a<05a<00`0C4`0n4`0301<C07@C0P0L4`0301<C02lC

000L4`0301<C008C00@04a<C0`034`0301<C00@C00<04a<0]1<23GLC00<04a<05a<00`0C4`0n4`03

01<C07<C00<04a<071<00`0C4`0_4`006a<00`0C00074`0301<C008C00<04`001A<00`0C4`2`4`@=

NA<00`0C4`0G4`0301<C03lC00<04a<0L1<201lC00<04a<0;a<001/C00<04`0021<00`0C4`034`03

01<C00<C0P2^4`<=OQ<00`0C4`0F4`0301<C03lC00<04a<0KA<3024C00<04a<0;a<001/C00<04`00

21<0100C4a<200HC00<04a<0TA<L3H4C00<04a<05Q<00`0C4`0o4`0301<C06`C0P0S4`0301<C02lC

000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C08/C1PfM4`0301<C01HC0P104`0301<C06XC

0P0U4`0301<C02lC000L4`0301<C00LC00@04a<C0`054`0301<C08HC1@fS4`0301<C01HC00<04a<0

?a<00`0C4`1X4`809a<00`0C4`0_4`00<Q<00`0C4`244`8=Z1<00`0C4`0F4`0301<C03lC00<04a<0

IQ<202TC00<04a<0;a<0038C00<04a<0PA<33J/C00<04a<05A<00`0C4`0o4`0301<C06@C0P0Z4`03

01<C030C000b4`0301<C07lC0Pf^4`0301<C00lC00<04a<00a<00`0C4`0o4`0301<C068C0P0/4`03

01<C030C000b4`0301<C07dC0Pf`4`0301<C00hC00<04`0011<00`0C4`104`0301<C05hC0`0^4`03

01<C030C000b4`0301<C07/C0Pfb4`0301<C010C00<04a<00Q<3040C00<04a<0G1<3030C00<04a<0

<1<0038C00<04a<0NA<23KDC00<04a<03A<200DC00<04a<0@1<00`0C4`1J4`80<Q<2038C000b4`03

01<C07LC0Pfg4`0301<C00dC00<04a<011<00`0C4`114`0301<C05LC0P0d4`0301<C034C000b4`03

01<C07DC0Pfj4`0301<C00`C0`044`0301<C044C00<04a<0E1<303HC00<04a<0<A<0038C00<04a<0

La<23K`C00<04a<04a<00`0C4`114`0301<C058C0`0g4`80<a<0038C00<04a<0LQ<00`dC4`2m4`03

01<C018C0P124`0301<C04lC0`0j4`0301<C038C000b4`0301<C074C00<=4a<0_Q<00`0C4`0B4`03

01<C048C00<04a<0C1<303`C00<04a<0<Q<0038C00<04a<0L1<00`dC4`304`0301<C014C00<04a<0

@Q<00`0C4`194`<0?Q<00`0C4`0c4`00<Q<00`0C4`1_4`033A<C0<4C00<04a<04A<00`0C4`124`03

01<C04LC0`104`0301<C03<C000Q4`0301<C008C00<04a<00Q<00`0C4`044`0301<C06dC0Pg54`03

01<C010C00<04a<0@Q<00`0C4`144`<0@Q<203DC000P4`0301<000LC00<04`001A<00`0C4`1/4`03

3A<C0<DC00<04a<041<00`0C4`134`0301<C040C0`154`0301<C03@C000P4`0301<000TC00<04a<0

0a<206`C00<=4a<0aa<00`0C4`0?4`80A1<00`0C4`0m4`<0Aa<203HC000P4`0301<000LC0P064`03

01<C06XC00<=4a<0b1<00`0C4`0?4`0301<C04@C00<04a<0>A<304XC00<04a<0=A<0020C00<04`00

1a<00`0C4`054`0301<C06TC00<=4a<0bQ<00`0C4`0>4`0301<C04@C00<04a<0=Q<404/C0P0g4`00

8A<00`0C4`064`<01A<00`0C4`1X4`033A<C0<`C00<04a<03A<00`0C4`144`0301<C03<C0`1?4`03

01<C03HC000b4`0301<C06HC0Pg@4`0301<C00`C00<04a<0AA<00`0C4`0_4`<0DA<00`0C4`0g4`00

<Q<00`0C4`1U4`033A<C0=0C00<04a<031<00`0C4`154`0301<C02/C101C4`80>A<0038C00<04a<0

I1<00`dC4`3B4`0301<C00/C0P174`0301<C02LC101F4`0301<C03PC000b4`0301<C06<C00<=4a<0

da<00`0C4`0;4`0301<C04HC00<04a<08a<505PC0P0j4`00<Q<00`0C4`1Q4`8=ea<200/C00<04a<0

AQ<00`0C4`0P4`@0Fa<203/C000b4`0301<C060C00<=4a<0fA<00`0C4`084`0301<C04LC00<04a<0

6a<405lC00<04a<0>Q<0038C00<04a<0Ga<00`dC4`3K4`0301<C00LC00<04a<0Aa<201PC1@1Q4`03

01<C03/C000b4`0301<C05dC0PgN4`0301<C00LC00<04a<0B1<00`0C4`0C4`@0I1<203dC000b4`<=

Fa<23N4C00<04a<01Q<204XC00<04a<03Q<406LC0P0n4`00<Q<00`0C3@0:3E0C00<=4a<0hQ<200HC

00<04a<0BA<00`0C4`0:4`@0JQ<203lC000b4`0301<C00XC10e:4`8=ia<00`0C4`034`0301<C04XC

00<04a<01A<506`C0P104`00<Q<00`0C4`0>4`@=A1<23NXC0P034`0301<C04XC0P000a<0000306XC

00<=4a<00a<2044C000b4`0301<C018C0`e04`033A<C0>8C1@024`0401<C008C00<04a<0BA<506/C

1Pd24`80@Q<001`C00<04a<00Q<00`0C4`024`0301<C008C00<04a<011<00`0C4`0E4`@=>Q<23NLC

00L04a<C01<0008C0`174`D00Q<00`0C4`1Y4`T=00<04a<0@A<001/C00<04`0021<01`0C4a<04`00

1A<00`0C4`0I4`<==A<23NTC00L04a<C01<000@C0`104`D021<00`0C4`1X4`T=A1<001/C00<04`00

21<00`0C4`034`0301<C00<C0P0M4`<=<A<00`dC4`3Y4`0701<C4`0C00044`0401<003XC1@0=4`03

01<C06PC2@e44`006a<00`0C00094`0301<C00801Q<00`0C4`0O4`@=:a<23N`C00L04a<C01<000@C

00@04a<C0`0a4`H04a<206LC2`e34`006a<00`0C00074`0301<0008C00<04a<01A<00`0C4`0S4`@=

9A<23NdC0P044`0301<C00<C00<04a<011<302PC1`0I4`80Ia<93D@C000L4`0301<C00HC0`024`<0

1A<00`0C4`0W4`@=7Q<33O/C00<04a<01a<501/C2@0P4`0301<C06@C00<03@d01`e44`00<Q<00`0C

4`0[4`8=6A<33OhC00<04a<031<L02TC0P1R4`<02@e44`00<Q<00`0C4`0]4`D=3a<53OlC0Q<205<C

0P1O4`<00a<63DHC000b4`0301<C038C3`go4`LC00<04a<0Da<205XC10094`033A<C04HC000b4`03

01<C0?lCB1<00`0C4`1D4`80EQ<405DC000b4`0301<C0?lCB1<00`0C4`1F4`80Ca<505TC000b4`03

01<C0?lCB1<00`0C4`1G4`<0B1<605dC000b4`0301<C0?lCB1<00`0C4`1I4`<0@1<7068C000b4`03

01<C0?lCB1<205`C0`0h4`L0J1<0038C00<04a<0oa=84`0301<C05hC0`0^4`P0KQ<0038C00<04a<0

oa=84`0301<C060C1@0S4`P0MA<0038C00<04a<0oa=84`0301<C06@C1`0D4`X0O1<0038C00<04a<0

oa=84`0301<C06XC5@264`00<Q<00`0C4`3o4dPC00<04a<0oa<64`00:A<500@C00<04a<0oa=84`80

oa<74`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`3o4`HC000[4`0301<C00@C0P3o4dTC00<04a<0

oa<64`00:a<00`0C4`3o4olCF1<002/C00<04a<0oa?o4ePC000Z4`80oa?o4eXC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00LA<400034`0000L00Q<00`0C4`024`0401<C4`80

11<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`03

01<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`0:0?lC[1<0074C0`084`07

01<C4`0C00074`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`03

01<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0a<00`0C4`024`0301<C0:4C0P3o4`TC001c4`0301<C00@00Q<01`0C4a<04`001a<00`0C00044`03

01<C008C00H04a<04`024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C

00024`0301<0008C00<04`000Q<00`0C00024`0301<000<C00<04a<00Q<00`0C4`2R4`0301<C0?lC

1a<001TC10000a<00006008C2P024`800Q<3008C0`034`8000HC00004`0W4`8021<00`0C4`024`03

01<C00HC0P034`800a<200<C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`03

01<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00034`0301<C008C00<04a<0

X1<3008C00<04a<0oa<44`006Q<01P0C4`0C008C00<04`0011<01P0C4`0C008C00<04`001A<00`0C

4`024`0501<C4`000Q<0100C01<2034C00L04a<C01<000LC00<04a<00Q<00`0C4`024`0301<C008C

00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C

00024`0301<0008C00<04`000Q<00`0C00034`0301<C008C00<04a<00a<00`0C4`2I4`0801<C01<0

4`3o4`DC000J4`0601<C01<011<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`034`0301<C008C

00D04a<C00024`0401<04`80<1<200@C00<04a<01a<2008C0`024`<00a<00`0C4`024`0301<C008C

00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C

4`024`0401<C4`800a<200@C00<04a<0VQ<0200C4`0C01<0oa<54`006Q<01@0C4`0C00800a<200<C

00<04a<00Q<200<C00<04a<00a<00`0C4`024`0501<C4`000Q<01P0C000C0?lC;a<300044`0C0?lC

1A<001XC00H04a<04`024`0301<0008C00<04`0011<03P0C4`0C01<04`0C01<00Q<01@0C4a<0008C

00H04`004`3o4c<C00<04`00oa<54`006A<400034`0000/00Q<500054`0001<01@0011<000034`80

00@C000C0P3o4c@C00<04a<0oa<44`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olC

QQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.77084, -14.119, 0.0242408, 0.16996}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -57 0 ]

[.5 .63053 57 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -118 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(18.9349999999999916`) show

173.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .54872 m

.02499 .54873 L

.02606 .54873 L

.02729 .54874 L

.02846 .54875 L

.03053 .54879 L

.03279 .54884 L

.03527 .54891 L

.0379 .549 L

.04262 .54922 L

.05205 .54984 L

.06245 .55079 L

.07293 .55203 L

.0842 .55364 L

.10458 .55722 L

.14581 .56612 L

.1664 .57076 L

.18551 .57476 L

.20518 .5782 L

.21483 .57954 L

.22371 .58053 L

.22841 .58095 L

.23356 .58131 L

.23607 .58145 L

.23875 .58157 L

.24023 .58163 L

.24158 .58167 L

.24287 .58171 L

.24423 .58174 L

.24536 .58175 L

.24661 .58177 L

.24774 .58177 L

.24881 .58178 L

.25006 .58177 L

.2512 .58176 L

.25246 .58174 L

.25378 .58172 L

.25602 .58165 L

.25811 .58157 L

.26284 .58132 L

.26546 .58113 L

.26789 .58093 L

.27336 .58037 L

.28329 .57897 L

.29232 .57725 L

.30188 .57496 L

.32146 .56872 L

.33977 .56101 L

.37859 .53905 L

.41987 .50895 L

Mistroke

.45963 .4766 L

.49788 .44636 L

.51923 .43136 L

.53857 .41962 L

.55899 .40949 L

.57775 .4024 L

.58714 .39965 L

.59704 .39731 L

.60698 .39549 L

.61258 .39469 L

.61787 .39406 L

.62278 .39359 L

.6281 .39318 L

.63295 .39289 L

.63742 .39269 L

.64225 .39254 L

.645 .39247 L

.64758 .39243 L

.6489 .39241 L

.65028 .39239 L

.65148 .39238 L

.65276 .39237 L

.65415 .39236 L

.65543 .39236 L

.65622 .39235 L

.65696 .39235 L

.65763 .39235 L

.65835 .39235 L

.65959 .39235 L

.66072 .39235 L

.66202 .39235 L

.66326 .39235 L

.66545 .39236 L

.66784 .39236 L

.66919 .39236 L

.67046 .39237 L

.67115 .39237 L

.67179 .39237 L

.67249 .39237 L

.67325 .39237 L

.67442 .39237 L

.67569 .39237 L

.67634 .39237 L

.67702 .39236 L

.67826 .39236 L

.67968 .39235 L

.68098 .39234 L

.68242 .39233 L

.68393 .39232 L

.68648 .39228 L

Mistroke

.68929 .39223 L

.69179 .39217 L

.69447 .39209 L

.69932 .39189 L

.70457 .39161 L

.70944 .39127 L

.71522 .39075 L

.72047 .39017 L

.7302 .38879 L

.74056 .38684 L

.75983 .38185 L

.78065 .3745 L

.82167 .3555 L

.86118 .33568 L

.88106 .32689 L

.89917 .32023 L

.9187 .3148 L

.92944 .31262 L

.93962 .31108 L

.94883 .31009 L

.95349 .30973 L

.95862 .30942 L

.96298 .30924 L

.96544 .30916 L

.96768 .3091 L

.96966 .30907 L

.97079 .30905 L

.97183 .30904 L

.97293 .30903 L

.97394 .30902 L

.9751 .30902 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.93579 .50029 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4gdC00<04a<0oa<64`00oa=m4`0301<C0?lC1Q<002TC1@3o4dlC0P3o4`LC

000[4`0301<C0?lCCa<00`0C4`1^4`d0RQ<002DC0`034`0301<C00@C0P3o4dTC00<04a<0IQ<800`C

3@1n4`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`1Q4`D081<807LC000[4`0301<C00@C00<04a<0

oa=84`0301<C05hC100/4`L0L1<002XC0P064`0301<C0?lCB1<00`0C4`1L4`<0=A<706XC000b4`03

01<C0?lCB1<205/C0P0o4`H0I1<0038C00<04a<0oa=84`0301<C05PC0P164`H0Ga<0038C00<04a<0

oa=84`0301<C05HC0P1>4`D0FQ<0038C00<04a<0oa=84`0301<C05DC0P1C4`D0EQ<0038C00<04a<0

oa=84`0301<C05@C00<04a<0Ea<5058C000b4`0301<C0?lCB1<205<C0P1N4`<0D1<0038C00<04a<0

oa=84`0301<C00lC5P0/4`80HA<404dC000b4`0301<C0?lCB1<00`0C4`0:4`D05Q<9028C0P1U4`<0

Ba<0038C00<04a<0oa=84`0301<C00DC1@0S4`L06a<206PC0`194`00<Q<00`0C4`3o4c/C1@024`03

01<C00<C00<04a<00a<202lC1P0D4`80Ja<204PC000b4`0301<C0?lC?A<01`0C4a<04`0011<00`0C

4`0303HC1P0>4`80KA<304HC000b4`0301<C0?lC=a<300<C00L04a<C01<000@C0`0n4`H02A<00`0C

4`1^4`80AA<0038C00<04a<0oa<m4`0701<C4`0C00034`80AA<500@C00<04a<0L1<204@C000L4`03

01<C008C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0oa<m4`0701<C4`0C00024`0301<004XC

1@1d4`80@Q<001/C00<04`0021<01`0C4a<04`001A<00`0C4`3o4c`C0P044`0401<0008C00<04a<0

Ba<6074C0P114`005Q<3008C00<04`0021<00`0C4`034`0301<C00<C0P3o4d<C0P044`0301<C04XC

00<04a<011<406hC0P104`006a<00`0C00094`0301<C00801Q<00`0C4`3o4d4C00<04a<011<00`0C

4`194`0301<C00TC101[4`0301<C03hC000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C0?lC

@1<00`0C4`054`80BQ<00`0C4`0=4`@0J1<203hC000L4`0301<C00HC0`024`<01A<00`0C4`3o4clC

00<04a<01Q<00`0C4`184`0301<C018C101U4`0301<C03`C000b4`0301<C0?lC?Q<00`0C4`074`03

01<C04PC00<04a<05A<5068C00<04a<0>a<0038C00<04a<0oa<m4`0301<C00PC00<04a<0Aa<00`0C

4`0J4`@0Ga<203`C000b4`0301<C0?lC?1<00`0C4`094`0301<C04HC00<04a<07a<405`C0P0k4`00

<Q<00`0C4`3o4c/C00<04a<02Q<00`0C4`164`0301<C028C1@1I4`0301<C03TC000b4`0301<C0?lC

>Q<00`0C4`0;4`80Aa<00`0C4`0V4`@0Ea<00`0C4`0h4`00<Q<00`0C4`3o4cTC00<04a<031<00`0C

4`154`0301<C02XC101D4`80>A<0038C00<04a<0oa<i4`0301<C00`C00<04a<0AA<00`0C4`0^4`@0

DA<00`0C4`0g4`00<Q<00`0C4`3o4cPC00<04a<03A<00`0C4`144`0301<C03<C0P1?4`80>1<0038C

00<04a<0oa<g4`0301<C00hC00<04a<0A1<00`0C4`0e4`@0C1<203LC000b4`0301<C0?lC=Q<00`0C

4`0?4`0301<C04@C00<04a<0>A<204/C00<04a<0=A<0038C00<04a<0oa<f4`0301<C00lC0P144`03

01<C03`C10174`80=Q<0038C00<04a<0oa<e4`0301<C010C00<04a<0@a<00`0C4`0o4`<0AQ<00`0C

4`0d4`00<Q<00`0C4`3o4cDC00<04a<041<00`0C4`134`0301<C048C0`134`80=A<0024C00<04a<0

0Q<00`0C4`024`0301<C00@C00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`164`<0@A<00`0C

4`0c4`0081<00`0C00074`0301<000DC00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`194`80

?a<00`0C4`0c4`006a<3008C00<04`002A<00`0C4`034`80oa<d4`0301<C018C00<04a<0@Q<00`0C

4`1;4`<0?A<00`0C4`0b4`0081<00`0C00074`801Q<00`0C4`3o4c<C00<04a<04Q<204<C00<04a<0

CQ<203/C00<04a<0<Q<0020C00<04`001a<00`0C4`054`0301<C0?lC<Q<00`0C4`0C4`0301<C044C

00<04a<0DA<303PC00<04a<0<Q<0024C00<04a<01Q<300DC00<04a<0oa<b4`0301<C01<C00<04a<0

@A<00`0C4`1D4`80=a<00`0C4`0a4`00<Q<00`0C4`3o4c4C00<04a<051<00`0C4`114`0301<C05HC

0`0d4`0301<C034C000b4`0301<C0?lC<A<00`0C4`0>4`0301<C00<C00<04a<0@1<00`0C4`1I4`<0

<Q<2038C000b4`0301<C0?lC<1<00`0C4`0>4`0301<000@C00<04a<0@1<00`0C4`1L4`80<A<00`0C

4`0`4`00<Q<00`0C4`3o4c0C00<04a<02A<300@C00<04a<00Q<3040C00<04a<0GQ<202lC00<04a<0

<1<0038C00<04a<0oa<`4`0301<C00hC0P054`0301<C03lC00<04a<0HA<302`C00<04a<0<1<0038C

00<04a<0oa<`4`0301<C00hC00<04a<011<00`0C4`0o4`0301<C06@C00<04a<0:A<00`0C4`0`4`00

<Q<00`0C4`3o4blC00<04a<03a<300@C00<04a<0?a<00`0C4`1U4`<0:1<2034C000b4`0301<C0?lC

;a<00`0C4`0F4`0301<C03lC00<04a<0J1<00`0C4`0V4`0301<C02lC000b4`0301<C0?lC;a<00`0C

4`0F4`0301<C03lC00<04a<0JA<302DC00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC0P104`03

01<C06`C0P0S4`0301<C02lC000b4`0301<C0?lC;a<00`0C4`0F4`0301<C03lC00<04a<0KA<2028C

00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC00<04a<0?a<00`0C4`1_4`8081<00`0C4`0_4`00

<Q<00`0C4`3o4bhC00<04a<05a<00`0C4`0n4`0301<C078C0P0N4`0301<C02lC000L4`0301<C008C

00@04a<C0`034`0301<C00@C00<04a<0oa<^4`0301<C01LC00<04a<0?Q<00`0C4`1d4`8071<00`0C

4`0_4`006a<00`0C00074`0301<C008C00<04`001A<00`0C4`3o4bhC00<04a<05a<203lC00<04a<0

MQ<201XC00<04a<0;a<001HC0`024`0301<000PC00<04a<00a<00`0C4`034`80oa<_4`0301<C01LC

00<04a<0?Q<00`0C4`1h4`0301<C01HC00<04a<0<1<001/C00<04`0021<0100C4a<200HC00<04a<0

oa<]4`0301<C01PC00<04a<0?Q<00`0C4`1i4`805Q<00`0C4`0`4`006a<00`0C00074`0301<0008C

00<04a<01A<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07/C00<04a<04a<00`0C4`0`4`00

71<00`0C4`074`0401<C4`<01A<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07`C00<04a<0

4Q<00`0C4`0`4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0m4`0301<C07hC0P0B4`0301<C030C

000b4`0301<C0?lC;A<00`0C4`0H4`80?Q<00`0C4`204`8041<00`0C4`0`4`00<Q<00`0C4`3o4bdC

00<04a<061<00`0C4`0Q4`D00Q<00`0C4`0B4`0301<C00/C1@000a<0000Q4`D00Q<00`0C4`0O4`D0

0Q<00`0C4`0K4`0401<C4`D000<C00000a<00`0C4`0a4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C

4`0S4`0701<C4`0C000C4`0301<C00dC00L04a<C01<0028C00<04a<00Q<00`0C4`0Q4`0701<C4`0C

000L4`8011<00`0C4`034`0401<C03<C000b4`0301<C02HC00<04a<00Q<0100C4a<302<C00<04a<0

0Q<00`0C4`024`<08Q<00`0C4`024`0401<C4`8091<00`0C4`024`0301<C008C00<04a<09Q<5044C

00<04a<061<00`0C4`0S4`0301<C00<C00<04a<04A<00`0C4`0=4`0701<C4`0C000R4`0301<C008C

00<04a<08A<01`0C4a<04`007Q<01@0C4a<000@C0P024`0301<C034C000b4`0301<C02DC00<04`00

1a<00`0C4`0R4`0301<000TC00<04a<081<00`0C00074`0301<0028C00<04`001a<00`0C000Y4`03

01<C044C00<04a<061<00`0C4`0S4`0401<C4`8051<00`0C4`0=4`0401<C4`808a<00`0C4`034`03

01<C020C00<04a<00Q<00`0C4`0N4`8000<C01<00Q<00`0C00024`0301<C034C000b4`0301<C02DC

00<04`0021<00`0C4`0Q4`0301<000LC100Q4`0301<000LC00<04`008Q<00`0C00074`0301<002TC

00<04a<0@1<00`0C4`0I4`0301<C02<C00D04a<C000E4`0301<C00dC00D04a<C000T4`0701<C4`0C

000R4`0701<C4`0C000Q4`800a<01@0C01<003@C000b4`0301<C02DC00<04`0021<00`0C4`0Q4`03

01<000LC00<04`008Q<00`0C00074`808a<00`0C00084`0301<C02PC00<04a<0@1<00`0C4`0I4`80

8a<200<C0`0C4`0301<C00`C0P044`808A<200<C0`0Q4`8011<00`0C4`0P4`8011<200034`0C03<C

000b4`0301<C02DC00<04`001a<00`0C000R4`0301<000PC0P0R4`0301<000LC00<04a<08Q<00`0C

00074`0301<002TC00<04a<0@1<00`0C4`0I4`0301<C03dC00<04a<0R1<00`0C4`054`0301<C038C

000b4`0301<C02HC00<04a<01a<00`0C4`0R4`0301<C00PC00<04a<08A<00`0C4`074`808a<00`0C

4`074`0301<C02LC0P124`0301<C01TC00<04a<0?A<00`0C4`294`801A<00`0C4`0b4`00<Q<00`0C

4`3o4b`C00<04a<06A<00`0C4`0m4`0301<C08/C00D04a<C000e4`00<Q<00`0C4`3o4b`C00<04a<0

6A<00`0C4`0m4`0301<C08/C00@04a<04a<401lC000b4`0301<C0?lC;1<00`0C4`0I4`0301<C03dC

00<04a<0S1<201@C0`0P4`00<Q<00`0C4`3g4`<0:a?o00XC00<04a<07Q<0038C00<04a<0n1<00`0C

4`0[4`0301<C008C00@04a<021<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC

00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`034`0301<000LC00<04a<01Q<00`0C

4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC

00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<300HC

00<04a<031<2020C000/4nl00`d600TC00<04a<0<1<00`0C4`0I4`0301<C02HC00<04a<051<00`0C

4`0@4`0301<C02HC00<04a<09Q<00`0C4`0V4`0401<C03HC000b4`0301<C00PC00<04a<02A<00`0C

4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0C4`084`0301<C00TC

00<04a<02A<00`0C4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0C

4`084`0301<C00TC2Pd24`0301<C00`C100`4`0301<C01TC00<04a<0?A<00`0C4`2;4`0501<C4`00

=A<0038C00<04a<0;1<00`0C4`0/4`0301<C02`C00<04a<0;1<00`0C4`0L4`@=31<00`0C4`104`03

01<C01TC00<04a<0?A<00`0C4`2:4`0301<C008C00<04a<0<a<0038C00<04a<0e1<43E<C00<04a<0

6A<00`0C4`0m4`0301<C08TC00<04a<011<00`0C4`0b4`00<Q<00`0C4`3B4`8=Ea<00`0C4`0I4`80

?Q<00`0C4`274`801a<00`0C4`0b4`00<Q<00`0C4`3@4`8=FA<00`0C4`0I4`0301<C03dC00<04a<0

Qa<00`0C4`064`0301<C038C000b4`0301<C0<hC0PeL4`0301<C01PC00<04a<0?A<00`0C4`264`03

01<C00PC00<04a<0<A<0038C00<04a<0c1<23EhC00<04a<061<00`0C4`0m4`0301<C08@C0P0;4`03

01<C034C000b4`0301<C0<XC0PeP4`0301<C01PC00<04a<0?A<00`0C4`234`0301<C00/C00<04a<0

<A<0038C00<04a<0b1<23F8C00<04a<061<00`0C4`0m4`0301<C088C00<04a<031<00`0C4`0a4`00

<Q<00`0C4`364`8=I1<00`0C4`0H4`80?Q<00`0C4`204`803a<00`0C4`0a4`00<Q<00`0C4`344`8=

IQ<00`0C4`0H4`0301<C03dC00<04a<0Oa<00`0C4`0@4`0301<C030C000b4`0301<C0<8C0PeX4`03

01<C01PC00<04a<0?Q<00`0C4`1l4`804a<00`0C4`0`4`00<Q<00`0C4`304`8=JQ<00`0C4`0H4`03

01<C03hC00<04a<0Na<201@C00<04a<0<1<0038C00<04a<0_Q<23F`C00<04a<061<00`0C4`0n4`03

01<C07TC0P0F4`0301<C030C000b4`0301<C0;`C0Pe^4`0301<C01PC00<04a<0?Q<00`0C4`1h4`03

01<C01HC00<04a<0<1<0038C00<04a<0^Q<23G4C00<04a<05a<203lC00<04a<0MQ<201TC00<04a<0

<1<0038C00<04a<0]Q<43G<C00<04a<05a<00`0C4`0n4`0301<C07@C0P0L4`0301<C02lC000L4`03

01<C008C00@04a<C0`034`0301<C00@C00<04a<0/Q<43GLC00<04a<05a<00`0C4`0n4`0301<C07<C

00<04a<071<00`0C4`0_4`006a<00`0C00074`0301<C008C00<04`001A<00`0C4`2`4`8=Na<00`0C

4`0G4`0301<C03lC00<04a<0L1<201lC00<04a<0;a<001/C00<04`0021<00`0C4`034`0301<C00<C

0P2/4`D=OQ<00`0C4`0F4`0301<C03lC00<04a<0KA<3024C00<04a<0;a<001/C00<04`0021<0100C

4a<200HC00<04a<0Sa<L3H<C00<04a<05Q<00`0C4`0o4`0301<C06`C0P0S4`0301<C02lC000K4`03

01<000LC00<04`000Q<00`0C4`054`0301<C08XC1@fO4`0301<C01HC0P104`0301<C06XC0P0U4`03

01<C02lC000L4`0301<C00LC00@04a<C0`054`0301<C08LC0`fT4`0301<C01HC00<04a<0?a<00`0C

4`1X4`809a<00`0C4`0_4`00<Q<00`0C4`244`<=Ya<00`0C4`0F4`0301<C03lC00<04a<0IQ<202TC

00<04a<0;a<0038C00<04a<0PA<33J/C00<04a<05A<00`0C4`0o4`0301<C06@C0P0Z4`0301<C030C

000b4`0301<C07lC0Pf^4`0301<C00lC00<04a<00a<00`0C4`0o4`0301<C068C0P0/4`0301<C030C

000b4`0301<C07dC0Pf`4`0301<C00hC00<04`0011<00`0C4`104`0301<C05hC0`0^4`0301<C030C

000b4`0301<C07`C00<=4a<0/1<00`0C4`0@4`0301<C008C0`104`0301<C05`C0`0`4`0301<C030C

000b4`0301<C07XC0Pfd4`0301<C00dC0P054`0301<C040C00<04a<0FQ<2038C0P0b4`00<Q<00`0C

4`1h4`8=]Q<00`0C4`0=4`0301<C00@C00<04a<0@A<00`0C4`1G4`80=1<00`0C4`0a4`00<Q<00`0C

4`1g4`033A<C0;LC00<04a<031<300@C00<04a<0@A<00`0C4`1D4`<0=Q<00`0C4`0a4`00<Q<00`0C

4`1e4`8=^Q<00`0C4`0C4`0301<C044C00<04a<0DQ<303LC0P0c4`00<Q<00`0C4`1c4`8=_A<00`0C

4`0B4`80@Q<00`0C4`1?4`<0>Q<00`0C4`0b4`00<Q<00`0C4`1b4`033A<C0;dC00<04a<04Q<00`0C

4`124`0301<C04`C0`0l4`0301<C038C000b4`0301<C074C00<=4a<0_a<00`0C4`0A4`0301<C048C

00<04a<0BA<303hC00<04a<0<a<0038C00<04a<0Ka<23L8C00<04a<04A<00`0C4`124`0301<C04LC

0`104`0301<C03<C000Q4`0301<C008C00<04a<00Q<00`0C4`044`0301<C06hC00<=4a<0`a<00`0C

4`0@4`0301<C048C00<04a<0A1<3048C0P0e4`0081<00`0C00074`0301<000DC00<04a<0KA<00`dC

4`344`0301<C010C00<04a<0@a<00`0C4`104`<0AA<00`0C4`0d4`0081<00`0C00094`0301<C00<C

0P1]4`033A<C0<HC00<04a<03a<204@C00<04a<0?A<304LC0P0f4`0081<00`0C00074`801Q<00`0C

4`1Z4`8=bA<00`0C4`0?4`0301<C04@C00<04a<0>A<304XC00<04a<0=A<0020C00<04`001a<00`0C

4`054`0301<C06TC00<=4a<0bQ<00`0C4`0>4`0301<C04@C00<04a<0=Q<404/C0P0g4`008A<00`0C

4`064`<01A<00`0C4`1X4`033A<C0<`C00<04a<03A<00`0C4`144`0301<C03<C0`1?4`0301<C03HC

000b4`0301<C06LC00<=4a<0cQ<00`0C4`0<4`0301<C04DC00<04a<0;a<304hC00@=4a<0>A<0038C

00<04a<0IA<23M4C00<04a<031<00`0C4`154`0301<C02/C101>4`H=00<04a<0=a<0038C00<04a<0

I1<00`dC4`3B4`0301<C00/C0P174`0301<C02LC101@4`T=>1<0038C00<04a<0Ha<00`dC4`3C4`03

01<C00/C00<04a<0AQ<00`0C4`0S4`D0Da<93CPC000b4`0301<C068C00<=4a<0eA<200/C00<04a<0

AQ<00`0C4`0P4`@0Ea<93CPC000b4`0301<C060C0PgJ4`0301<C00PC00<04a<0Aa<00`0C4`0K4`@0

FQ<;3CLC000b4`0301<C05lC00<=4a<0fa<00`0C4`074`0301<C04LC0P0H4`D0GQ<93CPC000b4`03

01<C05hC00<=4a<0g1<00`0C4`074`0301<C04PC00<04a<04a<4068C2@dh4`00<Q<00`0C4`1L4`8=

h1<00`0C4`064`80BQ<00`0C4`0>4`@0IQ<93CPC000b4`0301<C05/C00<=4a<0hA<200HC00<04a<0

BA<00`0C4`0:4`@0JQ<00`0=3@043CXC000b4`0301<C05XC00<=4a<0i1<00`0C4`034`0301<C04XC

00<04a<01A<506`C0P034`033A<C03XC000b4`0301<C05PC0PgX4`800a<00`0C4`1:4`8000<C0000

0`1`4`80@A<0038C00<04a<0Ea<00`dC4`3P4`D00Q<0100C4`024`0301<C04TC1@1c4`80@Q<001`C

00<04a<00Q<00`0C4`024`0301<C008C00<04a<011<00`0C4`1E4`8=iA<01`0C4a<04`000Q<304LC

1@024`0301<C074C0P134`006a<00`0C00084`0701<C4`0C00054`0301<C05@C00<=4a<0iA<01`0C

4a<04`0011<3040C1@084`0301<C06hC0P154`006a<00`0C00084`0301<C00<C00<04a<00a<205<C

0PgX4`0701<C4`0C00044`0401<003XC1@0=4`0301<C06dC0P164`006a<00`0C00094`0301<C0080

1Q<00`0C4`1A4`033A<C0>PC00L04a<C01<000@C00@04a<C0`0a4`H04a<206/C0`174`006a<00`0C

00074`0301<0008C00<04a<01A<;3DLC0PgZ4`8011<00`0C4`034`0301<C00@C0`0X4`L06A<206TC

0P194`0071<00`0C4`064`<00Q<300DC00<04a<021<63D0C00<=4a<0mQ<00`0C4`074`D06a<9020C

00<04a<0I1<304/C000b4`0301<C00hC1@di4`8=nA<00`0C4`0<4a`0:A<2068C0`1=4`00<Q<00`0C

4`0C4`H=<A<23O/C0P1C4`80Ga<304lC000b4`0301<C01TC1@dZ4`8=oA<00`0C4`1C4`80FQ<4058C

000b4`0301<C01hC1@dQ4`@=oa<00`0C4`1D4`80EQ<405DC000b4`0301<C02<C10dJ4`<=oa<44`03

01<C05HC0P1?4`D0FA<0038C00<04a<09a<63@lC1@go4`LC00<04a<0Ea<304PC1P1M4`00<Q<00`0C

4`0]4`l=oa<<4`0301<C05TC0`104`L0HQ<0038C00<04a<0oa=84`80G1<303PC1`1X4`00<Q<00`0C

4`3o4dPC00<04a<0GQ<302hC201^4`00<Q<00`0C4`3o4dPC00<04a<0H1<502<C201e4`00<Q<00`0C

4`3o4dPC00<04a<0I1<701@C2P1l4`00<Q<00`0C4`3o4dPC00<04a<0JQ<E08HC000b4`0301<C0?lC

B1<00`0C4`3o4`HC000Y4`D011<00`0C4`3o4dPC0P3o4`LC000[4`0301<C00@C00<04a<0oa=84`03

01<C0?lC1Q<002/C00<04a<011<20?lCBA<00`0C4`3o4`HC000[4`0301<C0?lCoa=H4`00:a<00`0C

4`3o4olCF1<002XC0P3o4olCFQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC

001a4`@000<C00001`024`0301<C008C00@04a<C0P034`8011<300034`0000<C0P034`800a<200<C

0P034`800a<200<C0P034`800a<200<C0P024`D000<C0000oa>^4`00LA<300PC00L04a<C01<000TC

00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C

4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<01@0C4a<000<C00<04`00

XQ<20?lC2A<007<C00<04a<010024`0701<C4`0C00084`800a<0100C4a<4008C0P034`800a<200<C

0P034`800a<200<C0P034`800a<200<C0P034`800a<01`0C4a<04`00Xa<00`0C4`3o4`LC000I4`@0

00<C00001P024`X00Q<2008C0`024`<00a<200064`0001<09a<200PC00<04a<00Q<00`0C4`064`03

01<000@C00H04a<04`024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C

00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000a<0100C4a<20:8C0`024`03

01<C0?lC11<001XC00H04a<04`024`0301<000@C00H04a<04`024`0301<000DC00<04a<00Q<01@0C

4a<0008C00@04`0C0P0a4`0701<C4`0C00074`0301<0008C00<04`000a<2008C00<04`000Q<00`0C

00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C

00<04`000Q<00`0C00034`0501<C4`001Q<00`0C4`2I4`0801<C01<04`3o4`DC000J4`0601<C01<0

11<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`034`0301<C008C00D04a<C00024`0401<04`80

<1<200@C00<04a<01a<200<C00<04a<00a<0100C4a<200<C0P034`800a<200<C0P034`800a<200<C

0P034`800a<200<C0P024`8011<200<C00<04a<0VQ<0200C4`0C01<0oa<54`006Q<01@0C4`0C0080

0a<200<C00<04a<00Q<200<C00<04a<00a<00`0C4`024`0501<C4`000Q<01P0C000C0?lC;a<30004

4`0C0?lC1A<001XC00H04a<04`024`0301<0008C00<04`0011<03P0C4`0C01<04`0C01<00Q<01@0C

4a<0008C00H04`004`3o4c<C00<04`00oa<54`006A<400034`0000/00Q<500054`0001<01@0011<0

00034`8000@C000C0P3o4c@C00<04a<0oa<44`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC

003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.77084, -14.119, 0.0242408, 0.16996}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -57 0 ]

[.5 .63053 57 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -118 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(19.1509999999999891`) show

173.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .58089 m

.02499 .58089 L

.02606 .58089 L

.02729 .5809 L

.02846 .58091 L

.03053 .58093 L

.03279 .58096 L

.03527 .581 L

.0379 .58106 L

.04262 .58119 L

.05205 .58157 L

.06245 .58215 L

.0842 .58385 L

.10458 .58592 L

.14335 .59039 L

.16306 .59248 L

.17348 .59342 L

.18458 .59424 L

.19014 .59456 L

.19538 .59481 L

.20008 .59497 L

.20273 .59505 L

.20391 .59507 L

.20517 .5951 L

.20637 .59511 L

.20746 .59513 L

.20856 .59514 L

.2096 .59515 L

.21081 .59515 L

.21193 .59515 L

.21316 .59515 L

.21446 .59514 L

.21562 .59513 L

.21687 .59511 L

.21913 .59507 L

.22182 .595 L

.22429 .59491 L

.22903 .5947 L

.23409 .59438 L

.24321 .59359 L

.24879 .59295 L

.25405 .59225 L

.26391 .59062 L

.28392 .58607 L

.30238 .58029 L

.32114 .57282 L

.34178 .56273 L

.38212 .53773 L

.42094 .50843 L

.46222 .47458 L

Mistroke

.50198 .44335 L

.54023 .41853 L

.55994 .40873 L

.58092 .40083 L

.59123 .3979 L

.60237 .39541 L

.61289 .39364 L

.62256 .39247 L

.62727 .39203 L

.63232 .39165 L

.63668 .39139 L

.64142 .39117 L

.64431 .39106 L

.64698 .39097 L

.64948 .3909 L

.65224 .39084 L

.65702 .39076 L

.6621 .3907 L

.67155 .39061 L

.6767 .39056 L

.68148 .39049 L

.684 .39044 L

.68669 .39038 L

.69238 .39021 L

.69761 .38999 L

.70235 .38973 L

.70722 .3894 L

.71236 .38896 L

.72157 .38793 L

.73149 .38645 L

.74239 .38431 L

.76187 .37911 L

.78278 .37163 L

.82411 .35262 L

.86392 .33327 L

.88212 .3256 L

.90222 .31868 L

.91172 .31607 L

.92197 .31374 L

.93279 .31184 L

.93806 .31111 L

.94297 .31055 L

.95069 .30986 L

.95478 .30959 L

.95914 .30936 L

.96135 .30927 L

.96373 .30919 L

.96584 .30914 L

.96807 .30909 L

.97008 .30906 L

Mistroke

.97122 .30904 L

.97229 .30903 L

.97327 .30903 L

.97417 .30902 L

.97521 .30902 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.97084 .42645 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4gdC00<04a<0oa<64`00oa=m4`0301<C0?lC1Q<002TC1@3o4dlC0P3o4`LC

000[4`0301<C0?lCCa<00`0C4`1^4`d0RQ<002DC0`034`0301<C00@C0P3o4dTC00<04a<0IQ<800`C

3@1n4`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`1Q4`D081<807LC000[4`0301<C00@C00<04a<0

oa=84`0301<C05hC100/4`L0L1<002XC0P064`0301<C0?lCB1<00`0C4`1L4`<0=A<706XC000b4`03

01<C0?lCB1<205/C0P0o4`H0I1<0038C00<04a<0oa=84`0301<C05PC0P164`H0Ga<0038C00<04a<0

oa=84`0301<C05HC0P1>4`D0FQ<0038C00<04a<0oa=84`0301<C05DC0P1C4`D0EQ<0038C00<04a<0

oa=84`0301<C05@C00<04a<0Ea<5058C000b4`0301<C0?lCB1<205<C0P1N4`<0D1<0038C00<04a<0

oa=84`0301<C00lC5P0/4`80HA<404dC000b4`0301<C0?lCB1<00`0C4`0:4`D05Q<9028C0P1U4`<0

Ba<0038C00<04a<0oa=84`0301<C00DC1@0S4`L06a<206PC0`194`00<Q<00`0C4`3o4c/C1@024`03

01<C00<C00<04a<00a<202lC1P0D4`80Ja<204PC000b4`0301<C0?lC?A<01`0C4a<04`0011<00`0C

4`0303HC1P0>4`80KA<304HC000b4`0301<C0?lC=a<300<C00L04a<C01<000@C0`0n4`H02A<00`0C

4`1^4`80AA<0038C00<04a<0oa<m4`0701<C4`0C00034`80AA<500@C00<04a<0L1<204@C000L4`03

01<C008C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0oa<m4`0701<C4`0C00024`0301<004XC

1@1d4`80@Q<001/C00<04`0021<01`0C4a<04`001A<00`0C4`3o4c`C0P044`0401<0008C00<04a<0

Ba<6074C0P114`005Q<3008C00<04`0021<00`0C4`034`0301<C00<C0P3o4d<C0P044`0301<C04XC

00<04a<011<406hC0P104`006a<00`0C00094`0301<C00801Q<00`0C4`3o4d4C00<04a<011<00`0C

4`194`0301<C00TC101[4`0301<C03hC000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C0?lC

@1<00`0C4`054`80BQ<00`0C4`0=4`@0J1<203hC000L4`0301<C00HC0`024`<01A<00`0C4`3o4clC

00<04a<01Q<00`0C4`184`0301<C018C101U4`0301<C03`C000b4`0301<C0?lC?Q<00`0C4`074`03

01<C04PC00<04a<05A<5068C00<04a<0>a<0038C00<04a<0oa<m4`0301<C00PC00<04a<0Aa<00`0C

4`0J4`@0Ga<203`C000b4`0301<C0?lC?1<00`0C4`094`0301<C04HC00<04a<07a<405`C0P0k4`00

<Q<00`0C4`3o4c/C00<04a<02Q<00`0C4`164`0301<C028C1@1I4`0301<C03TC000b4`0301<C0?lC

>Q<00`0C4`0;4`80Aa<00`0C4`0V4`@0Ea<00`0C4`0h4`00<Q<00`0C4`3o4cTC00<04a<031<00`0C

4`154`0301<C02XC101D4`80>A<0038C00<04a<0oa<i4`0301<C00`C00<04a<0AA<00`0C4`0^4`@0

DA<00`0C4`0g4`00<Q<00`0C4`3o4cPC00<04a<03A<00`0C4`144`0301<C03<C0P1?4`80>1<0038C

00<04a<0oa<g4`0301<C00hC00<04a<0A1<00`0C4`0e4`@0C1<203LC000b4`0301<C0?lC=Q<00`0C

4`0?4`0301<C04@C00<04a<0>A<204/C00<04a<0=A<0038C00<04a<0oa<f4`0301<C00lC0P144`03

01<C03`C10174`80=Q<0038C00<04a<0oa<e4`0301<C010C00<04a<0@a<00`0C4`0o4`<0AQ<00`0C

4`0d4`00<Q<00`0C4`3o4cDC00<04a<041<00`0C4`134`0301<C048C0`134`80=A<0024C00<04a<0

0Q<00`0C4`024`0301<C00@C00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`164`<0@A<00`0C

4`0c4`0081<00`0C00074`0301<000DC00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`194`80

?a<00`0C4`0c4`006a<3008C00<04`002A<00`0C4`034`80oa<d4`0301<C018C00<04a<0@Q<00`0C

4`1;4`<0?A<00`0C4`0b4`0081<00`0C00074`801Q<00`0C4`3o4c<C00<04a<04Q<204<C00<04a<0

CQ<203/C00<04a<0<Q<0020C00<04`001a<00`0C4`054`0301<C0?lC<Q<00`0C4`0C4`0301<C044C

00<04a<0DA<303PC00<04a<0<Q<0024C00<04a<01Q<300DC00<04a<0oa<b4`0301<C01<C00<04a<0

@A<00`0C4`1D4`80=a<00`0C4`0a4`00<Q<00`0C4`3o4c4C00<04a<051<00`0C4`114`0301<C05HC

0`0d4`0301<C034C000b4`0301<C0?lC<A<00`0C4`0>4`0301<C00<C00<04a<0@1<00`0C4`1I4`<0

<Q<2038C000b4`0301<C0?lC<1<00`0C4`0>4`0301<000@C00<04a<0@1<00`0C4`1L4`80<A<00`0C

4`0`4`00<Q<00`0C4`3o4c0C00<04a<02A<300@C00<04a<00Q<3040C00<04a<0GQ<202lC00<04a<0

<1<0038C00<04a<0oa<`4`0301<C00hC0P054`0301<C03lC00<04a<0HA<302`C00<04a<0<1<0038C

00<04a<0oa<`4`0301<C00hC00<04a<011<00`0C4`0o4`0301<C06@C00<04a<0:A<00`0C4`0`4`00

<Q<00`0C4`3o4blC00<04a<03a<300@C00<04a<0?a<00`0C4`1U4`<0:1<2034C000b4`0301<C0?lC

;a<00`0C4`0F4`0301<C03lC00<04a<0J1<00`0C4`0V4`0301<C02lC000b4`0301<C0?lC;a<00`0C

4`0F4`0301<C03lC00<04a<0JA<302DC00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC0P104`03

01<C06`C0P0S4`0301<C02lC000b4`0301<C0?lC;a<00`0C4`0F4`0301<C03lC00<04a<0KA<2028C

00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC00<04a<0?a<00`0C4`1_4`8081<00`0C4`0_4`00

<Q<00`0C4`3o4bhC00<04a<05a<00`0C4`0n4`0301<C078C0P0N4`0301<C02lC000L4`0301<C008C

00@04a<C0`034`0301<C00@C00<04a<0oa<^4`0301<C01LC00<04a<0?Q<00`0C4`1d4`8071<00`0C

4`0_4`006a<00`0C00074`0301<C008C00<04`001A<00`0C4`3o4bhC00<04a<05a<203lC00<04a<0

MQ<201XC00<04a<0;a<001HC0`024`0301<000PC00<04a<00a<00`0C4`034`80oa<_4`0301<C01LC

00<04a<0?Q<00`0C4`1h4`0301<C01HC00<04a<0<1<001/C00<04`0021<0100C4a<200HC00<04a<0

oa<]4`0301<C01PC00<04a<0?Q<00`0C4`1i4`805Q<00`0C4`0`4`006a<00`0C00074`0301<0008C

00<04a<01A<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07/C00<04a<04a<00`0C4`0`4`00

71<00`0C4`074`0401<C4`<01A<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07`C00<04a<0

4Q<00`0C4`0`4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0m4`0301<C07hC0P0B4`0301<C030C

000b4`0301<C0?lC;A<00`0C4`0H4`80?Q<00`0C4`204`8041<00`0C4`0`4`00<Q<00`0C4`3o4bdC

00<04a<061<00`0C4`0Q4`D00Q<00`0C4`0B4`0301<C00/C1@000a<0000Q4`D00Q<00`0C4`0O4`D0

0Q<00`0C4`0K4`0401<C4`D000<C00000a<00`0C4`0a4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C

4`0S4`0701<C4`0C000C4`0301<C00dC00L04a<C01<0028C00<04a<00Q<00`0C4`0Q4`0701<C4`0C

000L4`8011<00`0C4`034`0401<C03<C000b4`0301<C02HC00<04a<00Q<0100C4a<302<C00<04a<0

0Q<00`0C4`024`<08Q<00`0C4`024`0401<C4`8091<00`0C4`024`0301<C008C00<04a<09Q<5044C

00<04a<061<00`0C4`0S4`0301<C00<C00<04a<04A<00`0C4`0=4`0701<C4`0C000R4`0301<C008C

00<04a<08A<01`0C4a<04`007Q<01@0C4a<000@C0P024`0301<C034C000b4`0301<C02DC00<04`00

1a<00`0C4`0R4`0301<000TC00<04a<081<00`0C00074`0301<0028C00<04`001a<00`0C000Y4`03

01<C044C00<04a<061<00`0C4`0S4`0401<C4`8051<00`0C4`0=4`0401<C4`808a<00`0C4`034`03

01<C020C00<04a<00Q<00`0C4`0N4`8000<C01<00Q<00`0C00024`0301<C034C000b4`0301<C02DC

00<04`0021<00`0C4`0Q4`0301<000LC100Q4`0301<000LC00<04`008Q<00`0C00074`0301<002TC

00<04a<0@1<00`0C4`0I4`0301<C02<C00D04a<C000E4`0301<C00dC00D04a<C000T4`0701<C4`0C

000R4`0701<C4`0C000Q4`800a<01@0C01<003@C000b4`0301<C02DC00<04`0021<00`0C4`0Q4`03

01<000LC00<04`008Q<00`0C00074`808a<00`0C00084`0301<C02PC00<04a<0@1<00`0C4`0I4`80

8a<200<C0`0C4`0301<C00`C0P044`808A<200<C0`0Q4`8011<00`0C4`0P4`8011<200034`0C03<C

000b4`0301<C02DC00<04`001a<00`0C000R4`0301<000PC0P0R4`0301<000LC00<04a<08Q<00`0C

00074`0301<002TC00<04a<0@1<00`0C4`0I4`0301<C03dC00<04a<0R1<00`0C4`054`0301<C038C

000b4`0301<C02HC00<04a<01a<00`0C4`0R4`0301<C00PC00<04a<08A<00`0C4`074`808a<00`0C

4`074`0301<C02LC0P124`0301<C01TC00<04a<0?A<00`0C4`294`801A<00`0C4`0b4`00<Q<00`0C

4`3o4b`C00<04a<06A<00`0C4`0m4`0301<C08/C00D04a<C000e4`00<Q<00`0C4`3o4b`C00<04a<0

6A<00`0C4`0m4`0301<C08/C00@04a<04a<401lC000b4`0301<C0?lC;1<00`0C4`0I4`0301<C03dC

00<04a<0S1<201@C0`0P4`00<Q<00`0C4`3g4`<0:a?o00XC00<04a<07Q<0038C00<04a<0n1<00`0C

4`0[4`0301<C008C00@04a<021<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC

00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`034`0301<000LC00<04a<01Q<00`0C

4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC

00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<300HC

00<04a<031<2020C000/4nl00`d600TC00<04a<0<1<00`0C4`0I4`0301<C02HC00<04a<051<00`0C

4`0@4`0301<C02HC00<04a<09Q<00`0C4`0V4`0401<C03HC000b4`0301<C00PC00<04a<02A<00`0C

4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0C4`084`0301<C00TC

00<04a<02A<00`0C4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0C

4`084`0301<C00TC00<03@d01`d24`0301<C00`C100`4`0301<C01TC00<04a<0?A<00`0C4`2;4`05

01<C4`00=A<0038C00<04a<0;1<00`0C4`0/4`0301<C02`C00<04a<0;1<00`0C4`0L4`D=2a<00`0C

4`104`0301<C01TC00<04a<0?A<00`0C4`2:4`0301<C008C00<04a<0<a<0038C00<04a<0eA<33E<C

00<04a<06A<00`0C4`0m4`0301<C08TC00<04a<011<00`0C4`0b4`00<Q<00`0C4`3C4`8=EQ<00`0C

4`0I4`80?Q<00`0C4`274`801a<00`0C4`0b4`00<Q<00`0C4`3?4`@=F1<00`0C4`0I4`0301<C03dC

00<04a<0Qa<00`0C4`064`0301<C038C000b4`0301<C0<`C0`eM4`0301<C01PC00<04a<0?A<00`0C

4`264`0301<C00PC00<04a<0<A<0038C00<04a<0bQ<23F0C00<04a<061<00`0C4`0m4`0301<C08@C

0P0;4`0301<C034C000b4`0301<C0<PC0PeR4`0301<C01PC00<04a<0?A<00`0C4`234`0301<C00/C

00<04a<0<A<0038C00<04a<0aQ<23F@C00<04a<061<00`0C4`0m4`0301<C088C00<04a<031<00`0C

4`0a4`00<Q<00`0C4`344`8=IQ<00`0C4`0H4`80?Q<00`0C4`204`803a<00`0C4`0a4`00<Q<00`0C

4`324`8=J1<00`0C4`0H4`0301<C03dC00<04a<0Oa<00`0C4`0@4`0301<C030C000b4`0301<C0<0C

0PeZ4`0301<C01PC00<04a<0?Q<00`0C4`1l4`804a<00`0C4`0`4`00<Q<00`0C4`2n4`8=K1<00`0C

4`0H4`0301<C03hC00<04a<0Na<201@C00<04a<0<1<0038C00<04a<0_1<23FhC00<04a<061<00`0C

4`0n4`0301<C07TC0P0F4`0301<C030C000b4`0301<C0;XC0Pe`4`0301<C01PC00<04a<0?Q<00`0C

4`1h4`0301<C01HC00<04a<0<1<0038C00<04a<0]a<33G<C00<04a<05a<203lC00<04a<0MQ<201TC

00<04a<0<1<0038C00<04a<0]A<23GHC00<04a<05a<00`0C4`0n4`0301<C07@C0P0L4`0301<C02lC

000L4`0301<C008C00@04a<C0`034`0301<C00@C00<04a<0/A<43GPC00<04a<05a<00`0C4`0n4`03

01<C07<C00<04a<071<00`0C4`0_4`006a<00`0C00074`0301<C008C00<04`001A<00`0C4`2^4`<=

O1<00`0C4`0G4`0301<C03lC00<04a<0L1<201lC00<04a<0;a<001/C00<04`0021<00`0C4`034`03

01<C00<C0P2T4`/=P1<00`0C4`0F4`0301<C03lC00<04a<0KA<3024C00<04a<0;a<001/C00<04`00

21<0100C4a<200HC00<04a<0SQ<E3H/C00<04a<05Q<00`0C4`0o4`0301<C06`C0P0S4`0301<C02lC

000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C08PC1PfP4`0301<C01HC0P104`0301<C06XC

0P0U4`0301<C02lC000L4`0301<C00LC00@04a<C0`054`0301<C08DC0`fV4`0301<C01HC00<04a<0

?a<00`0C4`1X4`809a<00`0C4`0_4`00<Q<00`0C4`234`8=ZA<00`0C4`0F4`0301<C03lC00<04a<0

IQ<202LC00<=4`00<A<0038C00<04a<0PA<23J`C00<04a<05A<00`0C4`0o4`0301<C06@C0P0V4`H=

<A<0038C00<04a<0Oa<23JhC00<04a<03a<00`0C4`034`0301<C03lC00<04a<0HQ<202LC2@d_4`00

<Q<00`0C4`1m4`8=/1<00`0C4`0>4`0301<000@C00<04a<0@1<00`0C4`1N4`<0:A<93BlC000b4`03

01<C07`C00<=4a<0/1<00`0C4`0@4`0301<C008C0`104`0301<C05`C0`0[4`T=;a<0038C00<04a<0

NQ<23K@C00<04a<03A<200DC00<04a<0@1<00`0C4`1J4`80;A<;3BhC000b4`0301<C07TC00<=4a<0

]1<00`0C4`0=4`0301<C00@C00<04a<0@A<00`0C4`1G4`80<1<93BlC000b4`0301<C07LC0Pfh4`03

01<C00`C0`044`0301<C044C00<04a<0E1<3038C2@d_4`00<Q<00`0C4`1f4`033A<C0;PC00<04a<0

4a<00`0C4`114`0301<C058C0`0d4`T=;a<0038C00<04a<0M1<23K`C00<04a<04Q<2048C00<04a<0

Ca<303PC1Pda4`00<Q<00`0C4`1c4`033A<C0;`C00<04a<04Q<00`0C4`124`0301<C04`C0`0l4`03

00dC038C000b4`0301<C074C0Pg04`0301<C014C00<04a<0@Q<00`0C4`194`<0?Q<00`0C4`0c4`00

<Q<00`0C4`1`4`033A<C0<0C00<04a<04A<00`0C4`124`0301<C04LC0`104`0301<C03<C000Q4`03

01<C008C00<04a<00Q<00`0C4`044`0301<C06lC00<=4a<0`Q<00`0C4`0@4`0301<C048C00<04a<0

A1<3048C0P0e4`0081<00`0C00074`0301<000DC00<04a<0KA<23LDC00<04a<041<00`0C4`134`03

01<C040C0`154`0301<C03@C000P4`0301<000TC00<04a<00a<206dC00<=4a<0aQ<00`0C4`0?4`80

A1<00`0C4`0m4`<0Aa<203HC000P4`0301<000LC0P064`0301<C06XC0Pg94`0301<C00lC00<04a<0

A1<00`0C4`0i4`<0BQ<00`0C4`0e4`0081<00`0C00074`0301<C00DC00<04a<0JA<00`dC4`3:4`03

01<C00hC00<04a<0A1<00`0C4`0f4`@0Ba<203LC000Q4`0301<C00HC0`054`0301<C06PC00<=4a<0

c1<00`0C4`0=4`0301<C04@C00<04a<0<a<304lC00<04a<0=Q<0038C00<04a<0Ia<00`dC4`3>4`03

01<C00`C00<04a<0AA<00`0C4`0_4`<0DA<00`0C4`0g4`00<Q<00`0C4`1V4`033A<C0<lC00<04a<0

31<00`0C4`154`0301<C02/C101C4`80>A<0038C00<04a<0IA<00`dC4`3A4`0301<C00/C0P174`03

01<C02LC101F4`0301<C03PC000b4`0301<C06<C0PgD4`0301<C00/C00<04a<0AQ<00`0C4`0S4`D0

F1<203XC000b4`0301<C068C00<=4a<0eA<200/C00<04a<0AQ<00`0C4`0P4`@0Fa<203/C000b4`03

01<C064C00<=4a<0f1<00`0C4`084`0301<C04LC00<04a<06a<405lC00<04a<0>Q<0038C00<04a<0

H1<00`dC4`3J4`0301<C00LC00<04a<0Aa<201PC1@1Q4`0301<C03/C000b4`0301<C05lC00<=4a<0

fa<00`0C4`074`0301<C04PC00<04a<04a<406@C0P0m4`00<Q<00`0C4`1M4`8=ga<00`0C4`064`80

BQ<00`0C4`0>4`@0Ia<203hC000b4`0301<C05`C00<=4a<0h1<200HC00<04a<0BA<00`0C4`0:4`@0

JQ<203lC000b4`0301<C05/C00<=4a<0ha<00`0C4`034`0301<C04XC00<04a<01A<506`C0P104`00

<Q<00`0C4`1I4`8=ia<200<C00<04a<0BQ<200034`0000<0L1<2044C000b4`0301<C05PC00<=4a<0

ga<5008C00@04a<00Q<00`0C4`194`D0La<2048C000L4`0301<C008C00<04a<00Q<00`0C4`024`03

01<C00@C00<04a<0EQ<23N@C00L04a<C01<0008C0`174`D00Q<00`0C4`1a4`80@a<001/C00<04`00

21<01`0C4a<04`001A<00`0C4`1E4`033A<C0>@C00L04a<C01<000@C0`104`D021<00`0C4`1^4`80

AA<001/C00<04`0021<00`0C4`034`0301<C00<C0P1D4`8=ia<01`0C4a<04`0011<0100C000j4`D0

3A<00`0C4`1]4`80AQ<001/C00<04`002A<00`0C4`0200HC00<04a<0DA<23NTC00L04a<C01<000@C

00@04a<C0`0a4`H04a<206/C0`174`006a<00`0C00074`0301<0008C00<04a<01A<00`0C4`1@4`03

3A<C0>PC0P044`0301<C00<C00<04a<011<302PC1`0I4`80JA<204TC000L4`0301<C00HC0`024`<0

1A<00`0C4`1>4`8=ma<00`0C4`074`D06a<9020C00<04a<0I1<304/C000b4`0301<C04`C0Pgi4`03

01<C00`C700Y4`80HQ<304dC000b4`0301<C04/C00<=4a<0nA<205<C0P1O4`<0Ca<0038C00<04a<0

BA<23O`C00<04a<0Da<205XC101B4`00<Q<00`0C4`174`8=oQ<00`0C4`1D4`80EQ<405DC000b4`03

01<C04DC0Pgo4`4C00<04a<0EQ<204lC1@1I4`00<Q<00`0C4`134`8=oa<34`0301<C05LC0`184`H0

GA<0038C4@db4`<=oa<54`0301<C05TC0`104`L0HQ<0038C00<04a<03Q<73BHC1@go4`PC0P1L4`<0

>1<706PC000b4`0301<C01DC20dJ4`@=oa<=4`0301<C05hC0`0^4`P0KQ<0038C00<04a<07A<J3OlC

4A<00`0C4`1P4`D08a<807DC000b4`0301<C0?lCB1<00`0C4`1T4`L051<:07`C000b4`0301<C0?lC

B1<00`0C4`1Z4aD0QQ<0038C00<04a<0oa=84`0301<C0?lC1Q<002TC1@044`0301<C0?lCB1<20?lC

1a<002/C00<04a<011<00`0C4`3o4dPC00<04a<0oa<64`00:a<00`0C4`044`80oa=94`0301<C0?lC

1Q<002/C00<04a<0oa?o4ePC000[4`0301<C0?lCoa=H4`00:Q<20?lCoa=J4`00oa?o4hHC003o4olC

QQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<0074C10000a<0000700034`0000@C00<04a<01@024`03

01<C008C00@04a<C0P034`800a<200<C0P034`800a<200<C0P034`800a<200<C0P044`0401<C4`80

0Q<50?lC[1<0074C0`084`0301<C00<C00<04a<01Q<01`0C4a<04`000Q<00`0C00044`0301<C008C

00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C

4`024`0601<C01<011<01@0C4a<00:<C0P3o4`TC001c4`0301<C00@00Q<00`0C4`024`8021<00`0C

4`034`0601<C01<00a<200<C0P034`800a<200<C0P034`800a<200<C0P034`800a<2008C00<04`00

0a<200<C00<04a<0XQ<00`0C4`3o4`LC000I4`@000<C00001P024`X00Q<2008C0`024`<00a<20006

4`0001<09a<200PC00L04a<C01<000PC00@04a<C0P034`0301<0008C00<04`000Q<00`0C00024`03

01<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0a<01`0C4a<04`000a<00`0C4`2P4`<00Q<00`0C4`3o4`@C000J4`0601<C01<00Q<00`0C00044`06

01<C01<00Q<00`0C00054`0301<C008C00D04a<C00024`0401<04`80<A<01`0C4a<04`0021<01@0C

4a<000@C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000a<00`0C4`034`03

01<C09TC00P04a<04`0C0?lC1A<001XC00H04a<04`044`0301<C008C00<04a<00Q<00`0C4`024`03

01<C00<C00<04a<00Q<01@0C4a<0008C00@04`0C0P0`4`8011<200LC0P034`<00a<00`0C4`024`80

0a<200<C0P034`800a<200<C0P034`800a<200<C0P034`800a<00`0C4`024`800Q<200@C00<04a<0

VQ<0200C4`0C01<0oa<54`006Q<01@0C4`0C00800a<200<C00<04a<00Q<200<C00<04a<00a<00`0C

4`024`0501<C4`000Q<01P0C000C0?lC;a<300044`0C0?lC1A<001XC00H04a<04`024`0301<0008C

00<04`0011<03P0C4`0C01<04`0C01<00Q<01@0C4a<0008C00H04`004`3o4c<C00<04`00oa<54`00

6A<400034`0000/00Q<500054`0001<01@0011<000034`8000@C000C0P3o4c@C00<04a<0oa<44`00

oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olC

QQ<00?lCoa>64`00\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.77084, -14.119, 0.0242408, 0.16996}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -57 0 ]

[.5 .63053 57 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -118 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(18.6999999999999886`) show

173.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .60731 m

.02499 .60731 L

.02606 .60731 L

.02729 .60731 L

.02846 .6073 L

.03053 .60729 L

.03279 .60728 L

.03527 .60726 L

.0379 .60724 L

.04262 .60718 L

.04749 .6071 L

.05205 .60701 L

.06245 .60674 L

.07305 .60637 L

.08274 .60594 L

.10458 .60462 L

.12357 .60302 L

.14429 .6007 L

.16396 .59783 L

.18493 .59394 L

.20491 .58934 L

.22652 .58323 L

.26658 .56844 L

.30759 .54822 L

.34707 .52403 L

.38505 .49731 L

.42547 .46722 L

.46438 .43954 L

.48419 .42697 L

.50574 .41506 L

.52468 .40638 L

.54558 .3989 L

.56536 .39384 L

.57619 .39183 L

.58637 .39039 L

.5962 .38934 L

.60655 .38855 L

.61539 .38807 L

.62505 .3877 L

.63599 .38737 L

.64631 .38707 L

.65557 .38674 L

.66561 .38624 L

.67548 .38556 L

.68593 .38455 L

.69485 .38342 L

.70466 .38186 L

.72411 .37768 L

.745 .37156 L

.78628 .35538 L

Mistroke

.82604 .33775 L

.86428 .32304 L

.88399 .31737 L

.89493 .31491 L

.90498 .31307 L

.91529 .3116 L

.92061 .311 L

.92643 .31045 L

.93117 .31008 L

.93625 .30977 L

.94161 .3095 L

.94661 .30932 L

.9504 .30922 L

.9539 .30915 L

.95774 .30909 L

.95968 .30907 L

.96181 .30905 L

.96368 .30904 L

.96539 .30903 L

.96726 .30903 L

.9682 .30902 L

.96923 .30902 L

.97015 .30902 L

.97098 .30902 L

.97194 .30902 L

.97284 .30902 L

.97368 .30902 L

.97445 .30902 L

.9753 .30902 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.89766 .25817 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4gdC00<04a<0oa<64`00oa=m4`0301<C0?lC1Q<002TC1@3o4dlC0P3o4`LC

000[4`0301<C0?lCCa<00`0C4`1^4`d0RQ<002DC0`034`0301<C00@C0P3o4dTC00<04a<0IQ<800`C

3@1n4`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`1Q4`D081<807LC000[4`0301<C00@C00<04a<0

oa=84`0301<C05hC100/4`L0L1<002XC0P064`0301<C0?lCB1<00`0C4`1L4`<0=A<706XC000b4`03

01<C0?lCB1<205/C0P0o4`H0I1<0038C00<04a<0oa=84`0301<C05PC0P164`H0Ga<0038C00<04a<0

oa=84`0301<C05HC0P1>4`D0FQ<0038C00<04a<0oa=84`0301<C05DC0P1C4`D0EQ<0038C00<04a<0

oa=84`0301<C05@C00<04a<0Ea<5058C000b4`0301<C0?lCB1<205<C0P1N4`<0D1<0038C00<04a<0

oa=84`0301<C00lC5P0/4`80HA<404dC000b4`0301<C0?lCB1<00`0C4`0:4`D05Q<9028C0P1U4`<0

Ba<0038C00<04a<0oa=84`0301<C00DC1@0S4`L06a<206PC0`194`00<Q<00`0C4`3o4c/C1@024`03

01<C00<C00<04a<00a<202lC1P0D4`80Ja<204PC000b4`0301<C0?lC?A<01`0C4a<04`0011<00`0C

4`0303HC1P0>4`80KA<304HC000b4`0301<C0?lC=a<300<C00L04a<C01<000@C0`0n4`H02A<00`0C

4`1^4`80AA<0038C00<04a<0oa<m4`0701<C4`0C00034`80AA<500@C00<04a<0L1<204@C000L4`03

01<C008C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0oa<m4`0701<C4`0C00024`0301<004XC

1@1d4`80@Q<001/C00<04`0021<01`0C4a<04`001A<00`0C4`3o4c`C0P044`0401<0008C00<04a<0

Ba<6074C0P114`005Q<3008C00<04`0021<00`0C4`034`0301<C00<C0P3o4d<C0P044`0301<C04XC

00<04a<011<406hC0P104`006a<00`0C00094`0301<C00801Q<00`0C4`3o4d4C00<04a<011<00`0C

4`194`0301<C00TC101[4`0301<C03hC000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C0?lC

@1<00`0C4`054`80BQ<00`0C4`0=4`@0J1<203hC000L4`0301<C00HC0`024`<01A<00`0C4`3o4clC

00<04a<01Q<00`0C4`184`0301<C018C101U4`0301<C03`C000b4`0301<C0?lC?Q<00`0C4`074`03

01<C04PC00<04a<05A<5068C00<04a<0>a<0038C00<04a<0oa<m4`0301<C00PC00<04a<0Aa<00`0C

4`0J4`@0Ga<203`C000b4`0301<C0?lC?1<00`0C4`094`0301<C04HC00<04a<07a<405`C0P0k4`00

<Q<00`0C4`3o4c/C00<04a<02Q<00`0C4`164`0301<C028C1@1I4`0301<C03TC000b4`0301<C0?lC

>Q<00`0C4`0;4`80Aa<00`0C4`0V4`@0Ea<00`0C4`0h4`00<Q<00`0C4`3o4cTC00<04a<031<00`0C

4`154`0301<C02XC101D4`80>A<0038C00<04a<0oa<i4`0301<C00`C00<04a<0AA<00`0C4`0^4`@0

DA<00`0C4`0g4`00<Q<00`0C4`3o4cPC00<04a<03A<00`0C4`144`0301<C03<C0P1?4`80>1<0038C

00<04a<0oa<g4`0301<C00hC00<04a<0A1<00`0C4`0e4`@0C1<203LC000b4`0301<C0?lC=Q<00`0C

4`0?4`0301<C04@C00<04a<0>A<204/C00<04a<0=A<0038C00<04a<0oa<f4`0301<C00lC0P144`03

01<C03`C10174`80=Q<0038C00<04a<0oa<e4`0301<C010C00<04a<0@a<00`0C4`0o4`<0AQ<00`0C

4`0d4`00<Q<00`0C4`3o4cDC00<04a<041<00`0C4`134`0301<C048C0`134`80=A<0024C00<04a<0

0Q<00`0C4`024`0301<C00@C00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`164`<0@A<00`0C

4`0c4`0081<00`0C00074`0301<000DC00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`194`80

?a<00`0C4`0c4`006a<3008C00<04`002A<00`0C4`034`80oa<d4`0301<C018C00<04a<0@Q<00`0C

4`1;4`<0?A<00`0C4`0b4`0081<00`0C00074`801Q<00`0C4`3o4c<C00<04a<04Q<204<C00<04a<0

CQ<203/C00<04a<0<Q<0020C00<04`001a<00`0C4`054`0301<C0?lC<Q<00`0C4`0C4`0301<C044C

00<04a<0DA<303PC00<04a<0<Q<0024C00<04a<01Q<300DC00<04a<0oa<b4`0301<C01<C00<04a<0

@A<00`0C4`1D4`80=a<00`0C4`0a4`00<Q<00`0C4`3o4c4C00<04a<051<00`0C4`114`0301<C05HC

0`0d4`0301<C034C000b4`0301<C0?lC<A<00`0C4`0>4`0301<C00<C00<04a<0@1<00`0C4`1I4`<0

<Q<2038C000b4`0301<C0?lC<1<00`0C4`0>4`0301<000@C00<04a<0@1<00`0C4`1L4`80<A<00`0C

4`0`4`00<Q<00`0C4`3o4c0C00<04a<02A<300@C00<04a<00Q<3040C00<04a<0GQ<202lC00<04a<0

<1<0038C00<04a<0oa<`4`0301<C00hC0P054`0301<C03lC00<04a<0HA<302`C00<04a<0<1<0038C

00<04a<0oa<`4`0301<C00hC00<04a<011<00`0C4`0o4`0301<C06@C00<04a<0:A<00`0C4`0`4`00

<Q<00`0C4`3o4blC00<04a<03a<300@C00<04a<0?a<00`0C4`1U4`<0:1<2034C000b4`0301<C0?lC

;a<00`0C4`0F4`0301<C03lC00<04a<0J1<00`0C4`0V4`0301<C02lC000b4`0301<C0?lC;a<00`0C

4`0F4`0301<C03lC00<04a<0JA<302DC00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC0P104`03

01<C06`C0P0S4`0301<C02lC000b4`0301<C0?lC;a<00`0C4`0F4`0301<C03lC00<04a<0KA<2028C

00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC00<04a<0?a<00`0C4`1_4`8081<00`0C4`0_4`00

<Q<00`0C4`3o4bhC00<04a<05a<00`0C4`0n4`0301<C078C0P0N4`0301<C02lC000L4`0301<C008C

00@04a<C0`034`0301<C00@C00<04a<0oa<^4`0301<C01LC00<04a<0?Q<00`0C4`1d4`8071<00`0C

4`0_4`006a<00`0C00074`0301<C008C00<04`001A<00`0C4`3o4bhC00<04a<05a<203lC00<04a<0

MQ<201XC00<04a<0;a<001HC0`024`0301<000PC00<04a<00a<00`0C4`034`80oa<_4`0301<C01LC

00<04a<0?Q<00`0C4`1h4`0301<C008C00<=4a<04A<00`0C4`0`4`006a<00`0C00084`0401<C4`80

1Q<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07TC00<03@d010dA4`0301<C030C000K4`03

01<000LC00<04`000Q<00`0C4`054`0301<C0?lC;A<00`0C4`0H4`0301<C03hC00<04a<0NA<93@lC

00<04a<0<1<001`C00<04a<01a<0100C4a<300DC00<04a<0oa<]4`0301<C01PC00<04a<0?Q<00`0C

4`1i4`T=3a<00`0C4`0`4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0m4`0301<C07XC2@d?4`03

01<C030C000b4`0301<C0?lC;A<00`0C4`0H4`80?Q<00`0C4`1i4`/=3Q<00`0C4`0`4`00<Q<00`0C

4`3o4bdC00<04a<061<00`0C4`0Q4`D00Q<00`0C4`0B4`0301<C00/C1@000a<0000Q4`D00Q<00`0C

4`0O4`D00Q<00`0C4`0C4`T=0a<500034`0000<C00<04a<0<A<0038C00<04a<0oa<]4`0301<C01PC

00<04a<08a<01`0C4a<04`004a<00`0C4`0=4`0701<C4`0C000R4`0301<C008C00<04a<08A<01`0C

4a<04`0051<93@0301<C008C00<04a<00a<0100C4`0c4`00<Q<00`0C4`0V4`0301<C008C00@04a<C

0`0S4`0301<C008C00<04a<00Q<3028C00<04a<00Q<0100C4a<202@C00<04a<00Q<00`0C4`024`03

01<C02HC1@114`0301<C01PC00<04a<08a<00`0C4`034`0301<C014C00<04a<03A<01`0C4a<04`00

8Q<00`0C4`024`0301<C024C00L04a<C01<001@C2@d00a<04`024`0301<C008C0P024`0301<C034C

000b4`0301<C02DC00<04`001a<00`0C4`0R4`0301<000TC00<04a<081<00`0C00074`0301<0028C

00<04`001a<00`0C000Y4`0301<C044C00<04a<061<00`0C4`0S4`0401<C4`8051<00`0C4`0=4`04

01<C4`808a<00`0C4`034`0301<C020C00<04a<00Q<00`0C4`0D4`H=11<200034`0C008C00<04`00

0Q<00`0C4`0a4`00<Q<00`0C4`0U4`0301<000PC00<04a<08A<00`0C00074`@08A<00`0C00074`03

01<0028C00<04`001a<00`0C000Y4`0301<C040C00<04a<06A<00`0C4`0S4`0501<C4`005A<00`0C

4`0=4`0501<C4`0091<01`0C4a<04`008Q<01`0C4a<04`0061<00`dC4`064`800a<01@0C01<003@C

000b4`0301<C02DC00<04`0021<00`0C4`0Q4`0301<000LC00<04`008Q<00`0C00074`808a<00`0C

00084`0301<C02PC00<04a<0@1<00`0C4`0I4`808a<200<C0`0C4`0301<C00`C0P044`808A<200<C

0`0Q4`8011<00`0C4`0P4`8011<200034`0C03<C000b4`0301<C02DC00<04`001a<00`0C000R4`03

01<000PC0P0R4`0301<000LC00<04a<08Q<00`0C00074`0301<002TC00<04a<0@1<00`0C4`0I4`03

01<C03dC00<04a<0R1<00`0C4`054`0301<C038C000b4`0301<C02HC00<04a<01a<00`0C4`0R4`03

01<C00PC00<04a<08A<00`0C4`074`808a<00`0C4`074`0301<C02LC0P124`0301<C01TC00<04a<0

?A<00`0C4`294`801A<00`0C4`0b4`00<Q<00`0C4`3o4b`C00<04a<06A<00`0C4`0m4`0301<C08/C

00D04a<C000e4`00<Q<00`0C4`3o4b`C00<04a<06A<00`0C4`0m4`0301<C08/C00@04a<04a<401lC

000b4`0301<C0?lC;1<00`0C4`0I4`0301<C03dC00<04a<0S1<201@C0`0P4`00<Q<00`0C4`3g4`<0

:a?o00XC00<04a<07Q<0038C00<04a<0n1<00`0C4`0[4`0301<C008C00@04a<021<00`0C4`054`03

01<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<0

1A<00`0C4`034`0301<000LC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`03

01<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC00<04a<0

1Q<00`0C4`054`0301<C00DC00<04a<01A<300HC00<04a<031<2020C000/4n`01Pd600TC00<04a<0

<1<00`0C4`0I4`0301<C02HC00<04a<051<00`0C4`0@4`0301<C02HC00<04a<09Q<00`0C4`0V4`04

01<C03HC000b4`0301<C00PC00<04a<02A<00`0C4`094`0301<C00TC00<04a<021<00`0C4`094`03

01<C00TC00<04a<02A<00`0C4`084`0301<C00TC00<04a<02A<00`0C4`094`0301<C00TC00<04a<0

21<00`0C4`094`0301<C00TC00<04a<02A<00`0C4`084`0301<C00<C3@d54`0301<C00`C100`4`03

01<C01TC00<04a<0?A<00`0C4`2;4`0501<C4`00=A<0038C00<04a<0;1<00`0C4`0/4`0301<C02`C

00<04a<0;1<00`0C4`0G4`<=4Q<00`0C4`104`0301<C01TC00<04a<0?A<00`0C4`2:4`0301<C008C

00<04a<0<a<0038C00<04a<0ca<43EPC00<04a<06A<00`0C4`0m4`0301<C08TC00<04a<011<00`0C

4`0b4`00<Q<00`0C4`3;4`@=G1<00`0C4`0I4`80?Q<00`0C4`274`801a<00`0C4`0b4`00<Q<00`0C

4`394`8=H1<00`0C4`0I4`0301<C03dC00<04a<0Qa<00`0C4`064`0301<C038C000b4`0301<C0<LC

0PeS4`0301<C01PC00<04a<0?A<00`0C4`264`0301<C00PC00<04a<0<A<0038C00<04a<0aA<23FDC

00<04a<061<00`0C4`0m4`0301<C08@C0P0;4`0301<C034C000b4`0301<C0<8C0`eW4`0301<C01PC

00<04a<0?A<00`0C4`234`0301<C00/C00<04a<0<A<0038C00<04a<0`1<23FXC00<04a<061<00`0C

4`0m4`0301<C088C00<04a<031<00`0C4`0a4`00<Q<00`0C4`2m4`<=K1<00`0C4`0H4`80?Q<00`0C

4`204`803a<00`0C4`0a4`00<Q<00`0C4`2k4`8=Ka<00`0C4`0H4`0301<C03dC00<04a<0Oa<00`0C

4`0@4`0301<C030C000b4`0301<C0;PC0`ea4`0301<C01PC00<04a<0?Q<00`0C4`1l4`804a<00`0C

4`0`4`00<Q<00`0C4`2f4`8=M1<00`0C4`0H4`0301<C03hC00<04a<0Na<201@C00<04a<0<1<0038C

00<04a<0/a<33GHC00<04a<061<00`0C4`0n4`0301<C07TC0P0F4`0301<C030C000b4`0301<C0;4C

0Pei4`0301<C01PC00<04a<0?Q<00`0C4`1h4`0301<C01HC00<04a<0<1<0038C00<04a<0[A<43G`C

00<04a<05a<203lC00<04a<0MQ<201TC00<04a<0<1<0038C00<04a<0Z1<53H0C00<04a<05a<00`0C

4`0n4`0301<C07@C0P0L4`0301<C02lC000L4`0301<C008C00@04a<C0`034`0301<C00@C00<04a<0

Y1<43HDC00<04a<05a<00`0C4`0n4`0301<C07<C00<04a<071<00`0C4`0_4`006a<00`0C00074`03

01<C008C00<04`001A<00`0C4`2M4`L=RA<00`0C4`0G4`0301<C03lC00<04a<0L1<201lC00<04a<0

;a<001/C00<04`0021<00`0C4`034`0301<C00<C0P2;4a<=TA<00`0C4`0F4`0301<C03lC00<04a<0

KA<3024C00<04a<0;a<001/C00<04`0021<0100C4a<200HC00<04a<0PQ<83J@C00<04a<05Q<00`0C

4`0o4`0301<C06`C0P0S4`0301<C02lC000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C080C

0Pf/4`0301<C01HC0P104`0301<C06XC0P0U4`0301<C02lC000L4`0301<C00LC00@04a<C0`054`03

01<C07dC0`f^4`0301<C01HC00<04a<0?a<00`0C4`1X4`809a<00`0C4`0_4`00<Q<00`0C4`1j4`<=

/A<00`0C4`0F4`0301<C03lC00<04a<0IQ<202TC00<04a<0;a<0038C00<04a<0N1<23KDC00<04a<0

5A<00`0C4`0o4`0301<C06@C0P0Z4`0301<C030C000b4`0301<C07HC0Pfg4`0301<C00lC00<04a<0

0a<00`0C4`0o4`0301<C068C0P0/4`0301<C030C000b4`0301<C07@C0Pfi4`0301<C00hC00<04`00

11<00`0C4`104`0301<C05hC0`0^4`0301<C030C000b4`0301<C078C0Pfk4`0301<C010C00<04a<0

0Q<3040C00<04a<0G1<3030C00<04a<0<1<0038C00<04a<0L1<23KhC00<04a<03A<200DC00<04a<0

@1<00`0C4`1J4`80<Q<2038C000b4`0301<C06hC0Pg04`0301<C00dC00<04a<011<00`0C4`114`03

01<C05LC0P0d4`0301<C034C000b4`0301<C06`C0Pg34`0301<C00`C0`044`0301<C044C00<04a<0

E1<303HC00<04a<0<A<0038C00<04a<0JQ<23LDC00<04a<04a<00`0C4`114`0301<C058C0`0g4`80

<a<0038C00<04a<0JA<00`dC4`364`0301<C018C0P124`0301<C04lC0`0j4`0301<C038C000b4`03

01<C06PC00<=4a<0aa<00`0C4`0B4`0301<C048C00<04a<0C1<303`C00<04a<0<Q<0038C00<04a<0

IQ<23L/C00<04a<04A<00`0C4`124`0301<C04TC0`0n4`0301<C03<C000b4`0301<C06DC00<=4a<0

ba<00`0C4`0A4`0301<C048C00<04a<0Aa<3040C00<04a<0<a<0024C00<04a<00Q<00`0C4`024`03

01<C00@C00<04a<0I1<00`dC4`3=4`0301<C010C00<04a<0@Q<00`0C4`144`<0@Q<203DC000P4`03

01<000LC00<04`001A<00`0C4`1R4`8=d1<00`0C4`0@4`0301<C04<C00<04a<0@1<304DC00<04a<0

=1<0020C00<04`002A<00`0C4`034`80HQ<00`dC4`3A4`0301<C00lC0P144`0301<C03dC0`174`80

=Q<0020C00<04`001a<200HC00<04a<0H1<00`dC4`3B4`0301<C00lC00<04a<0A1<00`0C4`0i4`<0

BQ<00`0C4`0e4`0081<00`0C00074`0301<C00DC00<04a<0GQ<23MHC00<04a<03Q<00`0C4`144`03

01<C03HC101;4`80=a<0024C00<04a<01Q<300DC00<04a<0GA<00`dC4`3G4`0301<C00dC00<04a<0

A1<00`0C4`0c4`<0Ca<00`0C4`0f4`00<Q<00`0C4`1L4`033A<C0=TC00<04a<031<00`0C4`154`03

01<C02lC0`1A4`0301<C03LC000b4`0301<C05XC0PgL4`0301<C00`C00<04a<0AA<00`0C4`0[4`@0

Da<203TC000b4`0301<C05TC00<=4a<0gA<00`0C4`0;4`80Aa<00`0C4`0W4`@0EQ<00`0C4`0h4`00

<Q<00`0C4`1G4`8=h1<00`0C4`0;4`0301<C04HC00<04a<08a<505PC0P0j4`00<Q<00`0C4`1F4`03

3A<C0>4C0P0;4`0301<C04HC00<04a<081<405/C0P0k4`00<Q<00`0C4`1D4`8=iQ<00`0C4`084`03

01<C04LC00<04a<06a<405lC00<04a<0>Q<0038C00<04a<0Da<00`dC4`3W4`0301<C00LC00<04a<0

Aa<201PC1@1Q4`0301<C03/C000b4`0301<C058C00<=4a<0j1<00`0C4`074`0301<C04PC00<04a<0

4a<406@C0P0m4`00<Q<00`0C4`1@4`8=k1<00`0C4`064`80BQ<00`0C4`0>4`@0Ia<203hC000b4`03

01<C04lC00<=4a<0kA<200HC00<04a<0BA<00`0C4`0:4`@0JQ<203lC000b4`0301<C04dC0Pgb4`03

01<C00<C00<04a<0BQ<00`0C4`054`D0K1<2040C000b4`0301<C04`C00<=4a<0la<200<C00<04a<0

BQ<200034`0000<0L1<2044C000b4`0301<C04XC0Pg^4`D00Q<0100C4`024`0301<C04TC1@1c4`80

@Q<001`C00<04a<00Q<00`0C4`024`0301<C008C00<04a<011<00`0C4`194`033A<C0?0C00L04a<C

01<0008C0`174`D00Q<00`0C4`1a4`80@a<001/C00<04`0021<01`0C4a<04`001A<00`0C4`174`8=

la<01`0C4a<04`0011<3040C1@084`0301<C06hC0P154`006a<00`0C00084`0301<C00<C00<04a<0

0a<204LC00<=4a<0la<01`0C4a<04`0011<0100C000j4`D03A<00`0C4`1]4`80AQ<001/C00<04`00

2A<00`0C4`0200HC00<04a<0A1<23OHC00L04a<C01<000@C00@04a<C0`0a4`H04a<206/C0`174`00

6a<00`0C00074`0301<0008C00<04a<01A<00`0C4`134`033A<C0?DC0P044`0301<C00<C00<04a<0

11<302PC1`0I4`80JA<204TC000L4`0301<C00HC0`024`<01A<00`0C4`114`8=oa<54`0301<C00LC

1@0K4`T081<00`0C4`1T4`<0Ba<0038C00<04a<0?a<23OlC1a<00`0C4`0<4a`0:A<2068C0`1=4`00

<Q<00`0C4`0m4`8=oa<94`80Da<205lC0`1?4`00<Q<00`0C4`0k4`8=oa<;4`0301<C05<C0P1J4`@0

DQ<0038C00<04a<0>1<33OlC3A<00`0C4`1D4`80EQ<405DC000b4`0301<C03DC0`go4a0C00<04a<0

EQ<204lC1@1I4`00<Q<00`0C4`0a4`@=oa<C4`0301<C05LC0`184`H0GA<0038C00<04a<0;Q<33OlC

5a<00`0C4`1I4`<0@1<7068C000b4`0301<C02/C0`go4aXC0P1L4`<0>1<706PC000b4`0301<C02LC

10go4adC00<04a<0GQ<302hC201^4`00<Q<00`0C4`0R4`D=oa<Q4`0301<C060C1@0S4`P0MA<0038C

00<04a<07A<53OlC9Q<00`0C4`1T4`L051<:07`C000b4`0301<C01<C2Pgo4b/C00<04a<0JQ<E08HC

000b4aH=oa<e4`0301<C0?lC1Q<002TC1@044`0301<C0?lCB1<20?lC1a<002/C00<04a<011<00`0C

4`3o4dPC00<04a<0oa<64`00:a<00`0C4`044`80oa=94`0301<C0?lC1Q<002/C00<04a<0oa?o4ePC

000[4`0301<C0?lCoa=H4`00:Q<20?lCoa=J4`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC

003o4olCQQ<0074C10000a<00007008C00<04a<00Q<0100C4a<200<C0P034`800a<200<C0P034`80

0a<200<C0P034`800a<200<C0P034`800a<200@C00<04a<00Q<0100C4a<20?lC[Q<0074C0`084`07

01<C4`0C00074`0301<000@C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`03

01<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0601<C01<00Q<00`0C

00024`0301<00:8C0P3o4`TC001c4`0301<C00@00Q<01`0C4a<04`001a<00`0C00034`800a<200<C

0P034`800a<200<C0P034`800a<200<C0P034`800a<200<C0P024`0301<0008C00<04`000Q<00`0C

002S4`0301<C0?lC1a<001TC10000a<00006008C2P024`800Q<3008C0`034`8000HC00004`0W4`80

21<00`0C4`024`0301<C00HC0P034`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00034`03

01<C008C00@04a<C0P2R4`<00Q<00`0C4`3o4`@C000J4`0601<C01<00Q<00`0C00044`0601<C01<0

0Q<00`0C00054`0301<C008C00D04a<C00024`0401<04`80<A<01`0C4a<04`001a<00`0C4`024`03

01<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C4`044`03

01<C09TC00P04a<04`0C0?lC1A<001XC00H04a<04`044`0301<C008C00<04a<00Q<00`0C4`024`03

01<C00<C00<04a<00Q<01@0C4a<0008C00@04`0C0P0`4`8011<00`0C4`074`800a<200<C0P034`80

0a<200<C0P034`800a<200<C0P034`800a<200<C0P034`800a<00`0C4`024`0301<C008C0P034`03

01<C09XC00P04a<04`0C0?lC1A<001XC00D04a<04`0200<C0P034`0301<C008C0P034`0301<C00<C

00<04a<00Q<01@0C4a<0008C00H04`004`3o4blC0`0011<04`3o4`DC000J4`0601<C01<00Q<00`0C

00024`0301<000@C00h04a<04`0C01<04`0C008C00D04a<C00024`0601<001<0oa<c4`0301<00?lC

1A<001TC10000a<0000;008C1@001A<0000C00D000@C00000a<200044`004`80oa<d4`0301<C0?lC

11<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00

oa?o4hHC003o4olCQQ<00001\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.77084, -14.119, 0.0242408, 0.16996}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -57 0 ]

[.5 .63053 57 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -118 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(17.5799999999999911`) show

173.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .5573 m

.02499 .5573 L

.02606 .5573 L

.02729 .55729 L

.02846 .55728 L

.03053 .55725 L

.03279 .55722 L

.03527 .55716 L

.0379 .55709 L

.04262 .55693 L

.04749 .55671 L

.05205 .55646 L

.06245 .55573 L

.07305 .55474 L

.08274 .55362 L

.10458 .55032 L

.12357 .54654 L

.14429 .54141 L

.18493 .52808 L

.22406 .51098 L

.26565 .48836 L

.30571 .46307 L

.34426 .43718 L

.38527 .41069 L

.40569 .39894 L

.42475 .38932 L

.44425 .38112 L

.46273 .37503 L

.47247 .37251 L

.48308 .37029 L

.49272 .36875 L

.50163 .3677 L

.50627 .36729 L

.51126 .36695 L

.51356 .36682 L

.51598 .36671 L

.51824 .36662 L

.5203 .36656 L

.52276 .36651 L

.52412 .36648 L

.5254 .36647 L

.52658 .36646 L

.52767 .36645 L

.52887 .36645 L

.53014 .36645 L

.53141 .36646 L

.53213 .36647 L

.53279 .36647 L

.53526 .36651 L

.53665 .36654 L

Mistroke

.53816 .36657 L

.5409 .36665 L

.54623 .36684 L

.55125 .36706 L

.56061 .36757 L

.5816 .36886 L

.59139 .36939 L

.59673 .36963 L

.60172 .3698 L

.60598 .36991 L

.6072 .36994 L

.60836 .36996 L

.6094 .36997 L

.61053 .36998 L

.6117 .36999 L

.61294 .37 L

.61409 .37 L

.61517 .37 L

.61643 .36999 L

.61759 .36999 L

.61886 .36997 L

.6202 .36995 L

.62278 .36989 L

.62522 .36982 L

.62977 .36964 L

.63467 .36936 L

.63998 .36896 L

.64955 .36797 L

.65836 .36675 L

.67716 .36311 L

.69782 .35759 L

.73821 .34331 L

.77709 .32818 L

.79687 .32122 L

.81841 .31487 L

.82843 .31247 L

.83909 .31033 L

.84907 .30873 L

.85823 .30759 L

.86758 .30676 L

.8725 .30644 L

.875 .30631 L

.87767 .3062 L

.88004 .30612 L

.88219 .30606 L

.88435 .30601 L

.8864 .30598 L

.88755 .30596 L

.88878 .30595 L

.88982 .30595 L

Mistroke

.89098 .30594 L

.89221 .30595 L

.89291 .30595 L

.89354 .30595 L

.89477 .30596 L

.89595 .30597 L

.89719 .30599 L

.89854 .30601 L

.90098 .30606 L

.90554 .30618 L

.91087 .30636 L

.91577 .30657 L

.93416 .30752 L

.94402 .30805 L

.9546 .30854 L

.95972 .30873 L

.96457 .30887 L

.96669 .30892 L

.96893 .30896 L

.9701 .30897 L

.97139 .30899 L

.97256 .309 L

.97367 .30901 L

.97488 .30901 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.71595 .16672 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4gdC00<04a<0oa<64`00oa=m4`0301<C0?lC1Q<002TC1@3o4dlC0P3o4`LC

000[4`0301<C0?lCCa<00`0C4`1^4`d0RQ<002DC0`034`0301<C00@C0P3o4dTC00<04a<0IQ<800`C

3@1n4`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`1Q4`D081<807LC000[4`0301<C00@C00<04a<0

oa=84`0301<C05hC100/4`L0L1<002XC0P064`0301<C0?lCB1<00`0C4`1L4`<0=A<706XC000b4`03

01<C0?lCB1<205/C0P0o4`H0I1<0038C00<04a<0oa=84`0301<C05PC0P164`H0Ga<0038C00<04a<0

oa=84`0301<C05HC0P1>4`D0FQ<0038C00<04a<0oa=84`0301<C05DC0P1C4`D0EQ<0038C00<04a<0

oa=84`0301<C05@C00<04a<0Ea<5058C000b4`0301<C0?lCB1<205<C0P1N4`<0D1<0038C00<04a<0

oa=84`0301<C00lC5P0/4`80HA<404dC000b4`0301<C0?lCB1<00`0C4`0:4`D05Q<9028C0P1U4`<0

Ba<0038C00<04a<0oa=84`0301<C00DC1@0S4`L06a<206PC0`194`00<Q<00`0C4`3o4c/C1@024`03

01<C00<C00<04a<00a<202lC1P0D4`80Ja<204PC000b4`0301<C0?lC?A<01`0C4a<04`0011<00`0C

4`0303HC1P0>4`80KA<304HC000b4`0301<C0?lC=a<300<C00L04a<C01<000@C0`0n4`H02A<00`0C

4`1^4`80AA<0038C00<04a<0oa<m4`0701<C4`0C00034`80AA<500@C00<04a<0L1<204@C000L4`03

01<C008C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0oa<m4`0701<C4`0C00024`0301<004XC

1@1d4`80@Q<001/C00<04`0021<01`0C4a<04`001A<00`0C4`3o4c`C0P044`0401<0008C00<04a<0

Ba<6074C0P114`005Q<3008C00<04`0021<00`0C4`034`0301<C00<C0P3o4d<C0P044`0301<C04XC

00<04a<011<406hC0P104`006a<00`0C00094`0301<C00801Q<00`0C4`3o4d4C00<04a<011<00`0C

4`194`0301<C00TC101[4`0301<C03hC000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C0?lC

@1<00`0C4`054`80BQ<00`0C4`0=4`@0J1<203hC000L4`0301<C00HC0`024`<01A<00`0C4`3o4clC

00<04a<01Q<00`0C4`184`0301<C018C101U4`0301<C03`C000b4`0301<C0?lC?Q<00`0C4`074`03

01<C04PC00<04a<05A<5068C00<04a<0>a<0038C00<04a<0oa<m4`0301<C00PC00<04a<0Aa<00`0C

4`0J4`@0Ga<203`C000b4`0301<C0?lC?1<00`0C4`094`0301<C04HC00<04a<07a<405`C0P0k4`00

<Q<00`0C4`3o4c/C00<04a<02Q<00`0C4`164`0301<C028C1@1I4`0301<C03TC000b4`0301<C0?lC

>Q<00`0C4`0;4`80Aa<00`0C4`0V4`@0Ea<00`0C4`0h4`00<Q<00`0C4`3o4cTC00<04a<031<00`0C

4`154`0301<C02XC101D4`80>A<0038C00<04a<0oa<i4`0301<C00`C00<04a<0AA<00`0C4`0^4`@0

DA<00`0C4`0g4`00<Q<00`0C4`3o4cPC00<04a<03A<00`0C4`144`0301<C03<C0P1?4`80>1<0038C

00<04a<0oa<g4`0301<C00hC00<04a<0A1<00`0C4`0e4`@0C1<203LC000b4`0301<C0?lC=Q<00`0C

4`0?4`0301<C04@C00<04a<0>A<204/C00<04a<0=A<0038C00<04a<0oa<f4`0301<C00lC0P144`03

01<C03`C10174`80=Q<0038C00<04a<0oa<e4`0301<C010C00<04a<0@a<00`0C4`0o4`<021<00`dC

4`0k4`0301<C03@C000b4`0301<C0?lC=A<00`0C4`0@4`0301<C04<C00<04a<0@Q<3008C1Pdk4`80

=A<0024C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C

4`164`0300d=00L=>Q<00`0C4`0c4`0081<00`0C00074`0301<000DC00<04a<0oa<d4`0301<C014C

00<04a<0@Q<00`0C4`174`T=>Q<00`0C4`0c4`006a<3008C00<04`002A<00`0C4`034`80oa<d4`03

01<C018C00<04a<0@Q<00`0C4`174`T=>a<00`0C4`0b4`0081<00`0C00074`801Q<00`0C4`3o4c<C

00<04a<04Q<204<C00<04a<0AQ<;3CXC00<04a<0<Q<0020C00<04`001a<00`0C4`054`0301<C0?lC

<Q<00`0C4`0C4`0301<C044C00<04a<0B1<93@<0>1<00`0C4`0b4`008A<00`0C4`064`<01A<00`0C

4`3o4c8C00<04a<04a<00`0C4`114`0301<C04PC2@d34`80=a<00`0C4`0a4`00<Q<00`0C4`3o4c4C

00<04a<051<00`0C4`114`0301<C04PC2@d54`<0=1<00`0C4`0a4`00<Q<00`0C4`3o4c4C00<04a<0

3Q<00`0C4`034`0301<C040C00<04a<0BQ<63@TC0`0b4`80<Q<0038C00<04a<0oa<`4`0301<C00hC

00<04`0011<00`0C4`104`0301<C04dC00<=4a<031<2034C00<04a<0<1<0038C00<04a<0oa<`4`03

01<C00TC0`044`0301<C008C0`104`0301<C05hC0P0_4`0301<C030C000b4`0301<C0?lC<1<00`0C

4`0>4`801A<00`0C4`0o4`0301<C064C0`0/4`0301<C030C000b4`0301<C0?lC<1<00`0C4`0>4`03

01<C00@C00<04a<0?a<00`0C4`1T4`0301<C02TC00<04a<0<1<0038C00<04a<0oa<_4`0301<C00lC

0`044`0301<C03lC00<04a<0IA<302PC0P0a4`00<Q<00`0C4`3o4blC00<04a<05Q<00`0C4`0o4`03

01<C06PC00<04a<09Q<00`0C4`0_4`00<Q<00`0C4`3o4blC00<04a<05Q<00`0C4`0o4`0301<C06TC

0`0U4`0301<C02lC000b4`0301<C0?lC;a<00`0C4`0F4`80@1<00`0C4`1/4`808a<00`0C4`0_4`00

<Q<00`0C4`3o4blC00<04a<05Q<00`0C4`0o4`0301<C06dC0P0R4`0301<C02lC000b4`0301<C0?lC

;a<00`0C4`0F4`0301<C03lC00<04a<0Ka<2020C00<04a<0;a<0038C00<04a<0oa<^4`0301<C01LC

00<04a<0?Q<00`0C4`1b4`807Q<00`0C4`0_4`0071<00`0C4`024`0401<C4`<00a<00`0C4`044`03

01<C0?lC;Q<00`0C4`0G4`0301<C03hC00<04a<0M1<201`C00<04a<0;a<001/C00<04`001a<00`0C

4`024`0301<000DC00<04a<0oa<^4`0301<C01LC0P0o4`0301<C07HC0P0J4`0301<C02lC000F4`<0

0Q<00`0C00084`0301<C00<C00<04a<00a<20?lC;a<00`0C4`0G4`0301<C03hC00<04a<0N1<00`0C

4`0F4`0301<C030C000K4`0301<000PC00@04a<C0P064`0301<C0?lC;A<00`0C4`0H4`0301<C03hC

00<04a<0NA<201HC00<04a<0<1<001/C00<04`001a<00`0C00024`0301<C00DC00<04a<0oa<]4`03

01<C01PC00<04a<0?Q<00`0C4`1k4`0301<C01<C00<04a<0<1<001`C00<04a<01a<0100C4a<300DC

00<04a<0oa<]4`0301<C01PC00<04a<0?Q<00`0C4`1l4`0301<C018C00<04a<0<1<0038C00<04a<0

oa<]4`0301<C01PC00<04a<0?A<00`0C4`1n4`804Q<00`0C4`0`4`00<Q<00`0C4`3o4bdC00<04a<0

61<203hC00<04a<0P1<2010C00<04a<0<1<0038C00<04a<0oa<]4`0301<C01PC00<04a<08A<5008C

00<04a<04Q<00`0C4`0;4`D000<C00008A<5008C00<04a<07a<5008C00<04a<06a<0100C4a<50003

4`0000<C00<04a<0<A<0038C00<04a<0oa<]4`0301<C01PC00<04a<08a<01`0C4a<04`004a<00`0C

4`0=4`0701<C4`0C000R4`0301<C008C00<04a<08A<01`0C4a<04`0071<200@C00<04a<00a<0100C

4`0c4`00<Q<00`0C4`0V4`0301<C008C00@04a<C0`0S4`0301<C008C00<04a<00Q<3028C00<04a<0

0Q<0100C4a<202@C00<04a<00Q<00`0C4`024`0301<C02HC1@114`0301<C01PC00<04a<08a<00`0C

4`034`0301<C014C00<04a<03A<01`0C4a<04`008Q<00`0C4`024`0301<C024C00L04a<C01<001hC

00D04a<C00044`800Q<00`0C4`0a4`00<Q<00`0C4`0U4`0301<000LC00<04a<08Q<00`0C00094`03

01<C020C00<04`001a<00`0C000R4`0301<000LC00<04`00:A<00`0C4`114`0301<C01PC00<04a<0

8a<0100C4a<201@C00<04a<03A<0100C4a<202<C00<04a<00a<00`0C4`0P4`0301<C008C00<04a<0

7Q<200034`0C008C00<04`000Q<00`0C4`0a4`00<Q<00`0C4`0U4`0301<000PC00<04a<08A<00`0C

00074`@08A<00`0C00074`0301<0028C00<04`001a<00`0C000Y4`0301<C040C00<04a<06A<00`0C

4`0S4`0501<C4`005A<00`0C4`0=4`0501<C4`0091<01`0C4a<04`008Q<01`0C4a<04`008A<200<C

00D04`0C000d4`00<Q<00`0C4`0U4`0301<000PC00<04a<08A<00`0C00074`0301<0028C00<04`00

1a<202<C00<04`0021<00`0C4`0X4`0301<C040C00<04a<06A<202<C0P034`<04a<00`0C4`0<4`80

11<2024C0P034`<08A<200@C00<04a<081<200@C0P000a<04`0c4`00<Q<00`0C4`0U4`0301<000LC

00<04`008Q<00`0C00084`808Q<00`0C00074`0301<C028C00<04`001a<00`0C000Y4`0301<C040C

00<04a<06A<00`0C4`0m4`0301<C08PC00<04a<01A<00`0C4`0b4`00<Q<00`0C4`0V4`0301<C00LC

00<04a<08Q<00`0C4`084`0301<C024C00<04a<01a<202<C00<04a<01a<00`0C4`0W4`80@Q<00`0C

4`0I4`0301<C03dC00<04a<0RA<200DC00<04a<0<Q<0038C00<04a<0oa</4`0301<C01TC00<04a<0

?A<00`0C4`2;4`0501<C4`00=A<0038C00<04a<0oa</4`0301<C01TC00<04a<0?A<00`0C4`2;4`04

01<C01<C100O4`00<Q<00`0C4`3o4b`C00<04a<06A<00`0C4`0m4`0301<C08`C0P0D4`<081<0038C

00<04a<0ma<302/Co`0:4`0301<C01hC000b4`0301<C0?PC00<04a<0:a<00`0C4`024`0401<C00PC

00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C

4`064`0301<C00DC00<04a<00a<00`0C00074`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC

00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C

4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC0`064`0301<C00`C0P0P4`00;1?A024=

1P094`0301<C030C00<04a<06A<00`0C4`0V4`0301<C01@C00<04a<041<00`0C4`0V4`0301<C02HC

00<04a<09Q<0100C4`0f4`00<Q<00`0C4`084`0301<C00TC00<04a<02A<00`0C4`094`0301<C00PC

00<04a<02A<00`0C4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0C

4`094`0301<C00PC00<04a<02A<00`0C4`094`0301<C00LC1@d84`0301<C00TC00<04a<02A<00`0C

4`0<4`@0<1<00`0C4`0I4`0301<C03dC00<04a<0Ra<01@0C4a<003DC000b4`0301<C02`C00<04a<0

;1<00`0C4`0/4`0301<C02`C00<04a<00a<43BDC00<04a<0@1<00`0C4`0I4`0301<C03dC00<04a<0

RQ<00`0C4`024`0301<C03<C000b4`0301<C0;/C10e/4`0301<C01TC00<04a<0?A<00`0C4`294`03

01<C00@C00<04a<0<Q<0038C00<04a<0^A<23G0C00<04a<06A<203hC00<04a<0Qa<200LC00<04a<0

<Q<0038C00<04a<0]Q<33G8C00<04a<06A<00`0C4`0m4`0301<C08LC00<04a<01Q<00`0C4`0b4`00

<Q<00`0C4`2d4`8=MQ<00`0C4`0H4`0301<C03dC00<04a<0QQ<00`0C4`084`0301<C034C000b4`03

01<C0;4C0`eh4`0301<C01PC00<04a<0?A<00`0C4`244`802a<00`0C4`0a4`00<Q<00`0C4`2_4`8=

Na<00`0C4`0H4`0301<C03dC00<04a<0Pa<00`0C4`0;4`0301<C034C000b4`0301<C0:`C0`em4`03

01<C01PC00<04a<0?A<00`0C4`224`0301<C00`C00<04a<0<A<0038C00<04a<0ZA<33H0C00<04a<0

61<203hC00<04a<0P1<200lC00<04a<0<A<0038C00<04a<0YA<43H<C00<04a<061<00`0C4`0m4`03

01<C07lC00<04a<041<00`0C4`0`4`00<Q<00`0C4`2R4`<=Qa<00`0C4`0H4`0301<C03hC00<04a<0

O1<201<C00<04a<0<1<0038C00<04a<0X1<23HXC00<04a<061<00`0C4`0n4`0301<C07/C0P0D4`03

01<C030C000b4`0301<C09`C10f<4`0301<C01PC00<04a<0?Q<00`0C4`1i4`805Q<00`0C4`0`4`00

<Q<00`0C4`1`4a`=1Q<:3I0C00<04a<061<00`0C4`0n4`0301<C07PC00<04a<05Q<00`0C4`0`4`00

<Q<00`0C4`1[4`D=71<63I/C00<04a<05a<203lC00<04a<0MQ<201TC00<04a<0<1<0038C00<04a<0

Ia<43L8C00<04a<05a<00`0C4`0n4`0301<C07@C0P0L4`0301<C02lC000L4`0301<C008C00@04a<C

0`034`0301<C00@C00<04a<0I1<33LHC00<04a<05a<00`0C4`0n4`0301<C07<C00<04a<071<00`0C

4`0_4`006a<00`0C00074`0301<C008C00<04`001A<00`0C4`1R4`8=bA<00`0C4`0G4`0301<C03lC

00<04a<0L1<201lC00<04a<0;a<001/C00<04`0021<00`0C4`034`0301<C00<C0P1Q4`8=c1<00`0C

4`0F4`0301<C03lC00<04a<0KA<3024C00<04a<0;a<001/C00<04`0021<0100C4a<200HC00<04a<0

GQ<23LhC00<04a<05Q<00`0C4`0o4`0301<C06`C0P0S4`0301<C02lC000K4`0301<000LC00<04`00

0Q<00`0C4`054`0301<C05`C0Pg@4`0301<C01HC0P104`0301<C06XC0P0U4`0301<C02lC000L4`03

01<C00LC00@04a<C0`054`0301<C05/C00<=4a<0d1<00`0C4`0F4`0301<C03lC00<04a<0J1<202LC

00<04a<0;a<0038C00<04a<0FA<23M<C00<04a<05Q<00`0C4`0o4`0301<C06HC0P0Y4`0301<C02lC

000b4`0301<C05LC0PgF4`0301<C01DC00<04a<0?a<00`0C4`1T4`80:Q<00`0C4`0`4`00<Q<00`0C

4`1F4`033A<C0=HC00<04a<03a<00`0C4`034`0301<C03lC00<04a<0HQ<202`C00<04a<0<1<0038C

00<04a<0E1<23MTC00<04a<03Q<00`0C00044`0301<C040C00<04a<0GQ<302hC00<04a<0<1<0038C

00<04a<0DQ<23M/C00<04a<041<00`0C4`024`<0@1<00`0C4`1L4`<0<1<00`0C4`0`4`00<Q<00`0C

4`1A4`033A<C0=`C00<04a<03A<200DC00<04a<0@1<00`0C4`1J4`80<Q<2038C000b4`0301<C04lC

0PgO4`0301<C00dC00<04a<011<00`0C4`114`0301<C05LC0P0d4`0301<C034C000b4`0301<C04dC

0PgR4`0301<C00`C0`044`0301<C044C00<04a<0E1<303HC00<04a<0<A<0038C00<04a<0C1<00`dC

4`3R4`0301<C01<C00<04a<0@A<00`0C4`1B4`<0=a<203<C000b4`0301<C04XC0PgV4`0301<C018C

0P124`0301<C04lC0`0j4`0301<C038C000b4`0301<C04TC00<=4a<0iQ<00`0C4`0B4`0301<C048C

00<04a<0C1<303`C00<04a<0<Q<0038C00<04a<0B1<00`dC4`3X4`0301<C014C00<04a<0@Q<00`0C

4`194`<0?Q<00`0C4`0c4`00<Q<00`0C4`164`8=ja<00`0C4`0A4`0301<C048C00<04a<0Aa<3040C

00<04a<0<a<0024C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0AA<00`dC4`3/4`0301<C010C

00<04a<0@Q<00`0C4`144`<0@Q<203DC000P4`0301<000LC00<04`001A<00`0C4`134`8=ka<00`0C

4`0@4`0301<C04<C00<04a<0@1<304DC00<04a<0=1<0020C00<04`002A<00`0C4`034`80@a<00`dC

4`3`4`0301<C00lC0P144`0301<C03dC0`174`80=Q<0020C00<04`001a<200HC00<04a<0@1<23O<C

00<04a<03a<00`0C4`144`0301<C03TC0`1:4`0301<C03DC000P4`0301<000LC00<04a<01A<00`0C

4`0n4`8=mQ<00`0C4`0>4`0301<C04@C00<04a<0=Q<404/C0P0g4`008A<00`0C4`064`<01A<00`0C

4`0m4`033A<C0?LC00<04a<03A<00`0C4`144`0301<C03<C0`1?4`0301<C03HC000b4`0301<C03/C

0Pgk4`0301<C00`C00<04a<0AA<00`0C4`0_4`<0DA<00`0C4`0g4`00<Q<00`0C4`0i4`8=oA<00`0C

4`0<4`0301<C04DC00<04a<0:a<405<C0P0i4`00<Q<00`0C4`0h4`033A<C0?hC00<04a<02a<204LC

00<04a<09a<405HC00<04a<0>1<0038C00<04a<0=Q<23OlC0Q<00`0C4`0;4`0301<C04HC00<04a<0

8a<505PC0P0j4`00<Q<00`0C4`0d4`8=oa<54`802a<00`0C4`164`0301<C020C101K4`80>a<0038C

00<04a<0<Q<23OlC2A<00`0C4`084`0301<C04LC00<04a<06a<405lC00<04a<0>Q<0038C00<04a<0

<1<23OlC31<00`0C4`074`0301<C04LC0P0H4`D0HA<00`0C4`0k4`00<Q<00`0C4`0^4`8=oa<>4`03

01<C00LC00<04a<0B1<00`0C4`0C4`@0I1<203dC000b4`0301<C02`C0Pgo4a4C00<04a<01Q<204XC

00<04a<03Q<406LC0P0n4`00<Q<00`0C4`0Z4`8=oa<D4`801Q<00`0C4`194`0301<C00XC101Z4`80

?a<0038C00<04a<0:1<23OlC61<00`0C4`034`0301<C04XC00<04a<01A<506`C0P104`00<Q<00`0C

4`0V4`8=oa<K4`800a<00`0C4`1:4`8000<C00000`1`4`80@A<0038C00<04a<08a<33OlC5A<5008C

00@04a<00Q<00`0C4`194`D0La<2048C000L4`0301<C008C00<04a<00Q<00`0C4`024`0301<C00@C

00<04a<081<33OlC6Q<01`0C4a<04`000Q<304LC1@024`0301<C074C0P134`006a<00`0C00084`07

01<C4`0C00054`0301<C01`C10go4adC00L04a<C01<000@C0`104`D021<00`0C4`1^4`80AA<001/C

00<04`0021<00`0C4`034`0301<C00<C0P0I4`@=oa<Q4`0701<C4`0C00044`0401<003XC1@0=4`03

01<C06dC0P164`006a<00`0C00094`0301<C00801Q<00`0C4`0C4`D=oa<U4`0701<C4`0C00044`04

01<C4`<0<A<601<C0P1[4`<0Aa<001/C00<04`001a<00`0C00024`0301<C00DC00<04a<03Q<53OlC

:A<200@C00<04a<00a<00`0C4`044`<0:1<701TC0P1Y4`80BA<001`C00<04a<01Q<3008C0`054`03

01<C00HC20go4cXC00<04a<01a<501/C2@0P4`0301<C06@C0`1;4`00<Q<93OlC@Q<00`0C4`0<4a`0

:A<2068C0`1=4`00<Q<00`0C4`3o4dPC0P1C4`80Ga<304lC000b4`0301<C0?lCB1<00`0C4`1C4`80

FQ<4058C000b4`0301<C0?lCB1<00`0C4`1D4`80EQ<405DC000b4`0301<C0?lCB1<00`0C4`1F4`80

Ca<505TC000b4`0301<C0?lCB1<00`0C4`1G4`<0B1<605dC000b4`0301<C0?lCB1<00`0C4`1I4`<0

@1<7068C000b4`0301<C0?lCB1<205`C0`0h4`L0J1<0038C00<04a<0oa=84`0301<C05hC0`0^4`P0

KQ<0038C00<04a<0oa=84`0301<C060C1@0S4`P0MA<0038C00<04a<0oa=84`0301<C06@C1`0D4`X0

O1<0038C00<04a<0oa=84`0301<C06XC5@264`00<Q<00`0C4`3o4dPC00<04a<0oa<64`00:A<500@C

00<04a<0oa=84`80oa<74`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`3o4`HC000[4`0301<C00@C

0P3o4dTC00<04a<0oa<64`00:a<00`0C4`3o4olCF1<002/C00<04a<0oa?o4ePC000Z4`80oa?o4eXC

003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00LA<400034`0000L00Q<00`0C

4`024`0301<C008C00<04a<00Q<0100C4a<200<C0P034`800a<200<C0P034`800a<200<C0P034`80

0a<200<C0P034`800Q<:0?lC[1<0074C0`084`0301<C008C00<04a<01Q<00`0C00034`0301<C00<C

00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C

4`024`0301<C008C00<04a<00Q<00`0C4`024`0501<C4`0011<00`0C4`2Q4`80oa<94`00La<00`0C

4`04008C00<04a<00Q<00`0C4`084`0501<C4`0011<200<C0P034`800a<200<C0P034`800a<200<C

0P034`800a<200<C0P034`800a<00`0C4`024`0301<C0:8C00<04a<0oa<74`006A<400034`0000H0

0Q<:008C0P024`<00Q<300<C0P001Q<0000C02LC0P084`0301<C00<C00<04a<01A<200DC00H04a<0

4`024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C

00<04`000Q<00`0C00024`0301<0008C00<04`000a<00`0C4`024`0301<C0:0C0`024`0301<C0?lC

11<001XC00H04a<04`024`0301<000@C00H04a<04`024`0301<000DC00<04a<00Q<01@0C4a<0008C

00@04`0C0P0a4`0701<C4`0C00074`0301<C008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`03

01<0008C00<04`000a<00`0C4`024`0301<C00<C00<04a<0VA<0200C4`0C01<0oa<54`006Q<01P0C

4`0C00@C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00a<00`0C4`024`0501<C4`000Q<0100C

01<2030C0P034`<01a<3008C0`034`800a<200<C0P034`800a<200<C0P034`800a<200<C0P034`80

0a<200<C0P024`800a<200@C00<04a<0VQ<0200C4`0C01<0oa<54`006Q<01@0C4`0C00800a<200<C

00<04a<00Q<200<C00<04a<00a<00`0C4`024`0501<C4`000Q<01P0C000C0?lC;a<300044`0C0?lC

1A<001XC00H04a<04`024`0301<0008C00<04`0011<03P0C4`0C01<04`0C01<00Q<01@0C4a<0008C

00H04`004`3o4c<C00<04`00oa<54`006A<400034`0000/00Q<500054`0001<01@0011<000034`80

00@C000C0P3o4c@C00<04a<0oa<44`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olC

QQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.77084, -14.119, 0.0242408, 0.16996}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -57 0 ]

[.5 .63053 57 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -118 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(16.7199999999999926`) show

173.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .51356 m

.02499 .51355 L

.02606 .51355 L

.02729 .51354 L

.02846 .51353 L

.03053 .51349 L

.03279 .51344 L

.03527 .51337 L

.0379 .51328 L

.04262 .51306 L

.04749 .51278 L

.05205 .51245 L

.06245 .51148 L

.07305 .51018 L

.08274 .50871 L

.10458 .50441 L

.12357 .49956 L

.14429 .49306 L

.18493 .47671 L

.22406 .45677 L

.26565 .4321 L

.30571 .40689 L

.34426 .38386 L

.36381 .37356 L

.38527 .36386 L

.40569 .35649 L

.42475 .35144 L

.43521 .34944 L

.44035 .34865 L

.44511 .34804 L

.44933 .34758 L

.45399 .34718 L

.45868 .34687 L

.46125 .34674 L

.46366 .34665 L

.46484 .34661 L

.4661 .34658 L

.46718 .34656 L

.46836 .34654 L

.46908 .34653 L

.46974 .34652 L

.47105 .34651 L

.47224 .34651 L

.47349 .34651 L

.47472 .34652 L

.47604 .34654 L

.47729 .34656 L

.47842 .34659 L

.4812 .34666 L

.48385 .34676 L

Mistroke

.48844 .34699 L

.4927 .34726 L

.50235 .34804 L

.52291 .35032 L

.54153 .35268 L

.55171 .35393 L

.56244 .35512 L

.57238 .35603 L

.57723 .3564 L

.58165 .35667 L

.58622 .3569 L

.59054 .35706 L

.5917 .35709 L

.59292 .35712 L

.59397 .35714 L

.59511 .35716 L

.59633 .35717 L

.59747 .35718 L

.59813 .35719 L

.59882 .35719 L

.60007 .35719 L

.60133 .35718 L

.60249 .35717 L

.60312 .35716 L

.60381 .35715 L

.60507 .35713 L

.60749 .35706 L

.60971 .35699 L

.61484 .35674 L

.61742 .35657 L

.62025 .35636 L

.63044 .35534 L

.63974 .35405 L

.66065 .34993 L

.67971 .34485 L

.70046 .33823 L

.74121 .32383 L

.76144 .31703 L

.78044 .31145 L

.79859 .30713 L

.80872 .30522 L

.81816 .30379 L

.82772 .30268 L

.83277 .30223 L

.83818 .30185 L

.8409 .3017 L

.84386 .30157 L

.84665 .30147 L

.84798 .30143 L

.84922 .30141 L

Mistroke

.85044 .30138 L

.85154 .30136 L

.85278 .30135 L

.85346 .30134 L

.8541 .30134 L

.85538 .30133 L

.85657 .30133 L

.85788 .30134 L

.85861 .30134 L

.85927 .30135 L

.86047 .30136 L

.8616 .30138 L

.86415 .30143 L

.86664 .3015 L

.8693 .30159 L

.87413 .3018 L

.87853 .30204 L

.89935 .30364 L

.92007 .30562 L

.93922 .30736 L

.94847 .30804 L

.95715 .30854 L

.96151 .30873 L

.9662 .30888 L

.96874 .30894 L

.97013 .30897 L

.97141 .30898 L

.97252 .309 L

.9737 .30901 L

.975 .30901 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.57642 .12027 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4gdC00<04a<0oa<64`00oa=m4`0301<C0?lC1Q<002TC1@3o4dlC0P3o4`LC

000[4`0301<C0?lCCa<00`0C4`1^4`d0RQ<002DC0`034`0301<C00@C0P3o4dTC00<04a<0IQ<800`C

3@1n4`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`1Q4`D081<807LC000[4`0301<C00@C00<04a<0

oa=84`0301<C05hC100/4`L0L1<002XC0P064`0301<C0?lCB1<00`0C4`1L4`<0=A<706XC000b4`03

01<C0?lCB1<205/C0P0o4`H0I1<0038C00<04a<0oa=84`0301<C05PC0P164`H0Ga<0038C00<04a<0

oa=84`0301<C05HC0P1>4`D0FQ<0038C00<04a<0oa=84`0301<C05DC0P1C4`D0EQ<0038C00<04a<0

oa=84`0301<C05@C00<04a<0Ea<5058C000b4`0301<C0?lCB1<205<C0P1N4`<0D1<0038C00<04a<0

oa=84`0301<C00lC5P0/4`80HA<404dC000b4`0301<C0?lCB1<00`0C4`0:4`D05Q<9028C0P1U4`<0

Ba<0038C00<04a<0oa=84`0301<C00DC1@0S4`L06a<206PC0`194`00<Q<00`0C4`3o4c/C1@024`03

01<C00<C00<04a<00a<202lC1P0D4`80Ja<204PC000b4`0301<C0?lC?A<01`0C4a<04`0011<00`0C

4`0303HC1P0>4`80KA<304HC000b4`0301<C0?lC=a<300<C00L04a<C01<000@C0`0n4`H02A<00`0C

4`1^4`80AA<0038C00<04a<0oa<m4`0701<C4`0C00034`80AA<500@C00<04a<0L1<204@C000L4`03

01<C008C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0oa<m4`0701<C4`0C00024`0301<004XC

1@1d4`80@Q<001/C00<04`0021<01`0C4a<04`001A<00`0C4`3o4c`C0P044`0401<0008C00<04a<0

Ba<6074C0P114`005Q<3008C00<04`0021<00`0C4`034`0301<C00<C0P3o4d<C0P044`0301<C04XC

00<04a<011<406hC0P104`006a<00`0C00094`0301<C00801Q<00`0C4`3o4d4C00<04a<011<00`0C

4`194`0301<C00TC101[4`0301<C03hC000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C0?lC

@1<00`0C4`054`80BQ<00`0C4`0=4`@0J1<203hC000L4`0301<C00HC0`024`<01A<00`0C4`3o4clC

00<04a<01Q<00`0C4`184`0301<C018C100<4`033A<C05HC00<04a<0?1<0038C00<04a<0oa<n4`03

01<C00LC00<04a<0B1<00`0C4`0E4`D01A<63ELC00<04a<0>a<0038C00<04a<0oa<m4`0301<C00PC

00<04a<0Aa<00`0C4`0J4`@000<C3@d01`eE4`80?1<0038C00<04a<0oa<l4`0301<C00TC00<04a<0

AQ<00`0C4`0O4`0300d=00L=EQ<203/C000b4`0301<C0?lC>a<00`0C4`0:4`0301<C04HC00<04a<0

81<93ELC00<04a<0>A<0038C00<04a<0oa<j4`0301<C00/C0P174`0301<C01lC2`eG4`0301<C03PC

000b4`0301<C0?lC>A<00`0C4`0<4`0301<C04DC00<04a<08A<93@@0E1<203TC000b4`0301<C0?lC

>A<00`0C4`0<4`0301<C04DC00<04a<08A<93@@C101A4`0301<C03LC000b4`0301<C0?lC>1<00`0C

4`0=4`0301<C04@C00<04a<08Q<93@PC0P1?4`80>1<0038C00<04a<0oa<g4`0301<C00hC00<04a<0

A1<00`0C4`0S4`H=31<404`C0P0g4`00<Q<00`0C4`3o4cHC00<04a<03a<00`0C4`144`0301<C02HC

00<=4a<041<204/C00<04a<0=A<0038C00<04a<0oa<f4`0301<C00lC0P144`0301<C03`C10174`80

=Q<0038C00<04a<0oa<e4`0301<C010C00<04a<0@a<00`0C4`0o4`<0AQ<00`0C4`0d4`00<Q<00`0C

4`3o4cDC00<04a<041<00`0C4`134`0301<C048C0`134`80=A<0024C00<04a<00Q<00`0C4`024`03

01<C00@C00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`164`<0@A<00`0C4`0c4`0081<00`0C

00074`0301<000DC00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`194`80?a<00`0C4`0c4`00

6a<3008C00<04`002A<00`0C4`034`80oa<d4`0301<C018C00<04a<0@Q<00`0C4`1;4`<0?A<00`0C

4`0b4`0081<00`0C00074`801Q<00`0C4`3o4c<C00<04a<04Q<204<C00<04a<0CQ<203/C00<04a<0

<Q<0020C00<04`001a<00`0C4`054`0301<C0?lC<Q<00`0C4`0C4`0301<C044C00<04a<0DA<303PC

00<04a<0<Q<0024C00<04a<01Q<300DC00<04a<0oa<b4`0301<C01<C00<04a<0@A<00`0C4`1D4`80

=a<00`0C4`0a4`00<Q<00`0C4`3o4c4C00<04a<051<00`0C4`114`0301<C05HC0`0d4`0301<C034C

000b4`0301<C0?lC<A<00`0C4`0>4`0301<C00<C00<04a<0@1<00`0C4`1I4`<0<Q<2038C000b4`03

01<C0?lC<1<00`0C4`0>4`0301<000@C00<04a<0@1<00`0C4`1L4`80<A<00`0C4`0`4`00<Q<00`0C

4`3o4c0C00<04a<02A<300@C00<04a<00Q<3040C00<04a<0GQ<202lC00<04a<0<1<0038C00<04a<0

oa<`4`0301<C00hC0P054`0301<C03lC00<04a<0HA<302`C00<04a<0<1<0038C00<04a<0oa<`4`03

01<C00hC00<04a<011<00`0C4`0o4`0301<C06@C00<04a<0:A<00`0C4`0`4`00<Q<00`0C4`3o4blC

00<04a<03a<300@C00<04a<0?a<00`0C4`1U4`<0:1<2034C000b4`0301<C0?lC;a<00`0C4`0F4`03

01<C03lC00<04a<0J1<00`0C4`0V4`0301<C02lC000b4`0301<C0?lC;a<00`0C4`0F4`0301<C03lC

00<04a<0JA<302DC00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC0P104`0301<C06`C0P0S4`03

01<C02lC000b4`0301<C0?lC;a<00`0C4`0F4`0301<C03lC00<04a<0KA<2028C00<04a<0;a<0038C

00<04a<0oa<_4`0301<C01HC00<04a<0?a<00`0C4`1_4`8081<00`0C4`0_4`00<Q<00`0C4`3o4bhC

00<04a<05a<00`0C4`0n4`0301<C078C0P0N4`0301<C02lC000L4`0301<C008C00@04a<C0`034`03

01<C00@C00<04a<0oa<^4`0301<C01LC00<04a<0?Q<00`0C4`1d4`8071<00`0C4`0_4`006a<00`0C

00074`0301<C008C00<04`001A<00`0C4`3o4bhC00<04a<05a<203lC00<04a<0MQ<201XC00<04a<0

;a<001HC0`024`0301<000PC00<04a<00a<00`0C4`034`80oa<_4`0301<C01LC00<04a<0?Q<00`0C

4`1h4`0301<C01HC00<04a<0<1<001/C00<04`0021<0100C4a<200HC00<04a<0oa<]4`0301<C01PC

00<04a<0?Q<00`0C4`1i4`805Q<00`0C4`0`4`006a<00`0C00074`0301<0008C00<04a<01A<00`0C

4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07/C00<04a<04a<00`0C4`0`4`0071<00`0C4`074`04

01<C4`<01A<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07`C00<04a<04Q<00`0C4`0`4`00

<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0m4`0301<C07hC0P0B4`0301<C030C000b4`0301<C0?lC

;A<00`0C4`0H4`80?Q<00`0C4`204`8041<00`0C4`0`4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C

4`0Q4`D00Q<00`0C4`0B4`0301<C00/C1@000a<0000Q4`D00Q<00`0C4`0O4`D00Q<00`0C4`0K4`04

01<C4`D000<C00000a<00`0C4`0a4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0S4`0701<C4`0C

000C4`0301<C00dC00L04a<C01<0028C00<04a<00Q<00`0C4`0Q4`0701<C4`0C000L4`8011<00`0C

4`034`0401<C03<C000b4`0301<C02HC00<04a<00Q<0100C4a<302<C00<04a<00Q<00`0C4`024`<0

8Q<00`0C4`024`0401<C4`8091<00`0C4`024`0301<C008C00<04a<09Q<5044C00<04a<061<00`0C

4`0S4`0301<C00<C00<04a<04A<00`0C4`0=4`0701<C4`0C000R4`0301<C008C00<04a<08A<01`0C

4a<04`007Q<01@0C4a<000@C0P024`0301<C034C000b4`0301<C02DC00<04`001a<00`0C4`0R4`03

01<000TC00<04a<081<00`0C00074`0301<0028C00<04`001a<00`0C000Y4`0301<C044C00<04a<0

61<00`0C4`0S4`0401<C4`8051<00`0C4`0=4`0401<C4`808a<00`0C4`034`0301<C020C00<04a<0

0Q<00`0C4`0N4`8000<C01<00Q<00`0C00024`0301<C034C000b4`0301<C02DC00<04`0021<00`0C

4`0Q4`0301<000LC100Q4`0301<000LC00<04`008Q<00`0C00074`0301<002TC00<04a<0@1<00`0C

4`0I4`0301<C02<C00D04a<C000E4`0301<C00dC00D04a<C000T4`0701<C4`0C000R4`0701<C4`0C

000Q4`800a<01@0C01<003@C000b4`0301<C02DC00<04`0021<00`0C4`0Q4`0301<000LC00<04`00

8Q<00`0C00074`808a<00`0C00084`0301<C02PC00<04a<0@1<00`0C4`0I4`808a<200<C0`0C4`03

01<C00`C0P044`808A<200<C0`0Q4`8011<00`0C4`0P4`8011<200034`0C03<C000b4`0301<C02DC

00<04`001a<00`0C000R4`0301<000PC0P0R4`0301<000LC00<04a<08Q<00`0C00074`0301<002TC

00<04a<0@1<00`0C4`0I4`0301<C03dC00<04a<0R1<00`0C4`054`0301<C038C000b4`0301<C02HC

00<04a<01a<00`0C4`0R4`0301<C00PC00<04a<08A<00`0C4`074`808a<00`0C4`074`0301<C02LC

0P124`0301<C01TC00<04a<0?A<00`0C4`294`801A<00`0C4`0b4`00<Q<00`0C4`3o4b`C00<04a<0

6A<00`0C4`0m4`0301<C08/C00D04a<C000e4`00<Q<00`0C4`3o4b`C00<04a<06A<00`0C4`0m4`03

01<C08/C00@04a<04a<401lC000b4`0301<C0?lC;1<00`0C4`0I4`0301<C03dC00<04a<0S1<201@C

0`0P4`00<Q<00`0C4`3g4`<0:a?o00XC00<04a<07Q<0038C00<04a<0`A<G3B0C00<04a<0:a<00`0C

4`024`0401<C00PC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC

00<04a<01A<00`0C4`064`0301<C00DC00<04a<00a<00`0C00074`0301<C00HC00<04a<01A<00`0C

4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC

00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC0`064`0301<C00`C

0P0P4`00;1?400H=5`0A3@H02A<00`0C4`0`4`0301<C01TC00<04a<09Q<00`0C4`0D4`0301<C010C

00<04a<09Q<00`0C4`0V4`0301<C02HC00@04a<0=Q<0038C00<04a<021<00`0C4`094`0301<C00TC

00<04a<02A<00`0C4`084`0301<C00TC00<04a<02A<00`0C4`094`0301<C00PC00<04a<02A<00`0C

4`094`0301<C00TC00<04a<02A<00`0C4`084`0301<C00TC00<04a<01Q<53@XC00<04a<021<00`0C

4`094`0301<C00TC00<04a<031<4030C00<04a<06A<00`0C4`0m4`0301<C08/C00D04a<C000e4`00

<Q<00`0C4`0/4`0301<C02`C00<04a<0;1<00`0C4`0U4`@=0a<00`0C4`0/4`0301<C040C00<04a<0

6A<00`0C4`0m4`0301<C08XC00<04a<00Q<00`0C4`0c4`00<Q<00`0C4`2`4`8=NA<00`0C4`0I4`03

01<C03dC00<04a<0RA<00`0C4`044`0301<C038C000b4`0301<C0:dC0`ek4`0301<C01TC0P0n4`03

01<C08LC0P074`0301<C038C000b4`0301<C0:/C0Pen4`0301<C01TC00<04a<0?A<00`0C4`274`03

01<C00HC00<04a<0<Q<0038C00<04a<0Z1<33H4C00<04a<061<00`0C4`0m4`0301<C08HC00<04a<0

21<00`0C4`0a4`00<Q<00`0C4`2V4`8=Q1<00`0C4`0H4`0301<C03dC00<04a<0Q1<200/C00<04a<0

<A<0038C00<04a<0XQ<43HHC00<04a<061<00`0C4`0m4`0301<C08<C00<04a<02a<00`0C4`0a4`00

<Q<00`0C4`2N4`@=RQ<00`0C4`0H4`0301<C03dC00<04a<0PQ<00`0C4`0<4`0301<C034C000b4`03

01<C068C50dV4`8=SQ<00`0C4`0H4`80?Q<00`0C4`204`803a<00`0C4`0a4`00<Q<00`0C4`1N4`@=

51<83AXC10f@4`0301<C01PC00<04a<0?A<00`0C4`1o4`0301<C010C00<04a<0<1<0038C00<04a<0

FQ<43B0C6PfD4`0301<C01PC00<04a<0?Q<00`0C4`1l4`804a<00`0C4`0`4`00<Q<00`0C4`1H4`8=

dQ<00`0C4`0H4`0301<C03hC00<04a<0Na<201@C00<04a<0<1<0038C00<04a<0EA<33M@C00<04a<0

61<00`0C4`0n4`0301<C07TC0P0F4`0301<C030C000b4`0301<C05<C0PgG4`0301<C01PC00<04a<0

?Q<00`0C4`1h4`0301<C01HC00<04a<0<1<0038C00<04a<0DA<23MXC00<04a<05a<203lC00<04a<0

MQ<201TC00<04a<0<1<0038C00<04a<0Ca<23M`C00<04a<05a<00`0C4`0n4`0301<C07@C0P0L4`03

01<C02lC000L4`0301<C008C00@04a<C0`034`0301<C00@C00<04a<0CA<23MhC00<04a<05a<00`0C

4`0n4`0301<C07<C00<04a<071<00`0C4`0_4`006a<00`0C00074`0301<C008C00<04`001A<00`0C

4`1<4`033A<C0=hC00<04a<05a<00`0C4`0o4`0301<C070C0P0O4`0301<C02lC000K4`0301<000PC

00<04a<00a<00`0C4`034`80Ba<23N8C00<04a<05Q<00`0C4`0o4`0301<C06dC0`0Q4`0301<C02lC

000K4`0301<000PC00@04a<C0P064`0301<C04PC0PgT4`0301<C01HC00<04a<0?a<00`0C4`1/4`80

8a<00`0C4`0_4`006a<00`0C00074`0301<0008C00<04a<01A<00`0C4`174`033A<C0>@C00<04a<0

5Q<2040C00<04a<0JQ<202DC00<04a<0;a<001`C00<04a<01a<0100C4a<300DC00<04a<0AA<23NLC

00<04a<05Q<00`0C4`0o4`0301<C06PC0P0W4`0301<C02lC000b4`0301<C04<C0PgY4`0301<C01HC

00<04a<0?a<00`0C4`1V4`80:A<00`0C4`0_4`00<Q<00`0C4`124`033A<C0>XC00<04a<05A<00`0C

4`0o4`0301<C06@C0P0Z4`0301<C030C000b4`0301<C040C0Pg]4`0301<C00lC00<04a<00a<00`0C

4`0o4`0301<C068C0P0/4`0301<C030C000b4`0301<C03hC0Pg_4`0301<C00hC00<04`0011<00`0C

4`104`0301<C05hC0`0^4`0301<C030C000b4`0301<C03dC00<=4a<0ka<00`0C4`0@4`0301<C008C

0`104`0301<C05`C0`0`4`0301<C030C000b4`0301<C03/C0Pgc4`0301<C00dC0P054`0301<C040C

00<04a<0FQ<2038C0P0b4`00<Q<00`0C4`0i4`8=mA<00`0C4`0=4`0301<C00@C00<04a<0@A<00`0C

4`1G4`80=1<00`0C4`0a4`00<Q<00`0C4`0h4`033A<C0?HC00<04a<031<300@C00<04a<0@A<00`0C

4`1D4`<0=Q<00`0C4`0a4`00<Q<00`0C4`0f4`8=nA<00`0C4`0C4`0301<C044C00<04a<0DQ<303LC

0P0c4`00<Q<00`0C4`0d4`8=o1<00`0C4`0B4`80@Q<00`0C4`1?4`<0>Q<00`0C4`0b4`00<Q<00`0C

4`0c4`033A<C0?`C00<04a<04Q<00`0C4`124`0301<C04`C0`0l4`0301<C038C000b4`0301<C034C

0Pgo4`4C00<04a<04A<00`0C4`124`0301<C04TC0`0n4`0301<C03<C000b4`0301<C02lC0Pgo4`<C

00<04a<04A<00`0C4`124`0301<C04LC0`104`0301<C03<C000Q4`0301<C008C00<04a<00Q<00`0C

4`044`0301<C02hC00<=4a<0oa<44`0301<C010C00<04a<0@Q<00`0C4`144`<0@Q<203DC000P4`03

01<000LC00<04`001A<00`0C4`0/4`8=oa<74`0301<C010C00<04a<0@a<00`0C4`104`<0AA<00`0C

4`0d4`0081<00`0C00094`0301<C00<C0P0[4`8=oa<:4`0301<C00lC0P144`0301<C03dC0`174`80

=Q<0020C00<04`001a<200HC00<04a<0:1<23OlC31<00`0C4`0?4`0301<C04@C00<04a<0>A<304XC

00<04a<0=A<0020C00<04`001a<00`0C4`054`0301<C02HC0Pgo4`lC00<04a<03Q<00`0C4`144`03

01<C03HC101;4`80=a<0024C00<04a<01Q<300DC00<04a<08a<33OlC4Q<00`0C4`0=4`0301<C04@C

00<04a<0<a<304lC00<04a<0=Q<0038C00<04a<08A<23OlC5Q<00`0C4`0<4`0301<C04DC00<04a<0

;a<3054C00<04a<0=a<0038C00<04a<07Q<33OlC61<00`0C4`0<4`0301<C04DC00<04a<0:a<405<C

0P0i4`00<Q<00`0C4`0L4`8=oa<L4`0301<C00/C0P174`0301<C02LC101F4`0301<C03PC000b4`03

01<C01TC0`go4ahC00<04a<02a<00`0C4`164`0301<C02<C1@1H4`80>Q<0038C00<04a<05a<23OlC

8Q<200/C00<04a<0AQ<00`0C4`0P4`@0Fa<203/C000b4`0301<C01<C10go4bHC00<04a<021<00`0C

4`174`0301<C01/C101O4`0301<C03XC000b4`0301<C00hC1@go4b/C00<04a<01a<00`0C4`174`80

61<5064C00<04a<0>a<0038C00<04a<021<63OlC<1<00`0C4`074`0301<C04PC00<04a<04a<406@C

0P0m4`00<Q<;3OlC=a<00`0C4`064`80BQ<00`0C4`0>4`@0Ia<203hC000b4`0301<C0?lC@1<200HC

00<04a<0BA<00`0C4`0:4`@0JQ<203lC000b4`0301<C0?lC@Q<00`0C4`034`0301<C04XC00<04a<0

1A<506`C0P104`00<Q<00`0C4`3o4d<C0P034`0301<C04XC0P000a<00003070C0P114`00<Q<00`0C

4`3o4c/C1@024`0401<C008C00<04a<0BA<507<C0P124`0071<00`0C4`024`0301<C008C00<04a<0

0Q<00`0C4`044`0301<C0?lC?A<01`0C4a<04`000Q<304LC1@024`0301<C074C0P134`006a<00`0C

00084`0701<C4`0C00054`0301<C0?lC?A<01`0C4a<04`0011<3040C1@084`0301<C06hC0P154`00

6a<00`0C00084`0301<C00<C00<04a<00a<20?lC?Q<01`0C4a<04`0011<0100C000j4`D03A<00`0C

4`1]4`80AQ<001/C00<04`002A<00`0C4`0200HC00<04a<0oa<m4`0701<C4`0C00044`0401<C4`<0

<A<601<C0P1[4`<0Aa<001/C00<04`001a<00`0C00024`0301<C00DC00<04a<0oa<l4`8011<00`0C

4`034`0301<C00@C0`0X4`L06A<206TC0P194`0071<00`0C4`064`<00Q<300DC00<04a<0oa=84`03

01<C00LC1@0K4`T081<00`0C4`1T4`<0Ba<0038C00<04a<0oa=84`0301<C00`C700Y4`80HQ<304dC

000b4`0301<C0?lCB1<205<C0P1O4`<0Ca<0038C00<04a<0oa=84`0301<C05<C0P1J4`@0DQ<0038C

00<04a<0oa=84`0301<C05@C0P1F4`@0EA<0038C00<04a<0oa=84`0301<C05HC0P1?4`D0FA<0038C

00<04a<0oa=84`0301<C05LC0`184`H0GA<0038C00<04a<0oa=84`0301<C05TC0`104`L0HQ<0038C

00<04a<0oa=84`80G1<303PC1`1X4`00<Q<00`0C4`3o4dPC00<04a<0GQ<302hC201^4`00<Q<00`0C

4`3o4dPC00<04a<0H1<502<C201e4`00<Q<00`0C4`3o4dPC00<04a<0I1<701@C2P1l4`00<Q<00`0C

4`3o4dPC00<04a<0JQ<E08HC000b4`0301<C0?lCB1<00`0C4`3o4`HC000Y4`D011<00`0C4`3o4dPC

0P3o4`LC000[4`0301<C00@C00<04a<0oa=84`0301<C0?lC1Q<002/C00<04a<011<20?lCBA<00`0C

4`3o4`HC000[4`0301<C0?lCoa=H4`00:a<00`0C4`3o4olCF1<002XC0P3o4olCFQ<00?lCoa>64`00

oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC001a4`@000<C00001`000a<000044`0301<C008C

00<04a<01@000a<000034`800a<200<C0P034`800a<200<C0P034`800a<200<C0P034`800a<200<C

0`024`80oa>^4`00LA<300PC00L04a<C01<000PC00<04a<00Q<00`0C4`034`0301<C008C00<04a<0

0Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`03

01<C008C00<04a<00Q<0100C4`044`0301<00:8C0P3o4`TC001c4`0301<C00@00Q<01`0C4a<04`00

21<00`0C4`024`0301<C008C0P034`800a<200<C0P034`800a<200<C0P034`800a<200<C0P034`80

0a<200<C00L04a<C01<00:<C00<04a<0oa<74`006A<400034`0000H00Q<:008C0P024`<00Q<300<C

0P001Q<0000C02LC0P084`0401<C4`802Q<01@0C4a<000<C00<04`000Q<00`0C00024`0301<0008C

00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C

00024`0301<000<C00@04a<C0P2R4`<00Q<00`0C4`3o4`@C000J4`0601<C01<00Q<00`0C00044`06

01<C01<00Q<00`0C00054`0301<C008C00D04a<C00024`0401<04`80<A<01@0C4a<000TC00<04`00

0a<01`0C4a<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C4`044`03

01<C09TC00P04a<04`0C0?lC1A<001XC00H04a<04`044`0301<C008C00<04a<00Q<00`0C4`024`03

01<C00<C00<04a<00Q<01@0C4a<0008C00@04`0C0P0`4`8011<200LC0`024`8011<200<C0P034`80

0a<200<C0P034`800a<200<C0P034`800a<200<C0P034`800a<00`0C4`024`800a<00`0C4`2J4`08

01<C01<04`3o4`DC000J4`0501<C01<00P034`800a<00`0C4`024`800a<00`0C4`034`0301<C008C

00D04a<C00024`0601<001<0oa<_4`<000@C01<0oa<54`006Q<01P0C4`0C008C00<04`000Q<00`0C

00044`0>01<C01<04`0C01<04`024`0501<C4`000Q<01P0C000C0?lC<a<00`0C003o4`DC000I4`@0

00<C00002`024`D000DC00004`0500044`0000<C0P0011<001<20?lC=1<00`0C4`3o4`@C003o4olC

QQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00

oa?o4hHC0000\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.77084, -14.119, 0.0242408, 0.16996}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -54.5 0 ]

[.5 .63053 54.5 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -115.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(16.160000000000001`) show

168.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .49154 m

.02499 .49154 L

.02606 .49153 L

.02729 .49152 L

.02846 .49151 L

.03053 .49147 L

.03279 .49141 L

.03527 .49134 L

.0379 .49123 L

.04262 .49099 L

.04749 .49066 L

.05205 .49029 L

.06245 .4892 L

.07305 .48774 L

.08274 .48609 L

.10458 .48131 L

.12357 .47594 L

.14429 .46882 L

.18493 .45128 L

.22406 .4306 L

.26565 .40618 L

.30571 .38272 L

.34426 .36298 L

.36381 .35487 L

.37417 .35122 L

.38527 .34784 L

.39595 .34514 L

.40569 .34315 L

.41548 .34161 L

.42475 .34056 L

.42934 .34019 L

.43441 .33988 L

.43695 .33977 L

.43829 .33973 L

.4397 .33969 L

.44093 .33966 L

.44229 .33963 L

.44352 .33962 L

.44466 .33961 L

.44582 .3396 L

.44706 .3396 L

.44824 .33961 L

.44933 .33962 L

.45031 .33963 L

.45139 .33965 L

.45357 .3397 L

.45594 .33977 L

.45848 .33988 L

.46308 .34011 L

.46834 .34047 L

Mistroke

.47321 .34087 L

.48426 .34199 L

.50436 .34459 L

.52319 .34729 L

.54354 .35 L

.55472 .35121 L

.55962 .35166 L

.56499 .35208 L

.56974 .35238 L

.57481 .35264 L

.57762 .35274 L

.58018 .35281 L

.58141 .35284 L

.58275 .35286 L

.58401 .35288 L

.58518 .35289 L

.58636 .3529 L

.5876 .3529 L

.58866 .35289 L

.58982 .35289 L

.59108 .35287 L

.59242 .35285 L

.59483 .35279 L

.59727 .35272 L

.59957 .35262 L

.60388 .35239 L

.60903 .35202 L

.61378 .3516 L

.6245 .35031 L

.63421 .34878 L

.6433 .34703 L

.66395 .34207 L

.70283 .33004 L

.74416 .3164 L

.76483 .31045 L

.78397 .30596 L

.80253 .30274 L

.81191 .30157 L

.81695 .30107 L

.82227 .30064 L

.82708 .30034 L

.82962 .30021 L

.83234 .3001 L

.83485 .30002 L

.83713 .29996 L

.83823 .29994 L

.83942 .29992 L

.84055 .2999 L

.84159 .29989 L

.84279 .29989 L

Mistroke

.84408 .29988 L

.84529 .29989 L

.84641 .29989 L

.84771 .2999 L

.84844 .29991 L

.84913 .29992 L

.85171 .29997 L

.85444 .30004 L

.8569 .30012 L

.86244 .30036 L

.87247 .30097 L

.8817 .3017 L

.90252 .30373 L

.92296 .30587 L

.93294 .30682 L

.94203 .30759 L

.94993 .30815 L

.95852 .30861 L

.96324 .30879 L

.96531 .30886 L

.9676 .30892 L

.96975 .30896 L

.97176 .30899 L

.97288 .309 L

.9739 .30901 L

.97501 .30901 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.48556 .09599 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4gdC00<04a<0oa<64`00oa=m4`0301<C0?lC1Q<002TC1@3o4dlC0P3o4`LC

000[4`0301<C0?lCCa<00`0C4`1^4`d0RQ<002DC0`034`0301<C00@C0P3o4dTC00<04a<0IQ<800`C

3@1n4`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`1Q4`D081<807LC000[4`0301<C00@C00<04a<0

oa=84`0301<C05hC100/4`L0L1<002XC0P064`0301<C0?lCB1<00`0C4`1L4`<0=A<706XC000b4`03

01<C0?lCB1<205/C0P0o4`H0I1<0038C00<04a<0oa=84`0301<C05PC0P164`H0Ga<0038C00<04a<0

oa=84`0301<C05HC0P1>4`D0FQ<0038C00<04a<0oa=84`0301<C05DC0P1C4`D0EQ<0038C00<04a<0

oa=84`0301<C05@C00<04a<0Ea<5058C000b4`0301<C0?lCB1<205<C0P1N4`<0D1<0038C00<04a<0

oa=84`0301<C00lC5P0/4`80HA<404dC000b4`0301<C0?lCB1<00`0C4`0:4`D05Q<9028C0P1U4`<0

Ba<0038C00<04a<0oa=84`0301<C00DC1@0S4`L06a<206PC0`194`00<Q<00`0C4`3o4c/C1@024`03

01<C00<C00<04a<00a<202lC1P0D4`80Ja<204PC000b4`0301<C0?lC?A<01`0C4a<04`0011<00`0C

4`0303HC1P0>4`80KA<304HC000b4`0301<C0?lC=a<300<C00L04a<C01<000@C0`0n4`H02A<00`0C

4`1^4`80AA<0038C00<04a<0oa<m4`0701<C4`0C00034`80AA<500@C00<04a<01a<00`dC4`1V4`80

A1<001`C00<04a<00Q<00`0C4`024`0301<C008C00<04a<011<00`0C4`3o4cdC00L04a<C01<0008C

00<04`00BQ<500HC1PeX4`80@Q<001/C00<04`0021<01`0C4a<04`001A<00`0C4`3o4c`C0P044`04

01<0008C00<04a<0Ba<600034`d=00L=Ia<2044C000F4`<00Q<00`0C00084`0301<C00<C00<04a<0

0a<20?lC@a<200@C00<04a<0BQ<00`0C4`044`0300d=00L=J1<2040C000K4`0301<000TC00<04a<0

0P064`0301<C0?lC@A<00`0C4`044`0301<C04TC00<04a<01Q<93FTC00<04a<0?Q<001/C00<04`00

1a<00`0C00024`0301<C00DC00<04a<0oa=04`0301<C00DC0P1:4`0301<C00DC2`d00`0C4`1V4`80

?Q<001`C00<04a<01Q<3008C0`054`0301<C0?lC?a<00`0C4`064`0301<C04PC00<04a<01a<93@8C

101U4`0301<C03`C000b4`0301<C0?lC?Q<00`0C4`074`0301<C04PC00<04a<01a<93@DC1@1R4`03

01<C03/C000b4`0301<C0?lC?A<00`0C4`084`0301<C04LC00<04a<021<93@TC101O4`80?1<0038C

00<04a<0oa<l4`0301<C00TC00<04a<0AQ<00`0C4`0:4`H=3a<405`C0P0k4`00<Q<00`0C4`3o4c/C

00<04a<02Q<00`0C4`164`0301<C00dC00<=4a<04Q<505TC00<04a<0>A<0038C00<04a<0oa<j4`03

01<C00/C0P174`0301<C02HC101G4`0301<C03PC000b4`0301<C0?lC>A<00`0C4`0<4`0301<C04DC

00<04a<0:Q<405@C0P0i4`00<Q<00`0C4`3o4cTC00<04a<031<00`0C4`154`0301<C02hC101A4`03

01<C03LC000b4`0301<C0?lC>1<00`0C4`0=4`0301<C04@C00<04a<0<a<204lC0P0h4`00<Q<00`0C

4`3o4cLC00<04a<03Q<00`0C4`144`0301<C03DC101<4`80=a<0038C00<04a<0oa<f4`0301<C00lC

00<04a<0A1<00`0C4`0i4`80Ba<00`0C4`0e4`00<Q<00`0C4`3o4cHC00<04a<03a<204@C00<04a<0

?1<404LC0P0f4`00<Q<00`0C4`3o4cDC00<04a<041<00`0C4`134`0301<C03lC0`164`0301<C03@C

000b4`0301<C0?lC=A<00`0C4`0@4`0301<C04<C00<04a<0@Q<304<C0P0e4`008A<00`0C4`024`03

01<C008C00<04a<011<00`0C4`3o4c@C00<04a<04A<00`0C4`124`0301<C04HC0`114`0301<C03<C

000P4`0301<000LC00<04`001A<00`0C4`3o4c@C00<04a<04A<00`0C4`124`0301<C04TC0P0o4`03

01<C03<C000K4`<00Q<00`0C00094`0301<C00<C0P3o4c@C00<04a<04Q<00`0C4`124`0301<C04/C

0`0m4`0301<C038C000P4`0301<000LC0P064`0301<C0?lC<a<00`0C4`0B4`80@a<00`0C4`1>4`80

>a<00`0C4`0b4`0081<00`0C00074`0301<C00DC00<04a<0oa<b4`0301<C01<C00<04a<0@A<00`0C

4`1A4`<0>1<00`0C4`0b4`008A<00`0C4`064`<01A<00`0C4`3o4c8C00<04a<04a<00`0C4`114`03

01<C05@C0P0g4`0301<C034C000b4`0301<C0?lC<A<00`0C4`0D4`0301<C044C00<04a<0EQ<303@C

00<04a<0<A<0038C00<04a<0oa<a4`0301<C00hC00<04a<00a<00`0C4`104`0301<C05TC0`0b4`80

<Q<0038C00<04a<0oa<`4`0301<C00hC00<04`0011<00`0C4`104`0301<C05`C0P0a4`0301<C030C

000b4`0301<C0?lC<1<00`0C4`094`<011<00`0C4`024`<0@1<00`0C4`1N4`80;a<00`0C4`0`4`00

<Q<00`0C4`3o4c0C00<04a<03Q<200DC00<04a<0?a<00`0C4`1Q4`<0;1<00`0C4`0`4`00<Q<00`0C

4`3o4c0C00<04a<03Q<00`0C4`044`0301<C03lC00<04a<0I1<00`0C4`0Y4`0301<C030C000b4`03

01<C0?lC;a<00`0C4`0?4`<011<00`0C4`0o4`0301<C06DC0`0X4`80<A<0038C00<04a<0oa<_4`03

01<C01HC00<04a<0?a<00`0C4`1X4`0301<C02HC00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC

00<04a<0?a<00`0C4`1Y4`<09A<00`0C4`0_4`00<Q<00`0C4`3o4blC00<04a<05Q<2040C00<04a<0

K1<202<C00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC00<04a<0?a<00`0C4`1]4`808Q<00`0C

4`0_4`00<Q<00`0C4`3o4blC00<04a<05Q<00`0C4`0o4`0301<C06lC0P0P4`0301<C02lC000b4`03

01<C0?lC;Q<00`0C4`0G4`0301<C03hC00<04a<0LQ<201hC00<04a<0;a<001`C00<04a<00Q<0100C

4a<300<C00<04a<011<00`0C4`3o4bhC00<04a<05a<00`0C4`0n4`0301<C07@C0P0L4`0301<C02lC

000K4`0301<000LC00<04a<00Q<00`0C00054`0301<C0?lC;Q<00`0C4`0G4`80?a<00`0C4`1f4`80

6Q<00`0C4`0_4`005Q<3008C00<04`0021<00`0C4`034`0301<C00<C0P3o4blC00<04a<05a<00`0C

4`0n4`0301<C07PC00<04a<05Q<00`0C4`0`4`006a<00`0C00084`0401<C4`801Q<00`0C4`3o4bdC

00<04a<061<00`0C4`0n4`0301<C07TC0P0F4`0301<C030C000K4`0301<000LC00<04`000Q<00`0C

4`054`0301<C0?lC;A<00`0C4`0H4`0301<C03hC00<04a<0Na<00`0C4`0C4`0301<C030C000L4`03

01<C00LC00@04a<C0`054`0301<C0?lC;A<00`0C4`0H4`0301<C03hC00<04a<0O1<00`0C4`0B4`03

01<C030C000b4`0301<C0?lC;A<00`0C4`0H4`0301<C03dC00<04a<0OQ<2018C00<04a<0<1<0038C

00<04a<0oa<]4`0301<C01PC0P0n4`0301<C080C0P0@4`0301<C030C000b4`0301<C0?lC;A<00`0C

4`0H4`0301<C024C1@024`0301<C018C00<04a<02a<500034`00024C1@024`0301<C01lC1@024`03

01<C01/C00@04a<C1@000a<000034`0301<C034C000b4`0301<C0?lC;A<00`0C4`0H4`0301<C02<C

00L04a<C01<001<C00<04a<03A<01`0C4a<04`008Q<00`0C4`024`0301<C024C00L04a<C01<001`C

0P044`0301<C00<C00@04a<0<a<0038C00<04a<09Q<00`0C4`024`0401<C4`<08a<00`0C4`024`03

01<C008C0`0R4`0301<C008C00@04a<C0P0T4`0301<C008C00<04a<00Q<00`0C4`0V4`D0@A<00`0C

4`0H4`0301<C02<C00<04a<00a<00`0C4`0A4`0301<C00dC00L04a<C01<0028C00<04a<00Q<00`0C

4`0Q4`0701<C4`0C000N4`0501<C4`0011<2008C00<04a<0<A<0038C00<04a<09A<00`0C00074`03

01<C028C00<04`002A<00`0C4`0P4`0301<000LC00<04`008Q<00`0C00074`0301<002TC00<04a<0

@A<00`0C4`0H4`0301<C02<C00@04a<C0P0D4`0301<C00dC00@04a<C0P0S4`0301<C00<C00<04a<0

81<00`0C4`024`0301<C01hC0P000a<04`024`0301<0008C00<04a<0<A<0038C00<04a<09A<00`0C

00084`0301<C024C00<04`001a<4024C00<04`001a<00`0C000R4`0301<000LC00<04`00:A<00`0C

4`104`0301<C01TC00<04a<08a<01@0C4a<001DC00<04a<03A<01@0C4a<002@C00L04a<C01<0028C

00L04a<C01<0024C0P034`0501<04`00=1<0038C00<04a<09A<00`0C00084`0301<C024C00<04`00

1a<00`0C000R4`0301<000LC0P0S4`0301<000PC00<04a<0:1<00`0C4`104`0301<C01TC0P0S4`80

0a<301<C00<04a<031<200@C0P0Q4`800a<3024C0P044`0301<C020C0P044`8000<C01<0<a<0038C

00<04a<09A<00`0C00074`0301<0028C00<04`0021<2028C00<04`001a<00`0C4`0R4`0301<000LC

00<04`00:A<00`0C4`104`0301<C01TC00<04a<0?A<00`0C4`284`0301<C00DC00<04a<0<Q<0038C

00<04a<09Q<00`0C4`074`0301<C028C00<04a<021<00`0C4`0Q4`0301<C00LC0P0S4`0301<C00LC

00<04a<09a<2048C00<04a<06A<00`0C4`0m4`0301<C08TC0P054`0301<C038C000b4`0301<C0?lC

;1<00`0C4`0I4`0301<C03dC00<04a<0Ra<01@0C4a<003DC000b4`0301<C0?lC;1<00`0C4`0I4`03

01<C03dC00<04a<0Ra<0100C4`0C4`@07a<0038C00<04a<0oa</4`0301<C01TC00<04a<0?A<00`0C

4`2<4`8051<3020C000b4`0301<C0<8C3PdW4`<0:a?o00XC00<04a<07Q<0038C00<04a<0^a<73@hC

2@dO4`0301<C02/C00<04a<00Q<0100C4`084`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC

00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00<C00<04`001a<00`0C

4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC

00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C

4`054`<01Q<00`0C4`0<4`8081<002`C`0043Ah040d600TC00<04a<0<1<00`0C4`0I4`0301<C02HC

00<04a<051<00`0C4`0@4`0301<C02HC00<04a<09Q<00`0C4`0V4`0401<C03HC000b4`0301<C00PC

00<04a<02A<00`0C4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0C

4`084`0301<C00TC00<04a<02A<00`0C4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C008C

1@d24`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC00<04a<031<4030C00<04a<06A<00`0C

4`0m4`0301<C08/C00D04a<C000e4`00<Q<00`0C4`0/4`0301<C02`C00<04a<0;1<00`0C4`0Q4`@=

1a<00`0C4`0/4`0301<C040C00<04a<06A<00`0C4`0m4`0301<C08XC00<04a<00Q<00`0C4`0c4`00

<Q<00`0C4`2[4`<=OA<00`0C4`0I4`0301<C03dC00<04a<0RA<00`0C4`044`0301<C038C000b4`03

01<C0:TC0Pf04`0301<C01TC0P0n4`0301<C08LC0P074`0301<C038C000b4`0301<C0:HC0`f24`03

01<C01TC00<04a<0?A<00`0C4`274`0301<C00HC00<04a<0<Q<0038C00<04a<0Xa<33HHC00<04a<0

61<00`0C4`0m4`0301<C08HC00<04a<021<00`0C4`0a4`00<Q<00`0C4`2P4`<=RA<00`0C4`0H4`03

01<C03dC00<04a<0Q1<200/C00<04a<0<A<0038C00<04a<0Ga<>3C0C0`f<4`0301<C01PC00<04a<0

?A<00`0C4`234`0301<C00/C00<04a<0<A<0038C00<04a<0F1<73@hC2@dS4`@=Sa<00`0C4`0H4`03

01<C03dC00<04a<0PQ<00`0C4`0<4`0301<C034C000b4`0301<C05DC0`dN4`D=61<63I<C00<04a<0

61<203hC00<04a<0P1<200lC00<04a<0<A<0038C00<04a<0Da<23BHC60fI4`0301<C01PC00<04a<0

?A<00`0C4`1o4`0301<C010C00<04a<0<1<0038C00<04a<0D1<33MTC00<04a<061<00`0C4`0n4`03

01<C07`C0P0C4`0301<C030C000b4`0301<C04hC0PgL4`0301<C01PC00<04a<0?Q<00`0C4`1k4`80

51<00`0C4`0`4`00<Q<00`0C4`1<4`8=gQ<00`0C4`0H4`0301<C03hC00<04a<0NA<201HC00<04a<0

<1<0038C00<04a<0BQ<23N0C00<04a<061<00`0C4`0n4`0301<C07PC00<04a<05Q<00`0C4`0`4`00

<Q<00`0C4`184`8=ha<00`0C4`0G4`80?a<00`0C4`1f4`806A<00`0C4`0`4`00<Q<00`0C4`164`8=

iA<00`0C4`0G4`0301<C03hC00<04a<0M1<201`C00<04a<0;a<001`C00<04a<00Q<0100C4a<300<C

00<04a<011<00`0C4`144`8=ia<00`0C4`0G4`0301<C03hC00<04a<0La<00`0C4`0L4`0301<C02lC

000K4`0301<000LC00<04a<00Q<00`0C00054`0301<C048C0PgY4`0301<C01LC00<04a<0?a<00`0C

4`1`4`807a<00`0C4`0_4`006a<00`0C00084`0301<C00<C00<04a<00a<2044C0Pg/4`0301<C01HC

00<04a<0?a<00`0C4`1]4`<08A<00`0C4`0_4`006a<00`0C00084`0401<C4`801Q<00`0C4`0n4`8=

kQ<00`0C4`0F4`0301<C03lC00<04a<0K1<202<C00<04a<0;a<001/C00<04`001a<00`0C00024`03

01<C00DC00<04a<0?1<23O0C00<04a<05Q<2040C00<04a<0JQ<202DC00<04a<0;a<001`C00<04a<0

1a<0100C4a<300DC00<04a<0>Q<23O8C00<04a<05Q<00`0C4`0o4`0301<C06PC0P0W4`0301<C02lC

000b4`0301<C03PC0Pgd4`0301<C01HC00<04a<0?a<00`0C4`1V4`80:A<00`0C4`0_4`00<Q<00`0C

4`0f4`8=ma<00`0C4`0E4`0301<C03lC00<04a<0I1<202XC00<04a<0<1<0038C00<04a<0=A<00`dC

4`3g4`0301<C00lC00<04a<00a<00`0C4`0o4`0301<C068C0P0/4`0301<C030C000b4`0301<C03@C

00<=4a<0n1<00`0C4`0>4`0301<000@C00<04a<0@1<00`0C4`1N4`<0;Q<00`0C4`0`4`00<Q<00`0C

4`0b4`8=na<00`0C4`0@4`0301<C008C0`104`0301<C05`C0`0`4`0301<C030C000b4`0301<C034C

00<=4a<0o1<00`0C4`0=4`801A<00`0C4`104`0301<C05XC0P0b4`80<Q<0038C00<04a<0;a<23OlC

00<04a<03A<00`0C4`044`0301<C044C00<04a<0Ea<203@C00<04a<0<A<0038C00<04a<0;Q<00`dC

4`3o4`4C00<04a<031<300@C00<04a<0@A<00`0C4`1D4`<0=Q<00`0C4`0a4`00<Q<00`0C4`0/4`8=

oa<44`0301<C01<C00<04a<0@A<00`0C4`1B4`<0=a<203<C000b4`0301<C02XC0Pgo4`LC00<04a<0

4Q<2048C00<04a<0Ca<303XC00<04a<0<Q<0038C00<04a<0:1<23OlC2A<00`0C4`0B4`0301<C048C

00<04a<0C1<303`C00<04a<0<Q<0038C00<04a<09Q<23OlC31<00`0C4`0A4`0301<C048C00<04a<0

BA<303hC00<04a<0<a<0038C00<04a<08a<33OlC3Q<00`0C4`0A4`0301<C048C00<04a<0Aa<3040C

00<04a<0<a<0024C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<08A<23OlC4Q<00`0C4`0@4`03

01<C048C00<04a<0A1<3048C0P0e4`0081<00`0C00074`0301<000DC00<04a<07Q<33OlC51<00`0C

4`0@4`0301<C04<C00<04a<0@1<304DC00<04a<0=1<0020C00<04`002A<00`0C4`034`807A<23OlC

61<00`0C4`0?4`80A1<00`0C4`0m4`<0Aa<203HC000P4`0301<000LC0P064`0301<C01TC0`go4aXC

00<04a<03a<00`0C4`144`0301<C03TC0`1:4`0301<C03DC000P4`0301<000LC00<04a<01A<00`0C

4`0G4`8=oa<N4`0301<C00hC00<04a<0A1<00`0C4`0f4`@0Ba<203LC000Q4`0301<C00HC0`054`03

01<C01<C10go4b4C00<04a<03A<00`0C4`144`0301<C03<C0`1?4`0301<C03HC000b4`0301<C00hC

1@go4bHC00<04a<031<00`0C4`154`0301<C02lC0`1A4`0301<C03LC000b4`0301<C00/C0`go4b/C

00<04a<031<00`0C4`154`0301<C02/C101C4`80>A<0038C00@04a<C2Pgo4blC00<04a<02a<204LC

00<04a<09a<405HC00<04a<0>1<0038C10go4cTC00<04a<02a<00`0C4`164`0301<C02<C1@1H4`80

>Q<0038C00<04a<0oa<k4`802a<00`0C4`164`0301<C020C101K4`80>a<0038C00<04a<0oa<m4`03

01<C00PC00<04a<0Aa<00`0C4`0K4`@0Ga<00`0C4`0j4`00<Q<00`0C4`3o4chC00<04a<01a<00`0C

4`174`8061<5064C00<04a<0>a<0038C00<04a<0oa<n4`0301<C00LC00<04a<0B1<00`0C4`0C4`@0

I1<203dC000b4`0301<C0?lC?a<00`0C4`064`80BQ<00`0C4`0>4`@0Ia<203hC000b4`0301<C0?lC

@1<200HC00<04a<0BA<00`0C4`0:4`@0JQ<203lC000b4`0301<C0?lC@Q<00`0C4`034`0301<C04XC

00<04a<01A<506`C0P104`00<Q<00`0C4`3o4d<C0P034`0301<C04XC0P000a<00003070C0P114`00

<Q<00`0C4`3o4c/C1@024`0401<C008C00<04a<0BA<507<C0P124`0071<00`0C4`024`0301<C008C

00<04a<00Q<00`0C4`044`0301<C0?lC?A<01`0C4a<04`000Q<304LC1@024`0301<C074C0P134`00

6a<00`0C00084`0701<C4`0C00054`0301<C0?lC?A<01`0C4a<04`0011<3040C1@084`0301<C06hC

0P154`006a<00`0C00084`0301<C00<C00<04a<00a<20?lC?Q<01`0C4a<04`0011<0100C000j4`D0

3A<00`0C4`1]4`80AQ<001/C00<04`002A<00`0C4`0200HC00<04a<0oa<m4`0701<C4`0C00044`04

01<C4`<0<A<601<C0P1[4`<0Aa<001/C00<04`001a<00`0C00024`0301<C00DC00<04a<0oa<l4`80

11<00`0C4`034`0301<C00@C0`0X4`L06A<206TC0P194`0071<00`0C4`064`<00Q<300DC00<04a<0

oa=84`0301<C00LC1@0K4`T081<00`0C4`1T4`<0Ba<0038C00<04a<0oa=84`0301<C00`C700Y4`80

HQ<304dC000b4`0301<C0?lCB1<205<C0P1O4`<0Ca<0038C00<04a<0oa=84`0301<C05<C0P1J4`@0

DQ<0038C00<04a<0oa=84`0301<C05@C0P1F4`@0EA<0038C00<04a<0oa=84`0301<C05HC0P1?4`D0

FA<0038C00<04a<0oa=84`0301<C05LC0`184`H0GA<0038C00<04a<0oa=84`0301<C05TC0`104`L0

HQ<0038C00<04a<0oa=84`80G1<303PC1`1X4`00<Q<00`0C4`3o4dPC00<04a<0GQ<302hC201^4`00

<Q<00`0C4`3o4dPC00<04a<0H1<502<C201e4`00<Q<00`0C4`3o4dPC00<04a<0I1<701@C2P1l4`00

<Q<00`0C4`3o4dPC00<04a<0JQ<E08HC000b4`0301<C0?lCB1<00`0C4`3o4`HC000Y4`D011<00`0C

4`3o4dPC0P3o4`LC000[4`0301<C00@C00<04a<0oa=84`0301<C0?lC1Q<002/C00<04a<011<20?lC

BA<00`0C4`3o4`HC000[4`0301<C0?lCoa=H4`00:a<00`0C4`3o4olCF1<002XC0P3o4olCFQ<00?lC

oa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC001d4`@000<C00001`000a<000044`03

01<C00D000<C000011<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<0

0Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<01@3o4jhC001d4`<0

21<01`0C4a<04`0021<01`0C4a<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`03

01<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0a<00`0C4`2S4`80oa<94`00MQ<00`0C4`04008C00L04a<C01<000PC00L04a<C01<0008C00<04`00

0Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`03

01<0008C00<04`000Q<00`0C00024`0301<000<C00<04a<0Y1<00`0C4`3o4`LC000I4`@000<C0000

1P024`X00Q<2008C0`024`<00a<200064`0001<0:Q<200PC00@04a<C0P094`0401<C4`800a<00`0C

00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C

00<04`000Q<00`0C00024`0301<0008C00<04`000a<00`0C4`2R4`<00Q<00`0C4`3o4`@C000J4`06

01<C01<00Q<00`0C00044`0601<C01<00Q<00`0C00054`0301<C008C00D04a<C00024`0401<04`80

=1<01@0C4a<000XC00D04a<C00044`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00034`03

01<C00<C00<04a<0Va<0200C4`0C01<0oa<54`006Q<01P0C4`0C00@C00<04a<00Q<00`0C4`024`03

01<C008C00<04a<00a<00`0C4`024`0501<C4`000Q<0100C01<203<C0P044`801a<200@C0P034`03

01<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<0

0Q<00`0C4`024`0301<C008C00<04a<00Q<0100C4a<200@C00<04a<0W1<0200C4`0C01<0oa<54`00

6Q<01@0C4`0C00800a<200<C00<04a<00Q<200<C00<04a<00a<00`0C4`024`0501<C4`000Q<01P0C

000C0?lC;a<300044`0C0?lC1A<001XC00H04a<04`024`0301<0008C00<04`0011<03P0C4`0C01<0

4`0C01<00Q<01@0C4a<0008C00H04`004`3o4c<C00<04`00oa<54`006A<400034`0000/00Q<50005

4`0001<01@0011<000034`8000@C000C0P3o4c@C00<04a<0oa<44`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.77084, -14.119, 0.0242408, 0.16996}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -57 0 ]

[.5 .63053 57 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -118 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(15.6000000000000005`) show

173.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .47082 m

.02499 .47082 L

.02606 .47081 L

.02729 .4708 L

.02846 .47078 L

.03053 .47074 L

.03279 .47068 L

.03527 .47059 L

.0379 .47048 L

.04262 .47021 L

.04749 .46985 L

.05205 .46945 L

.06245 .46825 L

.07305 .46666 L

.08274 .46487 L

.10458 .45969 L

.14429 .44639 L

.18248 .42942 L

.22313 .40812 L

.26226 .38639 L

.30384 .36478 L

.32471 .35548 L

.34391 .34827 L

.36265 .34266 L

.37221 .34039 L

.38246 .33841 L

.39273 .33691 L

.40209 .33594 L

.4066 .33561 L

.40898 .33547 L

.41151 .33534 L

.41371 .33526 L

.41488 .33522 L

.41614 .33518 L

.4173 .33516 L

.41835 .33514 L

.41936 .33512 L

.42043 .33511 L

.42166 .3351 L

.42236 .3351 L

.423 .3351 L

.42418 .33511 L

.42543 .33512 L

.42655 .33513 L

.42759 .33515 L

.42997 .3352 L

.43254 .33528 L

.43489 .33537 L

.44017 .33565 L

.44468 .33595 L

Mistroke

.44959 .33634 L

.45854 .33722 L

.49923 .34281 L

.51807 .34555 L

.53842 .34803 L

.54386 .34855 L

.5496 .34903 L

.55491 .34939 L

.55987 .34965 L

.56452 .34983 L

.56712 .3499 L

.56827 .34992 L

.5695 .34995 L

.57014 .34995 L

.57085 .34996 L

.5721 .34997 L

.5728 .34998 L

.57355 .34998 L

.57427 .34998 L

.57492 .34998 L

.57611 .34998 L

.57742 .34996 L

.57808 .34996 L

.57878 .34995 L

.58005 .34992 L

.58265 .34986 L

.5854 .34976 L

.59032 .34953 L

.59562 .34918 L

.60144 .34868 L

.61186 .34749 L

.6216 .34603 L

.64193 .34199 L

.66048 .3373 L

.70029 .32527 L

.73859 .3136 L

.75795 .30856 L

.76824 .30625 L

.77934 .30411 L

.78989 .30243 L

.79956 .3012 L

.80882 .30031 L

.81347 .29997 L

.81857 .29967 L

.8211 .29956 L

.82385 .29945 L

.82644 .29938 L

.82767 .29935 L

.82883 .29932 L

.82995 .29931 L

Mistroke

.83098 .29929 L

.83213 .29928 L

.83336 .29927 L

.83454 .29927 L

.83582 .29927 L

.83703 .29927 L

.83816 .29928 L

.83947 .29929 L

.8409 .29931 L

.84348 .29936 L

.84599 .29943 L

.8483 .2995 L

.85355 .29972 L

.8591 .30001 L

.86859 .30066 L

.87875 .30151 L

.89709 .30333 L

.91692 .30541 L

.92737 .30644 L

.93847 .3074 L

.94779 .30807 L

.95274 .30836 L

.95807 .30862 L

.96295 .3088 L

.96508 .30886 L

.96742 .30892 L

.96963 .30896 L

.97169 .30899 L

.97283 .309 L

.97387 .30901 L

.97506 .30902 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.3947 .07524 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4gdC00<04a<0oa<64`00oa=m4`0301<C0?lC1Q<002TC1@3o4dlC0P3o4`LC

000[4`0301<C0?lCCa<00`0C4`1^4`d0RQ<002DC0`034`0301<C00@C0P3o4dTC00<04a<0IQ<800`C

3@1n4`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`1Q4`D081<807LC000[4`0301<C00@C00<04a<0

oa=84`0301<C05hC100/4`L0L1<002XC0P064`0301<C0?lCB1<00`0C4`1L4`<0=A<706XC000b4`03

01<C0?lCB1<205/C0P0o4`H0I1<0038C00<04a<0oa=84`0301<C05PC0P164`H0Ga<0038C00<04a<0

oa=84`0301<C05HC0P1>4`D0FQ<0038C00<04a<0oa=84`0301<C05DC0P1C4`D0EQ<0038C00<04a<0

oa=84`0301<C05@C00<04a<0Ea<5058C000b4`0301<C0?lCB1<205<C0P1N4`<0D1<0038C00<04a<0

oa=84`0301<C00lC5P0/4`80HA<404dC000b4`0301<C0?lCB1<00`0C4`0:4`D05Q<9010C00<=4a<0

3a<206DC0`1;4`00<Q<00`0C4`3o4dPC00<04a<01A<502<C1`074`H=3Q<206PC0`194`00<Q<00`0C

4`3o4c/C1@024`0301<C00<C00<04a<00a<202lC1P093@/C0P1[4`80B1<0038C00<04a<0oa<m4`07

01<C4`0C00044`0301<C00<0=Q<00`0=3@073@XC0P1]4`<0AQ<0038C00<04a<0oa<g4`<00a<01`0C

4a<04`0011<303XC2@d00`0C4`074`0301<C06hC0P154`00<Q<00`0C4`3o4cdC00L04a<C01<000<C

0P0k4`/=10044`0301<C070C0P144`0071<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`044`03

01<C0?lC?A<01`0C4a<04`000Q<00`0C000l4`T=1A<507@C0P124`006a<00`0C00084`0701<C4`0C

00054`0301<C0?lC?1<200@C00@04`000Q<00`0C4`0j4`T=21<6074C0P114`005Q<3008C00<04`00

21<00`0C4`034`0301<C00<C0P3o4d<C0P044`0301<C03XC2@d74`0301<C00@C101^4`80@1<001/C

00<04`002A<00`0C4`0200HC00<04a<0oa=14`0301<C00@C00<04a<0>a<63@PC00<04a<02A<406/C

00<04a<0?Q<001/C00<04`001a<00`0C00024`0301<C00DC00<04a<0oa=04`0301<C00DC0P0o4`03

3A<C00PC00<04a<03A<406PC0P0n4`0071<00`0C4`064`<00Q<300DC00<04a<0oa<o4`0301<C00HC

00<04a<0B1<00`0C4`0B4`@0IA<00`0C4`0l4`00<Q<00`0C4`3o4chC00<04a<01a<00`0C4`184`03

01<C01DC1@1R4`0301<C03/C000b4`0301<C0?lC?A<00`0C4`084`0301<C04LC00<04a<06Q<405lC

0P0l4`00<Q<00`0C4`3o4c`C00<04a<02A<00`0C4`164`0301<C01lC101L4`80>a<0038C00<04a<0

oa<k4`0301<C00XC00<04a<0AQ<00`0C4`0R4`D0FA<00`0C4`0i4`00<Q<00`0C4`3o4cXC00<04a<0

2a<204LC00<04a<09Q<405LC00<04a<0>1<0038C00<04a<0oa<i4`0301<C00`C00<04a<0AA<00`0C

4`0Z4`@0E1<203TC000b4`0301<C0?lC>A<00`0C4`0<4`0301<C04DC00<04a<0;Q<4054C00<04a<0

=a<0038C00<04a<0oa<h4`0301<C00dC00<04a<0A1<00`0C4`0c4`80Ca<203PC000b4`0301<C0?lC

=a<00`0C4`0>4`0301<C04@C00<04a<0=A<404`C0P0g4`00<Q<00`0C4`3o4cHC00<04a<03a<00`0C

4`144`0301<C03TC0P1;4`0301<C03DC000b4`0301<C0?lC=Q<00`0C4`0?4`80A1<00`0C4`0l4`@0

Aa<203HC000b4`0301<C0?lC=A<00`0C4`0@4`0301<C04<C00<04a<0?a<304HC00<04a<0=1<0038C

00<04a<0oa<e4`0301<C010C00<04a<0@a<00`0C4`124`<0@a<203DC000Q4`0301<C008C00<04a<0

0Q<00`0C4`044`0301<C0?lC=1<00`0C4`0A4`0301<C048C00<04a<0AQ<3044C00<04a<0<a<0020C

00<04`001a<00`0C00054`0301<C0?lC=1<00`0C4`0A4`0301<C048C00<04a<0BA<203lC00<04a<0

<a<001/C0`024`0301<000TC00<04a<00a<20?lC=1<00`0C4`0B4`0301<C048C00<04a<0Ba<303dC

00<04a<0<Q<0020C00<04`001a<200HC00<04a<0oa<c4`0301<C018C0P134`0301<C04hC0P0k4`03

01<C038C000P4`0301<000LC00<04a<01A<00`0C4`3o4c8C00<04a<04a<00`0C4`114`0301<C054C

0`0h4`0301<C038C000Q4`0301<C00HC0`054`0301<C0?lC<Q<00`0C4`0C4`0301<C044C00<04a<0

E1<203LC00<04a<0<A<0038C00<04a<0oa<a4`0301<C01@C00<04a<0@A<00`0C4`1F4`<0=1<00`0C

4`0a4`00<Q<00`0C4`3o4c4C00<04a<03Q<00`0C4`034`0301<C040C00<04a<0FA<3038C0P0b4`00

<Q<00`0C4`3o4c0C00<04a<03Q<00`0C00044`0301<C040C00<04a<0G1<2034C00<04a<0<1<0038C

00<04a<0oa<`4`0301<C00TC0`044`0301<C008C0`104`0301<C05hC0P0_4`0301<C030C000b4`03

01<C0?lC<1<00`0C4`0>4`801A<00`0C4`0o4`0301<C064C0`0/4`0301<C030C000b4`0301<C0?lC

<1<00`0C4`0>4`0301<C00@C00<04a<0?a<00`0C4`1T4`0301<C02TC00<04a<0<1<0038C00<04a<0

oa<_4`0301<C00lC0`044`0301<C03lC00<04a<0IA<302PC0P0a4`00<Q<00`0C4`3o4blC00<04a<0

5Q<00`0C4`0o4`0301<C06PC00<04a<09Q<00`0C4`0_4`00<Q<00`0C4`3o4blC00<04a<05Q<00`0C

4`0o4`0301<C06TC0`0U4`0301<C02lC000b4`0301<C0?lC;a<00`0C4`0F4`80@1<00`0C4`1/4`80

8a<00`0C4`0_4`00<Q<00`0C4`3o4blC00<04a<05Q<00`0C4`0o4`0301<C06dC0P0R4`0301<C02lC

000b4`0301<C0?lC;a<00`0C4`0F4`0301<C03lC00<04a<0Ka<2020C00<04a<0;a<0038C00<04a<0

oa<^4`0301<C01LC00<04a<0?Q<00`0C4`1b4`807Q<00`0C4`0_4`0071<00`0C4`024`0401<C4`<0

0a<00`0C4`044`0301<C0?lC;Q<00`0C4`0G4`0301<C03hC00<04a<0M1<201`C00<04a<0;a<001/C

00<04`001a<00`0C4`024`0301<000DC00<04a<0oa<^4`0301<C01LC0P0o4`0301<C07HC0P0J4`03

01<C02lC000F4`<00Q<00`0C00084`0301<C00<C00<04a<00a<20?lC;a<00`0C4`0G4`0301<C03hC

00<04a<0N1<00`0C4`0F4`0301<C030C000K4`0301<000PC00@04a<C0P064`0301<C0?lC;A<00`0C

4`0H4`0301<C03hC00<04a<0NA<201HC00<04a<0<1<001/C00<04`001a<00`0C00024`0301<C00DC

00<04a<0oa<]4`0301<C01PC00<04a<0?Q<00`0C4`1k4`0301<C01<C00<04a<0<1<001`C00<04a<0

1a<0100C4a<300DC00<04a<0oa<]4`0301<C01PC00<04a<0?Q<00`0C4`1l4`0301<C018C00<04a<0

<1<0038C00<04a<0oa<]4`0301<C01PC00<04a<0?A<00`0C4`1n4`804Q<00`0C4`0`4`00<Q<00`0C

4`3o4bdC00<04a<061<203hC00<04a<0P1<2010C00<04a<0<1<0038C00<04a<0oa<]4`0301<C01PC

00<04a<08A<5008C00<04a<04Q<00`0C4`0;4`D000<C00008A<5008C00<04a<07a<5008C00<04a<0

6a<0100C4a<500034`0000<C00<04a<0<A<0038C00<04a<0oa<]4`0301<C01PC00<04a<08a<01`0C

4a<04`004a<00`0C4`0=4`0701<C4`0C000R4`0301<C008C00<04a<08A<01`0C4a<04`0071<200@C

00<04a<00a<0100C4`0c4`00<Q<00`0C4`0V4`0301<C008C00@04a<C0`0S4`0301<C008C00<04a<0

0Q<3028C00<04a<00Q<0100C4a<202@C00<04a<00Q<00`0C4`024`0301<C02HC1@114`0301<C01PC

00<04a<08a<00`0C4`034`0301<C014C00<04a<03A<01`0C4a<04`008Q<00`0C4`024`0301<C024C

00L04a<C01<001hC00D04a<C00044`800Q<00`0C4`0a4`00<Q<00`0C4`0U4`0301<000LC00<04a<0

8Q<00`0C00094`0301<C020C00<04`001a<00`0C000R4`0301<000LC00<04`00:A<00`0C4`114`03

01<C01PC00<04a<08a<0100C4a<201@C00<04a<03A<0100C4a<202<C00<04a<00a<00`0C4`0P4`03

01<C008C00<04a<07Q<200034`0C008C00<04`000Q<00`0C4`0a4`00<Q<00`0C4`0U4`0301<000PC

00<04a<08A<00`0C00074`@08A<00`0C00074`0301<0028C00<04`001a<00`0C000Y4`0301<C040C

00<04a<06A<00`0C4`0S4`0501<C4`005A<00`0C4`0=4`0501<C4`0091<01`0C4a<04`008Q<01`0C

4a<04`008A<200<C00D04`0C000d4`00<Q<00`0C4`0U4`0301<000PC00<04a<08A<00`0C00074`03

01<0028C00<04`001a<202<C00<04`0021<00`0C4`0X4`0301<C040C00<04a<06A<202<C0P034`<0

4a<00`0C4`0<4`8011<2024C0P034`<08A<200@C00<04a<081<200@C0P000a<04`0c4`00<Q<00`0C

4`0U4`0301<000LC00<04`008Q<00`0C00084`808Q<00`0C00074`0301<C028C00<04`001a<00`0C

000Y4`0301<C040C00<04a<06A<00`0C4`0m4`0301<C08PC00<04a<01A<00`0C4`0b4`00<Q<00`0C

4`0V4`0301<C00LC00<04a<08Q<00`0C4`084`0301<C024C00<04a<01a<202<C00<04a<01a<00`0C

4`0W4`80@Q<00`0C4`0I4`0301<C03dC00<04a<0RA<200DC00<04a<0<Q<0038C00<04a<0oa</4`03

01<C01TC00<04a<0?A<00`0C4`2;4`0501<C4`00=A<0038C00<04a<0oa</4`0301<C01TC00<04a<0

?A<00`0C4`2;4`0401<C01<C100O4`00<Q<00`0C4`3o4b`C00<04a<06A<00`0C4`0m4`0301<C08`C

0P0D4`<081<0038C00<04a<0_Q<A3BPC0`0[4ol02Q<00`0C4`0N4`00<Q<00`0C4`2g4`L=4A<83B4C

00<04a<0:a<00`0C4`024`0401<C00PC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C

4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<00a<00`0C00074`0301<C00HC

00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C

4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC

0`064`0301<C00`C0P0P4`00;1>j00H=800B3@H02A<00`0C4`0`4`0301<C01TC00<04a<09Q<00`0C

4`0D4`0301<C010C00<04a<09Q<00`0C4`0V4`0301<C02HC00@04a<0=Q<0038C00<04a<021<00`0C

4`094`0301<C00TC00<04a<02A<00`0C4`084`0301<C00TC00<04a<02A<00`0C4`094`0301<C00PC

00<04a<02A<00`0C4`094`0301<C00TC00<04a<02A<00`0C4`084`0301<C00TC00@04`d=21<00`0C

4`094`0301<C00PC00<04a<02A<00`0C4`094`0301<C00`C100`4`0301<C01TC00<04a<0?A<00`0C

4`2;4`0501<C4`00=A<0038C00<04a<0;1<00`0C4`0/4`0301<C02`C00<04a<07Q<43@XC00<04a<0

;1<00`0C4`104`0301<C01TC00<04a<0?A<00`0C4`2:4`0301<C008C00<04a<0<a<0038C00<04a<0

Ya<43H0C00<04a<06A<00`0C4`0m4`0301<C08TC00<04a<011<00`0C4`0b4`00<Q<00`0C4`2S4`@=

Q1<00`0C4`0I4`80?Q<00`0C4`274`801a<00`0C4`0b4`00<Q<00`0C4`2P4`<=R1<00`0C4`0I4`03

01<C03dC00<04a<0Qa<00`0C4`064`0301<C038C000b4`0301<C09`C10f<4`0301<C01PC00<04a<0

?A<00`0C4`264`0301<C00PC00<04a<0<A<0038C00<04a<0Ea<D3BhC0`f@4`0301<C01PC00<04a<0

?A<00`0C4`244`802a<00`0C4`0a4`00<Q<00`0C4`1B4`D=51<53BLC0PfC4`0301<C01PC00<04a<0

?A<00`0C4`234`0301<C00/C00<04a<0<A<0038C00<04a<0Ca<33AhC1@dN4`@=UA<00`0C4`0H4`03

01<C03dC00<04a<0PQ<00`0C4`0<4`0301<C034C000b4`0301<C04/C10dV4``=21<:3ITC00<04a<0

61<203hC00<04a<0P1<200lC00<04a<0<A<0038C00<04a<0BA<23CHC20fS4`0301<C01PC00<04a<0

?A<00`0C4`1o4`0301<C010C00<04a<0<1<0038C00<04a<0AQ<33N<C00<04a<061<00`0C4`0n4`03

01<C07`C0P0C4`0301<C030C000b4`0301<C04@C0PgV4`0301<C01PC00<04a<0?Q<00`0C4`1k4`80

51<00`0C4`0`4`00<Q<00`0C4`124`8=j1<00`0C4`0H4`0301<C03hC00<04a<0NA<201HC00<04a<0

<1<0038C00<04a<0@1<23NXC00<04a<061<00`0C4`0n4`0301<C07PC00<04a<05Q<00`0C4`0`4`00

<Q<00`0C4`0n4`8=kA<00`0C4`0G4`80?a<00`0C4`1f4`806A<00`0C4`0`4`00<Q<00`0C4`0l4`8=

ka<00`0C4`0G4`0301<C03hC00<04a<0M1<201`C00<04a<0;a<001`C00<04a<00Q<0100C4a<300<C

00<04a<011<00`0C4`0j4`8=lA<00`0C4`0G4`0301<C03hC00<04a<0La<00`0C4`0L4`0301<C02lC

000K4`0301<000LC00<04a<00Q<00`0C00054`0301<C03PC0Pgc4`0301<C01LC00<04a<0?a<00`0C

4`1`4`807a<00`0C4`0_4`006a<00`0C00084`0301<C00<C00<04a<00a<203PC00<=4a<0m1<00`0C

4`0F4`0301<C03lC00<04a<0KA<3024C00<04a<0;a<001/C00<04`0021<0100C4a<200HC00<04a<0

=A<23OLC00<04a<05Q<00`0C4`0o4`0301<C06`C0P0S4`0301<C02lC000K4`0301<000LC00<04`00

0Q<00`0C4`054`0301<C03<C0Pgi4`0301<C01HC0P104`0301<C06XC0P0U4`0301<C02lC000L4`03

01<C00LC00@04a<C0`054`0301<C034C0Pgk4`0301<C01HC00<04a<0?a<00`0C4`1X4`809a<00`0C

4`0_4`00<Q<00`0C4`0_4`8=oA<00`0C4`0F4`0301<C03lC00<04a<0IQ<202TC00<04a<0;a<0038C

00<04a<0;Q<00`dC4`3n4`0301<C01DC00<04a<0?a<00`0C4`1T4`80:Q<00`0C4`0`4`00<Q<00`0C

4`0/4`8=oa<24`0301<C00lC00<04a<00a<00`0C4`0o4`0301<C068C0P0/4`0301<C030C000b4`03

01<C02XC0Pgo4`@C00<04a<03Q<00`0C00044`0301<C040C00<04a<0GQ<302hC00<04a<0<1<0038C

00<04a<0:1<23OlC1Q<00`0C4`0@4`0301<C008C0`104`0301<C05`C0`0`4`0301<C030C000b4`03

01<C02HC0Pgo4`TC00<04a<03A<200DC00<04a<0@1<00`0C4`1J4`80<Q<2038C000b4`0301<C02<C

0`go4`/C00<04a<03A<00`0C4`044`0301<C044C00<04a<0Ea<203@C00<04a<0<A<0038C00<04a<0

8A<23OlC3a<00`0C4`0<4`<011<00`0C4`114`0301<C05@C0`0f4`0301<C034C000b4`0301<C01hC

0`go4a4C00<04a<04a<00`0C4`114`0301<C058C0`0g4`80<a<0038C00<04a<071<23OlC5A<00`0C

4`0B4`80@Q<00`0C4`1?4`<0>Q<00`0C4`0b4`00<Q<00`0C4`0I4`<=oa<G4`0301<C018C00<04a<0

@Q<00`0C4`1<4`<0?1<00`0C4`0b4`00<Q<00`0C4`0G4`8=oa<K4`0301<C014C00<04a<0@Q<00`0C

4`194`<0?Q<00`0C4`0c4`00<Q<00`0C4`0D4`<=oa<M4`0301<C014C00<04a<0@Q<00`0C4`174`<0

@1<00`0C4`0c4`008A<00`0C4`024`0301<C008C00<04a<011<00`0C4`0B4`8=oa<Q4`0301<C010C

00<04a<0@Q<00`0C4`144`<0@Q<203DC000P4`0301<000LC00<04`001A<00`0C4`0>4`@=oa<S4`03

01<C010C00<04a<0@a<00`0C4`104`<0AA<00`0C4`0d4`0081<00`0C00094`0301<C00<C0P094`H=

oa<X4`0301<C00lC0P144`0301<C03dC0`174`80=Q<0020C00<04`001a<200HC2`go4bhC00<04a<0

3a<00`0C4`144`0301<C03TC0`1:4`0301<C03DC000P4`0301<000LC00<04a<01A<00`0C4`3o4cLC

00<04a<03Q<00`0C4`144`0301<C03HC101;4`80=a<0024C00<04a<01Q<300DC00<04a<0oa<h4`03

01<C00dC00<04a<0A1<00`0C4`0c4`<0Ca<00`0C4`0f4`00<Q<00`0C4`3o4cTC00<04a<031<00`0C

4`154`0301<C02lC0`1A4`0301<C03LC000b4`0301<C0?lC>A<00`0C4`0<4`0301<C04DC00<04a<0

:a<405<C0P0i4`00<Q<00`0C4`3o4cXC00<04a<02a<204LC00<04a<09a<405HC00<04a<0>1<0038C

00<04a<0oa<j4`0301<C00/C00<04a<0AQ<00`0C4`0S4`D0F1<203XC000b4`0301<C0?lC>a<200/C

00<04a<0AQ<00`0C4`0P4`@0Fa<203/C000b4`0301<C0?lC?A<00`0C4`084`0301<C04LC00<04a<0

6a<405lC00<04a<0>Q<0038C00<04a<0oa<n4`0301<C00LC00<04a<0Aa<201PC1@1Q4`0301<C03/C

000b4`0301<C0?lC?Q<00`0C4`074`0301<C04PC00<04a<04a<406@C0P0m4`00<Q<00`0C4`3o4clC

00<04a<01Q<204XC00<04a<03Q<406LC0P0n4`00<Q<00`0C4`3o4d0C0P064`0301<C04TC00<04a<0

2Q<406XC0P0o4`00<Q<00`0C4`3o4d8C00<04a<00a<00`0C4`1:4`0301<C00DC1@1/4`80@1<0038C

00<04a<0oa=34`800a<00`0C4`1:4`8000<C00000`1`4`80@A<0038C00<04a<0oa<k4`D00Q<0100C

4`024`0301<C04TC1@1c4`80@Q<001`C00<04a<00Q<00`0C4`024`0301<C008C00<04a<011<00`0C

4`3o4cdC00L04a<C01<0008C0`174`D00Q<00`0C4`1a4`80@a<001/C00<04`0021<01`0C4a<04`00

1A<00`0C4`3o4cdC00L04a<C01<000@C0`104`D021<00`0C4`1^4`80AA<001/C00<04`0021<00`0C

4`034`0301<C00<C0P3o4chC00L04a<C01<000@C00@04`00>Q<500dC00<04a<0KA<204HC000K4`03

01<000TC00<04a<00P064`0301<C0?lC?A<01`0C4a<04`0011<0100C4a<3034C1P0C4`80Ja<304LC

000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C0?lC?1<200@C00<04a<00a<00`0C4`044`<0

:1<701TC0P1Y4`80BA<001`C00<04a<01Q<3008C0`054`0301<C0?lCB1<00`0C4`074`D06a<9020C

00<04a<0I1<304/C000b4`0301<C0?lCB1<00`0C4`0<4a`0:A<2068C0`1=4`00<Q<00`0C4`3o4dPC

0P1C4`80Ga<304lC000b4`0301<C0?lCB1<00`0C4`1C4`80FQ<4058C000b4`0301<C0?lCB1<00`0C

4`1D4`80EQ<405DC000b4`0301<C0?lCB1<00`0C4`1F4`80Ca<505TC000b4`0301<C0?lCB1<00`0C

4`1G4`<0B1<605dC000b4`0301<C0?lCB1<00`0C4`1I4`<0@1<7068C000b4`0301<C0?lCB1<205`C

0`0h4`L0J1<0038C00<04a<0oa=84`0301<C05hC0`0^4`P0KQ<0038C00<04a<0oa=84`0301<C060C

1@0S4`P0MA<0038C00<04a<0oa=84`0301<C06@C1`0D4`X0O1<0038C00<04a<0oa=84`0301<C06XC

5@264`00<Q<00`0C4`3o4dPC00<04a<0oa<64`00:A<500@C00<04a<0oa=84`80oa<74`00:a<00`0C

4`044`0301<C0?lCB1<00`0C4`3o4`HC000[4`0301<C00@C0P3o4dTC00<04a<0oa<64`00:a<00`0C

4`3o4olCF1<002/C00<04a<0oa?o4ePC000Z4`80oa?o4eXC003o4olCQQ<00?lCoa>64`00oa?o4hHC

003o4olCQQ<00?lCoa>64`00LA<400034`0000L00Q<00`0C4`024`0401<C4`8011<00`0C4`024`03

01<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<0

0Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<0oa>/4`00LA<300PC

00L04a<C01<000LC00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C

00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C

00024`0301<0008C00<04`00XQ<20?lC2A<007<C00<04a<010024`0301<C00<C00<04a<01A<00`0C

00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C

00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`0011<00`0C

4`2Q4`0301<C0?lC1a<001TC10000a<00006008C2P024`800Q<3008C0`034`8000HC00004`0W4`80

21<0100C4a<200PC0P034`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C

00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C

00<04`000Q<20:8C0`024`0301<C0?lC11<001XC00H04a<04`024`0301<000@C00H04a<04`024`03

01<000DC00<04a<00Q<01@0C4a<0008C00@04`0C0P0a4`0501<C4`002A<00`0C4`024`0301<0008C

00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C

00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C4`044`0301<C09TC

00P04a<04`0C0?lC1A<001XC00H04a<04`044`0301<C008C00<04a<00Q<00`0C4`024`0301<C00<C

00<04a<00Q<01@0C4a<0008C00@04`0C0P0`4`800a<300PC0P034`0301<C008C00<04a<00Q<00`0C

4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C

00<04a<00Q<00`0C4`024`0301<C008C00@04a<C0`034`0301<C09XC00P04a<04`0C0?lC1A<001XC

00D04a<04`0200<C0P034`0301<C008C0P034`0301<C00<C00<04a<00Q<01@0C4a<0008C00H04`00

4`3o4blC0`0011<04`3o4`DC000J4`0601<C01<00Q<00`0C00024`0301<000@C00h04a<04`0C01<0

4`0C008C00D04a<C00024`0601<001<0oa<c4`0301<00?lC1A<001TC10000a<0000;008C1@001A<0

000C00D000@C00000a<200044`004`80oa<d4`0301<C0?lC11<00?lCoa>64`00oa?o4hHC003o4olC

QQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00001\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.77084, -14.119, 0.0242408, 0.16996}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -22 0 ]

[.5 .63053 22 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -83 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(15.04`) show

103.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .44884 m

.02499 .44883 L

.02606 .44883 L

.02729 .44881 L

.02846 .4488 L

.03053 .44875 L

.03279 .44869 L

.03527 .44859 L

.0379 .44847 L

.04262 .44819 L

.04749 .44781 L

.05205 .44738 L

.06245 .44611 L

.07305 .44443 L

.08274 .44254 L

.10458 .43712 L

.14429 .42345 L

.18248 .40658 L

.22313 .38634 L

.26226 .36691 L

.28223 .35784 L

.30384 .34916 L

.32294 .34275 L

.33378 .33971 L

.34391 .33729 L

.35434 .33524 L

.36384 .33376 L

.37401 .33259 L

.37961 .33212 L

.38234 .33194 L

.38491 .33179 L

.3873 .33168 L

.3895 .3316 L

.39194 .33152 L

.39322 .3315 L

.39456 .33147 L

.39579 .33145 L

.3971 .33144 L

.39834 .33144 L

.39946 .33144 L

.40078 .33144 L

.40153 .33145 L

.40222 .33146 L

.40348 .33147 L

.40482 .3315 L

.407 .33155 L

.40935 .33162 L

.41359 .3318 L

.41863 .33208 L

.42324 .3324 L

Mistroke

.44226 .33428 L

.463 .33704 L

.48436 .34023 L

.5037 .34298 L

.5134 .34421 L

.52389 .34534 L

.53378 .3462 L

.53854 .34653 L

.54288 .34678 L

.54759 .34699 L

.55019 .34707 L

.55264 .34714 L

.55374 .34716 L

.55491 .34718 L

.55592 .3472 L

.557 .34721 L

.55817 .34722 L

.55926 .34722 L

.56055 .34723 L

.56174 .34722 L

.56295 .34721 L

.56424 .3472 L

.56545 .34718 L

.56656 .34716 L

.56927 .34709 L

.57182 .34701 L

.57691 .34678 L

.58242 .34643 L

.59191 .3456 L

.60233 .34435 L

.62339 .34083 L

.64288 .33651 L

.66378 .33104 L

.70511 .31912 L

.72578 .31341 L

.74492 .30871 L

.76467 .30471 L

.78322 .3019 L

.79219 .30089 L

.80186 .30007 L

.80709 .29975 L

.80994 .2996 L

.8126 .29949 L

.81506 .2994 L

.8173 .29933 L

.81979 .29927 L

.82116 .29925 L

.82245 .29923 L

.8236 .29922 L

.82484 .29921 L

Mistroke

.82601 .2992 L

.82707 .2992 L

.82832 .2992 L

.82903 .2992 L

.82968 .29921 L

.83088 .29922 L

.83216 .29923 L

.83349 .29925 L

.83494 .29927 L

.83755 .29933 L

.84244 .29948 L

.84712 .29967 L

.85205 .29992 L

.86089 .30048 L

.88054 .30211 L

.89888 .30392 L

.91888 .3059 L

.92871 .30678 L

.93781 .3075 L

.94655 .30809 L

.9562 .30858 L

.9612 .30877 L

.96589 .3089 L

.96848 .30895 L

.97085 .30898 L

.97209 .309 L

.97281 .309 L

.97345 .30901 L

.97414 .30901 L

.97487 .30902 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.30385 .0602 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4gdC00<04a<0oa<64`00oa=m4`0301<C0?lC1Q<002TC1@3o4dlC0P3o4`LC

000[4`0301<C0?lCCa<00`0C4`1^4`d0RQ<002DC0`034`0301<C00@C0P3o4dTC00<04a<0IQ<800`C

3@1n4`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`1Q4`D081<807LC000[4`0301<C00@C00<04a<0

oa=84`0301<C05hC100/4`L0L1<002XC0P064`0301<C0?lCB1<00`0C4`1L4`<0=A<706XC000b4`03

01<C0?lCB1<205/C0P0o4`H0I1<0038C00<04a<0oa=84`0301<C05PC0P164`H0Ga<0038C00<04a<0

oa=84`0301<C05HC0P1>4`D0FQ<0038C00<04a<0oa=84`0301<C02LC00<=4a<0:a<205<C1@1F4`00

<Q<00`0C4`3o4dPC00<04a<091<63BXC00<04a<0Ea<5058C000b4`0301<C0?lCB1<202@C2@dV4`80

GQ<3050C000b4`0301<C0?lCB1<00`0C4`0?4a@02@dU4`80HA<404dC000b4`0301<C0?lCB1<00`0C

4`0:4`D051<93@808Q<206DC0`1;4`00<Q<00`0C4`3o4dPC00<04a<01A<501PC2`d701/C0P1X4`<0

BA<0038C00<04a<0oa<k4`D00Q<00`0C4`034`0301<C00<C0P0N4`T=21<601@C0P1[4`80B1<0038C

00<04a<0oa<m4`0701<C4`0C00044`0301<C00<081<93@dC1P0>4`80KA<304HC000b4`0301<C0?lC

=a<300<C00L04a<C01<000@C0`0S4`T=4Q<600TC00<04a<0KQ<204DC000b4`0301<C0?lC?A<01`0C

4a<04`000a<202HC1PdI4`D011<00`0C4`1`4`80A1<001`C00<04a<00Q<00`0C4`024`0301<C008C

00<04a<011<00`0C4`3o4cdC00L04a<C01<0008C00<04`00:A<00`dC4`0N4`D0M1<2048C000K4`03

01<000PC00L04a<C01<000DC00<04a<0oa<l4`8011<0100C00024`0301<C04/C1P1a4`80@A<001HC

0`024`0301<000PC00<04a<00a<00`0C4`034`80oa=34`8011<00`0C4`1:4`0301<C00@C101^4`80

@1<001/C00<04`002A<00`0C4`0200HC00<04a<0oa=14`0301<C00@C00<04a<0BA<00`0C4`094`@0

Ja<00`0C4`0n4`006a<00`0C00074`0301<0008C00<04a<01A<00`0C4`3o4d0C00<04a<01A<204XC

00<04a<03A<406PC0P0n4`0071<00`0C4`064`<00Q<300DC00<04a<0oa<o4`0301<C00HC00<04a<0

B1<00`0C4`0B4`@0IA<00`0C4`0l4`00<Q<00`0C4`3o4chC00<04a<01a<00`0C4`184`0301<C01DC

1@1R4`0301<C03/C000b4`0301<C0?lC?A<00`0C4`084`0301<C04LC00<04a<06Q<405lC0P0l4`00

<Q<00`0C4`3o4c`C00<04a<02A<00`0C4`164`0301<C01lC101L4`80>a<0038C00<04a<0oa<k4`03

01<C00XC00<04a<0AQ<00`0C4`0R4`D0FA<00`0C4`0i4`00<Q<00`0C4`3o4cXC00<04a<02a<204LC

00<04a<09Q<405LC00<04a<0>1<0038C00<04a<0oa<i4`0301<C00`C00<04a<0AA<00`0C4`0Z4`@0

E1<203TC000b4`0301<C0?lC>A<00`0C4`0<4`0301<C04DC00<04a<0;Q<4054C00<04a<0=a<0038C

00<04a<0oa<h4`0301<C00dC00<04a<0A1<00`0C4`0c4`80Ca<203PC000b4`0301<C0?lC=a<00`0C

4`0>4`0301<C04@C00<04a<0=A<404`C0P0g4`00<Q<00`0C4`3o4cHC00<04a<03a<00`0C4`144`03

01<C03TC0P1;4`0301<C03DC000b4`0301<C0?lC=Q<00`0C4`0?4`80A1<00`0C4`0l4`@0Aa<203HC

000b4`0301<C0?lC=A<00`0C4`0@4`0301<C04<C00<04a<0?a<304HC00<04a<0=1<0038C00<04a<0

oa<e4`0301<C010C00<04a<0@a<00`0C4`124`<0@a<203DC000Q4`0301<C008C00<04a<00Q<00`0C

4`044`0301<C0?lC=1<00`0C4`0A4`0301<C048C00<04a<0AQ<3044C00<04a<0<a<0020C00<04`00

1a<00`0C00054`0301<C0?lC=1<00`0C4`0A4`0301<C048C00<04a<0BA<203lC00<04a<0<a<001/C

0`024`0301<000TC00<04a<00a<20?lC=1<00`0C4`0B4`0301<C048C00<04a<0Ba<303dC00<04a<0

<Q<0020C00<04`001a<200HC00<04a<0oa<c4`0301<C018C0P134`0301<C04hC0P0k4`0301<C038C

000P4`0301<000LC00<04a<01A<00`0C4`3o4c8C00<04a<04a<00`0C4`114`0301<C054C0`0h4`03

01<C038C000Q4`0301<C00HC0`054`0301<C0?lC<Q<00`0C4`0C4`0301<C044C00<04a<0E1<203LC

00<04a<0<A<0038C00<04a<0oa<a4`0301<C01@C00<04a<0@A<00`0C4`1F4`<0=1<00`0C4`0a4`00

<Q<00`0C4`3o4c4C00<04a<03Q<00`0C4`034`0301<C040C00<04a<0FA<3038C0P0b4`00<Q<00`0C

4`3o4c0C00<04a<03Q<00`0C00044`0301<C040C00<04a<0G1<2034C00<04a<0<1<0038C00<04a<0

oa<`4`0301<C00TC0`044`0301<C008C0`104`0301<C05hC0P0_4`0301<C030C000b4`0301<C0?lC

<1<00`0C4`0>4`801A<00`0C4`0o4`0301<C064C0`0/4`0301<C030C000b4`0301<C0?lC<1<00`0C

4`0>4`0301<C00@C00<04a<0?a<00`0C4`1T4`0301<C02TC00<04a<0<1<0038C00<04a<0oa<_4`03

01<C00lC0`044`0301<C03lC00<04a<0IA<302PC0P0a4`00<Q<00`0C4`3o4blC00<04a<05Q<00`0C

4`0o4`0301<C06PC00<04a<09Q<00`0C4`0_4`00<Q<00`0C4`3o4blC00<04a<05Q<00`0C4`0o4`03

01<C06TC0`0U4`0301<C02lC000b4`0301<C0?lC;a<00`0C4`0F4`80@1<00`0C4`1/4`808a<00`0C

4`0_4`00<Q<00`0C4`3o4blC00<04a<05Q<00`0C4`0o4`0301<C06dC0P0R4`0301<C02lC000b4`03

01<C0?lC;a<00`0C4`0F4`0301<C03lC00<04a<0Ka<2020C00<04a<0;a<0038C00<04a<0oa<^4`03

01<C01LC00<04a<0?Q<00`0C4`1b4`807Q<00`0C4`0_4`0071<00`0C4`024`0401<C4`<00a<00`0C

4`044`0301<C0?lC;Q<00`0C4`0G4`0301<C03hC00<04a<0M1<201`C00<04a<0;a<001/C00<04`00

1a<00`0C4`024`0301<000DC00<04a<0oa<^4`0301<C01LC0P0o4`0301<C07HC0P0J4`0301<C02lC

000F4`<00Q<00`0C00084`0301<C00<C00<04a<00a<20?lC;a<00`0C4`0G4`0301<C03hC00<04a<0

N1<00`0C4`0F4`0301<C030C000K4`0301<000PC00@04a<C0P064`0301<C0?lC;A<00`0C4`0H4`03

01<C03hC00<04a<0NA<201HC00<04a<0<1<001/C00<04`001a<00`0C00024`0301<C00DC00<04a<0

oa<]4`0301<C01PC00<04a<0?Q<00`0C4`1k4`0301<C01<C00<04a<0<1<001`C00<04a<01a<0100C

4a<300DC00<04a<0oa<]4`0301<C01PC00<04a<0?Q<00`0C4`1l4`0301<C018C00<04a<0<1<0038C

00<04a<0oa<]4`0301<C01PC00<04a<0?A<00`0C4`1n4`804Q<00`0C4`0`4`00<Q<00`0C4`3o4bdC

00<04a<061<203hC00<04a<0P1<2010C00<04a<0<1<0038C00<04a<0oa<]4`0301<C01PC00<04a<0

8A<5008C00<04a<04Q<00`0C4`0;4`D000<C00008A<5008C00<04a<07a<5008C00<04a<06a<0100C

4a<500034`0000<C00<04a<0<A<0038C00<04a<0oa<]4`0301<C01PC00<04a<08a<01`0C4a<04`00

4a<00`0C4`0=4`0701<C4`0C000R4`0301<C008C00<04a<08A<01`0C4a<04`0071<200@C00<04a<0

0a<0100C4`0c4`00<Q<00`0C4`0V4`0301<C008C00@04a<C0`0S4`0301<C008C00<04a<00Q<3028C

00<04a<00Q<0100C4a<202@C00<04a<00Q<00`0C4`024`0301<C02HC1@114`0301<C01PC00<04a<0

8a<00`0C4`034`0301<C014C00<04a<03A<01`0C4a<04`008Q<00`0C4`024`0301<C024C00L04a<C

01<001hC00D04a<C00044`800Q<00`0C4`0a4`00<Q<00`0C4`0U4`0301<000LC00<04a<08Q<00`0C

00094`0301<C020C00<04`001a<00`0C000R4`0301<000LC00<04`00:A<00`0C4`114`0301<C01PC

00<04a<08a<0100C4a<201@C00<04a<03A<0100C4a<202<C00<04a<00a<00`0C4`0P4`0301<C008C

00<04a<07Q<200034`0C008C00<04`000Q<00`0C4`0a4`00<Q<00`0C4`0U4`0301<000PC00<04a<0

8A<00`0C00074`@08A<00`0C00074`0301<0028C00<04`001a<00`0C000Y4`0301<C040C00<04a<0

6A<00`0C4`0S4`0501<C4`005A<00`0C4`0=4`0501<C4`0091<01`0C4a<04`008Q<01`0C4a<04`00

8A<200<C00D04`0C000d4`00<Q<00`0C4`0U4`0301<000PC00<04a<08A<00`0C00074`0301<0028C

00<04`001a<202<C00<04`0021<00`0C4`0X4`0301<C040C00<04a<06A<202<C0P034`<04a<00`0C

4`0<4`8011<2024C0P034`<08A<200@C00<04a<081<200@C0P000a<04`0c4`00<Q<00`0C4`0U4`03

01<000LC00<04`008Q<00`0C00084`808Q<00`0C00074`0301<C028C00<04`001a<00`0C000Y4`03

01<C040C00<04a<06A<00`0C4`0m4`0301<C08PC00<04a<01A<00`0C4`0b4`00<Q<00`0C4`0V4`03

01<C00LC00<04a<08Q<00`0C4`084`0301<C024C00<04a<01a<202<C00<04a<01a<00`0C4`0W4`80

@Q<00`0C4`0I4`0301<C03dC00<04a<0RA<200DC00<04a<0<Q<0038C00<04a<0oa</4`0301<C01TC

00<04a<0?A<00`0C4`2;4`0501<C4`00=A<0038C00<04a<0oa</4`0301<C01TC00<04a<0?A<00`0C

4`2;4`0401<C01<C100O4`00<Q<00`0C4`3o4b`C00<04a<06A<00`0C4`0m4`0301<C08`C0P0D4`<0

81<0038C00<04a<0^Q<D3BTC0`0[4ol02Q<00`0C4`0N4`00<Q<00`0C4`2b4`P=51<:3B0C00<04a<0

:a<00`0C4`024`0401<C00PC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`03

01<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<00a<00`0C00074`0301<C00HC00<04a<0

1A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`03

01<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC0`064`03

01<C00`C0P0P4`00;1>g00@=9P0A3@H02A<00`0C4`0`4`0301<C01TC00<04a<09Q<00`0C4`0D4`03

01<C010C00<04a<09Q<00`0C4`0V4`0301<C02HC00@04a<0=Q<0038C00<04a<021<00`0C4`094`03

01<C00TC00<04a<02A<00`0C4`084`0301<C00TC00<04a<02A<00`0C4`094`0301<C00PC00<04a<0

2A<00`0C4`094`0301<C00TC00<04a<02A<00`0C4`084`0301<C00PC0Pd;4`0301<C00TC00<04a<0

21<00`0C4`094`0301<C00TC00<04a<031<4030C00<04a<06A<00`0C4`0m4`0301<C08/C00D04a<C

000e4`00<Q<00`0C4`0/4`0301<C02`C00<04a<0;1<00`0C4`0K4`@=3A<00`0C4`0/4`0301<C040C

00<04a<06A<00`0C4`0m4`0301<C08XC00<04a<00Q<00`0C4`0c4`00<Q<00`0C4`2T4`@=Pa<00`0C

4`0I4`0301<C03dC00<04a<0RA<00`0C4`044`0301<C038C000b4`0301<C0:4C0`f74`0301<C01TC

0P0n4`0301<C08LC0P074`0301<C038C000b4`0301<C09dC10f:4`0301<C01TC00<04a<0?A<00`0C

4`274`0301<C00HC00<04a<0<Q<0038C00<04a<0Da<?3CLC10f?4`0301<C01PC00<04a<0?A<00`0C

4`264`0301<C00PC00<04a<0<A<0038C00<04a<0Ba<83@lC2PdX4`D=Ta<00`0C4`0H4`0301<C03dC

00<04a<0Q1<200/C00<04a<0<A<0038C00<04a<0B1<33B4C1@dN4`D=V1<00`0C4`0H4`0301<C03dC

00<04a<0Pa<00`0C4`0;4`0301<C034C000b4`0301<C04DC0`dY4`T=4A<43IdC00<04a<061<00`0C

4`0m4`0301<C088C00<04a<031<00`0C4`0a4`00<Q<00`0C4`124`<==A<A3J4C00<04a<061<203hC

00<04a<0P1<200lC00<04a<0<A<0038C00<04a<0@1<23NXC00<04a<061<00`0C4`0m4`0301<C07lC

00<04a<041<00`0C4`0`4`00<Q<00`0C4`0n4`8=k1<00`0C4`0H4`0301<C03hC00<04a<0O1<201<C

00<04a<0<1<0038C00<04a<0>a<33NhC00<04a<061<00`0C4`0n4`0301<C07/C0P0D4`0301<C030C

000b4`0301<C03TC0Pga4`0301<C01PC00<04a<0?Q<00`0C4`1i4`805Q<00`0C4`0`4`00<Q<00`0C

4`0g4`8=la<00`0C4`0H4`0301<C03hC00<04a<0N1<00`0C4`0F4`0301<C030C000b4`0301<C03DC

0Pgf4`0301<C01LC0P0o4`0301<C07HC0P0I4`0301<C030C000b4`0301<C03<C0Pgh4`0301<C01LC

00<04a<0?Q<00`0C4`1d4`8071<00`0C4`0_4`0071<00`0C4`024`0401<C4`<00a<00`0C4`044`03

01<C034C0Pgj4`0301<C01LC00<04a<0?Q<00`0C4`1c4`0301<C01`C00<04a<0;a<001/C00<04`00

1a<00`0C4`024`0301<000DC00<04a<0;a<23O`C00<04a<05a<00`0C4`0o4`0301<C070C0P0O4`03

01<C02lC000K4`0301<000PC00<04a<00a<00`0C4`034`80;a<00`dC4`3m4`0301<C01HC00<04a<0

?a<00`0C4`1]4`<08A<00`0C4`0_4`006a<00`0C00084`0401<C4`801Q<00`0C4`0/4`8=oa<14`03

01<C01HC00<04a<0?a<00`0C4`1/4`808a<00`0C4`0_4`006a<00`0C00074`0301<0008C00<04a<0

1A<00`0C4`0Z4`8=oa<34`0301<C01HC0P104`0301<C06XC0P0U4`0301<C02lC000L4`0301<C00LC

00@04a<C0`054`0301<C02PC0Pgo4`DC00<04a<05Q<00`0C4`0o4`0301<C06PC0P0W4`0301<C02lC

000b4`0301<C02HC0Pgo4`LC00<04a<05Q<00`0C4`0o4`0301<C06HC0P0Y4`0301<C02lC000b4`03

01<C02<C0`go4`XC00<04a<05A<00`0C4`0o4`0301<C06@C0P0Z4`0301<C030C000b4`0301<C024C

0Pgo4`dC00<04a<03a<00`0C4`034`0301<C03lC00<04a<0HQ<202`C00<04a<0<1<0038C00<04a<0

7Q<33OlC3a<00`0C4`0>4`0301<000@C00<04a<0@1<00`0C4`1N4`<0;Q<00`0C4`0`4`00<Q<00`0C

4`0L4`8=oa<B4`0301<C010C00<04a<00Q<3040C00<04a<0G1<3030C00<04a<0<1<0038C00<04a<0

6A<33OlC5A<00`0C4`0=4`801A<00`0C4`104`0301<C05XC0P0b4`80<Q<0038C00<04a<05Q<33OlC

61<00`0C4`0=4`0301<C00@C00<04a<0@A<00`0C4`1G4`80=1<00`0C4`0a4`00<Q<00`0C4`0B4`@=

oa<L4`0301<C00`C0`044`0301<C044C00<04a<0E1<303HC00<04a<0<A<0038C00<04a<03Q<43OlC

81<00`0C4`0C4`0301<C044C00<04a<0DQ<303LC0P0c4`00<Q<00`0C4`0;4`<=oa<U4`0301<C018C

0P124`0301<C04lC0`0j4`0301<C038C000b4`0301<C00HC1@go4bPC00<04a<04Q<00`0C4`124`03

01<C04`C0`0l4`0301<C038C000b4`T=oa<^4`0301<C014C00<04a<0@Q<00`0C4`194`<0?Q<00`0C

4`0c4`00<Q<00`0C4`3o4c@C00<04a<04A<00`0C4`124`0301<C04LC0`104`0301<C03<C000Q4`03

01<C008C00<04a<00Q<00`0C4`044`0301<C0?lC=A<00`0C4`0@4`0301<C048C00<04a<0A1<3048C

0P0e4`0081<00`0C00074`0301<000DC00<04a<0oa<e4`0301<C010C00<04a<0@a<00`0C4`104`<0

AA<00`0C4`0d4`0081<00`0C00094`0301<C00<C0P3o4cLC00<04a<03a<204@C00<04a<0?A<304LC

0P0f4`0081<00`0C00074`801Q<00`0C4`3o4cHC00<04a<03a<00`0C4`144`0301<C03TC0`1:4`03

01<C03DC000P4`0301<000LC00<04a<01A<00`0C4`3o4cLC00<04a<03Q<00`0C4`144`0301<C03HC

101;4`80=a<0024C00<04a<01Q<300DC00<04a<0oa<h4`0301<C00dC00<04a<0A1<00`0C4`0c4`<0

Ca<00`0C4`0f4`00<Q<00`0C4`3o4cTC00<04a<031<00`0C4`154`0301<C02lC0`1A4`0301<C03LC

000b4`0301<C0?lC>A<00`0C4`0<4`0301<C04DC00<04a<0:a<405<C0P0i4`00<Q<00`0C4`3o4cXC

00<04a<02a<204LC00<04a<09a<405HC00<04a<0>1<0038C00<04a<0oa<j4`0301<C00/C00<04a<0

AQ<00`0C4`0S4`D0F1<203XC000b4`0301<C0?lC>a<200/C00<04a<0AQ<00`0C4`0P4`@0Fa<203/C

000b4`0301<C0?lC?A<00`0C4`084`0301<C04LC00<04a<06a<405lC00<04a<0>Q<0038C00<04a<0

oa<n4`0301<C00LC00<04a<0Aa<201PC1@1Q4`0301<C03/C000b4`0301<C0?lC?Q<00`0C4`074`03

01<C04PC00<04a<04a<406@C0P0m4`00<Q<00`0C4`3o4clC00<04a<01Q<204XC00<04a<03Q<406LC

0P0n4`00<Q<00`0C4`3o4d0C0P064`0301<C04TC00<04a<02Q<406XC0P0o4`00<Q<00`0C4`3o4d8C

00<04a<00a<00`0C4`1:4`0301<C00DC1@1/4`80@1<0038C00<04a<0oa=34`800a<00`0C4`1:4`80

00<C00000`1`4`80@A<0038C00<04a<0oa<k4`D00Q<0100C4`024`0301<C04TC1@1c4`80@Q<001`C

00<04a<00Q<00`0C4`024`0301<C008C00<04a<011<00`0C4`3o4cdC00L04a<C01<0008C0`174`D0

0Q<00`0C4`1a4`80@a<001/C00<04`0021<01`0C4a<04`001A<00`0C4`3o4cdC00L04a<C01<000@C

0`104`D021<00`0C4`1^4`80AA<001/C00<04`0021<00`0C4`034`0301<C00<C0P3o4chC00L04a<C

01<000@C00@04`00>Q<500dC00<04a<0KA<204HC000K4`0301<000TC00<04a<00P064`0301<C0?lC

?A<01`0C4a<04`0011<0100C4a<3034C1P0C4`80Ja<304LC000K4`0301<000LC00<04`000Q<00`0C

4`054`0301<C0?lC?1<200@C00<04a<00a<00`0C4`044`<0:1<701TC0P1Y4`80BA<001`C00<04a<0

1Q<3008C0`054`0301<C0?lCB1<00`0C4`074`D06a<9020C00<04a<0I1<304/C000b4`0301<C0?lC

B1<00`0C4`0<4a`0:A<2068C0`1=4`00<Q<00`0C4`3o4dPC0P1C4`80Ga<304lC000b4`0301<C0?lC

B1<00`0C4`1C4`80FQ<4058C000b4`0301<C0?lCB1<00`0C4`1D4`80EQ<405DC000b4`0301<C0?lC

B1<00`0C4`1F4`80Ca<505TC000b4`0301<C0?lCB1<00`0C4`1G4`<0B1<605dC000b4`0301<C0?lC

B1<00`0C4`1I4`<0@1<7068C000b4`0301<C0?lCB1<205`C0`0h4`L0J1<0038C00<04a<0oa=84`03

01<C05hC0`0^4`P0KQ<0038C00<04a<0oa=84`0301<C060C1@0S4`P0MA<0038C00<04a<0oa=84`03

01<C06@C1`0D4`X0O1<0038C00<04a<0oa=84`0301<C06XC5@264`00<Q<00`0C4`3o4dPC00<04a<0

oa<64`00:A<500@C00<04a<0oa=84`80oa<74`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`3o4`HC

000[4`0301<C00@C0P3o4dTC00<04a<0oa<64`00:a<00`0C4`3o4olCF1<002/C00<04a<0oa?o4ePC

000Z4`80oa?o4eXC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00U1<40003

4`0000L00Q<00`0C4`024`0301<C008C00<04a<00Q<30?lCca<009@C0`084`0701<C4`0C00074`03

01<000@C00<04a<0`a<20?lC2A<009HC00<04a<010024`0301<C00<C00<04a<01A<00`0C00024`@0

aA<00`0C4`3o4`LC000I4`@000<C00001P024`X00Q<2008C0`024`<00a<200064`0001<0BQ<200PC

00@04a<C0P084`0301<0008C00<04`00a1<3008C00<04a<0oa<44`006Q<01P0C4`0C008C00<04`00

11<01P0C4`0C008C00<04`001A<00`0C4`024`0501<C4`000Q<0100C01<205@C00D04a<C00094`03

01<000<C0P044`0301<C0;`C00P04a<04`0C0?lC1A<001XC00H04a<04`044`0301<C008C00<04a<0

0Q<00`0C4`024`0301<C00<C00<04a<00Q<01@0C4a<0008C00@04`0C0P1C4`800a<300PC00<04a<0

0a<01@0C4a<00;lC00P04a<04`0C0?lC1A<001XC00D04a<04`0200<C0P034`0301<C008C0P034`03

01<C00<C00<04a<00Q<01@0C4a<0008C00H04`004`3o4blC0`0011<04`3o4`DC000J4`0601<C01<0

0Q<00`0C00024`0301<000@C00h04a<04`0C01<04`0C008C00D04a<C00024`0601<001<0oa<c4`03

01<00?lC1A<001TC10000a<0000;008C1@001A<0000C00D000@C00000a<200044`004`80oa<d4`03

01<C0?lC11<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4olCQQ<00001\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.77084, -14.119, 0.0242408, 0.16996}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -57 0 ]

[.5 .63053 57 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -118 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(14.4199999999999883`) show

173.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .42026 m

.02499 .42025 L

.02606 .42025 L

.02729 .42023 L

.02846 .42022 L

.03053 .42017 L

.03279 .42011 L

.03527 .42001 L

.0379 .41989 L

.04262 .4196 L

.04749 .41922 L

.05205 .41879 L

.06245 .41752 L

.07305 .41584 L

.08274 .41397 L

.10458 .40863 L

.14429 .39554 L

.18248 .38007 L

.22313 .36264 L

.26226 .34727 L

.28223 .34069 L

.30384 .33489 L

.31399 .3327 L

.32471 .33077 L

.33386 .32945 L

.34391 .32835 L

.34915 .32791 L

.35411 .32759 L

.35857 .32737 L

.36109 .32728 L

.36342 .32721 L

.36461 .32718 L

.3659 .32715 L

.36702 .32714 L

.36824 .32712 L

.36894 .32711 L

.36959 .32711 L

.37028 .32711 L

.37101 .3271 L

.3717 .3271 L

.37234 .32711 L

.37356 .32711 L

.37486 .32712 L

.37552 .32713 L

.37625 .32714 L

.37873 .32718 L

.38012 .32722 L

.38162 .32726 L

.38433 .32735 L

.38959 .32759 L

Mistroke

.39446 .32787 L

.4055 .32872 L

.42561 .33087 L

.46479 .33622 L

.4848 .33887 L

.49532 .34009 L

.50642 .34119 L

.5164 .34197 L

.52206 .34232 L

.52733 .34257 L

.52983 .34267 L

.53219 .34275 L

.53433 .3428 L

.53661 .34285 L

.53779 .34287 L

.53908 .34289 L

.54026 .3429 L

.54137 .34291 L

.54267 .34292 L

.54386 .34292 L

.54517 .34291 L

.54582 .34291 L

.54654 .3429 L

.54787 .34289 L

.54909 .34287 L

.55184 .34282 L

.55427 .34276 L

.55684 .34267 L

.5613 .34248 L

.56619 .3422 L

.57703 .34136 L

.58715 .34027 L

.60748 .33729 L

.62603 .33376 L

.66584 .3244 L

.70414 .31481 L

.7235 .3104 L

.74489 .30623 L

.75462 .30464 L

.76512 .30316 L

.77496 .30202 L

.78412 .30117 L

.79368 .3005 L

.79874 .30024 L

.80414 .30002 L

.80687 .29994 L

.80982 .29987 L

.81118 .29985 L

.81261 .29983 L

.81384 .29981 L

Mistroke

.81453 .29981 L

.81519 .2998 L

.81649 .29979 L

.81769 .29979 L

.81897 .29979 L

.8197 .29979 L

.82038 .29979 L

.82161 .2998 L

.82273 .2998 L

.82402 .29982 L

.82523 .29983 L

.82764 .29987 L

.82989 .29992 L

.83501 .30006 L

.83999 .30024 L

.84533 .30048 L

.8638 .30164 L

.90518 .30519 L

.9259 .30691 L

.935 .30756 L

.94505 .30816 L

.95284 .30852 L

.96015 .30878 L

.96418 .30888 L

.96787 .30895 L

.96981 .30898 L

.97193 .309 L

.97299 .30901 L

.97414 .30901 L

.97521 .30902 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.20325 .05857 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4gdC00<04a<0oa<64`00oa=m4`0301<C0?lC1Q<002TC1@3o4dlC0P3o4`LC

000[4`0301<C0?lCCa<00`0C4`1^4`d0RQ<002DC0`034`0301<C00@C0P3o4dTC00<04a<0IQ<800`C

3@1n4`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`1Q4`D081<807LC000[4`0301<C00@C00<04a<0

oa=84`0301<C05hC100/4`L0L1<002XC0P064`0301<C0?lCB1<00`0C4`1L4`<0=A<706XC000b4`03

01<C0?lCB1<205/C0P0o4`H0I1<0038C00<04a<0oa=84`0301<C05PC0P164`H0Ga<0038C00<04a<0

oa=84`0301<C00hC00<=4a<0AA<204hC1@1J4`00<Q<00`0C4`3o4dPC00<04a<02a<63D@C0P1C4`D0

EQ<0038C00<04a<0oa=84`0301<C00XC2@e14`0301<C05LC1@1B4`00<Q<00`0C4`3o4dPC0P0;4`T=

?a<205hC0`1@4`00<Q<00`0C4`3o4dPC00<04a<02Q<93A80;1<2064C101=4`00<Q<00`0C4`3o4dPC

00<04a<02A<;3A4C2@0R4`80IA<304/C000b4`0301<C0?lCB1<00`0C4`054`D02@dJ4`L06a<206PC

0`194`00<Q<00`0C4`3o4c/C1@024`0301<C00<C00<04a<00a<200DC2@dQ4`H051<206/C0P184`00

<Q<00`0C4`3o4cdC00L04a<C01<000@C00<04a<00`074`T=9Q<600hC0P1]4`<0AQ<0038C00<04a<0

oa<g4`<00a<01`0C4a<04`0011<300/C1Pd]4`H02A<00`0C4`1^4`80AA<0038C00<04a<0oa<m4`07

01<C4`0C00034`8041<00`dC4`0b4`D011<00`0C4`1`4`80A1<001`C00<04a<00Q<00`0C4`024`03

01<C008C00<04a<011<00`0C4`3o4cdC00L04a<C01<0008C00<04`00BQ<507@C0P124`006a<00`0C

00084`0701<C4`0C00054`0301<C0?lC?1<200@C00@04`000Q<00`0C4`1;4`H0LA<2044C000F4`<0

0Q<00`0C00084`0301<C00<C00<04a<00a<20?lC@a<200@C00<04a<0BQ<00`0C4`044`@0KQ<2040C

000K4`0301<000TC00<04a<00P064`0301<C0?lC@A<00`0C4`044`0301<C04TC00<04a<02A<406/C

00<04a<0?Q<001/C00<04`001a<00`0C00024`0301<C00DC00<04a<0oa=04`0301<C00DC0P1:4`03

01<C00dC101X4`80?Q<001`C00<04a<01Q<3008C0`054`0301<C0?lC?a<00`0C4`064`0301<C04PC

00<04a<04Q<406DC00<04a<0?1<0038C00<04a<0oa<n4`0301<C00LC00<04a<0B1<00`0C4`0E4`D0

HQ<00`0C4`0k4`00<Q<00`0C4`3o4cdC00<04a<021<00`0C4`174`0301<C01XC101O4`80?1<0038C

00<04a<0oa<l4`0301<C00TC00<04a<0AQ<00`0C4`0O4`@0G1<203/C000b4`0301<C0?lC>a<00`0C

4`0:4`0301<C04HC00<04a<08Q<505TC00<04a<0>A<0038C00<04a<0oa<j4`0301<C00/C0P174`03

01<C02HC101G4`0301<C03PC000b4`0301<C0?lC>A<00`0C4`0<4`0301<C04DC00<04a<0:Q<405@C

0P0i4`00<Q<00`0C4`3o4cTC00<04a<031<00`0C4`154`0301<C02hC101A4`0301<C03LC000b4`03

01<C0?lC>1<00`0C4`0=4`0301<C04@C00<04a<0<a<204lC0P0h4`00<Q<00`0C4`3o4cLC00<04a<0

3Q<00`0C4`144`0301<C03DC101<4`80=a<0038C00<04a<0oa<f4`0301<C00lC00<04a<0A1<00`0C

4`0i4`80Ba<00`0C4`0e4`00<Q<00`0C4`3o4cHC00<04a<03a<204@C00<04a<0?1<404LC0P0f4`00

<Q<00`0C4`3o4cDC00<04a<041<00`0C4`134`0301<C03lC0`164`0301<C03@C000b4`0301<C0?lC

=A<00`0C4`0@4`0301<C04<C00<04a<0@Q<304<C0P0e4`008A<00`0C4`024`0301<C008C00<04a<0

11<00`0C4`3o4c@C00<04a<04A<00`0C4`124`0301<C04HC0`114`0301<C03<C000P4`0301<000LC

00<04`001A<00`0C4`3o4c@C00<04a<04A<00`0C4`124`0301<C04TC0P0o4`0301<C03<C000K4`<0

0Q<00`0C00094`0301<C00<C0P3o4c@C00<04a<04Q<00`0C4`124`0301<C04/C0`0m4`0301<C038C

000P4`0301<000LC0P064`0301<C0?lC<a<00`0C4`0B4`80@a<00`0C4`1>4`80>a<00`0C4`0b4`00

81<00`0C00074`0301<C00DC00<04a<0oa<b4`0301<C01<C00<04a<0@A<00`0C4`1A4`<0>1<00`0C

4`0b4`008A<00`0C4`064`<01A<00`0C4`3o4c8C00<04a<04a<00`0C4`114`0301<C05@C0P0g4`03

01<C034C000b4`0301<C0?lC<A<00`0C4`0D4`0301<C044C00<04a<0EQ<303@C00<04a<0<A<0038C

00<04a<0oa<a4`0301<C00hC00<04a<00a<00`0C4`104`0301<C05TC0`0b4`80<Q<0038C00<04a<0

oa<`4`0301<C00hC00<04`0011<00`0C4`104`0301<C05`C0P0a4`0301<C030C000b4`0301<C0?lC

<1<00`0C4`094`<011<00`0C4`024`<0@1<00`0C4`1N4`80;a<00`0C4`0`4`00<Q<00`0C4`3o4c0C

00<04a<03Q<200DC00<04a<0?a<00`0C4`1Q4`<0;1<00`0C4`0`4`00<Q<00`0C4`3o4c0C00<04a<0

3Q<00`0C4`044`0301<C03lC00<04a<0I1<00`0C4`0Y4`0301<C030C000b4`0301<C0?lC;a<00`0C

4`0?4`<011<00`0C4`0o4`0301<C06DC0`0X4`80<A<0038C00<04a<0oa<_4`0301<C01HC00<04a<0

?a<00`0C4`1X4`0301<C02HC00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC00<04a<0?a<00`0C

4`1Y4`<09A<00`0C4`0_4`00<Q<00`0C4`3o4blC00<04a<05Q<2040C00<04a<0K1<202<C00<04a<0

;a<0038C00<04a<0oa<_4`0301<C01HC00<04a<0?a<00`0C4`1]4`808Q<00`0C4`0_4`00<Q<00`0C

4`3o4blC00<04a<05Q<00`0C4`0o4`0301<C06lC0P0P4`0301<C02lC000b4`0301<C0?lC;Q<00`0C

4`0G4`0301<C03hC00<04a<0LQ<201hC00<04a<0;a<001`C00<04a<00Q<0100C4a<300<C00<04a<0

11<00`0C4`3o4bhC00<04a<05a<00`0C4`0n4`0301<C07@C0P0L4`0301<C02lC000K4`0301<000LC

00<04a<00Q<00`0C00054`0301<C0?lC;Q<00`0C4`0G4`80?a<00`0C4`1f4`806Q<00`0C4`0_4`00

5Q<3008C00<04`0021<00`0C4`034`0301<C00<C0P3o4blC00<04a<05a<00`0C4`0n4`0301<C07PC

00<04a<05Q<00`0C4`0`4`006a<00`0C00084`0401<C4`801Q<00`0C4`3o4bdC00<04a<061<00`0C

4`0n4`0301<C07TC0P0F4`0301<C030C000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C0?lC

;A<00`0C4`0H4`0301<C03hC00<04a<0Na<00`0C4`0C4`0301<C030C000L4`0301<C00LC00@04a<C

0`054`0301<C0?lC;A<00`0C4`0H4`0301<C03hC00<04a<0O1<00`0C4`0B4`0301<C030C000b4`03

01<C0?lC;A<00`0C4`0H4`0301<C03dC00<04a<0OQ<2018C00<04a<0<1<0038C00<04a<0oa<]4`03

01<C01PC0P0n4`0301<C080C0P0@4`0301<C030C000b4`0301<C0?lC;A<00`0C4`0H4`0301<C024C

1@024`0301<C018C00<04a<02a<500034`00024C1@024`0301<C01lC1@024`0301<C01/C00@04a<C

1@000a<000034`0301<C034C000b4`0301<C0?lC;A<00`0C4`0H4`0301<C02<C00L04a<C01<001<C

00<04a<03A<01`0C4a<04`008Q<00`0C4`024`0301<C024C00L04a<C01<001`C0P044`0301<C00<C

00@04a<0<a<0038C00<04a<09Q<00`0C4`024`0401<C4`<08a<00`0C4`024`0301<C008C0`0R4`03

01<C008C00@04a<C0P0T4`0301<C008C00<04a<00Q<00`0C4`0V4`D0@A<00`0C4`0H4`0301<C02<C

00<04a<00a<00`0C4`0A4`0301<C00dC00L04a<C01<0028C00<04a<00Q<00`0C4`0Q4`0701<C4`0C

000N4`0501<C4`0011<2008C00<04a<0<A<0038C00<04a<09A<00`0C00074`0301<C028C00<04`00

2A<00`0C4`0P4`0301<000LC00<04`008Q<00`0C00074`0301<002TC00<04a<0@A<00`0C4`0H4`03

01<C02<C00@04a<C0P0D4`0301<C00dC00@04a<C0P0S4`0301<C00<C00<04a<081<00`0C4`024`03

01<C01hC0P000a<04`024`0301<0008C00<04a<0<A<0038C00<04a<09A<00`0C00084`0301<C024C

00<04`001a<4024C00<04`001a<00`0C000R4`0301<000LC00<04`00:A<00`0C4`104`0301<C01TC

00<04a<08a<01@0C4a<001DC00<04a<03A<01@0C4a<002@C00L04a<C01<0028C00L04a<C01<0024C

0P034`0501<04`00=1<0038C00<04a<09A<00`0C00084`0301<C024C00<04`001a<00`0C000R4`03

01<000LC0P0S4`0301<000PC00<04a<0:1<00`0C4`104`0301<C01TC0P0S4`800a<301<C00<04a<0

31<200@C0P0Q4`800a<3024C0P044`0301<C020C0P044`8000<C01<0<a<0038C00<04a<09A<00`0C

00074`0301<0028C00<04`0021<2028C00<04`001a<00`0C4`0R4`0301<000LC00<04`00:A<00`0C

4`104`0301<C01TC00<04a<0?A<00`0C4`284`0301<C00DC00<04a<0<Q<0038C00<04a<09Q<00`0C

4`074`0301<C028C00<04a<021<00`0C4`0Q4`0301<C00LC0P0S4`0301<C00LC00<04a<09a<2048C

00<04a<06A<00`0C4`0m4`0301<C08TC0P054`0301<C038C000b4`0301<C0?lC;1<00`0C4`0I4`03

01<C03dC00<04a<0Ra<01@0C4a<003DC000b4`0301<C0?lC;1<00`0C4`0I4`0301<C03dC00<04a<0

Ra<0100C4`0C4`@07a<0038C00<04a<0oa</4`0301<C01TC00<04a<0?A<00`0C4`2<4`8051<3020C

000b4`0301<C0;/C3`d]4`<0:a?o00XC00<04a<07Q<0038C00<04a<0/A<:3@lC1`dW4`0301<C02/C

00<04a<00Q<0100C4`084`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C

4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00<C00<04`001a<00`0C4`064`0301<C00DC

00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C

4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`<01Q<00`0C

4`0<4`8081<002`C]P043B0060d600TC00<04a<0<1<00`0C4`0I4`0301<C02HC00<04a<051<00`0C

4`0@4`0301<C02HC00<04a<09Q<00`0C4`0V4`0401<C03HC000b4`0301<C00PC00<04a<02A<00`0C

4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0C4`084`0301<C00TC

00<04a<02A<00`0C4`094`0301<C00TC00<04a<021<00`0C4`044`D=00<04a<02A<00`0C4`094`03

01<C00PC00<04a<02A<00`0C4`094`0301<C00`C100`4`0301<C01TC00<04a<0?A<00`0C4`2;4`05

01<C4`00=A<0038C00<04a<0;1<00`0C4`0/4`0301<C02`C00<04a<05Q<53A4C00<04a<0;1<00`0C

4`104`0301<C01TC00<04a<0?A<00`0C4`2:4`0301<C008C00<04a<0<a<0038C00<04a<0WQ<53HPC

00<04a<06A<00`0C4`0m4`0301<C08TC00<04a<011<00`0C4`0b4`00<Q<00`0C4`2J4`@=SA<00`0C

4`0I4`80?Q<00`0C4`274`801a<00`0C4`0b4`00<Q<00`0C4`1;4a<=>A<33I4C00<04a<06A<00`0C

4`0m4`0301<C08LC00<04a<01Q<00`0C4`0b4`00<Q<00`0C4`144`L=4a<73BhC10fE4`0301<C01PC

00<04a<0?A<00`0C4`264`0301<C00PC00<04a<0<A<0038C00<04a<0@1<43B4C20dN4`P=VA<00`0C

4`0H4`0301<C03dC00<04a<0Q1<200/C00<04a<0<A<0038C00<04a<0>a<53BdC20d@4`H=XA<00`0C

4`0H4`0301<C03dC00<04a<0Pa<00`0C4`0;4`0301<C034C000b4`0301<C03TC0Pdj4a0=Ya<00`0C

4`0H4`0301<C03dC00<04a<0PQ<00`0C4`0<4`0301<C034C000b4`0301<C03HC0`gc4`0301<C01PC

0P0n4`0301<C080C0P0?4`0301<C034C000b4`0301<C03@C0Pgf4`0301<C01PC00<04a<0?A<00`0C

4`1o4`0301<C010C00<04a<0<1<0038C00<04a<0<Q<23OPC00<04a<061<00`0C4`0n4`0301<C07`C

0P0C4`0301<C030C000b4`0301<C030C0Pgj4`0301<C01PC00<04a<0?Q<00`0C4`1k4`8051<00`0C

4`0`4`00<Q<00`0C4`0]4`<=o1<00`0C4`0H4`0301<C03hC00<04a<0NA<201HC00<04a<0<1<0038C

00<04a<0:a<23OlC00<04a<061<00`0C4`0n4`0301<C07PC00<04a<05Q<00`0C4`0`4`00<Q<00`0C

4`0X4`<=oa<34`0301<C01LC0P0o4`0301<C07HC0P0I4`0301<C030C000b4`0301<C02HC0Pgo4`HC

00<04a<05a<00`0C4`0n4`0301<C07@C0P0L4`0301<C02lC000L4`0301<C008C00@04a<C0`034`03

01<C00@C00<04a<08a<33OlC21<00`0C4`0G4`0301<C03hC00<04a<0La<00`0C4`0L4`0301<C02lC

000K4`0301<000LC00<04a<00Q<00`0C00054`0301<C024C0Pgo4`/C00<04a<05a<00`0C4`0o4`03

01<C070C0P0O4`0301<C02lC000K4`0301<000PC00<04a<00a<00`0C4`034`807a<33OlC3Q<00`0C

4`0F4`0301<C03lC00<04a<0KA<3024C00<04a<0;a<001/C00<04`0021<0100C4a<200HC00<04a<0

71<23OlC4A<00`0C4`0F4`0301<C03lC00<04a<0K1<202<C00<04a<0;a<001/C00<04`001a<00`0C

00024`0301<C00DC00<04a<06A<33OlC4a<00`0C4`0F4`80@1<00`0C4`1Z4`809A<00`0C4`0_4`00

71<00`0C4`074`0401<C4`<01A<00`0C4`0F4`<=oa<F4`0301<C01HC00<04a<0?a<00`0C4`1X4`80

9a<00`0C4`0_4`00<Q<00`0C4`0B4`@=oa<I4`0301<C01HC00<04a<0?a<00`0C4`1V4`80:A<00`0C

4`0_4`00<Q<00`0C4`0>4`@=oa<N4`0301<C01DC00<04a<0?a<00`0C4`1T4`80:Q<00`0C4`0`4`00

<Q<00`0C4`0;4`<=oa<R4`0301<C00lC00<04a<00a<00`0C4`0o4`0301<C068C0P0/4`0301<C030C

000b4`0301<C00HC1@go4bDC00<04a<03Q<00`0C00044`0301<C040C00<04a<0GQ<302hC00<04a<0

<1<0038C2@go4bXC00<04a<041<00`0C4`024`<0@1<00`0C4`1L4`<0<1<00`0C4`0`4`00<Q<00`0C

4`3o4c4C00<04a<03A<200DC00<04a<0@1<00`0C4`1J4`80<Q<2038C000b4`0301<C0?lC<A<00`0C

4`0=4`0301<C00@C00<04a<0@A<00`0C4`1G4`80=1<00`0C4`0a4`00<Q<00`0C4`3o4c8C00<04a<0

31<300@C00<04a<0@A<00`0C4`1D4`<0=Q<00`0C4`0a4`00<Q<00`0C4`3o4c8C00<04a<04a<00`0C

4`114`0301<C058C0`0g4`80<a<0038C00<04a<0oa<c4`0301<C018C0P124`0301<C04lC0`0j4`03

01<C038C000b4`0301<C0?lC<a<00`0C4`0B4`0301<C048C00<04a<0C1<303`C00<04a<0<Q<0038C

00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`194`<0?Q<00`0C4`0c4`00<Q<00`0C4`3o4c@C

00<04a<04A<00`0C4`124`0301<C04LC0`104`0301<C03<C000Q4`0301<C008C00<04a<00Q<00`0C

4`044`0301<C0?lC=A<00`0C4`0@4`0301<C048C00<04a<0A1<3048C0P0e4`0081<00`0C00074`03

01<000DC00<04a<0oa<e4`0301<C010C00<04a<0@a<00`0C4`104`<0AA<00`0C4`0d4`0081<00`0C

00094`0301<C00<C0P3o4cLC00<04a<03a<204@C00<04a<0?A<304LC0P0f4`0081<00`0C00074`80

1Q<00`0C4`3o4cHC00<04a<03a<00`0C4`144`0301<C03TC0`1:4`0301<C03DC000P4`0301<000LC

00<04a<01A<00`0C4`3o4cLC00<04a<03Q<00`0C4`144`0301<C03HC101;4`80=a<0024C00<04a<0

1Q<300DC00<04a<0oa<h4`0301<C00dC00<04a<0A1<00`0C4`0c4`<0Ca<00`0C4`0f4`00<Q<00`0C

4`3o4cTC00<04a<031<00`0C4`154`0301<C02lC0`1A4`0301<C03LC000b4`0301<C0?lC>A<00`0C

4`0<4`0301<C04DC00<04a<0:a<405<C0P0i4`00<Q<00`0C4`3o4cXC00<04a<02a<204LC00<04a<0

9a<405HC00<04a<0>1<0038C00<04a<0oa<j4`0301<C00/C00<04a<0AQ<00`0C4`0S4`D0F1<203XC

000b4`0301<C0?lC>a<200/C00<04a<0AQ<00`0C4`0P4`@0Fa<203/C000b4`0301<C0?lC?A<00`0C

4`084`0301<C04LC00<04a<06a<405lC00<04a<0>Q<0038C00<04a<0oa<n4`0301<C00LC00<04a<0

Aa<201PC1@1Q4`0301<C03/C000b4`0301<C0?lC?Q<00`0C4`074`0301<C04PC00<04a<04a<406@C

0P0m4`00<Q<00`0C4`3o4clC00<04a<01Q<204XC00<04a<03Q<406LC0P0n4`00<Q<00`0C4`3o4d0C

0P064`0301<C04TC00<04a<02Q<406XC0P0o4`00<Q<00`0C4`3o4d8C00<04a<00a<00`0C4`1:4`03

01<C00DC1@1/4`80@1<0038C00<04a<0oa=34`800a<00`0C4`1:4`8000<C00000`1`4`80@A<0038C

00<04a<0oa<k4`D00Q<0100C4`024`0301<C04TC1@1c4`80@Q<001`C00<04a<00Q<00`0C4`024`03

01<C008C00<04a<011<00`0C4`3o4cdC00L04a<C01<0008C0`174`D00Q<00`0C4`1a4`80@a<001/C

00<04`0021<01`0C4a<04`001A<00`0C4`3o4cdC00L04a<C01<000@C0`104`D021<00`0C4`1^4`80

AA<001/C00<04`0021<00`0C4`034`0301<C00<C0P3o4chC00L04a<C01<000@C00@04`00>Q<500dC

00<04a<0KA<204HC000K4`0301<000TC00<04a<00P064`0301<C0?lC?A<01`0C4a<04`0011<0100C

4a<3034C1P0C4`80Ja<304LC000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C0?lC?1<200@C

00<04a<00a<00`0C4`044`<0:1<701TC0P1Y4`80BA<001`C00<04a<01Q<3008C0`054`0301<C0?lC

B1<00`0C4`074`D06a<9020C00<04a<0I1<304/C000b4`0301<C0?lCB1<00`0C4`0<4a`0:A<2068C

0`1=4`00<Q<00`0C4`3o4dPC0P1C4`80Ga<304lC000b4`0301<C0?lCB1<00`0C4`1C4`80FQ<4058C

000b4`0301<C0?lCB1<00`0C4`1D4`80EQ<405DC000b4`0301<C0?lCB1<00`0C4`1F4`80Ca<505TC

000b4`0301<C0?lCB1<00`0C4`1G4`<0B1<605dC000b4`0301<C0?lCB1<00`0C4`1I4`<0@1<7068C

000b4`0301<C0?lCB1<205`C0`0h4`L0J1<0038C00<04a<0oa=84`0301<C05hC0`0^4`P0KQ<0038C

00<04a<0oa=84`0301<C060C1@0S4`P0MA<0038C00<04a<0oa=84`0301<C06@C1`0D4`X0O1<0038C

00<04a<0oa=84`0301<C06XC5@264`00<Q<00`0C4`3o4dPC00<04a<0oa<64`00:A<500@C00<04a<0

oa=84`80oa<74`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`3o4`HC000[4`0301<C00@C0P3o4dTC

00<04a<0oa<64`00:a<00`0C4`3o4olCF1<002/C00<04a<0oa?o4ePC000Z4`80oa?o4eXC003o4olC

QQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00LA<400034`0000L00Q<3008C00<04a<0

0Q<800034`0000<C0P034`800a<200<C0P034`800a<200<C0P034`800a<200<C0P044`0301<C008C

00@04a<C0P3o4jhC001a4`<021<00`0C4`034`0301<C00LC00D04a<C00054`0301<C008C00<04a<0

0Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`03

01<C008C00H04a<04`024`0301<000@C00<04a<0X1<20?lC2A<007<C00<04a<010024`0401<C4`@0

1Q<4008C00<04a<00Q<200<C0P034`800a<200<C0P034`800a<200<C0P034`800a<200<C0P024`03

01<0008C00<04`000a<00`0C4`2R4`0301<C0?lC1a<001TC10000a<00006008C2P024`800Q<3008C

0`034`8000HC00004`0W4`8021<01`0C4a<04`001a<00`0C00034`0701<C4`0C00024`0301<0008C

00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C

00024`0301<000<C00<04a<00Q<00`0C4`034`0301<C09lC0`024`0301<C0?lC11<001XC00H04a<0

4`024`0301<000@C00H04a<04`024`0301<000DC00<04a<00Q<01@0C4a<0008C00@04`0C0P0a4`03

01<C008C0P084`800a<01`0C4a<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`03

01<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0Q<00`0C00044`0301<C09TC00P04a<04`0C0?lC1A<001XC00H04a<04`044`0301<C008C00<04a<0

0Q<00`0C4`024`0301<C00<C00<04a<00Q<01@0C4a<0008C00@04`0C0P0`4`801A<00`0C4`074`03

01<C008011<200<C0P034`800a<200<C0P034`800a<200<C0P034`800a<200<C0P034`0301<C008C

00<04a<00Q<00`0C4`024`0301<C09XC00P04a<04`0C0?lC1A<001XC00D04a<04`0200<C0P034`03

01<C008C0P034`0301<C00<C00<04a<00Q<01@0C4a<0008C00H04`004`3o4blC0`0011<04`3o4`DC

000J4`0601<C01<00Q<00`0C00024`0301<000@C00h04a<04`0C01<04`0C008C00D04a<C00024`06

01<001<0oa<c4`0301<00?lC1A<001TC10000a<0000;008C1@001A<0000C00D000@C00000a<20004

4`004`80oa<d4`0301<C0?lC11<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC

003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00001\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.77084, -14.119, 0.0242408, 0.16996}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -57 0 ]

[.5 .63053 57 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -118 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(13.6999999999999899`) show

173.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .37378 m

.02499 .37378 L

.02606 .37377 L

.02729 .37376 L

.02846 .37375 L

.03053 .37371 L

.03279 .37366 L

.03527 .37359 L

.0379 .3735 L

.04262 .37328 L

.04749 .37298 L

.05205 .37265 L

.06245 .37167 L

.07305 .37039 L

.08274 .36897 L

.10458 .36498 L

.14429 .35557 L

.18248 .34518 L

.22313 .33451 L

.26226 .3263 L

.27254 .32464 L

.28367 .32311 L

.29328 .32201 L

.30384 .32106 L

.30882 .32071 L

.31415 .32039 L

.31876 .32017 L

.32378 .31998 L

.32672 .3199 L

.32944 .31984 L

.33204 .3198 L

.33335 .31979 L

.33405 .31978 L

.3348 .31977 L

.3361 .31977 L

.33729 .31976 L

.33857 .31976 L

.3393 .31976 L

.33998 .31977 L

.34121 .31977 L

.34233 .31978 L

.34362 .31979 L

.34484 .31981 L

.34723 .31985 L

.34947 .31989 L

.35456 .32003 L

.35953 .32022 L

.36486 .32046 L

.38331 .32163 L

.40448 .32346 L

Mistroke

.42459 .32546 L

.46283 .32918 L

.48254 .33067 L

.49356 .3313 L

.50353 .33171 L

.50842 .33185 L

.51109 .33191 L

.51358 .33195 L

.51571 .33199 L

.51798 .33201 L

.51928 .33202 L

.52051 .33203 L

.52161 .33203 L

.52281 .33203 L

.5241 .33203 L

.52531 .33202 L

.526 .33202 L

.52664 .33202 L

.52807 .33201 L

.52937 .33199 L

.53078 .33197 L

.53364 .33193 L

.53615 .33187 L

.53883 .3318 L

.54365 .33164 L

.55392 .33115 L

.56503 .33041 L

.5852 .32854 L

.60511 .32609 L

.62617 .323 L

.66411 .31674 L

.7045 .31029 L

.72311 .30776 L

.74338 .30549 L

.75439 .3045 L

.76459 .30375 L

.77434 .30319 L

.77974 .30294 L

.7847 .30275 L

.78917 .30261 L

.79406 .30249 L

.7966 .30245 L

.79897 .30241 L

.80147 .30238 L

.80288 .30237 L

.80415 .30236 L

.80529 .30236 L

.80649 .30236 L

.80752 .30235 L

.80866 .30235 L

Mistroke

.80987 .30236 L

.81118 .30236 L

.81242 .30237 L

.81355 .30237 L

.81572 .30239 L

.8181 .30242 L

.82242 .30249 L

.82774 .3026 L

.83275 .30274 L

.84211 .30307 L

.86309 .30406 L

.90166 .30634 L

.92122 .30744 L

.93158 .30794 L

.94268 .30839 L

.95175 .30868 L

.96002 .30886 L

.964 .30893 L

.9661 .30896 L

.96832 .30898 L

.97027 .309 L

.9713 .309 L

.97241 .30901 L

.97343 .30901 L

.97436 .30901 L

.97525 .30902 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.08644 .115 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4gdC00<04a<0oa<64`00oa=m4`0301<C0?lC1Q<002TC1@3o4dlC0P3o4`LC

000[4`0301<C0?lCCa<00`0C4`1^4`d0RQ<002DC0`034`0301<C00@C0P3o4dTC00<04a<0IQ<800`C

3@1n4`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`1Q4`D081<807LC000[4`0301<C00@C00<04a<0

oa=84`0301<C05hC100/4`L0L1<002XC0P064`0301<C0?lCB1<00`0C4`1L4`<0=A<706XC000b4`03

01<C0?lCB1<205/C0P0o4`H0I1<0038C00<04a<0oa=84`0301<C05PC0P164`H0Ga<0038C00<04a<0

oa=84`0301<C05HC0P1>4`D0FQ<0038C00<04a<0oa=84`0301<C05DC0P1C4`D0EQ<0038C00<04a<0

oa=84`0301<C05@C00<04a<0Ea<5058C000b4`0301<C0?lCB1<205<C0P1N4`<0D1<0038C00<04a<0

oa=84`0301<C00lC5P0/4`80HA<404dC000b4`0301<C0?lCB1<00`0C4`0:4`D05Q<9028C0P1U4`<0

Ba<0038C00<04a<0oa=84`0301<C00DC1@0S4`L06a<206PC0`194`00<Q<00`0C4`3o4c/C1@024`03

01<C00<C00<04a<00a<202lC1P0D4`80Ja<204PC000b4`0301<C0?lC?A<01`0C4a<04`0011<00`0C

4`0303HC1P0>4`80KA<304HC000b4`0301<C0?lC=a<300<C00L04a<C01<000@C0`0n4`H02A<00`0C

4`1^4`80AA<0038C00<04a<0oa<m4`0701<C4`0C00034`80AA<500@C00<04a<0L1<204@C000L4`03

01<C008C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0oa<m4`0701<C4`0C00024`0301<004XC

1@1d4`80@Q<001/C00<04`0021<01`0C4a<04`001A<00`0C4`3o4c`C0P044`0401<0008C00<04a<0

Ba<6074C0P114`005Q<3008C00<04`0021<00`0C4`034`0301<C00<C0P3o4d<C0P044`0301<C04XC

00<04a<011<406hC0P104`006a<00`0C00094`0301<C00801Q<00`0C4`3o4d4C00<04a<011<00`0C

4`194`0301<C00TC101[4`0301<C03hC000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C0?lC

>a<00`dC4`024`0301<C00DC0P1:4`0301<C00dC101X4`80?Q<001`C00<04a<01Q<3008C0`054`03

01<C0?lC>1<63@034`0C00LC00<04a<0B1<00`0C4`0B4`@0IA<00`0C4`0l4`00<Q<00`0C4`3o4cLC

2@d84`0301<C04PC00<04a<05A<5068C00<04a<0>a<0038C00<04a<0oa<g4`T=21<00`0C4`174`03

01<C01XC101O4`80?1<0038C00<04a<0oa<g4`T=21<00`0C4`164`0301<C01lC101L4`80>a<0038C

00<04a<0oa<f4`/=1a<00`0C4`164`0301<C028C1@1I4`0301<C03TC000b4`0301<C0?lC=a<93@PC

0P174`0301<C02HC101G4`0301<C03PC000b4`0301<C0?lC=a<93@PC00<04a<0AA<00`0C4`0Z4`@0

E1<203TC000b4`0301<C0?lC=a<93@PC00<04a<0AA<00`0C4`0^4`@0DA<00`0C4`0g4`00<Q<00`0C

4`3o4cPC1Pd:4`0301<C04@C00<04a<0<a<204lC0P0h4`00<Q<00`0C4`3o4cLC00D04a<C3@0<4`03

01<C04@C00<04a<0=A<404`C0P0g4`00<Q<00`0C4`3o4cHC00<04a<03a<00`0C4`144`0301<C03TC

0P1;4`0301<C03DC000b4`0301<C0?lC=Q<00`0C4`0?4`80A1<00`0C4`0l4`@0Aa<203HC000b4`03

01<C0?lC=A<00`0C4`0@4`0301<C04<C00<04a<0?a<304HC00<04a<0=1<0038C00<04a<0oa<e4`03

01<C010C00<04a<0@a<00`0C4`124`<0@a<203DC000Q4`0301<C008C00<04a<00Q<00`0C4`044`03

01<C0?lC=1<00`0C4`0A4`0301<C048C00<04a<0AQ<3044C00<04a<0<a<0020C00<04`001a<00`0C

00054`0301<C0?lC=1<00`0C4`0A4`0301<C048C00<04a<0BA<203lC00<04a<0<a<001/C0`024`03

01<000TC00<04a<00a<20?lC=1<00`0C4`0B4`0301<C048C00<04a<0Ba<303dC00<04a<0<Q<0020C

00<04`001a<200HC00<04a<0oa<c4`0301<C018C0P134`0301<C04hC0P0k4`0301<C038C000P4`03

01<000LC00<04a<01A<00`0C4`3o4c8C00<04a<04a<00`0C4`114`0301<C054C0`0h4`0301<C038C

000Q4`0301<C00HC0`054`0301<C0?lC<Q<00`0C4`0C4`0301<C044C00<04a<0E1<203LC00<04a<0

<A<0038C00<04a<0oa<a4`0301<C01@C00<04a<0@A<00`0C4`1F4`<0=1<00`0C4`0a4`00<Q<00`0C

4`3o4c4C00<04a<03Q<00`0C4`034`0301<C040C00<04a<0FA<3038C0P0b4`00<Q<00`0C4`3o4c0C

00<04a<03Q<00`0C00044`0301<C040C00<04a<0G1<2034C00<04a<0<1<0038C00<04a<0oa<`4`03

01<C00TC0`044`0301<C008C0`104`0301<C05hC0P0_4`0301<C030C000b4`0301<C0?lC<1<00`0C

4`0>4`801A<00`0C4`0o4`0301<C064C0`0/4`0301<C030C000b4`0301<C0?lC<1<00`0C4`0>4`03

01<C00@C00<04a<0?a<00`0C4`1T4`0301<C02TC00<04a<0<1<0038C00<04a<0oa<_4`0301<C00lC

0`044`0301<C03lC00<04a<0IA<302PC0P0a4`00<Q<00`0C4`3o4blC00<04a<05Q<00`0C4`0o4`03

01<C06PC00<04a<09Q<00`0C4`0_4`00<Q<00`0C4`3o4blC00<04a<05Q<00`0C4`0o4`0301<C06TC

0`0U4`0301<C02lC000b4`0301<C0?lC;a<00`0C4`0F4`80@1<00`0C4`1/4`808a<00`0C4`0_4`00

<Q<00`0C4`3o4blC00<04a<05Q<00`0C4`0o4`0301<C06dC0P0R4`0301<C02lC000b4`0301<C0?lC

;a<00`0C4`0F4`0301<C03lC00<04a<0Ka<2020C00<04a<0;a<0038C00<04a<0oa<^4`0301<C01LC

00<04a<0?Q<00`0C4`1b4`807Q<00`0C4`0_4`0071<00`0C4`024`0401<C4`<00a<00`0C4`044`03

01<C0?lC;Q<00`0C4`0G4`0301<C03hC00<04a<0M1<201`C00<04a<0;a<001/C00<04`001a<00`0C

4`024`0301<000DC00<04a<0oa<^4`0301<C01LC0P0o4`0301<C07HC0P0J4`0301<C02lC000F4`<0

0Q<00`0C00084`0301<C00<C00<04a<00a<20?lC;a<00`0C4`0G4`0301<C03hC00<04a<0N1<00`0C

4`0F4`0301<C030C000K4`0301<000PC00@04a<C0P064`0301<C0?lC;A<00`0C4`0H4`0301<C03hC

00<04a<0NA<201HC00<04a<0<1<001/C00<04`001a<00`0C00024`0301<C00DC00<04a<0oa<]4`03

01<C01PC00<04a<0?Q<00`0C4`1k4`0301<C01<C00<04a<0<1<001`C00<04a<01a<0100C4a<300DC

00<04a<0oa<]4`0301<C01PC00<04a<0?Q<00`0C4`1l4`0301<C018C00<04a<0<1<0038C00<04a<0

oa<]4`0301<C01PC00<04a<0?A<00`0C4`1n4`804Q<00`0C4`0`4`00<Q<00`0C4`3o4bdC00<04a<0

61<203hC00<04a<0P1<2010C00<04a<0<1<0038C00<04a<0oa<]4`0301<C01PC00<04a<08A<5008C

00<04a<04Q<00`0C4`0;4`D000<C00008A<5008C00<04a<07a<5008C00<04a<06a<0100C4a<50003

4`0000<C00<04a<0<A<0038C00<04a<0oa<]4`0301<C01PC00<04a<08a<01`0C4a<04`004a<00`0C

4`0=4`0701<C4`0C000R4`0301<C008C00<04a<08A<01`0C4a<04`0071<200@C00<04a<00a<0100C

4`0c4`00<Q<00`0C4`0V4`0301<C008C00@04a<C0`0S4`0301<C008C00<04a<00Q<3028C00<04a<0

0Q<0100C4a<202@C00<04a<00Q<00`0C4`024`0301<C02HC1@114`0301<C01PC00<04a<08a<00`0C

4`034`0301<C014C00<04a<03A<01`0C4a<04`008Q<00`0C4`024`0301<C024C00L04a<C01<001hC

00D04a<C00044`800Q<00`0C4`0a4`00<Q<00`0C4`0U4`0301<000LC00<04a<08Q<00`0C00094`03

01<C020C00<04`001a<00`0C000R4`0301<000LC00<04`00:A<00`0C4`114`0301<C01PC00<04a<0

8a<0100C4a<201@C00<04a<03A<0100C4a<202<C00<04a<00a<00`0C4`0P4`0301<C008C00<04a<0

7Q<200034`0C008C00<04`000Q<00`0C4`0a4`00<Q<00`0C4`0U4`0301<000PC00<04a<08A<00`0C

00074`@08A<00`0C00074`0301<0028C00<04`001a<00`0C000Y4`0301<C040C00<04a<06A<00`0C

4`0S4`0501<C4`005A<00`0C4`0=4`0501<C4`0091<01`0C4a<04`008Q<01`0C4a<04`008A<200<C

00D04`0C000d4`00<Q<00`0C4`0U4`0301<000PC00<04a<08A<00`0C00074`0301<0028C00<04`00

1a<202<C00<04`0021<00`0C4`0X4`0301<C040C00<04a<06A<202<C0P034`<04a<00`0C4`0<4`80

11<2024C0P034`<08A<200@C00<04a<081<200@C0P000a<04`0c4`00<Q<00`0C4`0U4`0301<000LC

00<04`008Q<00`0C00084`808Q<00`0C00074`0301<C028C00<04`001a<00`0C000Y4`0301<C040C

00<04a<06A<00`0C4`0m4`0301<C08PC00<04a<01A<00`0C4`0b4`00<Q<00`0C4`0V4`0301<C00LC

00<04a<08Q<00`0C4`084`0301<C024C00<04a<01a<202<C00<04a<01a<00`0C4`0W4`80@Q<00`0C

4`0I4`0301<C03dC00<04a<0RA<200DC00<04a<0<Q<0038C00<04a<0oa</4`0301<C01TC00<04a<0

?A<00`0C4`2;4`0501<C4`00=A<0038C00<04a<0oa</4`0301<C01TC00<04a<0?A<00`0C4`2;4`04

01<C01<C100O4`00<Q<00`0C4`3o4b`C00<04a<06A<00`0C4`0m4`0301<C08`C0P0D4`<081<0038C

00<04a<0ma<302/Co`0:4`0301<C01hC000b4`0301<C0;0C8@dW4`0301<C02/C00<04a<00Q<0100C

4`084`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC

00<04a<01Q<00`0C4`054`0301<C00<C00<04`001a<00`0C4`064`0301<C00DC00<04a<01A<00`0C

4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC

00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`<01Q<00`0C4`0<4`8081<002`C

/@083B4060d600TC00<04a<0<1<00`0C4`0I4`0301<C02HC00<04a<051<00`0C4`0@4`0301<C02HC

00<04a<09Q<00`0C4`0V4`0401<C03HC000b4`0301<C00PC00<04a<02A<00`0C4`094`0301<C00TC

00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0C4`084`0301<C00TC00<04a<02A<00`0C

4`094`0301<C00TC00<04a<021<73@DC00<04a<02A<00`0C4`094`0301<C00PC00<04a<02A<00`0C

4`094`0301<C00`C100`4`0301<C01TC00<04a<0?A<00`0C4`2;4`0501<C4`00=A<0038C00<04a<0

;1<00`0C4`0/4`0301<C02`C00<04a<031<83APC00<04a<0;1<00`0C4`104`0301<C01TC00<04a<0

?A<00`0C4`2:4`0301<C008C00<04a<0<a<0038C00<04a<0@A<B3D4C1@fB4`0301<C01TC00<04a<0

?A<00`0C4`294`0301<C00@C00<04a<0<Q<0038C00<04a<0>A<83A8C2`da4`D=Ua<00`0C4`0I4`80

?Q<00`0C4`274`801a<00`0C4`0b4`00<Q<00`0C4`0e4`@=9A<>3ATC2PfL4`0301<C01TC00<04a<0

?A<00`0C4`274`0301<C00HC00<04a<0<Q<0038C00<04a<0<A<43CLC6@fW4`0301<C01PC00<04a<0

?A<00`0C4`264`0301<C00PC00<04a<0<A<0038C00<04a<0;1<53O/C00<04a<061<00`0C4`0m4`03

01<C08@C0P0;4`0301<C034C000b4`0301<C02LC1@go4`4C00<04a<061<00`0C4`0m4`0301<C08<C

00<04a<02a<00`0C4`0a4`00<Q<00`0C4`0S4`@=oa<64`0301<C01PC00<04a<0?A<00`0C4`224`03

01<C00`C00<04a<0<A<0038C00<04a<081<33OlC2Q<00`0C4`0H4`80?Q<00`0C4`204`803a<00`0C

4`0a4`00<Q<00`0C4`0L4`@=oa<=4`0301<C01PC00<04a<0?A<00`0C4`1o4`0301<C010C00<04a<0

<1<0038C00<04a<061<43OlC4A<00`0C4`0H4`0301<C03hC00<04a<0O1<201<C00<04a<0<1<0038C

00<04a<04a<53OlC5A<00`0C4`0H4`0301<C03hC00<04a<0Na<201@C00<04a<0<1<0038C00<04a<0

3Q<53OlC6Q<00`0C4`0H4`0301<C03hC00<04a<0NA<201HC00<04a<0<1<0038C00<04a<02a<33OlC

7a<00`0C4`0H4`0301<C03hC00<04a<0N1<00`0C4`0F4`0301<C030C000b4`h=oa<S4`0301<C01LC

0P0o4`0301<C07HC0P0I4`0301<C030C000b4`0301<C0?lC;Q<00`0C4`0G4`0301<C03hC00<04a<0

M1<201`C00<04a<0;a<001`C00<04a<00Q<0100C4a<300<C00<04a<011<00`0C4`3o4bhC00<04a<0

5a<00`0C4`0n4`0301<C07<C00<04a<071<00`0C4`0_4`006a<00`0C00074`0301<C008C00<04`00

1A<00`0C4`3o4bhC00<04a<05a<00`0C4`0o4`0301<C070C0P0O4`0301<C02lC000K4`0301<000PC

00<04a<00a<00`0C4`034`80oa<`4`0301<C01HC00<04a<0?a<00`0C4`1]4`<08A<00`0C4`0_4`00

6a<00`0C00084`0401<C4`801Q<00`0C4`3o4blC00<04a<05Q<00`0C4`0o4`0301<C06`C0P0S4`03

01<C02lC000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C0?lC;a<00`0C4`0F4`80@1<00`0C

4`1Z4`809A<00`0C4`0_4`0071<00`0C4`074`0401<C4`<01A<00`0C4`3o4blC00<04a<05Q<00`0C

4`0o4`0301<C06PC0P0W4`0301<C02lC000b4`0301<C0?lC;a<00`0C4`0F4`0301<C03lC00<04a<0

IQ<202TC00<04a<0;a<0038C00<04a<0oa<`4`0301<C01DC00<04a<0?a<00`0C4`1T4`80:Q<00`0C

4`0`4`00<Q<00`0C4`3o4c0C00<04a<03a<00`0C4`034`0301<C03lC00<04a<0HQ<202`C00<04a<0

<1<0038C00<04a<0oa<`4`0301<C00hC00<04`0011<00`0C4`104`0301<C05hC0`0^4`0301<C030C

000b4`0301<C0?lC<1<00`0C4`0@4`0301<C008C0`104`0301<C05`C0`0`4`0301<C030C000b4`03

01<C0?lC<A<00`0C4`0=4`801A<00`0C4`104`0301<C05XC0P0b4`80<Q<0038C00<04a<0oa<a4`03

01<C00dC00<04a<011<00`0C4`114`0301<C05LC0P0d4`0301<C034C000b4`0301<C0?lC<Q<00`0C

4`0<4`<011<00`0C4`114`0301<C05@C0`0f4`0301<C034C000b4`0301<C0?lC<Q<00`0C4`0C4`03

01<C044C00<04a<0DQ<303LC0P0c4`00<Q<00`0C4`3o4c<C00<04a<04Q<2048C00<04a<0Ca<303XC

00<04a<0<Q<0038C00<04a<0oa<c4`0301<C018C00<04a<0@Q<00`0C4`1<4`<0?1<00`0C4`0b4`00

<Q<00`0C4`3o4c@C00<04a<04A<00`0C4`124`0301<C04TC0`0n4`0301<C03<C000b4`0301<C0?lC

=1<00`0C4`0A4`0301<C048C00<04a<0Aa<3040C00<04a<0<a<0024C00<04a<00Q<00`0C4`024`03

01<C00@C00<04a<0oa<e4`0301<C010C00<04a<0@Q<00`0C4`144`<0@Q<203DC000P4`0301<000LC

00<04`001A<00`0C4`3o4cDC00<04a<041<00`0C4`134`0301<C040C0`154`0301<C03@C000P4`03

01<000TC00<04a<00a<20?lC=a<00`0C4`0?4`80A1<00`0C4`0m4`<0Aa<203HC000P4`0301<000LC

0P064`0301<C0?lC=Q<00`0C4`0?4`0301<C04@C00<04a<0>A<304XC00<04a<0=A<0020C00<04`00

1a<00`0C4`054`0301<C0?lC=a<00`0C4`0>4`0301<C04@C00<04a<0=Q<404/C0P0g4`008A<00`0C

4`064`<01A<00`0C4`3o4cPC00<04a<03A<00`0C4`144`0301<C03<C0`1?4`0301<C03HC000b4`03

01<C0?lC>A<00`0C4`0<4`0301<C04DC00<04a<0;a<3054C00<04a<0=a<0038C00<04a<0oa<i4`03

01<C00`C00<04a<0AA<00`0C4`0[4`@0Da<203TC000b4`0301<C0?lC>Q<00`0C4`0;4`80Aa<00`0C

4`0W4`@0EQ<00`0C4`0h4`00<Q<00`0C4`3o4cXC00<04a<02a<00`0C4`164`0301<C02<C1@1H4`80

>Q<0038C00<04a<0oa<k4`802a<00`0C4`164`0301<C020C101K4`80>a<0038C00<04a<0oa<m4`03

01<C00PC00<04a<0Aa<00`0C4`0K4`@0Ga<00`0C4`0j4`00<Q<00`0C4`3o4chC00<04a<01a<00`0C

4`174`8061<5064C00<04a<0>a<0038C00<04a<0oa<n4`0301<C00LC00<04a<0B1<00`0C4`0C4`@0

I1<203dC000b4`0301<C0?lC?a<00`0C4`064`80BQ<00`0C4`0>4`@0Ia<203hC000b4`0301<C0?lC

@1<200HC00<04a<0BA<00`0C4`0:4`@0JQ<203lC000b4`0301<C0?lC@Q<00`0C4`034`0301<C04XC

00<04a<01A<506`C0P104`00<Q<00`0C4`3o4d<C0P034`0301<C04XC0P000a<00003070C0P114`00

<Q<00`0C4`3o4c/C1@024`0401<C008C00<04a<0BA<507<C0P124`0071<00`0C4`024`0301<C008C

00<04a<00Q<00`0C4`044`0301<C0?lC?A<01`0C4a<04`000Q<304LC1@024`0301<C074C0P134`00

6a<00`0C00084`0701<C4`0C00054`0301<C0?lC?A<01`0C4a<04`0011<3040C1@084`0301<C06hC

0P154`006a<00`0C00084`0301<C00<C00<04a<00a<20?lC?Q<01`0C4a<04`0011<0100C000j4`D0

3A<00`0C4`1]4`80AQ<001/C00<04`002A<00`0C4`0200HC00<04a<0oa<m4`0701<C4`0C00044`04

01<C4`<0<A<601<C0P1[4`<0Aa<001/C00<04`001a<00`0C00024`0301<C00DC00<04a<0oa<l4`80

11<00`0C4`034`0301<C00@C0`0X4`L06A<206TC0P194`0071<00`0C4`064`<00Q<300DC00<04a<0

oa=84`0301<C00LC1@0K4`T081<00`0C4`1T4`<0Ba<0038C00<04a<0oa=84`0301<C00`C700Y4`80

HQ<304dC000b4`0301<C0?lCB1<205<C0P1O4`<0Ca<0038C00<04a<0oa=84`0301<C05<C0P1J4`@0

DQ<0038C00<04a<0oa=84`0301<C05@C0P1F4`@0EA<0038C00<04a<0oa=84`0301<C05HC0P1?4`D0

FA<0038C00<04a<0oa=84`0301<C05LC0`184`H0GA<0038C00<04a<0oa=84`0301<C05TC0`104`L0

HQ<0038C00<04a<0oa=84`80G1<303PC1`1X4`00<Q<00`0C4`3o4dPC00<04a<0GQ<302hC201^4`00

<Q<00`0C4`3o4dPC00<04a<0H1<502<C201e4`00<Q<00`0C4`3o4dPC00<04a<0I1<701@C2P1l4`00

<Q<00`0C4`3o4dPC00<04a<0JQ<E08HC000b4`0301<C0?lCB1<00`0C4`3o4`HC000Y4`D011<00`0C

4`3o4dPC0P3o4`LC000[4`0301<C00@C00<04a<0oa=84`0301<C0?lC1Q<002/C00<04a<011<20?lC

BA<00`0C4`3o4`HC000[4`0301<C0?lCoa=H4`00:a<00`0C4`3o4olCF1<002XC0P3o4olCFQ<00?lC

oa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC001a4`@000<C00001`000a<000044`04

01<C4`800a<200<C0P034`800a<200<C0P034`800a<200<C0P034`800a<200<C0P034`8011<0100C

4a<200<C0P3o4jhC001a4`<021<00`0C4`034`0301<C00DC00<04`0011<00`0C4`024`0301<C008C

00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C

4`024`0301<C008C00H04a<04`044`0301<C008C00<04a<0X1<20?lC2A<007<C00<04a<010024`03

01<C008C00<04a<01Q<00`0C00034`800a<200<C0P034`800a<200<C0P034`800a<200<C0P034`80

0a<200<C0P024`0301<000<C0P034`80Xa<00`0C4`3o4`LC000I4`@000<C00001P024`X00Q<2008C

0`024`<00a<200064`0001<09a<200PC00<04a<00a<00`0C4`054`800a<00`0C00024`0301<0008C

00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C

00024`0301<0008C00<04`000a<01`0C4a<04`000Q<00`0C002Q4`<00Q<00`0C4`3o4`@C000J4`06

01<C01<00Q<00`0C00044`0601<C01<00Q<00`0C00054`0301<C008C00D04a<C00024`0401<04`80

<A<01`0C4a<04`001a<00`0C4`024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`03

01<0008C00<04`000Q<00`0C00044`0301<C09TC00P04a<04`0C0?lC1A<001XC00H04a<04`044`03

01<C008C00<04a<00Q<00`0C4`024`0301<C00<C00<04a<00Q<01@0C4a<0008C00@04`0C0P0`4`80

11<00`0C4`074`800a<200<C0P034`800a<200<C0P034`800a<200<C0P034`800a<200<C0P034`80

0a<00`0C4`024`800a<200<C00<04a<0VQ<0200C4`0C01<0oa<54`006Q<01@0C4`0C00800a<200<C

00<04a<00Q<200<C00<04a<00a<00`0C4`024`0501<C4`000Q<01P0C000C0?lC;a<300044`0C0?lC

1A<001XC00H04a<04`024`0301<0008C00<04`0011<03P0C4`0C01<04`0C01<00Q<01@0C4a<0008C

00H04`004`3o4c<C00<04`00oa<54`006A<400034`0000/00Q<500054`0001<01@0011<000034`80

00@C000C0P3o4c@C00<04a<0oa<44`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olC

QQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.77084, -14.119, 0.0242408, 0.16996}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -57 0 ]

[.5 .63053 57 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -118 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(13.6199999999999898`) show

173.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .36654 m

.02499 .36654 L

.02606 .36653 L

.02729 .36652 L

.02846 .36651 L

.03053 .36648 L

.03279 .36643 L

.03527 .36637 L

.0379 .36628 L

.04262 .36608 L

.04749 .36581 L

.05205 .3655 L

.06245 .36461 L

.07305 .36343 L

.08274 .36213 L

.10458 .35849 L

.14429 .34994 L

.18248 .34057 L

.22313 .33109 L

.24192 .32732 L

.26226 .32391 L

.27341 .32238 L

.28367 .32119 L

.2941 .32021 L

.30384 .31951 L

.31292 .31903 L

.31802 .31884 L

.32266 .31871 L

.3253 .31866 L

.32775 .31862 L

.32902 .3186 L

.33043 .31859 L

.33113 .31859 L

.3319 .31858 L

.33262 .31858 L

.33327 .31858 L

.33449 .31858 L

.33561 .31858 L

.33685 .31858 L

.33817 .31859 L

.33884 .3186 L

.33956 .3186 L

.34087 .31862 L

.34333 .31865 L

.34568 .31869 L

.34822 .31875 L

.35279 .31888 L

.3632 .31931 L

.3742 .31992 L

.38425 .3206 L

Mistroke

.42401 .32405 L

.46225 .3274 L

.48196 .32871 L

.49298 .32925 L

.49773 .32943 L

.50295 .3296 L

.50784 .32971 L

.51051 .32976 L

.513 .32979 L

.5142 .32981 L

.51533 .32982 L

.51636 .32982 L

.51746 .32983 L

.51865 .32984 L

.51975 .32984 L

.52093 .32984 L

.52223 .32984 L

.52355 .32983 L

.52421 .32983 L

.52494 .32982 L

.52741 .3298 L

.52881 .32978 L

.5303 .32976 L

.53299 .32971 L

.53827 .32958 L

.54307 .32942 L

.55308 .32897 L

.56229 .3284 L

.5831 .32666 L

.6019 .32459 L

.62256 .32187 L

.66295 .31587 L

.70183 .31026 L

.72161 .30782 L

.74315 .30567 L

.75317 .30487 L

.76383 .30417 L

.77292 .3037 L

.78297 .30331 L

.78787 .30318 L

.79055 .30311 L

.79304 .30307 L

.79536 .30303 L

.79746 .303 L

.79979 .30298 L

.80108 .30297 L

.80229 .30296 L

.80349 .30295 L

.80418 .30295 L

.80482 .30295 L

Mistroke

.8061 .30295 L

.80683 .30295 L

.80749 .30295 L

.80867 .30295 L

.80995 .30295 L

.81116 .30296 L

.81229 .30296 L

.81504 .30299 L

.81754 .30301 L

.82314 .3031 L

.82802 .3032 L

.83317 .30334 L

.8424 .30364 L

.86322 .30455 L

.90122 .30659 L

.92238 .30765 L

.93162 .30805 L

.94166 .30842 L

.95088 .30869 L

.95493 .30878 L

.9594 .30887 L

.9636 .30893 L

.96754 .30898 L

.96971 .30899 L

.9717 .30901 L

.97275 .30901 L

.97389 .30901 L

.97508 .30902 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.07346 .13099 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4gdC00<04a<0oa<64`00oa=m4`0301<C0?lC1Q<002TC1@3o4dlC0P3o4`LC

000[4`0301<C0?lCCa<00`0C4`1^4`d0RQ<002DC0`034`0301<C00@C0P3o4dTC00<04a<0IQ<800`C

3@1n4`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`1Q4`D081<807LC000[4`0301<C00@C00<04a<0

oa=84`0301<C05hC100/4`L0L1<002XC0P064`0301<C0?lCB1<00`0C4`1L4`<0=A<706XC000b4`03

01<C0?lCB1<205/C0P0o4`H0I1<0038C00<04a<0oa=84`0301<C05PC0P164`H0Ga<0038C00<04a<0

oa=84`0301<C05HC0P1>4`D0FQ<0038C00<04a<0oa=84`0301<C05DC0P1C4`D0EQ<0038C00<04a<0

oa=84`0301<C05@C00<04a<0Ea<5058C000b4`0301<C0?lCB1<205<C0P1N4`<0D1<0038C00<04a<0

oa=84`0301<C00lC5P0/4`80HA<404dC000b4`0301<C0?lCB1<00`0C4`0:4`D05Q<9028C0P1U4`<0

Ba<0038C00<04a<0oa=84`0301<C00DC1@0S4`L06a<206PC0`194`00<Q<00`0C4`3o4c/C1@024`03

01<C00<C00<04a<00a<202lC1P0D4`80Ja<204PC000b4`0301<C0?lC?A<01`0C4a<04`0011<00`0C

4`0303HC1P0>4`80KA<304HC000b4`0301<C0?lC=a<300<C00L04a<C01<000@C0`0n4`H02A<00`0C

4`1^4`80AA<0038C00<04a<0oa<m4`0701<C4`0C00034`80AA<500@C00<04a<0L1<204@C000L4`03

01<C008C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0oa<m4`0701<C4`0C00024`0301<004XC

1@1d4`80@Q<001/C00<04`0021<01`0C4a<04`001A<00`0C4`3o4c`C0P044`0401<0008C00<04a<0

Ba<6074C0P114`005Q<3008C00<04`0021<00`0C4`034`0301<C00<C0P3o4d<C0P044`0301<C04XC

00<04a<011<406hC0P104`006a<00`0C00094`0301<C00801Q<00`0C4`3o4d4C00<04a<011<00`0C

4`194`0301<C00TC101[4`0301<C03hC000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C0?lC

@1<00`0C4`054`80BQ<00`0C4`0=4`@0J1<203hC000L4`0301<C00HC0`024`<01A<00`0C4`3o4clC

00<04a<01Q<00`0C4`184`0301<C018C101U4`0301<C03`C000b4`0301<C0?lC?Q<00`0C4`074`03

01<C04PC00<04a<05A<5068C00<04a<0>a<0038C00<04a<0oa<m4`0301<C00PC00<04a<0Aa<00`0C

4`0J4`@0Ga<203`C000b4`0301<C0?lC>1<01@dC4a<000/C00<04a<0AQ<00`0C4`0O4`@0G1<203/C

000b4`0301<C0?lC=A<63@0301<C00XC00<04a<0AQ<00`0C4`0R4`D0FA<00`0C4`0i4`00<Q<00`0C

4`3o4c@C2@d;4`80Aa<00`0C4`0V4`@0Ea<00`0C4`0h4`00<Q<00`0C4`3o4c@C2@d;4`0301<C04DC

00<04a<0:Q<405@C0P0i4`00<Q<00`0C4`3o4c@C2@d;4`0301<C04DC00<04a<0;Q<4054C00<04a<0

=a<0038C00<04a<0oa<c4`/=2Q<00`0C4`144`0301<C03<C0P1?4`80>1<0038C00<04a<0oa<d4`T=

2a<00`0C4`144`0301<C03DC101<4`80=a<0038C00<04a<0oa<d4`T=2a<00`0C4`144`0301<C03TC

0P1;4`0301<C03DC000b4`0301<C0?lC=1<93@/C0P144`0301<C03`C10174`80=Q<0038C00<04a<0

oa<e4`H=3A<00`0C4`134`0301<C03lC0`164`0301<C03@C000b4`0301<C0?lC=A<0100C4`d?4`03

01<C04<C00<04a<0@Q<304<C0P0e4`008A<00`0C4`024`0301<C008C00<04a<011<00`0C4`3o4c@C

00<04a<04A<00`0C4`124`0301<C04HC0`114`0301<C03<C000P4`0301<000LC00<04`001A<00`0C

4`3o4c@C00<04a<04A<00`0C4`124`0301<C04TC0P0o4`0301<C03<C000K4`<00Q<00`0C00094`03

01<C00<C0P3o4c@C00<04a<04Q<00`0C4`124`0301<C04/C0`0m4`0301<C038C000P4`0301<000LC

0P064`0301<C0?lC<a<00`0C4`0B4`80@a<00`0C4`1>4`80>a<00`0C4`0b4`0081<00`0C00074`03

01<C00DC00<04a<0oa<b4`0301<C01<C00<04a<0@A<00`0C4`1A4`<0>1<00`0C4`0b4`008A<00`0C

4`064`<01A<00`0C4`3o4c8C00<04a<04a<00`0C4`114`0301<C05@C0P0g4`0301<C034C000b4`03

01<C0?lC<A<00`0C4`0D4`0301<C044C00<04a<0EQ<303@C00<04a<0<A<0038C00<04a<0oa<a4`03

01<C00hC00<04a<00a<00`0C4`104`0301<C05TC0`0b4`80<Q<0038C00<04a<0oa<`4`0301<C00hC

00<04`0011<00`0C4`104`0301<C05`C0P0a4`0301<C030C000b4`0301<C0?lC<1<00`0C4`094`<0

11<00`0C4`024`<0@1<00`0C4`1N4`80;a<00`0C4`0`4`00<Q<00`0C4`3o4c0C00<04a<03Q<200DC

00<04a<0?a<00`0C4`1Q4`<0;1<00`0C4`0`4`00<Q<00`0C4`3o4c0C00<04a<03Q<00`0C4`044`03

01<C03lC00<04a<0I1<00`0C4`0Y4`0301<C030C000b4`0301<C0?lC;a<00`0C4`0?4`<011<00`0C

4`0o4`0301<C06DC0`0X4`80<A<0038C00<04a<0oa<_4`0301<C01HC00<04a<0?a<00`0C4`1X4`03

01<C02HC00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC00<04a<0?a<00`0C4`1Y4`<09A<00`0C

4`0_4`00<Q<00`0C4`3o4blC00<04a<05Q<2040C00<04a<0K1<202<C00<04a<0;a<0038C00<04a<0

oa<_4`0301<C01HC00<04a<0?a<00`0C4`1]4`808Q<00`0C4`0_4`00<Q<00`0C4`3o4blC00<04a<0

5Q<00`0C4`0o4`0301<C06lC0P0P4`0301<C02lC000b4`0301<C0?lC;Q<00`0C4`0G4`0301<C03hC

00<04a<0LQ<201hC00<04a<0;a<001`C00<04a<00Q<0100C4a<300<C00<04a<011<00`0C4`3o4bhC

00<04a<05a<00`0C4`0n4`0301<C07@C0P0L4`0301<C02lC000K4`0301<000LC00<04a<00Q<00`0C

00054`0301<C0?lC;Q<00`0C4`0G4`80?a<00`0C4`1f4`806Q<00`0C4`0_4`005Q<3008C00<04`00

21<00`0C4`034`0301<C00<C0P3o4blC00<04a<05a<00`0C4`0n4`0301<C07PC00<04a<05Q<00`0C

4`0`4`006a<00`0C00084`0401<C4`801Q<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07TC

0P0F4`0301<C030C000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C0?lC;A<00`0C4`0H4`03

01<C03hC00<04a<0Na<00`0C4`0C4`0301<C030C000L4`0301<C00LC00@04a<C0`054`0301<C0?lC

;A<00`0C4`0H4`0301<C03hC00<04a<0O1<00`0C4`0B4`0301<C030C000b4`0301<C0?lC;A<00`0C

4`0H4`0301<C03dC00<04a<0OQ<2018C00<04a<0<1<0038C00<04a<0oa<]4`0301<C01PC0P0n4`03

01<C080C0P0@4`0301<C030C000b4`0301<C0?lC;A<00`0C4`0H4`0301<C024C1@024`0301<C018C

00<04a<02a<500034`00024C1@024`0301<C01lC1@024`0301<C01/C00@04a<C1@000a<000034`03

01<C034C000b4`0301<C0?lC;A<00`0C4`0H4`0301<C02<C00L04a<C01<001<C00<04a<03A<01`0C

4a<04`008Q<00`0C4`024`0301<C024C00L04a<C01<001`C0P044`0301<C00<C00@04a<0<a<0038C

00<04a<09Q<00`0C4`024`0401<C4`<08a<00`0C4`024`0301<C008C0`0R4`0301<C008C00@04a<C

0P0T4`0301<C008C00<04a<00Q<00`0C4`0V4`D0@A<00`0C4`0H4`0301<C02<C00<04a<00a<00`0C

4`0A4`0301<C00dC00L04a<C01<0028C00<04a<00Q<00`0C4`0Q4`0701<C4`0C000N4`0501<C4`00

11<2008C00<04a<0<A<0038C00<04a<09A<00`0C00074`0301<C028C00<04`002A<00`0C4`0P4`03

01<000LC00<04`008Q<00`0C00074`0301<002TC00<04a<0@A<00`0C4`0H4`0301<C02<C00@04a<C

0P0D4`0301<C00dC00@04a<C0P0S4`0301<C00<C00<04a<081<00`0C4`024`0301<C01hC0P000a<0

4`024`0301<0008C00<04a<0<A<0038C00<04a<09A<00`0C00084`0301<C024C00<04`001a<4024C

00<04`001a<00`0C000R4`0301<000LC00<04`00:A<00`0C4`104`0301<C01TC00<04a<08a<01@0C

4a<001DC00<04a<03A<01@0C4a<002@C00L04a<C01<0028C00L04a<C01<0024C0P034`0501<04`00

=1<0038C00<04a<09A<00`0C00084`0301<C024C00<04`001a<00`0C000R4`0301<000LC0P0S4`03

01<000PC00<04a<0:1<00`0C4`104`0301<C01TC0P0S4`800a<301<C00<04a<031<200@C0P0Q4`80

0a<3024C0P044`0301<C020C0P044`8000<C01<0<a<0038C00<04a<09A<00`0C00074`0301<0028C

00<04`0021<2028C00<04`001a<00`0C4`0R4`0301<000LC00<04`00:A<00`0C4`104`0301<C01TC

00<04a<0?A<00`0C4`284`0301<C00DC00<04a<0<Q<0038C00<04a<09Q<00`0C4`074`0301<C028C

00<04a<021<00`0C4`0Q4`0301<C00LC0P0S4`0301<C00LC00<04a<09a<2048C00<04a<06A<00`0C

4`0m4`0301<C08TC0P054`0301<C038C000b4`0301<C0?lC;1<00`0C4`0I4`0301<C03dC00<04a<0

Ra<01@0C4a<003DC000b4`0301<C0?lC;1<00`0C4`0I4`0301<C03dC00<04a<0Ra<0100C4`0C4`@0

7a<0038C00<04a<0oa</4`0301<C01TC00<04a<0?A<00`0C4`2<4`8051<3020C000b4`0301<C0?LC

0`0[4ol02Q<00`0C4`0N4`00<Q<00`0C4`2`4b4=9a<00`0C4`0[4`0301<C008C00@04a<021<00`0C

4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC

00<04a<01A<00`0C4`034`0301<000LC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C

4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC

00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<300HC00<04a<031<2020C000/4k002@dQ01P=

1P094`0301<C030C00<04a<06A<00`0C4`0V4`0301<C01@C00<04a<041<00`0C4`0V4`0301<C02HC

00<04a<09Q<0100C4`0f4`00<Q<00`0C4`084`0301<C00TC00<04a<02A<00`0C4`094`0301<C00PC

00<04a<02A<00`0C4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0C

4`094`0301<C00LC1`d64`0301<C00TC00<04a<02A<00`0C4`084`0301<C00TC00<04a<02A<00`0C

4`0<4`@0<1<00`0C4`0I4`0301<C03dC00<04a<0Ra<01@0C4a<003DC000b4`0301<C02`C00<04a<0

;1<00`0C4`0/4`0301<C00`C1`dI4`0301<C02`C00<04a<0@1<00`0C4`0I4`0301<C03dC00<04a<0

RQ<00`0C4`024`0301<C03<C000b4`0301<C03`C7`di4`D=TQ<00`0C4`0I4`0301<C03dC00<04a<0

RA<00`0C4`044`0301<C038C000b4`0301<C03DC1`dO4`T=9Q<:3ILC00<04a<06A<203hC00<04a<0

Qa<200LC00<04a<0<Q<0038C00<04a<0<A<43BlC3Pd=4`/=XA<00`0C4`0I4`0301<C03dC00<04a<0

Qa<00`0C4`064`0301<C038C000b4`0301<C02`C1@e14`d=[A<00`0C4`0H4`0301<C03dC00<04a<0

QQ<00`0C4`084`0301<C034C000b4`0301<C02LC1@go4`4C00<04a<061<00`0C4`0m4`0301<C08@C

0P0;4`0301<C034C000b4`0301<C02<C10go4`HC00<04a<061<00`0C4`0m4`0301<C08<C00<04a<0

2a<00`0C4`0a4`00<Q<00`0C4`0P4`<=oa<:4`0301<C01PC00<04a<0?A<00`0C4`224`0301<C00`C

00<04a<0<A<0038C00<04a<071<43OlC3A<00`0C4`0H4`80?Q<00`0C4`204`803a<00`0C4`0a4`00

<Q<00`0C4`0H4`@=oa<A4`0301<C01PC00<04a<0?A<00`0C4`1o4`0301<C010C00<04a<0<1<0038C

00<04a<04a<53OlC5A<00`0C4`0H4`0301<C03hC00<04a<0O1<201<C00<04a<0<1<0038C00<04a<0

3Q<53OlC6Q<00`0C4`0H4`0301<C03hC00<04a<0Na<201@C00<04a<0<1<0038C00<04a<011<:3OlC

7a<00`0C4`0H4`0301<C03hC00<04a<0NA<201HC00<04a<0<1<0038C1`go4bTC00<04a<061<00`0C

4`0n4`0301<C07PC00<04a<05Q<00`0C4`0`4`00<Q<00`0C4`3o4bhC00<04a<05a<203lC00<04a<0

MQ<201TC00<04a<0<1<0038C00<04a<0oa<^4`0301<C01LC00<04a<0?Q<00`0C4`1d4`8071<00`0C

4`0_4`0071<00`0C4`024`0401<C4`<00a<00`0C4`044`0301<C0?lC;Q<00`0C4`0G4`0301<C03hC

00<04a<0La<00`0C4`0L4`0301<C02lC000K4`0301<000LC00<04a<00Q<00`0C00054`0301<C0?lC

;Q<00`0C4`0G4`0301<C03lC00<04a<0L1<201lC00<04a<0;a<001/C00<04`0021<00`0C4`034`03

01<C00<C0P3o4c0C00<04a<05Q<00`0C4`0o4`0301<C06dC0`0Q4`0301<C02lC000K4`0301<000PC

00@04a<C0P064`0301<C0?lC;a<00`0C4`0F4`0301<C03lC00<04a<0K1<202<C00<04a<0;a<001/C

00<04`001a<00`0C00024`0301<C00DC00<04a<0oa<_4`0301<C01HC0P104`0301<C06XC0P0U4`03

01<C02lC000L4`0301<C00LC00@04a<C0`054`0301<C0?lC;a<00`0C4`0F4`0301<C03lC00<04a<0

J1<202LC00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC00<04a<0?a<00`0C4`1V4`80:A<00`0C

4`0_4`00<Q<00`0C4`3o4c0C00<04a<05A<00`0C4`0o4`0301<C06@C0P0Z4`0301<C030C000b4`03

01<C0?lC<1<00`0C4`0?4`0301<C00<C00<04a<0?a<00`0C4`1R4`80;1<00`0C4`0`4`00<Q<00`0C

4`3o4c0C00<04a<03Q<00`0C00044`0301<C040C00<04a<0GQ<302hC00<04a<0<1<0038C00<04a<0

oa<`4`0301<C010C00<04a<00Q<3040C00<04a<0G1<3030C00<04a<0<1<0038C00<04a<0oa<a4`03

01<C00dC0P054`0301<C040C00<04a<0FQ<2038C0P0b4`00<Q<00`0C4`3o4c4C00<04a<03A<00`0C

4`044`0301<C044C00<04a<0Ea<203@C00<04a<0<A<0038C00<04a<0oa<b4`0301<C00`C0`044`03

01<C044C00<04a<0E1<303HC00<04a<0<A<0038C00<04a<0oa<b4`0301<C01<C00<04a<0@A<00`0C

4`1B4`<0=a<203<C000b4`0301<C0?lC<a<00`0C4`0B4`80@Q<00`0C4`1?4`<0>Q<00`0C4`0b4`00

<Q<00`0C4`3o4c<C00<04a<04Q<00`0C4`124`0301<C04`C0`0l4`0301<C038C000b4`0301<C0?lC

=1<00`0C4`0A4`0301<C048C00<04a<0BA<303hC00<04a<0<a<0038C00<04a<0oa<d4`0301<C014C

00<04a<0@Q<00`0C4`174`<0@1<00`0C4`0c4`008A<00`0C4`024`0301<C008C00<04a<011<00`0C

4`3o4cDC00<04a<041<00`0C4`124`0301<C04@C0`124`80=A<0020C00<04`001a<00`0C00054`03

01<C0?lC=A<00`0C4`0@4`0301<C04<C00<04a<0@1<304DC00<04a<0=1<0020C00<04`002A<00`0C

4`034`80oa<g4`0301<C00lC0P144`0301<C03dC0`174`80=Q<0020C00<04`001a<200HC00<04a<0

oa<f4`0301<C00lC00<04a<0A1<00`0C4`0i4`<0BQ<00`0C4`0e4`0081<00`0C00074`0301<C00DC

00<04a<0oa<g4`0301<C00hC00<04a<0A1<00`0C4`0f4`@0Ba<203LC000Q4`0301<C00HC0`054`03

01<C0?lC>1<00`0C4`0=4`0301<C04@C00<04a<0<a<304lC00<04a<0=Q<0038C00<04a<0oa<i4`03

01<C00`C00<04a<0AA<00`0C4`0_4`<0DA<00`0C4`0g4`00<Q<00`0C4`3o4cTC00<04a<031<00`0C

4`154`0301<C02/C101C4`80>A<0038C00<04a<0oa<j4`0301<C00/C0P174`0301<C02LC101F4`03

01<C03PC000b4`0301<C0?lC>Q<00`0C4`0;4`0301<C04HC00<04a<08a<505PC0P0j4`00<Q<00`0C

4`3o4c/C0P0;4`0301<C04HC00<04a<081<405/C0P0k4`00<Q<00`0C4`3o4cdC00<04a<021<00`0C

4`174`0301<C01/C101O4`0301<C03XC000b4`0301<C0?lC?Q<00`0C4`074`0301<C04LC0P0H4`D0

HA<00`0C4`0k4`00<Q<00`0C4`3o4chC00<04a<01a<00`0C4`184`0301<C01<C101T4`80?A<0038C

00<04a<0oa<o4`0301<C00HC0P1:4`0301<C00hC101W4`80?Q<0038C00<04a<0oa=04`801Q<00`0C

4`194`0301<C00XC101Z4`80?a<0038C00<04a<0oa=24`0301<C00<C00<04a<0BQ<00`0C4`054`D0

K1<2040C000b4`0301<C0?lC@a<200<C00<04a<0BQ<200034`0000<0L1<2044C000b4`0301<C0?lC

>a<5008C00@04a<00Q<00`0C4`194`D0La<2048C000L4`0301<C008C00<04a<00Q<00`0C4`024`03

01<C00@C00<04a<0oa<m4`0701<C4`0C00024`<0Aa<5008C00<04a<0LA<204<C000K4`0301<000PC

00L04a<C01<000DC00<04a<0oa<m4`0701<C4`0C00044`<0@1<500PC00<04a<0KQ<204DC000K4`03

01<000PC00<04a<00a<00`0C4`034`80oa<n4`0701<C4`0C00044`0401<003XC1@0=4`0301<C06dC

0P164`006a<00`0C00094`0301<C00801Q<00`0C4`3o4cdC00L04a<C01<000@C00@04a<C0`0a4`H0

4a<206/C0`174`006a<00`0C00074`0301<0008C00<04a<01A<00`0C4`3o4c`C0P044`0301<C00<C

00<04a<011<302PC1`0I4`80JA<204TC000L4`0301<C00HC0`024`<01A<00`0C4`3o4dPC00<04a<0

1a<501/C2@0P4`0301<C06@C0`1;4`00<Q<00`0C4`3o4dPC00<04a<031<L02TC0P1R4`<0CA<0038C

00<04a<0oa=84`80Da<205lC0`1?4`00<Q<00`0C4`3o4dPC00<04a<0Da<205XC101B4`00<Q<00`0C

4`3o4dPC00<04a<0E1<205HC101E4`00<Q<00`0C4`3o4dPC00<04a<0EQ<204lC1@1I4`00<Q<00`0C

4`3o4dPC00<04a<0Ea<304PC1P1M4`00<Q<00`0C4`3o4dPC00<04a<0FA<3040C1`1R4`00<Q<00`0C

4`3o4dPC0P1L4`<0>1<706PC000b4`0301<C0?lCB1<00`0C4`1N4`<0;Q<806hC000b4`0301<C0?lC

B1<00`0C4`1P4`D08a<807DC000b4`0301<C0?lCB1<00`0C4`1T4`L051<:07`C000b4`0301<C0?lC

B1<00`0C4`1Z4aD0QQ<0038C00<04a<0oa=84`0301<C0?lC1Q<002TC1@044`0301<C0?lCB1<20?lC

1a<002/C00<04a<011<00`0C4`3o4dPC00<04a<0oa<64`00:a<00`0C4`044`80oa=94`0301<C0?lC

1Q<002/C00<04a<0oa?o4ePC000[4`0301<C0?lCoa=H4`00:Q<20?lCoa=J4`00oa?o4hHC003o4olC

QQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<0074C10000a<0000700034`0000@C00@04a<C0P024`D0

00<C00000a<200<C0P034`800a<200<C0P034`800a<200<C0P034`800a<200@C00@04a<C0P044`03

01<C0?lC[1<0074C0`084`0301<C00<C00<04a<01A<00`0C00034`0301<C00<C00<04a<00Q<00`0C

4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C

00<04a<00Q<01P0C4`0C00@C00H04a<04`2R4`80oa<94`00La<00`0C4`04008C00<04a<00Q<00`0C

4`064`0301<000<C00<04a<00Q<200<C0P034`800a<200<C0P034`800a<200<C0P034`800a<200<C

0P024`0301<000<C0P024`0301<00:<C00<04a<0oa<74`006A<400034`0000H00Q<:008C0P024`<0

0Q<300<C0P001Q<0000C02LC0P084`0301<C00<C00<04a<01A<200@C00L04a<C01<0008C00<04`00

0Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`03

01<0008C00<04`000a<01`0C4a<04`000a<00`0C4`2P4`<00Q<00`0C4`3o4`@C000J4`0601<C01<0

0Q<00`0C00044`0601<C01<00Q<00`0C00054`0301<C008C00D04a<C00024`0401<04`80<A<01`0C

4a<04`001a<00`0C4`034`0701<C4`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C

00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C

00024`0301<000@C00<04a<0VA<0200C4`0C01<0oa<54`006Q<01P0C4`0C00@C00<04a<00Q<00`0C

4`024`0301<C008C00<04a<00a<00`0C4`024`0501<C4`000Q<0100C01<2030C0P044`0301<C00LC

0P024`8011<200<C0P034`800a<200<C0P034`800a<200<C0P034`800a<200<C0P034`0301<C008C

0P034`0301<C008C00<04a<0VQ<0200C4`0C01<0oa<54`006Q<01@0C4`0C00800a<200<C00<04a<0

0Q<200<C00<04a<00a<00`0C4`024`0501<C4`000Q<01P0C000C0?lC;a<300044`0C0?lC1A<001XC

00H04a<04`024`0301<0008C00<04`0011<03P0C4`0C01<04`0C01<00Q<01@0C4a<0008C00H04`00

4`3o4c<C00<04`00oa<54`006A<400034`0000/00Q<500054`0001<01@0011<000034`8000@C000C

0P3o4c@C00<04a<0oa<44`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.77084, -14.119, 0.0242408, 0.16996}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -57 0 ]

[.5 .63053 57 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -118 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(13.5399999999999898`) show

173.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .35832 m

.02499 .35832 L

.02606 .35831 L

.02729 .35831 L

.02846 .3583 L

.03053 .35827 L

.03279 .35823 L

.03527 .35817 L

.0379 .35809 L

.04262 .35791 L

.04749 .35767 L

.05205 .3574 L

.06245 .35661 L

.08274 .35442 L

.10458 .35122 L

.14581 .3434 L

.18551 .33494 L

.22371 .32733 L

.24502 .32378 L

.26435 .32115 L

.27403 .32008 L

.2845 .3191 L

.29432 .31838 L

.30348 .31786 L

.30807 .31766 L

.31299 .31749 L

.31579 .31741 L

.31844 .31735 L

.32081 .3173 L

.32216 .31728 L

.32342 .31727 L

.32475 .31725 L

.32596 .31724 L

.32726 .31723 L

.32794 .31723 L

.32866 .31723 L

.32986 .31722 L

.33098 .31722 L

.3322 .31723 L

.33351 .31723 L

.33425 .31723 L

.33493 .31724 L

.33647 .31725 L

.33926 .31728 L

.3418 .31732 L

.34448 .31738 L

.34942 .3175 L

.35392 .31765 L

.36406 .31807 L

.38237 .31912 L

Mistroke

.42213 .32217 L

.46038 .3251 L

.48009 .32624 L

.48576 .3265 L

.4911 .32671 L

.49586 .32686 L

.50108 .327 L

.50352 .32705 L

.50614 .3271 L

.50841 .32714 L

.51086 .32716 L

.51231 .32718 L

.51364 .32719 L

.51492 .32719 L

.51556 .3272 L

.51627 .3272 L

.51749 .3272 L

.51881 .3272 L

.52005 .3272 L

.52119 .32719 L

.52227 .32719 L

.52343 .32718 L

.5255 .32716 L

.52797 .32713 L

.5302 .3271 L

.53508 .32699 L

.53968 .32687 L

.54943 .3265 L

.55973 .32596 L

.5782 .32465 L

.59781 .32281 L

.61614 .32076 L

.65501 .31578 L

.69634 .31051 L

.71701 .30824 L

.73615 .30648 L

.75472 .30517 L

.76409 .30466 L

.77445 .30422 L

.77936 .30406 L

.78453 .30392 L

.78894 .30383 L

.79377 .30375 L

.79651 .30372 L

.79899 .3037 L

.80037 .30369 L

.80109 .30369 L

.80186 .30368 L

.80253 .30368 L

.80327 .30368 L

Mistroke

.80457 .30368 L

.80588 .30368 L

.80707 .30368 L

.80773 .30368 L

.80845 .30368 L

.80976 .30368 L

.81098 .30369 L

.81228 .3037 L

.81462 .30372 L

.81723 .30375 L

.81999 .30378 L

.82492 .30386 L

.83605 .30413 L

.84567 .30443 L

.85622 .30483 L

.89667 .30669 L

.91532 .30754 L

.9356 .30832 L

.94643 .30863 L

.95119 .30874 L

.95645 .30884 L

.96139 .30892 L

.96602 .30897 L

.96858 .30899 L

.97092 .309 L

.97214 .30901 L

.97285 .30901 L

.97349 .30901 L

.97416 .30902 L

.97489 .30902 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.06048 .15137 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4gdC00<04a<0oa<64`00oa=m4`0301<C0?lC1Q<002TC1@3o4dlC0P3o4`LC

000[4`0301<C0?lCCa<00`0C4`1^4`d0RQ<002DC0`034`0301<C00@C0P3o4dTC00<04a<0IQ<800`C

3@1n4`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`1Q4`D081<807LC000[4`0301<C00@C00<04a<0

oa=84`0301<C05hC100/4`L0L1<002XC0P064`0301<C0?lCB1<00`0C4`1L4`<0=A<706XC000b4`03

01<C0?lCB1<205/C0P0o4`H0I1<0038C00<04a<0oa=84`0301<C05PC0P164`H0Ga<0038C00<04a<0

oa=84`0301<C05HC0P1>4`D0FQ<0038C00<04a<0oa=84`0301<C05DC0P1C4`D0EQ<0038C00<04a<0

oa=84`0301<C05@C00<04a<0Ea<5058C000b4`0301<C0?lCB1<205<C0P1N4`<0D1<0038C00<04a<0

oa=84`0301<C00lC5P0/4`80HA<404dC000b4`0301<C0?lCB1<00`0C4`0:4`D05Q<9028C0P1U4`<0

Ba<0038C00<04a<0oa=84`0301<C00DC1@0S4`L06a<206PC0`194`00<Q<00`0C4`3o4c/C1@024`03

01<C00<C00<04a<00a<202lC1P0D4`80Ja<204PC000b4`0301<C0?lC?A<01`0C4a<04`0011<00`0C

4`0303HC1P0>4`80KA<304HC000b4`0301<C0?lC=a<300<C00L04a<C01<000@C0`0n4`H02A<00`0C

4`1^4`80AA<0038C00<04a<0oa<m4`0701<C4`0C00034`80AA<500@C00<04a<0L1<204@C000L4`03

01<C008C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0oa<m4`0701<C4`0C00024`0301<004XC

1@1d4`80@Q<001/C00<04`0021<01`0C4a<04`001A<00`0C4`3o4c`C0P044`0401<0008C00<04a<0

Ba<6074C0P114`005Q<3008C00<04`0021<00`0C4`034`0301<C00<C0P3o4d<C0P044`0301<C04XC

00<04a<011<406hC0P104`006a<00`0C00094`0301<C00801Q<00`0C4`3o4d4C00<04a<011<00`0C

4`194`0301<C00TC101[4`0301<C03hC000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C0?lC

@1<00`0C4`054`80BQ<00`0C4`0=4`@0J1<203hC000L4`0301<C00HC0`024`<01A<00`0C4`3o4clC

00<04a<01Q<00`0C4`184`0301<C018C101U4`0301<C03`C000b4`0301<C0?lC?Q<00`0C4`074`03

01<C04PC00<04a<05A<5068C00<04a<0>a<0038C00<04a<0oa<m4`0301<C00PC00<04a<0Aa<00`0C

4`0J4`@0Ga<203`C000b4`0301<C0?lC?1<00`0C4`094`0301<C04HC00<04a<07a<405`C0P0k4`00

<Q<00`0C4`3o4c/C00<04a<02Q<00`0C4`164`0301<C028C1@1I4`0301<C03TC000b4`0301<C0?lC

>Q<00`0C4`0;4`80Aa<00`0C4`0V4`@0Ea<00`0C4`0h4`00<Q<00`0C4`3o4cTC00<04a<031<00`0C

4`154`0301<C02XC101D4`80>A<0038C00<04a<0oa<i4`0301<C00`C00<04a<0AA<00`0C4`0^4`@0

DA<00`0C4`0g4`00<Q<00`0C4`3o4c@C00D=4a<C000?4`0301<C04@C00<04a<0<a<204lC0P0h4`00

<Q<00`0C4`3o4c4C1Pd00`0C4`0>4`0301<C04@C00<04a<0=A<404`C0P0g4`00<Q<00`0C4`3o4c0C

2@d?4`0301<C04@C00<04a<0>A<204/C00<04a<0=A<0038C00<04a<0oa<`4`T=3a<204@C00<04a<0

?1<404LC0P0f4`00<Q<00`0C4`3o4c0C2@d?4`0301<C04<C00<04a<0?a<304HC00<04a<0=1<0038C

00<04a<0oa<_4`/=3Q<00`0C4`134`0301<C048C0`134`80=A<0024C00<04a<00Q<00`0C4`024`03

01<C00@C00<04a<0oa<`4`T=3a<00`0C4`124`0301<C04HC0`114`0301<C03<C000P4`0301<000LC

00<04`001A<00`0C4`3o4c0C2@d?4`0301<C048C00<04a<0BA<203lC00<04a<0<a<001/C0`024`03

01<000TC00<04a<00a<20?lC<A<93@lC00<04a<0@Q<00`0C4`1;4`<0?A<00`0C4`0b4`0081<00`0C

00074`801Q<00`0C4`3o4c4C1PdA4`80@a<00`0C4`1>4`80>a<00`0C4`0b4`0081<00`0C00074`03

01<C00DC00<04a<0oa<b4`0301<=01<C00<04a<0@A<00`0C4`1A4`<0>1<00`0C4`0b4`008A<00`0C

4`064`<01A<00`0C4`3o4c8C00<04a<04a<00`0C4`114`0301<C05@C0P0g4`0301<C034C000b4`03

01<C0?lC<A<00`0C4`0D4`0301<C044C00<04a<0EQ<303@C00<04a<0<A<0038C00<04a<0oa<a4`03

01<C00hC00<04a<00a<00`0C4`104`0301<C05TC0`0b4`80<Q<0038C00<04a<0oa<`4`0301<C00hC

00<04`0011<00`0C4`104`0301<C05`C0P0a4`0301<C030C000b4`0301<C0?lC<1<00`0C4`094`<0

11<00`0C4`024`<0@1<00`0C4`1N4`80;a<00`0C4`0`4`00<Q<00`0C4`3o4c0C00<04a<03Q<200DC

00<04a<0?a<00`0C4`1Q4`<0;1<00`0C4`0`4`00<Q<00`0C4`3o4c0C00<04a<03Q<00`0C4`044`03

01<C03lC00<04a<0I1<00`0C4`0Y4`0301<C030C000b4`0301<C0?lC;a<00`0C4`0?4`<011<00`0C

4`0o4`0301<C06DC0`0X4`80<A<0038C00<04a<0oa<_4`0301<C01HC00<04a<0?a<00`0C4`1X4`03

01<C02HC00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC00<04a<0?a<00`0C4`1Y4`<09A<00`0C

4`0_4`00<Q<00`0C4`3o4blC00<04a<05Q<2040C00<04a<0K1<202<C00<04a<0;a<0038C00<04a<0

oa<_4`0301<C01HC00<04a<0?a<00`0C4`1]4`808Q<00`0C4`0_4`00<Q<00`0C4`3o4blC00<04a<0

5Q<00`0C4`0o4`0301<C06lC0P0P4`0301<C02lC000b4`0301<C0?lC;Q<00`0C4`0G4`0301<C03hC

00<04a<0LQ<201hC00<04a<0;a<001`C00<04a<00Q<0100C4a<300<C00<04a<011<00`0C4`3o4bhC

00<04a<05a<00`0C4`0n4`0301<C07@C0P0L4`0301<C02lC000K4`0301<000LC00<04a<00Q<00`0C

00054`0301<C0?lC;Q<00`0C4`0G4`80?a<00`0C4`1f4`806Q<00`0C4`0_4`005Q<3008C00<04`00

21<00`0C4`034`0301<C00<C0P3o4blC00<04a<05a<00`0C4`0n4`0301<C07PC00<04a<05Q<00`0C

4`0`4`006a<00`0C00084`0401<C4`801Q<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07TC

0P0F4`0301<C030C000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C0?lC;A<00`0C4`0H4`03

01<C03hC00<04a<0Na<00`0C4`0C4`0301<C030C000L4`0301<C00LC00@04a<C0`054`0301<C0?lC

;A<00`0C4`0H4`0301<C03hC00<04a<0O1<00`0C4`0B4`0301<C030C000b4`0301<C0?lC;A<00`0C

4`0H4`0301<C03dC00<04a<0OQ<2018C00<04a<0<1<0038C00<04a<0oa<]4`0301<C01PC0P0n4`03

01<C080C0P0@4`0301<C030C000b4`0301<C0?lC;A<00`0C4`0H4`0301<C024C1@024`0301<C018C

00<04a<02a<500034`00024C1@024`0301<C01lC1@024`0301<C01/C00@04a<C1@000a<000034`03

01<C034C000b4`0301<C0?lC;A<00`0C4`0H4`0301<C02<C00L04a<C01<001<C00<04a<03A<01`0C

4a<04`008Q<00`0C4`024`0301<C024C00L04a<C01<001`C0P044`0301<C00<C00@04a<0<a<0038C

00<04a<09Q<00`0C4`024`0401<C4`<08a<00`0C4`024`0301<C008C0`0R4`0301<C008C00@04a<C

0P0T4`0301<C008C00<04a<00Q<00`0C4`0V4`D0@A<00`0C4`0H4`0301<C02<C00<04a<00a<00`0C

4`0A4`0301<C00dC00L04a<C01<0028C00<04a<00Q<00`0C4`0Q4`0701<C4`0C000N4`0501<C4`00

11<2008C00<04a<0<A<0038C00<04a<09A<00`0C00074`0301<C028C00<04`002A<00`0C4`0P4`03

01<000LC00<04`008Q<00`0C00074`0301<002TC00<04a<0@A<00`0C4`0H4`0301<C02<C00@04a<C

0P0D4`0301<C00dC00@04a<C0P0S4`0301<C00<C00<04a<081<00`0C4`024`0301<C01hC0P000a<0

4`024`0301<0008C00<04a<0<A<0038C00<04a<09A<00`0C00084`0301<C024C00<04`001a<4024C

00<04`001a<00`0C000R4`0301<000LC00<04`00:A<00`0C4`104`0301<C01TC00<04a<08a<01@0C

4a<001DC00<04a<03A<01@0C4a<002@C00L04a<C01<0028C00L04a<C01<0024C0P034`0501<04`00

=1<0038C00<04a<09A<00`0C00084`0301<C024C00<04`001a<00`0C000R4`0301<000LC0P0S4`03

01<000PC00<04a<0:1<00`0C4`104`0301<C01TC0P0S4`800a<301<C00<04a<031<200@C0P0Q4`80

0a<3024C0P044`0301<C020C0P044`8000<C01<0<a<0038C00<04a<09A<00`0C00074`0301<0028C

00<04`0021<2028C00<04`001a<00`0C4`0R4`0301<000LC00<04`00:A<00`0C4`104`0301<C01TC

00<04a<0?A<00`0C4`284`0301<C00DC00<04a<0<Q<0038C00<04a<09Q<00`0C4`074`0301<C028C

00<04a<021<00`0C4`0Q4`0301<C00LC0P0S4`0301<C00LC00<04a<09a<2048C00<04a<06A<00`0C

4`0m4`0301<C08TC0P054`0301<C038C000b4`0301<C0?lC;1<00`0C4`0I4`0301<C03dC00<04a<0

Ra<01@0C4a<003DC000b4`0301<C0?lC;1<00`0C4`0I4`0301<C03dC00<04a<0Ra<0100C4`0C4`@0

7a<0038C00<04a<0oa</4`0301<C01TC00<04a<0?A<00`0C4`2<4`8051<3020C000b4`0301<C0?LC

0`0[4ol02Q<00`0C4`0N4`00<Q<00`0C4`2c4a`=:A<00`0C4`0[4`0301<C008C00@04a<021<00`0C

4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC

00<04a<01A<00`0C4`034`0301<000LC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C

4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC

00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<300HC00<04a<031<2020C000/4jl03@dL01X=

1P094`0301<C030C00<04a<06A<00`0C4`0V4`0301<C01@C00<04a<041<00`0C4`0V4`0301<C02HC

00<04a<09Q<0100C4`0f4`00<Q<00`0C4`084`0301<C00TC00<04a<02A<00`0C4`094`0301<C00PC

00<04a<02A<00`0C4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0C

4`094`0301<C00HC1`d74`0301<C00TC00<04a<02A<00`0C4`084`0301<C00TC00<04a<02A<00`0C

4`0<4`@0<1<00`0C4`0I4`0301<C03dC00<04a<0Ra<01@0C4a<003DC000b4`0301<C02`C00<04a<0

6A<00`dC4`0@4`0301<C02`C00<04a<021<:3AXC00<04a<0;1<00`0C4`104`0301<C01TC00<04a<0

?A<00`0C4`2:4`0301<C008C00<04a<0<a<0038C00<04a<0=Q<T3C<C20fF4`0301<C01TC00<04a<0

?A<00`0C4`294`0301<C00@C00<04a<0<Q<0038C00<04a<0<A<53B@C4@dI4`T=WQ<00`0C4`0I4`80

?Q<00`0C4`274`801a<00`0C4`0b4`00<Q<00`0C4`0/4`D=>Q<I3JLC00<04a<06A<00`0C4`0m4`03

01<C08LC00<04a<01Q<00`0C4`0b4`00<Q<00`0C4`0X4`@=oa<14`0301<C01PC00<04a<0?A<00`0C

4`264`0301<C00PC00<04a<0<A<0038C00<04a<08a<53OlC1A<00`0C4`0H4`0301<C03dC00<04a<0

Q1<200/C00<04a<0<A<0038C00<04a<07Q<53OlC2Q<00`0C4`0H4`0301<C03dC00<04a<0Pa<00`0C

4`0;4`0301<C034C000b4`0301<C01TC1@go4`lC00<04a<061<00`0C4`0m4`0301<C088C00<04a<0

31<00`0C4`0a4`00<Q<00`0C4`0C4`H=oa<D4`0301<C01PC0P0n4`0301<C080C0P0?4`0301<C034C

000b4`0301<C00hC1@go4aXC00<04a<061<00`0C4`0m4`0301<C07lC00<04a<041<00`0C4`0`4`00

<Q<00`0C4`044`X=oa<O4`0301<C01PC00<04a<0?Q<00`0C4`1l4`804a<00`0C4`0`4`00<Q<73OlC

:A<00`0C4`0H4`0301<C03hC00<04a<0Na<201@C00<04a<0<1<0038C00<04a<0oa<]4`0301<C01PC

00<04a<0?Q<00`0C4`1i4`805Q<00`0C4`0`4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`03

01<C07PC00<04a<05Q<00`0C4`0`4`00<Q<00`0C4`3o4bhC00<04a<05a<203lC00<04a<0MQ<201TC

00<04a<0<1<0038C00<04a<0oa<^4`0301<C01LC00<04a<0?Q<00`0C4`1d4`8071<00`0C4`0_4`00

71<00`0C4`024`0401<C4`<00a<00`0C4`044`0301<C0?lC;Q<00`0C4`0G4`0301<C03hC00<04a<0

La<00`0C4`0L4`0301<C02lC000K4`0301<000LC00<04a<00Q<00`0C00054`0301<C0?lC;Q<00`0C

4`0G4`0301<C03lC00<04a<0L1<201lC00<04a<0;a<001/C00<04`0021<00`0C4`034`0301<C00<C

0P3o4c0C00<04a<05Q<00`0C4`0o4`0301<C06dC0`0Q4`0301<C02lC000K4`0301<000PC00@04a<C

0P064`0301<C0?lC;a<00`0C4`0F4`0301<C03lC00<04a<0K1<202<C00<04a<0;a<001/C00<04`00

1a<00`0C00024`0301<C00DC00<04a<0oa<_4`0301<C01HC0P104`0301<C06XC0P0U4`0301<C02lC

000L4`0301<C00LC00@04a<C0`054`0301<C0?lC;a<00`0C4`0F4`0301<C03lC00<04a<0J1<202LC

00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC00<04a<0?a<00`0C4`1V4`80:A<00`0C4`0_4`00

<Q<00`0C4`3o4c0C00<04a<05A<00`0C4`0o4`0301<C06@C0P0Z4`0301<C030C000b4`0301<C0?lC

<1<00`0C4`0?4`0301<C00<C00<04a<0?a<00`0C4`1R4`80;1<00`0C4`0`4`00<Q<00`0C4`3o4c0C

00<04a<03Q<00`0C00044`0301<C040C00<04a<0GQ<302hC00<04a<0<1<0038C00<04a<0oa<`4`03

01<C010C00<04a<00Q<3040C00<04a<0G1<3030C00<04a<0<1<0038C00<04a<0oa<a4`0301<C00dC

0P054`0301<C040C00<04a<0FQ<2038C0P0b4`00<Q<00`0C4`3o4c4C00<04a<03A<00`0C4`044`03

01<C044C00<04a<0Ea<203@C00<04a<0<A<0038C00<04a<0oa<b4`0301<C00`C0`044`0301<C044C

00<04a<0E1<303HC00<04a<0<A<0038C00<04a<0oa<b4`0301<C01<C00<04a<0@A<00`0C4`1B4`<0

=a<203<C000b4`0301<C0?lC<a<00`0C4`0B4`80@Q<00`0C4`1?4`<0>Q<00`0C4`0b4`00<Q<00`0C

4`3o4c<C00<04a<04Q<00`0C4`124`0301<C04`C0`0l4`0301<C038C000b4`0301<C0?lC=1<00`0C

4`0A4`0301<C048C00<04a<0BA<303hC00<04a<0<a<0038C00<04a<0oa<d4`0301<C014C00<04a<0

@Q<00`0C4`174`<0@1<00`0C4`0c4`008A<00`0C4`024`0301<C008C00<04a<011<00`0C4`3o4cDC

00<04a<041<00`0C4`124`0301<C04@C0`124`80=A<0020C00<04`001a<00`0C00054`0301<C0?lC

=A<00`0C4`0@4`0301<C04<C00<04a<0@1<304DC00<04a<0=1<0020C00<04`002A<00`0C4`034`80

oa<g4`0301<C00lC0P144`0301<C03dC0`174`80=Q<0020C00<04`001a<200HC00<04a<0oa<f4`03

01<C00lC00<04a<0A1<00`0C4`0i4`<0BQ<00`0C4`0e4`0081<00`0C00074`0301<C00DC00<04a<0

oa<g4`0301<C00hC00<04a<0A1<00`0C4`0f4`@0Ba<203LC000Q4`0301<C00HC0`054`0301<C0?lC

>1<00`0C4`0=4`0301<C04@C00<04a<0<a<304lC00<04a<0=Q<0038C00<04a<0oa<i4`0301<C00`C

00<04a<0AA<00`0C4`0_4`<0DA<00`0C4`0g4`00<Q<00`0C4`3o4cTC00<04a<031<00`0C4`154`03

01<C02/C101C4`80>A<0038C00<04a<0oa<j4`0301<C00/C0P174`0301<C02LC101F4`0301<C03PC

000b4`0301<C0?lC>Q<00`0C4`0;4`0301<C04HC00<04a<08a<505PC0P0j4`00<Q<00`0C4`3o4c/C

0P0;4`0301<C04HC00<04a<081<405/C0P0k4`00<Q<00`0C4`3o4cdC00<04a<021<00`0C4`174`03

01<C01/C101O4`0301<C03XC000b4`0301<C0?lC?Q<00`0C4`074`0301<C04LC0P0H4`D0HA<00`0C

4`0k4`00<Q<00`0C4`3o4chC00<04a<01a<00`0C4`184`0301<C01<C101T4`80?A<0038C00<04a<0

oa<o4`0301<C00HC0P1:4`0301<C00hC101W4`80?Q<0038C00<04a<0oa=04`801Q<00`0C4`194`03

01<C00XC101Z4`80?a<0038C00<04a<0oa=24`0301<C00<C00<04a<0BQ<00`0C4`054`D0K1<2040C

000b4`0301<C0?lC@a<200<C00<04a<0BQ<200034`0000<0L1<2044C000b4`0301<C0?lC>a<5008C

00@04a<00Q<00`0C4`194`D0La<2048C000L4`0301<C008C00<04a<00Q<00`0C4`024`0301<C00@C

00<04a<0oa<m4`0701<C4`0C00024`<0Aa<5008C00<04a<0LA<204<C000K4`0301<000PC00L04a<C

01<000DC00<04a<0oa<m4`0701<C4`0C00044`<0@1<500PC00<04a<0KQ<204DC000K4`0301<000PC

00<04a<00a<00`0C4`034`80oa<n4`0701<C4`0C00044`0401<003XC1@0=4`0301<C06dC0P164`00

6a<00`0C00094`0301<C00801Q<00`0C4`3o4cdC00L04a<C01<000@C00@04a<C0`0a4`H04a<206/C

0`174`006a<00`0C00074`0301<0008C00<04a<01A<00`0C4`3o4c`C0P044`0301<C00<C00<04a<0

11<302PC1`0I4`80JA<204TC000L4`0301<C00HC0`024`<01A<00`0C4`3o4dPC00<04a<01a<501/C

2@0P4`0301<C06@C0`1;4`00<Q<00`0C4`3o4dPC00<04a<031<L02TC0P1R4`<0CA<0038C00<04a<0

oa=84`80Da<205lC0`1?4`00<Q<00`0C4`3o4dPC00<04a<0Da<205XC101B4`00<Q<00`0C4`3o4dPC

00<04a<0E1<205HC101E4`00<Q<00`0C4`3o4dPC00<04a<0EQ<204lC1@1I4`00<Q<00`0C4`3o4dPC

00<04a<0Ea<304PC1P1M4`00<Q<00`0C4`3o4dPC00<04a<0FA<3040C1`1R4`00<Q<00`0C4`3o4dPC

0P1L4`<0>1<706PC000b4`0301<C0?lCB1<00`0C4`1N4`<0;Q<806hC000b4`0301<C0?lCB1<00`0C

4`1P4`D08a<807DC000b4`0301<C0?lCB1<00`0C4`1T4`L051<:07`C000b4`0301<C0?lCB1<00`0C

4`1Z4aD0QQ<0038C00<04a<0oa=84`0301<C0?lC1Q<002TC1@044`0301<C0?lCB1<20?lC1a<002/C

00<04a<011<00`0C4`3o4dPC00<04a<0oa<64`00:a<00`0C4`044`80oa=94`0301<C0?lC1Q<002/C

00<04a<0oa?o4ePC000[4`0301<C0?lCoa=H4`00:Q<20?lCoa=J4`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4olCQQ<0074C10000a<0000700034`0000@C00<04a<00Q<0100C4a<200<C

0P034`800a<200<C0P034`800a<200<C0P034`800a<200<C0P034`8011<0100C4a<200@C00<04a<0

oa>/4`00LA<300PC00<04a<00a<00`0C4`054`0301<000@C00<04a<00Q<00`0C4`024`0301<C008C

00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C

4`024`0601<C01<011<01P0C4`0C0:8C0P3o4`TC001c4`0301<C00@00Q<00`0C4`024`0301<C00PC

00D04a<C00044`800a<200<C0P034`800a<200<C0P034`800a<200<C0P034`800a<2008C00<04`00

0a<2008C00<04`00Xa<00`0C4`3o4`LC000I4`@000<C00001P024`X00Q<2008C0`024`<00a<20006

4`0001<09a<200PC00<04a<00a<00`0C4`054`801A<01P0C4`0C008C00<04`000Q<00`0C00024`03

01<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0a<01`0C4a<04`000a<00`0C4`2P4`<00Q<00`0C4`3o4`@C000J4`0601<C01<00Q<00`0C00044`06

01<C01<00Q<00`0C00054`0301<C008C00D04a<C00024`0401<04`80<A<01`0C4a<04`001a<00`0C

4`024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C

00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C

00044`0301<C09TC00P04a<04`0C0?lC1A<001XC00H04a<04`044`0301<C008C00<04a<00Q<00`0C

4`024`0301<C00<C00<04a<00Q<01@0C4a<0008C00@04`0C0P0`4`8011<00`0C4`064`<00a<00`0C

4`024`800a<200<C0P034`800a<200<C0P034`800a<200<C0P034`800a<200<C00<04a<00Q<200<C

00<04a<00Q<00`0C4`2J4`0801<C01<04`3o4`DC000J4`0501<C01<00P034`800a<00`0C4`024`80

0a<00`0C4`034`0301<C008C00D04a<C00024`0601<001<0oa<_4`<000@C01<0oa<54`006Q<01P0C

4`0C008C00<04`000Q<00`0C00044`0>01<C01<04`0C01<04`024`0501<C4`000Q<01P0C000C0?lC

<a<00`0C003o4`DC000I4`@000<C00002`024`D000DC00004`0500044`0000<C0P0011<001<20?lC

=1<00`0C4`3o4`@C003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC

003o4olCQQ<00?lCoa>64`00oa?o4hHC0000\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.77084, -14.119, 0.0242408, 0.16996}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -57 0 ]

[.5 .63053 57 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -118 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(13.4600000000000008`) show

173.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .34853 m

.02499 .34853 L

.02606 .34853 L

.02729 .34852 L

.02846 .34851 L

.03053 .34849 L

.03279 .34845 L

.03527 .34841 L

.0379 .34834 L

.04262 .34819 L

.05205 .34777 L

.06245 .34712 L

.07293 .34627 L

.0842 .34516 L

.10458 .34267 L

.14581 .33627 L

.18551 .32939 L

.22371 .3233 L

.24502 .3205 L

.26435 .31845 L

.27403 .31763 L

.2845 .31689 L

.29439 .31635 L

.30348 .31599 L

.30818 .31585 L

.31077 .31578 L

.31322 .31573 L

.31549 .31569 L

.31797 .31566 L

.32022 .31563 L

.32231 .31562 L

.32349 .31561 L

.32476 .3156 L

.32597 .3156 L

.32707 .3156 L

.32829 .3156 L

.32898 .3156 L

.32963 .31561 L

.33093 .31561 L

.33233 .31562 L

.3337 .31563 L

.33519 .31565 L

.3379 .31568 L

.34297 .31577 L

.34786 .31588 L

.35243 .31601 L

.36284 .31639 L

.38389 .31745 L

.42271 .31995 L

.44246 .32125 L

Mistroke

.46399 .32247 L

.47398 .32294 L

.48462 .32334 L

.48979 .3235 L

.49466 .32362 L

.49936 .32372 L

.50375 .32379 L

.506 .32381 L

.50842 .32384 L

.5098 .32385 L

.5111 .32386 L

.51227 .32386 L

.51354 .32387 L

.51478 .32387 L

.51548 .32387 L

.51614 .32387 L

.51684 .32387 L

.51747 .32387 L

.51817 .32386 L

.51891 .32386 L

.52014 .32386 L

.52128 .32385 L

.52387 .32383 L

.52628 .3238 L

.52856 .32377 L

.53281 .3237 L

.53739 .32359 L

.54235 .32345 L

.55184 .32311 L

.56227 .32261 L

.58332 .32126 L

.62371 .31763 L

.66259 .3135 L

.70392 .30934 L

.72459 .30762 L

.74373 .30635 L

.76229 .30544 L

.77167 .30511 L

.77672 .30497 L

.78203 .30485 L

.78684 .30476 L

.78939 .30472 L

.79211 .30469 L

.79461 .30466 L

.7969 .30465 L

.79799 .30464 L

.79919 .30463 L

.80031 .30463 L

.80135 .30463 L

.80255 .30462 L

Mistroke

.80384 .30462 L

.80506 .30462 L

.80617 .30462 L

.80747 .30463 L

.80821 .30463 L

.80889 .30463 L

.81148 .30464 L

.81288 .30465 L

.8142 .30466 L

.81667 .30469 L

.8222 .30475 L

.82686 .30483 L

.83197 .30493 L

.84229 .30518 L

.86077 .30576 L

.90122 .3073 L

.92121 .30802 L

.93105 .30832 L

.94014 .30856 L

.94836 .30874 L

.95741 .30889 L

.96211 .30894 L

.96652 .30898 L

.96895 .309 L

.97118 .30901 L

.97234 .30901 L

.97362 .30901 L

.97426 .30902 L

.97495 .30902 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.0475 .17847 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4gdC00<04a<0oa<64`00oa=m4`0301<C0?lC1Q<002TC1@3o4dlC0P3o4`LC

000[4`0301<C0?lCCa<00`0C4`1^4`d0RQ<002DC0`034`0301<C00@C0P3o4dTC00<04a<0IQ<800`C

3@1n4`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`1Q4`D081<807LC000[4`0301<C00@C00<04a<0

oa=84`0301<C05hC100/4`L0L1<002XC0P064`0301<C0?lCB1<00`0C4`1L4`<0=A<706XC000b4`03

01<C0?lCB1<205/C0P0o4`H0I1<0038C00<04a<0oa=84`0301<C05PC0P164`H0Ga<0038C00<04a<0

oa=84`0301<C05HC0P1>4`D0FQ<0038C00<04a<0oa=84`0301<C05DC0P1C4`D0EQ<0038C00<04a<0

oa=84`0301<C05@C00<04a<0Ea<5058C000b4`0301<C0?lCB1<205<C0P1N4`<0D1<0038C00<04a<0

oa=84`0301<C00lC5P0/4`80HA<404dC000b4`0301<C0?lCB1<00`0C4`0:4`D05Q<9028C0P1U4`<0

Ba<0038C00<04a<0oa=84`0301<C00DC1@0S4`L06a<206PC0`194`00<Q<00`0C4`3o4c/C1@024`03

01<C00<C00<04a<00a<202lC1P0D4`80Ja<204PC000b4`0301<C0?lC?A<01`0C4a<04`0011<00`0C

4`0303HC1P0>4`80KA<304HC000b4`0301<C0?lC=a<300<C00L04a<C01<000@C0`0n4`H02A<00`0C

4`1^4`80AA<0038C00<04a<0oa<m4`0701<C4`0C00034`80AA<500@C00<04a<0L1<204@C000L4`03

01<C008C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0oa<m4`0701<C4`0C00024`0301<004XC

1@1d4`80@Q<001/C00<04`0021<01`0C4a<04`001A<00`0C4`3o4c`C0P044`0401<0008C00<04a<0

Ba<6074C0P114`005Q<3008C00<04`0021<00`0C4`034`0301<C00<C0P3o4d<C0P044`0301<C04XC

00<04a<011<406hC0P104`006a<00`0C00094`0301<C00801Q<00`0C4`3o4d4C00<04a<011<00`0C

4`194`0301<C00TC101[4`0301<C03hC000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C0?lC

@1<00`0C4`054`80BQ<00`0C4`0=4`@0J1<203hC000L4`0301<C00HC0`024`<01A<00`0C4`3o4clC

00<04a<01Q<00`0C4`184`0301<C018C101U4`0301<C03`C000b4`0301<C0?lC?Q<00`0C4`074`03

01<C04PC00<04a<05A<5068C00<04a<0>a<0038C00<04a<0oa<m4`0301<C00PC00<04a<0Aa<00`0C

4`0J4`@0Ga<203`C000b4`0301<C0?lC?1<00`0C4`094`0301<C04HC00<04a<07a<405`C0P0k4`00

<Q<00`0C4`3o4c/C00<04a<02Q<00`0C4`164`0301<C028C1@1I4`0301<C03TC000b4`0301<C0?lC

>Q<00`0C4`0;4`80Aa<00`0C4`0V4`@0Ea<00`0C4`0h4`00<Q<00`0C4`3o4cTC00<04a<031<00`0C

4`154`0301<C02XC101D4`80>A<0038C00<04a<0oa<i4`0301<C00`C00<04a<0AA<00`0C4`0^4`@0

DA<00`0C4`0g4`00<Q<00`0C4`3o4cPC00<04a<03A<00`0C4`144`0301<C03<C0P1?4`80>1<0038C

00<04a<0oa<g4`0301<C00hC00<04a<0A1<00`0C4`0e4`@0C1<203LC000b4`0301<C0?lC=Q<00`0C

4`0?4`0301<C04@C00<04a<0>A<204/C00<04a<0=A<0038C00<04a<0oa<f4`0301<C00lC0P144`03

01<C03`C10174`80=Q<0038C00<04a<0oa<e4`0301<C010C00<04a<0@a<00`0C4`0o4`<0AQ<00`0C

4`0d4`00<Q<00`0C4`3o4cDC00<04a<041<00`0C4`134`0301<C048C0`134`80=A<0024C00<04a<0

0Q<00`0C4`024`0301<C00@C00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`164`<0@A<00`0C

4`0c4`0081<00`0C00074`0301<000DC00<04a<0oa<a4`043A<C01<C00<04a<0@Q<00`0C4`194`80

?a<00`0C4`0c4`006a<3008C00<04`002A<00`0C4`034`80oa<_4`H=51<00`0C4`124`0301<C04/C

0`0m4`0301<C038C000P4`0301<000LC0P064`0301<C0?lC;A<93A8C0P134`0301<C04hC0P0k4`03

01<C038C000P4`0301<000LC00<04a<01A<00`0C4`3o4bdC2@dB4`0301<C044C00<04a<0DA<303PC

00<04a<0<Q<0024C00<04a<01Q<300DC00<04a<0oa<]4`T=4Q<00`0C4`114`0301<C05@C0P0g4`03

01<C034C000b4`0301<C0?lC;1<;3A4C00<04a<0@A<00`0C4`1F4`<0=1<00`0C4`0a4`00<Q<00`0C

4`3o4bdC2@d<4`0301<C00<C00<04a<0@1<00`0C4`1I4`<0<Q<2038C000b4`0301<C0?lC;A<93@/C

00<04`0011<00`0C4`104`0301<C05`C0P0a4`0301<C030C000b4`0301<C0?lC;A<93@HC0`044`03

01<C008C0`104`0301<C05hC0P0_4`0301<C030C000b4`0301<C0?lC;Q<63@dC0P054`0301<C03lC

00<04a<0HA<302`C00<04a<0<1<0038C00<04a<0oa<`4`0300dC00hC00<04a<011<00`0C4`0o4`03

01<C06@C00<04a<0:A<00`0C4`0`4`00<Q<00`0C4`3o4blC00<04a<03a<300@C00<04a<0?a<00`0C

4`1U4`<0:1<2034C000b4`0301<C0?lC;a<00`0C4`0F4`0301<C03lC00<04a<0J1<00`0C4`0V4`03

01<C02lC000b4`0301<C0?lC;a<00`0C4`0F4`0301<C03lC00<04a<0JA<302DC00<04a<0;a<0038C

00<04a<0oa<_4`0301<C01HC0P104`0301<C06`C0P0S4`0301<C02lC000b4`0301<C0?lC;a<00`0C

4`0F4`0301<C03lC00<04a<0KA<2028C00<04a<0;a<0038C00<04a<0oa<_4`0301<C01HC00<04a<0

?a<00`0C4`1_4`8081<00`0C4`0_4`00<Q<00`0C4`3o4bhC00<04a<05a<00`0C4`0n4`0301<C078C

0P0N4`0301<C02lC000L4`0301<C008C00@04a<C0`034`0301<C00@C00<04a<0oa<^4`0301<C01LC

00<04a<0?Q<00`0C4`1d4`8071<00`0C4`0_4`006a<00`0C00074`0301<C008C00<04`001A<00`0C

4`3o4bhC00<04a<05a<203lC00<04a<0MQ<201XC00<04a<0;a<001HC0`024`0301<000PC00<04a<0

0a<00`0C4`034`80oa<_4`0301<C01LC00<04a<0?Q<00`0C4`1h4`0301<C01HC00<04a<0<1<001/C

00<04`0021<0100C4a<200HC00<04a<0oa<]4`0301<C01PC00<04a<0?Q<00`0C4`1i4`805Q<00`0C

4`0`4`006a<00`0C00074`0301<0008C00<04a<01A<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`03

01<C07/C00<04a<04a<00`0C4`0`4`0071<00`0C4`074`0401<C4`<01A<00`0C4`3o4bdC00<04a<0

61<00`0C4`0n4`0301<C07`C00<04a<04Q<00`0C4`0`4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C

4`0m4`0301<C07hC0P0B4`0301<C030C000b4`0301<C0?lC;A<00`0C4`0H4`80?Q<00`0C4`204`80

41<00`0C4`0`4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0Q4`D00Q<00`0C4`0B4`0301<C00/C

1@000a<0000Q4`D00Q<00`0C4`0O4`D00Q<00`0C4`0K4`0401<C4`D000<C00000a<00`0C4`0a4`00

<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0S4`0701<C4`0C000C4`0301<C00dC00L04a<C01<0028C

00<04a<00Q<00`0C4`0Q4`0701<C4`0C000L4`8011<00`0C4`034`0401<C03<C000b4`0301<C02HC

00<04a<00Q<0100C4a<302<C00<04a<00Q<00`0C4`024`<08Q<00`0C4`024`0401<C4`8091<00`0C

4`024`0301<C008C00<04a<09Q<5044C00<04a<061<00`0C4`0S4`0301<C00<C00<04a<04A<00`0C

4`0=4`0701<C4`0C000R4`0301<C008C00<04a<08A<01`0C4a<04`007Q<01@0C4a<000@C0P024`03

01<C034C000b4`0301<C02DC00<04`001a<00`0C4`0R4`0301<000TC00<04a<081<00`0C00074`03

01<0028C00<04`001a<00`0C000Y4`0301<C044C00<04a<061<00`0C4`0S4`0401<C4`8051<00`0C

4`0=4`0401<C4`808a<00`0C4`034`0301<C020C00<04a<00Q<00`0C4`0N4`8000<C01<00Q<00`0C

00024`0301<C034C000b4`0301<C02DC00<04`0021<00`0C4`0Q4`0301<000LC100Q4`0301<000LC

00<04`008Q<00`0C00074`0301<002TC00<04a<0@1<00`0C4`0I4`0301<C02<C00D04a<C000E4`03

01<C00dC00D04a<C000T4`0701<C4`0C000R4`0701<C4`0C000Q4`800a<01@0C01<003@C000b4`03

01<C02DC00<04`0021<00`0C4`0Q4`0301<000LC00<04`008Q<00`0C00074`808a<00`0C00084`03

01<C02PC00<04a<0@1<00`0C4`0I4`808a<200<C0`0C4`0301<C00`C0P044`808A<200<C0`0Q4`80

11<00`0C4`0P4`8011<200034`0C03<C000b4`0301<C02DC00<04`001a<00`0C000R4`0301<000PC

0P0R4`0301<000LC00<04a<08Q<00`0C00074`0301<002TC00<04a<0@1<00`0C4`0I4`0301<C03dC

00<04a<0R1<00`0C4`054`0301<C038C000b4`0301<C02HC00<04a<01a<00`0C4`0R4`0301<C00PC

00<04a<08A<00`0C4`074`808a<00`0C4`074`0301<C02LC0P124`0301<C01TC00<04a<0?A<00`0C

4`294`801A<00`0C4`0b4`00<Q<00`0C4`3o4b`C00<04a<06A<00`0C4`0m4`0301<C08/C00D04a<C

000e4`00<Q<00`0C4`3o4b`C00<04a<06A<00`0C4`0m4`0301<C08/C00@04a<04a<401lC000b4`03

01<C0?lC;1<00`0C4`0I4`0301<C03dC00<04a<0S1<201@C0`0P4`00<Q<00`0C4`3g4`<0:a?o00XC

00<04a<07Q<0038C00<04a<0]a<?3C8C00<04a<0:a<00`0C4`024`0401<C00PC00<04a<01A<00`0C

4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC

00<04a<00a<00`0C00074`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C

4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC

00<04a<01A<00`0C4`054`0301<C00DC0`064`0301<C00`C0P0P4`00;1>a00l=3`0S3@H02A<00`0C

4`0`4`0301<C01TC00<04a<09Q<00`0C4`0D4`0301<C010C00<04a<09Q<00`0C4`0V4`0301<C02HC

00@04a<0=Q<0038C00<04a<021<00`0C4`094`0301<C00TC00<04a<02A<00`0C4`084`0301<C00TC

00<04a<02A<00`0C4`094`0301<C00PC00<04a<02A<00`0C4`094`0301<C00TC00<04a<02A<00`0C

4`074`P=1A<00`0C4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC00<04a<031<4030C

00<04a<06A<00`0C4`0m4`0301<C08/C00D04a<C000e4`00<Q<00`0C4`0/4`0301<C00dC5`d84`03

01<C02`C00<04a<02A<:3ATC00<04a<0;1<00`0C4`104`0301<C01TC00<04a<0?A<00`0C4`2:4`03

01<C008C00<04a<0<a<0038C00<04a<0<A<;3ALC50dN4a4=UA<00`0C4`0I4`0301<C03dC00<04a<0

RA<00`0C4`044`0301<C038C000b4`0301<C02`C1@df4ah=YQ<00`0C4`0I4`80?Q<00`0C4`274`80

1a<00`0C4`0b4`00<Q<00`0C4`0X4`@=oa<00`0C4`0I4`0301<C03dC00<04a<0Qa<00`0C4`064`03

01<C038C000b4`0301<C024C1`go4`DC00<04a<061<00`0C4`0m4`0301<C08HC00<04a<021<00`0C

4`0a4`00<Q<00`0C4`0I4`P=oa<<4`0301<C01PC00<04a<0?A<00`0C4`244`802a<00`0C4`0a4`00

<Q<00`0C4`0C4`H=oa<D4`0301<C01PC00<04a<0?A<00`0C4`234`0301<C00/C00<04a<0<A<0038C

00<04a<02a<83OlC6Q<00`0C4`0H4`0301<C03dC00<04a<0PQ<00`0C4`0<4`0301<C034C000b4`h=

oa<R4`0301<C01PC0P0n4`0301<C080C0P0?4`0301<C034C000b4`0301<C0?lC;A<00`0C4`0H4`03

01<C03dC00<04a<0Oa<00`0C4`0@4`0301<C030C000b4`0301<C0?lC;A<00`0C4`0H4`0301<C03hC

00<04a<0O1<201<C00<04a<0<1<0038C00<04a<0oa<]4`0301<C01PC00<04a<0?Q<00`0C4`1k4`80

51<00`0C4`0`4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`0301<C07TC0P0F4`0301<C030C

000b4`0301<C0?lC;A<00`0C4`0H4`0301<C03hC00<04a<0N1<00`0C4`0F4`0301<C030C000b4`03

01<C0?lC;Q<00`0C4`0G4`80?a<00`0C4`1f4`806A<00`0C4`0`4`00<Q<00`0C4`3o4bhC00<04a<0

5a<00`0C4`0n4`0301<C07@C0P0L4`0301<C02lC000L4`0301<C008C00@04a<C0`034`0301<C00@C

00<04a<0oa<^4`0301<C01LC00<04a<0?Q<00`0C4`1c4`0301<C01`C00<04a<0;a<001/C00<04`00

1a<00`0C4`024`0301<000DC00<04a<0oa<^4`0301<C01LC00<04a<0?a<00`0C4`1`4`807a<00`0C

4`0_4`006a<00`0C00084`0301<C00<C00<04a<00a<20?lC<1<00`0C4`0F4`0301<C03lC00<04a<0

KA<3024C00<04a<0;a<001/C00<04`0021<0100C4a<200HC00<04a<0oa<_4`0301<C01HC00<04a<0

?a<00`0C4`1/4`808a<00`0C4`0_4`006a<00`0C00074`0301<0008C00<04a<01A<00`0C4`3o4blC

00<04a<05Q<2040C00<04a<0JQ<202DC00<04a<0;a<001`C00<04a<01a<0100C4a<300DC00<04a<0

oa<_4`0301<C01HC00<04a<0?a<00`0C4`1X4`809a<00`0C4`0_4`00<Q<00`0C4`3o4blC00<04a<0

5Q<00`0C4`0o4`0301<C06HC0P0Y4`0301<C02lC000b4`0301<C0?lC<1<00`0C4`0E4`0301<C03lC

00<04a<0I1<202XC00<04a<0<1<0038C00<04a<0oa<`4`0301<C00lC00<04a<00a<00`0C4`0o4`03

01<C068C0P0/4`0301<C030C000b4`0301<C0?lC<1<00`0C4`0>4`0301<000@C00<04a<0@1<00`0C

4`1N4`<0;Q<00`0C4`0`4`00<Q<00`0C4`3o4c0C00<04a<041<00`0C4`024`<0@1<00`0C4`1L4`<0

<1<00`0C4`0`4`00<Q<00`0C4`3o4c4C00<04a<03A<200DC00<04a<0@1<00`0C4`1J4`80<Q<2038C

000b4`0301<C0?lC<A<00`0C4`0=4`0301<C00@C00<04a<0@A<00`0C4`1G4`80=1<00`0C4`0a4`00

<Q<00`0C4`3o4c8C00<04a<031<300@C00<04a<0@A<00`0C4`1D4`<0=Q<00`0C4`0a4`00<Q<00`0C

4`3o4c8C00<04a<04a<00`0C4`114`0301<C058C0`0g4`80<a<0038C00<04a<0oa<c4`0301<C018C

0P124`0301<C04lC0`0j4`0301<C038C000b4`0301<C0?lC<a<00`0C4`0B4`0301<C048C00<04a<0

C1<303`C00<04a<0<Q<0038C00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`194`<0?Q<00`0C

4`0c4`00<Q<00`0C4`3o4c@C00<04a<04A<00`0C4`124`0301<C04LC0`104`0301<C03<C000Q4`03

01<C008C00<04a<00Q<00`0C4`044`0301<C0?lC=A<00`0C4`0@4`0301<C048C00<04a<0A1<3048C

0P0e4`0081<00`0C00074`0301<000DC00<04a<0oa<e4`0301<C010C00<04a<0@a<00`0C4`104`<0

AA<00`0C4`0d4`0081<00`0C00094`0301<C00<C0P3o4cLC00<04a<03a<204@C00<04a<0?A<304LC

0P0f4`0081<00`0C00074`801Q<00`0C4`3o4cHC00<04a<03a<00`0C4`144`0301<C03TC0`1:4`03

01<C03DC000P4`0301<000LC00<04a<01A<00`0C4`3o4cLC00<04a<03Q<00`0C4`144`0301<C03HC

101;4`80=a<0024C00<04a<01Q<300DC00<04a<0oa<h4`0301<C00dC00<04a<0A1<00`0C4`0c4`<0

Ca<00`0C4`0f4`00<Q<00`0C4`3o4cTC00<04a<031<00`0C4`154`0301<C02lC0`1A4`0301<C03LC

000b4`0301<C0?lC>A<00`0C4`0<4`0301<C04DC00<04a<0:a<405<C0P0i4`00<Q<00`0C4`3o4cXC

00<04a<02a<204LC00<04a<09a<405HC00<04a<0>1<0038C00<04a<0oa<j4`0301<C00/C00<04a<0

AQ<00`0C4`0S4`D0F1<203XC000b4`0301<C0?lC>a<200/C00<04a<0AQ<00`0C4`0P4`@0Fa<203/C

000b4`0301<C0?lC?A<00`0C4`084`0301<C04LC00<04a<06a<405lC00<04a<0>Q<0038C00<04a<0

oa<n4`0301<C00LC00<04a<0Aa<201PC1@1Q4`0301<C03/C000b4`0301<C0?lC?Q<00`0C4`074`03

01<C04PC00<04a<04a<406@C0P0m4`00<Q<00`0C4`3o4clC00<04a<01Q<204XC00<04a<03Q<406LC

0P0n4`00<Q<00`0C4`3o4d0C0P064`0301<C04TC00<04a<02Q<406XC0P0o4`00<Q<00`0C4`3o4d8C

00<04a<00a<00`0C4`1:4`0301<C00DC1@1/4`80@1<0038C00<04a<0oa=34`800a<00`0C4`1:4`80

00<C00000`1`4`80@A<0038C00<04a<0oa<k4`D00Q<0100C4`024`0301<C04TC1@1c4`80@Q<001`C

00<04a<00Q<00`0C4`024`0301<C008C00<04a<011<00`0C4`3o4cdC00L04a<C01<0008C0`174`D0

0Q<00`0C4`1a4`80@a<001/C00<04`0021<01`0C4a<04`001A<00`0C4`3o4cdC00L04a<C01<000@C

0`104`D021<00`0C4`1^4`80AA<001/C00<04`0021<00`0C4`034`0301<C00<C0P3o4chC00L04a<C

01<000@C00@04`00>Q<500dC00<04a<0KA<204HC000K4`0301<000TC00<04a<00P064`0301<C0?lC

?A<01`0C4a<04`0011<0100C4a<3034C1P0C4`80Ja<304LC000K4`0301<000LC00<04`000Q<00`0C

4`054`0301<C0?lC?1<200@C00<04a<00a<00`0C4`044`<0:1<701TC0P1Y4`80BA<001`C00<04a<0

1Q<3008C0`054`0301<C0?lCB1<00`0C4`074`D06a<9020C00<04a<0I1<304/C000b4`0301<C0?lC

B1<00`0C4`0<4a`0:A<2068C0`1=4`00<Q<00`0C4`3o4dPC0P1C4`80Ga<304lC000b4`0301<C0?lC

B1<00`0C4`1C4`80FQ<4058C000b4`0301<C0?lCB1<00`0C4`1D4`80EQ<405DC000b4`0301<C0?lC

B1<00`0C4`1F4`80Ca<505TC000b4`0301<C0?lCB1<00`0C4`1G4`<0B1<605dC000b4`0301<C0?lC

B1<00`0C4`1I4`<0@1<7068C000b4`0301<C0?lCB1<205`C0`0h4`L0J1<0038C00<04a<0oa=84`03

01<C05hC0`0^4`P0KQ<0038C00<04a<0oa=84`0301<C060C1@0S4`P0MA<0038C00<04a<0oa=84`03

01<C06@C1`0D4`X0O1<0038C00<04a<0oa=84`0301<C06XC5@264`00<Q<00`0C4`3o4dPC00<04a<0

oa<64`00:A<500@C00<04a<0oa=84`80oa<74`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`3o4`HC

000[4`0301<C00@C0P3o4dTC00<04a<0oa<64`00:a<00`0C4`3o4olCF1<002/C00<04a<0oa?o4ePC

000Z4`80oa?o4eXC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00LA<40003

4`0000L000<C000011<00`0C4`024`<000<C000011<00`0C4`024`0301<C008C00<04a<00Q<00`0C

4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C

00<04a<00Q<00`0C4`024`0301<C0?lC[1<0074C0`084`0301<C00<C00<04a<01a<01P0C4`0C008C

00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C

00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C002R4`80oa<94`00

La<00`0C4`04008C00<04a<00Q<00`0C4`064`@000@C01<00Q<00`0C00024`0301<0008C00<04`00

0Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`03

01<0008C00<04`000Q<00`0C00024`0301<00:<C00<04a<0oa<74`006A<400034`0000H00Q<:008C

0P024`<00Q<300<C0P001Q<0000C02LC0P084`0301<C00<C00<04a<01A<00`0C00024`800a<00`0C

00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C

00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00034`0301<C0:0C0`024`0301<C0?lC

11<001XC00H04a<04`024`0301<000@C00H04a<04`024`0301<000DC00<04a<00Q<01@0C4a<0008C

00@04`0C0P0a4`0701<C4`0C00084`800Q<00`0C4`024`0301<0008C00<04`000Q<00`0C00024`03

01<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0Q<00`0C00024`0301<0008C00<04`0011<00`0C4`2I4`0801<C01<04`3o4`DC000J4`0601<C01<0

11<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`034`0301<C008C00D04a<C00024`0401<04`80

<1<200@C00<04a<021<0100C4a<200<C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C

4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C

00<04a<00Q<00`0C4`024`0301<C09XC00P04a<04`0C0?lC1A<001XC00D04a<04`0200<C0P034`03

01<C008C0P034`0301<C00<C00<04a<00Q<01@0C4a<0008C00H04`004`3o4blC0`0011<04`3o4`DC

000J4`0601<C01<00Q<00`0C00024`0301<000@C00h04a<04`0C01<04`0C008C00D04a<C00024`06

01<001<0oa<c4`0301<00?lC1A<001TC10000a<0000;008C1@001A<0000C00D000@C00000a<20004

4`004`80oa<d4`0301<C0?lC11<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC

003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00001\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.77084, -14.119, 0.0242408, 0.16996}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .2943 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.00700719 0.47619 [

[ 0 0 0 0 ]

[ 1 .2943 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .2943 L

0 .2943 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.00700719 0.477324 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.309017 0.309017 [

[.21429 .29652 -9 -9 ]

[.21429 .29652 9 0 ]

[.40476 .29652 -9 -9 ]

[.40476 .29652 9 0 ]

[.59524 .29652 -9 -9 ]

[.59524 .29652 9 0 ]

[.78571 .29652 -9 -9 ]

[.78571 .29652 9 0 ]

[.97619 .29652 -3 -9 ]

[.97619 .29652 3 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.01131 0 -12 -4.5 ]

[.01131 0 0 4.5 ]

[.01131 .07725 -30 -4.5 ]

[.01131 .07725 0 4.5 ]

[.01131 .15451 -24 -4.5 ]

[.01131 .15451 0 4.5 ]

[.01131 .23176 -30 -4.5 ]

[.01131 .23176 0 4.5 ]

[.01131 .38627 -24 -4.5 ]

[.01131 .38627 0 4.5 ]

[.01131 .46353 -18 -4.5 ]

[.01131 .46353 0 4.5 ]

[.01131 .54078 -24 -4.5 ]

[.01131 .54078 0 4.5 ]

[.01131 .61803 -6 -4.5 ]

[.01131 .61803 0 4.5 ]

[.02381 .64303 -27 0 ]

[.02381 .64303 27 16 ]

[.5 .63053 -57 0 ]

[.5 .63053 57 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .30902 m

.21429 .31527 L

s

[(0.2)] .21429 .29652 0 1 Mshowa

.40476 .30902 m

.40476 .31527 L

s

[(0.4)] .40476 .29652 0 1 Mshowa

.59524 .30902 m

.59524 .31527 L

s

[(0.6)] .59524 .29652 0 1 Mshowa

.78571 .30902 m

.78571 .31527 L

s

[(0.8)] .78571 .29652 0 1 Mshowa

.97619 .30902 m

.97619 .31527 L

s

[(1)] .97619 .29652 0 1 Mshowa

.125 Mabswid

.07143 .30902 m

.07143 .31277 L

s

.11905 .30902 m

.11905 .31277 L

s

.16667 .30902 m

.16667 .31277 L

s

.2619 .30902 m

.2619 .31277 L

s

.30952 .30902 m

.30952 .31277 L

s

.35714 .30902 m

.35714 .31277 L

s

.45238 .30902 m

.45238 .31277 L

s

.5 .30902 m

.5 .31277 L

s

.54762 .30902 m

.54762 .31277 L

s

.64286 .30902 m

.64286 .31277 L

s

.69048 .30902 m

.69048 .31277 L

s

.7381 .30902 m

.7381 .31277 L

s

.83333 .30902 m

.83333 .31277 L

s

.88095 .30902 m

.88095 .31277 L

s

.92857 .30902 m

.92857 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(r) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.02381 0 m

.03006 0 L

s

[(-1)] .01131 0 1 0 Mshowa

.02381 .07725 m

.03006 .07725 L

s

[(-0.75)] .01131 .07725 1 0 Mshowa

.02381 .15451 m

.03006 .15451 L

s

[(-0.5)] .01131 .15451 1 0 Mshowa

.02381 .23176 m

.03006 .23176 L

s

[(-0.25)] .01131 .23176 1 0 Mshowa

.02381 .38627 m

.03006 .38627 L

s

[(0.25)] .01131 .38627 1 0 Mshowa

.02381 .46353 m

.03006 .46353 L

s

[(0.5)] .01131 .46353 1 0 Mshowa

.02381 .54078 m

.03006 .54078 L

s

[(0.75)] .01131 .54078 1 0 Mshowa

.02381 .61803 m

.03006 .61803 L

s

[(1)] .01131 .61803 1 0 Mshowa

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

gsave

.02381 .64303 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(DEFLECTION) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .63053 -118 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

68.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

73.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(13.3800000000000007`) show

173.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .3355 m

.02499 .3355 L

.02606 .3355 L

.02729 .33549 L

.02846 .33549 L

.03053 .33547 L

.03279 .33545 L

.03527 .33541 L

.0379 .33537 L

.04262 .33527 L

.05205 .33497 L

.06245 .33452 L

.07293 .33394 L

.0842 .33317 L

.10458 .33145 L

.14581 .32707 L

.18551 .32241 L

.22371 .31833 L

.24502 .31648 L

.26435 .31515 L

.27403 .31463 L

.2845 .31417 L

.29439 .31383 L

.30348 .31362 L

.30818 .31354 L

.31077 .31351 L

.31322 .31348 L

.31549 .31346 L

.3167 .31345 L

.31797 .31345 L

.31904 .31344 L

.32022 .31344 L

.3213 .31344 L

.32231 .31343 L

.32351 .31343 L

.32483 .31344 L

.3255 .31344 L

.32621 .31344 L

.32749 .31344 L

.32878 .31345 L

.32999 .31346 L

.33225 .31347 L

.33493 .3135 L

.33739 .31352 L

.34297 .31361 L

.35266 .31381 L

.36173 .31405 L

.38237 .31479 L

.4212 .31652 L

.44094 .31741 L

Mistroke

.46247 .31824 L

.47247 .31855 L

.4831 .31882 L

.48828 .31892 L

.49314 .31901 L

.49751 .31907 L

.50223 .31911 L

.50462 .31913 L

.50593 .31914 L

.50717 .31915 L

.50832 .31915 L

.50957 .31916 L

.51071 .31916 L

.51176 .31916 L

.51301 .31916 L

.51417 .31916 L

.51545 .31916 L

.51617 .31916 L

.51683 .31916 L

.51809 .31915 L

.51945 .31915 L

.52221 .31913 L

.52498 .31911 L

.5275 .31908 L

.53314 .31901 L

.53836 .31891 L

.54329 .3188 L

.55304 .31854 L

.56334 .31817 L

.58181 .31734 L

.61975 .31503 L

.66014 .31211 L

.69901 .30942 L

.7188 .30826 L

.74034 .30725 L

.75036 .30687 L

.76102 .30655 L

.77011 .30633 L

.78016 .30615 L

.78506 .30609 L

.78774 .30606 L

.79023 .30604 L

.79255 .30602 L

.79465 .30601 L

.79698 .306 L

.79827 .306 L

.79948 .306 L

.80068 .30599 L

.80137 .30599 L

.802 .30599 L

Mistroke

.80329 .30599 L

.80402 .30599 L

.80468 .30599 L

.80586 .30599 L

.80714 .306 L

.80835 .306 L

.80948 .306 L

.81223 .30602 L

.81473 .30603 L

.82033 .30608 L

.82521 .30613 L

.83036 .30619 L

.83959 .30634 L

.86041 .30679 L

.89841 .30778 L

.91957 .3083 L

.9288 .3085 L

.93885 .30869 L

.94881 .30884 L

.9532 .30889 L

.95803 .30894 L

.96257 .30897 L

.96684 .309 L

.96919 .309 L

.97134 .30901 L

.97247 .30901 L

.9737 .30902 L

.97499 .30902 L

.97619 .30902 L

Mfstroke

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.00700719 0.97619 0.287295 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.13633 0.162245 0.309017 0.0231404 [

[.29736 .29652 -6 -9 ]

[.29736 .29652 6 0 ]

[.4596 .29652 -6 -9 ]

[.4596 .29652 6 0 ]

[.62185 .29652 -6 -9 ]

[.62185 .29652 6 0 ]

[.78409 .29652 -6 -9 ]

[.78409 .29652 6 0 ]

[.94634 .29652 -6 -9 ]

[.94634 .29652 6 0 ]

[1.025 .30902 0 -8 ]

[1.025 .30902 9 8 ]

[.12261 .07761 -18 -4.5 ]

[.12261 .07761 0 4.5 ]

[.12261 .19332 -12 -4.5 ]

[.12261 .19332 0 4.5 ]

[.12261 .42472 -6 -4.5 ]

[.12261 .42472 0 4.5 ]

[.12261 .54042 -12 -4.5 ]

[.12261 .54042 0 4.5 ]

[.13511 .64303 -7 0 ]

[.13511 .64303 7 16 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.29736 .30902 m

.29736 .31527 L

s

[(15)] .29736 .29652 0 1 Mshowa

.4596 .30902 m

.4596 .31527 L

s

[(16)] .4596 .29652 0 1 Mshowa

.62185 .30902 m

.62185 .31527 L

s

[(17)] .62185 .29652 0 1 Mshowa

.78409 .30902 m

.78409 .31527 L

s

[(18)] .78409 .29652 0 1 Mshowa

.94634 .30902 m

.94634 .31527 L

s

[(19)] .94634 .29652 0 1 Mshowa

.125 Mabswid

.16756 .30902 m

.16756 .31277 L

s

.20001 .30902 m

.20001 .31277 L

s

.23246 .30902 m

.23246 .31277 L

s

.26491 .30902 m

.26491 .31277 L

s

.3298 .30902 m

.3298 .31277 L

s

.36225 .30902 m

.36225 .31277 L

s

.3947 .30902 m

.3947 .31277 L

s

.42715 .30902 m

.42715 .31277 L

s

.49205 .30902 m

.49205 .31277 L

s

.5245 .30902 m

.5245 .31277 L

s

.55695 .30902 m

.55695 .31277 L

s

.5894 .30902 m

.5894 .31277 L

s

.6543 .30902 m

.6543 .31277 L

s

.68674 .30902 m

.68674 .31277 L

s

.71919 .30902 m

.71919 .31277 L

s

.75164 .30902 m

.75164 .31277 L

s

.81654 .30902 m

.81654 .31277 L

s

.84899 .30902 m

.84899 .31277 L

s

.88144 .30902 m

.88144 .31277 L

s

.91389 .30902 m

.91389 .31277 L

s

.10266 .30902 m

.10266 .31277 L

s

.07021 .30902 m

.07021 .31277 L

s

.03776 .30902 m

.03776 .31277 L

s

.00531 .30902 m

.00531 .31277 L

s

.97879 .30902 m

.97879 .31277 L

s

.25 Mabswid

0 .30902 m

1 .30902 L

s

gsave

1.025 .30902 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(a) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.13511 .07761 m

.14136 .07761 L

s

[(-10)] .12261 .07761 1 0 Mshowa

.13511 .19332 m

.14136 .19332 L

s

[(-5)] .12261 .19332 1 0 Mshowa

.13511 .42472 m

.14136 .42472 L

s

[(5)] .12261 .42472 1 0 Mshowa

.13511 .54042 m

.14136 .54042 L

s

[(10)] .12261 .54042 1 0 Mshowa

.125 Mabswid

.13511 .10075 m

.13886 .10075 L

s

.13511 .12389 m

.13886 .12389 L

s

.13511 .14703 m

.13886 .14703 L

s

.13511 .17017 m

.13886 .17017 L

s

.13511 .21646 m

.13886 .21646 L

s

.13511 .2396 m

.13886 .2396 L

s

.13511 .26274 m

.13886 .26274 L

s

.13511 .28588 m

.13886 .28588 L

s

.13511 .33216 m

.13886 .33216 L

s

.13511 .3553 m

.13886 .3553 L

s

.13511 .37844 m

.13886 .37844 L

s

.13511 .40158 m

.13886 .40158 L

s

.13511 .44786 m

.13886 .44786 L

s

.13511 .471 m

.13886 .471 L

s

.13511 .49414 m

.13886 .49414 L

s

.13511 .51728 m

.13886 .51728 L

s

.13511 .05447 m

.13886 .05447 L

s

.13511 .03133 m

.13886 .03133 L

s

.13511 .00819 m

.13886 .00819 L

s

.13511 .56356 m

.13886 .56356 L

s

.13511 .5867 m

.13886 .5867 L

s

.13511 .60984 m

.13886 .60984 L

s

.25 Mabswid

.13511 0 m

.13511 .61803 L

s

gsave

.13511 .64303 -68 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(q0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 Mabswid

.02381 .30902 m

.02803 .36656 L

.03452 .39943 L

.04101 .42192 L

.0475 .43957 L

.05399 .45419 L

.06048 .46667 L

.06697 .47751 L

.07346 .48704 L

.07995 .49549 L

.08644 .50303 L

.09293 .50979 L

.09942 .51586 L

.10591 .52133 L

.1124 .52626 L

.11889 .5307 L

.12538 .53471 L

.13187 .53832 L

.13835 .54157 L

.14484 .54449 L

.15133 .5471 L

.15782 .54943 L

.16431 .55151 L

.1708 .55334 L

.17729 .55495 L

.18378 .55635 L

.19027 .55756 L

.19676 .5586 L

.20325 .55946 L

.20974 .56017 L

.21623 .56073 L

.21786 .56085 L

.21948 .56096 L

.2211 .56106 L

.22272 .56115 L

.22434 .56124 L

.22597 .56132 L

.22759 .56139 L

.22921 .56145 L

.23083 .56151 L

.23246 .56156 L

.23408 .5616 L

.2357 .56163 L

.23732 .56165 L

.23895 .56168 L

.24057 .56169 L

.24219 .56169 L

.24381 .56169 L

.24544 .56168 L

.24706 .56167 L

Mistroke

.24868 .56165 L

.2503 .56162 L

.25193 .56159 L

.25355 .56156 L

.25517 .56151 L

.25679 .56146 L

.25842 .5614 L

.26004 .56134 L

.26166 .56128 L

.26328 .5612 L

.26491 .56112 L

.26653 .56104 L

.26815 .56095 L

.26977 .56086 L

.2714 .56076 L

.27302 .56066 L

.27464 .56055 L

.27626 .56044 L

.27789 .56032 L

.27951 .56019 L

.28113 .56007 L

.28275 .55994 L

.28438 .5598 L

.286 .55966 L

.28762 .55951 L

.28924 .55936 L

.29087 .55921 L

.29249 .55905 L

.29411 .55889 L

.29573 .55872 L

.29736 .55855 L

.29898 .55838 L

.3006 .5582 L

.30222 .55802 L

.30385 .55783 L

.30547 .55764 L

.30709 .55745 L

.30871 .55725 L

.31034 .55705 L

.31196 .55685 L

.31358 .55664 L

.3152 .55643 L

.31682 .55622 L

.31845 .556 L

.32007 .55578 L

.32169 .55555 L

.32331 .55533 L

.32494 .5551 L

.32656 .55487 L

.32818 .55463 L

Mistroke

.3298 .55439 L

.33143 .55415 L

.33305 .5539 L

.33467 .55365 L

.33629 .55341 L

.33792 .55315 L

.33954 .55289 L

.34116 .55264 L

.34278 .55238 L

.34441 .55211 L

.34603 .55184 L

.34765 .55157 L

.34927 .5513 L

.3509 .55103 L

.35252 .55075 L

.35414 .55047 L

.35576 .55019 L

.35739 .54991 L

.35901 .54962 L

.36063 .54933 L

.36225 .54904 L

.36388 .54875 L

.3655 .54845 L

.36712 .54816 L

.36874 .54786 L

.37037 .54756 L

.37199 .54725 L

.37361 .54695 L

.37523 .54664 L

.37686 .54633 L

.37848 .54602 L

.3801 .5457 L

.38172 .54539 L

.38335 .54507 L

.38497 .54475 L

.38659 .54443 L

.38821 .54411 L

.38984 .54378 L

.39146 .54345 L

.39308 .54313 L

.3947 .5428 L

.39633 .54246 L

.39795 .54213 L

.39957 .5418 L

.40119 .54146 L

.40281 .54112 L

.40444 .54078 L

.40606 .54044 L

.40768 .5401 L

.4093 .53975 L

Mistroke

.41093 .5394 L

.41255 .53906 L

.41417 .53871 L

.41579 .53836 L

.41742 .538 L

.41904 .53765 L

.42066 .5373 L

.42228 .53694 L

.42391 .53658 L

.42553 .53622 L

.42715 .53586 L

.42877 .5355 L

.4304 .53513 L

.43202 .53477 L

.43364 .5344 L

.43526 .53404 L

.43689 .53367 L

.43851 .5333 L

.44013 .53292 L

.44175 .53255 L

.44338 .53218 L

.445 .5318 L

.44662 .53143 L

.44824 .53105 L

.44987 .53067 L

.45149 .53029 L

.45311 .52991 L

.45473 .52953 L

.45636 .52914 L

.45798 .52876 L

.4596 .52837 L

.46122 .52798 L

.46285 .5276 L

.46447 .52721 L

.46609 .52682 L

.46771 .52643 L

.46934 .52603 L

.47096 .52564 L

.47258 .52524 L

.4742 .52485 L

.47583 .52445 L

.47745 .52405 L

.47907 .52365 L

.48069 .52325 L

.48232 .52285 L

.48394 .52245 L

.48556 .52205 L

.48718 .52164 L

.48881 .52124 L

.49043 .52083 L

Mistroke

.49205 .52042 L

.49367 .52001 L

.49529 .5196 L

.49692 .51919 L

.49854 .51878 L

.50016 .51837 L

.50178 .51795 L

.50341 .51754 L

.50503 .51712 L

.50665 .51671 L

.50827 .51629 L

.5099 .51587 L

.51152 .51545 L

.51314 .51503 L

.51476 .51461 L

.51639 .51418 L

.51801 .51376 L

.51963 .51334 L

.52125 .51291 L

.52288 .51248 L

.5245 .51205 L

.52612 .51162 L

.52774 .51119 L

.52937 .51076 L

.53099 .51033 L

.53261 .5099 L

.53423 .50946 L

.53586 .50903 L

.53748 .50859 L

.5391 .50815 L

.54072 .50771 L

.54235 .50727 L

.54397 .50683 L

.54559 .50639 L

.54721 .50595 L

.54884 .5055 L

.55046 .50506 L

.55208 .50461 L

.5537 .50416 L

.55533 .50371 L

.55695 .50326 L

.55857 .50281 L

.56019 .50236 L

.56182 .50191 L

.56344 .50145 L

.56506 .50099 L

.56668 .50054 L

.56831 .50008 L

.56993 .49962 L

.57155 .49916 L

Mistroke

.57317 .4987 L

.5748 .49823 L

.57642 .49777 L

.57804 .4973 L

.57966 .49684 L

.58128 .49637 L

.58291 .4959 L

.58453 .49543 L

.58615 .49495 L

.58777 .49448 L

.5894 .494 L

.59102 .49353 L

.59264 .49305 L

.59426 .49257 L

.59589 .49209 L

.59751 .49161 L

.59913 .49112 L

.60075 .49064 L

.60238 .49015 L

.604 .48966 L

.60562 .48917 L

.60724 .48868 L

.60887 .48819 L

.61049 .48769 L

.61211 .4872 L

.61373 .4867 L

.61536 .4862 L

.61698 .4857 L

.6186 .4852 L

.62022 .48469 L

.62509 .48317 L

.62834 .48214 L

.63158 .48111 L

.63483 .48007 L

.63807 .47903 L

.64132 .47797 L

.64456 .47691 L

.64781 .47584 L

.65105 .47476 L

.6543 .47368 L

.65754 .47258 L

.66079 .47148 L

.66403 .47037 L

.66728 .46925 L

.67052 .46812 L

.67376 .46698 L

.67701 .46583 L

.68025 .46468 L

.6835 .46351 L

.68674 .46234 L

Mistroke

.68999 .46115 L

.69323 .45996 L

.69648 .45875 L

.69972 .45754 L

.70297 .45631 L

.70621 .45508 L

.70946 .45383 L

.7127 .45258 L

.71595 .45131 L

.71919 .45004 L

.72244 .44876 L

.72568 .44746 L

.72893 .44616 L

.73217 .44484 L

.73542 .44352 L

.73866 .44218 L

.74191 .44083 L

.74515 .43948 L

.7484 .43811 L

.75164 .43673 L

.75489 .43535 L

.75813 .43395 L

.76138 .43254 L

.76462 .43112 L

.76787 .4297 L

.77111 .42826 L

.77436 .42681 L

.7776 .42535 L

.78085 .42387 L

.78409 .42239 L

.78734 .4209 L

.79058 .41939 L

.79383 .41787 L

.79707 .41634 L

.80032 .4148 L

.80356 .41325 L

.80681 .41168 L

.81005 .4101 L

.8133 .40851 L

.81654 .4069 L

.81979 .40528 L

.82303 .40364 L

.82628 .40199 L

.82952 .40032 L

.83277 .39864 L

.83601 .39694 L

.83926 .39522 L

.8425 .39348 L

.84575 .39172 L

.84899 .38994 L

Mistroke

.85223 .38814 L

.85548 .38632 L

.85872 .38447 L

.86197 .3826 L

.86521 .3807 L

.86846 .37877 L

.8717 .37682 L

.87495 .37483 L

.87819 .37281 L

.88144 .37075 L

.88468 .36866 L

.88793 .36653 L

.89117 .36435 L

.89442 .36213 L

.89766 .35986 L

.90091 .35754 L

.90415 .35516 L

.9074 .35272 L

.91064 .35022 L

.91389 .34764 L

.91713 .34499 L

.92038 .34225 L

.92362 .33941 L

.92687 .33647 L

.93011 .33342 L

.93336 .33023 L

.9366 .32691 L

.93985 .32341 L

.94309 .31973 L

.94634 .31582 L

.94958 .31166 L

.95283 .30718 L

.95607 .30233 L

.95932 .297 L

.96256 .29103 L

.96581 .28419 L

.96905 .27601 L

.97619 .22688 L

.97603 .22369 L

.97587 .22138 L

.9757 .21945 L

.97554 .21774 L

.97538 .2162 L

.97522 .21477 L

.97505 .21345 L

.97489 .21221 L

.97473 .21104 L

.97457 .20992 L

.97441 .20886 L

.97424 .20784 L

Mistroke

.97408 .20685 L

.97392 .2059 L

.97376 .20498 L

.97359 .20408 L

.97343 .20321 L

.97327 .20236 L

.97311 .20154 L

.97295 .20073 L

.97278 .19995 L

.97262 .19918 L

.97246 .19843 L

.9723 .19769 L

.97213 .19697 L

.97197 .19625 L

.97181 .19555 L

.97165 .19486 L

.97149 .19419 L

.97132 .19352 L

.97116 .19287 L

.971 .19222 L

.97084 .19158 L

.97067 .19096 L

.97051 .19034 L

.97035 .18972 L

.97019 .18912 L

.97003 .18852 L

.96986 .18793 L

.9697 .18736 L

.96954 .18678 L

.96938 .18622 L

.96921 .18566 L

.96905 .18509 L

.96889 .18455 L

.96873 .184 L

.96856 .18347 L

.9684 .18294 L

.96824 .1824 L

.96743 .17984 L

.96662 .17738 L

.96581 .17502 L

.965 .17274 L

.96418 .17055 L

.96337 .16841 L

.96256 .16636 L

.96175 .16434 L

.96094 .1624 L

.96013 .1605 L

.95932 .15865 L

.95851 .15684 L

.95769 .15508 L

Mistroke

.95688 .15335 L

.95607 .15165 L

.95526 .15 L

.95445 .14837 L

.95364 .14679 L

.95283 .14523 L

.95202 .14369 L

.9512 .14219 L

.95039 .14071 L

.94958 .13926 L

.94877 .13783 L

.94796 .13643 L

.94715 .13504 L

.94634 .13369 L

.94553 .13235 L

.94471 .13103 L

.9439 .12973 L

.94309 .12845 L

.94228 .1272 L

.94147 .12595 L

.94066 .12473 L

.93985 .12352 L

.93904 .12234 L

.93823 .12116 L

.93741 .12001 L

.9366 .11887 L

.93579 .11775 L

.93498 .11664 L

.93417 .11554 L

.93336 .11446 L

.93255 .11339 L

.93174 .11234 L

.93092 .1113 L

.93011 .11028 L

.9293 .10927 L

.92849 .10827 L

.92768 .10728 L

.92687 .10631 L

.92606 .10535 L

.92525 .1044 L

.92443 .10346 L

.92362 .10254 L

.92281 .10163 L

.922 .10073 L

.92119 .09984 L

.92038 .09896 L

.91957 .09809 L

.91876 .09723 L

.91794 .09638 L

.91713 .09554 L

Mistroke

.91632 .09471 L

.91551 .0939 L

.9147 .09309 L

.91389 .09229 L

.91308 .09151 L

.91227 .09073 L

.91145 .08996 L

.91064 .0892 L

.90983 .08845 L

.90902 .08771 L

.90821 .08698 L

.9074 .08626 L

.90659 .08555 L

.90578 .08484 L

.90496 .08414 L

.90415 .08346 L

.90334 .08278 L

.90253 .08211 L

.90172 .08145 L

.90091 .08079 L

.9001 .08015 L

.89929 .07951 L

.89847 .07888 L

.89766 .07826 L

.89685 .07764 L

.89604 .07704 L

.89523 .07644 L

.89442 .07585 L

.89361 .07526 L

.8928 .07469 L

.89199 .07412 L

.89117 .07355 L

.89036 .073 L

.88955 .07246 L

.88874 .07191 L

.88793 .07138 L

.88712 .07085 L

.88631 .07033 L

.8855 .06982 L

.88468 .06931 L

.88387 .06881 L

.88306 .06832 L

.88225 .06783 L

.88144 .06735 L

.88063 .06687 L

.87982 .0664 L

.87901 .06594 L

.87819 .06548 L

.87738 .06503 L

.87657 .06458 L

Mistroke

.87576 .06415 L

.87495 .06371 L

.87414 .06328 L

.87333 .06286 L

.87252 .06244 L

.8717 .06203 L

.87089 .06163 L

.87008 .06123 L

.86927 .06083 L

.86846 .06044 L

.86765 .06006 L

.86684 .05967 L

.86603 .0593 L

.86521 .05893 L

.8644 .05856 L

.86359 .05821 L

.86278 .05785 L

.86197 .0575 L

.86116 .05715 L

.86035 .05681 L

.85954 .05647 L

.85872 .05614 L

.85791 .05581 L

.8571 .05548 L

.85629 .05516 L

.85548 .05485 L

.85467 .05454 L

.85386 .05423 L

.85305 .05392 L

.85223 .05362 L

.85142 .05332 L

.85061 .05303 L

.8498 .05274 L

.84899 .05246 L

.84818 .05217 L

.84737 .0519 L

.84656 .05162 L

.84575 .05135 L

.84493 .05108 L

.84412 .05081 L

.84331 .05055 L

.8425 .05029 L

.84169 .05004 L

.84088 .04978 L

.84007 .04953 L

.83926 .04928 L

.83844 .04904 L

.83763 .0488 L

.83682 .04856 L

.83601 .04832 L

Mistroke

.8352 .04809 L

.83439 .04786 L

.83358 .04763 L

.83277 .0474 L

.83195 .04718 L

.83114 .04696 L

.83033 .04674 L

.82952 .04652 L

.82871 .0463 L

.8279 .04609 L

.82709 .04588 L

.82628 .04567 L

.82546 .04546 L

.82465 .04526 L

.82384 .04505 L

.82303 .04485 L

.82222 .04465 L

.82141 .04446 L

.8206 .04426 L

.81979 .04406 L

.81897 .04387 L

.81816 .04368 L

.81735 .04349 L

.81654 .0433 L

.81573 .04311 L

.81492 .04293 L

.81411 .04274 L

.8133 .04256 L

.81248 .04238 L

.81167 .0422 L

.81086 .04202 L

.81005 .04184 L

.80924 .04167 L

.80843 .04149 L

.80762 .04131 L

.80681 .04114 L

.80599 .04097 L

.80518 .0408 L

.80437 .04063 L

.80356 .04046 L

.80275 .04029 L

.80194 .04013 L

.80113 .03996 L

.80032 .03979 L

.79951 .03963 L

.79869 .03947 L

.79788 .0393 L

.79707 .03914 L

.79626 .03898 L

.79545 .03882 L

Mistroke

.79464 .03866 L

.79383 .0385 L

.79302 .03834 L

.7922 .03818 L

.79139 .03803 L

.79058 .03787 L

.78977 .03772 L

.78896 .03756 L

.78815 .03741 L

.78734 .03725 L

.78653 .0371 L

.78571 .03695 L

.7849 .0368 L

.78409 .03665 L

.78328 .03649 L

.78247 .03634 L

.78166 .03619 L

.78085 .03604 L

.78004 .0359 L

.77922 .03575 L

.77841 .0356 L

.7776 .03545 L

.77679 .03531 L

.77598 .03516 L

.77517 .03501 L

.77436 .03487 L

.77355 .03472 L

.77273 .03458 L

.77192 .03443 L

.77111 .03429 L

.7703 .03415 L

.76949 .034 L

.76868 .03386 L

.76787 .03372 L

.76706 .03358 L

.76624 .03344 L

.76543 .03329 L

.76462 .03315 L

.76381 .03301 L

.763 .03287 L

.76219 .03273 L

.76138 .03259 L

.76057 .03245 L

.75976 .03232 L

.75894 .03218 L

.75813 .03204 L

.75732 .0319 L

.75651 .03176 L

.7557 .03163 L

.75489 .03149 L

Mistroke

.75408 .03136 L

.75327 .03122 L

.75245 .03108 L

.75164 .03095 L

.75083 .03081 L

.75002 .03068 L

.74921 .03054 L

.7484 .03041 L

.74759 .03028 L

.74678 .03014 L

.74596 .03001 L

.74515 .02988 L

.74434 .02974 L

.74353 .02961 L

.74272 .02948 L

.74191 .02935 L

.7411 .02922 L

.74029 .02909 L

.73947 .02896 L

.73866 .02883 L

.73785 .0287 L

.73704 .02857 L

.73623 .02844 L

.73542 .02831 L

.73461 .02818 L

.7338 .02805 L

.73298 .02793 L

.73217 .0278 L

.73136 .02767 L

.73055 .02754 L

.72974 .02742 L

.72893 .02729 L

.72812 .02717 L

.72731 .02704 L

.72649 .02691 L

.72568 .02679 L

.72487 .02667 L

.72406 .02654 L

.72325 .02642 L

.72244 .02629 L

.72163 .02617 L

.72082 .02605 L

.72 .02593 L

.71919 .02581 L

.71838 .02568 L

.71757 .02556 L

.71676 .02544 L

.71595 .02532 L

.71514 .0252 L

.71433 .02508 L

Mistroke

.71352 .02496 L

.7127 .02484 L

.71189 .02473 L

.71108 .02461 L

.71027 .02449 L

.70946 .02437 L

.70865 .02426 L

.70784 .02414 L

.70703 .02402 L

.70621 .02391 L

.7054 .02379 L

.70459 .02368 L

.70378 .02356 L

.70297 .02345 L

.70216 .02333 L

.70135 .02322 L

.70054 .02311 L

.69972 .023 L

.69891 .02289 L

.6981 .02277 L

.69729 .02266 L

.69648 .02255 L

.69567 .02244 L

.69486 .02234 L

.69405 .02223 L

.69323 .02212 L

.69242 .02201 L

.69161 .0219 L

.6908 .0218 L

.68999 .02169 L

.68918 .02158 L

.68837 .02148 L

.68756 .02137 L

.68674 .02127 L

.68593 .02116 L

.68512 .02106 L

.68431 .02096 L

.6835 .02086 L

.68269 .02076 L

.68188 .02066 L

.68107 .02056 L

.68025 .02045 L

.67944 .02036 L

.67863 .02026 L

.67782 .02016 L

.67701 .02006 L

.6762 .01997 L

.67539 .01987 L

.67458 .01977 L

.67376 .01968 L

Mistroke

.67295 .01958 L

.67214 .01949 L

.67133 .0194 L

.67052 .0193 L

.66971 .01921 L

.6689 .01912 L

.66809 .01903 L

.66728 .01894 L

.66646 .01885 L

.66565 .01876 L

.66484 .01868 L

.66403 .01859 L

.66322 .0185 L

.66241 .01842 L

.6616 .01833 L

.66079 .01825 L

.65997 .01817 L

.65916 .01808 L

.65835 .018 L

.65754 .01792 L

.65673 .01784 L

.65592 .01776 L

.65511 .01768 L

.6543 .0176 L

.65348 .01753 L

.65267 .01745 L

.65186 .01737 L

.65105 .0173 L

.65024 .01723 L

.64943 .01715 L

.64862 .01708 L

.64781 .01701 L

.64699 .01694 L

.64618 .01687 L

.64537 .0168 L

.64456 .01674 L

.64375 .01667 L

.64213 .01654 L

.6405 .01641 L

.63888 .01629 L

.63726 .01617 L

.63564 .01605 L

.63401 .01594 L

.63239 .01583 L

.63077 .01573 L

.62915 .01563 L

.62752 .01554 L

.6259 .01545 L

.62428 .01537 L

.62266 .01528 L

Mistroke

.62104 .01521 L

.61941 .01514 L

.61779 .01507 L

.61617 .01501 L

.61455 .01496 L

.61292 .01491 L

.6113 .01487 L

.60968 .01483 L

.60806 .01479 L

.60643 .01477 L

.60481 .01474 L

.60319 .01473 L

.60157 .01472 L

.59994 .01472 L

.59832 .01472 L

.5967 .01473 L

.59508 .01475 L

.59345 .01477 L

.59183 .0148 L

.59021 .01484 L

.58859 .01488 L

.58696 .01493 L

.58534 .01499 L

.58372 .01506 L

.5821 .01514 L

.58047 .01522 L

.57885 .01531 L

.57723 .01541 L

.57561 .01552 L

.57398 .01563 L

.57236 .01576 L

.57074 .0159 L

.56912 .01604 L

.56749 .01619 L

.56587 .01636 L

.56425 .01653 L

.56263 .01671 L

.561 .0169 L

.55938 .01711 L

.55776 .01732 L

.55614 .01755 L

.55451 .01778 L

.55289 .01803 L

.55127 .01829 L

.54965 .01856 L

.54802 .01885 L

.5464 .01914 L

.54478 .01945 L

.54316 .01977 L

.54153 .0201 L

Mistroke

.53991 .02045 L

.53829 .02081 L

.53667 .02119 L

.53505 .02158 L

.53342 .02199 L

.5318 .02241 L

.53018 .02284 L

.52856 .02329 L

.52693 .02376 L

.52531 .02424 L

.52369 .02474 L

.52207 .02526 L

.52044 .0258 L

.51882 .02635 L

.5172 .02692 L

.51558 .02751 L

.51395 .02812 L

.51233 .02875 L

.51071 .0294 L

.50909 .03007 L

.50746 .03076 L

.50584 .03147 L

.50422 .03221 L

.5026 .03297 L

.50097 .03375 L

.49935 .03455 L

.49773 .03538 L

.49611 .03623 L

.49448 .03711 L

.49286 .03802 L

.49124 .03895 L

.48962 .03991 L

.48799 .04089 L

.48637 .04191 L

.48475 .04296 L

.48313 .04403 L

.4815 .04514 L

.47988 .04628 L

.47826 .04745 L

.47664 .04866 L

.47501 .0499 L

.47339 .05118 L

.47177 .0525 L

.47015 .05385 L

.46852 .05524 L

.4669 .05667 L

.46528 .05814 L

.46366 .05966 L

.46203 .06122 L

.46041 .06283 L

Mistroke

.45879 .06448 L

.45717 .06618 L

.45554 .06793 L

.45392 .06974 L

.4523 .07159 L

.45068 .0735 L

.44905 .07547 L

.44743 .0775 L

.44581 .07959 L

.44419 .08175 L

.44257 .08397 L

.44094 .08626 L

.43932 .08862 L

.4377 .09106 L

.43608 .09357 L

.43445 .09617 L

.43283 .09885 L

.43121 .10163 L

.42959 .10449 L

.42796 .10746 L

.42634 .11053 L

.42472 .11372 L

.4231 .11701 L

.42147 .12044 L

.41985 .12399 L

.41823 .12769 L

.41661 .13153 L

.41498 .13554 L

.41336 .13971 L

.41174 .14408 L

.41012 .14865 L

.40849 .15344 L

.40687 .15848 L

.40525 .1638 L

.40363 .16941 L

.402 .17538 L

.40038 .18173 L

.39876 .18855 L

.39714 .19591 L

.39551 .20393 L

.39389 .21278 L

.39227 .2227 L

.39065 .23415 L

.38902 .24795 L

.3874 .26636 L

.3874 .35167 L

.38902 .37008 L

.39065 .38389 L

.39227 .39533 L

.39389 .40526 L

Mistroke

.39551 .4141 L

.39714 .42212 L

.39876 .42948 L

.40038 .4363 L

.402 .44266 L

.40363 .44862 L

.40525 .45424 L

.40687 .45955 L

.40849 .46459 L

.41012 .46938 L

.41174 .47395 L

.41336 .47832 L

.41498 .4825 L

.41661 .4865 L

.41823 .49035 L

.41985 .49404 L

.42147 .4976 L

.4231 .50102 L

.42472 .50432 L

.42634 .5075 L

.42796 .51057 L

.42959 .51354 L

.43121 .51641 L

.43283 .51918 L

.43445 .52186 L

.43608 .52446 L

.4377 .52698 L

.43932 .52942 L

.44094 .53178 L

.44257 .53407 L

.44419 .53629 L

.44581 .53844 L

.44743 .54053 L

.44905 .54256 L

.45068 .54453 L

.4523 .54644 L

.45392 .5483 L

.45554 .5501 L

.45717 .55185 L

.45879 .55355 L

.46041 .55521 L

.46203 .55681 L

.46366 .55837 L

.46528 .55989 L

.4669 .56136 L

.46852 .56279 L

.47015 .56419 L

.47177 .56554 L

.47339 .56685 L

.47501 .56813 L

Mistroke

.47664 .56937 L

.47826 .57058 L

.47988 .57175 L

.4815 .57289 L

.48313 .574 L

.48475 .57508 L

.48637 .57612 L

.48799 .57714 L

.48962 .57813 L

.49124 .57909 L

.49286 .58002 L

.49448 .58092 L

.49611 .5818 L

.49773 .58266 L

.49935 .58349 L

.50097 .58429 L

.5026 .58507 L

.50422 .58583 L

.50584 .58656 L

.50746 .58727 L

.50909 .58796 L

.51071 .58863 L

.51233 .58928 L

.51395 .58991 L

.51558 .59052 L

.5172 .59111 L

.51882 .59168 L

.52044 .59224 L

.52207 .59277 L

.52369 .59329 L

.52531 .59379 L

.52693 .59427 L

.52856 .59474 L

.53018 .59519 L

.5318 .59563 L

.53342 .59605 L

.53505 .59645 L

.53667 .59684 L

.53829 .59722 L

.53991 .59758 L

.54153 .59793 L

.54316 .59826 L

.54478 .59858 L

.5464 .59889 L

.54802 .59919 L

.54965 .59947 L

.55127 .59974 L

.55289 .6 L

.55451 .60025 L

.55614 .60049 L

Mistroke

.55776 .60071 L

.55938 .60093 L

.561 .60113 L

.56263 .60132 L

.56425 .60151 L

.56587 .60168 L

.56749 .60184 L

.56912 .602 L

.57074 .60214 L

.57236 .60228 L

.57398 .6024 L

.57561 .60252 L

.57723 .60262 L

.57885 .60272 L

.58047 .60282 L

.5821 .6029 L

.58372 .60297 L

.58534 .60304 L

.58696 .6031 L

.58859 .60315 L

.59021 .6032 L

.59183 .60323 L

.59345 .60327 L

.59508 .60329 L

.5967 .60331 L

.59832 .60331 L

.59994 .60332 L

.60157 .60331 L

.60319 .60331 L

.60481 .60329 L

.60643 .60327 L

.60806 .60324 L

.60968 .60321 L

.6113 .60317 L

.61292 .60312 L

.61455 .60308 L

.61617 .60302 L

.61779 .60296 L

.61941 .6029 L

.62104 .60283 L

.62266 .60275 L

.62428 .60267 L

.6259 .60258 L

.62752 .6025 L

.62915 .6024 L

.63077 .6023 L

.63239 .6022 L

.63401 .60209 L

.63564 .60198 L

.63726 .60187 L

Mistroke

.63888 .60175 L

.6405 .60163 L

.64213 .6015 L

.64375 .60137 L

.64456 .6013 L

.64537 .60123 L

.64618 .60116 L

.64699 .6011 L

.64781 .60102 L

.64862 .60095 L

.64943 .60088 L

.65024 .60081 L

.65105 .60073 L

.65186 .60066 L

.65267 .60058 L

.65348 .60051 L

.6543 .60043 L

.65511 .60035 L

.65592 .60027 L

.65673 .60019 L

.65754 .60011 L

.65835 .60003 L

.65916 .59995 L

.65997 .59987 L

.66079 .59979 L

.6616 .5997 L

.66241 .59962 L

.66322 .59953 L

.66403 .59945 L

.66484 .59936 L

.66565 .59927 L

.66646 .59918 L

.66728 .59909 L

.66809 .599 L

.6689 .59891 L

.66971 .59882 L

.67052 .59873 L

.67133 .59864 L

.67214 .59855 L

.67295 .59845 L

.67376 .59836 L

.67458 .59826 L

.67539 .59817 L

.6762 .59807 L

.67701 .59797 L

.67782 .59787 L

.67863 .59778 L

.67944 .59768 L

.68025 .59758 L

.68107 .59748 L

Mistroke

.68188 .59738 L

.68269 .59728 L

.6835 .59718 L

.68431 .59707 L

.68512 .59697 L

.68593 .59687 L

.68674 .59677 L

.68756 .59666 L

.68837 .59655 L

.68918 .59645 L

.68999 .59634 L

.6908 .59624 L

.69161 .59613 L

.69242 .59603 L

.69323 .59592 L

.69405 .59581 L

.69486 .5957 L

.69567 .59559 L

.69648 .59548 L

.69729 .59537 L

.6981 .59526 L

.69891 .59515 L

.69972 .59504 L

.70054 .59492 L

.70135 .59481 L

.70216 .5947 L

.70297 .59459 L

.70378 .59447 L

.70459 .59436 L

.7054 .59424 L

.70621 .59413 L

.70703 .59401 L

.70784 .5939 L

.70865 .59378 L

.70946 .59366 L

.71027 .59354 L

.71108 .59343 L

.71189 .59331 L

.7127 .59319 L

.71352 .59307 L

.71433 .59295 L

.71514 .59283 L

.71595 .59271 L

.71676 .59259 L

.71757 .59247 L

.71838 .59235 L

.71919 .59223 L

.72 .59211 L

.72082 .59198 L

.72163 .59186 L

Mistroke

.72244 .59174 L

.72325 .59161 L

.72406 .59149 L

.72487 .59137 L

.72568 .59124 L

.72649 .59112 L

.72731 .59099 L

.72812 .59087 L

.72893 .59074 L

.72974 .59062 L

.73055 .59049 L

.73136 .59036 L

.73217 .59024 L

.73298 .59011 L

.7338 .58998 L

.73461 .58985 L

.73542 .58972 L

.73623 .58959 L

.73704 .58946 L

.73785 .58934 L

.73866 .58921 L

.73947 .58908 L

.74029 .58895 L

.7411 .58881 L

.74191 .58868 L

.74272 .58855 L

.74353 .58842 L

.74434 .58829 L

.74515 .58816 L

.74596 .58802 L

.74678 .58789 L

.74759 .58776 L

.7484 .58762 L

.74921 .58749 L

.75002 .58736 L

.75083 .58722 L

.75164 .58709 L

.75245 .58695 L

.75327 .58682 L

.75408 .58668 L

.75489 .58654 L

.7557 .58641 L

.75651 .58627 L

.75732 .58613 L

.75813 .58599 L

.75894 .58586 L

.75976 .58572 L

.76057 .58558 L

.76138 .58544 L

.76219 .5853 L

Mistroke

.763 .58516 L

.76381 .58502 L

.76462 .58488 L

.76543 .58474 L

.76624 .5846 L

.76706 .58446 L

.76787 .58432 L

.76868 .58417 L

.76949 .58403 L

.7703 .58389 L

.77111 .58374 L

.77192 .5836 L

.77273 .58346 L

.77355 .58331 L

.77436 .58317 L

.77517 .58302 L

.77598 .58287 L

.77679 .58273 L

.7776 .58258 L

.77841 .58243 L

.77922 .58229 L

.78004 .58214 L

.78085 .58199 L

.78166 .58184 L

.78247 .58169 L

.78328 .58154 L

.78409 .58139 L

.7849 .58124 L

.78571 .58109 L

.78653 .58093 L

.78734 .58078 L

.78815 .58063 L

.78896 .58047 L

.78977 .58032 L

.79058 .58016 L

.79139 .58001 L

.7922 .57985 L

.79302 .57969 L

.79383 .57953 L

.79464 .57938 L

.79545 .57922 L

.79626 .57905 L

.79707 .57889 L

.79788 .57873 L

.79869 .57857 L

.79951 .57841 L

.80032 .57824 L

.80113 .57808 L

.80194 .57791 L

.80275 .57774 L

Mistroke

.80356 .57757 L

.80437 .5774 L

.80518 .57724 L

.80599 .57706 L

.80681 .57689 L

.80762 .57672 L

.80843 .57654 L

.80924 .57637 L

.81005 .57619 L

.81086 .57601 L

.81167 .57584 L

.81248 .57565 L

.8133 .57547 L

.81411 .57529 L

.81492 .57511 L

.81573 .57492 L

.81654 .57473 L

.81735 .57455 L

.81816 .57436 L

.81897 .57416 L

.81979 .57397 L

.8206 .57378 L

.82141 .57358 L

.82222 .57338 L

.82303 .57318 L

.82384 .57298 L

.82465 .57278 L

.82546 .57257 L

.82628 .57236 L

.82709 .57216 L

.8279 .57194 L

.82871 .57173 L

.82952 .57151 L

.83033 .5713 L

.83114 .57108 L

.83195 .57086 L

.83277 .57063 L

.83358 .57041 L

.83439 .57018 L

.8352 .56995 L

.83601 .56971 L

.83682 .56947 L

.83763 .56924 L

.83844 .56899 L

.83926 .56875 L

.84007 .5685 L

.84088 .56825 L

.84169 .568 L

.8425 .56774 L

.84331 .56748 L

Mistroke

.84412 .56722 L

.84493 .56695 L

.84575 .56669 L

.84656 .56641 L

.84737 .56614 L

.84818 .56586 L

.84899 .56558 L

.8498 .56529 L

.85061 .565 L

.85142 .56471 L

.85223 .56441 L

.85305 .56411 L

.85386 .56381 L

.85467 .5635 L

.85548 .56319 L

.85629 .56287 L

.8571 .56255 L

.85791 .56222 L

.85872 .5619 L

.85954 .56156 L

.86035 .56122 L

.86116 .56088 L

.86197 .56054 L

.86278 .56019 L

.86359 .55983 L

.8644 .55947 L

.86521 .5591 L

.86603 .55873 L

.86684 .55836 L

.86765 .55798 L

.86846 .55759 L

.86927 .5572 L

.87008 .55681 L

.87089 .55641 L

.8717 .556 L

.87252 .55559 L

.87333 .55517 L

.87414 .55475 L

.87495 .55432 L

.87576 .55389 L

.87657 .55345 L

.87738 .553 L

.87819 .55255 L

.87901 .5521 L

.87982 .55163 L

.88063 .55117 L

.88144 .55069 L

.88225 .55021 L

.88306 .54972 L

.88387 .54922 L

Mistroke

.88468 .54872 L

.8855 .54822 L

.88631 .5477 L

.88712 .54718 L

.88793 .54666 L

.88874 .54612 L

.88955 .54558 L

.89036 .54503 L

.89117 .54448 L

.89199 .54392 L

.8928 .54335 L

.89361 .54277 L

.89442 .54219 L

.89523 .54159 L

.89604 .541 L

.89685 .54039 L

.89766 .53978 L

.89847 .53915 L

.89929 .53852 L

.9001 .53788 L

.90091 .53724 L

.90172 .53659 L

.90253 .53592 L

.90334 .53526 L

.90415 .53458 L

.90496 .53389 L

.90578 .53319 L

.90659 .53249 L

.9074 .53178 L

.90821 .53105 L

.90902 .53032 L

.90983 .52958 L

.91064 .52883 L

.91145 .52807 L

.91227 .52731 L

.91308 .52653 L

.91389 .52574 L

.9147 .52494 L

.91551 .52414 L

.91632 .52332 L

.91713 .52249 L

.91794 .52166 L

.91876 .52081 L

.91957 .51995 L

.92038 .51908 L

.92119 .5182 L

.922 .51731 L

.92281 .51641 L

.92362 .51549 L

.92443 .51457 L

Mistroke

.92525 .51363 L

.92606 .51268 L

.92687 .51172 L

.92768 .51075 L

.92849 .50976 L

.9293 .50877 L

.93011 .50775 L

.93092 .50673 L

.93174 .50569 L

.93255 .50464 L

.93336 .50357 L

.93417 .50249 L

.93498 .5014 L

.93579 .50029 L

.9366 .49916 L

.93741 .49803 L

.93823 .49687 L

.93904 .4957 L

.93985 .49451 L

.94066 .4933 L

.94147 .49208 L

.94228 .49084 L

.94309 .48958 L

.9439 .4883 L

.94471 .48701 L

.94553 .48569 L

.94634 .48435 L

.94715 .48299 L

.94796 .48161 L

.94877 .4802 L

.94958 .47878 L

.95039 .47732 L

.9512 .47584 L

.95202 .47434 L

.95283 .4728 L

.95364 .47125 L

.95445 .46966 L

.95526 .46803 L

.95607 .46638 L

.95688 .46468 L

.95769 .46296 L

.95851 .46119 L

.95932 .45938 L

.96013 .45753 L

.96094 .45564 L

.96175 .45369 L

.96256 .45168 L

.96337 .44962 L

.96418 .44749 L

.965 .44529 L

Mistroke

.96581 .44301 L

.96662 .44065 L

.96743 .43819 L

.96824 .43563 L

.9684 .4351 L

.96856 .43457 L

.96873 .43403 L

.96889 .43349 L

.96905 .43294 L

.96921 .43238 L

.96938 .43182 L

.96954 .43125 L

.9697 .43068 L

.96986 .4301 L

.97003 .42951 L

.97019 .42892 L

.97035 .42831 L

.97051 .42769 L

.97067 .42707 L

.97084 .42645 L

.971 .42581 L

.97116 .42516 L

.97132 .42451 L

.97149 .42384 L

.97165 .42317 L

.97181 .42249 L

.97197 .42178 L

.97213 .42107 L

.9723 .42034 L

.97246 .41961 L

.97262 .41885 L

.97278 .41809 L

.97295 .4173 L

.97311 .41649 L

.97327 .41567 L

.97343 .41482 L

.97359 .41395 L

.97376 .41306 L

.97392 .41213 L

.97408 .41119 L

.97424 .4102 L

.97441 .40917 L

.97457 .40812 L

.97473 .40699 L

.97489 .40582 L

.97505 .40458 L

.97522 .40326 L

.97538 .40184 L

.97554 .4003 L

.9757 .39859 L

Mistroke

.97587 .39665 L

.97603 .39434 L

.97619 .39115 L

.96905 .34203 L

.96581 .33385 L

.96256 .327 L

.95932 .32104 L

.95607 .31571 L

.95283 .31085 L

.94958 .30638 L

.94634 .30221 L

.94309 .29831 L

.93985 .29462 L

.9366 .29113 L

.93336 .2878 L

.93011 .28461 L

.92687 .28156 L

.92362 .27862 L

.92038 .27579 L

.91713 .27305 L

.91389 .27039 L

.91064 .26782 L

.9074 .26531 L

.90415 .26287 L

.90091 .26049 L

.89766 .25817 L

.89442 .2559 L

.89117 .25368 L

.88793 .25151 L

.88468 .24937 L

.88144 .24728 L

.87819 .24522 L

.87495 .2432 L

.8717 .24122 L

.86846 .23926 L

.86521 .23733 L

.86197 .23544 L

.85872 .23356 L

.85548 .23172 L

.85223 .22989 L

.84899 .22809 L

.84575 .22631 L

.8425 .22456 L

.83926 .22282 L

.83601 .2211 L

.83277 .2194 L

.82952 .21771 L

.82628 .21604 L

.82303 .21439 L

.81979 .21275 L

Mistroke

.81654 .21113 L

.8133 .20953 L

.81005 .20793 L

.80681 .20635 L

.80356 .20479 L

.80032 .20323 L

.79707 .20169 L

.79383 .20016 L

.79058 .19864 L

.78734 .19714 L

.78409 .19564 L

.78085 .19416 L

.7776 .19269 L

.77436 .19123 L

.77111 .18978 L

.76787 .18834 L

.76462 .18691 L

.76138 .18549 L

.75813 .18408 L

.75489 .18269 L

.75164 .1813 L

.7484 .17992 L

.74515 .17856 L

.74191 .1772 L

.73866 .17585 L

.73542 .17452 L

.73217 .17319 L

.72893 .17188 L

.72568 .17057 L

.72244 .16928 L

.71919 .16799 L

.71595 .16672 L

.7127 .16545 L

.70946 .1642 L

.70621 .16296 L

.70297 .16172 L

.69972 .1605 L

.69648 .15928 L

.69323 .15808 L

.68999 .15688 L

.68674 .1557 L

.6835 .15452 L

.68025 .15336 L

.67701 .1522 L

.67376 .15105 L

.67052 .14991 L

.66728 .14878 L

.66403 .14766 L

.66079 .14655 L

.65754 .14545 L

Mistroke

.6543 .14436 L

.65105 .14327 L

.64781 .14219 L

.64456 .14112 L

.64132 .14006 L

.63807 .13901 L

.63483 .13796 L

.63158 .13692 L

.62834 .13589 L

.62509 .13486 L

.62022 .13334 L

.6186 .13284 L

.61698 .13233 L

.61536 .13183 L

.61373 .13133 L

.61211 .13084 L

.61049 .13034 L

.60887 .12985 L

.60724 .12935 L

.60562 .12886 L

.604 .12837 L

.60238 .12788 L

.60075 .1274 L

.59913 .12691 L

.59751 .12643 L

.59589 .12594 L

.59426 .12546 L

.59264 .12498 L

.59102 .12451 L

.5894 .12403 L

.58777 .12355 L

.58615 .12308 L

.58453 .12261 L

.58291 .12214 L

.58128 .12167 L

.57966 .1212 L

.57804 .12073 L

.57642 .12027 L

.5748 .1198 L

.57317 .11934 L

.57155 .11888 L

.56993 .11841 L

.56831 .11795 L

.56668 .1175 L

.56506 .11704 L

.56344 .11658 L

.56182 .11613 L

.56019 .11568 L

.55857 .11522 L

.55695 .11477 L

Mistroke

.55533 .11432 L

.5537 .11387 L

.55208 .11342 L

.55046 .11298 L

.54884 .11253 L

.54721 .11209 L

.54559 .11164 L

.54397 .1112 L

.54235 .11076 L

.54072 .11032 L

.5391 .10988 L

.53748 .10944 L

.53586 .10901 L

.53423 .10857 L

.53261 .10814 L

.53099 .1077 L

.52937 .10727 L

.52774 .10684 L

.52612 .10641 L

.5245 .10598 L

.52288 .10555 L

.52125 .10513 L

.51963 .1047 L

.51801 .10427 L

.51639 .10385 L

.51476 .10343 L

.51314 .103 L

.51152 .10258 L

.5099 .10216 L

.50827 .10174 L

.50665 .10133 L

.50503 .10091 L

.50341 .10049 L

.50178 .10008 L

.50016 .09967 L

.49854 .09925 L

.49692 .09884 L

.49529 .09843 L

.49367 .09802 L

.49205 .09761 L

.49043 .0972 L

.48881 .0968 L

.48718 .09639 L

.48556 .09599 L

.48394 .09558 L

.48232 .09518 L

.48069 .09478 L

.47907 .09438 L

.47745 .09398 L

.47583 .09358 L

Mistroke

.4742 .09319 L

.47258 .09279 L

.47096 .09239 L

.46934 .092 L

.46771 .09161 L

.46609 .09122 L

.46447 .09083 L

.46285 .09044 L

.46122 .09005 L

.4596 .08966 L

.45798 .08928 L

.45636 .08889 L

.45473 .08851 L

.45311 .08813 L

.45149 .08774 L

.44987 .08736 L

.44824 .08698 L

.44662 .08661 L

.445 .08623 L

.44338 .08586 L

.44175 .08548 L

.44013 .08511 L

.43851 .08474 L

.43689 .08437 L

.43526 .084 L

.43364 .08363 L

.43202 .08326 L

.4304 .0829 L

.42877 .08254 L

.42715 .08217 L

.42553 .08181 L

.42391 .08145 L

.42228 .0811 L

.42066 .08074 L

.41904 .08038 L

.41742 .08003 L

.41579 .07968 L

.41417 .07933 L

.41255 .07898 L

.41093 .07863 L

.4093 .07828 L

.40768 .07794 L

.40606 .07759 L

.40444 .07725 L

.40281 .07691 L

.40119 .07657 L

.39957 .07624 L

.39795 .0759 L

.39633 .07557 L

.3947 .07524 L

Mistroke

.39308 .07491 L

.39146 .07458 L

.38984 .07425 L

.38821 .07393 L

.38659 .07361 L

.38497 .07328 L

.38335 .07296 L

.38172 .07265 L

.3801 .07233 L

.37848 .07202 L

.37686 .07171 L

.37523 .0714 L

.37361 .07109 L

.37199 .07078 L

.37037 .07048 L

.36874 .07018 L

.36712 .06988 L

.3655 .06958 L

.36388 .06928 L

.36225 .06899 L

.36063 .0687 L

.35901 .06841 L

.35739 .06813 L

.35576 .06784 L

.35414 .06756 L

.35252 .06728 L

.3509 .06701 L

.34927 .06673 L

.34765 .06646 L

.34603 .06619 L

.34441 .06592 L

.34278 .06566 L

.34116 .0654 L

.33954 .06514 L

.33792 .06488 L

.33629 .06463 L

.33467 .06438 L

.33305 .06413 L

.33143 .06389 L

.3298 .06365 L

.32818 .0634 L

.32656 .06317 L

.32494 .06294 L

.32331 .06271 L

.32169 .06248 L

.32007 .06225 L

.31845 .06203 L

.31682 .06182 L

.3152 .0616 L

.31358 .06139 L

Mistroke

.31196 .06119 L

.31034 .06098 L

.30871 .06078 L

.30709 .06059 L

.30547 .06039 L

.30385 .0602 L

.30222 .06002 L

.3006 .05984 L

.29898 .05966 L

.29736 .05948 L

.29573 .05931 L

.29411 .05915 L

.29249 .05898 L

.29087 .05883 L

.28924 .05867 L

.28762 .05852 L

.286 .05838 L

.28438 .05824 L

.28275 .0581 L

.28113 .05797 L

.27951 .05784 L

.27789 .05772 L

.27626 .0576 L

.27464 .05749 L

.27302 .05738 L

.2714 .05727 L

.26977 .05717 L

.26815 .05708 L

.26653 .05699 L

.26491 .05691 L

.26328 .05683 L

.26166 .05676 L

.26004 .05669 L

.25842 .05663 L

.25679 .05657 L

.25517 .05652 L

.25355 .05648 L

.25193 .05644 L

.2503 .05641 L

.24868 .05638 L

.24706 .05636 L

.24544 .05635 L

.24381 .05634 L

.24219 .05634 L

.24057 .05635 L

.23895 .05636 L

.23732 .05638 L

.2357 .0564 L

.23408 .05644 L

.23246 .05648 L

Mistroke

.23083 .05653 L

.22921 .05658 L

.22759 .05664 L

.22597 .05671 L

.22434 .05679 L

.22272 .05688 L

.2211 .05697 L

.21948 .05707 L

.21786 .05718 L

.21623 .0573 L

.20974 .05786 L

.20325 .05857 L

.19676 .05944 L

.19027 .06047 L

.18378 .06168 L

.17729 .06309 L

.1708 .0647 L

.16431 .06653 L

.15782 .0686 L

.15133 .07093 L

.14484 .07355 L

.13835 .07647 L

.13187 .07971 L

.12538 .08332 L

.11889 .08733 L

.1124 .09178 L

.10591 .0967 L

.09942 .10217 L

.09293 .10824 L

.08644 .115 L

.07995 .12254 L

.07346 .13099 L

.06697 .14053 L

.06048 .15137 L

.05399 .16384 L

.0475 .17847 L

.04101 .19611 L

.03452 .21861 L

.02803 .25147 L

.02381 .30902 L

Mfstroke

1 0 0 r

.05 w

.03452 .21861 Mdot

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{644, 189.438},

  ImageMargins->{{43, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:40000_@P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCoa>64`00oa?o4hHC003o4olCQQ<00?lC

oa>64`00oa?o4hHC003o4gdC00<04a<0oa<64`00oa=m4`0301<C0?lC1Q<002TC1@3o4dlC0P3o4`LC

000[4`0301<C0?lCCa<00`0C4`1^4`d0RQ<002DC0`034`0301<C00@C0P3o4dTC00<04a<0IQ<800`C

3@1n4`00:a<00`0C4`044`0301<C0?lCB1<00`0C4`1Q4`D081<807LC000[4`0301<C00@C00<04a<0

oa=84`0301<C05hC100/4`L0L1<002XC0P064`0301<C0?lCB1<00`0C4`1L4`<0=A<706XC000b4`03

01<C0?lCB1<205/C0P0o4`H0I1<0038C00<04a<0oa=84`0301<C05PC0P164`H0Ga<0038C00<04a<0

oa=84`0301<C05HC0P1>4`D0FQ<0038C00<04a<0oa=84`0301<C05DC0P1C4`D0EQ<0038C00<04a<0

oa=84`0301<C05@C00<04a<0Ea<5058C000b4`0301<C0?lCB1<205<C0P1N4`<0D1<0038C00<04a<0

oa=84`0301<C00lC5P0/4`80HA<404dC000b4`0301<C0?lCB1<00`0C4`0:4`D05Q<9028C0P1U4`<0

Ba<0038C00<04a<0oa=84`0301<C00DC1@0S4`L06a<206PC0`194`00<Q<00`0C4`3o4c/C1@024`03

01<C00<C00<04a<00a<202lC1P0D4`80Ja<204PC000b4`0301<C0?lC?A<01`0C4a<04`0011<00`0C

4`0303HC1P0>4`80KA<304HC000b4`0301<C0?lC=a<300<C00L04a<C01<000@C0`0n4`H02A<00`0C

4`1^4`80AA<0038C00<04a<0oa<m4`0701<C4`0C00034`80AA<500@C00<04a<0L1<204@C000L4`03

01<C008C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<0oa<m4`0701<C4`0C00024`0301<004XC

1@1d4`80@Q<001/C00<04`0021<01`0C4a<04`001A<00`0C4`3o4c`C0P044`0401<0008C00<04a<0

Ba<6074C0P114`005Q<3008C00<04`0021<00`0C4`034`0301<C00<C0P3o4d<C0P044`0301<C04XC

00<04a<011<406hC0P104`006a<00`0C00094`0301<C00801Q<00`0C4`3o4d4C00<04a<011<00`0C

4`194`0301<C00TC101[4`0301<C03hC000K4`0301<000LC00<04`000Q<00`0C4`054`0301<C0?lC

@1<00`0C4`054`80BQ<00`0C4`0=4`@0J1<203hC000L4`0301<C00HC0`024`<01A<00`0C4`3o4clC

00<04a<01Q<00`0C4`184`0301<C018C101U4`0301<C03`C000b4`0301<C0?lC?Q<00`0C4`074`03

01<C04PC00<04a<05A<5068C00<04a<0>a<0038C00<04a<0oa<m4`0301<C00PC00<04a<0Aa<00`0C

4`0J4`@0Ga<203`C000b4`0301<C0?lC?1<00`0C4`094`0301<C04HC00<04a<07a<405`C0P0k4`00

<Q<00`0C4`3o4c/C00<04a<02Q<00`0C4`164`0301<C028C1@1I4`0301<C03TC000b4`0301<C0?lC

>Q<00`0C4`0;4`80Aa<00`0C4`0V4`@0Ea<00`0C4`0h4`00<Q<00`0C4`3o4cTC00<04a<031<00`0C

4`154`0301<C02XC101D4`80>A<0038C00<04a<0oa<i4`0301<C00`C00<04a<0AA<00`0C4`0^4`@0

DA<00`0C4`0g4`00<Q<00`0C4`3o4cPC00<04a<03A<00`0C4`144`0301<C03<C0P1?4`80>1<0038C

00<04a<0oa<g4`0301<C00hC00<04a<0A1<00`0C4`0e4`@0C1<203LC000b4`0301<C0?lC=Q<00`0C

4`0?4`0301<C04@C00<04a<0>A<204/C00<04a<0=A<0038C00<04a<0oa<f4`0301<C00lC0P144`03

01<C03`C10174`80=Q<0038C00<04a<0oa<e4`0301<C010C00<04a<0@a<00`0C4`0o4`<0AQ<00`0C

4`0d4`00<Q<00`0C4`3o4cDC00<04a<041<00`0C4`134`0301<C048C0`134`80=A<0024C00<04a<0

0Q<00`0C4`024`0301<C00@C00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`164`<0@A<00`0C

4`0c4`0081<00`0C00074`0301<000DC00<04a<0oa<d4`0301<C014C00<04a<0@Q<00`0C4`194`80

?a<00`0C4`0c4`006a<3008C00<04`002A<00`0C4`034`80oa<d4`0301<C018C00<04a<0@Q<00`0C

4`1;4`<0?A<00`0C4`0b4`0081<00`0C00074`801Q<00`0C4`3o4c<C00<04a<04Q<204<C00<04a<0

CQ<203/C00<04a<0<Q<0020C00<04`001a<00`0C4`054`0301<C0?lC<Q<00`0C4`0C4`0301<C044C

00<04a<0DA<303PC00<04a<0<Q<0024C00<04a<01Q<300DC00<04a<0oa<b4`0301<C01<C00<04a<0

@A<00`0C4`1D4`80=a<00`0C4`0a4`00<Q<00`0C4`3o4c4C00<04a<051<00`0C4`114`0301<C05HC

0`0d4`0301<C034C000b4`0301<C0?lC<A<00`0C4`0>4`0301<C00<C00<04a<0@1<00`0C4`1I4`<0

<Q<2038C000b4`0301<C0?lC<1<00`0C4`0>4`0301<000@C00<04a<0@1<00`0C4`1L4`80<A<00`0C

4`0`4`00<Q<00`0C4`3o4c0C00<04a<02A<300@C00<04a<00Q<3040C00<04a<0GQ<202lC00<04a<0

<1<0038C00<04a<0oa<`4`0301<C00hC0P054`0301<C03lC00<04a<0HA<302`C00<04a<0<1<0038C

00<04a<0oa<^4`033A<0010C00<04a<011<00`0C4`0o4`0301<C06@C00<04a<0:A<00`0C4`0`4`00

<Q<00`0C4`3o4b/C1Pd@4`<011<00`0C4`0o4`0301<C06DC0`0X4`80<A<0038C00<04a<0oa<Z4`T=

5A<00`0C4`0o4`0301<C06PC00<04a<09Q<00`0C4`0_4`00<Q<00`0C4`3o4bXC2@dE4`0301<C03lC

00<04a<0JA<302DC00<04a<0;a<0038C00<04a<0oa<Z4`T=5A<2040C00<04a<0K1<202<C00<04a<0

;a<0038C00<04a<0oa<Y4`/=51<00`0C4`0o4`0301<C06dC0P0R4`0301<C02lC000b4`0301<C0?lC

:Q<93ADC00<04a<0?a<00`0C4`1_4`8081<00`0C4`0_4`00<Q<00`0C4`3o4bXC2@dE4`0301<C03hC

00<04a<0LQ<201hC00<04a<0;a<001`C00<04a<00Q<0100C4a<300<C00<04a<011<00`0C4`3o4bXC

2@dE4`0301<C03hC00<04a<0M1<201`C00<04a<0;a<001/C00<04`001a<00`0C4`024`0301<000DC

00<04a<0oa<[4`H=5a<203lC00<04a<0MQ<201XC00<04a<0;a<001HC0`024`0301<000PC00<04a<0

0a<00`0C4`034`80oa<_4`033A<C01LC00<04a<0?Q<00`0C4`1h4`0301<C01HC00<04a<0<1<001/C

00<04`0021<0100C4a<200HC00<04a<0oa<]4`0301<C01PC00<04a<0?Q<00`0C4`1i4`805Q<00`0C

4`0`4`006a<00`0C00074`0301<0008C00<04a<01A<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`03

01<C07/C00<04a<04a<00`0C4`0`4`0071<00`0C4`074`0401<C4`<01A<00`0C4`3o4bdC00<04a<0

61<00`0C4`0n4`0301<C07`C00<04a<04Q<00`0C4`0`4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C

4`0m4`0301<C07hC0P0B4`0301<C030C000b4`0301<C0?lC;A<00`0C4`0H4`80?Q<00`0C4`204`80

41<00`0C4`0`4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0Q4`D00Q<00`0C4`0B4`0301<C00/C

1@000a<0000Q4`D00Q<00`0C4`0O4`D00Q<00`0C4`0K4`0401<C4`D000<C00000a<00`0C4`0a4`00

<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0S4`0701<C4`0C000C4`0301<C00dC00L04a<C01<0028C

00<04a<00Q<00`0C4`0Q4`0701<C4`0C000L4`8011<00`0C4`034`0401<C03<C000b4`0301<C02HC

00<04a<00Q<0100C4a<302<C00<04a<00Q<00`0C4`024`<08Q<00`0C4`024`0401<C4`8091<00`0C

4`024`0301<C008C00<04a<09Q<5044C00<04a<061<00`0C4`0S4`0301<C00<C00<04a<04A<00`0C

4`0=4`0701<C4`0C000R4`0301<C008C00<04a<08A<01`0C4a<04`007Q<01@0C4a<000@C0P024`03

01<C034C000b4`0301<C02DC00<04`001a<00`0C4`0R4`0301<000TC00<04a<081<00`0C00074`03

01<0028C00<04`001a<00`0C000Y4`0301<C044C00<04a<061<00`0C4`0S4`0401<C4`8051<00`0C

4`0=4`0401<C4`808a<00`0C4`034`0301<C020C00<04a<00Q<00`0C4`0N4`8000<C01<00Q<00`0C

00024`0301<C034C000b4`0301<C02DC00<04`0021<00`0C4`0Q4`0301<000LC100Q4`0301<000LC

00<04`008Q<00`0C00074`0301<002TC00<04a<0@1<00`0C4`0I4`0301<C02<C00D04a<C000E4`03

01<C00dC00D04a<C000T4`0701<C4`0C000R4`0701<C4`0C000Q4`800a<01@0C01<003@C000b4`03

01<C02DC00<04`0021<00`0C4`0Q4`0301<000LC00<04`008Q<00`0C00074`808a<00`0C00084`03

01<C02PC00<04a<0@1<00`0C4`0I4`808a<200<C0`0C4`0301<C00`C0P044`808A<200<C0`0Q4`80

11<00`0C4`0P4`8011<200034`0C03<C000b4`0301<C02DC00<04`001a<00`0C000R4`0301<000PC

0P0R4`0301<000LC00<04a<08Q<00`0C00074`0301<002TC00<04a<0@1<00`0C4`0I4`0301<C03dC

00<04a<0R1<00`0C4`054`0301<C038C000b4`0301<C02HC00<04a<01a<00`0C4`0R4`0301<C00PC

00<04a<08A<00`0C4`074`808a<00`0C4`074`0301<C02LC0P124`0301<C01TC00<04a<0?A<00`0C

4`294`801A<00`0C4`0b4`00<Q<00`0C4`3o4b`C00<04a<06A<00`0C4`0m4`0301<C08/C00D04a<C

000e4`00<Q<00`0C4`3o4b`C00<04a<06A<00`0C4`0m4`0301<C08/C00@04a<04a<401lC000b4`03

01<C0?lC;1<00`0C4`0I4`0301<C03dC00<04a<0S1<201@C0`0P4`00<Q<00`0C4`3g4`<0:a?o00XC

00<04a<07Q<0038C00<04a<0n1<00`0C4`0[4`0301<C008C00@04a<021<00`0C4`054`0301<C00DC

00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C

4`034`0301<000LC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC

00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C

4`054`0301<C00DC00<04a<01A<300HC00<04a<031<2020C000/4jl0@`d600TC00<04a<0<1<00`0C

4`0I4`0301<C02HC00<04a<051<00`0C4`0@4`0301<C02HC00<04a<09Q<00`0C4`0V4`0401<C03HC

000b4`0301<C00PC00<04a<02A<00`0C4`094`0301<C00TC00<04a<021<00`0C4`094`0301<C00TC

00<04a<02A<00`0C4`084`0301<C00TC00<04a<02A<00`0C4`094`0301<C00TC40d74`0301<C00TC

00<04a<02A<00`0C4`084`0301<C00TC00<04a<02A<00`0C4`0<4`@0<1<00`0C4`0I4`0301<C03dC

00<04a<0Ra<01@0C4a<003DC000b4`0301<C02`C00<04a<00Q<a3BPC00<04`d02@dS4`0301<C02`C

00<04a<0@1<00`0C4`0I4`0301<C03dC00<04a<0RQ<00`0C4`024`0301<C03<C000b4`0301<C02XC

1`da4bX=Wa<00`0C4`0I4`0301<C03dC00<04a<0RA<00`0C4`044`0301<C038C000b4`0301<C024C

2@go4`8C00<04a<06A<203hC00<04a<0Qa<200LC00<04a<0<Q<0038C00<04a<05Q<;3OlC2a<00`0C

4`0I4`0301<C03dC00<04a<0Qa<00`0C4`064`0301<C038C000b4`0301<C00/C2`go4aLC00<04a<0

61<00`0C4`0m4`0301<C08HC00<04a<021<00`0C4`0a4`00<Q<>3OlC8Q<00`0C4`0H4`0301<C03dC

00<04a<0Q1<200/C00<04a<0<A<0038C00<04a<0oa<]4`0301<C01PC00<04a<0?A<00`0C4`234`03

01<C00/C00<04a<0<A<0038C00<04a<0oa<]4`0301<C01PC00<04a<0?A<00`0C4`224`0301<C00`C

00<04a<0<A<0038C00<04a<0oa<]4`0301<C01PC0P0n4`0301<C080C0P0?4`0301<C034C000b4`03

01<C0?lC;A<00`0C4`0H4`0301<C03dC00<04a<0Oa<00`0C4`0@4`0301<C030C000b4`0301<C0?lC

;A<00`0C4`0H4`0301<C03hC00<04a<0O1<201<C00<04a<0<1<0038C00<04a<0oa<]4`0301<C01PC

00<04a<0?Q<00`0C4`1k4`8051<00`0C4`0`4`00<Q<00`0C4`3o4bdC00<04a<061<00`0C4`0n4`03

01<C07TC0P0F4`0301<C030C000b4`0301<C0?lC;A<00`0C4`0H4`0301<C03hC00<04a<0N1<00`0C

4`0F4`0301<C030C000b4`0301<C0?lC;Q<00`0C4`0G4`80?a<00`0C4`1f4`806A<00`0C4`0`4`00

<Q<00`0C4`3o4bhC00<04a<05a<00`0C4`0n4`0301<C07@C0P0L4`0301<C02lC000L4`0301<C008C

00@04a<C0`034`0301<C00@C00<04a<0oa<^4`0301<C01LC00<04a<0?Q<00`0C4`1c4`0301<C01`C

00<04a<0;a<001/C00<04`001a<00`0C4`024`0301<000DC00<04a<0oa<^4`0301<C01LC00<04a<0

?a<00`0C4`1`4`807a<00`0C4`0_4`006a<00`0C00084`0301<C00<C00<04a<00a<20?lC<1<00`0C

4`0F4`0301<C03lC00<04a<0KA<3024C00<04a<0;a<001/C00<04`0021<0100C4a<200HC00<04a<0

oa<_4`0301<C01HC00<04a<0?a<00`0C4`1/4`808a<00`0C4`0_4`006a<00`0C00074`0301<0008C

00<04a<01A<00`0C4`3o4blC00<04a<05Q<2040C00<04a<0JQ<202DC00<04a<0;a<001`C00<04a<0

1a<0100C4a<300DC00<04a<0oa<_4`0301<C01HC00<04a<0?a<00`0C4`1X4`809a<00`0C4`0_4`00

<Q<00`0C4`3o4blC00<04a<05Q<00`0C4`0o4`0301<C06HC0P0Y4`0301<C02lC000b4`0301<C0?lC

<1<00`0C4`0E4`0301<C03lC00<04a<0I1<202XC00<04a<0<1<0038C00<04a<0oa<`4`0301<C00lC

00<04a<00a<00`0C4`0o4`0301<C068C0P0/4`0301<C030C000b4`0301<C0?lC<1<00`0C4`0>4`03

01<000@C00<04a<0@1<00`0C4`1N4`<0;Q<00`0C4`0`4`00<Q<00`0C4`3o4c0C00<04a<041<00`0C

4`024`<0@1<00`0C4`1L4`<0<1<00`0C4`0`4`00<Q<00`0C4`3o4c4C00<04a<03A<200DC00<04a<0

@1<00`0C4`1J4`80<Q<2038C000b4`0301<C0?lC<A<00`0C4`0=4`0301<C00@C00<04a<0@A<00`0C

4`1G4`80=1<00`0C4`0a4`00<Q<00`0C4`3o4c8C00<04a<031<300@C00<04a<0@A<00`0C4`1D4`<0

=Q<00`0C4`0a4`00<Q<00`0C4`3o4c8C00<04a<04a<00`0C4`114`0301<C058C0`0g4`80<a<0038C

00<04a<0oa<c4`0301<C018C0P124`0301<C04lC0`0j4`0301<C038C000b4`0301<C0?lC<a<00`0C

4`0B4`0301<C048C00<04a<0C1<303`C00<04a<0<Q<0038C00<04a<0oa<d4`0301<C014C00<04a<0

@Q<00`0C4`194`<0?Q<00`0C4`0c4`00<Q<00`0C4`3o4c@C00<04a<04A<00`0C4`124`0301<C04LC

0`104`0301<C03<C000Q4`0301<C008C00<04a<00Q<00`0C4`044`0301<C0?lC=A<00`0C4`0@4`03

01<C048C00<04a<0A1<3048C0P0e4`0081<00`0C00074`0301<000DC00<04a<0oa<e4`0301<C010C

00<04a<0@a<00`0C4`104`<0AA<00`0C4`0d4`0081<00`0C00094`0301<C00<C0P3o4cLC00<04a<0

3a<204@C00<04a<0?A<304LC0P0f4`0081<00`0C00074`801Q<00`0C4`3o4cHC00<04a<03a<00`0C

4`144`0301<C03TC0`1:4`0301<C03DC000P4`0301<000LC00<04a<01A<00`0C4`3o4cLC00<04a<0

3Q<00`0C4`144`0301<C03HC101;4`80=a<0024C00<04a<01Q<300DC00<04a<0oa<h4`0301<C00dC

00<04a<0A1<00`0C4`0c4`<0Ca<00`0C4`0f4`00<Q<00`0C4`3o4cTC00<04a<031<00`0C4`154`03

01<C02lC0`1A4`0301<C03LC000b4`0301<C0?lC>A<00`0C4`0<4`0301<C04DC00<04a<0:a<405<C

0P0i4`00<Q<00`0C4`3o4cXC00<04a<02a<204LC00<04a<09a<405HC00<04a<0>1<0038C00<04a<0

oa<j4`0301<C00/C00<04a<0AQ<00`0C4`0S4`D0F1<203XC000b4`0301<C0?lC>a<200/C00<04a<0

AQ<00`0C4`0P4`@0Fa<203/C000b4`0301<C0?lC?A<00`0C4`084`0301<C04LC00<04a<06a<405lC

00<04a<0>Q<0038C00<04a<0oa<n4`0301<C00LC00<04a<0Aa<201PC1@1Q4`0301<C03/C000b4`03

01<C0?lC?Q<00`0C4`074`0301<C04PC00<04a<04a<406@C0P0m4`00<Q<00`0C4`3o4clC00<04a<0

1Q<204XC00<04a<03Q<406LC0P0n4`00<Q<00`0C4`3o4d0C0P064`0301<C04TC00<04a<02Q<406XC

0P0o4`00<Q<00`0C4`3o4d8C00<04a<00a<00`0C4`1:4`0301<C00DC1@1/4`80@1<0038C00<04a<0

oa=34`800a<00`0C4`1:4`8000<C00000`1`4`80@A<0038C00<04a<0oa<k4`D00Q<0100C4`024`03

01<C04TC1@1c4`80@Q<001`C00<04a<00Q<00`0C4`024`0301<C008C00<04a<011<00`0C4`3o4cdC

00L04a<C01<0008C0`174`D00Q<00`0C4`1a4`80@a<001/C00<04`0021<01`0C4a<04`001A<00`0C

4`3o4cdC00L04a<C01<000@C0`104`D021<00`0C4`1^4`80AA<001/C00<04`0021<00`0C4`034`03

01<C00<C0P3o4chC00L04a<C01<000@C00@04`00>Q<500dC00<04a<0KA<204HC000K4`0301<000TC

00<04a<00P064`0301<C0?lC?A<01`0C4a<04`0011<0100C4a<3034C1P0C4`80Ja<304LC000K4`03

01<000LC00<04`000Q<00`0C4`054`0301<C0?lC?1<200@C00<04a<00a<00`0C4`044`<0:1<701TC

0P1Y4`80BA<001`C00<04a<01Q<3008C0`054`0301<C0?lCB1<00`0C4`074`D06a<9020C00<04a<0

I1<304/C000b4`0301<C0?lCB1<00`0C4`0<4a`0:A<2068C0`1=4`00<Q<00`0C4`3o4dPC0P1C4`80

Ga<304lC000b4`0301<C0?lCB1<00`0C4`1C4`80FQ<4058C000b4`0301<C0?lCB1<00`0C4`1D4`80

EQ<405DC000b4`0301<C0?lCB1<00`0C4`1F4`80Ca<505TC000b4`0301<C0?lCB1<00`0C4`1G4`<0

B1<605dC000b4`0301<C0?lCB1<00`0C4`1I4`<0@1<7068C000b4`0301<C0?lCB1<205`C0`0h4`L0

J1<0038C00<04a<0oa=84`0301<C05hC0`0^4`P0KQ<0038C00<04a<0oa=84`0301<C060C1@0S4`P0

MA<0038C00<04a<0oa=84`0301<C06@C1`0D4`X0O1<0038C00<04a<0oa=84`0301<C06XC5@264`00

<Q<00`0C4`3o4dPC00<04a<0oa<64`00:A<500@C00<04a<0oa=84`80oa<74`00:a<00`0C4`044`03

01<C0?lCB1<00`0C4`3o4`HC000[4`0301<C00@C0P3o4dTC00<04a<0oa<64`00:a<00`0C4`3o4olC

F1<002/C00<04a<0oa?o4ePC000Z4`80oa?o4eXC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olC

QQ<00?lCoa>64`00LA<400034`0000L000<C000011<0100C4a<200@C00<04a<00Q<00`0C4`024`03

01<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<0

0Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C0?lC[1<0074C0`084`0301<C00<C

00<04a<01a<01P0C4`0C008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`03

01<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0a<00`0C4`2Q4`80oa<94`00La<00`0C4`04008C00<04a<00Q<00`0C4`074`0701<C4`0C00024`03

01<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<000<C00<04a<0XQ<00`0C4`3o4`LC

000I4`@000<C00001P024`X00Q<2008C0`024`<00a<200064`0001<09a<200PC00<04a<00a<00`0C

4`074`0501<C4`000a<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`00

0Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00044`03

01<C09lC0`024`0301<C0?lC11<001XC00H04a<04`024`0301<000@C00H04a<04`024`0301<000DC

00<04a<00Q<01@0C4a<0008C00@04`0C0P0a4`0701<C4`0C00074`0301<0008C00<04`000Q<00`0C

00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<0008C

00<04`000Q<00`0C00024`0301<0008C00<04`000Q<00`0C00024`0301<000@C00<04a<0VA<0200C

4`0C01<0oa<54`006Q<01P0C4`0C00@C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00a<00`0C

4`024`0501<C4`000Q<0100C01<2030C0P044`0301<C00LC00<04a<00Q<00`0C4`024`0301<C008C

00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C

4`024`0301<C008C00<04a<00Q<00`0C4`024`0401<C4`<00a<00`0C4`2J4`0801<C01<04`3o4`DC

000J4`0501<C01<00P034`800a<00`0C4`024`800a<00`0C4`034`0301<C008C00D04a<C00024`06

01<001<0oa<_4`<000@C01<0oa<54`006Q<01P0C4`0C008C00<04`000Q<00`0C00044`0>01<C01<0

4`0C01<04`024`0501<C4`000Q<01P0C000C0?lC<a<00`0C003o4`DC000I4`@000<C00002`024`D0

00DC00004`0500044`0000<C0P0011<001<20?lC=1<00`0C4`3o4`@C003o4olCQQ<00?lCoa>64`00

oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC003o4olCQQ<00?lCoa>64`00oa?o4hHC0000\

\>"],

  ImageRangeCache->{{{0, 643}, {188.438, 0}} -> {-0.0544538, -0.0147182, 

  0.0032798, 0.0032798}, {{16.5625, 306.938}, {183.938, 

  4.4375}} -> {-0.212391, -1.1178, 0.00424647, 0.0130875}, {{336, 626.375}, {

  183.938, 4.4375}} -> {4.77084, -14.119, 0.0242408, 0.16996}}]

}, Closed]]

}, Open  ]]

}, Open  ]],



Cell[CellGroupData[{



Cell["3 The Cubic Polynomial Problem", "Subsection",

  FontSize->18],



Cell[CellGroupData[{



Cell[BoxData[{

    \(We\ now\ try\ to\ understand\ the\ global\ structure\ of\ the\ surface\ 

      \(q\_0\) \((a, k)\) . \nThe\ above\ bifurcation\ diagrams\ are\ just\ 

      sections\ of\ this\ surface\ at\ various\), 

    \(values\ of\ k . \ In\ this\ section\ we\ investigate\ the\ one - 

      dimensional\ \ algebraic\), 

    \(problem, \n

    \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ 

    c\  + \ d\ x\  - \ x\^3\  = \ 

      0. \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \

\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \((3.1)\)\), 

    \(This\ equation\ \ has\ a\ cubic\ nonlinearity\ and\ two\ parameters\ 

      "\<c\>"\ and\ "\<d\>" . \ Our\), 

    \(buckling\ problem\ also\ has\ a\ cubic\ nonlinearity\ and\ two\ 

      parameters\ "\<a\>"\ and\ "\<k\>", \n

    but\ is\ much\ more\ complicated\ since\ it\ is\ infinite\ dimensional\ 

      problem . \ The\ \), 

    \(surface\ x \((c, d)\)\ defined\ by\ \((3.1)\)\ is\ shown\ below\ 

      together\ with\ the\ graph\ of\), 

    \(the\ equation\ \), 

    \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ 

    d\  = \ 3\ 

        \((c\/2)\)\^\(2\/3

              \)\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \

\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ 

        \((3.2)\)\), 

    \(called\ a\ cusp, \ 

    which\ is\ the\ set\ of\ points\ in\ the\ \((c, d)\) - 

      plane\ for\ which\ the\), 

    \(folding\ surface\ below\ has\ vertical\ tangency . \ Over\ a\ point\ in

      \ the\ interior\ of\), 

    \(the\ cusp, \ the\ surface\ has\ multiple\ \(solutions . \)\ \t\n\t\t\t\n

    \)}], "Input",

  FontFamily->"Times New Roman",

  FontSize->16],



Cell[GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000@0000300P10`400001

00000800002008200000P800P020P<30`<3L`:K:l03o0?oo0000ool0o`3o

ooooo`000800002008200000P800P020P820P<30`?l0003o0?oo0000ool0

o`3oooooo`000800002008200000P800P020P820P<30`?l0003o0?oo0000

ool0o`3oooooo`000800002008200000P800P020P820P<30`?l0003o0?oo

0000ool0o`3oooooo`000800002008200000P800P020P820P<30`?l0003o

0?oo0000ool0o`3oooooo`000800002008200000P800P020P820P<30`?l0

003o0?oo0000ool0o`3oooooo`000800002008200000P800P020P820P<30

`?l0003o0?oo0000ool0o`3oooooo`000800002008200000P800P020P820

P<30`?l0003o0?oo0000ool0o`3oooooo`000800002008200000P800P020

P820P<30`?l0003o0?oo0000ool0o`3oooooo`000800002008200000P800

P020P820P<30`?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P820P<30`?l0003o0?oo0000ool0o`3oooooo`00080000200820

0000P800P020P820P<30`?l0003o0?oo0000ool0o`3oooooo`0008000020

08200000P800P020P820P<30`?l0003o0?oo0000ool0o`3oooooo`000800

002008200000P800P020P820P<30`?l0003o0?oo0000ool0o`3oooooo`00

0800002008200000P800P020P820P<30`?l0003o0?oo0000ool0o`3ooooo

o`000800002008200000P800P?okl:2PY820P?l0003o0?oo0000ool0o`3o

ooooool?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo

3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?

o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l0

0?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?

10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo

3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?

o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l0

0?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?

10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo

3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?

o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l0

0?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?

10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo

3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?

o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l0

0?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?

10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo

3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?

o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l0

0?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?

10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo

3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?

o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l0

0?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?

10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo

3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?

o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l0

0?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?

10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo

3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?

o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l0

0?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?

10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo

3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?

o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l0

0?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?

10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo

3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?

o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l0

0?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?

10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo

3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?

o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l0

0?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?

10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo

3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?

o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l0

0?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?

10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo

3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?

o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l0

0?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?

10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo

3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?

o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l0

0?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?

10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo

3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?o`oo3ol?10l00?l?

o`oo3ol?10l00?l?o`oo3ol?10l00?l?f@l00aT?3`0I3`036@l?0?l?o`l;

3`00o`oG3`8I7@l26Ol?o`l;3`00o`oF3`8I7`l26Ol?o`l:3`00o`oF3`8I

7`l26Ol?o`l:3`00o`nU3`<I00<?6AT06Pl56@/?0QT63`DI0Pl00aT?3`03

3`TI1@l26@h?2AT23`036@l?00D?1AWo3n8?003o3j@?0aT00`lI6@036AL?

0aT23`8I2Pl26@D?0aT33`046@l?6@D?21T53`8I3`l86@<?00<I3`l00`l3

6@8?0QWo3n4?003o3j<?0aT33`<I60l26@@?0QT83`<I10l36@L?00<I3`l0

10l86@@?0aT?3`PI0Pl00aT?3`033`8I10l26Ol?h0l00?l?X`l36@<?0aTN

3`<I1`l36@@?0aT73`036@l?00D?00<I3`l00`l00aT?3`023`<I40l00aT?

3`033`046@l?6@/?0aWo3ml?003o3j<?0aT33`<I7Pl36@L?0aT43`<I20l0

0aT?3`053`036@l?00L?0aTA3`036@l?00H?00<I3`l020l36Ol?g`l00?l?

X`l36@<?0aT73`XI30l46@L?0aT43`<I20l00aT?3`053`8I20l36A4?0QT7

3`036@l?00L?11Wo3ml?003o3j<?0aT33`<I70l56@L?0aT43`<I20l00aT?

3`063`8I1`l36A8?0QT63`036@l?00H?1AWo3ml?003o3j<?0aT33`<I6`l5

6@P?0aT53`8I0Pl36@@?00<I3`l01Pl26@H?0aT23`036@l?00D?00<I3`l0

1Pl26@H?00<I3`l010l56Ol?h0l00?l?Y0l36@033aTI008I1`l:6@/?0QT;

3`8I1@l36@043aTI6@@?00<I3`l01Pl26@H?0QT43`036@l?00<?00<I3`l0

1`l26@H?00<I3`l01@l26Ol?hPl00?l?Y@l36@043aTI6Ad?0QT:3`8I1`l4

6@D?00<I3`l01Pl36@D?0QT43`036@l?00<?00<I3`l01`l36@D?00<I3`l0

1Pl26Ol?h@l00?l?Z@l36Ad?0aT:3`8I40l00aT?6@053`<I10l26@H?00DI

3`l?6@043`036@l?00<?0aT63`036@l?00D?0aWo3n0?003o3jT?0aTH3`8I

0Pl46@X?0QT@3`046@l?6@<?11T43`8I1`l00aT?6@063`046@l?3`@I1Pl0

0aT?3`026@8?11Wo3n0?003o3jT?0aTI3`LI2`l26@l?00<I3`l01aT43`8I

20l00aT?6@063`LI1`l011T?3`l76Ol?h0l00?l?Z0l46AX?1AT>3`036@l?

00d?00@I3`l?11T43`036@l?00T?00<I3`l01`l46@T?00@I3`l?1AWo3n4?

003o3ol?o`oo3`@?003o3ol?o`oo3`@?003o3ol?o`oo3`@?003o3ol?o`oo

3`@?003o3ol?o`oo3`@?003o3ol?o`oo3`@?003o3ol?o`oo3`@?003o3ol?

o`oo3`@?003o3ol?o`oo3`@?003o3ol?o`oo3`@?003o3ol?o`oo3`@?003o

3ol?o`oo3`@?003o3ol?o`oo3`@?003o3ol?o`oo3`@?003o3ol?o`oo3`@?

003o3ol?o`oo3`@?003o3ol?o`oo3`@?003o3ol?o`oo3`@?003o3ol?o`oo

3`@?003Y3`80o`oo3ol?60l00>T?@`3o3ol?ePl00>T?P`3o3ol?UPl00>P?

0P123h00o`oo3eH?003X3`80PPn00?l?o`lF3`00i`l20<<?P@3o3m@?003W

3`80o`l43h40P@l30?l?40l00>H?0P3o3dH?P0113`<0o`l@3`00iPl20?l?

QPn20?l?4Pl00>H?0P3o3lH?@P3o3a8?003U3`80o`l?3`H0l@l20?l?4`l0

0>D?0P3o3`h?0P023`<0l@l20?l?4`l00>@?0P3o3`h?0P043`80l0l20?l?

50l00>@?0P3o3`h?0P043`80k`l20?l?5@l00><?0P3o3`l?0P043`80k`l2

0?l?5@l00><?0P3o3`l?0P043`80kPl20?l?5Pl00><?0P3o3`l?0P043`80

kPl20?l?5Pl00>8?0P3o3a4?0P023`<0k@l20?l?5`l00>8?0P3o3a8?1P3/

3`80o`lH3`00h@l20?l?5`l20>`?0P3o3aP?003Q3`80o`lG3`80j`l20?l?

6@l00>0?0P3o3aP?0P3[3`80o`lI3`00h0l20?l?o`l53`80o`lJ3`00h0l2

0?l?o`l43`80o`lK3`00g`l20?l?o`l53`80o`lK3`00g`l20?l?o`l43`80

o`lL3`00gPl20?l?o`l53`80o`lL3`00gPl20?l?o`l43`80o`lM3`00g@l2

0?l?5`l20>X?0P3o3ah?003M3`80o`lG3`<0j@l20?l?7Pl00=d?0P2Y3`@I

J@l30>P?0P3o3al?003L3`80Z@l00`0I6@056FH?103W3`80o`lO3`00g0l2

0:T?10076F0?10000`l0003V3`80o`lP3`00f`l20:d?10076Ed?1P000`l0

3`3S3`80o`lQ3`00f`l20;0?10076EP?10000`l000040><?0P3o3b4?003J

3`80]0l400LIE@l00`0?000803X?0aVU3`80o`lR3`00fPl20;L?10076E4?

3@0g3`DIY@l20?l?8Pl00=X?0P2j3`@01QU>3`X000@?0000=0l66@0300l?

0:<?0P3o3b<?003I3`80_Pl400HICPl300033`0000D0<Pl66@0300l?0:@?

0P3o3b@?003I3`80`@l300LIC0l503D?1AT00`0?3`2W3`80o`lT3`00f0l2

0<D?0`066Dh?00<03`l0<@l56@0300l?0:P?0P3o3bD?003H3`80b0l300HI

BPl00`0?3`0`3`DI00<03`l0ZPl20?l?9@l00=L?0P3<3`801QU83`0300l?

02h?1AT00`0?3`2[3`80o`lV3`00e`l20<l?0P066DD?00<03`l0:`l66Jl?

0P3o3bL?003G3`80d@l200HI@Pl00`0?3`0Z3`HI/@l20?l?9`l00=H?0P3E

3`801AU03`0300l?02P?1AT00`0?3`2`3`80o`lX3`00ePl20=L?0P056Cd?

00<03`l09`l56@0300l?0;8?0P3o3bP?003E3`80fPl200DI>`l00`0?3`0U

3`DI]Pl20?l?:@l00=D?0P3L3`8011Tj3`0300l?02<?1AVg3`80o`lZ3`00

e0l20=l?0P046CL?00<03`l08Pl56KT?0P3o3bX?003D3`80h@l00`0I6@02

6CH?00<03`l080l56KX?0P3o3b/?003D3`80h`l0100I6ATe3`0300l?01d?

00<06AT00aVl3`80o`l[3`00d`l20>D?00@06ATI<`l00`0?3`0L3`0301TI

00<I_@l20?l?;0l00=<?0P3W3`@I<@l00`0?3`0J3`0301TI00<I_Pl20?l?

;@l00=8?0P3Y3`@I;`l00`0?3`0I3`0301TI00<I`0l20?l?;@l00=8?0P3Z

3`0401TI6Bh?00<03`l05`l00`0I6@036L4?0P3o3bh?003A3`80k0l0100I

6AT]3`0300l?01D?00<06AT00aW33`80o`l^3`00d@l20>d?00@06ATI:`l0

0`0?3`0D3`0301TI00<Ia0l20?l?;`l00=4?0P3^3`0401TI6BX?00<03`l0

4`l56LD?0P3o3c0?003@3`80l0l00`0I6@0Y3`0300l?018?1AW73`80o`l`

3`00d0l20?4?00<06AT0:0l00`0?3`0@3`0301TI008Ib0l20?l?<@l00<l?

0P3c3`<I9`l00`0?3`0>3`0301TI008IbPl20?l?<@l00<l?0P3d3`8I9Pl0

0`0?3`0>3`0301TI008IbPl20?l?<Pl00<h?0P3e3`0301TI02D?00<03`l0

30l00`0I6@026L/?0P3o3c<?003>3`80mPl26BD?00<03`l02`l00`0I6@02

6L`?0P3o3c<?003>3`80m`l26B<?00<03`l02Pl00`0I6@026Ld?0P3o3c@?

003=3`80n0l36B8?00<03`l02@l00`0I6@026Lh?0P3o3c@?003=3`80n@l2

6B4?00<03`l02@l0100I6AW?3`80o`le3`00c0l20?X?00<06AT080l00`0?

3`083`@Ic`l20?l?=Pl00<`?0P3k3`8I80l00`0?3`063`0301TI008Id0l2

0?l?=Pl00</?0P3l3`0301TI01h?00<03`l01Pl0100I6AWA3`80o`lg3`00

b`l20?d?0QTN3`0300l?00D?00@06ATIdPl20?l?=`l00</?0P3m3`8I7Pl0

0`0?3`043`0401TI6M8?0P3o3cP?003:3`80o`l26A`?00<03`l010l0100I

6AWB3`80o`li3`00bPl20?l?0QTL3`0300l?00<?00@06ATId`l20?l?>@l0

0<T?0P3o3`4?00<06AT06Pl00`0?3`033`0401TI6M<?0P3o3cX?00393`80

o`l23`8I6Pl00`0?3`023`0401TI6M@?0P3o3cX?00383`80o`l33`8I6Pl0

1@0?3`l000<Ie0l20?l?>`l00<P?0P3o3`<?0QTI3`0500l?3`000aWD3`80

o`ll3`00b0l20?l?0`l00`0I6@0H3`0400l?3`<Ie@l20?l??0l00<L?0P3o

3`D?0QTH3`0400l?008Ie@l20?l??@l00<L?0P3o3`D?0QTG3`0400l?008I

ePl20?l??@l00<H?0P3o3`H?00<06AT05Pl0100?00026MD?0P3o3ch?0036

3`80o`l63`0301TI01D?00@03`l00QWE3`80o`lo3`00a@l20?l?20l26AD?

00<03`000aWE3`80o`lo3`00a@l20?l?20l26AD?00<03`000QWE3`80o`m0

3`00a@l20?l?20l00`0I6@0C3`0300l0008IePl20?l?@0l00<@?0P3o3`T?

00<06AT04`l00`0?00026MD?0P3o3d4?00343`80o`l:3`8I4`l2008IePl2

0?l?@@l00<<?0P3o3`/?0QTB3`800aWE3`80o`m23`00``l20?l?2`l00`0I

6@0A3`800QWE3`80o`m33`00`Pl20?l?30l00`0I6@0@3`0400lI6MH?0P3o

3d<?00323`80o`l<3`0301TI010?0P026MD?0P3o3d@?00323`80o`l<3`03

01TI010?00<06AT0ePl20?l?A0l00<4?0P3o3`h?0QT?3`0400lI6MD?0P3o

3dD?00313`80o`l>3`0301TI00h?0P026M@?0P3o3dH?00303`80o`l?3`03

01TI00d?0P026MD?0P3o3dH?00303`80o`l?3`0301TI00d?0P026M@?0P3o

3dL?002o3`80o`l@3`0301TI00d?00<06AT0e@l20?l?A`l00;l?0P3o3a0?

00<06AT030l0100?6AWD3`80o`m83`00_`l20?l?4@l00`0I6@0;3`0301TI

0=@?0P3o3dT?002n3`80o`lB3`0301TI00/?00<06AT0e0l20?l?B@l00;h?

0P3o3a8?00<06AT02Pl00`0I6@3D3`80o`m:3`00_@l20?l?4`l00`0I6@0:

3`0301TI0=@?0P3o3dX?002m3`80o`lC3`0301TI00T?00@03aTId`l20?l?

B`l00;`?0P3o3a@?00<06AT02@l00`0I6@3C3`80o`m<3`00_0l20?l?5@l0

0`0I6@083`0301TI0=<?0P3o3d`?002l3`80o`lE3`0301TI00L?00<06AT0

d`l20?l?C@l00;/?0P3o3aH?00<06AT01`l00`0I6@3C3`80o`m=3`00^`l2

0?l?5Pl00`0I6@073`0301TI0=8?0P3o3dh?002j3`80o`lG3`0301TI00H?

00<06AT0dPl20?l?C`l00;X?0P3o3aL?00<06AT01Pl00`0I6@3B3`80o`m?

3`00^@l20?l?60l2008I0`l2008IdPl20?l?D0l00;T?0P3o3aT?00<06AT0

0Pl3008IdPl20?l?D0l00;T?0P3o3aT?00<06AT00Pl3008Id@l20?l?D@l0

0;P?0P3o3aX?00@06AT?0`026M4?0P3o3e8?002h3`80o`lJ3`0401TI3`<0

0QWA3`80o`mB3`00]`l20?l?6`l0100I6@l2008Id@l20?l?D`l00;L?0P3o

3a/?0P026@800QU>3`80P@l20?l?D`l00;H?0P3o3a`?0P026@800QU=3`80

00<?00l0OPl20?l?E0l00;H?0P3o3a`?0P026@0301TI04h?200;3`@0J`l2

0?l?E@l00;H?0P3o3ad?00@06AT00QU>3`X000<?00l01@l2008?0P1Z3`80

o`mE3`00]@l20?l?7Pl00`0I6@026B@0:Pl=00D?0P043`80J0l20?l?EPl0

0;D?0P3o3ah?00@06AT09@lZ00033`0000@02`l206h?0P3o3eH?002d3`80

o`lO3`<0D@l400d?0P1]3`80o`mG3`00]0l20?l?7`l3054?0`0>3`80K0l2

0?l?F0l00;<?0P3o3b8?00<03`l0C`l200l?0P043`80IPl20?l?F0l00;<?

0P3o3b8?00<03`l0H@l2008?0P1V3`80o`mI3`00/`l20?l?8Pl00`0?3`1R

3`@0I`l20?l?F@l00;8?0P3o3b<?00<03`l0c0l20?l?FPl00;8?0P3o3b<?

00<03`l0b`l20?l?F`l00;4?0P3o3b@?00<03`l0b`l20?l?F`l00;4?0P3o

3b@?00<03`l0bPl20?l?G0l00;0?0P3o3bD?00<03`l0bPl20?l?G0l00;0?

0P3o3bD?00<03`l0b@l20?l?G@l00;0?0P3o3bD?00<03`l0b0l20?l?GPl0

0:l?0P3o3bH?00<03`l0b0l20?l?GPl00:l?0P3o3bH?00<03`l0a`l20?l?

G`l00:h?0P3o3bL?00<03`l0a`l20?l?G`l00:h?0P3o3bL?00<03`l0aPl2

0?l?H0l00:d?0P3o3bP?00<03`l0a@l20?l?H@l00:d?0P3o3bP?00<03`l0

a@l20?l?H@l00:d?0P3o3bL?00<03`l0a@l20?l?HPl00:`?0P3o3bP?00<0

3`l0a@l20?l?HPl00:`?0P3o3bP?00<03`l0a0l20?l?H`l00:/?0P3o3bT?

00<03`l0``l20?l?I0l00:/?0P3o3bT?00<03`l0``l20?l?I0l00:X?0P3o

3bX?00<03`l0`Pl20?l?I@l00:X?0P3o3bX?00<03`l0`Pl20?l?I@l00:X?

0P3o3bX?00<03`l0`@l20?l?IPl00:T?0P3o3b/?00<03`l0`0l20?l?I`l0

0:T?0P3o3b/?00<03`l0`0l20?l?I`l00:P?0P3o3b`?00<03`l0_`l20?l?

J0l00:P?0P3o3b`?00<03`l0_`l20?l?J0l00:L?0P3o3bd?00<03`l0_Pl2

0?l?J@l00:L?O@2a3`0300l?0;d?0P3o3fX?002V3oT0=Pl00`0?3`023b<0

V0l20?l?JPl00:H?0P1l3jl00Pl0100?3`m707@?0P3o3f/?003o3j0?=002

3`0400l?3kd0o`m[3`00o`oF3`0300l?02@?VP3o3f/?003o3mH?00<03`l0

APl00`0?3`1a3`@0o`m[3`00o`oF3`0300l?0;X?0`3o3f`?003o3mH?00<0

3`l0o`oo3bX?003o3mH?00<03`l0o`oo3bX?003o3mH?00<03`l0o`oo3bX?

003o3mH?00<03`l0o`oo3bX?003o3mH?00<03`l0o`oo3bX?003o3mH?00<0

3`l0o`oo3bX?003o3mH?00<03`l0o`oo3bX?003o3mH?00<03`l0o`oo3bX?

003o3mH?00<03`l0o`oo3bX?003o3mH?00<03`l0o`oo3bX?003o3mH?00<0

3`l0o`oo3bX?003o3mH?103o3ol?:@l00?l?d@l;0?l?o`lW3`00o`oB3`X0

o`oo3bL?003o3m8?0P000`l000040?l?o`lX3`00o`oC3`L0o`oo3bT?003o

3mD?1@3o3ol?:@l00?l?e0l50?l?o`lZ3`00o`oE3`80o`oo3b`?003o3ol?

o`oo3`@?003o3ol?o`oo3`@?003o3ol?o`oo3`@?003o3ol?o`oo3`@?003o

3ol?o`oo3`@?003o3ol?o`oo3`@?003o3ol?o`oo3`@?003o3ol?o`oo3`@?

003o3ol?o`oo3`@?003o3ol?o`oo3`@?003o3ol?o`oo3`@?003o3ol?o`oo

3`@?003o3m8?00<03`l0o`oo3bh?003o3m<?0P023`80o`oo3bX?003o3m<?

0P023`80o`oo3bX?003o3m@?103o3ol?:`l00?l?e@l20?l?o`l/3`00o`oD

3`@0o`oo3b/?003o3m<?0P023`80o`oo3bX?003o3m<?0P023`80o`oo3bX?

003o3m8?0P043`80o`oo3bT?003o3ol?o`oo3`@?003o3ol?o`oo3`@?003o

3ol?o`oo3`@?003o3ol?30l7024?2@093`<00`l301L?0`033`<04@l7024?

1`3o3e@?003o3ol?30l7024?2@093`<00`l301L?0`033`<04@l7024?1`3o

3e@?003o3ol?2Pl300D?0`0=3`<03@l300D?0`093`<00`l301L?0`033`<0

3`l300D?0`0M3`<01@l30?l?DPl00?l?o`l:3`<01@l300d?0`0=3`<01@l3

00T?0`033`<05`l300<?0`0?3`<01@l301d?0`053`<0o`mB3`00o`oo3`X?

0`0E3`<03@l300D?0`0;3`D06`l501T?0`093`/02@l300D?0`3o3e8?003o

3ol?2Pl301D?0`0=3`<01@l300/?1@0K3`D06@l300T?2`093`<01@l30?l?

DPl00?l?o`l:3`<04@l;00T?0`053`<02`l500/?1@0;3`D06@l301d?0`05

3`<0o`mB3`00o`oo3`X?0`0A3`/02@l300D?0`0;3`D02`l500/?1@0I3`<0

7@l300D?0`3o3e8?003o3ol?2Pl300D?0`0=3`<03@l300D?0`093`<00`l3

01L?0`033`<04`l500/?2`093`<01@l30?l?DPl00?l?o`l:3`<01@l300d?

0`0=3`<01@l300T?0`033`<05`l300<?0`0C3`D02`l;00T?0`053`<0o`mB

3`00o`oo3``?1`0?3`<03`l900T?0`033`<05`l300<?0`0G3`<07@l300D?

0`3o3e8?003o3ol?30l700l?0`0?3`T02@l300<?0`0G3`<00`l301L?0`0M

3`<01@l30?l?DPl00?l?o`lj3`<0B@l301d?0`053`<0o`mB3`00o`oo3cX?

0`193`<07@l300D?0`3o3e8?003o3ol?>Pl303@?0`053`<00Pl300D?0`0M

3`<01@l30?l?DPl00?l?o`lj3`<0=0l300D?0`023`<01@l301d?0`053`<0

o`mB3`00o`oo3cX?0`0f3`<000@?00001Pl7024?1`3o3e@?003o3ol?>Pl3

03H?0`0010l000063`L08@l70?l?E0l00?l?o`me3`<0o`n;3`00o`oo3gD?

0`3o3h/?003o3ol?o`oo3`@?003o3ol?o`oo3`@?003o3ol?o`oo3`@?003o

3ol?o`oo3`@?003o3ol?o`oo3`@?003o3ol?o`oo3`@?003o3ol?o`oo3`@?

003o3ol?o`oo3`@?003o3ol?o`lA3`0300l?0>l?003o3ol?o`l83``0k`l0

0?l?o`ol3aL0k`l00?l?o`oc3aD01`l20?4?003o3ol?j@lD018?0P3a3`00

o`oo3n4?4`0J3`80lPl00?l?o`oI3a4090l20?8?003o3ol?dPl@02/?0P3c

3`00o`oo3l/?3`0c3`80l`l00?l?o`o53`h0>@l20?@?003o3ol?`0l<040?

0P3d3`00o`oo3k/?2`163`80m0l00?l?o`ng3`X0BPl20?D?003o3ol?/Pl:

04l?0P3e3`00o`oo3jh?2P1B3`80mPl00?l?_Pl20>X?201G3`80mPl00?l?

_@l70>8?201J3`80m`l00?l?XPl`0=4?201M3`80m`l00?l?U`m<0;d?1`1Q

3`80m`l00?l?S`lD020?20063a@0^0l706<?0P3h3`00o`n93`l0<@l00`0?

3`0D3`P0/`l606H?0P3h3`00o`n23`h0E0l80:`?1P1X3`80n@l00?l?O@l=

05d?202W3`H0JPl20?T?003o3gP?2`1X3`L0XPl506d?0P3i3`00o`mc3`/0

L0l709d?1@1^3`80nPl00?l?KPl;07P?1@2J3`D0L0l20?X?003o3fX?2P20

3`<0U`l5074?0P3k3`00o`mU3`X0QPl309@?1@1c3`80n`l00?l?H@l:08/?

0`2A3`D0M0l20?`?003o3ed?2@2A3`<0SPl507H?0P3l3`00o`mH3`X0UPl2

08`?1@1h3`80o0l00?l?E0l:09/?0P293`D0N@l20?d?003o3e0?2@2P3`80

Q`l507/?0P3m3`00o`m<3`T0Y0l208H?101l3`80oPl00?l?A`l:0:T?0P23

3`@0OPl20?h?003o3d<?2P2]3`80P@l507h?0P3o3`00o`lo3`T0/Pl2080?

10203`80o`l00?l?>`l90;D?0`1n3`@0PPl20?l?003o3cL?2@2i3`<0O@l4

088?0P3o3`4?003o3c<?2@2m3`80O0l408@?0P3o3`4?003o3bl?2@313`80

N`l408@?0P3o3`8?003o3b/?2@353`80N@l408H?0P3o3`8?003o3bL?2@39

3`80M`l508L?0P3o3`8?003o3b<?2@3=3`80MPl408P?0P3o3`<?003o3al?

2@3@3`80M@l408X?0P3o3`<?003o3a/?2@3D3`80M0l408X?0P3o3`@?003o

3aL?2@3H3`80L`l308`?0P3o3`@?003o3a<?2@3K3`80LPl408`?0P3o3`D?

003o3`l?2@3O3`80L@l408d?0P3o3`D?003o3`/?2@3S3`80K`l408l?0P3o

3`D?003o3`L?2@3V3`80K`l408l?0P3o3`H?003o3`<?2@3Z3`80K@l4094?

0P3o3`H?003n3`T0k@l306`?102A3`80o`l73`00nPl90?0?0`1/3`<0T`l2

0?l?1`l00?H?2@3c3`<0J`l409<?0P3o3`P?003b3`T0mPl406X?102D3`80

o`l83`00kPl90?T?101Z3`<0UPl20?l?20l00>X?2@3l3`<0JPl409H?0P3o

3`T?003V3`T0o`l406T?102G3`80o`l93`00hPl90?l?0`l406P?102H3`80

o`l:3`00gPl90?l?1Pl200033`0006L?102I3`80o`l:3`00d`l200D?2@3o

3`T?00<03`l00P1W3`<0V`l20?l?2Pl00=<?0P000`l000070?l?30l2008?

0P1U3`@0V`l20?l?2`l00=8?2@3o3`l?0P023`80I@l409`?0P3o3`/?003B

3`D0o`lA3`@00Pl206@?0`2M3`80o`l<3`00dPl20?l?4`l4008?0P1S3`@0

WPl20?l?30l00=4?0P3o3a8?10043`80HPl409h?0P3o3`d?003A3`80o`lA

3`@010l2064?102P3`80o`l=3`00d0l20?l?40l400H?0P1P3`@0X@l20?l?

3@l00=0?0P3o3`h?1@063`80H0l30:8?0P3o3`h?003@3`80o`l<3`D020l2

05h?102S3`80o`l>3`00c`l20?l?2Pl600T?0P1N3`@0X`l20?l?3`l00<l?

0P3o3`P?1P0;3`80G@l30:D?0P3o3`l?003>3`80o`l63`H03@l205`?102U

3`80o`l@3`00cPl20?l?0`l700h?0P1L3`@0YPl20?l?40l00<d?0P3o3`8?

1P0A3`80FPl40:P?0P3o3a0?003=3`80oPl601<?0P1J3`@0Z0l20?l?4@l0

0<d?0P3k3`L05@l205P?102Z3`80o`lA3`00c0l20?P?200G3`80F0l40:X?

0P3o3a8?003<3`80m@l801X?0P1G3`<0[0l20?l?4Pl00</?0P3c3`L07@l2

05H?102]3`80o`lB3`00b`l20?0?1`0P3`80E@l40:d?0P3o3a<?003;3`80

k@l7028?0P1E3`<0[`l20?l?4`l00<X?0P3[3`L09@l205<?102_3`80o`lD

3`00bPl20>L?200W3`80D`l40;0?0P3o3a@?00393`80i@l802X?0P1B3`<0

/@l20?l?5@l00<T?0P3R3`L0;@l2054?102b3`80o`lE3`00b0l20>4?1P0`

3`80D0l40;<?0P3o3aD?00383`80gPl6038?0P1@3`<0]0l20?l?5Pl00<P?

0P3L3`H0=0l204h?102e3`80o`lF3`00a`l20=/?1@0f3`80CPl40;D?0P3o

3aL?00373`80f0l603L?0P1>3`<0]`l20?l?5`l00<H?0P3G3`H0>@l204`?

102g3`80o`lH3`00aPl20=D?1@0k3`80C0l40;P?0P3o3aP?00363`80dPl6

03d?0P1:3`@0^Pl20?l?60l00<D?0P3A3`H0?Pl204X?102j3`80o`lI3`00

a@l20<l?1@113`80B@l30;`?0P3o3aT?00343`80cPl5048?0P183`@0_0l2

0?l?6Pl00<@?0P3<3`D0A0l204L?102m3`80o`lJ3`00``l20<`?10153`80

A`l30;l?0P3o3aX?00333`80bPl404L?0P153`@0_`l20?l?6`l00<<?0P38

3`D0A`l204D?10303`80o`lK3`00`Pl20<P?10193`80A0l30<4?0P3o3a`?

00323`80a`l304X?0P133`@0`Pl20?l?70l00<4?0P373`<0B`l2048?1032

3`80o`lM3`00`@l20<H?0`1;3`80@Pl30<@?0P3o3ad?00313`80a@l304`?

0P103`@0a@l20?l?7@l00<0?0P353`<0C0l2040?10353`80o`lN3`00`0l2

0<@?0`1<3`80?`l40<L?0P3o3ah?002o3`80a@l204d?0P0n3`@0a`l20?l?

7`l00;l?0P343`80C@l203h?0`393`80o`lO3`00_Pl20<@?0`1=3`80?0l4

0<T?0P3o3b0?002n3`80a0l204d?0P0l3`@0bPl20?l?80l00;h?0P333`80

CPl203X?103<3`80o`lP3`00_@l20<@?0P1=3`80>Pl40<`?0P3o3b4?002m

3`80``l204h?0P0i3`<0cPl20?l?8@l00;`?0P343`80C@l203P?103>3`80

o`lR3`00_0l20<<?0P1>3`80=`l40<l?0P3o3b8?002l3`80``l204d?0P0f

3`@0d@l20?l?8Pl00;/?0P333`80CPl203D?103A3`80o`lS3`00^`l20<<?

0P1=3`80=@l30=<?0P3o3b<?002j3`80``l204h?0P0c3`@0d`l20?l?90l0

0;X?0P333`80C@l203<?103D3`80o`lT3`00^@l20<<?0P1>3`80<@l40=D?

0P3o3bD?002i3`80``l204d?0P0a3`@0ePl20?l?9@l00;T?0P323`80C@l2

030?103H3`80o`lU3`00^0l20<8?0P1>3`80;`l40=P?0P3o3bH?002h3`80

`Pl204d?0P0_3`<0fPl20?l?9Pl00;L?0P333`80C@l202d?103J3`80o`lW

3`00]`l20<<?0P1<3`80;@l40=/?0P3o3bL?002g3`80``l204`?0P0[3`@0

g0l20?l?:0l00;H?0P343`80B`l202/?103M3`80o`lX3`00]Pl20<@?0P1;

3`80:@l40=l?0P3o3bP?002e3`80a@l204X?0P0Y3`@0g`l20?l?:@l00;D?

0P353`80BPl202L?103Q3`80o`lY3`00]0l20<L?0P183`809Pl50>4?0P3o

3bX?002d3`80a`l204P?0P0U3`@0h`l20?l?:Pl00;@?0P373`80A`l202@?

103U3`80o`lZ3`00/`l20<T?0P163`808Pl50>D?0P3o3b/?002c3`80b@l2

04D?0P0R3`@0i`l20?l?:`l00;8?0P3:3`80A@l2020?103X3`80o`l/3`00

/Pl20</?0P133`807`l50>T?0P3o3b`?002b3`80b`l2048?0P0O3`@0jPl2

0?l?;@l00;4?0P3=3`80@@l201d?103/3`80o`l]3`00/@l20<d?0`0o3`80

70l50>d?0P3o3bd?002`3`80c`l203l?0P0J3`D0kPl20?l?;Pl00;0?0P3@

3`80?@l201T?1@3`3`80o`l^3`00[`l20=4?0P0m3`805`l50?4?0P3o3bl?

002_3`80dPl203/?0P0F3`D0l`l20?l?;`l00:l?0P3B3`80>`l201<?1P3d

3`80o`l`3`00[Pl20=@?0P0i3`804Pl60?H?0P3o3c0?002^3`80e0l203T?

0P0@3`L0m`l20?l?<0l00:d?0P3F3`<0=Pl200d?1`3j3`80o`la3`00[@l2

0=L?0`0e3`802`l70?`?0P3o3c4?002]3`80e`l5038?0P083`L0o`l20?l?

<Pl00:`?0P3J3`D0<0l200D?1`3o3`<?0P3o3c8?002/3`80f`l702`?0P04

3`H0o`l63`80o`lb3`00Z`l20=d?200Z3`8000<?0000103o3`P?0P3o3c<?

002[3`80gPl902L?203o3`X?0P3o3c<?002Z3`80h0l400033`0000<08`l7

0?l?30l20?l?=0l00:X?0P3R3`<00Pl601d?1`3o3`l?0P3o3c@?002Z3`80

h`l300<?1`0F3`P0o`lA3`80o`le3`00Z@l20>D?0`053`P03Pl90?l?50l2

0?l?=@l00:T?0P3V3`<01`lH0?l?60l20?l?=@l00:P?0P3X3`<02Pl@0?l?

6`l20?l?=Pl00:P?0P3Y3`<040l00`0?3`3o3b4?0P3o3cH?002X3`80jPl3

0?l?<Pl20?l?=`l00:L?0P3/3`<0o`la3`80o`lg3`00Y`l20>d?0`3o3bl?

0P3o3cP?002V3`80k`l30?l?;Pl20?l?>0l00:H?0P3`3`<0o`l]3`80o`lh

3`00Y@l20?8?0`3o3b/?0P3o3cT?002U3`80l`l30?l?:Pl20?l?>@l00:D?

0P3d3`<0o`lX3`80o`lj3`00Y0l20?H?0`3o3bL?0P3o3cX?002T3`80m`l3

0?l?9Pl20?l?>Pl00:<?0P3i3`<0o`lT3`80o`lk3`00X`l20?X?0`3o3b<?

0P3o3c/?002S3`80n`l30?l?8@l20?l??0l00:8?0P3m3`<0o`lP3`80o`ll

3`00XPl20?h?0`3o3ah?0P3o3cd?002Q3`80o`l13`<0o`lM3`80o`lm3`00

X@l20?l?0Pl20?l?7@l20?l??@l00:0?0P3o3`@?0P3o3a/?0P3o3ch?002P

3`80o`l43`<0o`lJ3`80o`ln3`00X0l20?l?1@l30?l?60l20?l??`l009l?

0P3o3`L?0`3o3aL?0P3o3cl?002O3`80o`l83`80o`lF3`80o`m03`00WPl2

0?l?2Pl20?l?5@l20?l?@0l009h?0P3o3`X?0P3o3aD?0P3o3d0?002N3`80

o`l;3`80o`lC3`80o`m13`00W@l20?l?30l20?l?4`l20?l?@@l009d?0P3o

3``?0P3o3a8?0P3o3d8?002L3`80o`l>3`80o`lA3`80o`m23`00W0l20?l?

3Pl20?l?4@l20?l?@Pl009/?0P3o3`l?0P3o3a0?0P3o3d<?002K3`80o`l@

3`80o`l?3`80o`m33`00V`l20?l?3`l20?l?3`l20?l?A0l009X?0P3o3a0?

0P3o3`l?0P3o3d@?002J3`80o`l@3`80o`l>3`80o`m53`00V@l20?l?4@l2

0?l?3Pl20?l?A@l009T?0P3o3a0?0P3o3`l?0P3o3dD?002I3`80o`l@3`80

o`l>3`80o`m63`00V0l20?l?40l20?l?3`l20?l?APl009P?0P3o3`l?0`3o

3`h?0P3o3dL?002G3`80o`l?3`<0o`l?3`80o`m73`00U`l20?l?3`l20?l?

3`l20?l?B0l009H?0P3o3`l?0P3o3a0?0P3o3dP?002F3`80o`l>3`<0o`l@

3`80o`m83`00UPl20?l?3@l30?l?40l20?l?B@l009D?0P3o3`d?0`3o3a4?

0P3o3dT?002E3`80o`l<3`<0o`lA3`80o`m:3`00U0l20?l?30l30?l?4Pl2

0?l?BPl009@?0P3o3`/?0`3o3a<?0P3o3dX?002D3`80o`l;3`80o`lC3`80

o`m;3`00T`l20?l?o`lQ3`80o`m;3`00T`l20?l?o`lP3`80o`m<3`00TPl2

0?l?o`lQ3`80o`m<3`00TPl20?l?o`lP3`80o`m=3`00T@m@0?l?dPl20?l?

C@l0094?W@3o3hD?0P3o3dd?003Q3i/0o`lf3`80o`m>3`00o`l_3i/0j0l2

0?l?CPl00?l?O@nK09T?0P3o3dl?003o3lX?V`1<3`80o`m?3`00o`oo3aT?

VP3o3e0?003o3ol?IPm>0?l?C`l00?l?o`nb3`80o`m?3`00o`oo3ol?o`l4

3`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?

o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo

3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00

o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l4

3`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?

o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo

3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00

o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l4

3`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?

o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo

3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00

o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l4

3`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?o`l43`00o`oo3ol?

o`l43`00o`oo3ol?o`l43`00\

\>"], "Graphics",

  ImageSize->{759, 569.25},

  ImageMargins->{{12, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}}]

}, Open  ]],



Cell[BoxData[{

    \(By\ cutting\ the\ surface\ defined\ by\ \((3.1)\)\ with\ planes\ 

      perpendicular\ to\ the\ \), 

    \(\((c, d)\) - plane, \ 

    we\ obtain\ curves\ which\ have\ the\ same\ characteristics\ as\), 

    \(th\ above\ bifurcation\ diagrams\ for\ thebuckling\ problem.\ \nWe\ do\ 

      this\ by\ letting\), 

    \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \

\ \ \ \ \ \ \ 

    d\  = \ m\ c\  + \ 

        \(1\/2\)\ .\nThis\ is\ a\ plane\ in\ \((x, c, d)\)\ space.\ We\ fix\ m

          \ \((the\ slope\ in\ the\ \((c, d)\) - plane)\)\ \), 

    \(and\ vary\ c\ which\ is\ analogous\ to\ fixing\ "\<k\>"\ and\ varying\ 

      "\<a\>"\ \ as\ was\ done\), 

    \(for\ the\ buckling\ problem.\ We\ do\ this\ with\ the\ following\ 

      \(commands.\)\ \t\t\t\)}], "Input",

  FontFamily->"Times New Roman",

  FontSize->16],



Cell["\<\



<<Graphics`ImplicitPlot`\

\>", "Input",

  PageWidth->Infinity,

  ShowSpecialCharacters->False,

  FormatType->InputForm],



Cell["\<\





cusp[c1_,m_] :=  Plot[{3/4^(1/3) (Abs[c])^(2/3),m c + .5},{c,-c1,c1},

               AspectRatio->Automatic, AxesLabel->{\"C\",\"d\"}, 

               PlotRange->{-1,3/4^(1/3) (c1)^(2/3)},

               PlotStyle->{{Hue[.6]},{Hue[1]}},DisplayFunction->Identity,

         PlotLabel->StringForm[\"d=``,           d=``\",3 (C/2)^(2/3), m \

C+.5]] 



cubic[c1_,m_]:=

                    ImplicitPlot[c+(m c +.5) x-x^3==0,{c,-c1,c1},

                      AspectRatio->Automatic, AxesLabel->{C,X},

                      PlotStyle->Hue[1],DisplayFunction->Identity,

    PlotLabel->StringForm[\"                               0=``\",C+(m \

C+.5)X-X^3]]\

\>", "Input",

  PageWidth->Infinity,

  ShowSpecialCharacters->False,

  FormatType->InputForm],



Cell[BoxData[

    \(\(\ncubicbifurcation[c1_, mmin_, mmax_, dm_] := \n

      Table[Show[GraphicsArray[{cusp[c1, m], cubic[c1, m]}]], {m, mmin, mmax, 

          dm}]\)\)], "Input"],



Cell[BoxData[

    \(\(\nUsing\ these\ commands\ we\ get\ the\ following\ \(diagrams.\)\)\)],

   "Input",

  FontFamily->"Times New Roman",

  FontSize->16],



Cell[CellGroupData[{



Cell[BoxData[

    \(cubicbifurcation[2, 1.65, 1.32, \(- .005\)]\)], "Input"],



Cell[CellGroupData[{



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -82 0 ]

[.5 .96488 82 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -143 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.65) show

217.250000 19.500000 moveto

(C) show

222.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.28355 0 m

.30316 .03235 L

.34309 .09823 L

.3815 .16162 L

.42237 .22905 L

.46172 .29398 L

.49955 .3564 L

.53984 .42288 L

.57861 .48685 L

.61984 .55487 L

.65954 .62039 L

.69774 .68341 L

.73838 .75047 L

.77751 .81504 L

.81909 .88365 L

.85916 .94976 L

s

.85916 .94976 m

.86075 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.402397 0.238095 [

[.02381 .3899 -6 -9 ]

[.02381 .3899 6 0 ]

[.2619 .3899 -6 -9 ]

[.2619 .3899 6 0 ]

[.7381 .3899 -3 -9 ]

[.7381 .3899 3 0 ]

[.97619 .3899 -3 -9 ]

[.97619 .3899 3 0 ]

[1.025 .4024 0 -8 ]

[1.025 .4024 9 8 ]

[.4875 .04525 -24 -4.5 ]

[.4875 .04525 0 4.5 ]

[.4875 .1643 -12 -4.5 ]

[.4875 .1643 0 4.5 ]

[.4875 .28335 -24 -4.5 ]

[.4875 .28335 0 4.5 ]

[.4875 .52144 -18 -4.5 ]

[.4875 .52144 0 4.5 ]

[.4875 .64049 -6 -4.5 ]

[.4875 .64049 0 4.5 ]

[.4875 .75954 -18 -4.5 ]

[.4875 .75954 0 4.5 ]

[.4875 .87859 -6 -4.5 ]

[.4875 .87859 0 4.5 ]

[.5 .96713 -4.5 0 ]

[.5 .96713 4.5 16 ]

[.5 .95463 -134.5 0 ]

[.5 .95463 134.5 16 ]

[ 0 0 0 0 ]

[ 1 .94213 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .4024 m

.02381 .40865 L

s

[(-2)] .02381 .3899 0 1 Mshowa

.2619 .4024 m

.2619 .40865 L

s

[(-1)] .2619 .3899 0 1 Mshowa

.7381 .4024 m

.7381 .40865 L

s

[(1)] .7381 .3899 0 1 Mshowa

.97619 .4024 m

.97619 .40865 L

s

[(2)] .97619 .3899 0 1 Mshowa

.125 Mabswid

.07143 .4024 m

.07143 .40615 L

s

.11905 .4024 m

.11905 .40615 L

s

.16667 .4024 m

.16667 .40615 L

s

.21429 .4024 m

.21429 .40615 L

s

.30952 .4024 m

.30952 .40615 L

s

.35714 .4024 m

.35714 .40615 L

s

.40476 .4024 m

.40476 .40615 L

s

.45238 .4024 m

.45238 .40615 L

s

.54762 .4024 m

.54762 .40615 L

s

.59524 .4024 m

.59524 .40615 L

s

.64286 .4024 m

.64286 .40615 L

s

.69048 .4024 m

.69048 .40615 L

s

.78571 .4024 m

.78571 .40615 L

s

.83333 .4024 m

.83333 .40615 L

s

.88095 .4024 m

.88095 .40615 L

s

.92857 .4024 m

.92857 .40615 L

s

.25 Mabswid

0 .4024 m

1 .4024 L

s

gsave

1.025 .4024 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .04525 m

.50625 .04525 L

s

[(-1.5)] .4875 .04525 1 0 Mshowa

.5 .1643 m

.50625 .1643 L

s

[(-1)] .4875 .1643 1 0 Mshowa

.5 .28335 m

.50625 .28335 L

s

[(-0.5)] .4875 .28335 1 0 Mshowa

.5 .52144 m

.50625 .52144 L

s

[(0.5)] .4875 .52144 1 0 Mshowa

.5 .64049 m

.50625 .64049 L

s

[(1)] .4875 .64049 1 0 Mshowa

.5 .75954 m

.50625 .75954 L

s

[(1.5)] .4875 .75954 1 0 Mshowa

.5 .87859 m

.50625 .87859 L

s

[(2)] .4875 .87859 1 0 Mshowa

.125 Mabswid

.5 .06906 m

.50375 .06906 L

s

.5 .09287 m

.50375 .09287 L

s

.5 .11668 m

.50375 .11668 L

s

.5 .14049 m

.50375 .14049 L

s

.5 .18811 m

.50375 .18811 L

s

.5 .21192 m

.50375 .21192 L

s

.5 .23573 m

.50375 .23573 L

s

.5 .25954 m

.50375 .25954 L

s

.5 .30716 m

.50375 .30716 L

s

.5 .33097 m

.50375 .33097 L

s

.5 .35478 m

.50375 .35478 L

s

.5 .37859 m

.50375 .37859 L

s

.5 .42621 m

.50375 .42621 L

s

.5 .45002 m

.50375 .45002 L

s

.5 .47383 m

.50375 .47383 L

s

.5 .49764 m

.50375 .49764 L

s

.5 .54525 m

.50375 .54525 L

s

.5 .56906 m

.50375 .56906 L

s

.5 .59287 m

.50375 .59287 L

s

.5 .61668 m

.50375 .61668 L

s

.5 .6643 m

.50375 .6643 L

s

.5 .68811 m

.50375 .68811 L

s

.5 .71192 m

.50375 .71192 L

s

.5 .73573 m

.50375 .73573 L

s

.5 .78335 m

.50375 .78335 L

s

.5 .80716 m

.50375 .80716 L

s

.5 .83097 m

.50375 .83097 L

s

.5 .85478 m

.50375 .85478 L

s

.5 .02144 m

.50375 .02144 L

s

.5 .9024 m

.50375 .9024 L

s

.5 .92621 m

.50375 .92621 L

s

.25 Mabswid

.5 0 m

.5 .94213 L

s

gsave

.5 .96713 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .95463 -195.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.65) show

293.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

298.000000 15.000000 moveto

(L) show

305.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

312.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

319.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

324.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

328.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .94213 L

0 .94213 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .25324 m

.02576 .25322 L

.03158 .25317 L

.04117 .25309 L

.05437 .25296 L

.07095 .2528 L

.09063 .2526 L

.11306 .25234 L

.13787 .25203 L

.16463 .25166 L

.19289 .25122 L

.22216 .25069 L

.25193 .25006 L

.28171 .24933 L

.31098 .24846 L

.33923 .24746 L

.366 .2463 L

.39081 .245 L

.41324 .24357 L

.43292 .24206 L

.44949 .24055 L

.46269 .23917 L

.47228 .23803 L

.47811 .23729 L

.48006 .23703 L

s

.48006 .23703 m

.48218 .23674 L

.48851 .23584 L

.49894 .23421 L

.51329 .23165 L

.53132 .22782 L

.55271 .2222 L

.57711 .21423 L

.60409 .20346 L

.63319 .18997 L

.66392 .17439 L

.69574 .15764 L

.72812 .14051 L

.7605 .12363 L

.79233 .10743 L

.82305 .09221 L

.85216 .07818 L

.87914 .06551 L

.90353 .05433 L

.92493 .04472 L

.94296 .03677 L

.95731 .03053 L

.96774 .02604 L

.97407 .02334 L

.97619 .02243 L

s

.48006 .48502 m

.48218 .45762 L

.48851 .43068 L

.49894 .40455 L

.51329 .3796 L

.53132 .35631 L

.55271 .33533 L

.57711 .31736 L

.60409 .30298 L

.63319 .29222 L

.66392 .28455 L

.69574 .27919 L

.72812 .27541 L

.7605 .2727 L

.79233 .27072 L

.82305 .26923 L

.85216 .26811 L

.87914 .26724 L

.90353 .26658 L

.92493 .26607 L

.94296 .26568 L

.95731 .2654 L

.96774 .26521 L

.97407 .2651 L

.97619 .26506 L

s

.48006 .48514 m

.48218 .51283 L

.48851 .54067 L

.49894 .56843 L

.51329 .59594 L

.53132 .62307 L

.55271 .64966 L

.57711 .6756 L

.60409 .70075 L

.63319 .725 L

.66392 .74824 L

.69574 .77037 L

.72812 .79127 L

.7605 .81086 L

.79233 .82905 L

.82305 .84575 L

.85216 .86091 L

.87914 .87444 L

.90353 .88629 L

.92493 .8964 L

.94296 .90474 L

.95731 .91127 L

.96774 .91594 L

.97407 .91876 L

.97619 .9197 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->1,

  AnimationCycleRepetitions->Infinity,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<00`0C4`1`4`00oa=B4`0301<C070C001T4`D0j1<00`0C4`1`4`00IQ<00`0C4`3X4`03

01<C070C00164`033A<C01LC0`034`0301<C008C0P3T4`80E1<33AXC00164`033A<C01dC00<04a<0

0Q<00`0C4`3S4`0301<C054C0PdM4`00Aa<00`dC4`0L4`0301<C008C00<04a<0dQ<5008C00<04a<0

0Q<00`0C4`024`0301<C04lC0PdO4`00Aa<00`dC4`0K4`8011<00`0C4`3D4`0301<C00HC00<04`00

0a<00`0C4`1=4`8=8A<004PC00<=4a<081<20<lC0`034`0301<C00PC00@04a<C0P1<4`8=8a<004PC

00<=4a<081<00`0C4`3D4`0301<C00HC0P044`0301<C04TC0PdU4`00BA<00`dC4`0O4`0301<C0=@C

00<04a<01Q<00`0C4`034`0301<C04LC0PdW4`00BQ<00`dC4`0N4`0301<C0=<C0P084`<00a<00`0C

4`154`8=:A<004XC00<=4a<07Q<20>@C0P134`<=:a<004/C00<=4a<07A<00`0C4`3S4`0301<C040C

0Pd^4`00C1<00`dC4`0L4`0301<C0><C00<04a<0?Q<23C0C001<4`033A<C01`C00<04a<0ha<00`0C

4`0l4`8=<Q<004dC00<=4a<06a<20>@C00<04a<0>Q<23C@C001=4`033A<C01/C00<04a<0ha<203TC

0Pdf4`00CQ<00`dC4`0J4`0301<C0><C00<04a<0=A<33CPC001?4`033A<C01TC00<04a<0ha<00`0C

4`0c4`8=>a<004lC00<=4a<06A<20>@C00<04a<0<A<23CdC001@4`033A<C01PC00<04a<0ha<2030C

0Pdo4`00DA<00`dC4`084`0301<C008C00<04a<00Q<00`0C4`024`0301<C0><C00<04a<0;A<23D4C

001A4`033A<C00LC00<04`001a<00`0C00034`0301<C0><C00<04a<0:a<23D<C001B4`043A<C4`<0

0Q<00`0C00094`0401<C4`80i1<00`0C4`0Y4`8=AA<005<C00<=4a<01A<00`0C00074`8011<00`0C

4`3S4`80:1<23DLC001C4`033A<C00DC00<04`001a<00`0C4`034`0301<C0><C00<04a<09A<23DTC

001D4`033A<C00DC00<04a<01Q<300<C00<04a<0ha<00`0C4`0T4`033A<C04TC001D4`033A<C01@C

00<04a<0g1<5008C00<04a<08Q<23D`C001E4`033A<C01<C0P3O4`0301<C008C00<04a<08A<00`dC

4`1<4`00EQ<00`dC4`0B4`0301<C0=PC0`034`0301<C008C0P0P4`8=Ca<005HC00<=4a<04Q<00`0C

4`3N4`0301<C008C00<04a<07A<23E4C001G4`033A<C014C00<04a<0gQ<00`0C4`024`0301<C01/C

0PeC4`00F1<00`dC4`0@4`80gQ<200@C00<04a<06A<23EDC001H4`033A<C010C00<04a<0ha<201PC

0PeG4`006Q<302DC1@0B4`033A<C00lC00<04a<091<502@C0`2C4`0301<C01DC0PeI4`006Q<00`0C

4`0W4`0301<C01<C00<=4a<03Q<00`0C4`0V4`0301<C02@C00<04a<0Ta<00`0C4`0B4`<=Fa<001DC

0`034`0301<C020C0`034`0301<C01<C00<=4a<03Q<202LC00<04a<09A<00`0C4`2B4`0301<C00lC

0`eN4`006a<00`0C4`0V4`0301<C01@C00<=4a<03A<00`0C4`0V4`0301<C02DC00<04a<0TQ<00`0C

4`0=4`8=HA<001XC00<04`009a<00`0C4`0D4`033A<C00dC00<04a<09Q<00`0C4`0T4`0301<009<C

0P0;4`<=Ha<001/C00<04a<09A<201LC00<=4a<031<00`0C4`0U4`809a<00`0C4`2B4`0301<C00LC

0`eV4`00GA<00`dC4`0;4`80i1<00`0C4`054`8=JA<005dC00<=4a<02a<00`0C4`3S4`0301<=00D=

Ja<005hC00<=4a<02Q<00`0C4`1K4`80PA<73G4C001O4`033A<C00TC00<04a<0FQ<00`0C4`1e4``=

1A<00`0C4`1`4`005A=:00033@0006001Q<00`0C4`1L4aT=4A<00`0C4`1`4`006A<00`0C4`064`03

01<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<0

0Q<010dC4`074`0341<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`03

01<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<021<00`0C4`0^4bh=:Q<00`0C4`1`4`00

H1<00`dC4`084`0341<C05XC00<04`00QQ<2074C001Q4`033A<C00LC0Q1K4`<0QQ<00`0C4`1>4`P=

6Q<0064C00<=4a<01a<24>@C00<04a<0<A<M3B8C001R4`033A<C00DC00<@0100eA<00`0C4`024`03

01<C008C00<04a<00Q<00`0C4`0U4``=?a<006<C00<=4a<011<00a00403D4`0301<000LC00<04`00

0a<00`0C4`0O4`H=Ba<006<C00<=4a<011<00a00403?4`<00Q<00`0C00094`0401<C4`806Q<63E4C

001T4`033A<C008C00D@4`00403C4`0301<000LC0P044`0301<C01DC10eG4`00I1<00`dC4`024`05

41<04a00da<00`0C00074`0301<C00<C00<04a<04Q<33E/C001U4`093A<C4a0C01<@0=@C00<04a<0

1Q<300<C00<04a<041<23EhC001V4`063A<C41<00Q<00a0C4`3P4`803a<23F0C001V4`053A<C41<0

0P000a<@4`3Q4`0301<C00`C0PeR4`00Ia<01@dC41<0008C00<@4a<0h1<00`0C4`0;4`033A<C068C

001W4`053A0C4`000a<00a0C4`3O4`0301<C00XC00<=4a<0Ha<006PC00@=4a<00a<00a0C4`3O4`03

01<C00PC0PeV4`00J1<00a0=4`02008C00<@4a<0ga<200PC00<=4a<0IQ<006LC00D@4`dC00044`03

41<C0=hC00<04a<01Q<00`dC4`1W4`00G1<00`0C4`024`0301<C008C00H041<C3@044`0341<C08LC

0`0X4`D09a<00`0C4`054`033A<C01hC1@0X4`<06Q<005/C00<04`001a<00`0@00024`033@0C00<C

00<@4a<0Qa<00`0C4`0Z4`0301<C02LC00<04a<011<00`dC4`0Q4`0301<C02PC00<04a<06Q<005/C

00<04`0021<00a004`024`033@0C00<C00<@4a<0PA<300<C00<04a<08a<300<C00<04a<09a<200@C

00<=4a<08Q<00`0C4`0Y4`0301<C01TC001K4`0301<000LC00<041<00a<00`0=4`034`0341<C08LC

00<04a<0:A<00`0C4`0W4`0301<C008C00<=4a<08a<00`0C4`0Y4`0301<C01TC001K4`0301<000LC

00<@4a<00a<00`0=4`044`0341<C08DC00<04`00:Q<00`0C4`0W4`0501<C4`d09Q<00`0C4`0X4`03

01<001XC001L4`0301<C00HC00<@00000a<00`0C3@044`0341<C08HC00<04a<0:1<202TC00D04a<C

3@0U4`80:a<00`0C4`0I4`00I1<00a0C4`044`8000<=4a<00Q<00a0C4`3L4`8000<C3A<0KQ<006@C

00<@4a<011<0100C4`d44`0341<C0=/C00<04`d0L1<006<C00<@4a<01A<0100C4`d44`0341<C0=/C

00<04`d0L1<006<C00<@4a<01A<01@0C4a<=00@C00<@4a<0fQ<00`0=4`1R4`8031<0068C00<@4a<0

1Q<00`0C4`024`053A<C4a00g1<00`0=4`1Q4`0301<C00`C001R4`0341<C00HC0P034`033A<C008C

00<@4a<0OA=L00033@0005X01a<00`0C4`0<4`00HA<00a0C4`074`0301<C00<C00D=4a<C40234`03

01<C02TC00<04a<0:A<00`dC4`0Y4`0301<C02TC00<04a<02A<00`0C4`0<4`00HA<00a0C4`074`03

01<C00<C00D=4a<C403J4`033@0C068C00<04`0031<0060C00<@4a<021<00`0C4`044`053A<C4a00

fA<00`d04`1R4`<031<0060C00<@4a<021<200HC00@=4a<@f1<010dC001a4`00Ga<00a0C4`094`03

01<C00DC00D=4a<C403G4`033A<0078C001O4`0341<C00TC00<04a<01Q<010dC4a3G4`033A<0078C

001N4`0341<C00XC00<04a<01a<010dC4a3F4`033A<0078C001N4`0341<C00XC0P084`043A<C4=DC

00<=4a<00P1a4`00GA<00a0C4`0;4`0301<C00PC00@=4a<@e1<010dC4`1b4`00GA<00a0C4`044`D0

0Q<00`0C4`084`043A<C4=@C00@=4a<0LQ<005`C00<@4a<01a<00`0C4`024`0301<C00TC00@=4a<@

da<010dC4`1b4`00Fa<00a0C4`084`0301<C008C0P0;4`043A<C4=8C00@=4a<0LQ<005/C00<@4a<0

21<00`0C4`024`0301<C00XC00@=4a<@dA<010dC4a<2074C001J4`0341<C00TC00<04a<00Q<00`0C

4`0;4`043A<C4=0C00D=4a<C001b4`00FQ<00a0C4`084`8011<00`0C4`0<4`043A<C4<lC00D=4a<C

001b4`00FA<00a0C4`0?4`803A<010dC4a3?4`053A<C4`00LQ<005PC00<@4a<041<00`0C4`0=4`04

3A<C4<hC00@=4a<C0P1a4`00F1<00a0C4`0@4`0301<C00hC00@=4a<@cQ<010dC4`1b4`00Ea<00a0C

4`0A4`0301<C00hC00@=4a<@cQ<010dC4`1b4`00EQ<00a0C4`0B4`8041<010dC4a314`0301<C008C

00<04a<00Q<00`0C3@024`0301<C070C001F4`0341<C018C00<04a<03a<01@dC4a<@0;lC00<04`00

1a<0100C00d24`0301<C070C001E4`0341<C01<C00<04a<041<010dC4a2o4`0301<000TC00@03A<C

0P1a4`00E1<00a0C4`0D4`0301<C014C00@=4a<@_Q<00`0C00074`800Q<00`dC001b4`00Da<00a0C

4`0E4`804Q<010dC4a2n4`0301<000LC00L04a<C3A<0078C001C4`0341<C01DC00<04a<04Q<010dC

4a2n4`0301<C00HC0`0011<=4`1b4`00DQ<00a0C4`0F4`0301<C01<C00@=4a<@bQ<010dC001a4`00

DA<00a0C4`0G4`0301<C01<C00@=4a<@ba<00`d04`1a4`00DA<00a0C4`0G4`805A<010dC4a3:4`03

3@0C074C001@4`0341<C01PC00<04a<051<010dC4a3;4`033A<C070C001?4`0341<C00PC1@024`03

01<C008C00<04a<00Q<00`0C4`0E4`043A<C4<XC00<=01<0L1<004lC00<@4a<02Q<00`0C4`064`03

01<000<C00<04a<05A<01@dC4a<@0<TC00<03A<0L1<004hC00<@4a<02a<00`0C4`084`0401<C4`80

5a<01@dC4a<@0<PC00<03A<0L1<004dC00<@4a<031<00`0C4`064`8011<00`0C4`0G4`043A<C4<PC

00<04`d0L1<004`C00<@4a<03A<00`0C4`064`0301<C00<C00<04a<05a<01@dC4a<@0<LC00<04`d0

L1<004`C00<@4a<031<200PC0`034`0301<C01PC00D=4a<C40364`8000<C3A<0KQ<004/C00<@4a<0

7A<201TC00<=4a<00Q<00a0C4`334`0501<C4`d0KQ<004XC00<@4a<07Q<00`0C4`0I4`053A<C4a00

aA<01@0C4a<=06hC001:4`0341<C01hC00<04a<06Q<01@dC4a<@0<@C00<04a<00Q<00`dC4`1[4`00

BA<00a0C4`0O4`0301<C01XC00<=4a<00Q<00a0C4`314`800a<00`dC4`1[4`00B1<00a0C4`0P4`80

71<00`dC4`024`0341<C0<0C00<04a<00a<00`dC4`1Z4`00Aa<00a0C4`0Q4`0301<C01/C00<=4a<0

0a<00a0C4`2o4`0301<C00@C00<=4a<0JA<004LC00<@4a<08A<00`0C4`0L4`033A<C008C00<@4a<0

^1<5008C00<04a<01A<00`dC4`1X4`00AQ<00a0C4`0R4`0301<C01dC00<=4a<00Q<00a0C4`2i4`03

01<C008C00<04a<01A<00`dC4`1X4`00AA<00a0C4`0S4`807Q<00`dC4`034`0341<C0;PC00<04a<0

0Q<200LC00<=4a<0Ia<004@C00<@4a<091<00`0C4`0N4`033A<C00<C00<@4a<0]a<00`0C4`024`03

01<C00LC00<=4a<0IQ<004@C00<@4a<091<00`0C4`0N4`033A<C00<C00<@4a<0]a<00`0C4`024`03

01<C00PC00<=4a<0IA<004<C00<@4a<09A<00`0C4`0O4`033A<C00<C00<@4a<0]A<200@C00<04a<0

2A<00`dC4`1T4`00@Q<00a0C4`0V4`0301<C020C00<=4a<00a<00a0C4`2j4`802Q<00`dC4`1T4`00

@A<00a0C4`0W4`808A<00`dC4`044`0341<C0;TC00<04a<02Q<00`dC4`1S4`00@1<00a0C4`0X4`03

01<C024C00<=4a<011<00a0C4`2h4`0301<C00/C00<=4a<0HQ<0040C00<@4a<08Q<300<C00<04a<0

8A<00`dC4`054`0341<C0;LC00<04a<031<00`dC4`1Q4`00?a<00a0C4`0S4`0301<C00<C00<04a<0

8Q<00`dC4`044`0341<C0;LC0P0>4`033A<C060C000n4`0341<C02DC00<04a<00Q<202<C00<=4a<0

1A<00a0C4`2f4`0301<C00hC00<=4a<0Ga<003dC00<@4a<09Q<00`0C4`024`0301<C02<C00<=4a<0

1A<00a0C4`2e4`0301<C00lC00<=4a<0GQ<003dC00<@4a<09A<00`0C00034`0301<C02@C00<=4a<0

1A<00a0C4`2d4`0301<C010C00<=4a<0GA<003`C00<@4a<09a<00`0C4`024`0301<C02@C00<=4a<0

1Q<00a0C4`2c4`0301<C014C0PeM4`00>a<00a0C4`0]4`809Q<00`dC4`064`0341<C0;8C0P0D4`03

3A<C05XC000j4`0341<C02hC00<04a<09A<00`dC4`064`0341<C0;8C00<04a<051<23EXC000j4`03

41<C02hC00<04a<09Q<00`dC4`064`0341<C0;4C00<04a<05Q<00`dC4`1G4`00>A<00a0C4`0_4`03

01<C02LC00<=4a<01Q<00a0C4`2`4`0301<C01LC00<=4a<0EQ<003PC00<@4a<0<1<202PC00<=4a<0

1a<00a0C4`2_4`806A<23EHC000g4`0341<C034C00<04a<0:1<00`dC4`064`0341<C0:lC00<04a<0

6Q<00`dC4`1C4`00=a<00a0C4`0a4`0301<C02TC00<=4a<01Q<00a0C4`2M4`D00Q<00`0C4`024`03

01<C008C00<04a<06a<00`dC4`1B4`00=Q<00a0C4`0b4`0301<C02TC00<=4a<01a<00a0C4`2N4`03

01<C00HC00<04`000a<00`0C4`0L4`8=DQ<003DC00<@4a<0<a<202/C00<=4a<01a<00a0C4`2M4`03

01<C00PC00@04a<C0P0O4`033A<C04lC000d4`0341<C03@C00<04a<0:Q<00`dC4`084`0341<C09`C

00<04a<01Q<200@C00<04a<07a<23DlC000c4`0341<C03DC00<04a<0:a<00`dC4`084`0341<C09/C

00<04a<01Q<00`0C4`034`0301<C024C00<=4a<0C1<0038C00<@4a<0=Q<00`0C4`0/4`033A<C00LC

00<@4a<0VQ<200PC0`034`0301<C028C0Pe<4`00<A<00a0C4`0g4`80;A<00`dC4`084`0341<C0:TC

00<04a<091<00`dC4`194`00<1<00a0C4`0h4`0301<C02dC00<=4a<021<00a0C4`2X4`809Q<23DTC

000_4`0341<C02TC0`034`0301<C008C00<04a<00Q<00`0C4`0^4`033A<C00PC00<@4a<0Ya<00`0C

4`0W4`033A<C04HC000^4`0341<C02XC00<04a<01a<00`0C00034`0301<C02hC00<=4a<02A<00a0C

4`2V4`0301<C02PC0Pe64`00;A<00a0C4`0/4`0301<C00PC00@04a<C0P0`4`033A<C00TC00<@4a<0

YA<00`0C4`0Z4`033A<C04<C000/4`0341<C02dC00<04a<01Q<200@C00<04a<0;a<00`dC4`0:4`03

41<C0:@C0P0/4`8=@a<002/C00<@4a<0;A<00`0C00074`0301<C00<C00<04a<0<1<00`dC4`0:4`03

41<C0:<C00<04a<0;A<00`dC4`104`00:Q<00a0C4`0_4`0301<C00HC0`034`0301<C030C00<=4a<0

2a<00a0C4`2R4`0301<C02hC0Pe04`00:A<00a0C4`0o4`80<Q<00`dC4`0;4`0341<C0:4C00<04a<0

<1<23ChC000X4`0341<C040C00<04a<0<Q<00`dC4`0;4`0341<C0:0C00<04a<0<Q<23C`C000W4`03

41<C044C00<04a<0<Q<00`dC4`0<4`0341<C09lC0P0e4`8=>Q<002HC00<@4a<0@Q<00`0C4`0c4`03

3A<C00`C00<@4a<0WQ<00`0C4`0f4`8=>1<002DC00<@4a<0@a<203@C00<=4a<03A<00a0C4`2M4`03

01<C03PC0Pdf4`0091<00a0C4`144`0301<C03@C00<=4a<03A<00a0C4`2L4`0301<C03XC0Pdd4`00

8a<00a0C4`154`0301<C03DC00<=4a<03A<00a0C4`2K4`80?A<23C8C000S4`0341<C04DC00<04a<0

=A<00`dC4`0>4`0341<C09XC00<04a<0?Q<00`dC4`0_4`008Q<00a0C4`164`80=a<00`dC4`0>4`03

41<C09<C0`034`0301<C03lC0Pd_4`008A<00a0C4`174`0301<C03LC00<=4a<03Q<00a0C4`2B4`03

01<C00<C00<04a<0@A<23BdC000P4`0341<C04PC00<04a<0=a<00`dC4`0?4`0341<C098C00<04a<0

0Q<204@C00<=4a<0:Q<001lC00<@4a<0BA<00`0C4`0h4`033A<C00lC00<@4a<0TA<00`0C4`024`03

01<C04@C0PdZ4`007Q<00a0C4`1:4`80>A<00`dC4`0@4`0341<C08lC00<04`000a<00`0C4`164`8=

:1<001dC00<@4a<0Ba<00`0C4`0i4`033A<C010C00<@4a<0Sa<00`0C4`024`0301<C04PC0PdV4`00

71<00a0C4`1<4`0301<C03XC00<=4a<041<00a0C4`2C4`0301<C04XC0`dS4`006a<00a0C4`174`80

11<00`0C4`0j4`033A<C014C00<@4a<0TQ<204hC0`dP4`006Q<00a0C4`1:4`0501<C4`00?A<00`dC

4`0A4`0341<C094C00<04a<0D1<23AhC000I4`0341<C04XC00<04a<00Q<203`C00<=4a<04A<00a0C

4`2A4`0301<C058C0PdL4`00Ia<00`0C4`3W4`0301<C05@C0PdJ4`00IA<00`0C003Y4`80LA<006HC

00<04a<0j1<00`0C4`1`4`00;1<30?lC8a<00`0C4`1`4`00;1<00`0C4`3o4b<C00<04a<0L1<002dC

00<04a<01A<00`0C4`3o4hdC000]4`0401<C4`<000@C01<C0`3o4hXC000/4`0301<0008C0P024`03

01<C008C00<04a<0oa>84`00;A<00`0C4`034`0401<C008C00<04a<0oa>94`00<a<0100C4`034`03

01<C00HC00<04a<09A<302dC00<04a<0oa<W4`007A<300034`00008031<300@C0`084`0301<C02@C

00@04a<04A<300034`0000800Q<00`0C4`024`0301<C008C00<04a<01A<0100C4a<5008C00@04a<C

0P044`0301<C00@C0P3;4`0301<C038C00<04a<021<001`C00@04a<091<00`0C4`0S4`0401<C010C

00@04a<01Q<00`0C00074`0301<000@C1@034`0301<C00HC00<04`000Q<00`0C00044`0301<C0<<C

00<04a<011<00`0C4`0C4`0301<C01hC00<04a<01a<001`C00D04a<04`0400034`0001P0:a<3010C

00D04a<04`0400044`0C00TC00<04a<011<00`0C4`034`0301<C00HC00<04`0011<00`0C4`024`03

01<C0;4C00@04a<C10024`801Q<00`0C4`034`0301<C008C00<04a<00Q<00`0C4`024`0301<C00DC

00@04a<C1@024`0401<C4`8011<00`0C4`044`8011<0100C4a<2004C0@0100007A<304dC00<04a<0

3a<300HC00<04`001a<200LC00<04a<00a<00`0C4`064`800a<200DC00<04a<0/1<00`0C00074`03

01<C00@C1@034`0701<C4`0C00074`0301<000@C1@034`0301<C00HC00<04`000Q<00`0C00044`03

01<C00@C00<04a<00Q<00`0C00014`007a<00`0C4`1:4`804a<00`0C4`044`0301<000LC00<04a<0

31<00`0C4`064`0301<C008C00<04a<011<00`0C002`4`0301<0008C10000a<04`074`0301<C00<C

00L04a<C01<000TC00<04a<011<00`0C4`034`0301<C00HC00<04`0011<00`0C4`024`0301<C00@C

00<04a<00a<1004C0A<001hC0P1P4`801a<00`0C4`064`<02a<200TC0P024`<011<309HC0P000a<0

000E4`0301<000LC00<04a<01Q<00`0C4`034`0701<C4`0C00074`801a<00`0C4`034`0301<C00HC

0P034`801A<00`0C4`044`0301<C00<C0@014`4C003o4e4C00<04`005Q<00`0C00074`0301<000dC

00H04a<04`074`0301<C00`C00<04a<01Q<00`0C4`024`0301<C00@C00<04`000a<00`0C4`034`03

01<0004C000Y4`801Q<20?lC7a<00`0C4`0F4`0301<C00HC0`0>4`0401<C00PC0`0;4`802A<2008C

0`044`<00Q<00`0C4`034`800A<10040000[4`0301<C008C00<04a<0oa<O4`0301<C070C000Z4`03

01<C00<C00<04a<01A<00`0C4`3o4aHC00<04`00LA<002/C00<04a<00Q<00`0C4`024`@00a<30?lC

4A<200034`00070C000Y4`0301<000@C00<04`000Q<200034`0C00@C00<04a<0oa>44`00:Q<00`0C

4`034`<011<00`0C00034`0301<C0?lCQA<003LC00<04`0011<00`0C4`3o4h@C000e4`<011<30?lC

QQ<00?lCaA<00?lCaA<00?lCaA<00?lCaA<00?lCaA<00001\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.69854, -1.80126, 0.0228042, 0.0228042}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -84.5 0 ]

[.5 .96488 84.5 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -145.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.645) show

222.250000 19.500000 moveto

(C) show

227.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.28289 0 m

.30316 .03333 L

.34309 .09902 L

.3815 .16221 L

.42237 .22943 L

.46172 .29417 L

.49955 .35641 L

.53984 .42268 L

.57861 .48646 L

.61984 .55427 L

.65954 .61959 L

.69774 .68242 L

.73838 .74928 L

.77751 .81365 L

.81909 .88205 L

.85916 .94796 L

s

.85916 .94796 m

.86185 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.401368 0.238095 [

[.02381 .38887 -6 -9 ]

[.02381 .38887 6 0 ]

[.2619 .38887 -6 -9 ]

[.2619 .38887 6 0 ]

[.7381 .38887 -3 -9 ]

[.7381 .38887 3 0 ]

[.97619 .38887 -3 -9 ]

[.97619 .38887 3 0 ]

[1.025 .40137 0 -8 ]

[1.025 .40137 9 8 ]

[.4875 .04423 -24 -4.5 ]

[.4875 .04423 0 4.5 ]

[.4875 .16327 -12 -4.5 ]

[.4875 .16327 0 4.5 ]

[.4875 .28232 -24 -4.5 ]

[.4875 .28232 0 4.5 ]

[.4875 .52042 -18 -4.5 ]

[.4875 .52042 0 4.5 ]

[.4875 .63946 -6 -4.5 ]

[.4875 .63946 0 4.5 ]

[.4875 .75851 -18 -4.5 ]

[.4875 .75851 0 4.5 ]

[.4875 .87756 -6 -4.5 ]

[.4875 .87756 0 4.5 ]

[.5 .96557 -4.5 0 ]

[.5 .96557 4.5 16 ]

[.5 .95307 -137 0 ]

[.5 .95307 137 16 ]

[ 0 0 0 0 ]

[ 1 .94057 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .40137 m

.02381 .40762 L

s

[(-2)] .02381 .38887 0 1 Mshowa

.2619 .40137 m

.2619 .40762 L

s

[(-1)] .2619 .38887 0 1 Mshowa

.7381 .40137 m

.7381 .40762 L

s

[(1)] .7381 .38887 0 1 Mshowa

.97619 .40137 m

.97619 .40762 L

s

[(2)] .97619 .38887 0 1 Mshowa

.125 Mabswid

.07143 .40137 m

.07143 .40512 L

s

.11905 .40137 m

.11905 .40512 L

s

.16667 .40137 m

.16667 .40512 L

s

.21429 .40137 m

.21429 .40512 L

s

.30952 .40137 m

.30952 .40512 L

s

.35714 .40137 m

.35714 .40512 L

s

.40476 .40137 m

.40476 .40512 L

s

.45238 .40137 m

.45238 .40512 L

s

.54762 .40137 m

.54762 .40512 L

s

.59524 .40137 m

.59524 .40512 L

s

.64286 .40137 m

.64286 .40512 L

s

.69048 .40137 m

.69048 .40512 L

s

.78571 .40137 m

.78571 .40512 L

s

.83333 .40137 m

.83333 .40512 L

s

.88095 .40137 m

.88095 .40512 L

s

.92857 .40137 m

.92857 .40512 L

s

.25 Mabswid

0 .40137 m

1 .40137 L

s

gsave

1.025 .40137 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .04423 m

.50625 .04423 L

s

[(-1.5)] .4875 .04423 1 0 Mshowa

.5 .16327 m

.50625 .16327 L

s

[(-1)] .4875 .16327 1 0 Mshowa

.5 .28232 m

.50625 .28232 L

s

[(-0.5)] .4875 .28232 1 0 Mshowa

.5 .52042 m

.50625 .52042 L

s

[(0.5)] .4875 .52042 1 0 Mshowa

.5 .63946 m

.50625 .63946 L

s

[(1)] .4875 .63946 1 0 Mshowa

.5 .75851 m

.50625 .75851 L

s

[(1.5)] .4875 .75851 1 0 Mshowa

.5 .87756 m

.50625 .87756 L

s

[(2)] .4875 .87756 1 0 Mshowa

.125 Mabswid

.5 .06803 m

.50375 .06803 L

s

.5 .09184 m

.50375 .09184 L

s

.5 .11565 m

.50375 .11565 L

s

.5 .13946 m

.50375 .13946 L

s

.5 .18708 m

.50375 .18708 L

s

.5 .21089 m

.50375 .21089 L

s

.5 .2347 m

.50375 .2347 L

s

.5 .25851 m

.50375 .25851 L

s

.5 .30613 m

.50375 .30613 L

s

.5 .32994 m

.50375 .32994 L

s

.5 .35375 m

.50375 .35375 L

s

.5 .37756 m

.50375 .37756 L

s

.5 .42518 m

.50375 .42518 L

s

.5 .44899 m

.50375 .44899 L

s

.5 .4728 m

.50375 .4728 L

s

.5 .49661 m

.50375 .49661 L

s

.5 .54423 m

.50375 .54423 L

s

.5 .56803 m

.50375 .56803 L

s

.5 .59184 m

.50375 .59184 L

s

.5 .61565 m

.50375 .61565 L

s

.5 .66327 m

.50375 .66327 L

s

.5 .68708 m

.50375 .68708 L

s

.5 .71089 m

.50375 .71089 L

s

.5 .7347 m

.50375 .7347 L

s

.5 .78232 m

.50375 .78232 L

s

.5 .80613 m

.50375 .80613 L

s

.5 .82994 m

.50375 .82994 L

s

.5 .85375 m

.50375 .85375 L

s

.5 .02042 m

.50375 .02042 L

s

.5 .90137 m

.50375 .90137 L

s

.5 .92518 m

.50375 .92518 L

s

.25 Mabswid

.5 0 m

.5 .94057 L

s

gsave

.5 .96557 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .95307 -198 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.645) show

298.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

303.000000 15.000000 moveto

(L) show

310.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

317.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

324.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

329.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

333.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .94057 L

0 .94057 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .25183 m

.02576 .25182 L

.03158 .25177 L

.04117 .25168 L

.05437 .25156 L

.07095 .2514 L

.09062 .2512 L

.11306 .25095 L

.13787 .25065 L

.16463 .25028 L

.19288 .24985 L

.22215 .24933 L

.25192 .24871 L

.2817 .24799 L

.31096 .24714 L

.33922 .24615 L

.36598 .24502 L

.39079 .24374 L

.41322 .24234 L

.4329 .24086 L

.44947 .23939 L

.46267 .23803 L

.47226 .23692 L

.47808 .23619 L

.48003 .23594 L

s

.48003 .23594 m

.48216 .23566 L

.48849 .23478 L

.49892 .23318 L

.51327 .23068 L

.5313 .22692 L

.5527 .22141 L

.57709 .21357 L

.60407 .20294 L

.63318 .18956 L

.66391 .17408 L

.69573 .15738 L

.72811 .1403 L

.76049 .12346 L

.79232 .10728 L

.82305 .09208 L

.85215 .07807 L

.87913 .06542 L

.90353 .05425 L

.92493 .04465 L

.94295 .03671 L

.95731 .03048 L

.96774 .026 L

.97407 .0233 L

.97619 .02239 L

s

.48003 .48402 m

.48216 .45664 L

.48849 .4297 L

.49892 .40356 L

.51327 .37859 L

.5313 .35525 L

.5527 .3342 L

.57709 .31613 L

.60407 .30164 L

.63318 .2908 L

.66391 .28307 L

.69573 .27768 L

.72811 .27388 L

.76049 .27117 L

.79232 .26918 L

.82305 .2677 L

.85215 .26657 L

.87913 .26571 L

.90353 .26505 L

.92493 .26454 L

.94295 .26416 L

.95731 .26388 L

.96774 .26368 L

.97407 .26357 L

.97619 .26354 L

s

.48003 .48414 m

.48216 .51181 L

.48849 .53963 L

.49892 .56736 L

.51327 .59484 L

.5313 .62193 L

.5527 .64849 L

.57709 .6744 L

.60407 .69952 L

.63318 .72374 L

.66391 .74695 L

.69573 .76904 L

.72811 .78992 L

.76049 .80948 L

.79232 .82764 L

.82305 .84433 L

.85215 .85946 L

.87913 .87297 L

.90353 .88481 L

.92493 .89491 L

.94295 .90323 L

.95731 .90975 L

.96774 .91442 L

.97407 .91723 L

.97619 .91817 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<00`0C4`1`4`00oa=B4`0301<C070C001T4`D0j1<00`0C4`1`4`00IQ<00`0C4`3X4`80

LA<004HC00<=4a<05a<300<C00<04a<00Q<20>@C00<04a<0Da<33AXC00164`033A<C01dC00<04a<0

0Q<00`0C4`3S4`0301<C054C0PdM4`00Aa<00`dC4`0L4`0301<C008C00<04a<0dQ<5008C00<04a<0

0Q<00`0C4`024`0301<C04lC0PdO4`00Aa<00`dC4`0K4`8011<00`0C4`3D4`0301<C00HC00<04`00

0a<00`0C4`1=4`8=8A<004PC00<=4a<081<20<lC0`034`0301<C00PC00@04a<C0P1<4`8=8a<004PC

00<=4a<081<00`0C4`3D4`0301<C00HC0P044`0301<C04TC0PdU4`00BA<00`dC4`0O4`0301<C0=@C

00<04a<01Q<00`0C4`034`0301<C04LC0PdW4`00BQ<00`dC4`0N4`0301<C0=<C0P084`<00a<00`0C

4`154`8=:A<004XC00<=4a<07Q<20>@C0P134`<=:a<004/C00<=4a<07A<00`0C4`3S4`0301<C040C

0Pd^4`00C1<00`dC4`0L4`0301<C0><C00<04a<0?Q<23C0C001<4`033A<C01`C00<04a<0ha<00`0C

4`0l4`8=<Q<004dC00<=4a<06a<20>@C00<04a<0>Q<23C@C001=4`033A<C01/C00<04a<0ha<203TC

0Pdf4`00CQ<00`dC4`0J4`0301<C0><C00<04a<0=A<33CPC001?4`033A<C01TC00<04a<0ha<00`0C

4`0c4`8=>a<004lC00<=4a<06A<20>@C00<04a<0<A<23CdC001@4`033A<C01PC00<04a<0ha<2030C

0Pdo4`00DA<00`dC4`084`0301<C008C00<04a<00Q<00`0C4`024`0301<C0><C00<04a<0;A<23D4C

001A4`033A<C00LC00<04`001a<00`0C00034`0301<C0><C00<04a<0:a<23D<C001B4`043A<C4`<0

0Q<00`0C00094`0401<C4`80i1<00`0C4`0Y4`8=AA<005<C00<=4a<01A<00`0C00074`8011<00`0C

4`3S4`80:1<23DLC001C4`033A<C00DC00<04`001a<00`0C4`034`0301<C0><C00<04a<09A<23DTC

001D4`033A<C00DC00<04a<01Q<300<C00<04a<0ha<00`0C4`0T4`033A<C04TC001D4`033A<C01@C

00<04a<0g1<5008C00<04a<08Q<23D`C001E4`033A<C01<C0P3O4`0301<C008C00<04a<08A<00`dC

4`1<4`00EQ<00`dC4`0B4`0301<C0=PC0`034`0301<C008C0P0P4`8=Ca<005HC00<=4a<04Q<00`0C

4`3N4`0301<C008C00<04a<07A<23E4C001G4`033A<C014C00<04a<0gQ<00`0C4`024`0301<C01/C

0PeC4`00F1<00`dC4`0@4`80gQ<200@C00<04a<06A<23EDC001H4`033A<C010C00<04a<0ha<201PC

0PeG4`006Q<302DC1@0B4`033A<C00lC00<04a<091<502@C0`2C4`0301<C01DC0PeI4`006Q<00`0C

4`0W4`0301<C01<C00<=4a<03Q<00`0C4`0V4`0301<C02@C00<04a<0Ta<00`0C4`0B4`<=Fa<001DC

0`034`0301<C020C0`034`0301<C01<C00<=4a<03Q<202LC00<04a<09A<00`0C4`2B4`0301<C00lC

0`eN4`006a<00`0C4`0V4`0301<C01@C00<=4a<03A<00`0C4`0V4`0301<C02DC00<04a<0TQ<200hC

0PeQ4`006Q<00`0C000W4`0301<C01@C00<=4a<03A<00`0C4`0V4`0301<C02@C00<04`00Ta<00`0C

4`0:4`<=Ha<001/C00<04a<09A<201LC00<=4a<031<00`0C4`0U4`809a<00`0C4`2B4`0301<C00HC

10eV4`00GA<00`dC4`0;4`80i1<00`0C4`024`@=JQ<005dC00<=4a<02a<00`0C4`3S4`0301<=008=

KQ<005hC00<=4a<02Q<00`0C4`1K4`80Oa<93G4C001O4`033A<C00TC00<04a<0FQ<00`0C4`1e4`X=

1a<00`0C4`1`4`005A=:00033@0006001Q<00`0C4`1F4al=4A<00`0C4`1`4`006A<00`0C4`064`03

01<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<0

0Q<010dC4`074`0341<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`03

01<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<021<00`0C4`0^4bP=<1<00`0C4`1`4`00

H1<00`dC4`084`0341<C05XC00<04`00QQ<2074C001Q4`033A<C00LC0Q1K4`<0QQ<00`0C4`164a0=

6Q<0064C00<=4a<01a<24>@C00<04a<0<A<E3BXC001R4`033A<C00DC00<@0100eA<00`0C4`024`03

01<C008C00<04a<00Q<00`0C4`0U4``=?a<006<C00<=4a<011<00a00403D4`0301<000LC00<04`00

0a<00`0C4`0O4`H=Ba<006<C00<=4a<011<00a00403?4`<00Q<00`0C00094`0401<C4`806Q<63E4C

001T4`033A<C008C00D@4`00403C4`0301<000LC0P044`0301<C01DC10eG4`00I1<00`dC4`024`05

41<04a00da<00`0C00074`0301<C00<C00<04a<04Q<33E/C001U4`093A<C4a0C01<@0=@C00<04a<0

1Q<300<C00<04a<041<23EhC001V4`063A<C41<00Q<00a0C4`3P4`803a<23F0C001V4`053A<C41<0

0P000a<@4`3Q4`0301<C00`C0PeR4`00Ia<01@dC41<0008C00<@4a<0h1<00`0C4`0;4`033A<C068C

001W4`053A0C4`000a<00a0C4`3O4`0301<C00XC00<=4a<0Ha<006PC00@=4a<00a<00a0C4`3O4`80

2A<23FHC001X4`0340dC00800Q<00a0C4`3O4`0301<C00LC00<=4a<0IQ<006LC00D@4`dC00044`03

41<C0=hC00<04a<01Q<00`dC4`1W4`00G1<00`0C4`024`0301<C008C00H041<C3@044`0341<C08LC

0`0X4`D09a<00`0C4`054`033A<C01lC1@0W4`<06Q<005/C00<04`001a<00`0@00024`033@0C00<C

00<@4a<0Qa<00`0C4`0Z4`0301<C02LC00<04a<011<00`dC4`0R4`0301<C02LC00<04a<06Q<005/C

00<04`0021<00a004`024`033@0C00<C00<@4a<0PA<300<C00<04a<08a<300<C00<04a<09a<200@C

00<=4a<08a<00`0C4`0X4`0301<C01TC001K4`0301<000LC00<041<00a<00`0=4`034`0341<C08LC

00<04a<0:A<00`0C4`0W4`0301<C008C00<=4a<091<00`0C4`0X4`0301<C01TC001K4`0301<000LC

00<@4a<00a<00`0=4`044`0341<C08DC00<04`00:Q<00`0C4`0W4`0501<C4`d09a<00`0C4`0W4`03

01<001XC001L4`0301<C00HC00<@00000a<00`0C3@044`0341<C08HC00<04a<0:1<202TC00D04a<C

3@0V4`80:Q<00`0C4`0I4`00I1<00a0C4`044`8000<=4a<00Q<00a0C4`3L4`8000<C3A<0KQ<006@C

00<@4a<011<0100C4`d44`0341<C0=/C00<04`d0L1<006<C00<@4a<01A<0100C4`d44`0341<C0=/C

00<04`d0L1<006<C00<@4a<01A<01@0C4a<=00@C00<@4a<0fQ<00`0=4`1R4`8031<0068C00<@4a<0

1Q<00`0C4`024`053A<C4a00g1<00`0=4`1Q4`0301<C00`C001R4`0341<C00HC0P034`033A<C008C

00<@4a<0OA=L00033@0005X01a<00`0C4`0<4`00HA<00a0C4`074`0301<C00<C00D=4a<C40234`03

01<C02TC00<04a<0:A<00`dC4`0Y4`0301<C02TC00<04a<02A<00`0C4`0<4`00HA<00a0C4`074`03

01<C00<C00D=4a<C403J4`033@0C068C00<04`0031<0060C00<@4a<021<00`0C4`044`053A<C4a00

fA<00`d04`1R4`<031<0060C00<@4a<021<200HC00@=4a<@f1<010dC001a4`00Ga<00a0C4`094`03

01<C00DC00D=4a<C403G4`033A<0078C001O4`0341<C00TC00<04a<01Q<010dC4a3G4`033A<0078C

001N4`0341<C00XC00<04a<01a<010dC4a3F4`033A<0078C001N4`0341<C00XC0P084`043A<C4=DC

00<=4a<00P1a4`00GA<00a0C4`0;4`0301<C00PC00@=4a<@e1<010dC4`1b4`00GA<00a0C4`044`D0

0Q<00`0C4`084`043A<C4=@C00@=4a<0LQ<005`C00<@4a<01a<00`0C4`024`0301<C00TC00@=4a<@

da<010dC4`1b4`00Fa<00a0C4`084`0301<C008C0P0;4`043A<C4=8C00@=4a<0LQ<005/C00<@4a<0

21<00`0C4`024`0301<C00XC00@=4a<@dA<010dC4a<2074C001J4`0341<C00TC00<04a<00Q<00`0C

4`0;4`043A<C4=0C00D=4a<C001b4`00FQ<00a0C4`084`8011<00`0C4`0<4`043A<C4<lC00D=4a<C

001b4`00FA<00a0C4`0?4`803A<010dC4a3?4`053A<C4`00LQ<005PC00<@4a<041<00`0C4`0=4`04

3A<C4<hC00@=4a<C0P1a4`00F1<00a0C4`0@4`0301<C00hC00@=4a<@cQ<010dC4`1b4`00Ea<00a0C

4`0A4`0301<C00hC00@=4a<@cQ<010dC4`1b4`00EQ<00a0C4`0B4`8041<010dC4a314`0301<C008C

00<04a<00Q<00`0C3@024`0301<C070C001F4`0341<C018C00<04a<03a<01@dC4a<@0;lC00<04`00

1a<0100C00d24`0301<C070C001E4`0341<C01<C00<04a<041<010dC4a2o4`0301<000TC00@03A<C

0P1a4`00E1<00a0C4`0D4`0301<C014C00@=4a<@_Q<00`0C00074`800Q<00`dC001b4`00Da<00a0C

4`0E4`804Q<010dC4a2n4`0301<000LC00L04a<C3A<0078C001C4`0341<C01DC00<04a<04Q<010dC

4a2n4`0301<C00HC0`0011<=4`1b4`00DQ<00a0C4`0F4`0301<C01<C00@=4a<@bQ<010dC001a4`00

DA<00a0C4`0G4`0301<C01<C00@=4a<@ba<00`d04`1a4`00DA<00a0C4`0G4`805A<010dC4a3:4`03

3@0C074C001@4`0341<C01PC00<04a<05A<00`dC403;4`033A<C070C001?4`0341<C00PC1@024`03

01<C008C00<04a<00Q<00`0C4`0E4`043A<C4<XC00<=01<0L1<004lC00<@4a<02Q<00`0C4`064`03

01<000<C00<04a<05Q<010dC4a394`0300dC070C001>4`0341<C00/C00<04a<021<0100C4a<201LC

00D=4a<C40384`0300dC070C001=4`0341<C00`C00<04a<01Q<200@C00<04a<05a<010dC4a384`03

01<=070C001<4`0341<C00dC00<04a<01Q<00`0C4`034`0301<C01PC00@=4a<@aa<00`0C3@1`4`00

C1<00a0C4`0<4`8021<300<C00<04a<061<01@dC4a<@0<HC0P000a<=4`1^4`00Ba<00a0C4`0M4`80

6Q<01@dC4a<@0<DC00D04a<C3@1^4`00BQ<00a0C4`0N4`0301<C01XC00@=4a<@aA<01@0C4a<=06hC

001:4`0341<C01hC00<04a<06Q<01@dC4a<@0<@C00<04a<00Q<00`dC4`1[4`00BA<00a0C4`0O4`03

01<C01/C00D=4a<C40334`800a<00`dC4`1[4`00B1<00a0C4`0P4`8071<00`dC4`024`0341<C0<0C

00<04a<00a<00`dC4`1Z4`00Aa<00a0C4`0Q4`0301<C01`C00<=4a<00Q<00a0C4`2o4`0301<C00@C

00<=4a<0JA<004LC00<@4a<08A<00`0C4`0L4`033A<C008C00<@4a<0^1<5008C00<04a<01A<00`dC

4`1X4`00AQ<00a0C4`0R4`0301<C01dC00<=4a<00Q<00a0C4`2i4`0301<C008C00<04a<01A<00`dC

4`1X4`00AA<00a0C4`0S4`807Q<00`dC4`034`0341<C0;PC00<04a<00Q<200LC00<=4a<0Ia<004@C

00<@4a<091<00`0C4`0N4`033A<C00<C00<@4a<0]a<00`0C4`024`0301<C00LC00<=4a<0IQ<004@C

00<@4a<091<00`0C4`0N4`033A<C00<C00<@4a<0]a<00`0C4`024`0301<C00PC00<=4a<0IA<004<C

00<@4a<09A<00`0C4`0O4`033A<C00<C00<@4a<0]A<200@C00<04a<02A<00`dC4`1T4`00@Q<00a0C

4`0V4`0301<C020C00<=4a<00a<00a0C4`2j4`802Q<00`dC4`1T4`00@A<00a0C4`0W4`808A<00`dC

4`044`0341<C0;TC00<04a<02Q<00`dC4`1S4`00@1<00a0C4`0X4`0301<C024C00<=4a<011<00a0C

4`2h4`0301<C00/C00<=4a<0HQ<0040C00<@4a<08Q<300<C00<04a<08A<00`dC4`054`0341<C0;LC

00<04a<031<00`dC4`1Q4`00?a<00a0C4`0S4`0301<C00<C00<04a<08Q<00`dC4`044`0341<C0;LC

0P0>4`033A<C060C000n4`0341<C02DC00<04a<00Q<202<C00<=4a<01A<00a0C4`2f4`0301<C00hC

00<=4a<0Ga<003dC00<@4a<09Q<00`0C4`024`0301<C02<C00<=4a<01A<00a0C4`2e4`0301<C00lC

00<=4a<0GQ<003dC00<@4a<09A<00`0C00034`0301<C02@C00<=4a<01A<00a0C4`2d4`0301<C010C

00<=4a<0GA<003`C00<@4a<09a<00`0C4`024`0301<C02@C00<=4a<01Q<00a0C4`2c4`0301<C014C

0PeM4`00>a<00a0C4`0]4`809Q<00`dC4`064`0341<C0;8C0P0D4`033A<C05XC000j4`0341<C02hC

00<04a<09A<00`dC4`064`0341<C0;8C00<04a<051<23EXC000j4`0341<C02hC00<04a<09Q<00`dC

4`064`0341<C0;4C00<04a<05Q<00`dC4`1G4`00>A<00a0C4`0_4`0301<C02LC00<=4a<01Q<00a0C

4`2`4`0301<C01LC00<=4a<0EQ<003PC00<@4a<0<1<202PC00<=4a<01a<00a0C4`2_4`806A<23EHC

000g4`0341<C034C00<04a<0:1<00`dC4`064`0341<C0:lC00<04a<06Q<00`dC4`1C4`00=a<00a0C

4`0a4`0301<C02TC00<=4a<01Q<00a0C4`2M4`D00Q<00`0C4`024`0301<C008C00<04a<06a<00`dC

4`1B4`00=Q<00a0C4`0b4`0301<C02TC00<=4a<01a<00a0C4`2N4`0301<C00HC00<04`000a<00`0C

4`0L4`8=DQ<003DC00<@4a<0<a<202/C00<=4a<01a<00a0C4`2M4`0301<C00PC00@04a<C0P0O4`03

3A<C04lC000d4`0341<C03@C00<04a<0:Q<00`dC4`084`0341<C09`C00<04a<01Q<200@C00<04a<0

7a<23DlC000c4`0341<C03DC00<04a<0:a<00`dC4`084`0341<C09/C00<04a<01Q<00`0C4`034`03

01<C024C00<=4a<0C1<0038C00<@4a<0=Q<00`0C4`0/4`033A<C00LC00<@4a<0VQ<200PC0`034`03

01<C028C0Pe<4`00<A<00a0C4`0g4`80;A<00`dC4`084`0341<C0:TC00<04a<091<00`dC4`194`00

<1<00a0C4`0h4`0301<C02dC00<=4a<021<00a0C4`2X4`809Q<23DTC000_4`0341<C02TC0`034`03

01<C008C00<04a<00Q<00`0C4`0^4`033A<C00PC00<@4a<0Ya<00`0C4`0W4`033A<C04HC000^4`03

41<C02XC00<04a<01a<00`0C00034`0301<C02hC00<=4a<02A<00a0C4`2V4`0301<C02PC0Pe64`00

;A<00a0C4`0/4`0301<C00PC00@04a<C0P0`4`033A<C00TC00<@4a<0YA<00`0C4`0Z4`033A<C04<C

000/4`0341<C02dC00<04a<01Q<200@C00<04a<0<1<00`dC4`094`0341<C0:@C0P0/4`8=@a<002/C

00<@4a<0;A<00`0C00074`0301<C00<C00<04a<0<1<00`dC4`0:4`0341<C0:<C00<04a<0;A<00`dC

4`104`00:Q<00a0C4`0_4`0301<C00HC0`034`0301<C034C00<=4a<02Q<00a0C4`2R4`0301<C02hC

0Pe04`00:A<00a0C4`0o4`80<Q<00`dC4`0;4`0341<C0:4C00<04a<0<1<23ChC000X4`0341<C040C

00<04a<0<Q<00`dC4`0;4`0341<C0:0C00<04a<0<Q<23C`C000W4`0341<C044C00<04a<0<a<00`dC

4`0;4`0341<C09lC0P0e4`8=>Q<002HC00<@4a<0@Q<00`0C4`0c4`033A<C00`C00<@4a<0WQ<00`0C

4`0f4`8=>1<002DC00<@4a<0@a<203DC00<=4a<031<00a0C4`2M4`0301<C03PC0Pdf4`0091<00a0C

4`144`0301<C03DC00<=4a<031<00a0C4`2L4`0301<C03XC0Pdd4`008a<00a0C4`154`0301<C03DC

00<=4a<03A<00a0C4`2K4`80?A<23C8C000S4`0341<C04DC00<04a<0=Q<00`dC4`0=4`0341<C09XC

00<04a<0?Q<00`dC4`0_4`008Q<00a0C4`164`80=a<00`dC4`0>4`0341<C09<C0`034`0301<C03lC

0Pd_4`008A<00a0C4`174`0301<C03LC00<=4a<03Q<00a0C4`2B4`0301<C00<C00<04a<0@A<23BdC

000P4`0341<C04PC00<04a<0=a<00`dC4`0?4`0341<C098C00<04a<00Q<204@C0Pd[4`007a<00a0C

4`194`0301<C03PC00<=4a<03a<00a0C4`2A4`0301<C008C00<04a<0AA<23BTC000N4`0341<C04XC

0P0j4`033A<C00lC00<@4a<0Sa<00`0C00034`0301<C04LC0PdW4`007A<00a0C4`1;4`0301<C03TC

00<=4a<041<00a0C4`2?4`0301<C008C00<04a<0BA<23BDC000L4`0341<C04`C00<04a<0>Q<00`dC

4`0@4`0341<C09<C00<04a<0Ba<23B<C000K4`0341<C04LC0P044`0301<C03XC00<=4a<04A<00a0C

4`2B4`80CQ<33B0C000J4`0341<C04XC00D04a<C000m4`033A<C014C00<@4a<0TA<00`0C4`1@4`8=

7Q<001TC00<@4a<0BQ<00`0C4`024`80?1<00`dC4`0A4`0341<C094C00<04a<0DQ<23A`C001W4`03

01<C0>LC00<04a<0E1<23AXC001U4`0301<00>TC0P1a4`00IQ<00`0C4`3X4`0301<C070C000Z4`<0

oa<U4`0301<C070C000Z4`0301<C0?lC9A<00`0C4`1`4`00:a<00`0C4`044`0301<C0?lCT1<002/C

00@04a<C10034`<0oa><4`00:Q<00`0C00024`8000<C01<011<00`0C4`3o4hXC000[4`0301<C00<C

00<04`000a<00`0C4`3o4h/C000a4`0301<000@C00<04a<01Q<00`0C4`0W4`<0:a<00`0C4`3o4bTC

000K4`<000<C00000P0<4`<011<300PC00<04a<09Q<0100C4`0?4`<000<C00000P024`0301<C008C

00<04a<00Q<00`0C4`054`0401<C4`D00Q<0100C4a<200@C0`024`0301<C00@C0P354`0301<C03LC

00<04a<01Q<001XC00@04a<091<00`0C4`0U4`0401<C00hC00@04a<01Q<00`0C00074`0301<000@C

1@034`0301<C00HC00<04`0011<01P0C4`0C00@C00<04a<0_A<00`0C4`044`0301<C01<C00<04a<0

8a<00`0C4`054`006Q<01@0C4`0C00@000<C0000600]4`<03Q<01@0C4`0C00@000@C01<02A<00`0C

4`044`0301<C00<C00<04a<01Q<00`0C00024`@00a<00`0C4`024`0301<C0:/C00@04a<C10024`80

1Q<00`0C4`034`0301<C008C00<04a<00Q<00`0C4`024`0301<C00DC00@04a<C1@024`0401<C4`80

11<3008C00<04a<011<200@C00@04a<C0P014`006a<304lC00<04a<03A<300HC00<04`001a<200LC

00<04a<00a<00`0C4`064`800a<00`0C00024`801A<00`0C4`2Z4`0301<000LC00<04a<011<500<C

00L04a<C01<000LC00<04`0011<500<C00<04a<01Q<00`0C00044`0601<C01<011<00`0C4`044`03

01<C008C0@014`007A<00`0C4`1<4`804A<00`0C4`044`0301<000LC00<04a<031<00`0C4`064`03

01<C00<C0P024`0301<C00@C00<04`00ZQ<00`0C00024`@000<C01<01a<00`0C4`034`0701<C4`0C

00094`0301<C00@C00<04a<00a<00`0C4`064`0301<0008C10034`0301<C008C00<04a<011<00`0C

4`034`40000L4`80H1<200LC00<04a<01Q<300/C0P094`8011<00`0C4`0300@C0`2C4`8000<C0000

4Q<00`0C00074`0301<C00HC00<04a<00a<01`0C4a<04`001a<200LC00<04a<00a<00`0C4`064`80

0a<00`0C00024`801A<00`0C4`044`0301<C00<C0@000?lCDA<00`0C000C4`0301<000LC00<04`00

3A<01P0C4`0C00LC00<04a<031<00`0C4`064`0301<C00<C0P024`0301<C00@C00<04`000a<00`0C

4`034`400A<002HC0P064`80oa<R4`0301<C01<C00<04a<01Q<300hC00@04a<021<300/C0P094`80

11<00`0C4`0300@C0`024`0301<C00<C0P014`00:1<00`0C4`024`0301<C0?lC8Q<00`0C4`1`4`00

9a<00`0C4`034`0301<C00HC00<04a<0oa<H4`0301<0074C000X4`0301<C008C00<04a<00Q<30004

4`0C4`<0oa<D4`8000<C0000L1<002HC00<04`0011<00`0C00024`800Q<00`0C4`024`0301<C0?lC

Qa<002LC00<04a<00a<300@C00@04a<00Q<00`0C4`3o4hPC000d4`0401<C00<C00<04a<0oa>74`00

<Q<300@C0`3o4hTC003o4lDC003o4lDC003o4lDC003o4lDC003o4lDC0000\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.68612, -1.79676, 0.0227674, 0.0227674}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -82 0 ]

[.5 .96488 82 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -143 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.64) show

217.250000 19.500000 moveto

(C) show

222.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.28223 0 m

.30316 .03432 L

.34309 .0998 L

.3815 .1628 L

.42237 .22982 L

.46172 .29436 L

.49955 .35641 L

.53984 .42248 L

.57861 .48607 L

.61984 .55367 L

.65954 .6188 L

.69774 .68143 L

.73838 .74809 L

.77751 .81226 L

.81909 .88046 L

.85916 .94617 L

s

.85916 .94617 m

.86295 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.400333 0.238095 [

[.02381 .38783 -6 -9 ]

[.02381 .38783 6 0 ]

[.2619 .38783 -6 -9 ]

[.2619 .38783 6 0 ]

[.7381 .38783 -3 -9 ]

[.7381 .38783 3 0 ]

[.97619 .38783 -3 -9 ]

[.97619 .38783 3 0 ]

[1.025 .40033 0 -8 ]

[1.025 .40033 9 8 ]

[.4875 .04319 -24 -4.5 ]

[.4875 .04319 0 4.5 ]

[.4875 .16224 -12 -4.5 ]

[.4875 .16224 0 4.5 ]

[.4875 .28129 -24 -4.5 ]

[.4875 .28129 0 4.5 ]

[.4875 .51938 -18 -4.5 ]

[.4875 .51938 0 4.5 ]

[.4875 .63843 -6 -4.5 ]

[.4875 .63843 0 4.5 ]

[.4875 .75748 -18 -4.5 ]

[.4875 .75748 0 4.5 ]

[.4875 .87652 -6 -4.5 ]

[.4875 .87652 0 4.5 ]

[.5 .964 -4.5 0 ]

[.5 .964 4.5 16 ]

[.5 .9515 -134.5 0 ]

[.5 .9515 134.5 16 ]

[ 0 0 0 0 ]

[ 1 .939 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .40033 m

.02381 .40658 L

s

[(-2)] .02381 .38783 0 1 Mshowa

.2619 .40033 m

.2619 .40658 L

s

[(-1)] .2619 .38783 0 1 Mshowa

.7381 .40033 m

.7381 .40658 L

s

[(1)] .7381 .38783 0 1 Mshowa

.97619 .40033 m

.97619 .40658 L

s

[(2)] .97619 .38783 0 1 Mshowa

.125 Mabswid

.07143 .40033 m

.07143 .40408 L

s

.11905 .40033 m

.11905 .40408 L

s

.16667 .40033 m

.16667 .40408 L

s

.21429 .40033 m

.21429 .40408 L

s

.30952 .40033 m

.30952 .40408 L

s

.35714 .40033 m

.35714 .40408 L

s

.40476 .40033 m

.40476 .40408 L

s

.45238 .40033 m

.45238 .40408 L

s

.54762 .40033 m

.54762 .40408 L

s

.59524 .40033 m

.59524 .40408 L

s

.64286 .40033 m

.64286 .40408 L

s

.69048 .40033 m

.69048 .40408 L

s

.78571 .40033 m

.78571 .40408 L

s

.83333 .40033 m

.83333 .40408 L

s

.88095 .40033 m

.88095 .40408 L

s

.92857 .40033 m

.92857 .40408 L

s

.25 Mabswid

0 .40033 m

1 .40033 L

s

gsave

1.025 .40033 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .04319 m

.50625 .04319 L

s

[(-1.5)] .4875 .04319 1 0 Mshowa

.5 .16224 m

.50625 .16224 L

s

[(-1)] .4875 .16224 1 0 Mshowa

.5 .28129 m

.50625 .28129 L

s

[(-0.5)] .4875 .28129 1 0 Mshowa

.5 .51938 m

.50625 .51938 L

s

[(0.5)] .4875 .51938 1 0 Mshowa

.5 .63843 m

.50625 .63843 L

s

[(1)] .4875 .63843 1 0 Mshowa

.5 .75748 m

.50625 .75748 L

s

[(1.5)] .4875 .75748 1 0 Mshowa

.5 .87652 m

.50625 .87652 L

s

[(2)] .4875 .87652 1 0 Mshowa

.125 Mabswid

.5 .067 m

.50375 .067 L

s

.5 .09081 m

.50375 .09081 L

s

.5 .11462 m

.50375 .11462 L

s

.5 .13843 m

.50375 .13843 L

s

.5 .18605 m

.50375 .18605 L

s

.5 .20986 m

.50375 .20986 L

s

.5 .23367 m

.50375 .23367 L

s

.5 .25748 m

.50375 .25748 L

s

.5 .3051 m

.50375 .3051 L

s

.5 .3289 m

.50375 .3289 L

s

.5 .35271 m

.50375 .35271 L

s

.5 .37652 m

.50375 .37652 L

s

.5 .42414 m

.50375 .42414 L

s

.5 .44795 m

.50375 .44795 L

s

.5 .47176 m

.50375 .47176 L

s

.5 .49557 m

.50375 .49557 L

s

.5 .54319 m

.50375 .54319 L

s

.5 .567 m

.50375 .567 L

s

.5 .59081 m

.50375 .59081 L

s

.5 .61462 m

.50375 .61462 L

s

.5 .66224 m

.50375 .66224 L

s

.5 .68605 m

.50375 .68605 L

s

.5 .70986 m

.50375 .70986 L

s

.5 .73367 m

.50375 .73367 L

s

.5 .78129 m

.50375 .78129 L

s

.5 .8051 m

.50375 .8051 L

s

.5 .8289 m

.50375 .8289 L

s

.5 .85271 m

.50375 .85271 L

s

.5 .01938 m

.50375 .01938 L

s

.5 .90033 m

.50375 .90033 L

s

.5 .92414 m

.50375 .92414 L

s

.25 Mabswid

.5 0 m

.5 .939 L

s

gsave

.5 .964 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .9515 -195.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.64) show

293.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

298.000000 15.000000 moveto

(L) show

305.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

312.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

319.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

324.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

328.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .939 L

0 .939 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .25042 m

.02576 .2504 L

.03158 .25036 L

.04117 .25027 L

.05437 .25016 L

.07095 .25 L

.09062 .2498 L

.11305 .24955 L

.13786 .24926 L

.16462 .2489 L

.19287 .24847 L

.22214 .24795 L

.25191 .24735 L

.28168 .24664 L

.31095 .24581 L

.3392 .24484 L

.36596 .24373 L

.39077 .24248 L

.4132 .2411 L

.43288 .23966 L

.44945 .23821 L

.46265 .23689 L

.47224 .2358 L

.47806 .23509 L

.48001 .23484 L

s

.48001 .23484 m

.48214 .23457 L

.48847 .23371 L

.4989 .23215 L

.51325 .2297 L

.53128 .22602 L

.55268 .22062 L

.57707 .21291 L

.60406 .20242 L

.63316 .18916 L

.66389 .17376 L

.69572 .15713 L

.7281 .14009 L

.76048 .12328 L

.79231 .10713 L

.82304 .09195 L

.85215 .07796 L

.87913 .06533 L

.90353 .05417 L

.92492 .04459 L

.94295 .03666 L

.95731 .03043 L

.96774 .02596 L

.97407 .02326 L

.97619 .02236 L

s

.48001 .48302 m

.48214 .45565 L

.48847 .42872 L

.4989 .40257 L

.51325 .37757 L

.53128 .35419 L

.55268 .33306 L

.57707 .3149 L

.60406 .3003 L

.63316 .28937 L

.66389 .28158 L

.69572 .27615 L

.7281 .27234 L

.76048 .26962 L

.79231 .26763 L

.82304 .26615 L

.85215 .26503 L

.87913 .26417 L

.90353 .26351 L

.92492 .263 L

.94295 .26262 L

.95731 .26234 L

.96774 .26215 L

.97407 .26204 L

.97619 .262 L

s

.48001 .48314 m

.48214 .51079 L

.48847 .53858 L

.4989 .56628 L

.51325 .59373 L

.53128 .62079 L

.55268 .64732 L

.57707 .67319 L

.60406 .69828 L

.63316 .72247 L

.66389 .74565 L

.69572 .76771 L

.7281 .78856 L

.76048 .8081 L

.79231 .82624 L

.82304 .8429 L

.85215 .85801 L

.87913 .8715 L

.90353 .88332 L

.92492 .89341 L

.94295 .90172 L

.95731 .90823 L

.96774 .91289 L

.97407 .9157 L

.97619 .91664 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<00`0C4`1`4`00oa=B4`0301<C070C001T4`D0j1<00`0C4`1`4`00IQ<00`0C4`3X4`80

LA<004HC00<=4a<05a<300<C00<04a<00Q<20>@C00<04a<0E1<23AXC00164`033A<C01dC00<04a<0

0Q<00`0C4`3S4`0301<C054C0`dL4`00Aa<00`dC4`0L4`0301<C008C00<04a<0dQ<5008C00<04a<0

0Q<00`0C4`024`0301<C04lC0PdO4`00Aa<00`dC4`0K4`8011<00`0C4`3D4`0301<C00HC00<04`00

0a<00`0C4`1=4`8=8A<004PC00<=4a<081<20<lC0`034`0301<C00PC00@04a<C0P1=4`033A<C024C

00184`033A<C020C00<04a<0e1<00`0C4`064`8011<00`0C4`1:4`8=91<004TC00<=4a<07a<00`0C

4`3D4`0301<C00HC00<04a<00a<00`0C4`174`<=9Q<004XC00<=4a<07Q<00`0C4`3C4`8021<300<C

00<04a<0AA<23BTC001:4`033A<C01hC0P3T4`80@a<33B/C001;4`033A<C01dC00<04a<0ha<00`0C

4`104`8=;Q<004`C00<=4a<071<00`0C4`3S4`0301<C03hC0Pd`4`00C1<00`dC4`0L4`0301<C0><C

00<04a<0?1<23C8C001=4`033A<C01/C0P3T4`80>a<23C@C001=4`033A<C01/C00<04a<0ha<00`0C

4`0h4`8==Q<004hC00<=4a<06Q<00`0C4`3S4`0301<C03DC0`dh4`00Ca<00`dC4`0I4`0301<C0><C

00<04a<0<a<23C/C001?4`033A<C01TC0P3T4`0301<C034C0Pdm4`00D1<00`dC4`0H4`0301<C0><C

0P0`4`8=?a<0054C00<=4a<021<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`3S4`0301<C02dC

0Pe14`00DA<00`dC4`074`0301<000LC00<04`000a<00`0C4`3S4`0301<C02/C0Pe34`00DQ<010dC

4a<3008C00<04`002A<0100C4a<20>@C00<04a<0:A<23DDC001C4`033A<C00DC00<04`001a<200@C

00<04a<0ha<202PC0Pe74`00Da<00`dC4`054`0301<000LC00<04a<00a<00`0C4`3S4`0301<C02DC

0Pe94`00E1<00`dC4`054`0301<C00HC0`034`0301<C0><C00<04a<091<00`dC4`194`00E1<00`dC

4`0D4`0301<C0=`C1@024`0301<C028C0Pe<4`00EA<00`dC4`0C4`80ga<00`0C4`024`0301<C024C

00<=4a<0C1<005HC00<=4a<04Q<00`0C4`3H4`<00a<00`0C4`024`8081<23DlC001F4`033A<C018C

00<04a<0gQ<00`0C4`024`0301<C01dC0PeA4`00Ea<00`dC4`0A4`0301<C0=hC00<04a<00Q<00`0C

4`0K4`8=Da<005PC00<=4a<041<20=hC0P044`0301<C01TC0PeE4`00F1<00`dC4`0@4`0301<C0><C

0P0H4`8=Ea<001XC0`0U4`D04Q<00`dC4`0?4`0301<C02@C1@0T4`<0Ta<00`0C4`0E4`8=FA<001XC

00<04a<09a<00`0C4`0B4`033A<C00lC00<04a<09Q<00`0C4`0T4`0301<C09<C00<04a<04Q<33E/C

000E4`<00a<00`0C4`0P4`<00a<00`0C4`0C4`033A<C00hC0P0W4`0301<C02DC00<04a<0TQ<00`0C

4`0?4`<=GQ<001/C00<04a<09Q<00`0C4`0C4`033A<C00hC00<04a<09Q<00`0C4`0U4`0301<C098C

0P0>4`8=HA<001XC00<04`009a<00`0C4`0D4`033A<C00dC00<04a<09Q<00`0C4`0T4`0301<009<C

00<04a<02Q<33F<C000K4`0301<C02DC0P0G4`033A<C00`C00<04a<09A<202LC00<04a<0TQ<00`0C

4`064`@=IQ<005`C00<=4a<031<20>@C00<04a<00Q<43FXC001M4`033A<C00/C00<04a<0ha<53FhC

001M4`033A<C00/C00<04a<0Fa<207lC1`d2074C001N4`033A<C00XC00<04a<0FQ<00`0C4`1`4`l=

1a<00`0C4`1`4`005A=:00033@0006001Q<00`0C4`1;4bD=5Q<00`0C4`1`4`006A<00`0C4`064`03

01<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00D04a<C

3@034`0301<C00DC00<@4a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00DC

00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`084`0301<C02hC7@dk4`0301<C070C

001P4`033A<C00PC00<@4a<0FQ<00`0C00264`80LA<0064C00<=4a<01a<245/C0`264`0301<C044C

5@dJ4`00HA<00`dC4`074`8@i1<00`0C4`0[4aH=;a<0068C00<=4a<01A<00a00403E4`0301<C008C

00<04a<00Q<00`0C4`024`0301<C02DC1Pe54`00HQ<00`dC4`054`03400@0=@C00<04`001a<00`0C

00034`0301<C01lC1Pe;4`00Ha<00`dC4`044`03400@0<lC0`024`0301<000TC00@04a<C0P0J4`H=

DA<006@C00<=4a<00Q<01A0C000@0=<C00<04`001a<200@C00<04a<05A<43ELC001T4`033A<C008C

00D@4`0C403C4`0301<000LC00<04a<00a<00`0C4`0B4`<=Fa<006DC00T=4a<C41<04a00e1<00`0C

4`064`<00a<00`0C4`0@4`8=GQ<006HC00H=4a<@4`024`0341<C0>0C0P0?4`8=H1<006HC00D=4a<@

4`0200034a0C0>4C00<04a<031<23F8C001W4`053A<@4`000Q<00a0C4`3P4`0301<C00/C00<=4a<0

HQ<006LC00D=41<C00034`0341<C0=lC00<04a<02Q<00`dC4`1S4`00J1<010dC4`034`0341<C0=lC

0P094`8=IQ<006PC00<@3A<00P024`0341<C0=lC00<04a<01a<00`dC4`1V4`00Ia<01A0C3A<000@C

00<@4a<0gQ<00`0C4`064`033A<C06LC001L4`0301<C008C00<04a<00Q<01P0@4a<=00@C00<@4a<0

Qa<302PC1@0W4`0301<C00DC00<=4a<07a<502PC0`0I4`00Fa<00`0C00074`030100008C00<=01<0

0a<00a0C4`274`0301<C02XC00<04a<09a<00`0C4`044`033A<C028C00<04a<0:1<00`0C4`0I4`00

Fa<00`0C00084`03400C008C00<=01<00a<00a0C4`214`<00a<00`0C4`0S4`<00a<00`0C4`0W4`80

11<00`dC4`0S4`0301<C02TC00<04a<061<005/C00<04`001a<00`0@4`034`0300dC00<C00<@4a<0

Qa<00`0C4`0Y4`0301<C02LC00<04a<00Q<00`dC4`0T4`0301<C02TC00<04a<061<005/C00<04`00

1a<00a0C4`034`0300dC00@C00<@4a<0QA<00`0C000Z4`0301<C02LC00D04a<C3@0W4`0301<C02PC

00<04`006A<005`C00<04a<01Q<00a0000034`0301<=00@C00<@4a<0QQ<00`0C4`0X4`80:A<01@0C

4a<=02HC0P0[4`0301<C01PC001T4`0341<C00@C0P000`dC4`024`0341<C0=`C0P000a<=4`1^4`00

I1<00a0C4`044`0401<C3@@C00<@4a<0fa<00`0C3@1`4`00Ha<00a0C4`054`0401<C3@@C00<@4a<0

fa<00`0C3@1`4`00Ha<00a0C4`054`0501<C4`d011<00a0C4`3J4`0300dC068C0P0<4`00HQ<00a0C

4`064`0301<C008C00D=4a<C403L4`0300dC064C00<04a<031<0068C00<@4a<01Q<200<C00<=4a<0

0Q<00a0C4`1m4e`000<=0000FP074`0301<C00`C001Q4`0341<C00LC00<04a<00a<01@dC4a<@08<C

00<04a<0:A<00`0C4`0Y4`033A<C02TC00<04a<0:A<00`0C4`094`0301<C00`C001Q4`0341<C00LC

00<04a<00a<01@dC4a<@0=XC00<=01<0HQ<00`0C000<4`00H1<00a0C4`084`0301<C00@C00D=4a<C

403I4`033@0C068C0`0<4`00H1<00a0C4`084`801Q<010dC4a3H4`043A<0074C001O4`0341<C00TC

00<04a<01A<01@dC4a<@0=LC00<=4`00LQ<005lC00<@4a<02A<00`0C4`064`043A<C4=LC00<=4`00

LQ<005hC00<@4a<02Q<00`0C4`074`043A<C4=HC00<=4`00LQ<005hC00<@4a<02Q<200PC00@=4a<@

eA<00`dC4`02074C001M4`0341<C00/C00<04a<021<010dC4a3D4`043A<C078C001M4`0341<C00@C

1@024`0301<C00TC00<=4a00e1<010dC4`1b4`00G1<00a0C4`074`0301<C008C00<04a<02Q<00`dC

403C4`043A<C078C001K4`0341<C00PC00<04a<00Q<200/C00@=4a<@dQ<010dC4`1b4`00Fa<00a0C

4`084`0301<C008C00<04a<02a<00`dC403A4`043A<C4`80LA<005XC00<@4a<02A<00`0C4`024`03

01<C00`C00<=4a00d1<01@dC4a<0078C001J4`0341<C00PC0P044`0301<C00`C00@=4a<@ca<01@dC

4a<0078C001I4`0341<C00lC0P0>4`033A<@0<lC00D=4a<C001b4`00F1<00a0C4`0@4`0301<C00dC

00@=4a<@cQ<010dC4a<2074C001H4`0341<C010C00<04a<03Q<010dC4a3>4`043A<C078C001G4`03

41<C014C00<04a<03Q<010dC4a3>4`043A<C078C001F4`0341<C018C0P0@4`043A<C4<4C00<04a<0

0Q<00`0C4`024`0301<=008C00<04a<0L1<005HC00<@4a<04Q<00`0C4`0@4`043A<C4;lC00<04`00

1a<0100C00d24`0301<C070C001E4`0341<C01<C00<04a<041<010dC4a2o4`0301<000TC00@03A<C

0P1a4`00E1<00a0C4`0D4`0301<C014C00@=4a<@_Q<00`0C00074`800Q<00`dC001b4`00Da<00a0C

4`0E4`804Q<010dC4a2n4`0301<000LC00L04a<C3A<0078C001C4`0341<C01DC00<04a<04Q<010dC

4a2n4`0301<C00HC0`0011<=4`1b4`00DQ<00a0C4`0F4`0301<C01<C00@=4a<@bQ<010dC001a4`00

DA<00a0C4`0G4`0301<C01<C00@=4a<@ba<00`d04`1a4`00DA<00a0C4`0G4`805A<010dC4a3:4`03

3@0C074C001@4`0341<C01PC00<04a<05A<00`dC403;4`033A<C070C001?4`0341<C00PC1@024`03

01<C008C00<04a<00Q<00`0C4`0E4`043A<C4<XC00<=01<0L1<004lC00<@4a<02Q<00`0C4`064`03

01<000<C00<04a<05Q<010dC4a394`0300dC070C001>4`0341<C00/C00<04a<021<0100C4a<201LC

00D=4a<C40384`0300dC070C001=4`0341<C00`C00<04a<01Q<200@C00<04a<05a<010dC4a384`03

01<=070C001<4`0341<C00dC00<04a<01Q<00`0C4`034`0301<C01PC00@=4a<@aa<00`0C3@1`4`00

C1<00a0C4`0<4`8021<300<C00<04a<061<01@dC4a<@0<HC0P000a<=4`1^4`00Ba<00a0C4`0M4`80

6Q<01@dC4a<@0<DC00D04a<C3@1^4`00BQ<00a0C4`0N4`0301<C01XC00@=4a<@aA<01@0C4a<=06hC

001:4`0341<C01hC00<04a<06Q<01@dC4a<@0<@C00<04a<00Q<00`dC4`1[4`00BA<00a0C4`0O4`03

01<C01/C00D=4a<C40334`800a<00`dC4`1[4`00B1<00a0C4`0P4`8071<00`dC4`024`0341<C0<0C

00<04a<00a<00`dC4`1Z4`00Aa<00a0C4`0Q4`0301<C01`C00<=4a<00Q<00a0C4`2o4`0301<C00@C

00<=4a<0JA<004LC00<@4a<08A<00`0C4`0L4`033A<C008C00<@4a<0^1<5008C00<04a<01A<00`dC

4`1X4`00AQ<00a0C4`0R4`0301<C01dC00<=4a<00Q<00a0C4`2i4`0301<C008C00<04a<01A<00`dC

4`1X4`00AA<00a0C4`0S4`807Q<00`dC4`034`0341<C0;PC00<04a<00Q<200LC00<=4a<0Ia<004@C

00<@4a<091<00`0C4`0N4`033A<C00<C00<@4a<0]a<00`0C4`024`0301<C00LC00<=4a<0IQ<004@C

00<@4a<091<00`0C4`0N4`033A<C00<C00<@4a<0]a<00`0C4`024`0301<C00PC00<=4a<0IA<004<C

00<@4a<09A<00`0C4`0O4`033A<C00<C00<@4a<0]A<200@C00<04a<02A<00`dC4`1T4`00@Q<00a0C

4`0V4`0301<C020C00<=4a<00a<00a0C4`2j4`802Q<00`dC4`1T4`00@A<00a0C4`0W4`808A<00`dC

4`044`0341<C0;TC00<04a<02Q<00`dC4`1S4`00@1<00a0C4`0X4`0301<C024C00<=4a<011<00a0C

4`2h4`0301<C00/C00<=4a<0HQ<0040C00<@4a<08Q<300<C00<04a<08Q<00`dC4`044`0341<C0;LC

00<04a<031<00`dC4`1Q4`00?a<00a0C4`0S4`0301<C00<C00<04a<08Q<00`dC4`044`0341<C0;LC

0P0>4`033A<C060C000n4`0341<C02DC00<04a<00Q<202@C00<=4a<011<00a0C4`2f4`0301<C00hC

00<=4a<0Ga<003dC00<@4a<09Q<00`0C4`024`0301<C02<C00<=4a<01A<00a0C4`2e4`0301<C00lC

00<=4a<0GQ<003dC00<@4a<09A<00`0C00034`0301<C02@C00<=4a<01A<00a0C4`2d4`0301<C010C

00<=4a<0GA<003`C00<@4a<09a<00`0C4`024`0301<C02DC00<=4a<01A<00a0C4`2c4`0301<C014C

0PeM4`00>a<00a0C4`0]4`809Q<00`dC4`064`0341<C0;8C0P0D4`033A<C05XC000j4`0341<C02hC

00<04a<09Q<00`dC4`054`0341<C0;8C00<04a<051<23EXC000j4`0341<C02hC00<04a<09a<00`dC

4`054`0341<C0;4C00<04a<05Q<00`dC4`1G4`00>A<00a0C4`0_4`0301<C02LC00<=4a<01Q<00a0C

4`2`4`0301<C01LC00<=4a<0EQ<003PC00<@4a<0<1<202TC00<=4a<01Q<00a0C4`2_4`806A<23EHC

000g4`0341<C034C00<04a<0:A<00`dC4`054`0341<C0:lC00<04a<06Q<00`dC4`1C4`00=a<00a0C

4`0a4`0301<C02TC00<=4a<01Q<00a0C4`2^4`0301<C01/C00<=4a<0DQ<003HC00<@4a<0<Q<00`0C

4`0Z4`033A<C00HC00<@4a<0W1<5008C00<04a<00Q<00`0C4`024`0301<C01`C0PeB4`00=A<00a0C

4`0c4`80:a<00`dC4`074`0341<C09dC00<04a<01Q<00`0C00034`0301<C01hC00<=4a<0Ca<003@C

00<@4a<0=1<00`0C4`0[4`033A<C00LC00<@4a<0W1<00`0C4`084`0401<C4`8081<23DlC000c4`03

41<C03DC00<04a<0;1<00`dC4`074`0341<C09/C00<04a<01Q<200@C00<04a<08A<00`dC4`1<4`00

<Q<00a0C4`0f4`0301<C02`C00<=4a<01a<00a0C4`2K4`0301<C00HC00<04a<00a<00`0C4`0R4`8=

C1<0034C00<@4a<0=a<202hC00<=4a<01a<00a0C4`2I4`8021<300<C00<04a<091<00`dC4`194`00

<1<00a0C4`0h4`0301<C02hC00<=4a<01a<00a0C4`2X4`809Q<23DTC000_4`0341<C02TC0`034`03

01<C008C00<04a<00Q<00`0C4`0^4`033A<C00PC00<@4a<0Ya<00`0C4`0W4`033A<C04HC000^4`03

41<C02XC00<04a<01a<00`0C00034`0301<C02lC00<=4a<021<00a0C4`2V4`0301<C02PC0Pe64`00

;A<00a0C4`0/4`0301<C00PC00@04a<C0P0`4`033A<C00TC00<@4a<0YA<00`0C4`0Z4`033A<C04<C

000/4`0341<C02dC00<04a<01Q<200@C00<04a<0<1<00`dC4`094`0341<C0:@C0P0/4`8=@a<002/C

00<@4a<0;A<00`0C00074`0301<C00<C00<04a<0<1<00`dC4`0:4`0341<C0:<C00<04a<0;A<00`dC

4`104`00:Q<00a0C4`0_4`0301<C00HC0`034`0301<C034C00<=4a<02Q<00a0C4`2R4`0301<C02hC

0Pe04`00:A<00a0C4`0o4`80<a<00`dC4`0:4`0341<C0:4C00<04a<0<1<23ChC000X4`0341<C040C

00<04a<0<Q<00`dC4`0;4`0341<C0:0C00<04a<0<Q<23C`C000W4`0341<C044C00<04a<0<a<00`dC

4`0;4`0341<C09lC0P0e4`8=>Q<002HC00<@4a<0@Q<00`0C4`0c4`033A<C00`C00<@4a<0WQ<00`0C

4`0f4`8=>1<002DC00<@4a<0@a<203DC00<=4a<031<00a0C4`2M4`0301<C03PC0Pdf4`0091<00a0C

4`144`0301<C03DC00<=4a<031<00a0C4`2L4`0301<C03XC0Pdd4`008a<00a0C4`154`0301<C03DC

00<=4a<03A<00a0C4`2K4`80?A<23C8C000S4`0341<C04DC00<04a<0=Q<00`dC4`0=4`0341<C09XC

00<04a<0?Q<00`dC4`0_4`008Q<00a0C4`164`80>1<00`dC4`0=4`0341<C09TC00<04a<0?a<23BlC

000Q4`0341<C04LC00<04a<0=a<00`dC4`0>4`0341<C098C0`034`0301<C044C0Pd]4`0081<00a0C

4`184`0301<C03PC00<=4a<03Q<00a0C4`2A4`0301<C00<C00<04a<0@a<23B/C000O4`0341<C04TC

00<04a<0>1<00`dC4`0?4`0341<C094C00<04a<00Q<204HC0PdY4`007Q<00a0C4`1:4`80>Q<00`dC

4`0?4`0341<C090C00<04a<00Q<00`0C4`174`8=9a<001dC00<@4a<0Ba<00`0C4`0j4`033A<C00lC

00<@4a<0SQ<00`0C00034`0301<C04TC0PdU4`0071<00a0C4`1<4`0301<C03XC00<=4a<041<00a0C

4`2>4`0301<C008C00<04a<0Ba<33B8C000K4`0341<C04LC0P044`0301<C03/C00<=4a<041<00a0C

4`2B4`80Ca<33AlC000J4`0341<C04XC00D04a<C000m4`033A<C014C00<@4a<0TA<00`0C4`1A4`8=

7A<001TC00<@4a<0BQ<00`0C4`024`80?1<00`dC4`0A4`0341<C094C00<04a<0Da<23A/C001W4`03

01<C0>LC00<04a<0EA<00`dC4`0H4`00IA<00`0C003Y4`80LA<006HC00<04a<0j1<00`0C4`1`4`00

;1<30?lC8a<00`0C4`1`4`00;1<00`0C4`3o4b<C00<04a<0L1<002dC00<04a<01A<00`0C4`3o4hdC

000]4`0401<C4`<000@C01<C0`3o4hXC000/4`0301<0008C0P024`0301<C008C00<04a<0oa>84`00

;A<00`0C4`034`0401<C008C00<04a<0oa>94`00<a<0100C4`034`0301<C00HC00<04a<09A<302dC

00<04a<0oa<W4`007A<300034`00008031<300@C0`084`0301<C02@C00@04a<04A<300034`000080

0Q<00`0C4`024`0301<C008C00<04a<01A<0100C4a<5008C00@04a<C0P044`<011<20</C00<04a<0

<Q<00`0C4`084`0071<0100C4`0T4`0301<C02<C00@04a<041<0100C4`064`0301<000LC00<04`00

11<500<C00<04a<01Q<00`0C00044`0301<C008C00<04a<0`a<00`0C4`044`0301<C01<C00<04a<0

7Q<00`0C4`074`0071<01@0C4`0C00@000<C0000600[4`<041<01@0C4`0C00@000@C01<02A<00`0C

4`044`0301<C00<C00<04a<01Q<00`0C00024`@00a<00`0C4`2a4`0401<C4`@00Q<200HC00<04a<0

0a<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`054`0401<C4`D00Q<0100C4a<200@C0`044`80

11<0100C4a<2004C0@0100007A<304dC00<04a<03a<300HC00<04`001a<200LC00<04a<00a<00`0C

4`064`800a<00`0C00044`0301<C0;0C00<04`001a<00`0C4`044`D00a<01`0C4a<04`001a<00`0C

00044`D00a<00`0C4`064`0301<000@C00<04a<00Q<00`0C4`044`0301<C008C00<04`000A<001lC

00<04a<0BQ<201<C00<04a<011<00`0C00074`0301<C00`C00<04a<01Q<00`0C4`034`8011<00`0C

002`4`0301<0008C10000a<04`074`0301<C00<C00L04a<C01<000TC00<04a<011<00`0C4`034`03

01<C00HC00<04`000Q<400<C00<04a<011<00`0C4`034`400A<14`007Q<2060C0P074`0301<C00HC

0`0;4`802A<200@C00<04a<00Q<309HC0P000a<0000E4`0301<000LC00<04a<01Q<00`0C4`034`07

01<C4`0C00074`801a<00`0C4`034`0301<C00HC0P034`0301<000@C00<04a<011<00`0C4`034`40

0A<14`00oa=A4`0301<001HC00<04`001a<00`0C000=4`0601<C01<01a<00`0C4`0<4`0301<C00HC

00<04a<00a<200@C00<04`000a<00`0C4`034`0301<0004C000Y4`801Q<20?lC7a<00`0C4`0F4`03

01<C00HC0`0>4`0401<C00PC0`0;4`802A<200@C00<04a<00Q<3008C00<04a<00a<2004C0@010000

:a<00`0C4`024`0301<C0?lC7a<00`0C4`1`4`00:Q<00`0C4`034`0301<C00DC00<04a<0oa<F4`03

01<0074C000[4`0301<C008C00<04a<00Q<400<C0`3o4a4C0P000a<0001`4`00:A<00`0C00044`03

01<0008C0P000a<04`044`0301<C0?lCQ1<002XC00<04a<00a<300@C00<04`000a<00`0C4`3o4hDC

000g4`0301<000@C00<04a<0oa>44`00=A<300@C0`3o4hHC003o4lDC003o4lDC003o4lDC003o4lDC

003o4lDC0000\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.67363, -1.79223, 0.0227304, 0.0227304}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -84.5 0 ]

[.5 .96488 84.5 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -145.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.635) show

222.250000 19.500000 moveto

(C) show

227.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.28156 0 m

.30316 .0353 L

.34309 .10059 L

.3815 .16339 L

.42237 .23021 L

.46172 .29455 L

.49955 .35641 L

.53984 .42228 L

.57861 .48567 L

.61984 .55307 L

.65954 .618 L

.69774 .68044 L

.73838 .7469 L

.77751 .81088 L

.81909 .87886 L

.85916 .94437 L

s

.85916 .94437 m

.86406 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.399293 0.238095 [

[.02381 .38679 -6 -9 ]

[.02381 .38679 6 0 ]

[.2619 .38679 -6 -9 ]

[.2619 .38679 6 0 ]

[.7381 .38679 -3 -9 ]

[.7381 .38679 3 0 ]

[.97619 .38679 -3 -9 ]

[.97619 .38679 3 0 ]

[1.025 .39929 0 -8 ]

[1.025 .39929 9 8 ]

[.4875 .04215 -24 -4.5 ]

[.4875 .04215 0 4.5 ]

[.4875 .1612 -12 -4.5 ]

[.4875 .1612 0 4.5 ]

[.4875 .28025 -24 -4.5 ]

[.4875 .28025 0 4.5 ]

[.4875 .51834 -18 -4.5 ]

[.4875 .51834 0 4.5 ]

[.4875 .63739 -6 -4.5 ]

[.4875 .63739 0 4.5 ]

[.4875 .75644 -18 -4.5 ]

[.4875 .75644 0 4.5 ]

[.4875 .87548 -6 -4.5 ]

[.4875 .87548 0 4.5 ]

[.5 .96242 -4.5 0 ]

[.5 .96242 4.5 16 ]

[.5 .94992 -137 0 ]

[.5 .94992 137 16 ]

[ 0 0 0 0 ]

[ 1 .93742 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .39929 m

.02381 .40554 L

s

[(-2)] .02381 .38679 0 1 Mshowa

.2619 .39929 m

.2619 .40554 L

s

[(-1)] .2619 .38679 0 1 Mshowa

.7381 .39929 m

.7381 .40554 L

s

[(1)] .7381 .38679 0 1 Mshowa

.97619 .39929 m

.97619 .40554 L

s

[(2)] .97619 .38679 0 1 Mshowa

.125 Mabswid

.07143 .39929 m

.07143 .40304 L

s

.11905 .39929 m

.11905 .40304 L

s

.16667 .39929 m

.16667 .40304 L

s

.21429 .39929 m

.21429 .40304 L

s

.30952 .39929 m

.30952 .40304 L

s

.35714 .39929 m

.35714 .40304 L

s

.40476 .39929 m

.40476 .40304 L

s

.45238 .39929 m

.45238 .40304 L

s

.54762 .39929 m

.54762 .40304 L

s

.59524 .39929 m

.59524 .40304 L

s

.64286 .39929 m

.64286 .40304 L

s

.69048 .39929 m

.69048 .40304 L

s

.78571 .39929 m

.78571 .40304 L

s

.83333 .39929 m

.83333 .40304 L

s

.88095 .39929 m

.88095 .40304 L

s

.92857 .39929 m

.92857 .40304 L

s

.25 Mabswid

0 .39929 m

1 .39929 L

s

gsave

1.025 .39929 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .04215 m

.50625 .04215 L

s

[(-1.5)] .4875 .04215 1 0 Mshowa

.5 .1612 m

.50625 .1612 L

s

[(-1)] .4875 .1612 1 0 Mshowa

.5 .28025 m

.50625 .28025 L

s

[(-0.5)] .4875 .28025 1 0 Mshowa

.5 .51834 m

.50625 .51834 L

s

[(0.5)] .4875 .51834 1 0 Mshowa

.5 .63739 m

.50625 .63739 L

s

[(1)] .4875 .63739 1 0 Mshowa

.5 .75644 m

.50625 .75644 L

s

[(1.5)] .4875 .75644 1 0 Mshowa

.5 .87548 m

.50625 .87548 L

s

[(2)] .4875 .87548 1 0 Mshowa

.125 Mabswid

.5 .06596 m

.50375 .06596 L

s

.5 .08977 m

.50375 .08977 L

s

.5 .11358 m

.50375 .11358 L

s

.5 .13739 m

.50375 .13739 L

s

.5 .18501 m

.50375 .18501 L

s

.5 .20882 m

.50375 .20882 L

s

.5 .23263 m

.50375 .23263 L

s

.5 .25644 m

.50375 .25644 L

s

.5 .30406 m

.50375 .30406 L

s

.5 .32786 m

.50375 .32786 L

s

.5 .35167 m

.50375 .35167 L

s

.5 .37548 m

.50375 .37548 L

s

.5 .4231 m

.50375 .4231 L

s

.5 .44691 m

.50375 .44691 L

s

.5 .47072 m

.50375 .47072 L

s

.5 .49453 m

.50375 .49453 L

s

.5 .54215 m

.50375 .54215 L

s

.5 .56596 m

.50375 .56596 L

s

.5 .58977 m

.50375 .58977 L

s

.5 .61358 m

.50375 .61358 L

s

.5 .6612 m

.50375 .6612 L

s

.5 .68501 m

.50375 .68501 L

s

.5 .70882 m

.50375 .70882 L

s

.5 .73263 m

.50375 .73263 L

s

.5 .78025 m

.50375 .78025 L

s

.5 .80406 m

.50375 .80406 L

s

.5 .82786 m

.50375 .82786 L

s

.5 .85167 m

.50375 .85167 L

s

.5 .01834 m

.50375 .01834 L

s

.5 .89929 m

.50375 .89929 L

s

.5 .9231 m

.50375 .9231 L

s

.25 Mabswid

.5 0 m

.5 .93742 L

s

gsave

.5 .96242 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .94992 -198 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.635) show

298.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

303.000000 15.000000 moveto

(L) show

310.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

317.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

324.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

329.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

333.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .93742 L

0 .93742 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .249 m

.02576 .24899 L

.03158 .24894 L

.04117 .24886 L

.05437 .24874 L

.07094 .24859 L

.09062 .24839 L

.11305 .24815 L

.13785 .24786 L

.16461 .2475 L

.19287 .24708 L

.22213 .24658 L

.2519 .24598 L

.28167 .24529 L

.31093 .24447 L

.33919 .24352 L

.36595 .24243 L

.39075 .24121 L

.41318 .23986 L

.43286 .23845 L

.44943 .23704 L

.46263 .23574 L

.47222 .23468 L

.47804 .23399 L

.47999 .23374 L

s

.47999 .23374 m

.48211 .23347 L

.48844 .23263 L

.49888 .23111 L

.51323 .22871 L

.53126 .22511 L

.55266 .21982 L

.57706 .21224 L

.60404 .20189 L

.63315 .18876 L

.66388 .17345 L

.69571 .15688 L

.72809 .13989 L

.76047 .12311 L

.7923 .10698 L

.82303 .09182 L

.85214 .07785 L

.87912 .06523 L

.90352 .05409 L

.92492 .04452 L

.94295 .0366 L

.9573 .03038 L

.96774 .02591 L

.97407 .02322 L

.97619 .02232 L

s

.47999 .48201 m

.48211 .45465 L

.48844 .42773 L

.49888 .40158 L

.51323 .37655 L

.53126 .35312 L

.55266 .33191 L

.57706 .31365 L

.60404 .29895 L

.63315 .28792 L

.66388 .28008 L

.69571 .27462 L

.72809 .27079 L

.76047 .26807 L

.7923 .26608 L

.82303 .2646 L

.85214 .26348 L

.87912 .26262 L

.90352 .26196 L

.92492 .26146 L

.94295 .26108 L

.9573 .2608 L

.96774 .26061 L

.97407 .2605 L

.97619 .26046 L

s

.47999 .48213 m

.48211 .50976 L

.48844 .53752 L

.49888 .56519 L

.51323 .59262 L

.53126 .61965 L

.55266 .64615 L

.57706 .67199 L

.60404 .69704 L

.63315 .7212 L

.66388 .74435 L

.69571 .76638 L

.72809 .7872 L

.76047 .80671 L

.7923 .82482 L

.82303 .84146 L

.85214 .85655 L

.87912 .87003 L

.90352 .88183 L

.92492 .8919 L

.94295 .9002 L

.9573 .9067 L

.96774 .91136 L

.97407 .91416 L

.97619 .9151 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<00`0C4`1`4`00oa=B4`0301<C070C001T4`D0j1<00`0C4`1`4`00IQ<00`0C4`3X4`80

LA<004HC00<=4a<05a<300<C00<04a<00Q<20>@C00<04a<0E1<23AXC00164`033A<C01dC00<04a<0

0Q<00`0C4`3B4`D00Q<00`0C4`024`0301<C008C00<04a<0DA<33A`C00174`033A<C01`C00<04a<0

0Q<00`0C4`3D4`0301<C00HC00<04`000a<00`0C4`1?4`8=7a<004LC00<=4a<06a<200@C00<04a<0

cQ<300<C00<04a<021<0100C4a<204hC0PdQ4`00B1<00`dC4`0P4`80eA<00`0C4`064`8011<00`0C

4`1<4`033A<C024C00184`033A<C020C00<04a<0e1<00`0C4`064`0301<C00<C00<04a<0BQ<23B@C

00194`033A<C01lC00<04a<0da<200PC0`034`0301<C04LC0`dV4`00BQ<00`dC4`0N4`0301<C0><C

00<04a<0AA<23BTC001:4`033A<C01hC0P3T4`80@a<33B/C001;4`033A<C01dC00<04a<0ha<00`0C

4`104`8=;Q<004`C00<=4a<071<00`0C4`3S4`0301<C03hC0Pd`4`00C1<00`dC4`0L4`0301<C0><C

00<04a<0?1<23C8C001=4`033A<C01/C0P3T4`80>a<23C@C001=4`033A<C01/C00<04a<0ha<00`0C

4`0h4`8==Q<004hC00<=4a<06Q<00`0C4`3S4`0301<C03DC0`dh4`00Ca<00`dC4`0I4`0301<C0><C

00<04a<0<a<23C/C001?4`033A<C01TC0P3T4`0301<C034C0Pdm4`00D1<00`dC4`0H4`0301<C0><C

0P0`4`8=?a<0054C00<=4a<021<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`3S4`0301<C02dC

0Pe14`00DA<00`dC4`074`0301<000LC00<04`000a<00`0C4`3S4`0301<C02/C0Pe34`00DQ<010dC

4a<3008C00<04`002A<0100C4a<20>@C00<04a<0:A<23DDC001C4`033A<C00DC00<04`001a<200@C

00<04a<0ha<202PC0Pe74`00Da<00`dC4`054`0301<000LC00<04a<00a<00`0C4`3S4`0301<C02DC

0Pe94`00E1<00`dC4`054`0301<C00HC0`034`0301<C0=`C1@024`0301<C02@C00<=4a<0BA<005@C

00<=4a<051<00`0C4`3N4`0301<C008C00<04a<08Q<23D`C001E4`033A<C01<C0P3I4`<00a<00`0C

4`024`808Q<00`dC4`1<4`00EQ<00`dC4`0B4`0301<C0=hC00<04a<00Q<00`0C4`0O4`8=Ca<005HC

00<=4a<04Q<00`0C4`3N4`0301<C008C00<04a<07A<23E4C001G4`033A<C014C00<04a<0gA<200@C

00<04a<06Q<33E<C001H4`033A<C010C0P3T4`0301<C01PC0PeF4`00F1<00`dC4`0@4`0301<C0><C

0P0G4`8=F1<001XC0`0U4`D04Q<00`dC4`0?4`0301<C02@C1@0T4`<0Ta<00`0C4`0D4`8=FQ<001XC

00<04a<09a<00`0C4`0B4`033A<C00lC00<04a<09Q<00`0C4`0T4`0301<C09<C00<04a<04Q<23E`C

000E4`<00a<00`0C4`0P4`<00a<00`0C4`0C4`033A<C00hC0P0W4`0301<C02DC00<04a<0TQ<00`0C

4`0?4`<=GQ<001/C00<04a<09Q<00`0C4`0C4`033A<C00hC00<04a<09Q<00`0C4`0U4`0301<C098C

0P0>4`8=HA<001XC00<04`009a<00`0C4`0D4`033A<C00dC00<04a<09Q<00`0C4`0T4`0301<009<C

00<04a<02Q<33F<C000K4`0301<C02DC0P0G4`033A<C00`C00<04a<09A<202LC00<04a<0TQ<00`0C

4`064`@=IQ<005`C00<=4a<031<20>@C00<04a<00Q<43FXC001M4`033A<C00/C00<04a<0ha<53FhC

001M4`033A<C00/C00<04a<0Fa<207`C2Pd2074C001N4`033A<C00XC00<04a<0FQ<00`0C4`1[4a4=

2Q<00`0C4`1`4`005A=:00033@0006001Q<00`0C4`0m4bh=6a<00`0C4`1`4`006A<00`0C4`064`03

01<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00D04a<C

3@034`0301<C00DC00<@4a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00DC

00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`084`0301<C02hC3`e94`0301<C070C

001P4`033A<C00PC00<@4a<0FQ<00`0C00264`80LA<0064C00<=4a<01a<245/C0`264`0301<C03`C

6PdJ4`00HA<00`dC4`074`8@eA<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`0[4a4==1<0068C

00<=4a<01A<00a00403D4`0301<000LC00<04`000a<00`0C4`0O4``=AA<0068C00<=4a<01A<00a00

403?4`<00Q<00`0C00094`0401<C4`806a<53E4C001S4`033A<C00@C00<@0100e1<00`0C00074`80

11<00`0C4`0H4`8=EQ<006@C00<=4a<00Q<01A0C000@0=<C00<04`001a<00`0C4`034`0301<C01DC

0`eH4`00I1<00`dC4`024`0541<04a00e1<00`0C4`064`<00a<00`0C4`0B4`<=Fa<006DC00T=4a<C

41<04a00ha<00`0C4`0@4`8=GQ<006HC00H=4a<@4`024`0341<C0>0C0P0?4`8=H1<006HC00D=4a<@

4`0200034a0C0>4C00<04a<031<23F8C001W4`053A<@4`000Q<00a0C4`3P4`0301<C00/C00<=4a<0

HQ<006LC00D=41<C00034`0341<C0=lC00<04a<02Q<00`dC4`1S4`00J1<010dC4`034`0341<C0=lC

0P094`8=IQ<006PC00<@3A<00P024`0341<C0=lC00<04a<01a<00`dC4`1V4`00Ia<01A0C3A<000@C

00<@4a<0gQ<00`0C4`064`033A<C06LC001L4`0301<C008C00<04a<00Q<01P0@4a<=00@C00<@4a<0

Qa<302PC1@0W4`0301<C00DC00<=4a<07a<502PC0`0I4`00Fa<00`0C00074`030100008C00<=01<0

0a<00a0C4`274`0301<C02XC00<04a<09a<00`0C4`044`033A<C028C00<04a<0:1<00`0C4`0I4`00

Fa<00`0C00084`03400C008C00<=01<00a<00a0C4`214`<00a<00`0C4`0S4`<00a<00`0C4`0W4`80

11<00`dC4`0S4`0301<C02TC00<04a<061<005/C00<04`001a<00`0@4`034`0300dC00<C00<@4a<0

Qa<00`0C4`0Y4`0301<C02LC00<04a<00Q<00`dC4`0T4`0301<C02TC00<04a<061<005/C00<04`00

1a<00a0C4`034`0300dC00@C00<@4a<0QA<00`0C000Z4`0301<C02LC00D04a<C3@0W4`0301<C02PC

00<04`006A<005`C00<04a<01Q<00a0000034`0301<=00@C00<@4a<0QQ<00`0C4`0X4`80:A<01@0C

4a<=02HC0P0[4`0301<C01PC001T4`0341<C00@C0P000`dC4`024`0341<C0=`C0P000a<=4`1^4`00

I1<00a0C4`044`0401<C3@@C00<@4a<0fa<00`0C3@1`4`00Ha<00a0C4`054`0401<C3@@C00<@4a<0

fa<00`0C3@1R4`8031<006<C00<@4a<01A<01@0C4a<=00@C00<@4a<0fQ<00`0=4`1Q4`0301<C00`C

001R4`0341<C00HC00<04a<00Q<01@dC4a<@080CG@000`d0001J00HC00<04a<031<0068C00<@4a<0

1Q<200<C00<=4a<00Q<00a0C4`214`0301<C00HC00<04a<01Q<00`0C4`054`0301<C00HC00<04a<0

1Q<00`0C4`064`0301<C00HC00<04a<01A<00`0C4`064`0301<C00HC00<=4a<01Q<00`0C4`064`03

01<C00HC00<04a<01A<00`0C4`064`0301<C00HC00<04a<01Q<00`0C4`064`0301<C00DC00<04a<0

1Q<00`0C4`094`0301<C00`C001Q4`0341<C00LC00<04a<00a<01@dC4a<@08<C00<04a<0:A<00`0C

4`0Y4`033A<C02TC00<04a<0:A<00`0C4`094`0301<000`C001Q4`0341<C00LC00<04a<00a<01@dC

4a<@0=XC00<=01<0HQ<300`C001P4`0341<C00PC00<04a<011<01@dC4a<@0=TC00<=01<0LA<0060C

00<@4a<021<200HC00@=4a<@f1<010dC001a4`00Ga<00a0C4`094`0301<C00DC00D=4a<C403G4`03

3A<0078C001O4`0341<C00TC00<04a<01Q<010dC4a3G4`033A<0078C001N4`0341<C00XC00<04a<0

1a<010dC4a3F4`033A<0078C001N4`0341<C00XC0P084`043A<C4=DC00<=4a<00P1a4`00GA<00a0C

4`0;4`0301<C00PC00@=4a<@e1<010dC4`1b4`00GA<00a0C4`044`D00Q<00`0C4`094`033A<@0=@C

00@=4a<0LQ<005`C00<@4a<01a<00`0C4`024`0301<C00XC00<=4a00da<010dC4`1b4`00Fa<00a0C

4`084`0301<C008C0P0;4`043A<C4=8C00@=4a<0LQ<005/C00<@4a<021<00`0C4`024`0301<C00/C

00<=4a00dA<010dC4a<2074C001J4`0341<C00TC00<04a<00Q<00`0C4`0<4`033A<@0=0C00D=4a<C

001b4`00FQ<00a0C4`084`8011<00`0C4`0<4`043A<C4<lC00D=4a<C001b4`00FA<00a0C4`0?4`80

3Q<00`dC403?4`053A<C4`00LQ<005PC00<@4a<041<00`0C4`0=4`043A<C4<hC00@=4a<C0P1a4`00

F1<00a0C4`0@4`0301<C00hC00@=4a<@cQ<010dC4`1b4`00Ea<00a0C4`0A4`0301<C00hC00@=4a<@

`Q<00`0C4`024`0301<C008C00<04`d00Q<00`0C4`1`4`00EQ<00a0C4`0B4`8041<010dC4a304`03

01<000LC00@04`0=0Q<00`0C4`1`4`00EQ<00a0C4`0B4`0301<C010C00@=4a<@_a<00`0C00094`04

00dC4`80LA<005DC00<@4a<04a<00`0C4`0@4`043A<C4;lC00<04`001a<200054`dC4`00LQ<005@C

00<@4a<051<00`0C4`0A4`043A<C4;hC00<04`001a<01`0C4a<=4`00LQ<005<C00<@4a<05A<2018C

00@=4a<@_a<00`0C4`064`<000@C3A<0LQ<005<C00<@4a<05A<00`0C4`0B4`043A<C4</C00<=4`00

LQ<0058C00<@4a<05Q<00`0C4`0C4`043A<C4<XC00@=4`00LA<0054C00<@4a<05a<00`0C4`0C4`04

3A<C4</C00<=01<0LA<0054C00<@4a<05a<201DC00@=4a<@bQ<00`d04`1a4`00D1<00a0C4`0H4`03

01<C01DC00<=4a00ba<00`dC4`1`4`00Ca<00a0C4`084`D00Q<00`0C4`024`0301<C008C00<04a<0

5A<010dC4a3:4`033@0C070C001?4`0341<C00XC00<04a<01Q<00`0C00034`0301<C01HC00@=4a<@

bA<00`0=4`1`4`00CQ<00a0C4`0;4`0301<C00PC00@04a<C0P0G4`053A<C4a00b1<00`0=4`1`4`00

CA<00a0C4`0<4`0301<C00HC0P044`0301<C01LC00@=4a<@b1<00`0C3@1`4`00C1<00a0C4`0=4`03

01<C00HC00<04a<00a<00`0C4`0H4`043A<C4<LC00<04`d0L1<004`C00<@4a<031<200PC0`034`03

01<C01PC00D=4a<C40364`8000<C3A<0KQ<004/C00<@4a<07A<201XC00D=4a<C40354`0501<C4`d0

KQ<004XC00<@4a<07Q<00`0C4`0J4`043A<C4<DC00D04a<C3@1^4`00BQ<00a0C4`0N4`0301<C01XC

00D=4a<C40344`0301<C008C00<=4a<0Ja<004TC00<@4a<07a<00`0C4`0K4`053A<C4a00`a<200<C

00<=4a<0Ja<004PC00<@4a<081<201`C00<=4a<00Q<00a0C4`304`0301<C00<C00<=4a<0JQ<004LC

00<@4a<08A<00`0C4`0L4`033A<C008C00<@4a<0_a<00`0C4`044`033A<C06TC00174`0341<C024C

00<04a<071<00`dC4`024`0341<C0;PC1@024`0301<C00DC00<=4a<0J1<004HC00<@4a<08Q<00`0C

4`0M4`033A<C008C00<@4a<0^A<00`0C4`024`0301<C00DC00<=4a<0J1<004DC00<@4a<08a<201hC

00<=4a<00a<00a0C4`2h4`0301<C008C0P074`033A<C06LC00144`0341<C02@C00<04a<07Q<00`dC

4`034`0341<C0;LC00<04a<00Q<00`0C4`074`033A<C06HC00144`0341<C02@C00<04a<07Q<00`dC

4`034`0341<C0;LC00<04a<00Q<00`0C4`084`033A<C06DC00134`0341<C02DC00<04a<07a<00`dC

4`034`0341<C0;DC0P044`0301<C00TC00<=4a<0I1<0048C00<@4a<09Q<00`0C4`0P4`033A<C00<C

00<@4a<0^Q<200XC00<=4a<0I1<0044C00<@4a<09a<2024C00<=4a<011<00a0C4`2i4`0301<C00XC

00<=4a<0Ha<0040C00<@4a<0:1<00`0C4`0Q4`033A<C00@C00<@4a<0^1<00`0C4`0;4`033A<C068C

00104`0341<C028C0`034`0301<C028C00<=4a<011<00a0C4`2g4`0301<C00`C00<=4a<0HA<003lC

00<@4a<08a<00`0C4`034`0301<C028C00<=4a<011<00a0C4`2g4`803Q<00`dC4`1P4`00?Q<00a0C

4`0U4`0301<C008C0P0T4`033A<C00@C00<@4a<0]Q<00`0C4`0>4`033A<C05lC000m4`0341<C02HC

00<04a<00Q<00`0C4`0S4`033A<C00DC00<@4a<0]A<00`0C4`0?4`033A<C05hC000m4`0341<C02DC

00<04`000a<00`0C4`0T4`033A<C00DC00<@4a<0]1<00`0C4`0@4`033A<C05dC000l4`0341<C02LC

00<04a<00Q<00`0C4`0U4`033A<C00DC00<@4a<0/a<00`0C4`0A4`8=GA<003/C00<@4a<0;A<202HC

00<=4a<01Q<00a0C4`2b4`8051<00`dC4`1J4`00>Q<00a0C4`0^4`0301<C02HC00<=4a<01A<00a0C

4`2b4`0301<C01@C0PeJ4`00>Q<00a0C4`0^4`0301<C02LC00<=4a<01A<00a0C4`2a4`0301<C01HC

00<=4a<0Ea<003TC00<@4a<0;a<00`0C4`0W4`033A<C00HC00<@4a<0/1<00`0C4`0G4`033A<C05HC

000h4`0341<C030C0P0Y4`033A<C00HC00<@4a<0[a<201TC0PeF4`00=a<00a0C4`0a4`0301<C02TC

00<=4a<01A<00a0C4`2_4`0301<C01XC00<=4a<0Da<003LC00<@4a<0<A<00`0C4`0Y4`033A<C00HC

00<@4a<0[Q<00`0C4`0K4`033A<C058C000f4`0341<C038C00<04a<0:Q<00`dC4`064`0341<C09`C

1@024`0301<C008C00<04a<00Q<00`0C4`0L4`8=DQ<003DC00<@4a<0<a<202/C00<=4a<01a<00a0C

4`2M4`0301<C00HC00<04`000a<00`0C4`0N4`033A<C04lC000d4`0341<C03@C00<04a<0:a<00`dC

4`074`0341<C09`C00<04a<021<0100C4a<2020C0Pe?4`00<a<00a0C4`0e4`0301<C02`C00<=4a<0

1a<00a0C4`2K4`0301<C00HC0P044`0301<C024C00<=4a<0C1<0038C00<@4a<0=Q<00`0C4`0/4`03

3A<C00LC00<@4a<0Va<00`0C4`064`0301<C00<C00<04a<08Q<23D`C000a4`0341<C03LC0P0^4`03

3A<C00LC00<@4a<0VA<200PC0`034`0301<C02@C00<=4a<0BA<0030C00<@4a<0>1<00`0C4`0^4`03

3A<C00LC00<@4a<0Z1<202HC0Pe94`00;a<00a0C4`0Y4`<00a<00`0C4`024`0301<C008C00<04a<0

;Q<00`dC4`084`0341<C0:LC00<04a<09a<00`dC4`164`00;Q<00a0C4`0Z4`0301<C00LC00<04`00

0a<00`0C4`0_4`033A<C00PC00<@4a<0YQ<00`0C4`0X4`8=AQ<002dC00<@4a<0;1<00`0C4`084`04

01<C4`80<1<00`dC4`094`0341<C0:DC00<04a<0:Q<00`dC4`134`00;1<00a0C4`0]4`0301<C00HC

0P044`0301<C030C00<=4a<02A<00a0C4`2T4`80;1<23D<C000[4`0341<C02dC00<04`001a<00`0C

4`034`0301<C030C00<=4a<02Q<00a0C4`2S4`0301<C02dC00<=4a<0@1<002XC00<@4a<0;a<00`0C

4`064`<00a<00`0C4`0a4`033A<C00XC00<@4a<0XQ<00`0C4`0^4`8=@1<002TC00<@4a<0?a<203<C

00<=4a<02Q<00a0C4`2Q4`0301<C030C0Pdn4`00:1<00a0C4`104`0301<C038C00<=4a<02a<00a0C

4`2P4`0301<C038C0Pdl4`009a<00a0C4`114`0301<C03<C00<=4a<02a<00a0C4`2O4`80=A<23CXC

000V4`0341<C048C00<04a<0<a<00`dC4`0<4`0341<C09hC00<04a<0=Q<23CPC000U4`0341<C04<C

0P0e4`033A<C00`C00<@4a<0WA<00`0C4`0h4`8==Q<002@C00<@4a<0A1<00`0C4`0e4`033A<C00`C

00<@4a<0W1<00`0C4`0j4`8==1<002<C00<@4a<0AA<00`0C4`0e4`033A<C00dC00<@4a<0Va<203dC

0Pdb4`008a<00a0C4`154`0301<C03HC00<=4a<03A<00a0C4`2J4`0301<C03hC00<=4a<0;a<0028C

00<@4a<0AQ<203PC00<=4a<03A<00a0C4`2I4`0301<C03lC0Pd_4`008A<00a0C4`174`0301<C03LC

00<=4a<03Q<00a0C4`2B4`<00a<00`0C4`114`8=;A<0020C00<@4a<0B1<00`0C4`0h4`033A<C00hC

00<@4a<0TA<00`0C4`034`0301<C04<C0Pd[4`007a<00a0C4`194`0301<C03PC00<=4a<03a<00a0C

4`2A4`0301<C008C0P164`8=:A<001hC00<@4a<0BQ<203XC00<=4a<03a<00a0C4`2@4`0301<C008C

00<04a<0Aa<23BLC000M4`0341<C04/C00<04a<0>Q<00`dC4`0?4`0341<C08hC00<04`000a<00`0C

4`194`8=9A<001`C00<@4a<0C1<00`0C4`0j4`033A<C010C00<@4a<0SQ<00`0C4`024`0301<C04/C

0`dR4`006a<00a0C4`174`8011<00`0C4`0k4`033A<C010C00<@4a<0TQ<204lC0`dO4`006Q<00a0C

4`1:4`0501<C4`00?A<00`dC4`0A4`0341<C094C00<04a<0DA<23AdC000I4`0341<C04XC00<04a<0

0Q<203dC00<=4a<041<00a0C4`2A4`0301<C05<C0PdK4`00Ia<00`0C4`3W4`0301<C05DC00<=4a<0

61<006DC00<04`00jA<2074C001V4`0301<C0>PC00<04a<0L1<002XC0`3o4bDC00<04a<0L1<002XC

00<04a<0oa<U4`0301<C070C000[4`0301<C00@C00<04a<0oa>@4`00:a<0100C4a<400<C0`3o4h`C

000Z4`0301<0008C0P000a<04`044`0301<C0?lCRQ<002/C00<04a<00a<00`0C00034`0301<C0?lC

Ra<0034C00<04`0011<00`0C4`064`0301<C02LC0`0[4`0301<C0?lC:A<001/C0`000a<0000200`C

0`044`<021<00`0C4`0V4`0401<C00lC0`000a<00002008C00<04a<00Q<00`0C4`024`0301<C00DC

00@04a<C1@024`0401<C4`800a<200@C00<04a<011<20<DC00<04a<0=a<00`0C4`064`006Q<0100C

4`0T4`0301<C02DC00@04a<03Q<0100C4`064`0301<000LC00<04`0011<500<C00<04a<01Q<00`0C

00044`0601<C01<011<00`0C4`2m4`0301<C00@C00<04a<04a<00`0C4`0S4`0301<C00DC000J4`05

01<C01<010000a<0000H02dC0`0>4`0501<C01<0100011<04`094`0301<C00@C00<04a<00a<00`0C

4`064`0301<000<C00<04a<00a<00`0C4`024`0301<C0:/C00@04a<C10024`801Q<00`0C4`034`03

01<C008C00<04a<00Q<00`0C4`024`0301<C00DC00@04a<C1@024`0401<C4`800a<200@C00<04a<0

11<200@C00@04a<C0P014`006a<304lC00<04a<03A<300HC00<04`001a<200LC00<04a<00a<00`0C

4`064`801A<00`0C4`0200DC00<04a<0ZQ<00`0C00074`0301<C00@C1@034`0701<C4`0C00074`03

01<000@C1@034`0301<C00HC00<04`0011<01P0C4`0C00@C00<04a<011<00`0C4`024`400A<001dC

00<04a<0C1<2014C00<04a<011<00`0C00074`0301<C00`C00<04a<01Q<00`0C4`024`0301<0008C

00<04a<011<00`0C002Z4`0301<0008C10000a<04`074`0301<C00<C00L04a<C01<000TC00<04a<0

11<00`0C4`034`0301<C00HC00<04`000a<00`0C4`034`0301<C008C00<04a<011<00`0C4`034`40

000L4`80H1<200LC00<04a<01Q<300/C0P094`800a<0100C4a<300@C0`2C4`8000<C00004Q<00`0C

00074`0301<C00HC00<04a<00a<01`0C4a<04`001a<200LC00<04a<00a<00`0C4`064`801A<00`0C

4`0200DC00<04a<011<00`0C4`034`40003o4e4C00<04`004a<00`0C00074`0301<000dC00H04a<0

4`074`0301<C00`C00<04a<01Q<00`0C4`024`0301<0008C00<04a<011<00`0C00034`0301<C00<C

0@014`009Q<200HC0P3o4b8C00<04a<04a<00`0C4`064`<03Q<0100C4`084`<02a<200TC0P034`04

01<C4`<011<3008C00<04a<00a<2004C000X4`0301<C008C00<04a<0oa<R4`0301<C070C000W4`03

01<C00<C00<04a<01Q<00`0C4`3o4aPC00<04`00LA<002PC00<04a<00Q<00`0C4`024`<000@C01<C

0`3o4a@C0P000a<0001`4`009Q<00`0C00044`0301<0008C0P024`0301<C008C00<04a<0oa>74`00

9a<00`0C4`034`<011<0100C4`024`0301<C0?lCR1<003@C00@04a<00a<00`0C4`3o4hLC000b4`<0

11<30?lCRA<00?lCaA<00?lCaA<00?lCaA<00?lCaA<00?lCaA<00001\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.66105, -1.78768, 0.0226931, 0.0226931}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -82 0 ]

[.5 .96488 82 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -143 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.63) show

217.250000 19.500000 moveto

(C) show

222.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.28089 0 m

.30316 .03629 L

.34309 .10137 L

.3815 .16399 L

.42237 .2306 L

.46172 .29474 L

.49955 .35641 L

.53984 .42208 L

.57861 .48528 L

.61984 .55247 L

.65954 .6172 L

.69774 .67945 L

.73838 .74571 L

.77751 .80949 L

.81909 .87727 L

.85916 .94257 L

s

.85916 .94257 m

.86518 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.398248 0.238095 [

[.02381 .38575 -6 -9 ]

[.02381 .38575 6 0 ]

[.2619 .38575 -6 -9 ]

[.2619 .38575 6 0 ]

[.7381 .38575 -3 -9 ]

[.7381 .38575 3 0 ]

[.97619 .38575 -3 -9 ]

[.97619 .38575 3 0 ]

[1.025 .39825 0 -8 ]

[1.025 .39825 9 8 ]

[.4875 .0411 -24 -4.5 ]

[.4875 .0411 0 4.5 ]

[.4875 .16015 -12 -4.5 ]

[.4875 .16015 0 4.5 ]

[.4875 .2792 -24 -4.5 ]

[.4875 .2792 0 4.5 ]

[.4875 .5173 -18 -4.5 ]

[.4875 .5173 0 4.5 ]

[.4875 .63634 -6 -4.5 ]

[.4875 .63634 0 4.5 ]

[.4875 .75539 -18 -4.5 ]

[.4875 .75539 0 4.5 ]

[.4875 .87444 -6 -4.5 ]

[.4875 .87444 0 4.5 ]

[.5 .96083 -4.5 0 ]

[.5 .96083 4.5 16 ]

[.5 .94833 -134.5 0 ]

[.5 .94833 134.5 16 ]

[ 0 0 0 0 ]

[ 1 .93583 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .39825 m

.02381 .4045 L

s

[(-2)] .02381 .38575 0 1 Mshowa

.2619 .39825 m

.2619 .4045 L

s

[(-1)] .2619 .38575 0 1 Mshowa

.7381 .39825 m

.7381 .4045 L

s

[(1)] .7381 .38575 0 1 Mshowa

.97619 .39825 m

.97619 .4045 L

s

[(2)] .97619 .38575 0 1 Mshowa

.125 Mabswid

.07143 .39825 m

.07143 .402 L

s

.11905 .39825 m

.11905 .402 L

s

.16667 .39825 m

.16667 .402 L

s

.21429 .39825 m

.21429 .402 L

s

.30952 .39825 m

.30952 .402 L

s

.35714 .39825 m

.35714 .402 L

s

.40476 .39825 m

.40476 .402 L

s

.45238 .39825 m

.45238 .402 L

s

.54762 .39825 m

.54762 .402 L

s

.59524 .39825 m

.59524 .402 L

s

.64286 .39825 m

.64286 .402 L

s

.69048 .39825 m

.69048 .402 L

s

.78571 .39825 m

.78571 .402 L

s

.83333 .39825 m

.83333 .402 L

s

.88095 .39825 m

.88095 .402 L

s

.92857 .39825 m

.92857 .402 L

s

.25 Mabswid

0 .39825 m

1 .39825 L

s

gsave

1.025 .39825 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .0411 m

.50625 .0411 L

s

[(-1.5)] .4875 .0411 1 0 Mshowa

.5 .16015 m

.50625 .16015 L

s

[(-1)] .4875 .16015 1 0 Mshowa

.5 .2792 m

.50625 .2792 L

s

[(-0.5)] .4875 .2792 1 0 Mshowa

.5 .5173 m

.50625 .5173 L

s

[(0.5)] .4875 .5173 1 0 Mshowa

.5 .63634 m

.50625 .63634 L

s

[(1)] .4875 .63634 1 0 Mshowa

.5 .75539 m

.50625 .75539 L

s

[(1.5)] .4875 .75539 1 0 Mshowa

.5 .87444 m

.50625 .87444 L

s

[(2)] .4875 .87444 1 0 Mshowa

.125 Mabswid

.5 .06491 m

.50375 .06491 L

s

.5 .08872 m

.50375 .08872 L

s

.5 .11253 m

.50375 .11253 L

s

.5 .13634 m

.50375 .13634 L

s

.5 .18396 m

.50375 .18396 L

s

.5 .20777 m

.50375 .20777 L

s

.5 .23158 m

.50375 .23158 L

s

.5 .25539 m

.50375 .25539 L

s

.5 .30301 m

.50375 .30301 L

s

.5 .32682 m

.50375 .32682 L

s

.5 .35063 m

.50375 .35063 L

s

.5 .37444 m

.50375 .37444 L

s

.5 .42206 m

.50375 .42206 L

s

.5 .44587 m

.50375 .44587 L

s

.5 .46968 m

.50375 .46968 L

s

.5 .49349 m

.50375 .49349 L

s

.5 .5411 m

.50375 .5411 L

s

.5 .56491 m

.50375 .56491 L

s

.5 .58872 m

.50375 .58872 L

s

.5 .61253 m

.50375 .61253 L

s

.5 .66015 m

.50375 .66015 L

s

.5 .68396 m

.50375 .68396 L

s

.5 .70777 m

.50375 .70777 L

s

.5 .73158 m

.50375 .73158 L

s

.5 .7792 m

.50375 .7792 L

s

.5 .80301 m

.50375 .80301 L

s

.5 .82682 m

.50375 .82682 L

s

.5 .85063 m

.50375 .85063 L

s

.5 .0173 m

.50375 .0173 L

s

.5 .89825 m

.50375 .89825 L

s

.5 .92206 m

.50375 .92206 L

s

.25 Mabswid

.5 0 m

.5 .93583 L

s

gsave

.5 .96083 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .94833 -195.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.63) show

293.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

298.000000 15.000000 moveto

(L) show

305.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

312.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

319.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

324.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

328.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .93583 L

0 .93583 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .24758 m

.02576 .24756 L

.03158 .24751 L

.04117 .24743 L

.05437 .24732 L

.07094 .24717 L

.09061 .24698 L

.11304 .24674 L

.13785 .24645 L

.16461 .2461 L

.19286 .24569 L

.22212 .2452 L

.25189 .24461 L

.28166 .24393 L

.31092 .24313 L

.33917 .2422 L

.36593 .24113 L

.39073 .23993 L

.41317 .23862 L

.43284 .23723 L

.44941 .23586 L

.46261 .23459 L

.4722 .23355 L

.47802 .23287 L

.47997 .23264 L

s

.47997 .23264 m

.48209 .23237 L

.48842 .23155 L

.49885 .23006 L

.51321 .22772 L

.53124 .2242 L

.55264 .21901 L

.57704 .21157 L

.60402 .20136 L

.63313 .18835 L

.66386 .17314 L

.69569 .15663 L

.72808 .13968 L

.76046 .12293 L

.7923 .10683 L

.82303 .0917 L

.85213 .07774 L

.87912 .06514 L

.90352 .05402 L

.92492 .04446 L

.94295 .03655 L

.9573 .03034 L

.96774 .02587 L

.97407 .02318 L

.97619 .02228 L

s

.47997 .481 m

.48209 .45365 L

.48842 .42673 L

.49885 .40058 L

.51321 .37553 L

.53124 .35205 L

.55264 .33077 L

.57704 .3124 L

.60402 .29759 L

.63313 .28647 L

.66386 .27856 L

.69569 .27307 L

.72808 .26923 L

.76046 .2665 L

.7923 .26451 L

.82303 .26303 L

.85213 .26191 L

.87912 .26106 L

.90352 .2604 L

.92492 .2599 L

.94295 .25952 L

.9573 .25924 L

.96774 .25906 L

.97407 .25895 L

.97619 .25891 L

s

.47997 .48111 m

.48209 .50872 L

.48842 .53646 L

.49885 .56411 L

.51321 .5915 L

.53124 .6185 L

.55264 .64496 L

.57704 .67077 L

.60402 .6958 L

.63313 .71992 L

.66386 .74304 L

.69569 .76504 L

.72808 .78583 L

.76046 .80531 L

.7923 .8234 L

.82303 .84002 L

.85213 .85509 L

.87912 .86854 L

.90352 .88033 L

.92492 .89039 L

.94295 .89868 L

.9573 .90516 L

.96774 .90982 L

.97407 .91262 L

.97619 .91355 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<00`0C4`1`4`00oa=B4`0301<C070C001T4`D0j1<00`0C4`1`4`00IQ<00`0C4`3X4`80

LA<004HC00<=4a<05a<300<C00<04a<00Q<20>@C00<04a<0E1<23AXC00164`033A<C01dC00<04a<0

0Q<00`0C4`3B4`D00Q<00`0C4`024`0301<C008C00<04a<0DA<33A`C00174`033A<C01`C00<04a<0

0Q<00`0C4`3D4`0301<C00HC00<04`000a<00`0C4`1?4`8=7a<004LC00<=4a<06a<200@C00<04a<0

cQ<300<C00<04a<021<0100C4a<204hC0PdQ4`00B1<00`dC4`0P4`80eA<00`0C4`064`8011<00`0C

4`1<4`033A<C024C00184`033A<C020C00<04a<0e1<00`0C4`064`0301<C00<C00<04a<0BQ<23B@C

00194`033A<C01lC00<04a<0da<200PC0`034`0301<C04LC0`dV4`00BQ<00`dC4`0N4`0301<C0><C

00<04a<0AA<23BTC001:4`033A<C01hC0P3T4`80@a<33B/C001;4`033A<C01dC00<04a<0ha<00`0C

4`104`8=;Q<004`C00<=4a<071<00`0C4`3S4`0301<C03hC0Pd`4`00C1<00`dC4`0L4`0301<C0><C

00<04a<0?1<23C8C001=4`033A<C01/C0P3T4`80>a<23C@C001=4`033A<C01/C00<04a<0ha<00`0C

4`0h4`8==Q<004hC00<=4a<06Q<00`0C4`3S4`0301<C03DC0`dh4`00Ca<00`dC4`0I4`0301<C0><C

00<04a<0<a<23C/C001?4`033A<C01TC0P3T4`80<Q<23CdC001@4`033A<C01PC00<04a<0ha<00`0C

4`0_4`8=?a<0054C00<=4a<021<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`3S4`0301<C02dC

0Pe14`00DA<00`dC4`074`0301<000LC00<04`000a<00`0C4`3S4`0301<C02/C0Pe34`00DQ<010dC

4a<3008C00<04`002A<0100C4a<20>@C00<04a<0:A<23DDC001C4`033A<C00DC00<04`001a<200@C

00<04a<0ha<202PC0Pe74`00Da<00`dC4`054`0301<000LC00<04a<00a<00`0C4`3S4`0301<C02DC

0Pe94`00E1<00`dC4`054`0301<C00HC0`034`0301<C0=`C1@024`0301<C02@C00<=4a<0BA<005@C

00<=4a<051<00`0C4`3N4`0301<C008C00<04a<08Q<23D`C001E4`033A<C01<C0P3I4`<00a<00`0C

4`024`808Q<00`dC4`1<4`00EQ<00`dC4`0B4`0301<C0=hC00<04a<00Q<00`0C4`0O4`8=Ca<005HC

00<=4a<04Q<00`0C4`3N4`0301<C008C00<04a<07A<23E4C001G4`033A<C014C00<04a<0gA<200@C

00<04a<06Q<33E<C001H4`033A<C010C0P3T4`0301<C01PC0PeF4`00F1<00`dC4`0@4`0301<C0><C

0P0G4`8=F1<001XC0`0U4`D04Q<00`dC4`0?4`0301<C02@C1@0T4`<0Ta<00`0C4`0D4`8=FQ<001XC

00<04a<09a<00`0C4`0B4`033A<C00lC00<04a<09Q<00`0C4`0T4`0301<C09<C00<04a<04Q<23E`C

000E4`<00a<00`0C4`0P4`<00a<00`0C4`0C4`033A<C00hC0P0W4`0301<C02DC00<04a<0TQ<00`0C

4`0?4`<=GQ<001/C00<04a<09Q<00`0C4`0C4`033A<C00hC00<04a<09Q<00`0C4`0U4`0301<C098C

0P0>4`8=HA<001XC00<04`009a<00`0C4`0D4`033A<C00dC00<04a<09Q<00`0C4`0T4`0301<009<C

00<04a<02Q<33F<C000K4`0301<C02DC0P0G4`033A<C00`C00<04a<09A<202LC00<04a<0TQ<00`0C

4`064`@=IQ<005`C00<=4a<031<20>@C00<04a<00Q<43FXC001M4`033A<C00/C00<04a<0hA<73FhC

001M4`033A<C00/C00<04a<0Fa<207`C20d24`0301<C070C001N4`033A<C00XC00<04a<0FQ<00`0C

4`1V4aH=2Q<00`0C4`1`4`005A=:00033@0006001Q<00`0C4`0^4cP=81<00`0C4`1`4`006A<00`0C

4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC

00D04a<C3@034`0301<C00DC00<@4a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`03

01<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`084`0301<C08HC00<04a<0

L1<0060C00<=4a<021<00a0C4`1J4`0301<008HC0P1a4`00HA<00`dC4`074`8@Fa<308HC00<04a<0

=a<O3AXC001Q4`033A<C00LC0Q3E4`0301<C008C00<04a<00Q<00`0C4`024`0301<C02DC4Pdi4`00

HQ<00`dC4`054`03400@0=@C00<04`001a<00`0C00034`0301<C01lC1Pe;4`00HQ<00`dC4`054`03

400@0<lC0`024`0301<000TC00@04a<C0P0K4`D=DA<006<C00<=4a<011<00a00403D4`0301<000LC

0P044`0301<C01PC0PeF4`00I1<00`dC4`024`0541<00100da<00`0C00074`0301<C00<C00<04a<0

5A<33EPC001T4`033A<C008C00D@4`0C403D4`0301<C00HC0`034`0301<C018C0`eK4`00IA<02@dC

4a<@4`0C403S4`0301<C00lC0`eN4`00IQ<01PdC4a0C008C00<@4a<0h1<200hC0PeQ4`00IQ<01@dC

4a0C008000<C41<0hA<00`0C4`0;4`8=Ha<006LC00D=4a0C00024`0341<C0>0C00<04a<02Q<00`dC

4`1S4`00Ia<01@d@4a<000<C00<@4a<0ga<00`0C4`094`033A<C06@C001X4`043A<C00<C00<@4a<0

ga<200TC00<=4a<0IA<006PC00<@3A<00P024`0341<C0=lC00<04a<01a<00`dC4`1V4`00Ia<01A0C

3A<000@C00<@4a<0gQ<00`0C4`064`033A<C06LC001L4`0301<C008C00<04a<00Q<01P0@4a<=00@C

00<@4a<0Qa<302PC1@0W4`0301<C00DC00<=4a<07a<502PC0`0I4`00Fa<00`0C00074`030100008C

00<=01<00a<00a0C4`274`0301<C02XC00<04a<09a<00`0C4`044`033A<C028C00<04a<0:1<00`0C

4`0I4`00Fa<00`0C00084`03400C008C00<=01<00a<00a0C4`214`<00a<00`0C4`0S4`<00a<00`0C

4`0W4`8011<00`dC4`0S4`0301<C02TC00<04a<061<005/C00<04`001a<00`0@4`034`0300dC00<C

00<@4a<0Qa<00`0C4`0Y4`0301<C02LC00<04a<00Q<00`dC4`0T4`0301<C02TC00<04a<061<005/C

00<04`001a<00a0C4`034`0300dC00@C00<@4a<0QA<00`0C000Z4`0301<C02LC00D04a<C3@0W4`03

01<C02PC00<04`006A<005`C00<04a<01Q<00a0000034`0301<=00@C00<@4a<0QQ<00`0C4`0X4`80

:A<01@0C4a<=02HC0P0[4`0301<C01PC001T4`0341<C00@C0P000`dC4`024`0341<C0=`C0P000a<=

4`1^4`00I1<00a0C4`044`0401<C3@@C00<@4a<0fa<00`0C3@1`4`00Ha<00a0C4`054`0401<C3@@C

00<@4a<0fa<00`0C3@1R4`8031<006<C00<@4a<01A<01@0C4a<=00@C00<@4a<0fQ<00`0=4`1Q4`03

01<C00`C001R4`0341<C00HC00<04a<00Q<01@dC4a<@07lCGP000`d0001J00HC00<04a<031<0068C

00<@4a<01Q<200<C00<=4a<00Q<00a0C4`214`0301<C00HC00<04a<01A<00`0C4`064`0301<C00HC

00<04a<01Q<00`0C4`064`0301<C00HC00<04a<01A<00`0C4`064`0301<C00HC00<=4a<01Q<00`0C

4`064`0301<C00HC00<04a<01A<00`0C4`064`0301<C00HC00<04a<01Q<00`0C4`064`0301<C00HC

00<04a<01A<00`0C4`094`0301<C00`C001Q4`0341<C00LC00<04a<00a<01@dC4a<@08<C00<04a<0

:A<00`0C4`0Y4`033A<C02TC00<04a<0:A<00`0C4`094`0301<000`C001Q4`0341<C00LC00<04a<0

0a<01@dC4a<@0=XC00<=01<0HQ<300`C001P4`0341<C00PC00<04a<011<01@dC4a<@0=TC00<=01<0

LA<0060C00<@4a<021<200HC00@=4a<@f1<010dC001a4`00Ga<00a0C4`094`0301<C00DC00D=4a<C

403G4`033A<0078C001O4`0341<C00TC00<04a<01Q<010dC4a3G4`033A<0078C001N4`0341<C00XC

00<04a<01a<010dC4a3F4`033A<0078C001N4`0341<C00XC0P084`043A<C4=DC00<=4a<00P1a4`00

GA<00a0C4`0;4`0301<C00PC00@=4a<@e1<010dC4`1b4`00GA<00a0C4`044`D00Q<00`0C4`094`03

3A<@0=@C00@=4a<0LQ<005`C00<@4a<01a<00`0C4`024`0301<C00XC00<=4a00da<010dC4`1b4`00

Fa<00a0C4`084`0301<C008C0P0;4`043A<C4=8C00@=4a<0LQ<005/C00<@4a<021<00`0C4`024`03

01<C00/C00<=4a00dA<010dC4a<2074C001J4`0341<C00TC00<04a<00Q<00`0C4`0<4`033A<@0=0C

00D=4a<C001b4`00FQ<00a0C4`084`8011<00`0C4`0<4`043A<C4<lC00D=4a<C001b4`00FA<00a0C

4`0?4`803Q<00`dC403?4`053A<C4`00LQ<005PC00<@4a<041<00`0C4`0=4`043A<C4<hC00@=4a<C

0P1a4`00F1<00a0C4`0@4`0301<C00hC00@=4a<@cQ<010dC4`1b4`00Ea<00a0C4`0A4`0301<C00hC

00@=4a<@`Q<00`0C4`024`0301<C008C00<04`d00Q<00`0C4`1`4`00EQ<00a0C4`0B4`8041<010dC

4a304`0301<000LC00@04`0=0Q<00`0C4`1`4`00EQ<00a0C4`0B4`0301<C010C00@=4a<@_a<00`0C

00094`0400dC4`80LA<005DC00<@4a<04a<00`0C4`0@4`043A<C4;lC00<04`001a<200054`dC4`00

LQ<005@C00<@4a<051<00`0C4`0A4`043A<C4;hC00<04`001a<01`0C4a<=4`00LQ<005<C00<@4a<0

5A<2018C00@=4a<@_a<00`0C4`064`<000@C3A<0LQ<005<C00<@4a<05A<00`0C4`0B4`043A<C4</C

00<=4`00LQ<0058C00<@4a<05Q<00`0C4`0C4`043A<C4<XC00@=4`00LA<0054C00<@4a<05a<00`0C

4`0C4`043A<C4</C00<=01<0LA<0054C00<@4a<05a<201DC00@=4a<@bQ<00`d04`1a4`00D1<00a0C

4`0H4`0301<C01DC00<=4a00ba<00`dC4`1`4`00Ca<00a0C4`084`D00Q<00`0C4`024`0301<C008C

00<04a<05A<010dC4a3:4`033@0C070C001?4`0341<C00XC00<04a<01Q<00`0C00034`0301<C01HC

00@=4a<@bA<00`0=4`1`4`00CQ<00a0C4`0;4`0301<C00PC00@04a<C0P0G4`053A<C4a00b1<00`0=

4`1`4`00CA<00a0C4`0<4`0301<C00HC0P044`0301<C01LC00@=4a<@b1<00`0C3@1`4`00C1<00a0C

4`0=4`0301<C00HC00<04a<00a<00`0C4`0H4`043A<C4<LC00<04`d0L1<004`C00<@4a<031<200PC

0`034`0301<C01PC00D=4a<C40364`8000<C3A<0KQ<004/C00<@4a<07A<201XC00D=4a<C40354`05

01<C4`d0KQ<004XC00<@4a<07Q<00`0C4`0J4`043A<C4<DC00D04a<C3@1^4`00BQ<00a0C4`0N4`03

01<C01XC00D=4a<C40344`0301<C008C00<=4a<0Ja<004TC00<@4a<07a<00`0C4`0K4`053A<C4a00

`a<200<C00<=4a<0Ja<004PC00<@4a<081<201`C00<=4a<00Q<00a0C4`304`0301<C00<C00<=4a<0

JQ<004LC00<@4a<08A<00`0C4`0L4`033A<C008C00<@4a<0_a<00`0C4`044`033A<C06TC00174`03

41<C024C00<04a<071<00`dC4`024`0341<C0;PC1@024`0301<C00DC00<=4a<0J1<004HC00<@4a<0

8Q<00`0C4`0M4`033A<C008C00<@4a<0^A<00`0C4`024`0301<C00DC00<=4a<0J1<004DC00<@4a<0

8a<201hC00<=4a<00a<00a0C4`2h4`0301<C008C0P074`033A<C06LC00144`0341<C02@C00<04a<0

7Q<00`dC4`034`0341<C0;LC00<04a<00Q<00`0C4`074`033A<C06HC00144`0341<C02@C00<04a<0

7Q<00`dC4`034`0341<C0;LC00<04a<00Q<00`0C4`084`033A<C06DC00134`0341<C02DC00<04a<0

7a<00`dC4`034`0341<C0;DC0P044`0301<C00TC00<=4a<0I1<0048C00<@4a<09Q<00`0C4`0P4`03

3A<C00<C00<@4a<0^Q<200XC00<=4a<0I1<0044C00<@4a<09a<2024C00<=4a<011<00a0C4`2i4`03

01<C00XC00<=4a<0Ha<0040C00<@4a<0:1<00`0C4`0Q4`033A<C00@C00<@4a<0^1<00`0C4`0;4`03

3A<C068C00104`0341<C028C0`034`0301<C028C00<=4a<011<00a0C4`2g4`0301<C00`C00<=4a<0

HA<003lC00<@4a<08a<00`0C4`034`0301<C028C00<=4a<011<00a0C4`2g4`803Q<00`dC4`1P4`00

?Q<00a0C4`0U4`0301<C008C0P0T4`033A<C00@C00<@4a<0]Q<00`0C4`0>4`033A<C05lC000m4`03

41<C02HC00<04a<00Q<00`0C4`0S4`033A<C00DC00<@4a<0]A<00`0C4`0?4`033A<C05hC000m4`03

41<C02DC00<04`000a<00`0C4`0T4`033A<C00DC00<@4a<0]1<00`0C4`0@4`033A<C05dC000l4`03

41<C02LC00<04a<00Q<00`0C4`0U4`033A<C00DC00<@4a<0/a<00`0C4`0A4`8=GA<003/C00<@4a<0

;A<202HC00<=4a<01Q<00a0C4`2b4`8051<00`dC4`1J4`00>Q<00a0C4`0^4`0301<C02HC00<=4a<0

1A<00a0C4`2b4`0301<C01@C0PeJ4`00>Q<00a0C4`0^4`0301<C02LC00<=4a<01A<00a0C4`2a4`03

01<C01HC00<=4a<0Ea<003TC00<@4a<0;a<00`0C4`0W4`033A<C00HC00<@4a<0/1<00`0C4`0G4`03

3A<C05HC000h4`0341<C030C0P0Y4`033A<C00HC00<@4a<0[a<201TC0PeF4`00=a<00a0C4`0a4`03

01<C02TC00<=4a<01A<00a0C4`2_4`0301<C01XC00<=4a<0Da<003LC00<@4a<0<A<00`0C4`0Y4`03

3A<C00HC00<@4a<0[Q<00`0C4`0K4`033A<C058C000f4`0341<C038C00<04a<0:Q<00`dC4`064`03

41<C09`C1@024`0301<C008C00<04a<00Q<00`0C4`0L4`8=DQ<003DC00<@4a<0<a<202/C00<=4a<0

1a<00a0C4`2M4`0301<C00HC00<04`000a<00`0C4`0N4`033A<C04lC000d4`0341<C03@C00<04a<0

:a<00`dC4`074`0341<C09`C00<04a<021<0100C4a<2020C0Pe?4`00<a<00a0C4`0e4`0301<C02`C

00<=4a<01a<00a0C4`2K4`0301<C00HC0P044`0301<C024C00<=4a<0C1<0038C00<@4a<0=Q<00`0C

4`0/4`033A<C00LC00<@4a<0Va<00`0C4`064`0301<C00<C00<04a<08Q<23D`C000a4`0341<C03LC

0P0^4`033A<C00LC00<@4a<0VA<200PC0`034`0301<C02@C00<=4a<0BA<0030C00<@4a<0>1<00`0C

4`0^4`033A<C00LC00<@4a<0Z1<202HC0Pe94`00;a<00a0C4`0Y4`<00a<00`0C4`024`0301<C008C

00<04a<0;Q<00`dC4`084`0341<C0:LC00<04a<09a<00`dC4`164`00;Q<00a0C4`0Z4`0301<C00LC

00<04`000a<00`0C4`0_4`033A<C00PC00<@4a<0YQ<00`0C4`0X4`8=AQ<002dC00<@4a<0;1<00`0C

4`084`0401<C4`80<1<00`dC4`094`0341<C0:DC00<04a<0:Q<00`dC4`134`00;1<00a0C4`0]4`03

01<C00HC0P044`0301<C030C00<=4a<02A<00a0C4`2T4`80;1<23D<C000[4`0341<C02dC00<04`00

1a<00`0C4`034`0301<C030C00<=4a<02Q<00a0C4`2S4`0301<C02dC00<=4a<0@1<002XC00<@4a<0

;a<00`0C4`064`<00a<00`0C4`0a4`033A<C00XC00<@4a<0XQ<00`0C4`0^4`8=@1<002TC00<@4a<0

?a<203<C00<=4a<02Q<00a0C4`2Q4`0301<C030C0Pdn4`00:1<00a0C4`104`0301<C038C00<=4a<0

2a<00a0C4`2P4`0301<C038C0Pdl4`009a<00a0C4`114`0301<C03<C00<=4a<02a<00a0C4`2O4`80

=A<23CXC000V4`0341<C048C00<04a<0<a<00`dC4`0<4`0341<C09hC00<04a<0=Q<23CPC000U4`03

41<C04<C0P0e4`033A<C00`C00<@4a<0WA<00`0C4`0h4`8==Q<002@C00<@4a<0A1<00`0C4`0e4`03

3A<C00`C00<@4a<0W1<00`0C4`0j4`8==1<002<C00<@4a<0AA<00`0C4`0e4`033A<C00dC00<@4a<0

Va<203dC0Pdb4`008a<00a0C4`154`0301<C03HC00<=4a<03A<00a0C4`2J4`0301<C03hC00<=4a<0

;a<0028C00<@4a<0AQ<203PC00<=4a<03A<00a0C4`2I4`0301<C03lC0Pd_4`008A<00a0C4`174`03

01<C03LC00<=4a<03Q<00a0C4`2B4`<00a<00`0C4`114`8=;A<0020C00<@4a<0B1<00`0C4`0h4`03

3A<C00hC00<@4a<0TA<00`0C4`034`0301<C04<C0Pd[4`007a<00a0C4`194`0301<C03PC00<=4a<0

3a<00a0C4`2A4`0301<C008C0P164`8=:A<001hC00<@4a<0BQ<203XC00<=4a<03a<00a0C4`2@4`03

01<C008C00<04a<0Aa<23BLC000M4`0341<C04/C00<04a<0>Q<00`dC4`0?4`0341<C08hC00<04`00

0a<00`0C4`194`8=9A<001`C00<@4a<0C1<00`0C4`0j4`033A<C010C00<@4a<0SQ<00`0C4`024`03

01<C04/C0`dR4`006a<00a0C4`174`8011<00`0C4`0k4`033A<C010C00<@4a<0TQ<204lC0`dO4`00

6Q<00a0C4`1:4`0501<C4`00?A<00`dC4`0A4`0341<C094C00<04a<0DA<23AdC000I4`0341<C04XC

00<04a<00Q<203dC00<=4a<041<00a0C4`2A4`0301<C05<C0PdK4`00Ia<00`0C4`3W4`0301<C05DC

00<=4a<061<006DC00<04`00jA<2074C001V4`0301<C0>PC00<04a<0L1<002`C0`3o4b<C00<04a<0

L1<002`C00<04a<0oa<S4`0301<C070C000]4`0301<C00DC00<04a<0oa>=4`00;A<0100C4a<30004

4`0C4`<0oa>:4`00;1<00`0C00024`800Q<00`0C4`024`0301<C0?lCR1<002dC00<04a<00a<0100C

4`024`0301<C0?lCRA<003<C00@04a<00a<00`0C4`064`0301<C02DC0`0]4`0301<C0?lC9a<001dC

0`000a<0000200`C0`044`<021<00`0C4`0T4`0401<C014C0`000a<00002008C00<04a<00Q<00`0C

4`024`0301<C00DC00@04a<C1@024`0401<C4`800a<200HC0P3;4`0301<C038C00<04a<021<001`C

00@04a<091<00`0C4`0S4`0401<C010C00@04a<01Q<00`0C00074`0301<000@C1@034`0301<C00HC

00<04`0011<00`0C4`024`0301<C0<<C00<04a<011<00`0C4`0C4`0301<C01hC00<04a<01a<001`C

00D04a<04`0400034`0001P0:a<3010C00D04a<04`0400044`0C00TC00<04a<011<00`0C4`034`03

01<C00HC00<04`000a<00`0C4`034`0301<C0;4C00@04a<C10024`801Q<00`0C4`034`0301<C008C

00<04a<00Q<00`0C4`024`0301<C00DC00@04a<C1@024`0401<C4`800a<200HC0P044`0401<C4`80

0A<10040000M4`<0CA<00`0C4`0?4`<01Q<00`0C00074`801a<00`0C4`034`0301<C00HC0P054`03

01<C008C00<04a<0/1<00`0C00074`0301<C00@C1@034`0701<C4`0C00074`0301<000@C1@034`03

01<C00HC00<04`0011<00`0C4`024`0301<C00@C00<04a<00Q<00`0C00014`007a<00`0C4`1:4`80

4a<00`0C4`044`0301<000LC00<04a<031<00`0C4`064`0301<C008C00<04`0011<00`0C002`4`03

01<0008C10000a<04`074`0301<C00<C00L04a<C01<000TC00<04a<011<00`0C4`034`0301<C00HC

00<04`000a<00`0C4`034`0301<C00@C00<04a<00a<1004C0A<001hC0P1P4`801a<00`0C4`064`<0

2a<200TC0P034`0301<C00<C0`2F4`8000<C00005A<00`0C00074`0301<C00HC00<04a<00a<01`0C

4a<04`001a<200LC00<04a<00a<00`0C4`064`801A<00`0C4`024`0301<C00@C00<04a<00a<1004C

0A<00?lCDA<00`0C000F4`0301<000LC00<04`003A<01P0C4`0C00LC00<04a<031<00`0C4`064`03

01<C008C00<04`0011<00`0C00034`0301<C00<C00<04`000A<002TC0P064`80oa<O4`0301<C01HC

00<04a<01Q<300hC00@04a<021<300/C0P094`800a<00`0C4`034`<00Q<00`0C4`034`800A<10040

000[4`0301<C008C00<04a<0oa<O4`0301<C070C000Z4`0301<C00<C00<04a<01A<00`0C4`3o4aHC

00<04`00LA<002/C00<04a<00Q<00`0C4`024`@00a<30?lC4A<200034`00070C000Y4`0301<000@C

00<04`000Q<200034`0C00@C00<04a<0oa>44`00:Q<00`0C4`034`<011<00`0C00034`0301<C0?lC

QA<003LC00<04`0011<00`0C4`3o4h@C000e4`<011<30?lCQQ<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCaA<00001\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.64839, -1.78311, 0.0226556, 0.0226556}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -84.5 0 ]

[.5 .96488 84.5 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -145.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.625) show

222.250000 19.500000 moveto

(C) show

227.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.28022 0 m

.30316 .03727 L

.34309 .10216 L

.3815 .16458 L

.42237 .23099 L

.46172 .29493 L

.49955 .35641 L

.53984 .42188 L

.57861 .48489 L

.61984 .55188 L

.65954 .6164 L

.69774 .67847 L

.73838 .74451 L

.77751 .8081 L

.81909 .87567 L

.85916 .94078 L

s

.85916 .94078 m

.8663 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.397197 0.238095 [

[.02381 .3847 -6 -9 ]

[.02381 .3847 6 0 ]

[.2619 .3847 -6 -9 ]

[.2619 .3847 6 0 ]

[.7381 .3847 -3 -9 ]

[.7381 .3847 3 0 ]

[.97619 .3847 -3 -9 ]

[.97619 .3847 3 0 ]

[1.025 .3972 0 -8 ]

[1.025 .3972 9 8 ]

[.4875 .04005 -24 -4.5 ]

[.4875 .04005 0 4.5 ]

[.4875 .1591 -12 -4.5 ]

[.4875 .1591 0 4.5 ]

[.4875 .27815 -24 -4.5 ]

[.4875 .27815 0 4.5 ]

[.4875 .51624 -18 -4.5 ]

[.4875 .51624 0 4.5 ]

[.4875 .63529 -6 -4.5 ]

[.4875 .63529 0 4.5 ]

[.4875 .75434 -18 -4.5 ]

[.4875 .75434 0 4.5 ]

[.4875 .87339 -6 -4.5 ]

[.4875 .87339 0 4.5 ]

[.5 .95924 -4.5 0 ]

[.5 .95924 4.5 16 ]

[.5 .94674 -137 0 ]

[.5 .94674 137 16 ]

[ 0 0 0 0 ]

[ 1 .93424 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .3972 m

.02381 .40345 L

s

[(-2)] .02381 .3847 0 1 Mshowa

.2619 .3972 m

.2619 .40345 L

s

[(-1)] .2619 .3847 0 1 Mshowa

.7381 .3972 m

.7381 .40345 L

s

[(1)] .7381 .3847 0 1 Mshowa

.97619 .3972 m

.97619 .40345 L

s

[(2)] .97619 .3847 0 1 Mshowa

.125 Mabswid

.07143 .3972 m

.07143 .40095 L

s

.11905 .3972 m

.11905 .40095 L

s

.16667 .3972 m

.16667 .40095 L

s

.21429 .3972 m

.21429 .40095 L

s

.30952 .3972 m

.30952 .40095 L

s

.35714 .3972 m

.35714 .40095 L

s

.40476 .3972 m

.40476 .40095 L

s

.45238 .3972 m

.45238 .40095 L

s

.54762 .3972 m

.54762 .40095 L

s

.59524 .3972 m

.59524 .40095 L

s

.64286 .3972 m

.64286 .40095 L

s

.69048 .3972 m

.69048 .40095 L

s

.78571 .3972 m

.78571 .40095 L

s

.83333 .3972 m

.83333 .40095 L

s

.88095 .3972 m

.88095 .40095 L

s

.92857 .3972 m

.92857 .40095 L

s

.25 Mabswid

0 .3972 m

1 .3972 L

s

gsave

1.025 .3972 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .04005 m

.50625 .04005 L

s

[(-1.5)] .4875 .04005 1 0 Mshowa

.5 .1591 m

.50625 .1591 L

s

[(-1)] .4875 .1591 1 0 Mshowa

.5 .27815 m

.50625 .27815 L

s

[(-0.5)] .4875 .27815 1 0 Mshowa

.5 .51624 m

.50625 .51624 L

s

[(0.5)] .4875 .51624 1 0 Mshowa

.5 .63529 m

.50625 .63529 L

s

[(1)] .4875 .63529 1 0 Mshowa

.5 .75434 m

.50625 .75434 L

s

[(1.5)] .4875 .75434 1 0 Mshowa

.5 .87339 m

.50625 .87339 L

s

[(2)] .4875 .87339 1 0 Mshowa

.125 Mabswid

.5 .06386 m

.50375 .06386 L

s

.5 .08767 m

.50375 .08767 L

s

.5 .11148 m

.50375 .11148 L

s

.5 .13529 m

.50375 .13529 L

s

.5 .18291 m

.50375 .18291 L

s

.5 .20672 m

.50375 .20672 L

s

.5 .23053 m

.50375 .23053 L

s

.5 .25434 m

.50375 .25434 L

s

.5 .30196 m

.50375 .30196 L

s

.5 .32577 m

.50375 .32577 L

s

.5 .34958 m

.50375 .34958 L

s

.5 .37339 m

.50375 .37339 L

s

.5 .42101 m

.50375 .42101 L

s

.5 .44482 m

.50375 .44482 L

s

.5 .46863 m

.50375 .46863 L

s

.5 .49243 m

.50375 .49243 L

s

.5 .54005 m

.50375 .54005 L

s

.5 .56386 m

.50375 .56386 L

s

.5 .58767 m

.50375 .58767 L

s

.5 .61148 m

.50375 .61148 L

s

.5 .6591 m

.50375 .6591 L

s

.5 .68291 m

.50375 .68291 L

s

.5 .70672 m

.50375 .70672 L

s

.5 .73053 m

.50375 .73053 L

s

.5 .77815 m

.50375 .77815 L

s

.5 .80196 m

.50375 .80196 L

s

.5 .82577 m

.50375 .82577 L

s

.5 .84958 m

.50375 .84958 L

s

.5 .01624 m

.50375 .01624 L

s

.5 .8972 m

.50375 .8972 L

s

.5 .92101 m

.50375 .92101 L

s

.25 Mabswid

.5 0 m

.5 .93424 L

s

gsave

.5 .95924 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .94674 -198 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.625) show

298.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

303.000000 15.000000 moveto

(L) show

310.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

317.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

324.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

329.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

333.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .93424 L

0 .93424 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .24614 m

.02576 .24613 L

.03158 .24608 L

.04117 .246 L

.05436 .24589 L

.07094 .24574 L

.09061 .24555 L

.11304 .24532 L

.13784 .24504 L

.1646 .2447 L

.19285 .24429 L

.22211 .24381 L

.25188 .24323 L

.28165 .24256 L

.31091 .24178 L

.33916 .24087 L

.36591 .23982 L

.39072 .23865 L

.41315 .23737 L

.43282 .23601 L

.44939 .23467 L

.46259 .23343 L

.47217 .23242 L

.478 .23175 L

.47995 .23152 L

s

.47995 .23152 m

.48207 .23127 L

.4884 .23046 L

.49883 .22901 L

.51319 .22672 L

.53122 .22328 L

.55262 .2182 L

.57702 .2109 L

.60401 .20083 L

.63312 .18795 L

.66385 .17283 L

.69568 .15639 L

.72807 .13948 L

.76045 .12276 L

.79229 .10669 L

.82302 .09157 L

.85213 .07764 L

.87912 .06505 L

.90352 .05394 L

.92492 .04439 L

.94295 .03649 L

.9573 .03029 L

.96774 .02583 L

.97407 .02314 L

.97619 .02224 L

s

.47995 .47997 m

.48207 .45264 L

.4884 .42573 L

.49883 .39957 L

.51319 .37449 L

.53122 .35097 L

.55262 .32961 L

.57702 .31114 L

.60401 .29622 L

.63312 .285 L

.66385 .27703 L

.69568 .27151 L

.72807 .26765 L

.76045 .26491 L

.79229 .26292 L

.82302 .26145 L

.85213 .26033 L

.87912 .25948 L

.90352 .25883 L

.92492 .25833 L

.94295 .25795 L

.9573 .25768 L

.96774 .25749 L

.97407 .25738 L

.97619 .25735 L

s

.47995 .48009 m

.48207 .50768 L

.4884 .5354 L

.49883 .56301 L

.51319 .59037 L

.53122 .61734 L

.55262 .64377 L

.57702 .66955 L

.60401 .69454 L

.63312 .71864 L

.66385 .74172 L

.69568 .7637 L

.72807 .78446 L

.76045 .80391 L

.79229 .82198 L

.82302 .83857 L

.85213 .85362 L

.87912 .86706 L

.90352 .87882 L

.92492 .88887 L

.94295 .89715 L

.9573 .90362 L

.96774 .90827 L

.97407 .91107 L

.97619 .912 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<00`0C4`1`4`00oa=B4`0301<C070C001T4`D0j1<00`0C4`1`4`00IQ<00`0C4`3X4`80

LA<004DC00<=4a<061<300<C00<04a<00Q<20>@C00<04a<0E1<33ATC00164`033A<C01dC00<04a<0

0Q<00`0C4`3B4`D00Q<00`0C4`024`0301<C008C00<04a<0DA<33A`C00164`033A<C01dC00<04a<0

0Q<00`0C4`3D4`0301<C00HC00<04`000a<00`0C4`1?4`8=7a<004LC00<=4a<06a<200@C00<04a<0

cQ<300<C00<04a<021<0100C4a<204hC0PdQ4`00B1<00`dC4`0P4`80eA<00`0C4`064`8011<00`0C

4`1<4`033A<C024C00184`033A<C020C00<04a<0e1<00`0C4`064`0301<C00<C00<04a<0BQ<23B@C

00194`033A<C01lC00<04a<0da<200PC0`034`0301<C04LC0`dV4`00BQ<00`dC4`0N4`0301<C0><C

0P164`8=:A<004XC00<=4a<07Q<20>@C00<04a<0@Q<33B/C001;4`033A<C01dC00<04a<0ha<00`0C

4`104`8=;Q<004/C00<=4a<07A<00`0C4`3S4`0301<C03hC0Pd`4`00C1<00`dC4`0L4`0301<C0><C

00<04a<0?1<23C8C001<4`033A<C01`C0P3T4`80>a<23C@C001=4`033A<C01/C00<04a<0ha<00`0C

4`0h4`8==Q<004hC00<=4a<06Q<00`0C4`3S4`0301<C03DC0`dh4`00CQ<00`dC4`0J4`0301<C0><C

00<04a<0<a<23C/C001?4`033A<C01TC0P3T4`80<Q<23CdC001?4`033A<C01TC00<04a<0ha<00`0C

4`0_4`8=?a<0050C00<=4a<02A<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`3S4`0301<C02dC

0Pe14`00DA<00`dC4`074`0301<000LC00<04`000a<00`0C4`3S4`0301<C02/C0Pe34`00DA<00`dC

4`024`<00Q<00`0C00094`0401<C4`80i1<00`0C4`0Y4`8=AA<0058C00<=4a<01Q<00`0C00074`80

11<00`0C4`3S4`80:1<23DLC001C4`033A<C00DC00<04`001a<00`0C4`034`0301<C0><C00<04a<0

9A<23DTC001C4`033A<C00HC00<04a<01Q<300<C00<04a<0g1<5008C00<04a<091<00`dC4`194`00

E1<00`dC4`0D4`0301<C0=hC00<04a<00Q<00`0C4`0R4`8=C1<005DC00<=4a<04a<20=TC0`034`03

01<C008C0P0R4`033A<C04`C001F4`033A<C018C00<04a<0gQ<00`0C4`024`0301<C01lC0Pe?4`00

EQ<00`dC4`0B4`0301<C0=hC00<04a<00Q<00`0C4`0M4`8=DA<005LC00<=4a<04A<00`0C4`3M4`80

11<00`0C4`0K4`8=Da<005PC00<=4a<041<20>@C00<04a<061<33EDC001H4`033A<C010C00<04a<0

ha<201LC0PeH4`006Q<302DC1@0B4`033A<C00lC00<04a<091<502@C0`2C4`0301<C01@C0PeJ4`00

6Q<00`0C4`0W4`0301<C018C00<=4a<03a<00`0C4`0V4`0301<C02@C00<04a<0Ta<00`0C4`0B4`8=

G1<001DC0`034`0301<C020C0`034`0301<C01<C00<=4a<03Q<202LC00<04a<09A<00`0C4`2B4`03

01<C00lC0`eN4`006a<00`0C4`0V4`0301<C01<C00<=4a<03Q<00`0C4`0V4`0301<C02DC00<04a<0

TQ<200hC0PeQ4`006Q<00`0C000W4`0301<C01@C00<=4a<03A<00`0C4`0V4`0301<C02@C00<04`00

Ta<00`0C4`0:4`<=Ha<001/C00<04a<09A<201LC00<=4a<031<00`0C4`0U4`809a<00`0C4`2B4`03

01<C00HC10eV4`00G1<00`dC4`0<4`80i1<00`0C4`024`@=JQ<005dC00<=4a<02a<00`0C4`3Q4`L=

KQ<005dC00<=4a<02a<00`0C4`1K4`80NA<;3@8C00<04a<0L1<005hC00<=4a<02Q<00`0C4`1J4`03

01<C064C60d=4`0301<C070C000E4dX000<=0000H0064`0301<C02hC<`dU4`0301<C070C000I4`03

01<C00HC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<0

1A<01@0C4a<=00<C00<04a<01A<00a0C4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC

00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00PC00<04a<0QQ<00`0C

4`1`4`00H1<00`dC4`084`0341<C05XC00<04`00QQ<204lC2@dI4`00HA<00`dC4`074`8@Fa<308HC

00<04a<0<A<M3B8C001Q4`033A<C00LC0Q3E4`0301<C008C00<04a<00Q<00`0C4`024`0301<C02DC

30do4`00HQ<00`dC4`054`03400@0=@C00<04`001a<00`0C00034`0301<C01lC1Pe;4`00HQ<00`dC

4`054`03400@0<lC0`024`0301<000TC00@04a<C0P0K4`D=DA<006<C00<=4a<011<00a00403D4`03

01<000LC0P044`0301<C01HC10eF4`00I1<00`dC4`024`0541<00100da<00`0C00074`0301<C00<C

00<04a<051<23EXC001T4`033A<C008C00D@4`0C403D4`0301<C00HC0`034`0301<C018C0PeL4`00

IA<02@dC4a<@4`0C403S4`0301<C00lC0`eN4`00IQ<01PdC4a0C008C00<@4a<0h1<200hC0PeQ4`00

IQ<01@dC4a0C008000<C41<0hA<00`0C4`0;4`8=Ha<006LC00D=4a0C00024`0341<C0>0C00<04a<0

2Q<00`dC4`1S4`00Ia<01@d@4a<000<C00<@4a<0ga<00`0C4`094`033A<C06@C001X4`043A<C00<C

00<@4a<0ga<200TC00<=4a<0IA<006PC00<@3A<00P024`0341<C0=lC00<04a<01a<00`dC4`1V4`00

Ia<01A0C3A<000@C00<@4a<0gQ<00`0C4`064`033A<C06LC001L4`0301<C008C00<04a<00Q<01P0@

4a<=00@C00<@4a<0Qa<302PC1@0W4`0301<C00DC00<=4a<07a<502PC0`0I4`00Fa<00`0C00074`03

0100008C00<=01<00a<00a0C4`274`0301<C02XC00<04a<09a<200DC00<=4a<08Q<00`0C4`0X4`03

01<C01TC001K4`0301<000PC00<@01<00Q<00`d04`034`0341<C084C0`034`0301<C02<C0`034`03

01<C02LC00<04a<00a<00`dC4`0S4`0301<C02TC00<04a<061<005/C00<04`001a<00`0@4`034`03

00dC00<C00<@4a<0Qa<00`0C4`0Y4`0301<C02LC00<04a<00Q<00`dC4`0T4`0301<C02TC00<04a<0

61<005/C00<04`001a<00a0C4`034`0300dC00@C00<@4a<0QA<00`0C000Z4`0301<C02LC00D04a<C

3@0W4`0301<C02PC00<04`006A<005`C00<04a<01Q<00a0000034`0301<=00@C00<@4a<0QQ<00`0C

4`0X4`80:A<01@0C4a<=02HC0P0[4`0301<C01PC001T4`0341<C00@C0P000a<=4`024`0341<C0=`C

0P000a<=4`1^4`00I1<00a0C4`044`0401<C3@@C00<@4a<0fa<00`0C3@1`4`00Ha<00a0C4`054`05

01<C4`d00a<00a0C4`3K4`0301<=06<C0P0;4`00Ha<00a0C4`054`0501<C4`d011<00a0C4`3J4`03

00dC068C00<04a<02a<0068C00<@4a<01Q<00`0C4`024`053A<C4a00Oa=N00033@0005X01a<00`0C

4`0;4`00HQ<00a0C4`064`8011<01@dC4a<@08<C00<04a<01Q<00`0C4`054`0301<C00HC00<04a<0

1Q<00`0C4`064`0301<C00HC00<04a<01Q<00`0C4`054`0301<C00HC00<04a<01Q<00`dC4`064`03

01<C00HC00<04a<01Q<00`0C4`054`0301<C00HC00<04a<01Q<00`0C4`064`0301<C00HC00<04a<0

1Q<00`0C4`064`0301<C00TC00<04a<02a<0064C00<@4a<01a<00`0C4`034`053A<C4a00fa<00`dC

4`1R4`0301<000/C001Q4`0341<C00LC00<04a<011<010dC4a3J4`033@0C06<C0`0;4`00H1<00a0C

4`084`0301<C00DC00@=4a<@fA<00`d04`1a4`00H1<00a0C4`084`801Q<010dC4a3H4`043A<0074C

001O4`0341<C00TC00<04a<01Q<010dC4a3G4`033A<0078C001O4`0341<C00TC00<04a<01a<00`dC

403G4`033A<0078C001N4`0341<C00XC00<04a<01a<010dC4a3F4`033A<0078C001N4`0341<C00XC

0P094`033A<@0=DC00<=4a<00P1a4`00GA<00a0C4`0;4`0301<C00PC00@=4a<@e1<010dC4`1b4`00

GA<00a0C4`044`D00Q<00`0C4`094`033A<@0=@C00@=4a<0LQ<005`C00<@4a<01a<00`0C4`024`03

01<C00XC00<=4a00da<010dC4`1b4`00Fa<00a0C4`084`0301<C008C0P0;4`043A<C4=8C00@=4a<0

LQ<005/C00<@4a<021<00`0C4`024`0301<C00/C00<=4a00dA<010dC4a<2074C001J4`0341<C00TC

00<04a<00Q<00`0C4`0<4`033A<@0=0C00D=4a<C001b4`00FQ<00a0C4`084`8011<00`0C4`0<4`04

3A<C4<lC00D=4a<C001b4`00FA<00a0C4`0?4`803Q<00`dC403?4`053A<C4`00LQ<005PC00<@4a<0

41<00`0C4`0=4`043A<C4<hC00@=4a<C0P1a4`00F1<00a0C4`0@4`0301<C00hC00@=4a<@cQ<010dC

4`1b4`00Ea<00a0C4`0A4`0301<C00hC00@=4a<@`Q<00`0C4`024`0301<C008C00<04`d00Q<00`0C

4`1`4`00EQ<00a0C4`0B4`8041<010dC4a304`0301<000LC00@04`0=0Q<00`0C4`1`4`00EQ<00a0C

4`0B4`0301<C010C00@=4a<@_a<00`0C00094`0400dC4`80LA<005DC00<@4a<04a<00`0C4`0@4`04

3A<C4;lC00<04`001a<200054`dC4`00LQ<005@C00<@4a<051<00`0C4`0A4`043A<C4;hC00<04`00

1a<01`0C4a<=4`00LQ<005<C00<@4a<05A<2018C00@=4a<@_a<00`0C4`064`<000@C3A<0LQ<005<C

00<@4a<05A<00`0C4`0B4`043A<C4</C00<=4`00LQ<0058C00<@4a<05Q<00`0C4`0C4`043A<C4<XC

00@=4`00LA<0054C00<@4a<05a<00`0C4`0C4`043A<C4</C00<=01<0LA<0054C00<@4a<05a<201DC

00@=4a<@bQ<00`d04`1a4`00D1<00a0C4`0H4`0301<C01DC00<=4a00ba<00`dC4`1`4`00Ca<00a0C

4`084`D00Q<00`0C4`024`0301<C008C00<04a<05A<010dC4a3:4`033@0C070C001?4`0341<C00XC

00<04a<01Q<00`0C00034`0301<C01HC00@=4a<@bA<00`0=4`1`4`00CQ<00a0C4`0;4`0301<C00PC

00@04a<C0P0G4`053A<C4a00b1<00`0=4`1`4`00CA<00a0C4`0<4`0301<C00HC0P044`0301<C01LC

00@=4a<@b1<00`0C3@1`4`00C1<00a0C4`0=4`0301<C00HC00<04a<00a<00`0C4`0H4`043A<C4<LC

00<04`d0L1<004`C00<@4a<031<200PC0`034`0301<C01PC00D=4a<C40364`8000<C3A<0KQ<004/C

00<@4a<07A<201XC00D=4a<C40354`0501<C4`d0KQ<004XC00<@4a<07Q<00`0C4`0J4`043A<C4<DC

00D04a<C3@1^4`00BQ<00a0C4`0N4`0301<C01XC00D=4a<C40344`0301<C008C00<=4a<0Ja<004TC

00<@4a<07a<00`0C4`0K4`053A<C4a00`a<200<C00<=4a<0Ja<004PC00<@4a<081<201`C00<=4a<0

0Q<00a0C4`304`0301<C00<C00<=4a<0JQ<004LC00<@4a<08A<00`0C4`0L4`033A<C008C00<@4a<0

_a<00`0C4`044`033A<C06TC00174`0341<C024C00<04a<071<00`dC4`024`0341<C0;PC1@024`03

01<C00DC00<=4a<0J1<004HC00<@4a<08Q<00`0C4`0M4`033A<C008C00<@4a<0^A<00`0C4`024`03

01<C00DC00<=4a<0J1<004DC00<@4a<08a<201hC00<=4a<00a<00a0C4`2h4`0301<C008C0P074`03

3A<C06LC00144`0341<C02@C00<04a<07Q<00`dC4`034`0341<C0;LC00<04a<00Q<00`0C4`074`03

3A<C06HC00144`0341<C02@C00<04a<07Q<00`dC4`034`0341<C0;LC00<04a<00Q<00`0C4`084`03

3A<C06DC00134`0341<C02DC00<04a<07a<00`dC4`034`0341<C0;DC0P044`0301<C00TC00<=4a<0

I1<0048C00<@4a<09Q<00`0C4`0P4`033A<C00<C00<@4a<0^Q<200XC00<=4a<0I1<0044C00<@4a<0

9a<2024C00<=4a<011<00a0C4`2i4`0301<C00XC00<=4a<0Ha<0040C00<@4a<0:1<00`0C4`0Q4`03

3A<C00@C00<@4a<0^1<00`0C4`0;4`033A<C068C00104`0341<C028C0`034`0301<C028C00<=4a<0

11<00a0C4`2g4`0301<C00`C00<=4a<0HA<003lC00<@4a<08a<00`0C4`034`0301<C028C00<=4a<0

11<00a0C4`2g4`803Q<00`dC4`1P4`00?Q<00a0C4`0U4`0301<C008C0P0T4`033A<C00@C00<@4a<0

]Q<00`0C4`0>4`033A<C05lC000m4`0341<C02HC00<04a<00Q<00`0C4`0S4`033A<C00DC00<@4a<0

]A<00`0C4`0?4`033A<C05hC000m4`0341<C02DC00<04`000a<00`0C4`0T4`033A<C00DC00<@4a<0

]1<00`0C4`0@4`033A<C05dC000l4`0341<C02LC00<04a<00Q<00`0C4`0U4`033A<C00DC00<@4a<0

/a<00`0C4`0A4`8=GA<003/C00<@4a<0;A<202HC00<=4a<01Q<00a0C4`2b4`8051<00`dC4`1J4`00

>Q<00a0C4`0^4`0301<C02HC00<=4a<01A<00a0C4`2b4`0301<C01@C0PeJ4`00>Q<00a0C4`0^4`03

01<C02LC00<=4a<01A<00a0C4`2a4`0301<C01HC00<=4a<0Ea<003TC00<@4a<0;a<00`0C4`0W4`03

3A<C00HC00<@4a<0/1<00`0C4`0G4`8=Ea<003PC00<@4a<0<1<202TC00<=4a<01Q<00a0C4`2_4`80

6Q<00`dC4`1D4`00=a<00a0C4`0a4`0301<C02TC00<=4a<01A<00a0C4`2_4`0301<C01XC0PeD4`00

=a<00a0C4`0a4`0301<C02TC00<=4a<01Q<00a0C4`2^4`0301<C01`C00<=4a<0DA<003HC00<@4a<0

<Q<00`0C4`0Z4`033A<C00HC00<@4a<0W1<5008C00<04a<00Q<00`0C4`024`0301<C01dC00<=4a<0

D1<003DC00<@4a<0<a<202/C00<=4a<01a<00a0C4`2M4`0301<C00HC00<04`000a<00`0C4`0N4`8=

D1<003@C00<@4a<0=1<00`0C4`0[4`033A<C00LC00<@4a<0W1<00`0C4`084`0401<C4`808A<00`dC

4`1=4`00<a<00a0C4`0e4`0301<C02`C00<=4a<01a<00a0C4`2K4`0301<C00HC0P044`0301<C024C

00<=4a<0C1<0038C00<@4a<0=Q<00`0C4`0/4`033A<C00LC00<@4a<0Va<00`0C4`064`0301<C00<C

00<04a<08Q<23D`C000a4`0341<C03LC0P0^4`033A<C00LC00<@4a<0VA<200PC0`034`0301<C02@C

00<=4a<0BA<0030C00<@4a<0>1<00`0C4`0^4`033A<C00LC00<@4a<0Z1<202HC0Pe94`00;a<00a0C

4`0Y4`<00a<00`0C4`024`0301<C008C00<04a<0;Q<00`dC4`084`0341<C0:LC00<04a<09a<00`dC

4`164`00;Q<00a0C4`0Z4`0301<C00LC00<04`000a<00`0C4`0_4`033A<C00PC00<@4a<0YQ<00`0C

4`0X4`8=AQ<002dC00<@4a<0;1<00`0C4`084`0401<C4`80<A<00`dC4`084`0341<C0:DC00<04a<0

:Q<00`dC4`134`00;1<00a0C4`0]4`0301<C00HC0P044`0301<C030C00<=4a<02A<00a0C4`2T4`80

;1<23D<C000[4`0341<C02dC00<04`001a<00`0C4`034`0301<C034C00<=4a<02A<00a0C4`2S4`03

01<C02dC00<=4a<0@1<002XC00<@4a<0;a<00`0C4`064`<00a<00`0C4`0a4`033A<C00XC00<@4a<0

XQ<00`0C4`0^4`8=@1<002TC00<@4a<0?a<203<C00<=4a<02Q<00a0C4`2Q4`0301<C030C0Pdn4`00

:1<00a0C4`104`0301<C03<C00<=4a<02Q<00a0C4`2P4`0301<C038C0Pdl4`009a<00a0C4`114`03

01<C03<C00<=4a<02a<00a0C4`2O4`80=A<23CXC000V4`0341<C048C00<04a<0=1<00`dC4`0;4`03

41<C09hC00<04a<0=Q<23CPC000U4`0341<C04<C0P0f4`033A<C00/C00<@4a<0WA<00`0C4`0h4`8=

=Q<002@C00<@4a<0A1<00`0C4`0e4`033A<C00`C00<@4a<0W1<00`0C4`0j4`8==1<002<C00<@4a<0

AA<00`0C4`0f4`033A<C00`C00<@4a<0Va<203dC0Pdb4`008a<00a0C4`154`0301<C03HC00<=4a<0

3A<00a0C4`2J4`0301<C03hC00<=4a<0;a<0028C00<@4a<0AQ<203PC00<=4a<03A<00a0C4`2I4`03

01<C03lC0Pd_4`008A<00a0C4`174`0301<C03LC00<=4a<03Q<00a0C4`2B4`<00a<00`0C4`114`8=

;A<0020C00<@4a<0B1<00`0C4`0h4`033A<C00hC00<@4a<0TA<00`0C4`034`0301<C04<C0Pd[4`00

7a<00a0C4`194`0301<C03TC00<=4a<03Q<00a0C4`2A4`0301<C008C0P164`8=:A<001hC00<@4a<0

BQ<203XC00<=4a<03a<00a0C4`2@4`0301<C008C00<04a<0Aa<23BLC000M4`0341<C04/C00<04a<0

>Q<00`dC4`0?4`0341<C08hC00<04`000a<00`0C4`194`8=9A<001`C00<@4a<0C1<00`0C4`0j4`03

3A<C010C00<@4a<0SQ<00`0C4`024`0301<C04/C0`dR4`006a<00a0C4`174`8011<00`0C4`0k4`03

3A<C010C00<@4a<0TQ<204lC0`dO4`006Q<00a0C4`1:4`0501<C4`00?A<00`dC4`0A4`0341<C094C

00<04a<0DA<23AdC000I4`0341<C04XC00<04a<00Q<203dC00<=4a<041<00a0C4`2A4`0301<C05<C

0PdK4`00Ia<00`0C4`3W4`0301<C05DC0PdI4`00IA<00`0C003Y4`0301<C070C001V4`0301<C0>PC

0P1a4`00:Q<30?lC9A<00`0C4`1`4`00:Q<00`0C4`3o4bDC00<04a<0L1<002/C00<04a<011<00`0C

4`3o4i0C000[4`0401<C4`@00a<30?lCS1<002XC00<04`000Q<200034`0C00@C00<04a<0oa>:4`00

:a<00`0C4`034`0301<000<C00<04a<0oa>;4`00<A<00`0C00044`0301<C00HC00<04a<09a<302/C

00<04a<0oa<Y4`006a<300034`00008031<300@C0`084`0301<C02HC00@04a<03a<300034`000080

0Q<00`0C4`024`0301<C008C00<04a<01A<0100C4a<5008C00@04a<C0P034`<00a<00`0C4`044`80

aA<00`0C4`0g4`0301<C00HC000J4`0401<C02@C00<04a<09A<0100C4`0>4`0401<C00HC00<04`00

1a<00`0C00044`D00a<00`0C4`064`0301<0008C00<04a<00Q<00`0C00044`0301<C0;dC00<04a<0

11<00`0C4`0C4`0301<C02<C00<04a<01A<001XC00D04a<04`0400034`0001P0;A<300hC00D04a<0

4`0400044`0C00TC00<04a<011<00`0C4`034`0301<C00HC00<04`000a<00`0C4`034`0301<C008C

00<04a<0Za<0100C4a<4008C0P064`0301<C00<C00<04a<00Q<00`0C4`024`0301<C008C00<04a<0

1A<0100C4a<5008C00@04a<C0P034`<00a<00`0C4`044`8011<0100C4a<2004C000K4`<0Ca<00`0C

4`0=4`<01Q<00`0C00074`801a<00`0C4`034`0301<C00HC0P044`0401<C4`801A<00`0C4`2Z4`03

01<000LC00<04a<011<500<C00L04a<C01<000LC00<04`0011<500<C00<04a<01Q<00`0C00024`03

01<C008C00<04`0011<00`0C4`044`0301<C008C0@014`007A<00`0C4`1<4`804A<00`0C4`044`03

01<000LC00<04a<031<00`0C4`064`0301<C008C00<04`000Q<00`0C4`044`0301<00:XC00<04`00

0Q<400034`0C00LC00<04a<00a<01`0C4a<04`002A<00`0C4`044`0301<C00<C00<04a<01Q<00`0C

00034`0301<C00<C00<04a<00Q<00`0C4`044`0301<C00<C0@0001`C0P1P4`801a<00`0C4`064`<0

2a<200TC0P034`0401<C4`<011<309<C0P000a<0000B4`0301<000LC00<04a<01Q<00`0C4`034`07

01<C4`0C00074`801a<00`0C4`034`0301<C00HC0P044`0401<C4`801A<00`0C4`044`0301<C00<C

0@000?lCDA<00`0C000C4`0301<000LC00<04`003A<01P0C4`0C00LC00<04a<031<00`0C4`064`03

01<C008C00<04`000Q<00`0C4`044`0301<000<C00<04a<00a<1004C000V4`801Q<20?lC8Q<00`0C

4`0C4`0301<C00HC0`0>4`0401<C00PC0`0;4`802A<200<C00@04a<C0`044`<00Q<00`0C4`034`80

0A<002PC00<04a<00Q<00`0C4`3o4b8C00<04a<0L1<002LC00<04a<00a<00`0C4`064`0301<C0?lC

61<00`0C001a4`00:1<00`0C4`024`0301<C008C0`0011<04a<30?lC51<200034`00070C000V4`03

01<000@C00<04`000Q<2008C00<04a<00Q<00`0C4`3o4hLC000W4`0301<C00<C0`044`0401<C008C

00<04a<0oa>84`00=1<0100C4`034`0301<C0?lCQa<0038C0`044`<0oa>94`00oa?54`00oa?54`00

oa?54`00oa?54`00oa?54`00\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.63574, -1.77851, 0.0226181, 0.0226181}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -82 0 ]

[.5 .96488 82 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -143 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.62) show

217.250000 19.500000 moveto

(C) show

222.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.27954 0 m

.30316 .03825 L

.34309 .10294 L

.3815 .16517 L

.42237 .23138 L

.46172 .29512 L

.49955 .35642 L

.53984 .42168 L

.57861 .48449 L

.61984 .55128 L

.65954 .6156 L

.69774 .67748 L

.73838 .74332 L

.77751 .80671 L

.81909 .87408 L

.85916 .93898 L

s

.85916 .93898 m

.86743 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.39614 0.238095 [

[.02381 .38364 -6 -9 ]

[.02381 .38364 6 0 ]

[.2619 .38364 -6 -9 ]

[.2619 .38364 6 0 ]

[.7381 .38364 -3 -9 ]

[.7381 .38364 3 0 ]

[.97619 .38364 -3 -9 ]

[.97619 .38364 3 0 ]

[1.025 .39614 0 -8 ]

[1.025 .39614 9 8 ]

[.4875 .039 -24 -4.5 ]

[.4875 .039 0 4.5 ]

[.4875 .15804 -12 -4.5 ]

[.4875 .15804 0 4.5 ]

[.4875 .27709 -24 -4.5 ]

[.4875 .27709 0 4.5 ]

[.4875 .51519 -18 -4.5 ]

[.4875 .51519 0 4.5 ]

[.4875 .63423 -6 -4.5 ]

[.4875 .63423 0 4.5 ]

[.4875 .75328 -18 -4.5 ]

[.4875 .75328 0 4.5 ]

[.4875 .87233 -6 -4.5 ]

[.4875 .87233 0 4.5 ]

[.5 .95765 -4.5 0 ]

[.5 .95765 4.5 16 ]

[.5 .94515 -134.5 0 ]

[.5 .94515 134.5 16 ]

[ 0 0 0 0 ]

[ 1 .93265 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .39614 m

.02381 .40239 L

s

[(-2)] .02381 .38364 0 1 Mshowa

.2619 .39614 m

.2619 .40239 L

s

[(-1)] .2619 .38364 0 1 Mshowa

.7381 .39614 m

.7381 .40239 L

s

[(1)] .7381 .38364 0 1 Mshowa

.97619 .39614 m

.97619 .40239 L

s

[(2)] .97619 .38364 0 1 Mshowa

.125 Mabswid

.07143 .39614 m

.07143 .39989 L

s

.11905 .39614 m

.11905 .39989 L

s

.16667 .39614 m

.16667 .39989 L

s

.21429 .39614 m

.21429 .39989 L

s

.30952 .39614 m

.30952 .39989 L

s

.35714 .39614 m

.35714 .39989 L

s

.40476 .39614 m

.40476 .39989 L

s

.45238 .39614 m

.45238 .39989 L

s

.54762 .39614 m

.54762 .39989 L

s

.59524 .39614 m

.59524 .39989 L

s

.64286 .39614 m

.64286 .39989 L

s

.69048 .39614 m

.69048 .39989 L

s

.78571 .39614 m

.78571 .39989 L

s

.83333 .39614 m

.83333 .39989 L

s

.88095 .39614 m

.88095 .39989 L

s

.92857 .39614 m

.92857 .39989 L

s

.25 Mabswid

0 .39614 m

1 .39614 L

s

gsave

1.025 .39614 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .039 m

.50625 .039 L

s

[(-1.5)] .4875 .039 1 0 Mshowa

.5 .15804 m

.50625 .15804 L

s

[(-1)] .4875 .15804 1 0 Mshowa

.5 .27709 m

.50625 .27709 L

s

[(-0.5)] .4875 .27709 1 0 Mshowa

.5 .51519 m

.50625 .51519 L

s

[(0.5)] .4875 .51519 1 0 Mshowa

.5 .63423 m

.50625 .63423 L

s

[(1)] .4875 .63423 1 0 Mshowa

.5 .75328 m

.50625 .75328 L

s

[(1.5)] .4875 .75328 1 0 Mshowa

.5 .87233 m

.50625 .87233 L

s

[(2)] .4875 .87233 1 0 Mshowa

.125 Mabswid

.5 .06281 m

.50375 .06281 L

s

.5 .08662 m

.50375 .08662 L

s

.5 .11043 m

.50375 .11043 L

s

.5 .13423 m

.50375 .13423 L

s

.5 .18185 m

.50375 .18185 L

s

.5 .20566 m

.50375 .20566 L

s

.5 .22947 m

.50375 .22947 L

s

.5 .25328 m

.50375 .25328 L

s

.5 .3009 m

.50375 .3009 L

s

.5 .32471 m

.50375 .32471 L

s

.5 .34852 m

.50375 .34852 L

s

.5 .37233 m

.50375 .37233 L

s

.5 .41995 m

.50375 .41995 L

s

.5 .44376 m

.50375 .44376 L

s

.5 .46757 m

.50375 .46757 L

s

.5 .49138 m

.50375 .49138 L

s

.5 .539 m

.50375 .539 L

s

.5 .56281 m

.50375 .56281 L

s

.5 .58662 m

.50375 .58662 L

s

.5 .61043 m

.50375 .61043 L

s

.5 .65804 m

.50375 .65804 L

s

.5 .68185 m

.50375 .68185 L

s

.5 .70566 m

.50375 .70566 L

s

.5 .72947 m

.50375 .72947 L

s

.5 .77709 m

.50375 .77709 L

s

.5 .8009 m

.50375 .8009 L

s

.5 .82471 m

.50375 .82471 L

s

.5 .84852 m

.50375 .84852 L

s

.5 .01519 m

.50375 .01519 L

s

.5 .89614 m

.50375 .89614 L

s

.5 .91995 m

.50375 .91995 L

s

.25 Mabswid

.5 0 m

.5 .93265 L

s

gsave

.5 .95765 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .94515 -195.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.62) show

293.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

298.000000 15.000000 moveto

(L) show

305.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

312.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

319.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

324.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

328.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .93265 L

0 .93265 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .2447 m

.02576 .24469 L

.03158 .24464 L

.04117 .24457 L

.05436 .24446 L

.07094 .24431 L

.09061 .24413 L

.11303 .2439 L

.13784 .24362 L

.16459 .24328 L

.19284 .24288 L

.2221 .24241 L

.25187 .24185 L

.28163 .24119 L

.31089 .24042 L

.33914 .23953 L

.3659 .23851 L

.3907 .23736 L

.41313 .23611 L

.4328 .23479 L

.44937 .23347 L

.46256 .23226 L

.47215 .23128 L

.47797 .23063 L

.47992 .2304 L

s

.47992 .2304 m

.48205 .23015 L

.48838 .22937 L

.49881 .22795 L

.51317 .22572 L

.5312 .22235 L

.5526 .21739 L

.577 .21022 L

.60399 .2003 L

.6331 .18755 L

.66384 .17252 L

.69567 .15614 L

.72806 .13928 L

.76045 .12259 L

.79228 .10654 L

.82301 .09145 L

.85212 .07753 L

.87911 .06496 L

.90351 .05386 L

.92491 .04433 L

.94295 .03644 L

.9573 .03024 L

.96774 .02579 L

.97407 .0231 L

.97619 .02221 L

s

.47992 .47895 m

.48205 .45163 L

.48838 .42473 L

.49881 .39856 L

.51317 .37346 L

.5312 .34989 L

.5526 .32845 L

.577 .30988 L

.60399 .29484 L

.6331 .28352 L

.66384 .27549 L

.69567 .26993 L

.72806 .26606 L

.76045 .26332 L

.79228 .26133 L

.82301 .25986 L

.85212 .25874 L

.87911 .2579 L

.90351 .25725 L

.92491 .25675 L

.94295 .25637 L

.9573 .2561 L

.96774 .25592 L

.97407 .25581 L

.97619 .25577 L

s

.47992 .47907 m

.48205 .50663 L

.48838 .53432 L

.49881 .56191 L

.51317 .58924 L

.5312 .61618 L

.5526 .64258 L

.577 .66832 L

.60399 .69328 L

.6331 .71735 L

.66384 .7404 L

.69567 .76235 L

.72806 .78308 L

.76045 .80251 L

.79228 .82055 L

.82301 .83712 L

.85212 .85214 L

.87911 .86556 L

.90351 .87731 L

.92491 .88734 L

.94295 .89561 L

.9573 .90208 L

.96774 .90672 L

.97407 .90951 L

.97619 .91044 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<00`0C4`1`4`00oa=B4`0301<C070C001T4`D0j1<2074C001V4`0301<C0>PC00<04a<0

L1<004DC00<=4a<061<300<C00<04a<00Q<20>@C00<04a<0E1<33ATC00164`033A<C01dC00<04a<0

0Q<00`0C4`3B4`D00Q<00`0C4`024`0301<C008C00<04a<0DA<33A`C00164`033A<C01dC00<04a<0

0Q<00`0C4`3D4`0301<C00HC00<04`000a<00`0C4`1?4`8=7a<004LC00<=4a<06a<200@C00<04a<0

cQ<300<C00<04a<021<0100C4a<204hC0PdQ4`00Aa<00`dC4`0Q4`80eA<00`0C4`064`8011<00`0C

4`1<4`033A<C024C00184`033A<C020C00<04a<0e1<00`0C4`064`0301<C00<C00<04a<0BQ<23B@C

00184`033A<C020C00<04a<0da<200PC0`034`0301<C04PC0PdV4`00BA<00`dC4`0O4`0301<C0><C

0P174`8=:1<004XC00<=4a<07Q<20>@C00<04a<0@a<33BXC001:4`033A<C01hC00<04a<0ha<00`0C

4`114`8=;A<004/C00<=4a<07A<00`0C4`3S4`0301<C03lC0Pd_4`00C1<00`dC4`0L4`0301<C0><C

00<04a<0?A<23C4C001<4`033A<C01`C0P3T4`80?1<23C<C001=4`033A<C01/C00<04a<0ha<00`0C

4`0h4`<==A<004dC00<=4a<06a<00`0C4`3S4`0301<C03DC0`dh4`00CQ<00`dC4`0J4`0301<C0><C

00<04a<0<a<23C/C001?4`033A<C01TC0P3T4`80<Q<23CdC001?4`033A<C01TC00<04a<0ha<00`0C

4`0_4`8=?a<0050C00<=4a<02A<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`3S4`0301<C02hC

00<=4a<0?a<0054C00<=4a<01a<00`0C00074`0301<000<C00<04a<0ha<00`0C4`0/4`8=@Q<0054C

00<=4a<00Q<3008C00<04`002A<0100C4a<20>@C00<04a<0:Q<23D@C001B4`033A<C00HC00<04`00

1a<200@C00<04a<0ha<202TC0Pe64`00Da<00`dC4`054`0301<000LC00<04a<00a<00`0C4`3S4`03

01<C02HC0Pe84`00Da<00`dC4`064`0301<C00HC0`034`0301<C0=`C1@024`0301<C02@C0Pe:4`00

E1<00`dC4`0D4`0301<C0=hC00<04a<00Q<00`0C4`0R4`8=C1<005DC00<=4a<04a<20=TC0`034`03

01<C008C0P0R4`033A<C04`C001F4`033A<C018C00<04a<0gQ<00`0C4`024`0301<C01lC0Pe?4`00

EQ<00`dC4`0B4`0301<C0=hC00<04a<00Q<00`0C4`0M4`8=DA<005LC00<=4a<04A<00`0C4`3M4`80

11<00`0C4`0K4`8=Da<005PC00<=4a<041<20>@C0P0I4`<=EA<005PC00<=4a<041<00`0C4`3S4`03

01<C01HC0PeH4`006Q<302DC1@0B4`033A<C00lC00<04a<091<502@C0`2C4`0301<C01@C0PeJ4`00

6Q<00`0C4`0W4`0301<C018C00<=4a<03a<00`0C4`0V4`0301<C02@C00<04a<0Ta<00`0C4`0B4`8=

G1<001DC0`034`0301<C020C0`034`0301<C01<C00<=4a<03Q<202LC00<04a<09A<00`0C4`2B4`03

01<C00lC0`eN4`006a<00`0C4`0V4`0301<C01<C00<=4a<03Q<00`0C4`0V4`0301<C02DC00<04a<0

TQ<200hC0PeQ4`006Q<00`0C000W4`0301<C01@C00<=4a<03A<00`0C4`0V4`0301<C02@C00<04`00

Ta<00`0C4`0:4`<=Ha<001/C00<04a<09A<201LC00<=4a<031<00`0C4`0U4`809a<00`0C4`2B4`03

01<C00HC10eV4`00G1<00`dC4`0<4`80i1<00`0C4`024`@=JQ<005dC00<=4a<02a<00`0C4`3O4`T=

KQ<005dC00<=4a<02a<00`0C4`1K4`80MA<=3@@C00<04a<0L1<005hC00<=4a<02Q<00`0C4`1J4`03

01<C05/C6PdA4`0301<C070C000E4dX000<=0000H0064`0301<C02hC;@d[4`0301<C070C000I4`03

01<C00HC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<0

1A<01@0C4a<=00<C00<04a<01A<00a0C4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC

00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00PC00<04a<0QQ<00`0C

4`1`4`00H1<00`dC4`084`0341<C05XC00<04`00QQ<204PC40dI4`00HA<00`dC4`074`8@Fa<308HC

00<04a<0<A<F3BTC001Q4`033A<C00LC0Q3E4`0301<C008C00<04a<00Q<00`0C4`024`0301<C02DC

30do4`00HQ<00`dC4`054`03400@0=@C00<04`001a<00`0C00034`0301<C01lC1Pe;4`00HQ<00`dC

4`054`03400@0<lC0`024`0301<000TC00@04a<C0P0K4`D=DA<006<C00<=4a<011<00a00403D4`03

01<000LC0P044`0301<C01DC1@eF4`00I1<00`dC4`024`0541<00100da<00`0C00074`0301<C00<C

00<04a<04Q<33E/C001T4`033A<C008C00D@4`0C403D4`0301<C00HC0`034`0301<C010C0PeN4`00

IA<02@dC4a<@4`0C403S4`0301<C00hC0PeP4`00IQ<01PdC4a0C008C00<@4a<0h1<200dC0PeR4`00

IQ<01@dC4a0C008000<C41<0hA<00`0C4`0;4`033A<C068C001W4`053A<@4`000Q<00a0C4`3P4`03

01<C00XC00<=4a<0Ha<006LC00D=41<C00034`0341<C0=lC00<04a<02A<00`dC4`1T4`00J1<010dC

4`034`0341<C0=lC0P094`033A<C06DC001X4`0340dC00800Q<00a0C4`3O4`0301<C00LC00<=4a<0

IQ<006LC00D@4`dC00044`0341<C0=hC00<04a<01Q<00`dC4`1W4`00G1<00`0C4`024`0301<C008C

00H041<C3@044`0341<C08LC0`0X4`D09a<00`0C4`054`033A<C01lC1@0X4`<06A<005/C00<04`00

1a<00`0@00024`033@0C00<C00<@4a<0Qa<00`0C4`0Z4`0301<C02LC0P054`033A<C028C00<04a<0

:1<00`0C4`0I4`00Fa<00`0C00084`03400C008C00<=01<00a<00a0C4`214`<00a<00`0C4`0S4`<0

0a<00`0C4`0W4`0301<C00<C00<=4a<08a<00`0C4`0Y4`0301<C01PC001K4`0301<000LC00<041<0

0a<00`0=4`034`0341<C08LC00<04a<0:A<00`0C4`0W4`0301<C008C00<=4a<091<00`0C4`0Y4`03

01<C01PC001K4`0301<000LC00<@4a<00a<00`0=4`044`0341<C08DC00<04`00:Q<00`0C4`0W4`05

01<C4`d09a<00`0C4`0X4`0301<001TC001L4`0301<C00HC00<@00000a<00`0C3@044`0341<C08HC

00<04a<0:1<202TC00D04a<C3@0V4`80:a<00`0C4`0H4`00I1<00a0C4`044`8000<C3A<00Q<00a0C

4`3L4`8000<C3A<0KQ<006@C00<@4a<011<0100C4`d44`0341<C0=/C00<04`d0L1<006<C00<@4a<0

1A<01@0C4a<=00<C00<@4a<0fa<00`0C3@1S4`802a<006<C00<@4a<01A<01@0C4a<=00@C00<@4a<0

fQ<00`0=4`1R4`0301<C00/C001R4`0341<C00HC00<04a<00Q<01@dC4a<@07lCGP000`d0001J00LC

00<04a<02a<0068C00<@4a<01Q<200@C00D=4a<C40234`0301<C00DC00<04a<01Q<00`0C4`064`03

01<C00HC00<04a<01Q<00`0C4`064`0301<C00HC00<04a<01A<00`0C4`064`0301<C00HC00<=4a<0

1Q<00`0C4`064`0301<C00HC00<04a<01Q<00`0C4`054`0301<C00HC00<04a<01Q<00`0C4`064`03

01<C00HC00<04a<01Q<00`0C4`094`0301<C00/C001Q4`0341<C00LC00<04a<00a<01@dC4a<@0=/C

00<=4a<0HQ<00`0C000;4`00HA<00a0C4`074`0301<C00@C00@=4a<@fQ<00`d04`1S4`<02a<0060C

00<@4a<021<00`0C4`054`043A<C4=TC00<=01<0LA<0060C00<@4a<021<200HC00@=4a<@f1<010dC

001a4`00Ga<00a0C4`094`0301<C00HC00@=4a<@ea<00`dC001b4`00Ga<00a0C4`094`0301<C00LC

00<=4a00ea<00`dC001b4`00GQ<00a0C4`0:4`0301<C00LC00@=4a<@eQ<00`dC001b4`00GQ<00a0C

4`0:4`802A<00`dC403E4`033A<C0080LA<005dC00<@4a<02a<00`0C4`084`043A<C4=@C00@=4a<0

LQ<005dC00<@4a<011<5008C00<04a<02A<00`dC403D4`043A<C078C001L4`0341<C00LC00<04a<0

0Q<00`0C4`0:4`033A<@0=<C00@=4a<0LQ<005/C00<@4a<021<00`0C4`024`802a<010dC4a3B4`04

3A<C078C001K4`0341<C00PC00<04a<00Q<00`0C4`0;4`033A<@0=4C00@=4a<C0P1a4`00FQ<00a0C

4`094`0301<C008C00<04a<031<00`dC403@4`053A<C4`00LQ<005XC00<@4a<021<200@C00<04a<0

31<010dC4a3?4`053A<C4`00LQ<005TC00<@4a<03a<200hC00<=4a00ca<01@dC4a<0078C001H4`03

41<C010C00<04a<03A<010dC4a3>4`043A<C4`80LA<005PC00<@4a<041<00`0C4`0>4`043A<C4<hC

00@=4a<0LQ<005LC00<@4a<04A<00`0C4`0>4`043A<C4<8C00<04a<00Q<00`0C4`024`0301<=008C

00<04a<0L1<005HC00<@4a<04Q<2010C00@=4a<@`1<00`0C00074`0401<03@8C00<04a<0L1<005HC

00<@4a<04Q<00`0C4`0@4`043A<C4;lC00<04`002A<0100=4a<2074C001E4`0341<C01<C00<04a<0

41<010dC4a2o4`0301<000LC0P001A<=4a<0078C001D4`0341<C01@C00<04a<04A<010dC4a2n4`03

01<000LC00L04a<C3A<0078C001C4`0341<C01DC0P0B4`043A<C4;lC00<04a<01Q<300044`dC078C

001C4`0341<C01DC00<04a<04Q<010dC4a3;4`033A<0078C001B4`0341<C01HC00<04a<04a<010dC

4a3:4`043A<0074C001A4`0341<C01LC00<04a<04a<010dC4a3;4`033@0C074C001A4`0341<C01LC

0P0E4`043A<C4<XC00<=01<0LA<0050C00<@4a<061<00`0C4`0E4`033A<@0</C00<=4a<0L1<004lC

00<@4a<021<5008C00<04a<00Q<00`0C4`024`0301<C01DC00@=4a<@bQ<00`d04`1`4`00Ca<00a0C

4`0:4`0301<C00HC00<04`000a<00`0C4`0F4`043A<C4<TC00<03A<0L1<004hC00<@4a<02a<00`0C

4`084`0401<C4`805a<01@dC4a<@0<PC00<03A<0L1<004dC00<@4a<031<00`0C4`064`8011<00`0C

4`0G4`043A<C4<PC00<04`d0L1<004`C00<@4a<03A<00`0C4`064`0301<C00<C00<04a<061<010dC

4a374`0301<=070C001<4`0341<C00`C0P084`<00a<00`0C4`0H4`053A<C4a00aQ<200034`dC06hC

001;4`0341<C01dC0P0J4`053A<C4a00aA<01@0C4a<=06hC001:4`0341<C01hC00<04a<06Q<010dC

4a354`0501<C4`d0KQ<004XC00<@4a<07Q<00`0C4`0J4`053A<C4a00a1<00`0C4`024`033A<C06/C

00194`0341<C01lC00<04a<06a<01@dC4a<@0<<C0P034`033A<C06/C00184`0341<C020C0P0L4`03

3A<C008C00<@4a<0`1<00`0C4`034`033A<C06XC00174`0341<C024C00<04a<071<00`dC4`024`03

41<C0;lC00<04a<011<00`dC4`1Y4`00Aa<00a0C4`0Q4`0301<C01dC00D=4a<C402j4`D00Q<00`0C

4`054`033A<C06PC00164`0341<C028C00<04a<07A<00`dC4`024`0341<C0;TC00<04a<00Q<00`0C

4`054`033A<C06PC00154`0341<C02<C0P0O4`033A<C008C00<@4a<0^1<00`0C4`024`801a<00`dC

4`1W4`00A1<00a0C4`0T4`0301<C01hC00<=4a<00a<00a0C4`2g4`0301<C008C00<04a<01a<00`dC

4`1V4`00A1<00a0C4`0T4`0301<C01lC00<=4a<00Q<00a0C4`2g4`0301<C008C00<04a<021<00`dC

4`1U4`00@a<00a0C4`0U4`0301<C020C00<=4a<00Q<00a0C4`2e4`8011<00`0C4`094`033A<C06@C

00124`0341<C02HC00<04a<081<00`dC4`034`0341<C0;XC0P0:4`033A<C06@C00114`0341<C02LC

0P0R4`033A<C00<C00<@4a<0^A<00`0C4`0:4`033A<C06<C00104`0341<C02PC00<04a<08A<00`dC

4`044`0341<C0;PC00<04a<02a<00`dC4`1R4`00@1<00a0C4`0R4`<00a<00`0C4`0R4`033A<C00@C

00<@4a<0]a<00`0C4`0<4`033A<C064C000o4`0341<C02<C00<04a<00a<00`0C4`0R4`033A<C00@C

00<@4a<0]a<200hC00<=4a<0H1<003hC00<@4a<09A<00`0C4`024`8091<00`dC4`044`0341<C0;HC

00<04a<03Q<00`dC4`1O4`00?A<00a0C4`0V4`0301<C008C00<04a<091<00`dC4`044`0341<C0;DC

00<04a<03a<00`dC4`1N4`00?A<00a0C4`0U4`0301<000<C00<04a<091<00`dC4`054`0341<C0;@C

00<04a<041<00`dC4`1M4`00?1<00a0C4`0W4`0301<C008C00<04a<09A<00`dC4`054`0341<C0;<C

00<04a<04A<23EdC000k4`0341<C02dC0P0V4`033A<C00HC00<@4a<0/Q<201@C00<=4a<0FQ<003XC

00<@4a<0;Q<00`0C4`0V4`033A<C00DC00<@4a<0/Q<00`0C4`0D4`8=FQ<003XC00<@4a<0;Q<00`0C

4`0W4`033A<C00DC00<@4a<0/A<00`0C4`0F4`033A<C05LC000i4`0341<C02lC00<04a<09a<00`dC

4`064`0341<C0;0C00<04a<05a<23ELC000h4`0341<C030C0P0Y4`033A<C00HC00<@4a<0[a<201XC

00<=4a<0E1<003LC00<@4a<0<A<00`0C4`0Y4`033A<C00DC00<@4a<0[a<00`0C4`0J4`8=E1<003LC

00<@4a<0<A<00`0C4`0Y4`033A<C00HC00<@4a<0[Q<00`0C4`0L4`033A<C054C000f4`0341<C038C

00<04a<0:Q<00`dC4`064`0341<C09`C1@024`0301<C008C00<04a<00Q<00`0C4`0M4`033A<C050C

000e4`0341<C03<C0P0[4`033A<C00LC00<@4a<0WA<00`0C4`064`0301<000<C00<04a<07Q<23E0C

000d4`0341<C03@C00<04a<0:a<00`dC4`074`0341<C09`C00<04a<021<0100C4a<2024C00<=4a<0

CA<003<C00<@4a<0=A<00`0C4`0/4`033A<C00LC00<@4a<0Va<00`0C4`064`8011<00`0C4`0Q4`03

3A<C04`C000b4`0341<C03HC00<04a<0;1<00`dC4`074`0341<C09/C00<04a<01Q<00`0C4`034`03

01<C028C0Pe<4`00<A<00a0C4`0g4`80;Q<00`dC4`074`0341<C09TC0P084`<00a<00`0C4`0T4`8=

BQ<0030C00<@4a<0>1<00`0C4`0^4`033A<C00LC00<@4a<0Z1<202LC0Pe84`00;a<00a0C4`0Y4`<0

0a<00`0C4`024`0301<C008C00<04a<0;Q<00`dC4`084`0341<C0:LC00<04a<0:1<00`dC4`154`00

;Q<00a0C4`0Z4`0301<C00LC00<04`000a<00`0C4`0_4`033A<C00PC00<@4a<0YQ<00`0C4`0Y4`8=

AA<002dC00<@4a<0;1<00`0C4`084`0401<C4`80<A<00`dC4`084`0341<C0:DC00<04a<0:a<00`dC

4`124`00;1<00a0C4`0]4`0301<C00HC0P044`0301<C030C00<=4a<02A<00a0C4`2T4`0301<C02`C

0Pe24`00:a<00a0C4`0]4`0301<000LC00<04a<00a<00`0C4`0a4`033A<C00TC00<@4a<0Xa<202lC

00<=4a<0?a<002XC00<@4a<0;a<00`0C4`064`<00a<00`0C4`0a4`033A<C00XC00<@4a<0XQ<00`0C

4`0_4`8=?a<002TC00<@4a<0?a<203<C00<=4a<02Q<00a0C4`2Q4`0301<C034C0Pdm4`00:1<00a0C

4`104`0301<C03<C00<=4a<02Q<00a0C4`2P4`0301<C03<C00<=4a<0>Q<002LC00<@4a<0@A<00`0C

4`0c4`033A<C00/C00<@4a<0Wa<203DC0Pdj4`009Q<00a0C4`124`0301<C03@C00<=4a<02a<00a0C

4`2N4`0301<C03HC0Pdh4`009A<00a0C4`134`80=Q<00`dC4`0;4`0341<C09dC00<04a<0>1<23CHC

000T4`0341<C04@C00<04a<0=A<00`dC4`0<4`0341<C09`C00<04a<0>Q<23C@C000S4`0341<C04DC

00<04a<0=Q<00`dC4`0<4`0341<C09/C0P0m4`8=<Q<002<C00<@4a<0AA<00`0C4`0g4`033A<C00`C

00<@4a<0VQ<00`0C4`0n4`8=<1<0028C00<@4a<0AQ<203PC00<=4a<03A<00a0C4`2I4`0301<C040C

0Pd^4`008A<00a0C4`174`0301<C03PC00<=4a<03A<00a0C4`2B4`<00a<00`0C4`124`8=;1<0020C

00<@4a<0B1<00`0C4`0h4`033A<C00hC00<@4a<0TA<00`0C4`034`0301<C04@C00<=4a<0:A<001lC

00<@4a<0BA<00`0C4`0i4`033A<C00hC00<@4a<0TA<00`0C4`024`80AQ<23BTC000N4`0341<C04XC

0P0k4`033A<C00hC00<@4a<0T1<00`0C4`024`0301<C04LC0PdW4`007A<00a0C4`1;4`0301<C03XC

00<=4a<03a<00a0C4`2>4`0301<000<C00<04a<0BA<23BDC000L4`0341<C04`C00<04a<0>a<00`dC

4`0?4`0341<C08hC00<04a<00Q<00`0C4`1;4`<=8Q<001/C00<@4a<0Aa<200@C00<04a<0>a<00`dC

4`0@4`0341<C098C0P1?4`<=7a<001XC00<@4a<0BQ<01@0C4a<003hC00<=4a<041<00a0C4`2A4`03

01<C054C0PdM4`006A<00a0C4`1:4`0301<C008C0P0m4`033A<C010C00<@4a<0TA<00`0C4`1C4`8=

6a<006LC00<04a<0ia<00`0C4`1E4`8=6A<006DC00<04`00jA<00`0C4`1`4`00IQ<00`0C4`3X4`80

LA<002`C0`3o4b<C00<04a<0L1<002`C00<04a<0oa<S4`0301<C070C000]4`0301<C00DC00<04a<0

oa>=4`00;A<0100C4a<300044`0C4`<0oa>:4`00;1<00`0C00024`800Q<00`0C4`024`0301<C0?lC

R1<002dC00<04a<00a<0100C4`024`0301<C0?lCRA<003<C00@04a<00a<00`0C4`064`0301<C02DC

0`0]4`0301<C0?lC9a<001dC0`000a<0000200`C0`044`<021<00`0C4`0T4`0401<C014C0`000a<0

0002008C00<04a<00Q<00`0C4`024`0301<C00DC00@04a<C1@024`0401<C4`800a<300DC0P3;4`03

01<C038C00<04a<021<001`C00@04a<091<00`0C4`0S4`0401<C010C00@04a<01Q<00`0C00074`03

01<000@C1@034`0301<C00HC00<04`000Q<00`0C4`044`0301<C0<<C00<04a<011<00`0C4`0C4`03

01<C01hC00<04a<01a<001`C00D04a<04`0400034`0001P0:a<3010C00D04a<04`0400044`0C00TC

00<04a<011<00`0C4`034`0301<C00HC00<04`000a<00`0C4`034`0301<C0;4C00@04a<C10024`80

1Q<00`0C4`034`0301<C008C00<04a<00Q<00`0C4`024`0301<C00DC00@04a<C1@024`0401<C4`80

0a<300DC0P044`0401<C4`800A<10040000M4`<0CA<00`0C4`0?4`<01Q<00`0C00074`801a<00`0C

4`034`0301<C00HC0P044`0301<C00<C00<04a<0/1<00`0C00074`0301<C00@C1@034`0701<C4`0C

00074`0301<000@C1@034`0301<C00HC00<04`000Q<00`0C4`044`0301<C00@C00<04a<00Q<00`0C

00014`007a<00`0C4`1:4`804a<00`0C4`044`0301<000LC00<04a<031<00`0C4`064`0301<C008C

00<04`0011<00`0C002`4`0301<0008C10000a<04`074`0301<C00<C00L04a<C01<000TC00<04a<0

11<00`0C4`034`0301<C00HC00<04`000a<00`0C4`034`0301<C00@C00<04a<00a<1004C0A<001hC

0P1P4`801a<00`0C4`064`<02a<200TC0P034`0301<C00<C0`2F4`8000<C00005A<00`0C00074`03

01<C00HC00<04a<00a<01`0C4a<04`001a<200LC00<04a<00a<00`0C4`064`8011<00`0C4`034`03

01<C00@C00<04a<00a<1004C0A<00?lCDA<00`0C000F4`0301<000LC00<04`003A<01P0C4`0C00LC

00<04a<031<00`0C4`064`0301<C008C00<04`0011<00`0C00034`0301<C00<C00<04`000A<002TC

0P064`80oa<O4`0301<C01HC00<04a<01Q<300hC00@04a<021<300/C0P094`800a<00`0C4`034`<0

0Q<00`0C4`034`800A<10040000[4`0301<C008C00<04a<0oa<O4`0301<C070C000Z4`0301<C00<C

00<04a<01A<00`0C4`3o4aHC00<04`00LA<002/C00<04a<00Q<00`0C4`024`@00a<30?lC4A<20003

4`00070C000Y4`0301<000@C00<04`000Q<200034`0C00@C00<04a<0oa>44`00:Q<00`0C4`034`<0

11<00`0C00034`0301<C0?lCQA<003LC00<04`0011<00`0C4`3o4h@C000e4`<011<30?lCQQ<00?lC

aA<00?lCaA<00?lCaA<00?lCaA<00?lCaA<00001\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.62308, -1.77389, 0.0225806, 0.0225806}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -84.5 0 ]

[.5 .96488 84.5 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -145.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.615) show

222.250000 19.500000 moveto

(C) show

227.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.27886 0 m

.30316 .03924 L

.34309 .10373 L

.3815 .16576 L

.42237 .23176 L

.46172 .29532 L

.49955 .35642 L

.53984 .42148 L

.57861 .4841 L

.61984 .55068 L

.65954 .61481 L

.69774 .67649 L

.73838 .74213 L

.77751 .80532 L

.81909 .87248 L

.85916 .93719 L

s

.85916 .93719 m

.86857 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.395077 0.238095 [

[.02381 .38258 -6 -9 ]

[.02381 .38258 6 0 ]

[.2619 .38258 -6 -9 ]

[.2619 .38258 6 0 ]

[.7381 .38258 -3 -9 ]

[.7381 .38258 3 0 ]

[.97619 .38258 -3 -9 ]

[.97619 .38258 3 0 ]

[1.025 .39508 0 -8 ]

[1.025 .39508 9 8 ]

[.4875 .03793 -24 -4.5 ]

[.4875 .03793 0 4.5 ]

[.4875 .15698 -12 -4.5 ]

[.4875 .15698 0 4.5 ]

[.4875 .27603 -24 -4.5 ]

[.4875 .27603 0 4.5 ]

[.4875 .51412 -18 -4.5 ]

[.4875 .51412 0 4.5 ]

[.4875 .63317 -6 -4.5 ]

[.4875 .63317 0 4.5 ]

[.4875 .75222 -18 -4.5 ]

[.4875 .75222 0 4.5 ]

[.4875 .87127 -6 -4.5 ]

[.4875 .87127 0 4.5 ]

[.5 .95605 -4.5 0 ]

[.5 .95605 4.5 16 ]

[.5 .94355 -137 0 ]

[.5 .94355 137 16 ]

[ 0 0 0 0 ]

[ 1 .93105 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .39508 m

.02381 .40133 L

s

[(-2)] .02381 .38258 0 1 Mshowa

.2619 .39508 m

.2619 .40133 L

s

[(-1)] .2619 .38258 0 1 Mshowa

.7381 .39508 m

.7381 .40133 L

s

[(1)] .7381 .38258 0 1 Mshowa

.97619 .39508 m

.97619 .40133 L

s

[(2)] .97619 .38258 0 1 Mshowa

.125 Mabswid

.07143 .39508 m

.07143 .39883 L

s

.11905 .39508 m

.11905 .39883 L

s

.16667 .39508 m

.16667 .39883 L

s

.21429 .39508 m

.21429 .39883 L

s

.30952 .39508 m

.30952 .39883 L

s

.35714 .39508 m

.35714 .39883 L

s

.40476 .39508 m

.40476 .39883 L

s

.45238 .39508 m

.45238 .39883 L

s

.54762 .39508 m

.54762 .39883 L

s

.59524 .39508 m

.59524 .39883 L

s

.64286 .39508 m

.64286 .39883 L

s

.69048 .39508 m

.69048 .39883 L

s

.78571 .39508 m

.78571 .39883 L

s

.83333 .39508 m

.83333 .39883 L

s

.88095 .39508 m

.88095 .39883 L

s

.92857 .39508 m

.92857 .39883 L

s

.25 Mabswid

0 .39508 m

1 .39508 L

s

gsave

1.025 .39508 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .03793 m

.50625 .03793 L

s

[(-1.5)] .4875 .03793 1 0 Mshowa

.5 .15698 m

.50625 .15698 L

s

[(-1)] .4875 .15698 1 0 Mshowa

.5 .27603 m

.50625 .27603 L

s

[(-0.5)] .4875 .27603 1 0 Mshowa

.5 .51412 m

.50625 .51412 L

s

[(0.5)] .4875 .51412 1 0 Mshowa

.5 .63317 m

.50625 .63317 L

s

[(1)] .4875 .63317 1 0 Mshowa

.5 .75222 m

.50625 .75222 L

s

[(1.5)] .4875 .75222 1 0 Mshowa

.5 .87127 m

.50625 .87127 L

s

[(2)] .4875 .87127 1 0 Mshowa

.125 Mabswid

.5 .06174 m

.50375 .06174 L

s

.5 .08555 m

.50375 .08555 L

s

.5 .10936 m

.50375 .10936 L

s

.5 .13317 m

.50375 .13317 L

s

.5 .18079 m

.50375 .18079 L

s

.5 .2046 m

.50375 .2046 L

s

.5 .22841 m

.50375 .22841 L

s

.5 .25222 m

.50375 .25222 L

s

.5 .29984 m

.50375 .29984 L

s

.5 .32365 m

.50375 .32365 L

s

.5 .34746 m

.50375 .34746 L

s

.5 .37127 m

.50375 .37127 L

s

.5 .41889 m

.50375 .41889 L

s

.5 .4427 m

.50375 .4427 L

s

.5 .46651 m

.50375 .46651 L

s

.5 .49031 m

.50375 .49031 L

s

.5 .53793 m

.50375 .53793 L

s

.5 .56174 m

.50375 .56174 L

s

.5 .58555 m

.50375 .58555 L

s

.5 .60936 m

.50375 .60936 L

s

.5 .65698 m

.50375 .65698 L

s

.5 .68079 m

.50375 .68079 L

s

.5 .7046 m

.50375 .7046 L

s

.5 .72841 m

.50375 .72841 L

s

.5 .77603 m

.50375 .77603 L

s

.5 .79984 m

.50375 .79984 L

s

.5 .82365 m

.50375 .82365 L

s

.5 .84746 m

.50375 .84746 L

s

.5 .01412 m

.50375 .01412 L

s

.5 .89508 m

.50375 .89508 L

s

.5 .91889 m

.50375 .91889 L

s

.25 Mabswid

.5 0 m

.5 .93105 L

s

gsave

.5 .95605 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .94355 -198 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.615) show

298.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

303.000000 15.000000 moveto

(L) show

310.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

317.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

324.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

329.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

333.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .93105 L

0 .93105 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .24326 m

.02576 .24324 L

.03158 .2432 L

.04117 .24312 L

.05436 .24302 L

.07093 .24287 L

.0906 .24269 L

.11303 .24247 L

.13783 .24219 L

.16459 .24186 L

.19283 .24147 L

.22209 .24101 L

.25186 .24046 L

.28162 .23981 L

.31088 .23906 L

.33912 .23819 L

.36588 .23719 L

.39068 .23607 L

.41311 .23484 L

.43278 .23356 L

.44935 .23227 L

.46254 .23109 L

.47213 .23013 L

.47795 .2295 L

.4799 .22928 L

s

.4799 .22928 m

.48202 .22904 L

.48836 .22827 L

.49879 .22689 L

.51315 .22471 L

.53118 .22142 L

.55258 .21657 L

.57699 .20954 L

.60397 .19977 L

.63309 .18715 L

.66382 .17222 L

.69566 .1559 L

.72805 .13908 L

.76044 .12243 L

.79227 .1064 L

.82301 .09132 L

.85212 .07743 L

.87911 .06487 L

.90351 .05378 L

.92491 .04426 L

.94295 .03638 L

.9573 .03019 L

.96774 .02574 L

.97407 .02306 L

.97619 .02217 L

s

.4799 .47792 m

.48202 .45062 L

.48836 .42372 L

.49879 .39754 L

.51315 .37241 L

.53118 .3488 L

.55258 .32728 L

.57699 .3086 L

.60397 .29345 L

.63309 .28203 L

.66382 .27394 L

.69566 .26834 L

.72805 .26446 L

.76044 .26171 L

.79227 .25972 L

.82301 .25825 L

.85212 .25714 L

.87911 .2563 L

.90351 .25565 L

.92491 .25516 L

.94295 .25478 L

.9573 .25451 L

.96774 .25433 L

.97407 .25422 L

.97619 .25419 L

s

.4799 .47803 m

.48202 .50558 L

.48836 .53325 L

.49879 .5608 L

.51315 .58811 L

.53118 .61501 L

.55258 .64138 L

.57699 .66709 L

.60397 .69202 L

.63309 .71605 L

.66382 .73908 L

.69566 .76099 L

.72805 .78169 L

.76044 .8011 L

.79227 .81911 L

.82301 .83566 L

.85212 .85066 L

.87911 .86406 L

.90351 .87579 L

.92491 .88581 L

.94295 .89407 L

.9573 .90052 L

.96774 .90516 L

.97407 .90795 L

.97619 .90888 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<00`0C4`1`4`00oa=B4`0301<C070C001T4`D0j1<2074C001V4`0301<C0>PC00<04a<0

L1<004DC00<=4a<061<300<C00<04a<00Q<20>@C00<04a<0E1<33ATC00164`033A<C01dC00<04a<0

0Q<00`0C4`3B4`D00Q<00`0C4`024`0301<C008C00<04a<0DQ<23A`C00164`033A<C01dC00<04a<0

0Q<00`0C4`3D4`0301<C00HC00<04`000a<00`0C4`1@4`8=7Q<004LC00<=4a<06a<200@C00<04a<0

cQ<300<C00<04a<021<0100C4a<204lC0PdP4`00Aa<00`dC4`0Q4`80eA<00`0C4`064`8011<00`0C

4`1<4`8=8Q<004PC00<=4a<081<00`0C4`3D4`0301<C00HC00<04a<00a<00`0C4`1:4`8=91<004PC

00<=4a<081<00`0C4`3C4`8021<300<C00<04a<0B1<23BHC00194`033A<C01lC00<04a<0ha<204LC

0PdX4`00BQ<00`dC4`0N4`80i1<00`0C4`134`<=:Q<004XC00<=4a<07Q<00`0C4`3S4`0301<C044C

0Pd]4`00Ba<00`dC4`0M4`0301<C0><C00<04a<0?a<23BlC001<4`033A<C01`C00<04a<0ha<00`0C

4`0m4`8=<A<004`C00<=4a<071<20>@C0P0l4`8=<a<004dC00<=4a<06a<00`0C4`3S4`0301<C03PC

0`de4`00CA<00`dC4`0K4`0301<C0><C00<04a<0=Q<23CPC001>4`033A<C01XC00<04a<0ha<00`0C

4`0d4`8=>Q<004lC00<=4a<06A<20>@C0P0c4`8=?1<004lC00<=4a<06A<00`0C4`3S4`0301<C030C

0Pdn4`00D1<00`dC4`094`0301<C008C00<04a<00Q<00`0C4`024`0301<C0><C00<04a<0;Q<23D0C

001A4`033A<C00LC00<04`001a<00`0C00034`0301<C0><C00<04a<0;1<23D8C001A4`033A<C008C

0`024`0301<000TC00@04a<C0P3T4`80:a<23D@C001B4`033A<C00HC00<04`001a<200@C00<04a<0

ha<00`0C4`0X4`8=AQ<005<C00<=4a<01A<00`0C00074`0301<C00<C00<04a<0ha<00`0C4`0V4`8=

B1<005<C00<=4a<01Q<00`0C4`064`<00a<00`0C4`3L4`D00Q<00`0C4`0U4`033A<C04PC001D4`03

3A<C01@C00<04a<0gQ<00`0C4`024`0301<C02<C0Pe;4`00E1<00`dC4`0D4`80fA<300<C00<04a<0

0Q<202<C00<=4a<0Ba<005DC00<=4a<04a<00`0C4`3N4`0301<C008C00<04a<081<23DhC001F4`03

3A<C018C00<04a<0gQ<00`0C4`024`0301<C01hC0Pe@4`00EQ<00`dC4`0B4`0301<C0=dC0P044`03

01<C01/C0`eB4`00Ea<00`dC4`0A4`80i1<201TC0`eE4`00F1<00`dC4`0@4`0301<C0><C00<04a<0

5Q<23EPC000J4`<09A<5014C00<=4a<041<00`0C4`0T4`D091<309<C00<04a<051<23EXC000J4`03

01<C02LC00<04a<04Q<00`dC4`0?4`0301<C02HC00<04a<091<00`0C4`2C4`0301<C018C0PeL4`00

5A<300<C00<04a<081<300<C00<04a<04a<00`dC4`0>4`809a<00`0C4`0U4`0301<C098C00<04a<0

3a<33EhC000K4`0301<C02HC00<04a<04a<00`dC4`0>4`0301<C02HC00<04a<09A<00`0C4`2B4`80

3Q<23F4C000J4`0301<002LC00<04a<051<00`dC4`0=4`0301<C02HC00<04a<091<00`0C002C4`03

01<C00XC0`eS4`006a<00`0C4`0U4`805Q<00`dC4`0=4`0301<C02DC0P0W4`0301<C098C00<04a<0

1Q<43FHC001L4`033A<C00`C0P3T4`0301<=00H=JQ<005dC00<=4a<02a<00`0C4`3N4`L=LA<005dC

00<=4a<02a<00`0C4`1K4`80MA<<3@DC00<04a<0L1<005hC00<=4a<02Q<00`0C4`1J4`0301<C050C

9@dA4`0301<C070C000E4dX000<=0000H0064`0301<C02dC8`df4`0301<C070C000I4`0301<C00HC

00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<01@0C

4a<=00<C00<04a<01A<00a0C4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC00<04a<0

1A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00PC00<04a<0QQ<00`0C4`1`4`00

H1<00`dC4`084`0341<C05XC00<04`00QQ<203hC6PdI4`00HA<00`dC4`074`8@Fa<308HC00<04a<0

;1<A3C<C001Q4`033A<C00LC0Q3E4`0301<C008C00<04a<00Q<00`0C4`024`0301<C02HC1Pe44`00

HQ<00`dC4`054`03400@0=@C00<04`001a<00`0C00034`0301<C020C1Pe:4`00HQ<00`dC4`054`03

400@0<lC0`024`0301<000TC00@04a<C0P0K4`H=D1<006<C00<=4a<011<00a00403D4`0301<000LC

0P044`0301<C01DC1@eF4`00I1<00`dC4`024`0541<00100da<00`0C00074`0301<C00<C00<04a<0

4Q<33E/C001T4`033A<C008C00D@4`0C403D4`0301<C00HC0`034`0301<C010C0PeN4`00IA<02@dC

4a<@4`0C403S4`803a<23F0C001V4`063A<C41<00Q<00a0C4`3P4`0301<C00`C0PeR4`00IQ<01@dC

4a0C008000<C41<0hA<00`0C4`0;4`033A<C068C001W4`053A<@4`000Q<00a0C4`3P4`0301<C00XC

00<=4a<0Ha<006LC00D=41<C00034`0341<C0=lC00<04a<02A<00`dC4`1T4`00J1<010dC4`034`03

41<C0=lC0P094`033A<C06DC001X4`0340dC00800Q<00a0C4`3O4`0301<C00LC00<=4a<0IQ<006LC

00D@4`dC00044`0341<C0=hC00<04a<01Q<00`dC4`1W4`00G1<00`0C4`024`0301<C008C00H041<C

3@044`0341<C08HC0`0Y4`D09a<00`0C4`054`033A<C01lC1@0X4`<06A<005/C00<04`001a<00`0@

00024`033@0C00<C00<@4a<0QQ<00`0C4`0[4`0301<C02LC0P054`033A<C028C00<04a<0:1<00`0C

4`0I4`00Fa<00`0C00084`03400C008C00<=01<00a<00a0C4`204`<00a<00`0C4`0T4`<00a<00`0C

4`0W4`0301<C00<C00<=4a<08a<00`0C4`0Y4`0301<C01PC001K4`0301<000LC00<041<00a<00`0=

4`034`0341<C08HC00<04a<0:Q<00`0C4`0W4`0301<C008C00<=4a<091<00`0C4`0Y4`0301<C01PC

001K4`0301<000LC00<@4a<00a<00`0=4`044`0341<C08@C00<04`00:a<00`0C4`0W4`0501<C4`d0

9a<00`0C4`0X4`0301<001TC001L4`0301<C00HC00<@00000a<00`0C3@044`0341<C08DC00<04a<0

:A<202TC00D04a<C3@0V4`80:a<00`0C4`0H4`00I1<00a0C4`044`8000<C3A<00Q<00a0C4`3L4`80

00<C3A<0KQ<006@C00<@4a<011<0100C4`d44`0341<C0=/C00<04`d0L1<006<C00<@4a<01A<01@0C

4a<=00<C00<@4a<0fa<00`0C3@1S4`802a<006<C00<@4a<01A<01@0C4a<=00@C00<@4a<0fQ<00`0=

4`1R4`0301<C00/C001R4`0341<C00HC00<04a<00Q<01@dC4a<@07lCGP000`d0001J00LC00<04a<0

2a<0068C00<@4a<01Q<200@C00D=4a<C40224`0301<C00HC00<04a<01Q<00`0C4`064`0301<C00HC

00<04a<01Q<00`0C4`064`0301<C00DC00<04a<01Q<00`0C4`064`0301<C00HC00<=4a<01Q<00`0C

4`064`0301<C00HC00<04a<01Q<00`0C4`054`0301<C00HC00<04a<01Q<00`0C4`064`0301<C00HC

00<04a<01Q<00`0C4`094`0301<C00/C001Q4`0341<C00LC00<04a<00a<01@dC4a<@0=/C00<=4a<0

HQ<00`0C000;4`00HA<00a0C4`074`0301<C00@C00@=4a<@fQ<00`d04`1S4`<02a<0060C00<@4a<0

21<00`0C4`054`043A<C4=TC00<=01<0LA<0060C00<@4a<021<200HC00@=4a<@f1<010dC001a4`00

Ga<00a0C4`094`0301<C00HC00@=4a<@ea<00`dC001b4`00Ga<00a0C4`094`0301<C00LC00<=4a00

ea<00`dC001b4`00GQ<00a0C4`0:4`0301<C00LC00@=4a<@eQ<00`dC001b4`00GQ<00a0C4`0:4`80

2A<00`dC403E4`033A<C0080LA<005dC00<@4a<02a<00`0C4`084`043A<C4=@C00@=4a<0LQ<005dC

00<@4a<011<5008C00<04a<02A<00`dC403D4`043A<C078C001L4`0341<C00LC00<04a<00Q<00`0C

4`0:4`033A<@0=<C00@=4a<0LQ<005/C00<@4a<021<00`0C4`024`802a<010dC4a3B4`033A<C0080

LA<005/C00<@4a<021<00`0C4`024`0301<C00/C00<=4a00dA<01@dC4a<0078C001J4`0341<C00TC

00<04a<00Q<00`0C4`0<4`033A<@0=0C00D=4a<C001b4`00FQ<00a0C4`084`8011<00`0C4`0<4`04

3A<C4<lC00D=4a<C001b4`00FA<00a0C4`0?4`803Q<00`dC403?4`053A<C4`00LQ<005PC00<@4a<0

41<00`0C4`0=4`043A<C4<hC00@=4a<C0P1a4`00F1<00a0C4`0@4`0301<C00hC00@=4a<@cQ<010dC

4`1b4`00Ea<00a0C4`0A4`0301<C00hC00@=4a<@`Q<00`0C4`024`0301<C008C00<04`d00Q<00`0C

4`1`4`00EQ<00a0C4`0B4`8041<010dC4a304`0301<000LC00@04`0=0Q<00`0C4`1`4`00EQ<00a0C

4`0B4`0301<C010C00@=4a<@_a<00`0C00094`0400dC4`80LA<005DC00<@4a<04a<00`0C4`0@4`04

3A<C4;lC00<04`001a<200054`dC4`00LQ<005@C00<@4a<051<00`0C4`0A4`043A<C4;hC00<04`00

1a<01`0C4a<=4`00LQ<005<C00<@4a<05A<2018C00@=4a<@_a<00`0C4`064`<000@C3A<0LQ<005<C

00<@4a<05A<00`0C4`0B4`043A<C4</C00<=4`00LQ<0058C00<@4a<05Q<00`0C4`0C4`043A<C4<XC

00@=4`00LA<0054C00<@4a<05a<00`0C4`0C4`043A<C4</C00<=01<0LA<0054C00<@4a<05a<201DC

00@=4a<@bQ<00`d04`1a4`00D1<00a0C4`0H4`0301<C01DC00<=4a00ba<00`dC4`1`4`00Ca<00a0C

4`084`D00Q<00`0C4`024`0301<C008C00<04a<05A<010dC4a3:4`033@0C070C001?4`0341<C00XC

00<04a<01Q<00`0C00034`0301<C01HC00@=4a<@bA<00`0=4`1`4`00CQ<00a0C4`0;4`0301<C00PC

00@04a<C0P0G4`053A<C4a00b1<00`0=4`1`4`00CA<00a0C4`0<4`0301<C00HC0P044`0301<C01LC

00@=4a<@b1<00`0C3@1`4`00C1<00a0C4`0=4`0301<C00HC00<04a<00a<00`0C4`0H4`043A<C4<LC

00<04`d0L1<004`C00<@4a<031<200PC0`034`0301<C01PC00D=4a<C40364`8000<C3A<0KQ<004/C

00<@4a<07A<201XC00D=4a<C40354`0501<C4`d0KQ<004XC00<@4a<07Q<00`0C4`0J4`043A<C4<DC

00D04a<C3@1^4`00BQ<00a0C4`0N4`0301<C01XC00D=4a<C40344`0301<C008C00<=4a<0Ja<004TC

00<@4a<07a<00`0C4`0K4`053A<C4a00`a<200<C00<=4a<0Ja<004PC00<@4a<081<201`C00<=4a<0

0Q<00a0C4`304`0301<C00<C00<=4a<0JQ<004LC00<@4a<08A<00`0C4`0L4`033A<C008C00<@4a<0

_a<00`0C4`044`033A<C06TC00174`0341<C024C00<04a<07A<01@dC4a<@0;XC1@024`0301<C00DC

00<=4a<0J1<004HC00<@4a<08Q<00`0C4`0M4`033A<C008C00<@4a<0^A<00`0C4`024`0301<C00DC

00<=4a<0J1<004DC00<@4a<08a<201lC00<=4a<00Q<00a0C4`2h4`0301<C008C0P074`033A<C06LC

00144`0341<C02@C00<04a<07Q<00`dC4`034`0341<C0;LC00<04a<00Q<00`0C4`074`033A<C06HC

00144`0341<C02@C00<04a<07a<00`dC4`024`0341<C0;LC00<04a<00Q<00`0C4`084`033A<C06DC

00134`0341<C02DC00<04a<081<00`dC4`024`0341<C0;DC0P044`0301<C00TC00<=4a<0I1<0048C

00<@4a<09Q<00`0C4`0P4`033A<C00<C00<@4a<0^Q<200XC00<=4a<0I1<0044C00<@4a<09a<2028C

00<=4a<00a<00a0C4`2i4`0301<C00XC00<=4a<0Ha<0040C00<@4a<0:1<00`0C4`0R4`033A<C00<C

00<@4a<0^1<00`0C4`0;4`033A<C068C00104`0341<C028C0`034`0301<C028C00<=4a<011<00a0C

4`2g4`0301<C00`C00<=4a<0HA<003lC00<@4a<08a<00`0C4`034`0301<C02<C00<=4a<00a<00a0C

4`2g4`803Q<23F4C000n4`0341<C02DC00<04a<00Q<202@C00<=4a<011<00a0C4`2f4`0301<C00lC

00<=4a<0GQ<003dC00<@4a<09Q<00`0C4`024`0301<C02@C00<=4a<011<00a0C4`2e4`0301<C010C

00<=4a<0GA<003dC00<@4a<09A<00`0C00034`0301<C02DC00<=4a<011<00a0C4`2d4`0301<C014C

00<=4a<0G1<003`C00<@4a<09a<00`0C4`024`0301<C02DC00<=4a<01A<00a0C4`2c4`0301<C018C

00<=4a<0Fa<003/C00<@4a<0;A<202LC00<=4a<01A<00a0C4`2b4`8051<23E/C000j4`0341<C02hC

00<04a<09a<00`dC4`044`0341<C0;8C00<04a<05A<00`dC4`1H4`00>Q<00a0C4`0^4`0301<C02LC

00<=4a<01A<00a0C4`2a4`0301<C01HC00<=4a<0Ea<003TC00<@4a<0;a<00`0C4`0X4`033A<C00DC

00<@4a<0/1<00`0C4`0G4`8=Ea<003PC00<@4a<0<1<202XC00<=4a<01A<00a0C4`2_4`806Q<00`dC

4`1D4`00=a<00a0C4`0a4`0301<C02TC00<=4a<01A<00a0C4`2_4`0301<C01XC0PeD4`00=a<00a0C

4`0a4`0301<C02XC00<=4a<01A<00a0C4`2^4`0301<C01`C00<=4a<0DA<003HC00<@4a<0<Q<00`0C

4`0Z4`033A<C00HC00<@4a<0W1<5008C00<04a<00Q<00`0C4`024`0301<C01dC0PeA4`00=A<00a0C

4`0c4`80;1<00`dC4`064`0341<C09dC00<04a<01Q<00`0C00034`0301<C01lC00<=4a<0CQ<003@C

00<@4a<0=1<00`0C4`0/4`033A<C00HC00<@4a<0W1<00`0C4`084`0401<C4`808A<23DhC000c4`03

41<C03DC00<04a<0;1<00`dC4`074`0341<C09/C00<04a<01Q<200@C00<04a<08Q<00`dC4`1;4`00

<Q<00a0C4`0f4`0301<C02dC00<=4a<01Q<00a0C4`2K4`0301<C00HC00<04a<00a<00`0C4`0S4`8=

Ba<0034C00<@4a<0=a<202lC00<=4a<01Q<00a0C4`2I4`8021<300<C00<04a<09A<00`dC4`184`00

<1<00a0C4`0h4`0301<C02hC00<=4a<01a<00a0C4`2X4`809a<23DPC000_4`0341<C02TC0`034`03

01<C008C00<04a<00Q<00`0C4`0_4`033A<C00LC00<@4a<0Ya<00`0C4`0X4`033A<C04DC000^4`03

41<C02XC00<04a<01a<00`0C00034`0301<C02lC00<=4a<021<00a0C4`2V4`0301<C02TC0Pe54`00

;A<00a0C4`0/4`0301<C00PC00@04a<C0P0a4`033A<C00PC00<@4a<0YA<00`0C4`0[4`033A<C048C

000/4`0341<C02dC00<04a<01Q<200@C00<04a<0<1<00`dC4`094`0341<C0:@C00<04a<0;1<23D8C

000[4`0341<C02dC00<04`001a<00`0C4`034`0301<C034C00<=4a<02A<00a0C4`2S4`80;a<00`dC

4`0o4`00:Q<00a0C4`0_4`0301<C00HC0`034`0301<C038C00<=4a<02A<00a0C4`2R4`0301<C02lC

0Pdo4`00:A<00a0C4`0o4`80<a<00`dC4`0:4`0341<C0:4C00<04a<0<A<23CdC000X4`0341<C040C

00<04a<0<a<00`dC4`0:4`0341<C0:0C00<04a<0<a<23C/C000W4`0341<C044C00<04a<0<a<00`dC

4`0;4`0341<C09lC0P0f4`8=>A<002HC00<@4a<0@Q<00`0C4`0d4`033A<C00/C00<@4a<0WQ<00`0C

4`0g4`8==a<002DC00<@4a<0@a<203HC00<=4a<02a<00a0C4`2M4`0301<C03TC00<=4a<0=1<002@C

00<@4a<0A1<00`0C4`0e4`033A<C00`C00<@4a<0W1<00`0C4`0j4`8==1<002<C00<@4a<0AA<00`0C

4`0f4`033A<C00`C00<@4a<0Va<203dC0Pdb4`008a<00a0C4`154`0301<C03LC00<=4a<031<00a0C

4`2J4`0301<C03hC0Pd`4`008Q<00a0C4`164`80>1<00`dC4`0=4`0341<C09TC00<04a<0@1<23BhC

000Q4`0341<C04LC00<04a<0>1<00`dC4`0=4`0341<C098C0`034`0301<C048C0Pd/4`0081<00a0C

4`184`0301<C03PC00<=4a<03Q<00a0C4`2A4`0301<C00<C00<04a<0A1<00`dC4`0Y4`007a<00a0C

4`194`0301<C03TC00<=4a<03Q<00a0C4`2A4`0301<C008C0P164`8=:A<001hC00<@4a<0BQ<203/C

00<=4a<03Q<00a0C4`2@4`0301<C008C00<04a<0Aa<23BLC000M4`0341<C04/C00<04a<0>Q<00`dC

4`0?4`0341<C08hC00<04`000a<00`0C4`194`8=9A<001`C00<@4a<0C1<00`0C4`0k4`033A<C00lC

00<@4a<0SQ<00`0C4`024`0301<C04/C0`dR4`006a<00a0C4`174`8011<00`0C4`0k4`033A<C010C

00<@4a<0TQ<204lC0`dO4`006Q<00a0C4`1:4`0501<C4`00?Q<00`dC4`0@4`0341<C094C00<04a<0

DA<23AdC000I4`0341<C04XC00<04a<00Q<203dC00<=4a<041<00a0C4`2A4`0301<C05<C0PdK4`00

Ia<00`0C4`3W4`0301<C05DC0PdI4`00IA<00`0C003Y4`0301<C070C001V4`0301<C0>PC0P1a4`00

:Q<30?lC9A<00`0C4`1`4`00:Q<00`0C4`3o4bDC00<04a<0L1<002/C00<04a<011<00`0C4`3o4i0C

000[4`0401<C4`@00a<30?lCS1<002XC00<04`000Q<200034`0C00@C00<04a<0oa>:4`00:a<00`0C

4`034`0301<000<C00<04a<0oa>;4`00<A<00`0C00044`0301<C00HC00<04a<09a<302/C00<04a<0

oa<Y4`006a<300034`00008031<300@C0`084`0301<C02HC00@04a<03a<300034`0000800Q<00`0C

4`024`0301<C008C00<04a<01A<0100C4a<5008C00@04a<C0P024`D00Q<00`0C4`044`80aA<00`0C

4`0g4`0301<C00HC000J4`0401<C02@C00<04a<09A<0100C4`0>4`0401<C00HC00<04`001a<00`0C

00044`D00a<00`0C4`064`0301<000<C00L04a<C01<000@C00<04a<0_A<00`0C4`044`0301<C01<C

00<04a<08a<00`0C4`054`006Q<01@0C4`0C00@000<C0000600]4`<03Q<01@0C4`0C00@000@C01<0

2A<00`0C4`044`0301<C00<C00<04a<01Q<00`0C00034`0301<C00<C00<04a<00Q<00`0C4`2[4`04

01<C4`@00Q<200HC00<04a<00a<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`054`0401<C4`D0

0Q<0100C4a<2008C1@024`0301<C00@C0P044`0401<C4`800A<001/C0`1?4`0301<C00dC0`064`03

01<000LC0P074`0301<C00<C00<04a<01Q<200@C00@04a<C0P054`0301<C0:XC00<04`001a<00`0C

4`044`D00a<01`0C4a<04`001a<00`0C00044`D00a<00`0C4`064`0301<000<C00L04a<C01<000@C

00<04a<011<00`0C4`024`400A<001dC00<04a<0C1<2014C00<04a<011<00`0C00074`0301<C00`C

00<04a<01Q<00`0C4`034`0501<C4`001Q<00`0C002Z4`0301<0008C10000a<04`074`0301<C00<C

00L04a<C01<000TC00<04a<011<00`0C4`034`0301<C00HC00<04`000a<00`0C4`034`0301<C008C

00<04a<011<00`0C4`034`40000L4`80H1<200LC00<04a<01Q<300/C0P094`800Q<200<C0`044`<0

Ta<200034`00018C00<04`001a<00`0C4`064`0301<C00<C00L04a<C01<000LC0P074`0301<C00<C

00<04a<01Q<200@C00@04a<C0P054`0301<C00@C00<04a<00a<10000oa=A4`0301<001<C00<04`00

1a<00`0C000=4`0601<C01<01a<00`0C4`0<4`0301<C00HC00<04a<00a<01@0C4a<000HC00<04`00

0a<00`0C4`034`400A<002HC0P064`80oa<R4`0301<C01<C00<04a<01Q<300hC00@04a<021<300/C

0P094`800Q<200<C0`044`<00Q<00`0C4`034`800A<002PC00<04a<00Q<00`0C4`3o4b8C00<04a<0

L1<002LC00<04a<00a<00`0C4`064`0301<C0?lC61<00`0C001a4`00:1<00`0C4`024`0301<C008C

0`0011<04a<30?lC51<200034`00070C000V4`0301<000@C00<04`000Q<2008C00<04a<00Q<00`0C

4`3o4hLC000W4`0301<C00<C0`044`0401<C008C00<04a<0oa>84`00=1<0100C4`034`0301<C0?lC

Qa<0038C0`044`<0oa>94`00oa?54`00oa?54`00oa?54`00oa?54`00oa?54`00\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.61034, -1.76924, 0.0225429, 0.0225429}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -82 0 ]

[.5 .96488 82 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -143 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.61) show

217.250000 19.500000 moveto

(C) show

222.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.27817 0 m

.30316 .04022 L

.34309 .10451 L

.3815 .16636 L

.42237 .23215 L

.46172 .29551 L

.49955 .35642 L

.53984 .42128 L

.57861 .48371 L

.61984 .55008 L

.65954 .61401 L

.69774 .6755 L

.73838 .74094 L

.77751 .80394 L

.81909 .87088 L

.85916 .93539 L

s

.85916 .93539 m

.86971 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.394008 0.238095 [

[.02381 .38151 -6 -9 ]

[.02381 .38151 6 0 ]

[.2619 .38151 -6 -9 ]

[.2619 .38151 6 0 ]

[.7381 .38151 -3 -9 ]

[.7381 .38151 3 0 ]

[.97619 .38151 -3 -9 ]

[.97619 .38151 3 0 ]

[1.025 .39401 0 -8 ]

[1.025 .39401 9 8 ]

[.4875 .03687 -24 -4.5 ]

[.4875 .03687 0 4.5 ]

[.4875 .15591 -12 -4.5 ]

[.4875 .15591 0 4.5 ]

[.4875 .27496 -24 -4.5 ]

[.4875 .27496 0 4.5 ]

[.4875 .51306 -18 -4.5 ]

[.4875 .51306 0 4.5 ]

[.4875 .6321 -6 -4.5 ]

[.4875 .6321 0 4.5 ]

[.4875 .75115 -18 -4.5 ]

[.4875 .75115 0 4.5 ]

[.4875 .8702 -6 -4.5 ]

[.4875 .8702 0 4.5 ]

[.5 .95444 -4.5 0 ]

[.5 .95444 4.5 16 ]

[.5 .94194 -134.5 0 ]

[.5 .94194 134.5 16 ]

[ 0 0 0 0 ]

[ 1 .92944 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .39401 m

.02381 .40026 L

s

[(-2)] .02381 .38151 0 1 Mshowa

.2619 .39401 m

.2619 .40026 L

s

[(-1)] .2619 .38151 0 1 Mshowa

.7381 .39401 m

.7381 .40026 L

s

[(1)] .7381 .38151 0 1 Mshowa

.97619 .39401 m

.97619 .40026 L

s

[(2)] .97619 .38151 0 1 Mshowa

.125 Mabswid

.07143 .39401 m

.07143 .39776 L

s

.11905 .39401 m

.11905 .39776 L

s

.16667 .39401 m

.16667 .39776 L

s

.21429 .39401 m

.21429 .39776 L

s

.30952 .39401 m

.30952 .39776 L

s

.35714 .39401 m

.35714 .39776 L

s

.40476 .39401 m

.40476 .39776 L

s

.45238 .39401 m

.45238 .39776 L

s

.54762 .39401 m

.54762 .39776 L

s

.59524 .39401 m

.59524 .39776 L

s

.64286 .39401 m

.64286 .39776 L

s

.69048 .39401 m

.69048 .39776 L

s

.78571 .39401 m

.78571 .39776 L

s

.83333 .39401 m

.83333 .39776 L

s

.88095 .39401 m

.88095 .39776 L

s

.92857 .39401 m

.92857 .39776 L

s

.25 Mabswid

0 .39401 m

1 .39401 L

s

gsave

1.025 .39401 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .03687 m

.50625 .03687 L

s

[(-1.5)] .4875 .03687 1 0 Mshowa

.5 .15591 m

.50625 .15591 L

s

[(-1)] .4875 .15591 1 0 Mshowa

.5 .27496 m

.50625 .27496 L

s

[(-0.5)] .4875 .27496 1 0 Mshowa

.5 .51306 m

.50625 .51306 L

s

[(0.5)] .4875 .51306 1 0 Mshowa

.5 .6321 m

.50625 .6321 L

s

[(1)] .4875 .6321 1 0 Mshowa

.5 .75115 m

.50625 .75115 L

s

[(1.5)] .4875 .75115 1 0 Mshowa

.5 .8702 m

.50625 .8702 L

s

[(2)] .4875 .8702 1 0 Mshowa

.125 Mabswid

.5 .06067 m

.50375 .06067 L

s

.5 .08448 m

.50375 .08448 L

s

.5 .10829 m

.50375 .10829 L

s

.5 .1321 m

.50375 .1321 L

s

.5 .17972 m

.50375 .17972 L

s

.5 .20353 m

.50375 .20353 L

s

.5 .22734 m

.50375 .22734 L

s

.5 .25115 m

.50375 .25115 L

s

.5 .29877 m

.50375 .29877 L

s

.5 .32258 m

.50375 .32258 L

s

.5 .34639 m

.50375 .34639 L

s

.5 .3702 m

.50375 .3702 L

s

.5 .41782 m

.50375 .41782 L

s

.5 .44163 m

.50375 .44163 L

s

.5 .46544 m

.50375 .46544 L

s

.5 .48925 m

.50375 .48925 L

s

.5 .53687 m

.50375 .53687 L

s

.5 .56067 m

.50375 .56067 L

s

.5 .58448 m

.50375 .58448 L

s

.5 .60829 m

.50375 .60829 L

s

.5 .65591 m

.50375 .65591 L

s

.5 .67972 m

.50375 .67972 L

s

.5 .70353 m

.50375 .70353 L

s

.5 .72734 m

.50375 .72734 L

s

.5 .77496 m

.50375 .77496 L

s

.5 .79877 m

.50375 .79877 L

s

.5 .82258 m

.50375 .82258 L

s

.5 .84639 m

.50375 .84639 L

s

.5 .01306 m

.50375 .01306 L

s

.5 .89401 m

.50375 .89401 L

s

.5 .91782 m

.50375 .91782 L

s

.25 Mabswid

.5 0 m

.5 .92944 L

s

gsave

.5 .95444 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .94194 -195.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.61) show

293.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

298.000000 15.000000 moveto

(L) show

305.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

312.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

319.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

324.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

328.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .92944 L

0 .92944 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .2418 m

.02576 .24179 L

.03158 .24175 L

.04117 .24167 L

.05436 .24157 L

.07093 .24143 L

.0906 .24125 L

.11303 .24103 L

.13783 .24076 L

.16458 .24044 L

.19282 .24005 L

.22208 .2396 L

.25184 .23906 L

.28161 .23843 L

.31086 .23769 L

.33911 .23684 L

.36586 .23586 L

.39066 .23477 L

.41309 .23357 L

.43276 .23232 L

.44933 .23107 L

.46252 .22992 L

.47211 .22898 L

.47793 .22836 L

.47988 .22815 L

s

.47988 .22815 m

.482 .22791 L

.48833 .22717 L

.49877 .22582 L

.51313 .22369 L

.53116 .22049 L

.55256 .21574 L

.57697 .20885 L

.60396 .19923 L

.63307 .18674 L

.66381 .17191 L

.69564 .15566 L

.72803 .13888 L

.76043 .12226 L

.79226 .10626 L

.823 .0912 L

.85211 .07732 L

.8791 .06478 L

.90351 .05371 L

.92491 .0442 L

.94294 .03632 L

.9573 .03014 L

.96773 .0257 L

.97407 .02302 L

.97619 .02213 L

s

.47988 .47688 m

.482 .44959 L

.48833 .4227 L

.49877 .39651 L

.51313 .37137 L

.53116 .3477 L

.55256 .32611 L

.57697 .30732 L

.60396 .29205 L

.63307 .28053 L

.66381 .27237 L

.69564 .26674 L

.72803 .26284 L

.76043 .26009 L

.79226 .2581 L

.823 .25663 L

.85211 .25553 L

.8791 .25469 L

.90351 .25404 L

.92491 .25355 L

.94294 .25318 L

.9573 .25291 L

.96773 .25273 L

.97407 .25262 L

.97619 .25259 L

s

.47988 .477 m

.482 .50452 L

.48833 .53216 L

.49877 .55969 L

.51313 .58696 L

.53116 .61384 L

.55256 .64017 L

.57697 .66585 L

.60396 .69075 L

.63307 .71475 L

.66381 .73774 L

.69564 .75963 L

.72803 .7803 L

.76043 .79968 L

.79226 .81767 L

.823 .83419 L

.85211 .84917 L

.8791 .86255 L

.90351 .87427 L

.92491 .88427 L

.94294 .89252 L

.9573 .89897 L

.96773 .90359 L

.97407 .90638 L

.97619 .90731 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<00`0C4`1`4`00oa=B4`0301<C070C001T4`D0j1<2074C001V4`0301<C0>PC00<04a<0

L1<004DC00<=4a<061<300<C00<04a<00Q<20=<C1@024`0301<C008C00<04a<00Q<00`0C4`1D4`<=

6A<004HC00<=4a<07A<00`0C4`024`0301<C0=@C00<04a<01Q<00`0C00034`0301<C058C0PdL4`00

AQ<00`dC4`0M4`0301<C008C00<04a<0cQ<300<C00<04a<021<0100C4a<2054C0PdN4`00Aa<00`dC

4`0K4`8011<00`0C4`3D4`0301<C00HC0P044`0301<C04hC0PdP4`00Aa<00`dC4`0Q4`80eA<00`0C

4`064`0301<C00<C00<04a<0C1<23B8C00184`033A<C020C00<04a<0da<200PC0`034`0301<C04XC

0PdT4`00B1<00`dC4`0P4`0301<C0><C00<04a<0B1<23BHC00194`033A<C01lC00<04a<0ha<204LC

0PdX4`00BQ<00`dC4`0N4`80i1<00`0C4`134`<=:Q<004XC00<=4a<07Q<00`0C4`3S4`0301<C044C

0Pd]4`00Ba<00`dC4`0M4`0301<C0><C00<04a<0?a<23BlC001<4`033A<C01`C00<04a<0ha<203hC

0Pda4`00C1<00`dC4`0L4`80i1<00`0C4`0k4`8=<a<004dC00<=4a<06a<00`0C4`3S4`0301<C03PC

0`de4`00CA<00`dC4`0K4`0301<C0><C00<04a<0=Q<23CPC001>4`033A<C01XC00<04a<0ha<00`0C

4`0d4`8=>Q<004lC00<=4a<06A<20>@C0P0c4`8=?1<004lC00<=4a<06A<00`0C4`3S4`0301<C030C

0Pdn4`00D1<00`dC4`094`0301<C008C00<04a<00Q<00`0C4`024`0301<C0><C00<04a<0;Q<23D0C

001A4`033A<C00LC00<04`001a<00`0C00034`0301<C0><C00<04a<0;1<23D8C001A4`033A<C008C

0`024`0301<000TC00@04a<C0P3T4`80:a<23D@C001B4`033A<C00HC00<04`001a<200@C00<04a<0

ha<00`0C4`0X4`8=AQ<005<C00<=4a<01A<00`0C00074`0301<C00<C00<04a<0ha<00`0C4`0V4`8=

B1<005<C00<=4a<01Q<00`0C4`064`<00a<00`0C4`3L4`D00Q<00`0C4`0U4`033A<C04PC001D4`03

3A<C01@C00<04a<0gQ<00`0C4`024`0301<C02<C0Pe;4`00E1<00`dC4`0D4`80fA<300<C00<04a<0

0Q<202<C00<=4a<0Ba<005DC00<=4a<04a<00`0C4`3N4`0301<C008C00<04a<081<23DhC001F4`03

3A<C018C00<04a<0gQ<00`0C4`024`0301<C01hC0Pe@4`00EQ<00`dC4`0B4`0301<C0=dC0P044`03

01<C01/C0`eB4`00Ea<00`dC4`0A4`80i1<201TC0`eE4`00F1<00`dC4`0@4`0301<C0><C00<04a<0

5Q<23EPC000J4`<09A<5014C00<=4a<041<00`0C4`0T4`D091<309<C00<04a<051<23EXC000J4`03

01<C02LC00<04a<04Q<00`dC4`0?4`0301<C02HC00<04a<091<00`0C4`2C4`0301<C018C0PeL4`00

5A<300<C00<04a<081<300<C00<04a<04a<00`dC4`0>4`809a<00`0C4`0U4`0301<C098C00<04a<0

3a<33EhC000K4`0301<C02HC00<04a<04a<00`dC4`0>4`0301<C02HC00<04a<09A<00`0C4`2B4`80

3Q<23F4C000J4`0301<002LC00<04a<051<00`dC4`0=4`0301<C02HC00<04a<091<00`0C002C4`03

01<C00XC0`eS4`006a<00`0C4`0U4`805Q<00`dC4`0=4`0301<C02DC0P0W4`0301<C098C00<04a<0

1Q<43FHC001L4`033A<C00`C0P3T4`0301<=00H=JQ<005dC00<=4a<02a<00`0C4`3L4`T=LA<005dC

00<=4a<02a<00`0C4`1K4`80L1<?3@LC00<04a<0L1<005hC00<=4a<02Q<00`0C4`1J4`0301<C044C

;`dF4`0301<C070C000E4dX000<=0000H0064`0301<C02dC50e54`0301<C070C000I4`0301<C00HC

00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<01@0C

4a<=00<C00<04a<01A<00a0C4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC00<04a<0

1A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00PC00<04a<0QQ<2074C001P4`03

3A<C00PC00<@4a<0FQ<00`0C00264`0301<C03LC80dI4`00HA<00`dC4`074`8@Fa<308HC00<04a<0

;1<;3CTC001Q4`033A<C00LC0Q3E4`0301<C008C00<04a<00Q<00`0C4`024`0301<C020C30e44`00

HQ<00`dC4`054`03400@0=@C00<04`001a<00`0C00034`0301<C01/C1@e@4`00HQ<00`dC4`054`03

400@0<lC0`024`0301<000TC00@04a<C0P0I4`<=EA<006<C00<=4a<011<00a00403D4`0301<000LC

0P044`0301<C01DC0`eH4`00I1<00`dC4`024`0541<00100da<00`0C00074`0301<C00<C00<04a<0

4Q<33E/C001T4`033A<C008C00D@4`0C403D4`0301<C00HC0`034`0301<C010C0PeN4`00IA<02@dC

4a<@4`0C403S4`803a<23F0C001V4`063A<C41<00Q<00a0C4`3P4`0301<C00`C0PeR4`00IQ<01@dC

4a0C008000<C41<0hA<00`0C4`0;4`033A<C068C001W4`053A<@4`000Q<00a0C4`3P4`0301<C00XC

00<=4a<0Ha<006LC00D=41<C00034`0341<C0=lC00<04a<021<23FHC001X4`043A<C00<C00<@4a<0

ga<200PC00<=4a<0IQ<006PC00<@3A<00P024`0341<C0=lC00<04a<01Q<00`dC4`1W4`00Ia<01A0C

3A<000@C00<@4a<0gQ<00`0C4`054`033A<C06PC001L4`0301<C008C00<04a<00Q<01P0@4a<=00@C

00<@4a<0QQ<302TC1@0W4`0301<C00@C00<=4a<081<502PC0`0I4`00Fa<00`0C00074`030100008C

00<=01<00a<00a0C4`264`0301<C02/C00<04a<09a<200@C00<=4a<08a<00`0C4`0X4`0301<C01TC

001K4`0301<000PC00<@01<00Q<00`d04`034`0341<C080C0`034`0301<C02@C0`034`0301<C02LC

00<04a<00Q<00`dC4`0T4`0301<C02TC00<04a<061<005/C00<04`001a<00`0@4`034`0300dC00<C

00<@4a<0QQ<00`0C4`0Z4`0301<C02LC00<04a<00Q<00`dC4`0T4`0301<C02TC00<04a<061<005/C

00<04`001a<00a0C4`034`0300dC00@C00<@4a<0Q1<00`0C000[4`0301<C02LC00D04a<C3@0W4`03

01<C02PC00<04`006A<005`C00<04a<01Q<00a0000034`0301<=00@C00<@4a<0QA<00`0C4`0Y4`80

:A<01@0C4a<=02HC0P0[4`0301<C01PC001T4`0341<C00@C0P000a<=4`024`0341<C0=`C0P000a<=

4`1^4`00I1<00a0C4`044`0401<C3@@C00<@4a<0fa<00`0C3@1`4`00Ha<00a0C4`054`0501<C4`d0

0a<00a0C4`3K4`0301<=06<C0P0;4`00Ha<00a0C4`054`0501<C4`d011<00a0C4`3J4`0300dC068C

00<04a<02a<0068C00<@4a<01Q<00`0C4`024`053A<C4a00Oa=N00033@0005X01a<00`0C4`0;4`00

HQ<00a0C4`064`8011<01@dC4a<@088C00<04a<01Q<00`0C4`064`0301<C00HC00<04a<01Q<00`0C

4`064`0301<C00HC00<04a<01A<00`0C4`064`0301<C00HC00<04a<01Q<00`dC4`064`0301<C00HC

00<04a<01Q<00`0C4`064`0301<C00HC00<04a<01A<00`0C4`064`0301<C00HC00<04a<01Q<00`0C

4`064`0301<C00TC00<04a<02a<0064C00<@4a<01a<00`0C4`034`053A<C4a00fQ<00`d04`1S4`03

01<000/C001Q4`0341<C00LC00<04a<011<010dC4a3J4`033@0C06<C0`0;4`00H1<00a0C4`084`03

01<C00DC00@=4a<@f1<00`dC001b4`00H1<00a0C4`084`801Q<010dC4a3H4`043A<0074C001O4`03

41<C00TC00<04a<01Q<010dC4a3G4`033A<0078C001O4`0341<C00TC00<04a<01a<00`dC403G4`03

3A<0078C001N4`0341<C00XC00<04a<01a<010dC4a3E4`043A<C078C001N4`0341<C00XC0P094`03

3A<@0=DC00<=4a<00P1a4`00GA<00a0C4`0;4`0301<C00PC00@=4a<@e1<010dC4`1b4`00GA<00a0C

4`044`D00Q<00`0C4`094`033A<@0=@C00@=4a<0LQ<005`C00<@4a<01a<00`0C4`024`0301<C00XC

00<=4a00da<010dC4`1b4`00Fa<00a0C4`084`0301<C008C0P0;4`043A<C4=4C00@=4a<C0P1a4`00

Fa<00a0C4`084`0301<C008C00<04a<02a<00`dC403A4`053A<C4`00LQ<005XC00<@4a<02A<00`0C

4`024`0301<C00`C00<=4a00d1<01@dC4a<0078C001J4`0341<C00PC0P044`0301<C00`C00@=4a<@

ca<01@dC4a<0078C001I4`0341<C00lC0P0>4`033A<@0<lC00D=4a<C001b4`00F1<00a0C4`0@4`03

01<C00hC00<=4a00cQ<010dC4a<2074C001H4`0341<C010C00<04a<03Q<010dC4a3>4`043A<C078C

001G4`0341<C014C00<04a<03a<00`dC40324`0301<C008C00<04a<00Q<00`0C3@024`0301<C070C

001F4`0341<C018C0P0@4`043A<C4<0C00<04`001a<0100C00d24`0301<C070C001F4`0341<C018C

00<04a<041<010dC4a2o4`0301<000TC00@03A<C0P1a4`00EA<00a0C4`0C4`0301<C014C00<=4a00

_a<00`0C00074`8000DC3A<C001b4`00E1<00a0C4`0D4`0301<C014C00@=4a<@_Q<00`0C00074`07

01<C4`dC001b4`00Da<00a0C4`0E4`804a<00`dC402o4`0301<C00HC0`0011<=4`1b4`00Da<00a0C

4`0E4`0301<C01<C00<=4a00ba<00`dC001b4`00DQ<00a0C4`0F4`0301<C01<C00@=4a<@bQ<010dC

001a4`00DA<00a0C4`0G4`0301<C01@C00<=4a00ba<00`d04`1a4`00DA<00a0C4`0G4`805Q<00`dC

403:4`033@0C074C001@4`0341<C01PC00<04a<05A<00`dC403;4`033A<C070C001?4`0341<C00PC

1@024`0301<C008C00<04a<00Q<00`0C4`0F4`033A<@0<XC00<=01<0L1<004lC00<@4a<02Q<00`0C

4`064`0301<000<C00<04a<05Q<010dC4a394`0300dC070C001>4`0341<C00/C00<04a<021<0100C

4a<201PC00@=4a<@b1<00`0=4`1`4`00CA<00a0C4`0<4`0301<C00HC0P044`0301<C01PC00<=4a00

b1<00`0C3@1`4`00C1<00a0C4`0=4`0301<C00HC00<04a<00a<00`0C4`0H4`043A<C4<LC00<04`d0

L1<004`C00<@4a<031<200PC0`034`0301<C01TC00@=4a<@aQ<200034`dC06hC001;4`0341<C01dC

0P0K4`043A<C4<DC00D04a<C3@1^4`00BQ<00a0C4`0N4`0301<C01XC00@=4a<@aA<01@0C4a<=06hC

001:4`0341<C01hC00<04a<06a<010dC4a344`0301<C008C00<=4a<0Ja<004TC00<@4a<07a<00`0C

4`0K4`053A<C4a00`a<200<C00<=4a<0Ja<004PC00<@4a<081<201dC00D=4a<C40324`0301<C00<C

00<=4a<0JQ<004LC00<@4a<08A<00`0C4`0L4`033A<C008C00<@4a<0_a<00`0C4`044`033A<C06TC

00174`0341<C024C00<04a<07A<01@dC4a<@0;XC1@024`0301<C00DC00<=4a<0J1<004HC00<@4a<0

8Q<00`0C4`0M4`033A<C008C00<@4a<0^A<00`0C4`024`0301<C00DC00<=4a<0J1<004DC00<@4a<0

8a<201lC00<=4a<00Q<00a0C4`2h4`0301<C008C0P074`033A<C06LC00144`0341<C02@C00<04a<0

7Q<00`dC4`034`0341<C0;LC00<04a<00Q<00`0C4`074`033A<C06HC00144`0341<C02@C00<04a<0

7a<00`dC4`024`0341<C0;LC00<04a<00Q<00`0C4`084`033A<C06DC00134`0341<C02DC00<04a<0

81<00`dC4`024`0341<C0;DC0P044`0301<C00TC00<=4a<0I1<0048C00<@4a<09Q<00`0C4`0P4`03

3A<C00<C00<@4a<0^Q<200XC00<=4a<0I1<0044C00<@4a<09a<2028C00<=4a<00a<00a0C4`2i4`03

01<C00XC00<=4a<0Ha<0040C00<@4a<0:1<00`0C4`0R4`033A<C00<C00<@4a<0^1<00`0C4`0;4`03

3A<C068C00104`0341<C028C0`034`0301<C028C00<=4a<011<00a0C4`2g4`0301<C00`C00<=4a<0

HA<003lC00<@4a<08a<00`0C4`034`0301<C02<C00<=4a<00a<00a0C4`2g4`803Q<23F4C000n4`03

41<C02DC00<04a<00Q<202@C00<=4a<011<00a0C4`2f4`0301<C00lC00<=4a<0GQ<003dC00<@4a<0

9Q<00`0C4`024`0301<C02@C00<=4a<011<00a0C4`2e4`0301<C010C00<=4a<0GA<003dC00<@4a<0

9A<00`0C00034`0301<C02DC00<=4a<011<00a0C4`2d4`0301<C014C00<=4a<0G1<003`C00<@4a<0

9a<00`0C4`024`0301<C02DC00<=4a<01A<00a0C4`2c4`0301<C018C00<=4a<0Fa<003/C00<@4a<0

;A<202LC00<=4a<01A<00a0C4`2b4`8051<23E/C000j4`0341<C02hC00<04a<09a<00`dC4`044`03

41<C0;8C00<04a<05A<00`dC4`1H4`00>Q<00a0C4`0^4`0301<C02LC00<=4a<01A<00a0C4`2a4`03

01<C01HC00<=4a<0Ea<003TC00<@4a<0;a<00`0C4`0X4`033A<C00DC00<@4a<0/1<00`0C4`0G4`8=

Ea<003PC00<@4a<0<1<202XC00<=4a<01A<00a0C4`2_4`806Q<00`dC4`1D4`00=a<00a0C4`0a4`03

01<C02TC00<=4a<01A<00a0C4`2_4`0301<C01XC0PeD4`00=a<00a0C4`0a4`0301<C02XC00<=4a<0

1A<00a0C4`2^4`0301<C01`C00<=4a<0DA<003HC00<@4a<0<Q<00`0C4`0Z4`033A<C00HC00<@4a<0

W1<5008C00<04a<00Q<00`0C4`024`0301<C01dC0PeA4`00=A<00a0C4`0c4`80;1<00`dC4`064`03

41<C09dC00<04a<01Q<00`0C00034`0301<C01lC00<=4a<0CQ<003@C00<@4a<0=1<00`0C4`0/4`03

3A<C00HC00<@4a<0W1<00`0C4`084`0401<C4`808A<23DhC000c4`0341<C03DC00<04a<0;1<00`dC

4`074`0341<C09/C00<04a<01Q<200@C00<04a<08Q<00`dC4`1;4`00<Q<00a0C4`0f4`0301<C02dC

00<=4a<01Q<00a0C4`2K4`0301<C00HC00<04a<00a<00`0C4`0S4`8=Ba<0034C00<@4a<0=a<202lC

00<=4a<01Q<00a0C4`2I4`8021<300<C00<04a<09A<00`dC4`184`00<1<00a0C4`0h4`0301<C02hC

00<=4a<01a<00a0C4`2X4`809a<23DPC000_4`0341<C02TC0`034`0301<C008C00<04a<00Q<00`0C

4`0_4`033A<C00LC00<@4a<0Ya<00`0C4`0X4`033A<C04DC000^4`0341<C02XC00<04a<01a<00`0C

00034`0301<C02lC00<=4a<021<00a0C4`2V4`0301<C02TC0Pe54`00;A<00a0C4`0/4`0301<C00PC

00@04a<C0P0a4`033A<C00PC00<@4a<0YA<00`0C4`0[4`033A<C048C000/4`0341<C02dC00<04a<0

1Q<200@C00<04a<0<1<00`dC4`094`0341<C0:@C00<04a<0;1<23D8C000[4`0341<C02dC00<04`00

1a<00`0C4`034`0301<C034C00<=4a<02A<00a0C4`2S4`80;a<00`dC4`0o4`00:Q<00a0C4`0_4`03

01<C00HC0`034`0301<C038C00<=4a<02A<00a0C4`2R4`0301<C02lC0Pdo4`00:A<00a0C4`0o4`80

<a<00`dC4`0:4`0341<C0:4C00<04a<0<A<23CdC000X4`0341<C040C00<04a<0<a<00`dC4`0:4`03

41<C0:0C00<04a<0<a<23C/C000W4`0341<C044C00<04a<0<a<00`dC4`0;4`0341<C09lC0P0f4`8=

>A<002HC00<@4a<0@Q<00`0C4`0d4`033A<C00/C00<@4a<0WQ<00`0C4`0g4`8==a<002DC00<@4a<0

@a<203HC00<=4a<02a<00a0C4`2M4`0301<C03TC00<=4a<0=1<002@C00<@4a<0A1<00`0C4`0e4`03

3A<C00`C00<@4a<0W1<00`0C4`0j4`8==1<002<C00<@4a<0AA<00`0C4`0f4`033A<C00`C00<@4a<0

Va<00`0C4`0l4`8=<Q<002<C00<@4a<0AA<00`0C4`0g4`033A<C00`C00<@4a<0VQ<203lC0Pd`4`00

8Q<00a0C4`164`80>1<00`dC4`0=4`0341<C09TC00<04a<0@1<23BhC000Q4`0341<C04LC00<04a<0

>1<00`dC4`0=4`0341<C098C0`034`0301<C048C0Pd/4`0081<00a0C4`184`0301<C03PC00<=4a<0

3Q<00a0C4`2A4`0301<C00<C00<04a<0A1<00`dC4`0Y4`007a<00a0C4`194`0301<C03TC00<=4a<0

3Q<00a0C4`2A4`0301<C008C0P164`8=:A<001hC00<@4a<0BQ<203/C00<=4a<03Q<00a0C4`2@4`03

01<C008C00<04a<0Aa<23BLC000M4`0341<C04/C00<04a<0>Q<00`dC4`0?4`0341<C08hC00<04`00

0a<00`0C4`194`8=9A<001`C00<@4a<0C1<00`0C4`0k4`033A<C00lC00<@4a<0SQ<00`0C4`024`03

01<C04/C0`dR4`006a<00a0C4`174`8011<00`0C4`0l4`033A<C00lC00<@4a<0TQ<204lC0`dO4`00

6Q<00a0C4`1:4`0501<C4`00?Q<00`dC4`0@4`0341<C094C00<04a<0DA<23AdC000I4`0341<C04XC

00<04a<00Q<203hC00<=4a<03a<00a0C4`2A4`0301<C05<C0PdK4`00Ia<00`0C4`3W4`0301<C05DC

0PdI4`00IA<00`0C003Y4`0301<C070C001V4`0301<C0>PC0P1a4`00;1<30?lC8a<00`0C4`1`4`00

;1<00`0C4`3o4b<C00<04a<0L1<002dC00<04a<01A<00`0C4`3o4hdC000]4`0401<C4`<000@C01<C

0`3o4hXC000/4`0301<0008C0P024`0301<C008C00<04a<0oa>84`00;A<00`0C4`034`0401<C008C

00<04a<0oa>94`00<a<0100C4`034`0301<C00HC00<04a<09A<302dC00<04a<0oa<W4`007A<30003

4`00008031<300@C0`084`0301<C02@C00@04a<04A<300034`0000800Q<00`0C4`024`0301<C008C

00<04a<01A<0100C4a<5008C00@04a<C0P024`D011<20</C00<04a<0<Q<00`0C4`084`0071<0100C

4`0T4`0301<C02<C00@04a<041<0100C4`064`0301<000LC00<04`0011<500<C00<04a<01Q<00`0C

00034`0301<C00<C00<04a<0`a<00`0C4`044`0301<C01<C00<04a<07Q<00`0C4`074`0071<01@0C

4`0C00@000<C0000600[4`<041<01@0C4`0C00@000@C01<02A<00`0C4`044`0301<C00<C00<04a<0

1Q<00`0C00034`0301<C00<C00<04a<0/A<0100C4a<4008C0P064`0301<C00<C00<04a<00Q<00`0C

4`024`0301<C008C00<04a<01A<0100C4a<5008C00@04a<C0P024`D011<200@C00@04a<C0P014`40

0@0001dC0`1=4`0301<C00lC0`064`0301<000LC0P074`0301<C00<C00<04a<01Q<200@C00<04a<0

0a<00`0C4`2`4`0301<000LC00<04a<011<500<C00L04a<C01<000LC00<04`0011<500<C00<04a<0

1Q<00`0C00034`0301<C00<C00<04a<011<00`0C4`024`0301<0004C000O4`0301<C04XC0P0C4`03

01<C00@C00<04`001a<00`0C4`0<4`0301<C00HC00<04a<00a<00`0C4`034`0301<00;0C00<04`00

0Q<400034`0C00LC00<04a<00a<01`0C4a<04`002A<00`0C4`044`0301<C00<C00<04a<01Q<00`0C

00034`0301<C00<C00<04a<011<00`0C4`034`400A<14`007Q<2060C0P074`0301<C00HC0`0;4`80

2A<2008C0P054`<0UQ<200034`0001DC00<04`001a<00`0C4`064`0301<C00<C00L04a<C01<000LC

0P074`0301<C00<C00<04a<01Q<200@C00<04a<00a<00`0C4`044`0301<C00<C0@014`4C003o4e4C

00<04`005Q<00`0C00074`0301<000dC00H04a<04`074`0301<C00`C00<04a<01Q<00`0C4`034`03

01<C00<C00<04`000a<00`0C4`034`0301<0004C000Y4`801Q<20?lC7a<00`0C4`0F4`0301<C00HC

0`0>4`0401<C00PC0`0;4`802A<2008C0P054`<00Q<00`0C4`034`800A<10040000[4`0301<C008C

00<04a<0oa<O4`0301<C070C000Z4`0301<C00<C00<04a<01A<00`0C4`3o4aHC00<04`00LA<002/C

00<04a<00Q<00`0C4`024`@00a<30?lC4A<200034`00070C000Y4`0301<000@C00<04`000Q<20003

4`0C00@C00<04a<0oa>44`00:Q<00`0C4`034`<011<00`0C00034`0301<C0?lCQA<003LC00<04`00

11<00`0C4`3o4h@C000e4`<011<30?lCQQ<00?lCaA<00?lCaA<00?lCaA<00?lCaA<00?lCaA<00001

\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.59753, -1.76457, 0.0225049, 0.0225049}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -84.5 0 ]

[.5 .96488 84.5 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -145.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.605) show

222.250000 19.500000 moveto

(C) show

227.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.27748 0 m

.30316 .04121 L

.34309 .10529 L

.3815 .16695 L

.42237 .23254 L

.46172 .2957 L

.49955 .35642 L

.53984 .42108 L

.57861 .48331 L

.61984 .54948 L

.65954 .61321 L

.69774 .67451 L

.73838 .73975 L

.77751 .80255 L

.81909 .86929 L

.85916 .9336 L

s

.85916 .9336 m

.87086 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.392933 0.238095 [

[.02381 .38043 -6 -9 ]

[.02381 .38043 6 0 ]

[.2619 .38043 -6 -9 ]

[.2619 .38043 6 0 ]

[.7381 .38043 -3 -9 ]

[.7381 .38043 3 0 ]

[.97619 .38043 -3 -9 ]

[.97619 .38043 3 0 ]

[1.025 .39293 0 -8 ]

[1.025 .39293 9 8 ]

[.4875 .03579 -24 -4.5 ]

[.4875 .03579 0 4.5 ]

[.4875 .15484 -12 -4.5 ]

[.4875 .15484 0 4.5 ]

[.4875 .27389 -24 -4.5 ]

[.4875 .27389 0 4.5 ]

[.4875 .51198 -18 -4.5 ]

[.4875 .51198 0 4.5 ]

[.4875 .63103 -6 -4.5 ]

[.4875 .63103 0 4.5 ]

[.4875 .75008 -18 -4.5 ]

[.4875 .75008 0 4.5 ]

[.4875 .86912 -6 -4.5 ]

[.4875 .86912 0 4.5 ]

[.5 .95282 -4.5 0 ]

[.5 .95282 4.5 16 ]

[.5 .94032 -137 0 ]

[.5 .94032 137 16 ]

[ 0 0 0 0 ]

[ 1 .92782 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .39293 m

.02381 .39918 L

s

[(-2)] .02381 .38043 0 1 Mshowa

.2619 .39293 m

.2619 .39918 L

s

[(-1)] .2619 .38043 0 1 Mshowa

.7381 .39293 m

.7381 .39918 L

s

[(1)] .7381 .38043 0 1 Mshowa

.97619 .39293 m

.97619 .39918 L

s

[(2)] .97619 .38043 0 1 Mshowa

.125 Mabswid

.07143 .39293 m

.07143 .39668 L

s

.11905 .39293 m

.11905 .39668 L

s

.16667 .39293 m

.16667 .39668 L

s

.21429 .39293 m

.21429 .39668 L

s

.30952 .39293 m

.30952 .39668 L

s

.35714 .39293 m

.35714 .39668 L

s

.40476 .39293 m

.40476 .39668 L

s

.45238 .39293 m

.45238 .39668 L

s

.54762 .39293 m

.54762 .39668 L

s

.59524 .39293 m

.59524 .39668 L

s

.64286 .39293 m

.64286 .39668 L

s

.69048 .39293 m

.69048 .39668 L

s

.78571 .39293 m

.78571 .39668 L

s

.83333 .39293 m

.83333 .39668 L

s

.88095 .39293 m

.88095 .39668 L

s

.92857 .39293 m

.92857 .39668 L

s

.25 Mabswid

0 .39293 m

1 .39293 L

s

gsave

1.025 .39293 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .03579 m

.50625 .03579 L

s

[(-1.5)] .4875 .03579 1 0 Mshowa

.5 .15484 m

.50625 .15484 L

s

[(-1)] .4875 .15484 1 0 Mshowa

.5 .27389 m

.50625 .27389 L

s

[(-0.5)] .4875 .27389 1 0 Mshowa

.5 .51198 m

.50625 .51198 L

s

[(0.5)] .4875 .51198 1 0 Mshowa

.5 .63103 m

.50625 .63103 L

s

[(1)] .4875 .63103 1 0 Mshowa

.5 .75008 m

.50625 .75008 L

s

[(1.5)] .4875 .75008 1 0 Mshowa

.5 .86912 m

.50625 .86912 L

s

[(2)] .4875 .86912 1 0 Mshowa

.125 Mabswid

.5 .0596 m

.50375 .0596 L

s

.5 .08341 m

.50375 .08341 L

s

.5 .10722 m

.50375 .10722 L

s

.5 .13103 m

.50375 .13103 L

s

.5 .17865 m

.50375 .17865 L

s

.5 .20246 m

.50375 .20246 L

s

.5 .22627 m

.50375 .22627 L

s

.5 .25008 m

.50375 .25008 L

s

.5 .29769 m

.50375 .29769 L

s

.5 .3215 m

.50375 .3215 L

s

.5 .34531 m

.50375 .34531 L

s

.5 .36912 m

.50375 .36912 L

s

.5 .41674 m

.50375 .41674 L

s

.5 .44055 m

.50375 .44055 L

s

.5 .46436 m

.50375 .46436 L

s

.5 .48817 m

.50375 .48817 L

s

.5 .53579 m

.50375 .53579 L

s

.5 .5596 m

.50375 .5596 L

s

.5 .58341 m

.50375 .58341 L

s

.5 .60722 m

.50375 .60722 L

s

.5 .65484 m

.50375 .65484 L

s

.5 .67865 m

.50375 .67865 L

s

.5 .70246 m

.50375 .70246 L

s

.5 .72627 m

.50375 .72627 L

s

.5 .77389 m

.50375 .77389 L

s

.5 .7977 m

.50375 .7977 L

s

.5 .8215 m

.50375 .8215 L

s

.5 .84531 m

.50375 .84531 L

s

.5 .01198 m

.50375 .01198 L

s

.5 .89293 m

.50375 .89293 L

s

.5 .91674 m

.50375 .91674 L

s

.25 Mabswid

.5 0 m

.5 .92782 L

s

gsave

.5 .95282 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .94032 -198 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.605) show

298.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

303.000000 15.000000 moveto

(L) show

310.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

317.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

324.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

329.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

333.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .92782 L

0 .92782 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .24034 m

.02576 .24033 L

.03158 .24029 L

.04117 .24021 L

.05436 .24011 L

.07093 .23997 L

.0906 .2398 L

.11302 .23958 L

.13782 .23932 L

.16457 .239 L

.19282 .23863 L

.22207 .23818 L

.25183 .23766 L

.2816 .23704 L

.31085 .23632 L

.33909 .23548 L

.36584 .23453 L

.39064 .23347 L

.41307 .2323 L

.43274 .23107 L

.44931 .22985 L

.4625 .22873 L

.47209 .22782 L

.47791 .22722 L

.47986 .22701 L

s

.47986 .22701 m

.48198 .22678 L

.48831 .22605 L

.49875 .22474 L

.5131 .22267 L

.53114 .21955 L

.55254 .21491 L

.57695 .20816 L

.60394 .19869 L

.63305 .18634 L

.66379 .17161 L

.69563 .15543 L

.72802 .13869 L

.76042 .1221 L

.79225 .10612 L

.82299 .09108 L

.85211 .07722 L

.8791 .06469 L

.9035 .05363 L

.92491 .04413 L

.94294 .03627 L

.9573 .0301 L

.96773 .02566 L

.97407 .02298 L

.97619 .02209 L

s

.47986 .47583 m

.48198 .44856 L

.48831 .42167 L

.49875 .39548 L

.5131 .37031 L

.53114 .3466 L

.55254 .32493 L

.57695 .30603 L

.60394 .29064 L

.63305 .27902 L

.66379 .27078 L

.69563 .26512 L

.72802 .2612 L

.76042 .25845 L

.79225 .25647 L

.82299 .255 L

.85211 .2539 L

.8791 .25307 L

.9035 .25243 L

.92491 .25194 L

.94294 .25157 L

.9573 .2513 L

.96773 .25112 L

.97407 .25101 L

.97619 .25098 L

s

.47986 .47595 m

.48198 .50346 L

.48831 .53107 L

.49875 .55857 L

.5131 .58582 L

.53114 .61266 L

.55254 .63896 L

.57695 .66461 L

.60394 .68947 L

.63305 .71344 L

.66379 .7364 L

.69563 .75826 L

.72802 .7789 L

.76042 .79825 L

.79225 .81622 L

.82299 .83272 L

.85211 .84768 L

.8791 .86104 L

.9035 .87274 L

.92491 .88273 L

.94294 .89096 L

.9573 .8974 L

.96773 .90202 L

.97407 .9048 L

.97619 .90573 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<00`0C4`1`4`00oa=B4`0301<C070C001T4`D0j1<2074C001V4`0301<C0>PC00<04a<0

L1<004DC00<=4a<061<300<C00<04a<00Q<20=<C1@024`0301<C008C00<04a<00Q<00`0C4`1E4`8=

6A<004HC00<=4a<07A<00`0C4`024`0301<C0=@C00<04a<01Q<00`0C00034`0301<C058C0`dK4`00

AQ<00`dC4`0M4`0301<C008C00<04a<0cQ<300<C00<04a<021<0100C4a<2054C0PdN4`00Aa<00`dC

4`0K4`8011<00`0C4`3D4`0301<C00HC0P044`0301<C04hC0PdP4`00Aa<00`dC4`0Q4`80eA<00`0C

4`064`0301<C00<C00<04a<0CA<00`dC4`0P4`00B1<00`dC4`0P4`0301<C0=<C0P084`<00a<00`0C

4`1;4`8=8a<004PC00<=4a<081<00`0C4`3S4`0301<C04PC0`dU4`00BA<00`dC4`0O4`0301<C0><C

0P174`8=:1<004XC00<=4a<07Q<20>@C00<04a<0@a<33BXC001:4`033A<C01hC00<04a<0ha<00`0C

4`114`8=;A<004/C00<=4a<07A<00`0C4`3S4`0301<C03lC0Pd_4`00C1<00`dC4`0L4`0301<C0><C

0P0n4`8=<A<004`C00<=4a<071<20>@C00<04a<0>a<23C<C001=4`033A<C01/C00<04a<0ha<00`0C

4`0h4`<==A<004dC00<=4a<06a<00`0C4`3S4`0301<C03HC0Pdh4`00CQ<00`dC4`0J4`0301<C0><C

00<04a<0=1<23CXC001?4`033A<C01TC0P3T4`80<a<23C`C001?4`033A<C01TC00<04a<0ha<00`0C

4`0`4`8=?Q<0050C00<=4a<02A<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`3S4`0301<C02hC

0Pe04`00DA<00`dC4`074`0301<000LC00<04`000a<00`0C4`3S4`0301<C02`C0Pe24`00DA<00`dC

4`024`<00Q<00`0C00094`0401<C4`80i1<202/C0Pe44`00DQ<00`dC4`064`0301<000LC0P044`03

01<C0><C00<04a<0:1<23DHC001C4`033A<C00DC00<04`001a<00`0C4`034`0301<C0><C00<04a<0

9Q<23DPC001C4`033A<C00HC00<04a<01Q<300<C00<04a<0g1<5008C00<04a<09A<00`dC4`184`00

E1<00`dC4`0D4`0301<C0=hC00<04a<00Q<00`0C4`0S4`8=Ba<005@C00<=4a<051<20=TC0`034`03

01<C008C0P0S4`033A<C04/C001E4`033A<C01<C00<04a<0gQ<00`0C4`024`0301<C020C0Pe>4`00

EQ<00`dC4`0B4`0301<C0=hC00<04a<00Q<00`0C4`0N4`8=D1<005HC00<=4a<04Q<00`0C4`3M4`80

11<00`0C4`0K4`<=DQ<005LC00<=4a<04A<20>@C0P0I4`<=EA<005PC00<=4a<041<00`0C4`3S4`03

01<C01HC0PeH4`006Q<302DC1@0A4`033A<C010C00<04a<091<502@C0`2C4`0301<C01@C0PeJ4`00

6Q<00`0C4`0W4`0301<C018C00<=4a<03a<00`0C4`0V4`0301<C02@C00<04a<0Ta<00`0C4`0B4`8=

G1<001DC0`034`0301<C020C0`034`0301<C01<C00<=4a<03Q<202LC00<04a<09A<00`0C4`2B4`80

41<33EhC000K4`0301<C02HC00<04a<04a<00`dC4`0>4`0301<C02HC00<04a<09A<00`0C4`2B4`03

01<C00/C10eQ4`006Q<00`0C000W4`0301<C01@C00<=4a<03A<00`0C4`0V4`0301<C02@C00<04`00

Ta<00`0C4`094`8=IA<001/C00<04a<09A<201HC00<=4a<03A<00`0C4`0U4`809a<00`0C4`2B4`03

01<C00HC0`eW4`00G1<00`dC4`0<4`80i1<00`0C3@063FXC001M4`033A<C00/C00<04a<0g1<93G4C

001M4`033A<C00/C00<04a<0Fa<206/C50d74`0301<C070C001N4`033A<C00XC00<04a<0FQ<00`0C

4`0]4ch=6a<00`0C4`1`4`005A=:00033@0006001Q<00`0C4`264`0301<C070C000I4`0301<C00HC

00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<01@0C

4a<=00<C00<04a<01A<00a0C4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC00<04a<0

1A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00PC00<04a<0QQ<205LC00<=4a<0

5a<0060C00<=4a<021<00a0C4`1J4`0301<008HC00<04a<0=a<O3AXC001Q4`033A<C00LC0Q1K4`<0

QQ<00`0C4`0V4a4=>A<0064C00<=4a<01a<24=DC00<04a<00Q<00`0C4`024`0301<C008C00<04a<0

81<63DXC001R4`033A<C00DC00<@0100e1<00`0C00074`0301<000<C00<04a<06a<53E0C001R4`03

3A<C00DC00<@0100ca<3008C00<04`002A<0100C4a<201TC0`eE4`00Ha<00`dC4`044`03400@0=@C

00<04`001a<200@C00<04a<05A<33EPC001T4`033A<C008C00D@4`00403C4`0301<000LC00<04a<0

0a<00`0C4`0C4`8=Fa<006@C00<=4a<00Q<01A0C01<@0=@C00<04a<01Q<300<C00<04a<04A<23EdC

001U4`093A<C4a0C01<@0><C0P0@4`8=Ga<006HC00H=4a<@4`024`0341<C0>0C00<04a<03A<23F4C

001V4`053A<C41<00P000a<@4`3Q4`0301<C00/C0PeS4`00Ia<01@dC41<0008C00<@4a<0h1<00`0C

4`0:4`033A<C06<C001W4`053A0C4`000a<00a0C4`3O4`0301<C00PC0PeV4`00J1<010dC4`034`03

41<C0=lC0P084`033A<C06HC001X4`0340dC00800Q<00a0C4`3O4`0301<C00HC00<=4a<0Ia<006LC

00D@4`dC00044`0341<C0=hC00<04a<01A<00`dC4`1X4`00G1<00`0C4`024`0301<C008C00H041<C

3@044`0341<C08HC0`0Y4`D09a<00`0C4`044`033A<C020C1@0Y4`<061<005/C00<04`001a<00`0@

00024`033@0C00<C00<@4a<0QQ<00`0C4`0[4`0301<C02LC0P044`033A<C02<C00<04a<0:A<00`0C

4`0H4`00Fa<00`0C00084`03400C008C00<=01<00a<00a0C4`204`<00a<00`0C4`0T4`<00a<00`0C

4`0W4`0301<C008C00<=4a<091<00`0C4`0Z4`0301<C01LC001K4`0301<000LC00<041<00a<00`0=

4`034`0341<C08HC00<04a<0:Q<00`0C4`0W4`0301<C008C00<=4a<091<00`0C4`0Z4`0301<C01LC

001K4`0301<000LC00<@4a<00a<00`0=4`044`0341<C08@C00<04`00:a<00`0C4`0W4`0501<C4`d0

9a<00`0C4`0Y4`0301<001PC001L4`0301<C00HC00<@00000a<00`0C3@044`0341<C08DC00<04a<0

:A<202TC00D04a<C3@0V4`80;1<00`0C4`0G4`00I1<00a0C4`044`8000<C3A<00Q<00a0C4`3L4`80

00<C3A<0KQ<006@C00<@4a<011<0100C4`d44`0341<C0=/C00<04`d0L1<006<C00<@4a<01A<01@0C

4a<=00<C00<@4a<0fa<00`0=4`1S4`802a<006<C00<@4a<01A<01@0C4a<=00@C00<@4a<0fQ<00`0=

4`1R4`0301<C00/C001R4`0341<C00HC00<04a<00Q<01@dC4a<@07lCG@000`d0001L00HC00<04a<0

2a<0068C00<@4a<01Q<200@C00D=4a<C40224`0301<C00HC00<04a<01Q<00`0C4`064`0301<C00HC

00<04a<01Q<00`0C4`054`0301<C00HC00<04a<01Q<00`0C4`064`0301<C00HC00<=4a<01Q<00`0C

4`064`0301<C00HC00<04a<01Q<00`0C4`064`0301<C00HC00<04a<01A<00`0C4`064`0301<C00HC

00<04a<01Q<00`0C4`094`0301<C00/C001Q4`0341<C00LC00<04a<00a<01@dC4a<@0=XC00<=01<0

Ha<00`0C000;4`00HA<00a0C4`074`0301<C00@C00@=4a<@fQ<00`d04`1S4`<02a<0060C00<@4a<0

21<00`0C4`054`043A<C4=PC00@=4`00LA<0060C00<@4a<021<200HC00@=4a<@f1<00`dC001b4`00

Ga<00a0C4`094`0301<C00HC00@=4a<@ea<00`dC001b4`00Ga<00a0C4`094`0301<C00LC00<=4a00

ea<00`dC001b4`00GQ<00a0C4`0:4`0301<C00LC00@=4a<@eA<010dC4`1b4`00GQ<00a0C4`0:4`80

2A<00`dC403E4`033A<C0080LA<005dC00<@4a<02a<00`0C4`084`043A<C4=@C00@=4a<0LQ<005dC

00<@4a<011<5008C00<04a<02A<00`dC403D4`043A<C078C001L4`0341<C00LC00<04a<00Q<00`0C

4`0:4`033A<@0=<C00@=4a<0LQ<005/C00<@4a<021<00`0C4`024`802a<010dC4a3A4`043A<C4`80

LA<005/C00<@4a<021<00`0C4`024`0301<C00/C00<=4a00dA<01@dC4a<0078C001J4`0341<C00TC

00<04a<00Q<00`0C4`0<4`033A<@0=0C00D=4a<C001b4`00FQ<00a0C4`084`8011<00`0C4`0<4`04

3A<C4<lC00D=4a<C001b4`00FA<00a0C4`0?4`803Q<00`dC403?4`053A<C4`00LQ<005PC00<@4a<0

41<00`0C4`0>4`033A<@0<hC00@=4a<C0P1a4`00F1<00a0C4`0@4`0301<C00hC00@=4a<@cQ<010dC

4`1b4`00Ea<00a0C4`0A4`0301<C00lC00<=4a00`Q<00`0C4`024`0301<C008C00<04`d00Q<00`0C

4`1`4`00EQ<00a0C4`0B4`8041<010dC4a304`0301<000LC00@04`0=0Q<00`0C4`1`4`00EQ<00a0C

4`0B4`0301<C010C00@=4a<@_a<00`0C00094`0400dC4`80LA<005DC00<@4a<04a<00`0C4`0A4`03

3A<@0;lC00<04`001a<200054`dC4`00LQ<005@C00<@4a<051<00`0C4`0A4`043A<C4;hC00<04`00

1a<01`0C4a<=4`00LQ<005<C00<@4a<05A<201<C00<=4a00_a<00`0C4`064`<000@C3A<0LQ<005<C

00<@4a<05A<00`0C4`0C4`033A<@0</C00<=4`00LQ<0058C00<@4a<05Q<00`0C4`0C4`043A<C4<XC

00@=4`00LA<0054C00<@4a<05a<00`0C4`0D4`033A<@0</C00<=01<0LA<0054C00<@4a<05a<201HC

00<=4a00bQ<00`d04`1a4`00D1<00a0C4`0H4`0301<C01DC00<=4a00ba<00`dC4`1`4`00Ca<00a0C

4`084`D00Q<00`0C4`024`0301<C008C00<04a<05Q<00`dC403:4`033@0C070C001?4`0341<C00XC

00<04a<01Q<00`0C00034`0301<C01HC00@=4a<@bA<00`0=4`1`4`00CQ<00a0C4`0;4`0301<C00PC

00@04a<C0P0H4`043A<C4<PC00<03A<0L1<004dC00<@4a<031<00`0C4`064`8011<00`0C4`0H4`03

3A<@0<PC00<04`d0L1<004`C00<@4a<03A<00`0C4`064`0301<C00<C00<04a<061<010dC4a374`03

01<=070C001<4`0341<C00`C0P084`<00a<00`0C4`0I4`043A<C4<HC0P000a<=4`1^4`00Ba<00a0C

4`0M4`806a<010dC4a354`0501<C4`d0KQ<004XC00<@4a<07Q<00`0C4`0J4`043A<C4<DC00D04a<C

3@1^4`00BQ<00a0C4`0N4`0301<C01/C00@=4a<@a1<00`0C4`024`033A<C06/C00194`0341<C01lC

00<04a<06a<01@dC4a<@0<<C0P034`033A<C06/C00184`0341<C020C0P0M4`053A<C4a00`Q<00`0C

4`034`033A<C06XC00174`0341<C024C00<04a<071<00`dC4`024`0341<C0;lC00<04a<011<00`dC

4`1Y4`00Aa<00a0C4`0Q4`0301<C01dC00D=4a<C402j4`D00Q<00`0C4`054`033A<C06PC00164`03

41<C028C00<04a<07A<00`dC4`024`0341<C0;TC00<04a<00Q<00`0C4`054`033A<C06PC00154`03

41<C02<C0P0O4`033A<C008C00<@4a<0^1<00`0C4`024`801a<00`dC4`1W4`00A1<00a0C4`0T4`03

01<C01hC00<=4a<00a<00a0C4`2g4`0301<C008C00<04a<01a<00`dC4`1V4`00A1<00a0C4`0T4`03

01<C01lC00<=4a<00Q<00a0C4`2g4`0301<C008C00<04a<021<00`dC4`1U4`00@a<00a0C4`0U4`03

01<C020C00<=4a<00Q<00a0C4`2e4`8011<00`0C4`094`033A<C06@C00124`0341<C02HC00<04a<0

81<00`dC4`034`0341<C0;XC0P0:4`033A<C06@C00114`0341<C02LC0P0R4`033A<C00<C00<@4a<0

^A<00`0C4`0:4`033A<C06<C00104`0341<C02PC00<04a<08Q<00`dC4`034`0341<C0;PC00<04a<0

2a<00`dC4`1R4`00@1<00a0C4`0R4`<00a<00`0C4`0R4`033A<C00@C00<@4a<0]a<00`0C4`0<4`8=

HQ<003lC00<@4a<08a<00`0C4`034`0301<C02<C00<=4a<00a<00a0C4`2g4`803a<00`dC4`1O4`00

?Q<00a0C4`0U4`0301<C008C0P0T4`033A<C00@C00<@4a<0]Q<00`0C4`0?4`8=Ga<003dC00<@4a<0

9Q<00`0C4`024`0301<C02@C00<=4a<011<00a0C4`2e4`0301<C014C00<=4a<0G1<003dC00<@4a<0

9A<00`0C00034`0301<C02DC00<=4a<011<00a0C4`2d4`0301<C018C00<=4a<0Fa<003`C00<@4a<0

9a<00`0C4`024`0301<C02DC00<=4a<01A<00a0C4`2c4`0301<C01<C00<=4a<0FQ<003/C00<@4a<0

;A<202LC00<=4a<01A<00a0C4`2b4`805A<00`dC4`1I4`00>Q<00a0C4`0^4`0301<C02LC00<=4a<0

11<00a0C4`2b4`0301<C01DC00<=4a<0F1<003XC00<@4a<0;Q<00`0C4`0W4`033A<C00DC00<@4a<0

/A<00`0C4`0F4`033A<C05LC000i4`0341<C02lC00<04a<0:1<00`dC4`054`0341<C0;0C00<04a<0

5a<23ELC000h4`0341<C030C0P0Z4`033A<C00DC00<@4a<0[a<201XC00<=4a<0E1<003LC00<@4a<0

<A<00`0C4`0Y4`033A<C00DC00<@4a<0[a<00`0C4`0J4`8=E1<003LC00<@4a<0<A<00`0C4`0Z4`03

3A<C00DC00<@4a<0[Q<00`0C4`0L4`033A<C054C000f4`0341<C038C00<04a<0:Q<00`dC4`064`03

41<C09`C1@024`0301<C008C00<04a<00Q<00`0C4`0M4`8=DA<003DC00<@4a<0<a<202`C00<=4a<0

1Q<00a0C4`2M4`0301<C00HC00<04`000a<00`0C4`0O4`033A<C04hC000d4`0341<C03@C00<04a<0

;1<00`dC4`064`0341<C09`C00<04a<021<0100C4a<2024C0Pe>4`00<a<00a0C4`0e4`0301<C02`C

00<=4a<01a<00a0C4`2K4`0301<C00HC0P044`0301<C028C00<=4a<0Ba<0038C00<@4a<0=Q<00`0C

4`0]4`033A<C00HC00<@4a<0Va<00`0C4`064`0301<C00<C00<04a<08a<23D/C000a4`0341<C03LC

0P0_4`033A<C00HC00<@4a<0VA<200PC0`034`0301<C02DC00<=4a<0B1<0030C00<@4a<0>1<00`0C

4`0^4`033A<C00LC00<@4a<0Z1<202LC0Pe84`00;a<00a0C4`0Y4`<00a<00`0C4`024`0301<C008C

00<04a<0;a<00`dC4`074`0341<C0:LC00<04a<0:1<00`dC4`154`00;Q<00a0C4`0Z4`0301<C00LC

00<04`000a<00`0C4`0`4`033A<C00LC00<@4a<0YQ<00`0C4`0Y4`8=AA<002dC00<@4a<0;1<00`0C

4`084`0401<C4`80<A<00`dC4`084`0341<C0:DC00<04a<0:a<00`dC4`124`00;1<00a0C4`0]4`03

01<C00HC0P044`0301<C034C00<=4a<021<00a0C4`2T4`0301<C02`C0Pe24`00:a<00a0C4`0]4`03

01<000LC00<04a<00a<00`0C4`0a4`033A<C00TC00<@4a<0Xa<202lC00<=4a<0?a<002XC00<@4a<0

;a<00`0C4`064`<00a<00`0C4`0b4`033A<C00TC00<@4a<0XQ<00`0C4`0_4`8=?a<002TC00<@4a<0

?a<203@C00<=4a<02A<00a0C4`2Q4`0301<C034C0Pdm4`00:1<00a0C4`104`0301<C03<C00<=4a<0

2Q<00a0C4`2P4`0301<C03<C0Pdk4`009a<00a0C4`114`0301<C03@C00<=4a<02Q<00a0C4`2O4`80

=Q<23CTC000V4`0341<C048C00<04a<0=A<00`dC4`0:4`0341<C09hC00<04a<0=a<23CLC000U4`03

41<C04<C0P0f4`033A<C00/C00<@4a<0WA<00`0C4`0i4`033A<C03@C000T4`0341<C04@C00<04a<0

=Q<00`dC4`0;4`0341<C09`C00<04a<0>Q<23C@C000S4`0341<C04DC00<04a<0=a<00`dC4`0;4`03

41<C09/C00<04a<0?1<23C8C000S4`0341<C04DC00<04a<0=a<00`dC4`0<4`0341<C09XC0P0o4`8=

<1<0028C00<@4a<0AQ<203TC00<=4a<031<00a0C4`2I4`0301<C040C0Pd^4`008A<00a0C4`174`03

01<C03PC00<=4a<03A<00a0C4`2B4`<00a<00`0C4`124`8=;1<0020C00<@4a<0B1<00`0C4`0i4`03

3A<C00dC00<@4a<0TA<00`0C4`034`0301<C04@C0PdZ4`007a<00a0C4`194`0301<C03XC00<=4a<0

3A<00a0C4`2A4`0301<C008C0P174`8=:1<001hC00<@4a<0BQ<203/C00<=4a<03Q<00a0C4`2@4`03

01<C008C00<04a<0B1<23BHC000M4`0341<C04/C00<04a<0>a<00`dC4`0>4`0341<C08hC00<04`00

0a<00`0C4`1:4`8=91<001`C00<@4a<0C1<00`0C4`0k4`033A<C00lC00<@4a<0SQ<00`0C4`024`03

01<C04`C0`dQ4`006a<00a0C4`174`8011<00`0C4`0l4`033A<C00lC00<@4a<0TQ<2050C0`dN4`00

6Q<00a0C4`1:4`0501<C4`00?Q<00`dC4`0@4`0341<C094C00<04a<0DQ<23A`C000I4`0341<C04XC

00<04a<00Q<203hC00<=4a<03a<00a0C4`2A4`0301<C05@C0PdJ4`00Ia<00`0C4`3W4`0301<C05HC

00<=4a<05a<006DC00<04`00jA<00`0C4`1`4`00IQ<00`0C4`3X4`80LA<002XC0`3o4bDC00<04a<0

L1<002XC00<04a<0oa<U4`0301<C070C000[4`0301<C00@C00<04a<0oa>@4`00:a<0100C4a<400<C

0`3o4h`C000Z4`0301<0008C0P000a<04`044`0301<C0?lCRQ<002/C00<04a<00a<00`0C00034`03

01<C0?lCRa<0034C00<04`0011<00`0C4`064`0301<C02LC0`0[4`0301<C0?lC:A<001/C0`000a<0

000200`C0`044`<021<00`0C4`0V4`0401<C00lC0`000a<00002008C00<04a<00Q<00`0C4`024`03

01<C00DC00@04a<C1@024`0401<C4`8011<00`0C4`024`0301<C00@C0P354`0301<C03LC00<04a<0

1Q<001XC00@04a<091<00`0C4`0U4`0401<C00hC00@04a<01Q<00`0C00074`0301<000@C1@034`03

01<C00HC00<04`000Q<00`0C00024`0301<000@C00<04a<0_A<00`0C4`044`0301<C01<C00<04a<0

8a<00`0C4`054`006Q<01@0C4`0C00@000<C0000600]4`<03Q<01@0C4`0C00@000@C01<02A<00`0C

4`044`0301<C00<C00<04a<01Q<00`0C00024`0301<000@C00<04a<00Q<00`0C4`2[4`0401<C4`@0

0Q<200HC00<04a<00a<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`054`0401<C4`D00Q<0100C

4a<200@C00<04a<00Q<00`0C4`044`8011<0100C4a<2004C000K4`<0Ca<00`0C4`0=4`<01Q<00`0C

00074`801a<00`0C4`034`0301<C00HC0P034`0301<0008C0P054`0301<C0:XC00<04`001a<00`0C

4`044`D00a<01`0C4a<04`001a<00`0C00044`D00a<00`0C4`064`0301<0008C00<04`000Q<00`0C

00044`0301<C00@C00<04a<00Q<1004C000M4`0301<C04`C0P0A4`0301<C00@C00<04`001a<00`0C

4`0<4`0301<C00HC00<04a<00Q<00`0C00024`0301<C00@C00<04`00ZQ<00`0C00024`@000<C01<0

1a<00`0C4`034`0701<C4`0C00094`0301<C00@C00<04a<00a<00`0C4`064`0301<0008C00<04`00

11<00`0C4`024`0301<C00@C00<04a<00a<1000071<2060C0P074`0301<C00HC0`0;4`802A<200<C

00@04a<C0`044`<0Ta<200034`00018C00<04`001a<00`0C4`064`0301<C00<C00L04a<C01<000LC

0P074`0301<C00<C00<04a<01Q<200<C00<04`000Q<200DC00<04a<011<00`0C4`034`40003o4e4C

00<04`004a<00`0C00074`0301<000dC00H04a<04`074`0301<C00`C00<04a<01Q<00`0C4`024`03

01<0008C00<04a<011<00`0C00034`0301<C00<C0@014`009Q<200HC0P3o4b8C00<04a<04a<00`0C

4`064`<03Q<0100C4`084`<02a<200TC0P034`0401<C4`<011<3008C00<04a<00a<2004C000X4`03

01<C008C00<04a<0oa<R4`0301<C070C000W4`0301<C00<C00<04a<01Q<00`0C4`3o4aPC00<04`00

LA<002PC00<04a<00Q<00`0C4`024`<000@C01<C0`3o4a@C0P000a<0001`4`009Q<00`0C00044`03

01<0008C0P024`0301<C008C00<04a<0oa>74`009a<00`0C4`034`<011<0100C4`024`0301<C0?lC

R1<003@C00@04a<00a<00`0C4`3o4hLC000b4`<011<30?lCRA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCaA<00001\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.58463, -1.75987, 0.0224667, 0.0224667}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -79.5 0 ]

[.5 .96488 79.5 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -140.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.6) show

212.250000 19.500000 moveto

(C) show

217.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.27679 0 m

.30316 .04219 L

.34309 .10608 L

.3815 .16754 L

.42237 .23293 L

.46172 .29589 L

.49955 .35643 L

.53984 .42089 L

.57861 .48292 L

.61984 .54888 L

.65954 .61241 L

.69774 .67352 L

.73838 .73855 L

.77751 .80116 L

.81909 .86769 L

.85916 .9318 L

s

.85916 .9318 m

.87202 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.391852 0.238095 [

[.02381 .37935 -6 -9 ]

[.02381 .37935 6 0 ]

[.2619 .37935 -6 -9 ]

[.2619 .37935 6 0 ]

[.7381 .37935 -3 -9 ]

[.7381 .37935 3 0 ]

[.97619 .37935 -3 -9 ]

[.97619 .37935 3 0 ]

[1.025 .39185 0 -8 ]

[1.025 .39185 9 8 ]

[.4875 .03471 -24 -4.5 ]

[.4875 .03471 0 4.5 ]

[.4875 .15376 -12 -4.5 ]

[.4875 .15376 0 4.5 ]

[.4875 .2728 -24 -4.5 ]

[.4875 .2728 0 4.5 ]

[.4875 .5109 -18 -4.5 ]

[.4875 .5109 0 4.5 ]

[.4875 .62995 -6 -4.5 ]

[.4875 .62995 0 4.5 ]

[.4875 .74899 -18 -4.5 ]

[.4875 .74899 0 4.5 ]

[.4875 .86804 -6 -4.5 ]

[.4875 .86804 0 4.5 ]

[.5 .9512 -4.5 0 ]

[.5 .9512 4.5 16 ]

[.5 .9387 -132 0 ]

[.5 .9387 132 16 ]

[ 0 0 0 0 ]

[ 1 .9262 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .39185 m

.02381 .3981 L

s

[(-2)] .02381 .37935 0 1 Mshowa

.2619 .39185 m

.2619 .3981 L

s

[(-1)] .2619 .37935 0 1 Mshowa

.7381 .39185 m

.7381 .3981 L

s

[(1)] .7381 .37935 0 1 Mshowa

.97619 .39185 m

.97619 .3981 L

s

[(2)] .97619 .37935 0 1 Mshowa

.125 Mabswid

.07143 .39185 m

.07143 .3956 L

s

.11905 .39185 m

.11905 .3956 L

s

.16667 .39185 m

.16667 .3956 L

s

.21429 .39185 m

.21429 .3956 L

s

.30952 .39185 m

.30952 .3956 L

s

.35714 .39185 m

.35714 .3956 L

s

.40476 .39185 m

.40476 .3956 L

s

.45238 .39185 m

.45238 .3956 L

s

.54762 .39185 m

.54762 .3956 L

s

.59524 .39185 m

.59524 .3956 L

s

.64286 .39185 m

.64286 .3956 L

s

.69048 .39185 m

.69048 .3956 L

s

.78571 .39185 m

.78571 .3956 L

s

.83333 .39185 m

.83333 .3956 L

s

.88095 .39185 m

.88095 .3956 L

s

.92857 .39185 m

.92857 .3956 L

s

.25 Mabswid

0 .39185 m

1 .39185 L

s

gsave

1.025 .39185 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .03471 m

.50625 .03471 L

s

[(-1.5)] .4875 .03471 1 0 Mshowa

.5 .15376 m

.50625 .15376 L

s

[(-1)] .4875 .15376 1 0 Mshowa

.5 .2728 m

.50625 .2728 L

s

[(-0.5)] .4875 .2728 1 0 Mshowa

.5 .5109 m

.50625 .5109 L

s

[(0.5)] .4875 .5109 1 0 Mshowa

.5 .62995 m

.50625 .62995 L

s

[(1)] .4875 .62995 1 0 Mshowa

.5 .74899 m

.50625 .74899 L

s

[(1.5)] .4875 .74899 1 0 Mshowa

.5 .86804 m

.50625 .86804 L

s

[(2)] .4875 .86804 1 0 Mshowa

.125 Mabswid

.5 .05852 m

.50375 .05852 L

s

.5 .08233 m

.50375 .08233 L

s

.5 .10614 m

.50375 .10614 L

s

.5 .12995 m

.50375 .12995 L

s

.5 .17757 m

.50375 .17757 L

s

.5 .20138 m

.50375 .20138 L

s

.5 .22519 m

.50375 .22519 L

s

.5 .24899 m

.50375 .24899 L

s

.5 .29661 m

.50375 .29661 L

s

.5 .32042 m

.50375 .32042 L

s

.5 .34423 m

.50375 .34423 L

s

.5 .36804 m

.50375 .36804 L

s

.5 .41566 m

.50375 .41566 L

s

.5 .43947 m

.50375 .43947 L

s

.5 .46328 m

.50375 .46328 L

s

.5 .48709 m

.50375 .48709 L

s

.5 .53471 m

.50375 .53471 L

s

.5 .55852 m

.50375 .55852 L

s

.5 .58233 m

.50375 .58233 L

s

.5 .60614 m

.50375 .60614 L

s

.5 .65376 m

.50375 .65376 L

s

.5 .67757 m

.50375 .67757 L

s

.5 .70138 m

.50375 .70138 L

s

.5 .72519 m

.50375 .72519 L

s

.5 .7728 m

.50375 .7728 L

s

.5 .79661 m

.50375 .79661 L

s

.5 .82042 m

.50375 .82042 L

s

.5 .84423 m

.50375 .84423 L

s

.5 .0109 m

.50375 .0109 L

s

.5 .89185 m

.50375 .89185 L

s

.5 .91566 m

.50375 .91566 L

s

.25 Mabswid

.5 0 m

.5 .9262 L

s

gsave

.5 .9512 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .9387 -193 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.6) show

288.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

293.000000 15.000000 moveto

(L) show

300.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

307.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

314.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

319.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

323.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .9262 L

0 .9262 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .23887 m

.02576 .23886 L

.03158 .23882 L

.04117 .23875 L

.05436 .23865 L

.07093 .23851 L

.09059 .23834 L

.11302 .23813 L

.13782 .23787 L

.16457 .23756 L

.19281 .23719 L

.22206 .23676 L

.25182 .23624 L

.28158 .23564 L

.31084 .23494 L

.33908 .23412 L

.36583 .23319 L

.39063 .23215 L

.41305 .23102 L

.43272 .22982 L

.44929 .22864 L

.46248 .22755 L

.47206 .22666 L

.47788 .22607 L

.47983 .22587 L

s

.47983 .22587 m

.48196 .22564 L

.48829 .22494 L

.49873 .22366 L

.51308 .22164 L

.53112 .2186 L

.55252 .21407 L

.57693 .20746 L

.60392 .19815 L

.63304 .18594 L

.66378 .17131 L

.69562 .15519 L

.72801 .1385 L

.76041 .12194 L

.79225 .10598 L

.82299 .09096 L

.8521 .07712 L

.87909 .06461 L

.9035 .05356 L

.92491 .04407 L

.94294 .03621 L

.9573 .03005 L

.96773 .02562 L

.97407 .02294 L

.97619 .02205 L

s

.47983 .47478 m

.48196 .44753 L

.48829 .42064 L

.49873 .39445 L

.51308 .36925 L

.53112 .34549 L

.55252 .32374 L

.57693 .30474 L

.60392 .28922 L

.63304 .27749 L

.66378 .26919 L

.69562 .26348 L

.72801 .25956 L

.76041 .2568 L

.79225 .25482 L

.82299 .25336 L

.8521 .25226 L

.87909 .25143 L

.9035 .25079 L

.92491 .25031 L

.94294 .24994 L

.9573 .24968 L

.96773 .2495 L

.97407 .24939 L

.97619 .24936 L

s

.47983 .4749 m

.48196 .50239 L

.48829 .52998 L

.49873 .55745 L

.51308 .58466 L

.53112 .61147 L

.55252 .63774 L

.57693 .66336 L

.60392 .68819 L

.63304 .71212 L

.66378 .73506 L

.69562 .75688 L

.72801 .7775 L

.76041 .79682 L

.79225 .81476 L

.82299 .83124 L

.8521 .84618 L

.87909 .85952 L

.9035 .8712 L

.92491 .88118 L

.94294 .8894 L

.9573 .89583 L

.96773 .90044 L

.97407 .90322 L

.97619 .90415 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<00`0C4`1`4`00oa=B4`0301<C070C001T4`D0j1<2074C001V4`0301<C0>PC00<04a<0

L1<004DC00<=4a<061<300<C00<04a<00Q<20=<C1@024`0301<C008C00<04a<00Q<00`0C4`1E4`8=

6A<004HC00<=4a<07A<00`0C4`024`0301<C0=@C00<04a<01Q<00`0C00034`0301<C058C0`dK4`00

AQ<00`dC4`0M4`0301<C008C00<04a<0cQ<300<C00<04a<021<0100C4a<2054C0PdN4`00Aa<00`dC

4`0K4`8011<00`0C4`3D4`0301<C00HC0P044`0301<C04hC0PdP4`00Aa<00`dC4`0Q4`80eA<00`0C

4`064`0301<C00<C00<04a<0CA<00`dC4`0P4`00B1<00`dC4`0P4`0301<C0=<C0P084`<00a<00`0C

4`1;4`8=8a<004PC00<=4a<081<00`0C4`3S4`0301<C04PC0`dU4`00BA<00`dC4`0O4`0301<C0><C

0P174`8=:1<004XC00<=4a<07Q<20>@C00<04a<0@a<33BXC001:4`033A<C01hC00<04a<0ha<00`0C

4`114`8=;A<004/C00<=4a<07A<00`0C4`3S4`0301<C03lC0Pd_4`00C1<00`dC4`0L4`0301<C0><C

0P0n4`8=<A<004`C00<=4a<071<20>@C00<04a<0>a<23C<C001=4`033A<C01/C00<04a<0ha<00`0C

4`0i4`8==A<004dC00<=4a<06a<00`0C4`3S4`0301<C03HC0`dg4`00CQ<00`dC4`0J4`0301<C0><C

0P0e4`8=>Q<004lC00<=4a<06A<20>@C00<04a<0<Q<23C`C001?4`033A<C01TC00<04a<0ha<00`0C

4`0`4`8=?Q<0050C00<=4a<02A<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`3S4`0301<C02hC

0Pe04`00DA<00`dC4`074`0301<000LC00<04`000a<00`0C4`3S4`0301<C02`C0Pe24`00DA<00`dC

4`024`<00Q<00`0C00094`0401<C4`80i1<202/C0Pe44`00DQ<00`dC4`064`0301<000LC0P044`03

01<C0><C00<04a<0:1<23DHC001C4`033A<C00DC00<04`001a<00`0C4`034`0301<C0=`C1@024`03

01<C02HC0Pe84`00Da<00`dC4`064`0301<C00HC0`034`0301<C0=hC00<04a<00Q<00`0C4`0U4`03

3A<C04PC001D4`033A<C01@C00<04a<0f1<300<C00<04a<00Q<202@C0Pe;4`00E1<00`dC4`0D4`80

ga<00`0C4`024`0301<C028C00<=4a<0Ba<005DC00<=4a<04a<00`0C4`3N4`0301<C008C00<04a<0

81<23DhC001F4`033A<C018C00<04a<0gA<200@C00<04a<07Q<23E0C001F4`033A<C018C00<04a<0

ha<00`0C4`0K4`<=DQ<005LC00<=4a<04A<20>@C0P0I4`<=EA<005PC00<=4a<041<00`0C4`3S4`03

01<C01HC0PeH4`006Q<302DC1@0A4`033A<C010C00<04a<091<502@C0`2C4`0301<C01@C0PeJ4`00

6Q<00`0C4`0W4`0301<C018C00<=4a<03a<00`0C4`0V4`0301<C02@C00<04a<0Ta<00`0C4`0B4`8=

G1<001DC0`034`0301<C020C0`034`0301<C01<C00<=4a<03Q<202LC00<04a<09A<00`0C4`2B4`80

41<33EhC000K4`0301<C02HC00<04a<04a<00`dC4`0>4`0301<C02HC00<04a<09A<00`0C4`2B4`03

01<C00/C10eQ4`006Q<00`0C000W4`0301<C01@C00<=4a<03A<00`0C4`0V4`0301<C02@C00<04`00

Ta<00`0C4`094`8=IA<001/C00<04a<09A<201HC00<=4a<03A<00`0C4`0U4`809a<00`0C4`2B4`03

01<C008C1`eW4`00G1<00`dC4`0<4`80i1<53FhC001M4`033A<C00/C00<04a<0fA<:3@80LA<005dC

00<=4a<02a<00`0C4`1K4`80IQ<F3@XC00<04a<0L1<005hC00<=4a<02Q<00`0C4`1J4`0301<C02dC

>@dP4`0301<C070C000E4dX000<=0000H0064`0301<C08HC00<04a<0L1<001TC00<04a<01Q<00`0C

4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0501<C4`d0

0a<00`0C4`054`0341<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`03

01<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<021<00`0C4`264`80CA<;3ATC001P4`03

3A<C00PC00<@4a<0FQ<00`0C00264`0301<C038C6PdT4`00HA<00`dC4`074`8@Fa<308HC00<04a<0

9Q<<3ChC001Q4`033A<C00LC0Q3E4`0301<C008C00<04a<00Q<00`0C4`024`0301<C020C1Pe:4`00

HQ<00`dC4`054`03400@0=@C00<04`001a<00`0C00034`0301<C01/C1@e@4`00HQ<00`dC4`054`03

400@0<lC0`024`0301<000TC00@04a<C0P0I4`<=EA<006<C00<=4a<011<00a00403D4`0301<000LC

0P044`0301<C01DC0`eH4`00I1<00`dC4`024`0541<00100da<00`0C00074`0301<C00<C00<04a<0

4a<23E/C001T4`033A<C008C00D@4`0C403D4`0301<C00HC0`034`0301<C014C0PeM4`00IA<02@dC

4a<@4`0C403S4`8041<23ElC001V4`063A<C41<00Q<00a0C4`3P4`0301<C00dC0PeQ4`00IQ<01@dC

4a0C008000<C41<0hA<00`0C4`0<4`033A<C064C001W4`053A<@4`000Q<00a0C4`3P4`0301<C00XC

0PeT4`00Ia<01@d@4a<000<C00<@4a<0ga<00`0C4`084`8=IQ<006PC00@=4a<00a<00a0C4`3O4`80

21<00`dC4`1V4`00J1<00a0=4`02008C00<@4a<0ga<00`0C4`064`033A<C06LC001W4`0541<=4`00

11<00a0C4`3N4`0301<C00DC00<=4a<0J1<005`C00<04a<00Q<00`0C4`024`06010C4`d011<00a0C

4`264`<0:A<502LC00<04a<011<00`dC4`0P4`D0:A<301PC001K4`0301<000LC00<040000Q<00`d0

4`034`0341<C08HC00<04a<0:a<00`0C4`0W4`8011<00`dC4`0S4`0301<C02TC00<04a<061<005/C

00<04`0021<00a004`024`033@0C00<C00<@4a<0P1<300<C00<04a<091<300<C00<04a<09a<00`0C

4`024`033A<C02@C00<04a<0:Q<00`0C4`0G4`00Fa<00`0C00074`03010C00<C00<03A<00a<00a0C

4`264`0301<C02XC00<04a<09a<00`0C4`024`033A<C02@C00<04a<0:Q<00`0C4`0G4`00Fa<00`0C

00074`0341<C00<C00<03A<011<00a0C4`244`0301<002/C00<04a<09a<01@0C4a<=02LC00<04a<0

:A<00`0C000H4`00G1<00`0C4`064`03400000<C00<04`d011<00a0C4`254`0301<C02TC0P0Y4`80

0Q<00`dC4`0T4`80;1<00`0C4`0G4`00I1<00a0C4`044`8000<C3A<00Q<00a0C4`3L4`0401<C3FlC

001T4`0341<C00@C00@04a<=11<00a0C4`3K4`0301<=070C001S4`0341<C00DC00D04a<C3@034`03

41<C0=/C00<03A<0Ha<200/C001S4`0341<C00DC00D04a<C3@044`0341<C0=XC00<03A<0HQ<00`0C

4`0;4`00HQ<00a0C4`064`0301<C008C00D=4a<C401n4eh000<=0000G0064`0301<C00/C001R4`03

41<C00HC0P044`053A<C4a00PQ<00`0C4`064`0301<C00HC00<04a<01Q<00`0C4`064`0301<C00HC

00<04a<01A<00`0C4`064`0301<C00HC00<04a<01Q<00`0C4`064`033A<C00HC00<04a<01Q<00`0C

4`064`0301<C00HC00<04a<01Q<00`0C4`064`0301<C00HC00<04a<01A<00`0C4`064`0301<C00HC

00<04a<02A<00`0C4`0;4`00HA<00a0C4`074`0301<C00<C00D=4a<C403J4`033@0C06<C00<04`00

2a<0064C00<@4a<01a<00`0C4`044`043A<C4=XC00<=01<0Ha<300/C001P4`0341<C00PC00<04a<0

1A<010dC4a3H4`043A<0074C001P4`0341<C00PC0P064`043A<C4=PC00<=4`00LQ<005lC00<@4a<0

2A<00`0C4`064`043A<C4=LC00<=4`00LQ<005lC00<@4a<02A<00`0C4`074`033A<@0=LC00<=4`00

LQ<005hC00<@4a<02Q<00`0C4`074`043A<C4=DC00@=4a<0LQ<005hC00<@4a<02Q<200TC00<=4a00

eA<00`dC4`02074C001M4`0341<C00/C00<04a<021<010dC4a3D4`043A<C078C001M4`0341<C00@C

1@024`0301<C00TC00<=4a00e1<010dC4`1b4`00G1<00a0C4`074`0301<C008C00<04a<02Q<00`dC

403C4`043A<C078C001K4`0341<C00PC00<04a<00Q<200/C00@=4a<@dA<010dC4a<2074C001K4`03

41<C00PC00<04a<00Q<00`0C4`0;4`033A<@0=4C00D=4a<C001b4`00FQ<00a0C4`094`0301<C008C

00<04a<031<00`dC403@4`053A<C4`00LQ<005XC00<@4a<021<200@C00<04a<031<010dC4a3?4`05

3A<C4`00LQ<005TC00<@4a<03a<200hC00<=4a00ca<01@dC4a<0078C001H4`0341<C010C00<04a<0

3Q<00`dC403>4`043A<C4`80LA<005PC00<@4a<041<00`0C4`0>4`043A<C4<hC00@=4a<0LQ<005LC

00<@4a<04A<00`0C4`0?4`033A<@0<8C00<04a<00Q<00`0C4`024`0301<=008C00<04a<0L1<005HC

00<@4a<04Q<2010C00@=4a<@`1<00`0C00074`0401<03@8C00<04a<0L1<005HC00<@4a<04Q<00`0C

4`0@4`043A<C4;lC00<04`002A<0100=4a<2074C001E4`0341<C01<C00<04a<04A<00`dC402o4`03

01<000LC0P001A<=4a<0078C001D4`0341<C01@C00<04a<04A<010dC4a2n4`0301<000LC00L04a<C

3A<0078C001C4`0341<C01DC0P0C4`033A<@0;lC00<04a<01Q<300044`dC078C001C4`0341<C01DC

00<04a<04a<00`dC403;4`033A<0078C001B4`0341<C01HC00<04a<04a<010dC4a3:4`043A<0074C

001A4`0341<C01LC00<04a<051<00`dC403;4`033@0C074C001A4`0341<C01LC0P0F4`033A<@0<XC

00<=01<0LA<0050C00<@4a<061<00`0C4`0E4`033A<@0</C00<=4a<0L1<004lC00<@4a<021<5008C

00<04a<00Q<00`0C4`024`0301<C01HC00<=4a00bQ<00`d04`1`4`00Ca<00a0C4`0:4`0301<C00HC

00<04`000a<00`0C4`0F4`043A<C4<TC00<03A<0L1<004hC00<@4a<02a<00`0C4`084`0401<C4`80

61<010dC4a384`0300dC070C001=4`0341<C00`C00<04a<01Q<200@C00<04a<061<00`dC40384`03

01<=070C001<4`0341<C00dC00<04a<01Q<00`0C4`034`0301<C01PC00@=4a<@aa<00`0C3@1`4`00

C1<00a0C4`0<4`8021<300<C00<04a<06A<010dC4a364`8000<C3A<0KQ<004/C00<@4a<07A<201/C

00@=4a<@aA<01@0C4a<=06hC001:4`0341<C01hC00<04a<06Q<010dC4a354`0501<C4`d0KQ<004XC

00<@4a<07Q<00`0C4`0K4`043A<C4<@C00<04a<00Q<00`dC4`1[4`00BA<00a0C4`0O4`0301<C01/C

00D=4a<C40334`800a<00`dC4`1[4`00B1<00a0C4`0P4`807A<01@dC4a<@0<8C00<04a<00a<00`dC

4`1Z4`00Aa<00a0C4`0Q4`0301<C01`C00<=4a<00Q<00a0C4`2o4`0301<C00@C00<=4a<0JA<004LC

00<@4a<08A<00`0C4`0M4`053A<C4a00^Q<5008C00<04a<01A<00`dC4`1X4`00AQ<00a0C4`0R4`03

01<C01dC00<=4a<00Q<00a0C4`2i4`0301<C008C00<04a<01A<00`dC4`1X4`00AA<00a0C4`0S4`80

7a<00`dC4`024`0341<C0;PC00<04a<00Q<200LC00<=4a<0Ia<004@C00<@4a<091<00`0C4`0N4`03

3A<C00<C00<@4a<0]a<00`0C4`024`0301<C00LC00<=4a<0IQ<004@C00<@4a<091<00`0C4`0O4`03

3A<C008C00<@4a<0]a<00`0C4`024`0301<C00PC00<=4a<0IA<004<C00<@4a<09A<00`0C4`0P4`03

3A<C008C00<@4a<0]A<200@C00<04a<02A<00`dC4`1T4`00@Q<00a0C4`0V4`0301<C020C00<=4a<0

0a<00a0C4`2j4`802a<00`dC4`1S4`00@A<00a0C4`0W4`808Q<00`dC4`034`0341<C0;TC00<04a<0

2a<00`dC4`1R4`00@1<00a0C4`0X4`0301<C028C00<=4a<00a<00a0C4`2h4`0301<C00`C00<=4a<0

HA<0040C00<@4a<08Q<300<C00<04a<08Q<00`dC4`044`0341<C0;LC00<04a<03A<00`dC4`1P4`00

?a<00a0C4`0S4`0301<C00<C00<04a<08a<00`dC4`034`0341<C0;LC0P0?4`8=H1<003hC00<@4a<0

9A<00`0C4`024`8091<00`dC4`044`0341<C0;HC00<04a<041<00`dC4`1M4`00?A<00a0C4`0V4`03

01<C008C00<04a<091<00`dC4`044`0341<C0;DC00<04a<04A<00`dC4`1L4`00?A<00a0C4`0U4`03

01<000<C00<04a<09A<00`dC4`044`0341<C0;@C00<04a<04Q<00`dC4`1K4`00?1<00a0C4`0W4`03

01<C008C00<04a<09A<00`dC4`054`0341<C0;<C00<04a<04a<00`dC4`1J4`00>a<00a0C4`0]4`80

9a<00`dC4`054`0341<C0;8C0P0E4`033A<C05TC000j4`0341<C02hC00<04a<09a<00`dC4`044`03

41<C0;8C00<04a<05A<00`dC4`1H4`00>Q<00a0C4`0^4`0301<C02LC00<=4a<01A<00a0C4`2a4`03

01<C01HC00<=4a<0Ea<003TC00<@4a<0;a<00`0C4`0X4`033A<C00DC00<@4a<0/1<00`0C4`0G4`8=

Ea<003PC00<@4a<0<1<202XC00<=4a<01A<00a0C4`2_4`806Q<00`dC4`1D4`00=a<00a0C4`0a4`03

01<C02TC00<=4a<01A<00a0C4`2_4`0301<C01XC0PeD4`00=a<00a0C4`0a4`0301<C02XC00<=4a<0

1A<00a0C4`2^4`0301<C01`C00<=4a<0DA<003HC00<@4a<0<Q<00`0C4`0Z4`033A<C00HC00<@4a<0

W1<5008C00<04a<00Q<00`0C4`024`0301<C01dC0PeA4`00=A<00a0C4`0c4`80;1<00`dC4`064`03

41<C09dC00<04a<01Q<00`0C00034`0301<C01lC00<=4a<0CQ<003@C00<@4a<0=1<00`0C4`0/4`03

3A<C00HC00<@4a<0W1<00`0C4`084`0401<C4`808A<23DhC000c4`0341<C03DC00<04a<0;1<00`dC

4`074`0341<C09/C00<04a<01Q<200@C00<04a<08Q<00`dC4`1;4`00<Q<00a0C4`0f4`0301<C02dC

00<=4a<01Q<00a0C4`2K4`0301<C00HC00<04a<00a<00`0C4`0S4`8=Ba<0034C00<@4a<0=a<202lC

00<=4a<01Q<00a0C4`2I4`8021<300<C00<04a<09A<00`dC4`184`00<1<00a0C4`0h4`0301<C02hC

00<=4a<01a<00a0C4`2X4`809a<23DPC000_4`0341<C02TC0`034`0301<C008C00<04a<00Q<00`0C

4`0_4`033A<C00LC00<@4a<0Ya<00`0C4`0X4`033A<C04DC000^4`0341<C02XC00<04a<01a<00`0C

00034`0301<C030C00<=4a<01a<00a0C4`2V4`0301<C02TC0Pe54`00;A<00a0C4`0/4`0301<C00PC

00@04a<C0P0a4`033A<C00PC00<@4a<0YA<00`0C4`0[4`033A<C048C000/4`0341<C02dC00<04a<0

1Q<200@C00<04a<0<A<00`dC4`084`0341<C0:@C00<04a<0;1<23D8C000[4`0341<C02dC00<04`00

1a<00`0C4`034`0301<C034C00<=4a<02A<00a0C4`2S4`80;a<00`dC4`0o4`00:Q<00a0C4`0_4`03

01<C00HC0`034`0301<C038C00<=4a<02A<00a0C4`2R4`0301<C02lC0Pdo4`00:A<00a0C4`0o4`80

=1<00`dC4`094`0341<C0:4C00<04a<0<A<23CdC000X4`0341<C040C00<04a<0<a<00`dC4`0:4`03

41<C0:0C00<04a<0<a<23C/C000W4`0341<C044C00<04a<0=1<00`dC4`0:4`0341<C09lC0P0f4`8=

>A<002HC00<@4a<0@Q<00`0C4`0e4`033A<C00XC00<@4a<0WQ<00`0C4`0g4`8==a<002DC00<@4a<0

@a<203HC00<=4a<02a<00a0C4`2M4`0301<C03TC0Pde4`0091<00a0C4`144`0301<C03HC00<=4a<0

2a<00a0C4`2L4`0301<C03/C0Pdc4`008a<00a0C4`154`0301<C03LC00<=4a<02a<00a0C4`2K4`03

01<C03dC0Pda4`008a<00a0C4`154`0301<C03LC00<=4a<031<00a0C4`2J4`80@1<00`dC4`0^4`00

8Q<00a0C4`164`80>A<00`dC4`0<4`0341<C09TC00<04a<0@1<23BhC000Q4`0341<C04LC00<04a<0

>1<00`dC4`0=4`0341<C098C0`034`0301<C048C0Pd/4`0081<00a0C4`184`0301<C03TC00<=4a<0

3A<00a0C4`2A4`0301<C00<C00<04a<0A1<23BXC000O4`0341<C04TC00<04a<0>Q<00`dC4`0=4`03

41<C094C00<04a<00Q<204LC0PdX4`007Q<00a0C4`1:4`80>a<00`dC4`0>4`0341<C090C00<04a<0

0Q<00`0C4`184`8=9Q<001dC00<@4a<0Ba<00`0C4`0k4`033A<C00hC00<@4a<0SQ<00`0C00034`03

01<C04XC0PdT4`0071<00a0C4`1<4`0301<C03/C00<=4a<03a<00a0C4`2>4`0301<C008C00<04a<0

C1<33B4C000K4`0341<C04LC0P044`0301<C03`C00<=4a<03a<00a0C4`2B4`0301<C04lC0`dN4`00

6Q<00a0C4`1:4`0501<C4`00?Q<00`dC4`0@4`0341<C094C0P1C4`8=71<001TC00<@4a<0BQ<00`0C

4`024`80?Q<00`dC4`0?4`0341<C094C00<04a<0E1<23AXC001W4`0301<C0>LC00<04a<0EQ<00`dC

4`0G4`00IA<00`0C003Y4`0301<C070C001V4`0301<C0>PC0P1a4`00;a<30?lC81<00`0C4`1`4`00

;a<00`0C4`3o4b0C00<04a<0L1<0030C00<04a<011<00`0C4`3o4h/C000`4`0401<C4`@00a<30?lC

Qa<002lC00<04`000Q<200034`0C00@C00<04a<0oa>54`00<1<00`0C4`034`0301<000<C00<04a<0

oa>64`00=Q<00`0C00044`0301<C00HC00<04a<08Q<3030C00<04a<0oa<T4`0081<300034`000080

31<300@C0`084`0301<C024C00@04a<051<300034`0000800Q<00`0C4`024`0301<C008C00<04a<0

1A<0100C4a<5008C00@04a<C0P064`80ca<00`0C4`0]4`0301<C00/C000O4`0401<C02@C00<04a<0

81<0100C4`0C4`0401<C00HC00<04`001a<00`0C00044`D00a<00`0C4`064`0301<000@C00<04a<0

aa<00`0C4`044`0301<C01<C00<04a<06A<00`0C4`0:4`007a<01@0C4`0C00@000<C0000600X4`<0

4a<01@0C4`0C00@000@C01<02A<00`0C4`044`0301<C00<C00<04a<01Q<00`0C00044`0301<C0;DC

00@04a<C10024`801Q<00`0C4`034`0301<C008C00<04a<00Q<00`0C4`024`0301<C00DC00@04a<C

1@024`0401<C4`801Q<200@C00@04a<C0P000a<000034`0081<304XC00<04a<04Q<300HC00<04`00

1a<200LC00<04a<00a<00`0C4`064`801A<00`0C4`2d4`0301<000LC00<04a<011<500<C00L04a<C

01<000LC00<04`0011<500<C00<04a<01Q<00`0C00044`0301<C00@C00<04a<00Q<00`0C00044`00

8Q<00`0C4`174`805Q<00`0C4`044`0301<000LC00<04a<031<00`0C4`064`0301<C00@C00<04`00

]1<00`0C00024`@000<C01<01a<00`0C4`034`0701<C4`0C00094`0301<C00@C00<04a<00a<00`0C

4`064`0301<000@C00<04a<011<00`0C4`034`0301<C00<C000Q4`80H1<200LC00<04a<01Q<300/C

0P094`8011<309PC0P000a<0000G4`0301<000LC00<04a<01Q<00`0C4`034`0701<C4`0C00074`80

1a<00`0C4`034`0301<C00HC0P054`0301<C00@C00<04a<00a<00`0C4`034`00oa=A4`0301<001PC

00<04`001a<00`0C000=4`0601<C01<01a<00`0C4`0<4`0301<C00HC00<04a<011<00`0C00034`03

01<C00<C00<04`0011<002/C0P064`80oa<M4`0301<C01PC00<04a<01Q<300hC00@04a<021<300/C

0P094`8011<3008C00<04a<00a<200034`0000<C000]4`0301<C008C00<04a<0oa<M4`0301<C070C

000/4`0301<C00<C00<04a<01Q<00`0C4`3o4a<C00<04`00LA<002dC00<04a<00Q<00`0C4`024`<0

00@C01<C0`3o4`lC0P000a<0001`4`00:a<00`0C00044`0301<0008C0P024`0301<C008C00<04a<0

oa>24`00;1<00`0C4`034`<011<0100C4`024`0301<C0?lCPa<003TC00@04a<00a<00`0C4`3o4h8C

000g4`<011<30?lCQ1<00?lCaA<00?lCaA<00?lCaA<00?lCaA<00?lCaA<00001\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.57174, -1.75514, 0.0224285, 0.0224285}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -84.5 0 ]

[.5 .96488 84.5 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -145.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.595) show

222.250000 19.500000 moveto

(C) show

227.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.27609 0 m

.30316 .04318 L

.34309 .10686 L

.3815 .16813 L

.42237 .23332 L

.46172 .29608 L

.49955 .35643 L

.53984 .42069 L

.57861 .48253 L

.61984 .54828 L

.65954 .61162 L

.69774 .67253 L

.73838 .73736 L

.77751 .79977 L

.81909 .8661 L

.85916 .93 L

s

.85916 .93 m

.87319 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.390765 0.238095 [

[.02381 .37826 -6 -9 ]

[.02381 .37826 6 0 ]

[.2619 .37826 -6 -9 ]

[.2619 .37826 6 0 ]

[.7381 .37826 -3 -9 ]

[.7381 .37826 3 0 ]

[.97619 .37826 -3 -9 ]

[.97619 .37826 3 0 ]

[1.025 .39076 0 -8 ]

[1.025 .39076 9 8 ]

[.4875 .03362 -24 -4.5 ]

[.4875 .03362 0 4.5 ]

[.4875 .15267 -12 -4.5 ]

[.4875 .15267 0 4.5 ]

[.4875 .27172 -24 -4.5 ]

[.4875 .27172 0 4.5 ]

[.4875 .50981 -18 -4.5 ]

[.4875 .50981 0 4.5 ]

[.4875 .62886 -6 -4.5 ]

[.4875 .62886 0 4.5 ]

[.4875 .74791 -18 -4.5 ]

[.4875 .74791 0 4.5 ]

[.4875 .86696 -6 -4.5 ]

[.4875 .86696 0 4.5 ]

[.5 .94957 -4.5 0 ]

[.5 .94957 4.5 16 ]

[.5 .93707 -137 0 ]

[.5 .93707 137 16 ]

[ 0 0 0 0 ]

[ 1 .92457 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .39076 m

.02381 .39701 L

s

[(-2)] .02381 .37826 0 1 Mshowa

.2619 .39076 m

.2619 .39701 L

s

[(-1)] .2619 .37826 0 1 Mshowa

.7381 .39076 m

.7381 .39701 L

s

[(1)] .7381 .37826 0 1 Mshowa

.97619 .39076 m

.97619 .39701 L

s

[(2)] .97619 .37826 0 1 Mshowa

.125 Mabswid

.07143 .39076 m

.07143 .39451 L

s

.11905 .39076 m

.11905 .39451 L

s

.16667 .39076 m

.16667 .39451 L

s

.21429 .39076 m

.21429 .39451 L

s

.30952 .39076 m

.30952 .39451 L

s

.35714 .39076 m

.35714 .39451 L

s

.40476 .39076 m

.40476 .39451 L

s

.45238 .39076 m

.45238 .39451 L

s

.54762 .39076 m

.54762 .39451 L

s

.59524 .39076 m

.59524 .39451 L

s

.64286 .39076 m

.64286 .39451 L

s

.69048 .39076 m

.69048 .39451 L

s

.78571 .39076 m

.78571 .39451 L

s

.83333 .39076 m

.83333 .39451 L

s

.88095 .39076 m

.88095 .39451 L

s

.92857 .39076 m

.92857 .39451 L

s

.25 Mabswid

0 .39076 m

1 .39076 L

s

gsave

1.025 .39076 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .03362 m

.50625 .03362 L

s

[(-1.5)] .4875 .03362 1 0 Mshowa

.5 .15267 m

.50625 .15267 L

s

[(-1)] .4875 .15267 1 0 Mshowa

.5 .27172 m

.50625 .27172 L

s

[(-0.5)] .4875 .27172 1 0 Mshowa

.5 .50981 m

.50625 .50981 L

s

[(0.5)] .4875 .50981 1 0 Mshowa

.5 .62886 m

.50625 .62886 L

s

[(1)] .4875 .62886 1 0 Mshowa

.5 .74791 m

.50625 .74791 L

s

[(1.5)] .4875 .74791 1 0 Mshowa

.5 .86696 m

.50625 .86696 L

s

[(2)] .4875 .86696 1 0 Mshowa

.125 Mabswid

.5 .05743 m

.50375 .05743 L

s

.5 .08124 m

.50375 .08124 L

s

.5 .10505 m

.50375 .10505 L

s

.5 .12886 m

.50375 .12886 L

s

.5 .17648 m

.50375 .17648 L

s

.5 .20029 m

.50375 .20029 L

s

.5 .2241 m

.50375 .2241 L

s

.5 .24791 m

.50375 .24791 L

s

.5 .29553 m

.50375 .29553 L

s

.5 .31934 m

.50375 .31934 L

s

.5 .34315 m

.50375 .34315 L

s

.5 .36696 m

.50375 .36696 L

s

.5 .41457 m

.50375 .41457 L

s

.5 .43838 m

.50375 .43838 L

s

.5 .46219 m

.50375 .46219 L

s

.5 .486 m

.50375 .486 L

s

.5 .53362 m

.50375 .53362 L

s

.5 .55743 m

.50375 .55743 L

s

.5 .58124 m

.50375 .58124 L

s

.5 .60505 m

.50375 .60505 L

s

.5 .65267 m

.50375 .65267 L

s

.5 .67648 m

.50375 .67648 L

s

.5 .70029 m

.50375 .70029 L

s

.5 .7241 m

.50375 .7241 L

s

.5 .77172 m

.50375 .77172 L

s

.5 .79553 m

.50375 .79553 L

s

.5 .81934 m

.50375 .81934 L

s

.5 .84315 m

.50375 .84315 L

s

.5 .00981 m

.50375 .00981 L

s

.5 .89076 m

.50375 .89076 L

s

.5 .91457 m

.50375 .91457 L

s

.25 Mabswid

.5 0 m

.5 .92457 L

s

gsave

.5 .94957 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .93707 -198 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.595) show

298.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

303.000000 15.000000 moveto

(L) show

310.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

317.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

324.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

329.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

333.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .92457 L

0 .92457 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .2374 m

.02576 .23738 L

.03158 .23734 L

.04117 .23727 L

.05436 .23717 L

.07093 .23704 L

.09059 .23687 L

.11301 .23667 L

.13781 .23642 L

.16456 .23611 L

.1928 .23575 L

.22205 .23533 L

.25181 .23483 L

.28157 .23424 L

.31082 .23355 L

.33906 .23276 L

.36581 .23185 L

.39061 .23084 L

.41303 .22973 L

.4327 .22857 L

.44927 .22741 L

.46246 .22635 L

.47204 .22549 L

.47786 .22492 L

.47981 .22472 L

s

.47981 .22472 m

.48193 .2245 L

.48827 .22381 L

.4987 .22257 L

.51306 .22061 L

.5311 .21764 L

.5525 .21323 L

.57691 .20676 L

.60391 .19761 L

.63302 .18554 L

.66376 .17102 L

.69561 .15496 L

.728 .13831 L

.7604 .12178 L

.79224 .10584 L

.82298 .09084 L

.8521 .07701 L

.87909 .06452 L

.9035 .05348 L

.9249 .04401 L

.94294 .03616 L

.9573 .03 L

.96773 .02557 L

.97407 .0229 L

.97619 .02201 L

s

.47981 .47373 m

.48193 .44648 L

.48827 .41961 L

.4987 .3934 L

.51306 .36818 L

.5311 .34437 L

.5525 .32254 L

.57691 .30343 L

.60391 .28779 L

.63302 .27595 L

.66376 .26757 L

.69561 .26183 L

.728 .25789 L

.7604 .25513 L

.79224 .25315 L

.82298 .2517 L

.8521 .25061 L

.87909 .24978 L

.9035 .24915 L

.9249 .24867 L

.94294 .24831 L

.9573 .24804 L

.96773 .24786 L

.97407 .24776 L

.97619 .24772 L

s

.47981 .47384 m

.48193 .50131 L

.48827 .52887 L

.4987 .55632 L

.51306 .5835 L

.5311 .61028 L

.5525 .63652 L

.57691 .6621 L

.60391 .6869 L

.63302 .7108 L

.66376 .7337 L

.69561 .7555 L

.728 .77609 L

.7604 .79538 L

.79224 .8133 L

.82298 .82975 L

.8521 .84467 L

.87909 .85799 L

.9035 .86966 L

.9249 .87962 L

.94294 .88783 L

.9573 .89425 L

.96773 .89886 L

.97407 .90163 L

.97619 .90256 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<00`0C4`1`4`00oa=B4`80LA<006@C1@3X4`0301<C070C001V4`0301<C0>PC00<04a<0

L1<004DC00<=4a<061<300<C00<04a<00Q<20=<C1@024`0301<C008C00<04a<00Q<00`0C4`1E4`8=

6A<004HC00<=4a<07A<00`0C4`024`0301<C0=@C00<04a<01Q<00`0C00034`0301<C058C0`dK4`00

AQ<00`dC4`0M4`0301<C008C00<04a<0cQ<300<C00<04a<021<0100C4a<2054C0PdN4`00Aa<00`dC

4`0K4`8011<00`0C4`3D4`0301<C00HC0P044`0301<C04hC0PdP4`00Aa<00`dC4`0Q4`80eA<00`0C

4`064`0301<C00<C00<04a<0CA<00`dC4`0P4`00B1<00`dC4`0P4`0301<C0=<C0P084`<00a<00`0C

4`1;4`8=8a<004PC00<=4a<081<00`0C4`3S4`80BA<33BDC00194`033A<C01lC00<04a<0ha<00`0C

4`164`8=:1<004XC00<=4a<07Q<20>@C00<04a<0@a<33BXC001:4`033A<C01hC00<04a<0ha<00`0C

4`114`8=;A<004/C00<=4a<07A<00`0C4`3S4`0301<C03lC0Pd_4`00C1<00`dC4`0L4`0301<C0><C

0P0n4`8=<A<004`C00<=4a<071<20>@C00<04a<0>a<23C<C001=4`033A<C01/C00<04a<0ha<00`0C

4`0i4`8==A<004dC00<=4a<06a<00`0C4`3S4`0301<C03HC0`dg4`00CQ<00`dC4`0J4`0301<C0><C

0P0e4`8=>Q<004lC00<=4a<06A<20>@C00<04a<0<Q<23C`C001?4`033A<C01TC00<04a<0ha<00`0C

4`0`4`8=?Q<0050C00<=4a<02A<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`3S4`0301<C02hC

0Pe04`00DA<00`dC4`074`0301<000LC00<04`000a<00`0C4`3S4`0301<C02`C0Pe24`00DA<00`dC

4`024`<00Q<00`0C00094`0401<C4`80i1<202`C00<=4a<0@Q<0058C00<=4a<01Q<00`0C00074`80

11<00`0C4`3S4`0301<C02TC0Pe54`00Da<00`dC4`054`0301<000LC00<04a<00a<00`0C4`3L4`D0

0Q<00`0C4`0X4`033A<C04DC001C4`033A<C00HC00<04a<01Q<300<C00<04a<0gQ<00`0C4`024`03

01<C02HC0Pe84`00E1<00`dC4`0D4`0301<C0=PC0`034`0301<C008C0P0U4`8=BQ<005@C00<=4a<0

51<20=lC00<04a<00Q<00`0C4`0R4`8=C1<005DC00<=4a<04a<00`0C4`3N4`0301<C008C00<04a<0

81<23DhC001F4`033A<C018C00<04a<0gA<200@C00<04a<07Q<23E0C001F4`033A<C018C00<04a<0

ha<00`0C4`0K4`<=DQ<005LC00<=4a<04A<20>@C0P0I4`<=EA<005PC00<=4a<041<00`0C4`3S4`03

01<C01HC0PeH4`006Q<302DC1@0A4`033A<C010C00<04a<091<502@C0`2C4`0301<C01@C0PeJ4`00

6Q<00`0C4`0W4`0301<C018C00<=4a<03a<00`0C4`0V4`0301<C02@C00<04a<0Ta<00`0C4`0B4`8=

G1<001DC0`034`0301<C020C0`034`0301<C01<C00<=4a<03Q<202LC00<04a<09A<00`0C4`2B4`80

41<33EhC000K4`0301<C02HC00<04a<04a<00`dC4`0>4`0301<C02HC00<04a<09A<00`0C4`2B4`03

01<C00/C10eQ4`006Q<00`0C000W4`0301<C01@C00<=4a<03A<00`0C4`0V4`0301<C02@C00<04`00

Ta<00`0C4`094`8=IA<001/C00<04a<09A<201HC00<=4a<03A<00`0C4`0U4`809a<00`0C4`2B4`03

01<C008C1`eW4`00G1<00`dC4`0<4`80i1<53FhC001M4`033A<C00/C00<04a<0eA<>3@80LA<005dC

00<=4a<02a<00`0C4`1K4`80HA<G3@hC00<04a<0L1<005hC00<=4a<02Q<00`0C4`1J4`0301<C02dC

=0dU4`0301<C070C000E4dX000<=0000H0064`0301<C08HC00<04a<0L1<001TC00<04a<01Q<00`0C

4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0501<C4`d0

0a<00`0C4`054`0341<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`03

01<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<021<00`0C4`264`80@a<E3ATC001P4`03

3A<C00PC00<@4a<0FQ<00`0C00264`0301<C02`C5Pd^4`00HA<00`dC4`074`8@Fa<308HC00<04a<0

9Q<63D@C001Q4`033A<C00LC0Q3E4`0301<C008C00<04a<00Q<00`0C4`024`0301<C020C1Pe:4`00

HQ<00`dC4`054`03400@0=@C00<04`001a<00`0C00034`0301<C01XC1Pe@4`00HQ<00`dC4`054`03

400@0<lC0`024`0301<000TC00@04a<C0P0G4`@=EQ<006<C00<=4a<011<00a00403D4`0301<000LC

0P044`0301<C01@C0PeJ4`00I1<00`dC4`024`0541<00100da<00`0C00074`0301<C00<C00<04a<0

4Q<23E`C001T4`033A<C008C00D@4`0C403D4`0301<C00HC0`034`0301<C010C0PeN4`00IA<02@dC

4a<@4`0C403S4`803a<23F0C001V4`063A<C41<00Q<00a0C4`3P4`0301<C00`C0PeR4`00IQ<01@dC

4a0C008000<C41<0hA<00`0C4`0;4`033A<C068C001W4`053A<@4`000Q<00a0C4`3P4`0301<C00TC

0PeU4`00Ia<01@d@4a<000<C00<@4a<0ga<200TC00<=4a<0IA<006PC00@=4a<00a<00a0C4`3O4`03

01<C00LC00<=4a<0IQ<006PC00<@3A<00P024`0341<C0=lC00<04a<01Q<00`dC4`1W4`00Ia<01A0C

3A<000@C00<@4a<0gQ<00`0C4`054`033A<C06PC001L4`0301<C008C00<04a<00Q<01P0@4a<=00@C

00<@4a<0QQ<302PC1@0X4`0301<C00@C00<=4a<081<502TC0`0H4`00Fa<00`0C00074`030100008C

00<=01<00a<00a0C4`264`0301<C02XC00<04a<0:1<200@C00<=4a<08a<00`0C4`0Y4`0301<C01PC

001K4`0301<000PC00<@01<00Q<00`d04`034`0341<C080C0`034`0301<C02<C0`034`0301<C02PC

00<04a<00Q<00`dC4`0T4`0301<C02XC00<04a<05a<005/C00<04`001a<00`0@4`034`0300dC00<C

00<@4a<0QQ<00`0C4`0Y4`0301<C02PC00<04a<00Q<00`dC4`0T4`0301<C02XC00<04a<05a<005/C

00<04`001a<00a0C4`034`0300dC00@C00<@4a<0Q1<00`0C000Z4`0301<C02PC00D04a<C3@0W4`03

01<C02TC00<04`0061<005`C00<04a<01Q<00a0000034`0301<=00@C00<@4a<0QA<00`0C4`0X4`80

:Q<2008C00<=4a<091<202`C00<04a<05a<006@C00<@4a<011<200034`dC008C00<@4a<0g1<0100C

4`e_4`00I1<00a0C4`044`0401<C3@@C00<@4a<0fa<00`0C3@1`4`00Ha<00a0C4`054`0501<C4`d0

0a<00a0C4`3K4`0300dC06@C0P0:4`00Ha<00a0C4`054`0501<C4`d011<00a0C4`3J4`0300dC06<C

00<04a<02Q<0068C00<@4a<01Q<00`0C4`024`053A<C4a00OQ=N00033@0005`01a<00`0C4`0:4`00

HQ<00a0C4`064`8011<01@dC4a<@088C00<04a<01Q<00`0C4`064`0301<C00HC00<04a<01Q<00`0C

4`054`0301<C00HC00<04a<01Q<00`0C4`064`0301<C00HC00<04a<01Q<00`dC4`064`0301<C00HC

00<04a<01Q<00`0C4`064`0301<C00HC00<04a<01Q<00`0C4`064`0301<C00HC00<04a<01A<00`0C

4`064`0301<C00XC00<04a<02Q<0064C00<@4a<01a<00`0C4`034`053A<C4a00fQ<00`d04`1T4`03

01<000XC001Q4`0341<C00LC00<04a<011<010dC4a3J4`033@0C06@C0`0:4`00H1<00a0C4`084`03

01<C00DC00@=4a<@f1<010dC001a4`00H1<00a0C4`084`801Q<010dC4a3H4`033A<0078C001O4`03

41<C00TC00<04a<01Q<010dC4a3G4`033A<0078C001O4`0341<C00TC00<04a<01a<00`dC403G4`03

3A<0078C001N4`0341<C00XC00<04a<01a<010dC4a3E4`043A<C078C001N4`0341<C00XC0P094`03

3A<@0=DC00<=4a<00P1a4`00GA<00a0C4`0;4`0301<C00PC00@=4a<@e1<010dC4`1b4`00GA<00a0C

4`044`D00Q<00`0C4`094`033A<@0=@C00@=4a<0LQ<005`C00<@4a<01a<00`0C4`024`0301<C00XC

00<=4a00da<010dC4`1b4`00Fa<00a0C4`084`0301<C008C0P0;4`043A<C4=4C00@=4a<C0P1a4`00

Fa<00a0C4`084`0301<C008C00<04a<02a<00`dC403A4`053A<C4`00LQ<005XC00<@4a<02A<00`0C

4`024`0301<C00`C00<=4a00d1<01@dC4a<0078C001J4`0341<C00PC0P044`0301<C00`C00@=4a<@

ca<01@dC4a<0078C001I4`0341<C00lC0P0>4`033A<@0<lC00D=4a<C001b4`00F1<00a0C4`0@4`03

01<C00hC00<=4a00cQ<010dC4a<2074C001H4`0341<C010C00<04a<03Q<010dC4a3>4`043A<C078C

001G4`0341<C014C00<04a<03a<00`dC40324`0301<C008C00<04a<00Q<00`0C3@024`0301<C070C

001F4`0341<C018C0P0@4`043A<C4<0C00<04`001a<0100C00d24`0301<C070C001F4`0341<C018C

00<04a<041<010dC4a2o4`0301<000TC00@03A<C0P1a4`00EA<00a0C4`0C4`0301<C014C00<=4a00

_a<00`0C00074`8000DC3A<C001b4`00E1<00a0C4`0D4`0301<C014C00@=4a<@_Q<00`0C00074`07

01<C4`dC001b4`00Da<00a0C4`0E4`804a<00`dC402o4`0301<C00HC0`0011<=4`1b4`00Da<00a0C

4`0E4`0301<C01<C00<=4a00ba<00`dC001b4`00DQ<00a0C4`0F4`0301<C01<C00@=4a<@bQ<010dC

001a4`00DA<00a0C4`0G4`0301<C01@C00<=4a00ba<00`d04`1a4`00DA<00a0C4`0G4`805Q<00`dC

403:4`033@0C074C001@4`0341<C01PC00<04a<05A<00`dC403;4`033A<C070C001?4`0341<C00PC

1@024`0301<C008C00<04a<00Q<00`0C4`0F4`033A<@0<XC00<=01<0L1<004lC00<@4a<02Q<00`0C

4`064`0301<000<C00<04a<05Q<010dC4a394`0300dC070C001>4`0341<C00/C00<04a<021<0100C

4a<201PC00@=4a<@b1<00`0=4`1`4`00CA<00a0C4`0<4`0301<C00HC0P044`0301<C01PC00<=4a00

b1<00`0C3@1`4`00C1<00a0C4`0=4`0301<C00HC00<04a<00a<00`0C4`0H4`043A<C4<LC00<04`d0

L1<004`C00<@4a<031<200PC0`034`0301<C01TC00@=4a<@aQ<200034`dC06hC001;4`0341<C01dC

0P0K4`043A<C4<DC00D04a<C3@1^4`00BQ<00a0C4`0N4`0301<C01XC00@=4a<@aA<01@0C4a<=06hC

001:4`0341<C01hC00<04a<06a<010dC4a344`0301<C008C00<=4a<0Ja<004TC00<@4a<07a<00`0C

4`0K4`053A<C4a00`a<200<C00<=4a<0Ja<004PC00<@4a<081<201dC00D=4a<C40324`0301<C00<C

00<=4a<0JQ<004LC00<@4a<08A<00`0C4`0L4`033A<C008C00<@4a<0_a<00`0C4`044`033A<C06TC

00174`0341<C024C00<04a<07A<01@dC4a<@0;XC1@024`0301<C00DC00<=4a<0J1<004HC00<@4a<0

8Q<00`0C4`0M4`033A<C008C00<@4a<0^A<00`0C4`024`0301<C00DC00<=4a<0J1<004DC00<@4a<0

8a<201lC00<=4a<00Q<00a0C4`2h4`0301<C008C0P074`033A<C06LC00144`0341<C02@C00<04a<0

7Q<00`dC4`034`0341<C0;LC00<04a<00Q<00`0C4`074`033A<C06HC00144`0341<C02@C00<04a<0

7a<00`dC4`024`0341<C0;LC00<04a<00Q<00`0C4`084`033A<C06DC00134`0341<C02DC00<04a<0

81<00`dC4`024`0341<C0;DC0P044`0301<C00TC00<=4a<0I1<0048C00<@4a<09Q<00`0C4`0P4`03

3A<C00<C00<@4a<0^Q<200/C00<=4a<0Ha<0044C00<@4a<09a<2028C00<=4a<00a<00a0C4`2i4`03

01<C00/C00<=4a<0HQ<0040C00<@4a<0:1<00`0C4`0R4`033A<C00<C00<@4a<0^1<00`0C4`0<4`03

3A<C064C00104`0341<C028C0`034`0301<C028C00<=4a<011<00a0C4`2g4`0301<C00dC00<=4a<0

H1<003lC00<@4a<08a<00`0C4`034`0301<C02<C00<=4a<00a<00a0C4`2g4`803a<23F0C000n4`03

41<C02DC00<04a<00Q<202@C00<=4a<011<00a0C4`2f4`0301<C010C00<=4a<0GA<003dC00<@4a<0

9Q<00`0C4`024`0301<C02@C00<=4a<011<00a0C4`2e4`0301<C014C00<=4a<0G1<003dC00<@4a<0

9A<00`0C00034`0301<C02DC00<=4a<011<00a0C4`2d4`0301<C018C00<=4a<0Fa<003`C00<@4a<0

9a<00`0C4`024`0301<C02DC00<=4a<01A<00a0C4`2c4`0301<C01<C00<=4a<0FQ<003/C00<@4a<0

;A<202LC00<=4a<01A<00a0C4`2b4`805A<00`dC4`1I4`00>Q<00a0C4`0^4`0301<C02LC00<=4a<0

11<00a0C4`2b4`0301<C01DC00<=4a<0F1<003XC00<@4a<0;Q<00`0C4`0W4`033A<C00DC00<@4a<0

/A<00`0C4`0F4`033A<C05LC000i4`0341<C02lC00<04a<0:1<00`dC4`054`0341<C0;0C00<04a<0

5a<23ELC000h4`0341<C030C0P0Z4`033A<C00DC00<@4a<0[a<201XC00<=4a<0E1<003LC00<@4a<0

<A<00`0C4`0Y4`033A<C00DC00<@4a<0[a<00`0C4`0J4`8=E1<003LC00<@4a<0<A<00`0C4`0Z4`03

3A<C00DC00<@4a<0[Q<00`0C4`0L4`033A<C054C000f4`0341<C038C00<04a<0:a<00`dC4`054`03

41<C09`C1@024`0301<C008C00<04a<00Q<00`0C4`0M4`8=DA<003DC00<@4a<0<a<202dC00<=4a<0

1A<00a0C4`2M4`0301<C00HC00<04`000a<00`0C4`0O4`033A<C04hC000d4`0341<C03@C00<04a<0

;1<00`dC4`064`0341<C09`C00<04a<021<0100C4a<2024C0Pe>4`00<a<00a0C4`0e4`0301<C02dC

00<=4a<01Q<00a0C4`2K4`0301<C00HC0P044`0301<C028C00<=4a<0Ba<0038C00<@4a<0=Q<00`0C

4`0^4`033A<C00DC00<@4a<0Va<00`0C4`064`0301<C00<C00<04a<08a<23D/C000a4`0341<C03LC

0P0_4`033A<C00HC00<@4a<0VA<200PC0`034`0301<C02DC00<=4a<0B1<0030C00<@4a<0>1<00`0C

4`0_4`033A<C00HC00<@4a<0Z1<202LC0Pe84`00;a<00a0C4`0Y4`<00a<00`0C4`024`0301<C008C

00<04a<0;a<00`dC4`074`0341<C0:LC00<04a<0:1<00`dC4`154`00;Q<00a0C4`0Z4`0301<C00LC

00<04`000a<00`0C4`0`4`033A<C00LC00<@4a<0YQ<00`0C4`0Y4`8=AA<002dC00<@4a<0;1<00`0C

4`084`0401<C4`80<A<00`dC4`084`0341<C0:DC00<04a<0:a<00`dC4`124`00;1<00a0C4`0]4`03

01<C00HC0P044`0301<C034C00<=4a<021<00a0C4`2T4`0301<C02`C0Pe24`00:a<00a0C4`0]4`03

01<000LC00<04a<00a<00`0C4`0b4`033A<C00PC00<@4a<0Xa<202lC00<=4a<0?a<002XC00<@4a<0

;a<00`0C4`064`<00a<00`0C4`0b4`033A<C00TC00<@4a<0XQ<00`0C4`0_4`8=?a<002TC00<@4a<0

?a<203@C00<=4a<02A<00a0C4`2Q4`0301<C034C0Pdm4`00:1<00a0C4`104`0301<C03<C00<=4a<0

2Q<00a0C4`2P4`0301<C03<C0Pdk4`009a<00a0C4`114`0301<C03@C00<=4a<02Q<00a0C4`2O4`80

=Q<23CTC000V4`0341<C048C00<04a<0=A<00`dC4`0:4`0341<C09hC00<04a<0=a<23CLC000U4`03

41<C04<C0P0f4`033A<C00/C00<@4a<0WA<00`0C4`0i4`8==A<002@C00<@4a<0A1<00`0C4`0f4`03

3A<C00/C00<@4a<0W1<00`0C4`0k4`8=<a<002<C00<@4a<0AA<00`0C4`0g4`033A<C00/C00<@4a<0

Va<00`0C4`0m4`8=<A<002<C00<@4a<0AA<00`0C4`0g4`033A<C00`C00<@4a<0VQ<2040C00<=4a<0

;Q<0028C00<@4a<0AQ<203TC00<=4a<031<00a0C4`2I4`0301<C040C0Pd^4`008A<00a0C4`174`03

01<C03PC00<=4a<03A<00a0C4`2B4`<00a<00`0C4`124`8=;1<0020C00<@4a<0B1<00`0C4`0i4`03

3A<C00dC00<@4a<0TA<00`0C4`034`0301<C04@C0PdZ4`007a<00a0C4`194`0301<C03XC00<=4a<0

3A<00a0C4`2A4`0301<C008C0P174`8=:1<001hC00<@4a<0BQ<203/C00<=4a<03Q<00a0C4`2@4`03

01<C008C00<04a<0B1<23BHC000M4`0341<C04/C00<04a<0>a<00`dC4`0>4`0341<C08hC00<04`00

0a<00`0C4`1:4`8=91<001`C00<@4a<0C1<00`0C4`0k4`033A<C00lC00<@4a<0SQ<00`0C4`024`03

01<C04`C0`dQ4`006a<00a0C4`174`8011<00`0C4`0l4`033A<C00lC00<@4a<0TQ<00`0C4`1?4`<=

7Q<001XC00<@4a<0BQ<01@0C4a<003hC00<=4a<041<00a0C4`2A4`80Da<23A`C000I4`0341<C04XC

00<04a<00Q<203hC00<=4a<03a<00a0C4`2A4`0301<C05@C0PdJ4`00Ia<00`0C4`3W4`0301<C05HC

00<=4a<05a<006DC00<04`00jA<00`0C4`1`4`00IQ<00`0C4`3X4`80LA<002XC0`3o4bDC00<04a<0

L1<002XC00<04a<0oa<U4`0301<C070C000[4`0301<C00@C00<04a<0oa>@4`00:a<0100C4a<400<C

0`3o4h`C000Z4`0301<0008C0P000a<04`044`0301<C0?lCRQ<002/C00<04a<00a<00`0C00034`03

01<C0?lCRa<0034C00<04`0011<00`0C4`064`0301<C02LC0`0[4`0301<C0?lC:A<001/C0`000a<0

000200`C0`044`<021<00`0C4`0V4`0401<C00lC0`000a<00002008C00<04a<00Q<00`0C4`024`03

01<C00DC00@04a<C1@024`0301<C008C00@04a<C0P044`0301<C00@C0P354`0301<C03LC00<04a<0

1Q<001XC00@04a<091<00`0C4`0U4`0401<C00hC00@04a<01Q<00`0C00074`0301<000@C1@034`03

01<C00HC00<04`0011<01P0C4`0C00@C00<04a<0_A<00`0C4`044`0301<C01<C00<04a<08a<00`0C

4`054`006Q<01@0C4`0C00@000<C0000600]4`<03Q<01@0C4`0C00@000@C01<02A<00`0C4`044`03

01<C00<C00<04a<021<0100C4a<200@C00<04a<00Q<00`0C4`2[4`0401<C4`@00Q<200HC00<04a<0

0a<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`054`0401<C4`D00Q<00`0C4`024`0401<C4`80

11<00`0C4`044`8011<0100C4a<2004C000K4`<0Ca<00`0C4`0=4`<01Q<00`0C00074`801a<00`0C

4`034`0301<C00HC0P034`0301<0008C0P054`0301<C0:XC00<04`001a<00`0C4`044`D00a<01`0C

4a<04`001a<00`0C00044`D00a<00`0C4`064`0301<000@C00H04a<04`044`0301<C00@C00<04a<0

0Q<1004C000M4`0301<C04`C0P0A4`0301<C00@C00<04`001a<00`0C4`0<4`0301<C00HC00<04a<0

0Q<00`0C00024`0301<C00@C00<04`00ZQ<00`0C00024`@000<C01<01a<00`0C4`034`0701<C4`0C

00094`0301<C00@C00<04a<00a<00`0C4`084`0401<C4`8011<00`0C4`024`0301<C00@C00<04a<0

0a<1000071<2060C0P074`0301<C00HC0`0;4`8021<300<C0P024`<011<309<C0P000a<0000B4`03

01<000LC00<04a<01Q<00`0C4`034`0701<C4`0C00074`801a<00`0C4`034`0301<C00HC0P034`03

01<0008C0P054`0301<C00@C00<04a<00a<10000oa=A4`0301<001<C00<04`001a<00`0C000=4`06

01<C01<01a<00`0C4`0<4`0301<C00HC00<04a<00Q<00`0C00024`0301<C00@C00<04`000a<00`0C

4`034`400A<002HC0P064`80oa<R4`0301<C01<C00<04a<01Q<300hC00@04a<021<300/C0P084`<0

0a<2008C0`044`<00Q<00`0C4`034`800A<002PC00<04a<00Q<00`0C4`3o4b8C00<04a<0L1<002LC

00<04a<00a<00`0C4`064`0301<C0?lC61<00`0C001a4`00:1<00`0C4`024`0301<C008C0`0011<0

4a<30?lC51<200034`00070C000V4`0301<000@C00<04`000Q<2008C00<04a<00Q<00`0C4`3o4hLC

000W4`0301<C00<C0`044`0401<C008C00<04a<0oa>84`00=1<0100C4`034`0301<C0?lCQa<0038C

0`044`<0oa>94`00oa?54`00oa?54`00oa?54`00oa?54`00oa?54`00\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.55876, -1.75039, 0.0223901, 0.0223901}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -82 0 ]

[.5 .96488 82 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -143 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.59) show

217.250000 19.500000 moveto

(C) show

222.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.27538 0 m

.30316 .04416 L

.34309 .10765 L

.3815 .16873 L

.42237 .2337 L

.46172 .29627 L

.49955 .35643 L

.53984 .42049 L

.57861 .48213 L

.61984 .54768 L

.65954 .61082 L

.69774 .67154 L

.73838 .73617 L

.77751 .79839 L

.81909 .8645 L

.85916 .92821 L

s

.85916 .92821 m

.87436 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.389671 0.238095 [

[.02381 .37717 -6 -9 ]

[.02381 .37717 6 0 ]

[.2619 .37717 -6 -9 ]

[.2619 .37717 6 0 ]

[.7381 .37717 -3 -9 ]

[.7381 .37717 3 0 ]

[.97619 .37717 -3 -9 ]

[.97619 .37717 3 0 ]

[1.025 .38967 0 -8 ]

[1.025 .38967 9 8 ]

[.4875 .03253 -24 -4.5 ]

[.4875 .03253 0 4.5 ]

[.4875 .15158 -12 -4.5 ]

[.4875 .15158 0 4.5 ]

[.4875 .27062 -24 -4.5 ]

[.4875 .27062 0 4.5 ]

[.4875 .50872 -18 -4.5 ]

[.4875 .50872 0 4.5 ]

[.4875 .62777 -6 -4.5 ]

[.4875 .62777 0 4.5 ]

[.4875 .74681 -18 -4.5 ]

[.4875 .74681 0 4.5 ]

[.4875 .86586 -6 -4.5 ]

[.4875 .86586 0 4.5 ]

[.5 .94793 -4.5 0 ]

[.5 .94793 4.5 16 ]

[.5 .93543 -134.5 0 ]

[.5 .93543 134.5 16 ]

[ 0 0 0 0 ]

[ 1 .92293 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .38967 m

.02381 .39592 L

s

[(-2)] .02381 .37717 0 1 Mshowa

.2619 .38967 m

.2619 .39592 L

s

[(-1)] .2619 .37717 0 1 Mshowa

.7381 .38967 m

.7381 .39592 L

s

[(1)] .7381 .37717 0 1 Mshowa

.97619 .38967 m

.97619 .39592 L

s

[(2)] .97619 .37717 0 1 Mshowa

.125 Mabswid

.07143 .38967 m

.07143 .39342 L

s

.11905 .38967 m

.11905 .39342 L

s

.16667 .38967 m

.16667 .39342 L

s

.21429 .38967 m

.21429 .39342 L

s

.30952 .38967 m

.30952 .39342 L

s

.35714 .38967 m

.35714 .39342 L

s

.40476 .38967 m

.40476 .39342 L

s

.45238 .38967 m

.45238 .39342 L

s

.54762 .38967 m

.54762 .39342 L

s

.59524 .38967 m

.59524 .39342 L

s

.64286 .38967 m

.64286 .39342 L

s

.69048 .38967 m

.69048 .39342 L

s

.78571 .38967 m

.78571 .39342 L

s

.83333 .38967 m

.83333 .39342 L

s

.88095 .38967 m

.88095 .39342 L

s

.92857 .38967 m

.92857 .39342 L

s

.25 Mabswid

0 .38967 m

1 .38967 L

s

gsave

1.025 .38967 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .03253 m

.50625 .03253 L

s

[(-1.5)] .4875 .03253 1 0 Mshowa

.5 .15158 m

.50625 .15158 L

s

[(-1)] .4875 .15158 1 0 Mshowa

.5 .27062 m

.50625 .27062 L

s

[(-0.5)] .4875 .27062 1 0 Mshowa

.5 .50872 m

.50625 .50872 L

s

[(0.5)] .4875 .50872 1 0 Mshowa

.5 .62777 m

.50625 .62777 L

s

[(1)] .4875 .62777 1 0 Mshowa

.5 .74681 m

.50625 .74681 L

s

[(1.5)] .4875 .74681 1 0 Mshowa

.5 .86586 m

.50625 .86586 L

s

[(2)] .4875 .86586 1 0 Mshowa

.125 Mabswid

.5 .05634 m

.50375 .05634 L

s

.5 .08015 m

.50375 .08015 L

s

.5 .10396 m

.50375 .10396 L

s

.5 .12777 m

.50375 .12777 L

s

.5 .17538 m

.50375 .17538 L

s

.5 .19919 m

.50375 .19919 L

s

.5 .223 m

.50375 .223 L

s

.5 .24681 m

.50375 .24681 L

s

.5 .29443 m

.50375 .29443 L

s

.5 .31824 m

.50375 .31824 L

s

.5 .34205 m

.50375 .34205 L

s

.5 .36586 m

.50375 .36586 L

s

.5 .41348 m

.50375 .41348 L

s

.5 .43729 m

.50375 .43729 L

s

.5 .4611 m

.50375 .4611 L

s

.5 .48491 m

.50375 .48491 L

s

.5 .53253 m

.50375 .53253 L

s

.5 .55634 m

.50375 .55634 L

s

.5 .58015 m

.50375 .58015 L

s

.5 .60396 m

.50375 .60396 L

s

.5 .65158 m

.50375 .65158 L

s

.5 .67538 m

.50375 .67538 L

s

.5 .69919 m

.50375 .69919 L

s

.5 .723 m

.50375 .723 L

s

.5 .77062 m

.50375 .77062 L

s

.5 .79443 m

.50375 .79443 L

s

.5 .81824 m

.50375 .81824 L

s

.5 .84205 m

.50375 .84205 L

s

.5 .00872 m

.50375 .00872 L

s

.5 .88967 m

.50375 .88967 L

s

.5 .91348 m

.50375 .91348 L

s

.25 Mabswid

.5 0 m

.5 .92293 L

s

gsave

.5 .94793 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .93543 -195.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.59) show

293.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

298.000000 15.000000 moveto

(L) show

305.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

312.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

319.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

324.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

328.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .92293 L

0 .92293 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .23591 m

.02576 .2359 L

.03158 .23586 L

.04116 .23579 L

.05435 .23569 L

.07092 .23556 L

.09059 .2354 L

.11301 .2352 L

.1378 .23495 L

.16455 .23466 L

.19279 .23431 L

.22204 .23389 L

.2518 .2334 L

.28156 .23282 L

.31081 .23215 L

.33905 .23138 L

.36579 .2305 L

.39059 .22951 L

.41301 .22843 L

.43268 .2273 L

.44924 .22618 L

.46243 .22515 L

.47202 .22431 L

.47784 .22376 L

.47979 .22357 L

s

.47979 .22357 m

.48191 .22335 L

.48825 .22268 L

.49868 .22147 L

.51304 .21957 L

.53108 .21668 L

.55249 .21238 L

.57689 .20606 L

.60389 .19707 L

.63301 .18514 L

.66375 .17072 L

.69559 .15474 L

.72799 .13813 L

.76039 .12162 L

.79223 .10571 L

.82297 .09073 L

.85209 .07691 L

.87908 .06443 L

.90349 .05341 L

.9249 .04394 L

.94294 .0361 L

.9573 .02995 L

.96773 .02553 L

.97407 .02286 L

.97619 .02197 L

s

.47979 .47267 m

.48191 .44544 L

.48825 .41857 L

.49868 .39235 L

.51304 .36711 L

.53108 .34325 L

.55249 .32134 L

.57689 .30212 L

.60389 .28634 L

.63301 .27439 L

.66375 .26594 L

.69559 .26017 L

.72799 .25621 L

.76039 .25345 L

.79223 .25148 L

.82297 .25003 L

.85209 .24894 L

.87908 .24812 L

.90349 .24749 L

.9249 .24701 L

.94294 .24666 L

.9573 .24639 L

.96773 .24622 L

.97407 .24611 L

.97619 .24608 L

s

.47979 .47278 m

.48191 .50022 L

.48825 .52776 L

.49868 .55518 L

.51304 .58233 L

.53108 .60908 L

.55249 .63529 L

.57689 .66084 L

.60389 .6856 L

.63301 .70947 L

.66375 .73234 L

.69559 .75411 L

.72799 .77467 L

.76039 .79394 L

.79223 .81183 L

.82297 .82826 L

.85209 .84316 L

.87908 .85646 L

.90349 .86811 L

.9249 .87806 L

.94294 .88625 L

.9573 .89267 L

.96773 .89727 L

.97407 .90003 L

.97619 .90096 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<00`0C4`1`4`00oa=B4`80LA<006@C1@3X4`0301<C070C001V4`0301<C0>PC00<04a<0

L1<004DC00<=4a<061<300<C00<04a<00Q<20=<C1@024`0301<C008C00<04a<00Q<00`0C4`1E4`<=

61<004DC00<=4a<07Q<00`0C4`024`0301<C0=@C00<04a<01Q<00`0C00034`0301<C058C0`dK4`00

AQ<00`dC4`0M4`0301<C008C00<04a<0cQ<300<C00<04a<021<0100C4a<2054C0PdN4`00AQ<00`dC

4`0L4`8011<00`0C4`3D4`0301<C00HC0P044`0301<C04hC0PdP4`00Aa<00`dC4`0Q4`80eA<00`0C

4`064`0301<C00<C00<04a<0CA<00`dC4`0P4`00Aa<00`dC4`0Q4`0301<C0=<C0P084`<00a<00`0C

4`1;4`8=8a<004PC00<=4a<081<00`0C4`3S4`80BA<33BDC00184`033A<C020C00<04a<0ha<00`0C

4`164`8=:1<004TC00<=4a<07a<20>@C00<04a<0@a<33BXC001:4`033A<C01hC00<04a<0ha<00`0C

4`114`8=;A<004XC00<=4a<07Q<00`0C4`3S4`0301<C03lC0Pd_4`00Ba<00`dC4`0M4`0301<C0><C

0P0n4`8=<A<004`C00<=4a<071<20>@C00<04a<0>a<23C<C001<4`033A<C01`C00<04a<0ha<00`0C

4`0i4`8==A<004dC00<=4a<06a<00`0C4`3S4`0301<C03HC0`dg4`00CA<00`dC4`0K4`0301<C0><C

0P0e4`8=>Q<004hC00<=4a<06Q<20>@C00<04a<0<Q<23C`C001?4`033A<C01TC00<04a<0ha<00`0C

4`0`4`8=?Q<004lC00<=4a<02Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`3S4`0301<C02hC

0Pe04`00D1<00`dC4`084`0301<000LC00<04`000a<00`0C4`3S4`0301<C02`C0Pe24`00DA<00`dC

4`024`<00Q<00`0C00094`0401<C4`80i1<202`C00<=4a<0@Q<0054C00<=4a<01a<00`0C00074`80

11<00`0C4`3S4`0301<C02TC0Pe54`00DQ<00`dC4`064`0301<000LC00<04a<00a<00`0C4`3L4`D0

0Q<00`0C4`0X4`033A<C04DC001C4`033A<C00HC00<04a<01Q<300<C00<04a<0gQ<00`0C4`024`03

01<C02HC0Pe84`00Da<00`dC4`0E4`0301<C0=PC0`034`0301<C008C0P0U4`8=BQ<005@C00<=4a<0

51<20=lC00<04a<00Q<00`0C4`0R4`8=C1<005DC00<=4a<04a<00`0C4`3N4`0301<C008C00<04a<0

81<23DhC001F4`033A<C018C00<04a<0gA<200@C00<04a<07Q<23E0C001F4`033A<C018C00<04a<0

ha<00`0C4`0K4`<=DQ<005LC00<=4a<04A<20>@C0P0I4`<=EA<005PC00<=4a<041<00`0C4`3S4`03

01<C01HC0PeH4`006Q<302DC1@0A4`033A<C010C00<04a<091<502@C0`2C4`0301<C01@C0PeJ4`00

6Q<00`0C4`0W4`0301<C018C00<=4a<03a<00`0C4`0V4`0301<C02@C00<04a<0Ta<00`0C4`0B4`8=

G1<001DC0`034`0301<C020C0`034`0301<C01<C00<=4a<03Q<202LC00<04a<09A<00`0C4`2B4`80

41<33EhC000K4`0301<C02HC00<04a<04a<00`dC4`0>4`0301<C02HC00<04a<09A<00`0C4`2B4`03

01<C00XC1@eQ4`006Q<00`0C000W4`0301<C01@C00<=4a<03A<00`0C4`0V4`0301<C02@C00<04`00

Ta<00`0C4`064`@=IQ<001/C00<04a<09A<201HC00<=4a<03A<00`0C4`0U4`809a<00`0C4`2B4`03

01<C008C10eZ4`00G1<00`dC4`0<4`80hQ<73FhC001M4`033A<C00/C00<04a<0dQ<?3@8C00<04a<0

L1<005dC00<=4a<02a<00`0C4`1K4`80EA<P3A4C00<04a<0L1<005hC00<=4a<02Q<00`0C4`1J4`03

01<C02dC:0da4`0301<C070C000E4dX000<=0000H0064`0301<C08HC00<04a<0L1<001TC00<04a<0

1Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`05

01<C4`d00a<00`0C4`054`0341<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C

4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<021<00`0C4`264`80?Q<K3APC

001P4`033A<C00PC00<@4a<0FQ<00`0C00264`0301<C02`C4@dc4`00HA<00`dC4`074`8@Fa<307LC

00<04a<00Q<00`0C4`024`0301<C008C00<04a<08A<;3D@C001Q4`033A<C00LC0Q3D4`0301<000LC

00<04`000a<00`0C4`0N4`<=Ca<0068C00<=4a<01A<00a00403?4`<00Q<00`0C00094`0401<C4`80

6a<43E8C001R4`033A<C00DC00<@0100e1<00`0C00074`8011<00`0C4`0E4`D=EQ<006<C00<=4a<0

11<00a00403D4`0301<000LC00<04a<00a<00`0C4`0C4`8=Fa<006@C00<=4a<00Q<01A0C000@0=@C

00<04a<01Q<300<C00<04a<04A<23EdC001T4`033A<C008C00D@4`0C403S4`0301<C00lC0PeO4`00

IA<02@dC4a<@4`0C403S4`803Q<23F4C001V4`063A<C41<00Q<00a0C4`3P4`0301<C00`C00<=4a<0

HA<006HC00D=4a<@4`0200034a0C0>4C00<04a<02a<00`dC4`1R4`00Ia<01@dC41<0008C00<@4a<0

h1<00`0C4`094`8=IA<006LC00D=41<C00034`0341<C0=lC0P094`033A<C06DC001X4`043A<C00<C

00<@4a<0ga<00`0C4`074`033A<C06HC001X4`0340dC00800Q<00a0C4`3O4`0301<C00HC00<=4a<0

Ia<006LC00D@4`dC00044`0341<C08HC0`0X4`D0:1<00`0C4`054`033A<C01lC1@0Y4`<061<005`C

00<04a<00Q<00`0C4`024`06010C4`d011<00a0C4`264`0301<C02XC00<04a<0:1<00`0C4`044`03

3A<C028C00<04a<0:A<00`0C4`0H4`00Fa<00`0C00074`030100008C00<=01<00a<00a0C4`214`<0

0a<00`0C4`0S4`<00a<00`0C4`0X4`8011<00`dC4`0S4`0301<C02XC00<04a<05a<005/C00<04`00

21<00a004`024`033@0C00<C00<@4a<0QQ<00`0C4`0Y4`0301<C02PC00<04a<00Q<00`dC4`0T4`03

01<C02XC00<04a<05a<005/C00<04`001a<00`0@4`034`0300dC00<C00<@4a<0QA<00`0C000Z4`03

01<C02PC00<04a<00Q<00`dC4`0T4`0301<C02TC00<04`0061<005/C00<04`001a<00a0C4`034`03

00dC00@C00<@4a<0QA<00`0C4`0X4`80:Q<01@0C4a<=02HC0P0/4`0301<C01LC001L4`0301<C00HC

00<@00000a<00`0C3@044`0341<C0=`C0P024`033A<C06`C001T4`0341<C00@C0P000a<=4`024`03

41<C0=`C00@04a<=Ka<006@C00<@4a<011<0100C4`d44`0341<C0=/C00<04`d0L1<006<C00<@4a<0

1A<01@0C4a<=00<C00<@4a<0fa<00`0=4`1T4`802Q<006<C00<@4a<01A<01@0C4a<=00@C00<@4a<0

fQ<00`0=4`1S4`0301<C00XC001R4`0341<C00HC00<04a<00Q<01@dC4a<@07hCGP000`d0001L00LC

00<04a<02Q<0068C00<@4a<01Q<200@C00D=4a<C40224`0301<C02TC00<04a<0:Q<00`dC4`0Z4`03

01<C02XC00<04a<02A<00`0C4`0:4`00HA<00a0C4`074`0301<C00<C00D=4a<C403J4`033@0C06@C

00<04`002Q<0064C00<@4a<01a<00`0C4`044`043A<C4=XC00<=01<0I1<300XC001P4`0341<C00PC

00<04a<01A<010dC4a3H4`043A<0074C001P4`0341<C00PC0P064`043A<C4=PC00<=4`00LQ<005lC

00<@4a<02A<00`0C4`064`043A<C4=LC00<=4`00LQ<005lC00<@4a<02A<00`0C4`074`033A<@0=LC

00<=4`00LQ<005hC00<@4a<02Q<00`0C4`074`043A<C4=DC00@=4a<0LQ<005hC00<@4a<02Q<200TC

00<=4a00eA<00`dC4`02074C001M4`0341<C00/C00<04a<021<010dC4a3D4`043A<C078C001M4`03

41<C00@C1@024`0301<C00TC00<=4a00e1<010dC4`1b4`00G1<00a0C4`074`0301<C008C00<04a<0

2Q<00`dC403C4`043A<C078C001K4`0341<C00PC00<04a<00Q<200/C00@=4a<@dA<010dC4a<2074C

001K4`0341<C00PC00<04a<00Q<00`0C4`0;4`033A<@0=4C00D=4a<C001b4`00FQ<00a0C4`094`03

01<C008C00<04a<031<00`dC403@4`053A<C4`00LQ<005XC00<@4a<021<200@C00<04a<031<010dC

4a3?4`053A<C4`00LQ<005TC00<@4a<03a<200hC00<=4a00ca<01@dC4a<0078C001H4`0341<C010C

00<04a<03Q<00`dC403>4`043A<C4`80LA<005PC00<@4a<041<00`0C4`0>4`043A<C4<hC00@=4a<0

LQ<005LC00<@4a<04A<00`0C4`0?4`033A<@0<8C00<04a<00Q<00`0C4`024`0301<=008C00<04a<0

L1<005HC00<@4a<04Q<2010C00@=4a<@`1<00`0C00074`0401<03@8C00<04a<0L1<005HC00<@4a<0

4Q<00`0C4`0@4`043A<C4;lC00<04`002A<0100=4a<2074C001E4`0341<C01<C00<04a<04A<00`dC

402o4`0301<000LC0P001A<=4a<0078C001D4`0341<C01@C00<04a<04A<010dC4a2n4`0301<000LC

00L04a<C3A<0078C001C4`0341<C01DC0P0C4`033A<@0;lC00<04a<01Q<300044`dC078C001C4`03

41<C01DC00<04a<04a<00`dC403;4`033A<0078C001B4`0341<C01HC00<04a<04a<010dC4a3:4`04

3A<0074C001A4`0341<C01LC00<04a<051<00`dC403;4`033@0C074C001A4`0341<C01LC0P0F4`03

3A<@0<XC00<=01<0LA<0050C00<@4a<061<00`0C4`0E4`033A<@0</C00<=4a<0L1<004lC00<@4a<0

21<5008C00<04a<00Q<00`0C4`024`0301<C01HC00<=4a00bQ<00`d04`1`4`00Ca<00a0C4`0:4`03

01<C00HC00<04`000a<00`0C4`0F4`043A<C4<TC00<03A<0L1<004hC00<@4a<02a<00`0C4`084`04

01<C4`8061<010dC4a384`0300dC070C001=4`0341<C00`C00<04a<01Q<200@C00<04a<061<00`dC

40384`0301<=070C001<4`0341<C00dC00<04a<01Q<00`0C4`034`0301<C01PC00@=4a<@aa<00`0C

3@1`4`00C1<00a0C4`0<4`8021<300<C00<04a<06A<010dC4a364`8000<C3A<0KQ<004/C00<@4a<0

7A<201/C00@=4a<@aA<01@0C4a<=06hC001:4`0341<C01hC00<04a<06Q<010dC4a354`0501<C4`d0

KQ<004XC00<@4a<07Q<00`0C4`0K4`043A<C4<@C00<04a<00Q<00`dC4`1[4`00BA<00a0C4`0O4`03

01<C01/C00D=4a<C40334`800a<00`dC4`1[4`00B1<00a0C4`0P4`807A<01@dC4a<@0<8C00<04a<0

0a<00`dC4`1Z4`00Aa<00a0C4`0Q4`0301<C01dC00D=4a<C40314`0301<C00@C00<=4a<0JA<004LC

00<@4a<08A<00`0C4`0M4`053A<C4a00^Q<5008C00<04a<01A<00`dC4`1X4`00AQ<00a0C4`0R4`03

01<C01hC00D=4a<C402k4`0301<C008C00<04a<01A<00`dC4`1X4`00AA<00a0C4`0S4`807a<00`dC

4`024`0341<C0;PC00<04a<00Q<200LC00<=4a<0Ia<004@C00<@4a<091<00`0C4`0O4`033A<C008C

00<@4a<0]a<00`0C4`024`0301<C00LC00<=4a<0IQ<004@C00<@4a<091<00`0C4`0P4`053A<C4a00

^A<00`0C4`024`0301<C00PC00<=4a<0IA<004<C00<@4a<09A<00`0C4`0P4`033A<C008C00<@4a<0

]A<200@C00<04a<02A<00`dC4`1T4`00@Q<00a0C4`0V4`0301<C024C00<=4a<00Q<00a0C4`2j4`80

2a<00`dC4`1S4`00@A<00a0C4`0W4`808a<00`dC4`024`0341<C0;TC00<04a<02a<00`dC4`1R4`00

@1<00a0C4`0X4`0301<C028C00<=4a<00a<00a0C4`2h4`0301<C00`C00<=4a<0HA<0040C00<@4a<0

8Q<300<C00<04a<08a<00`dC4`034`0341<C0;LC00<04a<03A<00`dC4`1P4`00?a<00a0C4`0S4`03

01<C00<C00<04a<08a<00`dC4`034`0341<C0;LC0P0?4`8=H1<003hC00<@4a<09A<00`0C4`024`80

9A<00`dC4`034`0341<C0;HC00<04a<041<00`dC4`1M4`00?A<00a0C4`0V4`0301<C008C00<04a<0

9A<00`dC4`034`0341<C0;DC00<04a<04A<00`dC4`1L4`00?A<00a0C4`0U4`0301<000<C00<04a<0

9A<00`dC4`044`0341<C0;@C00<04a<04Q<00`dC4`1K4`00?1<00a0C4`0W4`0301<C008C00<04a<0

9Q<00`dC4`044`0341<C0;<C00<04a<04a<00`dC4`1J4`00>a<00a0C4`0]4`80:1<00`dC4`044`03

41<C0;8C0P0E4`033A<C05TC000j4`0341<C02hC00<04a<09a<00`dC4`044`0341<C0;8C00<04a<0

5A<00`dC4`1H4`00>Q<00a0C4`0^4`0301<C02PC00<=4a<011<00a0C4`2a4`0301<C01HC00<=4a<0

Ea<003TC00<@4a<0;a<00`0C4`0Y4`033A<C00@C00<@4a<0/1<00`0C4`0G4`8=Ea<003PC00<@4a<0

<1<202XC00<=4a<01A<00a0C4`2_4`806Q<00`dC4`1D4`00=a<00a0C4`0a4`0301<C02XC00<=4a<0

11<00a0C4`2_4`0301<C01XC0PeD4`00=a<00a0C4`0a4`0301<C02XC00<=4a<01A<00a0C4`2^4`03

01<C01`C00<=4a<0DA<003HC00<@4a<0<Q<00`0C4`0[4`033A<C00DC00<@4a<0W1<5008C00<04a<0

0Q<00`0C4`024`0301<C01dC0PeA4`00=A<00a0C4`0c4`80;A<00`dC4`054`0341<C09dC00<04a<0

1Q<00`0C00034`0301<C01lC00<=4a<0CQ<003@C00<@4a<0=1<00`0C4`0/4`033A<C00HC00<@4a<0

W1<00`0C4`084`0401<C4`808A<23DhC000c4`0341<C03DC00<04a<0;A<00`dC4`064`0341<C09/C

00<04a<01Q<200@C00<04a<08Q<00`dC4`1;4`00<Q<00a0C4`0f4`0301<C02hC00<=4a<01A<00a0C

4`2K4`0301<C00HC00<04a<00a<00`0C4`0S4`8=Ba<0034C00<@4a<0=a<202lC00<=4a<01Q<00a0C

4`2I4`8021<300<C00<04a<09A<00`dC4`184`00<1<00a0C4`0h4`0301<C02lC00<=4a<01Q<00a0C

4`2X4`809a<23DPC000_4`0341<C02TC0`034`0301<C008C00<04a<00Q<00`0C4`0`4`033A<C00HC

00<@4a<0Ya<00`0C4`0X4`033A<C04DC000^4`0341<C02XC00<04a<01a<00`0C00034`0301<C030C

00<=4a<01a<00a0C4`2V4`0301<C02TC0Pe54`00;A<00a0C4`0/4`0301<C00PC00@04a<C0P0b4`03

3A<C00LC00<@4a<0YA<00`0C4`0[4`033A<C048C000/4`0341<C02dC00<04a<01Q<200@C00<04a<0

<A<00`dC4`084`0341<C0:@C00<04a<0;1<23D8C000[4`0341<C02dC00<04`001a<00`0C4`034`03

01<C038C00<=4a<021<00a0C4`2S4`80;a<00`dC4`0o4`00:Q<00a0C4`0_4`0301<C00HC0`034`03

01<C03<C00<=4a<021<00a0C4`2R4`0301<C02lC0Pdo4`00:A<00a0C4`0o4`80=1<00`dC4`094`03

41<C0:4C00<04a<0<A<23CdC000X4`0341<C040C00<04a<0=1<00`dC4`094`0341<C0:0C00<04a<0

<a<23C/C000W4`0341<C044C00<04a<0=A<00`dC4`094`0341<C09lC0P0f4`8=>A<002HC00<@4a<0

@Q<00`0C4`0e4`033A<C00XC00<@4a<0WQ<00`0C4`0g4`8==a<002DC00<@4a<0@a<203LC00<=4a<0

2Q<00a0C4`2M4`0301<C03TC0Pde4`0091<00a0C4`144`0301<C03LC00<=4a<02Q<00a0C4`2L4`03

01<C03/C0Pdc4`008a<00a0C4`154`0301<C03LC00<=4a<02a<00a0C4`2K4`0301<C03dC0Pda4`00

8a<00a0C4`154`0301<C03PC00<=4a<02a<00a0C4`2J4`80@1<23BlC000R4`0341<C04HC0P0i4`03

3A<C00`C00<@4a<0VA<00`0C4`114`8=;A<0024C00<@4a<0Aa<00`0C4`0i4`033A<C00`C00<@4a<0

TQ<300<C00<04a<0@a<23B/C000P4`0341<C04PC00<04a<0>Q<00`dC4`0<4`0341<C094C00<04a<0

0a<00`0C4`154`8=:A<001lC00<@4a<0BA<00`0C4`0j4`033A<C00dC00<@4a<0TA<00`0C4`024`80

B1<23BLC000N4`0341<C04XC0P0l4`033A<C00dC00<@4a<0T1<00`0C4`024`0301<C04TC00<=4a<0

91<001dC00<@4a<0Ba<00`0C4`0k4`033A<C00hC00<@4a<0SQ<00`0C00034`0301<C04XC0PdT4`00

71<00a0C4`1<4`0301<C03`C00<=4a<03Q<00a0C4`2>4`0301<C008C00<04a<0C1<33B4C000K4`03

41<C04LC0P044`0301<C03`C00<=4a<03a<00a0C4`2B4`0301<C04lC0`dN4`006Q<00a0C4`1:4`05

01<C4`00?a<00`dC4`0?4`0341<C094C0P1C4`8=71<001TC00<@4a<0BQ<00`0C4`024`80?Q<00`dC

4`0?4`0341<C094C00<04a<0E1<23AXC001W4`0301<C0>LC00<04a<0EQ<23APC001U4`0301<00>TC

00<04a<0L1<006HC00<04a<0j1<2074C000/4`<0oa<S4`0301<C070C000/4`0301<C0?lC8a<00`0C

4`1`4`00;A<00`0C4`054`0301<C0?lCSA<002dC00@04a<C0`0011<04a<30?lCRQ<002`C00<04`00

0Q<2008C00<04a<00Q<00`0C4`3o4hPC000]4`0301<C00<C00@04a<00Q<00`0C4`3o4hTC000c4`04

01<C00<C00<04a<01Q<00`0C4`0U4`<0;A<00`0C4`3o4bLC000M4`<000<C00000P0<4`<011<300PC

00<04a<091<0100C4`0A4`<000<C00000P024`0301<C008C00<04a<00Q<00`0C4`054`0401<C4`D0

0Q<00`0C4`024`0401<C4`801Q<20</C00<04a<0<Q<00`0C4`084`0071<0100C4`0T4`0301<C02<C

00@04a<041<0100C4`064`0301<000LC00<04`0011<500<C00<04a<01Q<00`0C00044`0301<C008C

00<04a<0`a<00`0C4`044`0301<C01<C00<04a<07Q<00`0C4`074`0071<01@0C4`0C00@000<C0000

600[4`<041<01@0C4`0C00@000@C01<02A<00`0C4`044`0301<C00<C00<04a<021<0100C4a<200@C

00<04a<0/A<0100C4a<4008C0P064`0301<C00<C00<04a<00Q<00`0C4`024`0301<C008C00<04a<0

1A<0100C4a<5008C00<04a<00Q<0100C4a<200HC0P044`0401<C4`800A<10040000M4`<0CA<00`0C

4`0?4`<01Q<00`0C00074`801a<00`0C4`034`0301<C00HC0P034`0301<000@C00<04a<0/1<00`0C

00074`0301<C00@C1@034`0701<C4`0C00074`0301<000@C1@034`0301<C00HC00<04`0011<00`0C

4`024`0301<C00@C00<04a<00Q<00`0C00014`007a<00`0C4`1:4`804a<00`0C4`044`0301<000LC

00<04a<031<00`0C4`064`0301<C008C00<04`0011<00`0C002`4`0301<0008C10000a<04`074`03

01<C00<C00L04a<C01<000TC00<04a<011<00`0C4`034`0301<C00PC00@04a<C0P044`0301<C00@C

00<04a<00a<1004C0A<001hC0P1P4`801a<00`0C4`064`<02a<200PC0`034`8011<309HC0P000a<0

000E4`0301<000LC00<04a<01Q<00`0C4`034`0701<C4`0C00074`801a<00`0C4`034`0301<C00HC

0P034`0301<000@C00<04a<011<00`0C4`034`400A<14`00oa=A4`0301<001HC00<04`001a<00`0C

000=4`0601<C01<01a<00`0C4`0<4`0301<C00HC00<04a<00Q<00`0C00044`0301<000<C00<04a<0

0a<00`0C00014`00:A<200HC0P3o4alC00<04a<05Q<00`0C4`064`<03Q<0100C4`084`<02a<200PC

0`034`8011<3008C00<04a<00a<2004C0@010000:a<00`0C4`024`0301<C0?lC7a<00`0C4`1`4`00

:Q<00`0C4`034`0301<C00DC00<04a<0oa<F4`0301<0074C000[4`0301<C008C00<04a<00Q<400<C

0`3o4a4C0P000a<0001`4`00:A<00`0C00044`0301<0008C0P000a<04`044`0301<C0?lCQ1<002XC

00<04a<00a<300@C00<04`000a<00`0C4`3o4hDC000g4`0301<000@C00<04a<0oa>44`00=A<300@C

0`3o4hHC003o4lDC003o4lDC003o4lDC003o4lDC003o4lDC0000\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.54571, -1.7456, 0.0223514, 0.0223514}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -84.5 0 ]

[.5 .96488 84.5 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -145.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.585) show

222.250000 19.500000 moveto

(C) show

227.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.27467 0 m

.30316 .04514 L

.34309 .10843 L

.3815 .16932 L

.42237 .23409 L

.46172 .29646 L

.49955 .35643 L

.53984 .42029 L

.57861 .48174 L

.61984 .54708 L

.65954 .61002 L

.69774 .67056 L

.73838 .73498 L

.77751 .797 L

.81909 .86291 L

.85916 .92641 L

s

.85916 .92641 m

.87554 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.38857 0.238095 [

[.02381 .37607 -6 -9 ]

[.02381 .37607 6 0 ]

[.2619 .37607 -6 -9 ]

[.2619 .37607 6 0 ]

[.7381 .37607 -3 -9 ]

[.7381 .37607 3 0 ]

[.97619 .37607 -3 -9 ]

[.97619 .37607 3 0 ]

[1.025 .38857 0 -8 ]

[1.025 .38857 9 8 ]

[.4875 .03143 -24 -4.5 ]

[.4875 .03143 0 4.5 ]

[.4875 .15047 -12 -4.5 ]

[.4875 .15047 0 4.5 ]

[.4875 .26952 -24 -4.5 ]

[.4875 .26952 0 4.5 ]

[.4875 .50762 -18 -4.5 ]

[.4875 .50762 0 4.5 ]

[.4875 .62667 -6 -4.5 ]

[.4875 .62667 0 4.5 ]

[.4875 .74571 -18 -4.5 ]

[.4875 .74571 0 4.5 ]

[.4875 .86476 -6 -4.5 ]

[.4875 .86476 0 4.5 ]

[.5 .94629 -4.5 0 ]

[.5 .94629 4.5 16 ]

[.5 .93379 -137 0 ]

[.5 .93379 137 16 ]

[ 0 0 0 0 ]

[ 1 .92129 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .38857 m

.02381 .39482 L

s

[(-2)] .02381 .37607 0 1 Mshowa

.2619 .38857 m

.2619 .39482 L

s

[(-1)] .2619 .37607 0 1 Mshowa

.7381 .38857 m

.7381 .39482 L

s

[(1)] .7381 .37607 0 1 Mshowa

.97619 .38857 m

.97619 .39482 L

s

[(2)] .97619 .37607 0 1 Mshowa

.125 Mabswid

.07143 .38857 m

.07143 .39232 L

s

.11905 .38857 m

.11905 .39232 L

s

.16667 .38857 m

.16667 .39232 L

s

.21429 .38857 m

.21429 .39232 L

s

.30952 .38857 m

.30952 .39232 L

s

.35714 .38857 m

.35714 .39232 L

s

.40476 .38857 m

.40476 .39232 L

s

.45238 .38857 m

.45238 .39232 L

s

.54762 .38857 m

.54762 .39232 L

s

.59524 .38857 m

.59524 .39232 L

s

.64286 .38857 m

.64286 .39232 L

s

.69048 .38857 m

.69048 .39232 L

s

.78571 .38857 m

.78571 .39232 L

s

.83333 .38857 m

.83333 .39232 L

s

.88095 .38857 m

.88095 .39232 L

s

.92857 .38857 m

.92857 .39232 L

s

.25 Mabswid

0 .38857 m

1 .38857 L

s

gsave

1.025 .38857 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .03143 m

.50625 .03143 L

s

[(-1.5)] .4875 .03143 1 0 Mshowa

.5 .15047 m

.50625 .15047 L

s

[(-1)] .4875 .15047 1 0 Mshowa

.5 .26952 m

.50625 .26952 L

s

[(-0.5)] .4875 .26952 1 0 Mshowa

.5 .50762 m

.50625 .50762 L

s

[(0.5)] .4875 .50762 1 0 Mshowa

.5 .62667 m

.50625 .62667 L

s

[(1)] .4875 .62667 1 0 Mshowa

.5 .74571 m

.50625 .74571 L

s

[(1.5)] .4875 .74571 1 0 Mshowa

.5 .86476 m

.50625 .86476 L

s

[(2)] .4875 .86476 1 0 Mshowa

.125 Mabswid

.5 .05524 m

.50375 .05524 L

s

.5 .07905 m

.50375 .07905 L

s

.5 .10286 m

.50375 .10286 L

s

.5 .12667 m

.50375 .12667 L

s

.5 .17428 m

.50375 .17428 L

s

.5 .19809 m

.50375 .19809 L

s

.5 .2219 m

.50375 .2219 L

s

.5 .24571 m

.50375 .24571 L

s

.5 .29333 m

.50375 .29333 L

s

.5 .31714 m

.50375 .31714 L

s

.5 .34095 m

.50375 .34095 L

s

.5 .36476 m

.50375 .36476 L

s

.5 .41238 m

.50375 .41238 L

s

.5 .43619 m

.50375 .43619 L

s

.5 .46 m

.50375 .46 L

s

.5 .48381 m

.50375 .48381 L

s

.5 .53143 m

.50375 .53143 L

s

.5 .55524 m

.50375 .55524 L

s

.5 .57905 m

.50375 .57905 L

s

.5 .60286 m

.50375 .60286 L

s

.5 .65047 m

.50375 .65047 L

s

.5 .67428 m

.50375 .67428 L

s

.5 .69809 m

.50375 .69809 L

s

.5 .7219 m

.50375 .7219 L

s

.5 .76952 m

.50375 .76952 L

s

.5 .79333 m

.50375 .79333 L

s

.5 .81714 m

.50375 .81714 L

s

.5 .84095 m

.50375 .84095 L

s

.5 .00762 m

.50375 .00762 L

s

.5 .88857 m

.50375 .88857 L

s

.5 .91238 m

.50375 .91238 L

s

.25 Mabswid

.5 0 m

.5 .92129 L

s

gsave

.5 .94629 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .93379 -198 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.585) show

298.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

303.000000 15.000000 moveto

(L) show

310.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

317.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

324.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

329.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

333.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .92129 L

0 .92129 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .23442 m

.02576 .23441 L

.03158 .23437 L

.04116 .2343 L

.05435 .23421 L

.07092 .23408 L

.09058 .23392 L

.113 .23372 L

.1378 .23348 L

.16454 .23319 L

.19278 .23285 L

.22203 .23244 L

.25179 .23197 L

.28154 .23141 L

.31079 .23075 L

.33903 .23 L

.36578 .22914 L

.39057 .22818 L

.41299 .22713 L

.43266 .22603 L

.44922 .22494 L

.46241 .22394 L

.472 .22312 L

.47782 .22259 L

.47977 .2224 L

s

.47977 .2224 m

.48189 .22219 L

.48822 .22154 L

.49866 .22037 L

.51302 .21852 L

.53106 .21571 L

.55247 .21153 L

.57688 .20535 L

.60387 .19652 L

.63299 .18475 L

.66374 .17043 L

.69558 .15451 L

.72798 .13795 L

.76038 .12147 L

.79222 .10558 L

.82296 .09061 L

.85208 .07681 L

.87908 .06435 L

.90349 .05333 L

.9249 .04388 L

.94294 .03605 L

.9573 .0299 L

.96773 .02549 L

.97407 .02282 L

.97619 .02194 L

s

.47977 .4716 m

.48189 .44438 L

.48822 .41752 L

.49866 .3913 L

.51302 .36603 L

.53106 .34212 L

.55247 .32013 L

.57688 .3008 L

.60387 .28489 L

.63299 .27282 L

.66374 .2643 L

.69558 .25848 L

.72798 .25452 L

.76038 .25176 L

.79222 .24978 L

.82296 .24834 L

.85208 .24726 L

.87908 .24644 L

.90349 .24582 L

.9249 .24535 L

.94294 .24499 L

.9573 .24473 L

.96773 .24456 L

.97407 .24445 L

.97619 .24442 L

s

.47977 .47171 m

.48189 .49913 L

.48822 .52665 L

.49866 .55404 L

.51302 .58116 L

.53106 .60787 L

.55247 .63405 L

.57688 .65956 L

.60387 .6843 L

.63299 .70814 L

.66374 .73098 L

.69558 .75271 L

.72798 .77325 L

.76038 .79249 L

.79222 .81035 L

.82296 .82676 L

.85208 .84164 L

.87908 .85492 L

.90349 .86655 L

.9249 .87648 L

.94294 .88467 L

.9573 .89107 L

.96773 .89567 L

.97407 .89843 L

.97619 .89935 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<00`0C4`1`4`00oa=B4`80LA<006@C1@3X4`0301<C070C001V4`0301<C0=LC1@024`03

01<C008C00<04a<00Q<00`0C4`1`4`00A1<00`dC4`0I4`<00a<00`0C4`024`80eA<00`0C4`064`03

01<000<C00<04a<0EA<33APC00154`033A<C01hC00<04a<00Q<00`0C4`3>4`<00a<00`0C4`084`04

01<C4`80Da<33A/C00154`033A<C01hC00<04a<00Q<00`0C4`3D4`0301<C00HC0P044`0301<C050C

0PdN4`00AQ<00`dC4`0L4`8011<00`0C4`3D4`0301<C00HC00<04a<00a<00`0C4`1>4`8=81<004HC

00<=4a<08Q<20=@C0P084`<00a<00`0C4`1=4`033A<C020C00174`033A<C024C00<04a<0ha<00`0C

4`1;4`8=8a<004PC00<=4a<081<00`0C4`3S4`80BA<33BDC00184`033A<C020C00<04a<0ha<00`0C

4`164`8=:1<004TC00<=4a<07a<20>@C00<04a<0@a<33BXC001:4`033A<C01hC00<04a<0ha<00`0C

4`114`8=;A<004XC00<=4a<07Q<00`0C4`3S4`80@1<23BlC001;4`033A<C01dC00<04a<0ha<00`0C

4`0m4`8=<A<004`C00<=4a<071<20>@C00<04a<0>a<23C<C001<4`033A<C01`C00<04a<0ha<00`0C

4`0i4`8==A<004dC00<=4a<06a<00`0C4`3S4`0301<C03HC0`dg4`00CA<00`dC4`0K4`0301<C0><C

0P0e4`8=>Q<004hC00<=4a<06Q<20>@C00<04a<0<Q<23C`C001?4`033A<C01TC00<04a<0ha<00`0C

4`0`4`8=?Q<004lC00<=4a<02Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`3S4`0301<C02hC

0Pe04`00D1<00`dC4`084`0301<000LC00<04`000a<00`0C4`3S4`80;A<23D8C001A4`033A<C008C

0`024`0301<000TC00@04a<C0P3T4`0301<C02/C00<=4a<0@Q<0054C00<=4a<01a<00`0C00074`80

11<00`0C4`3S4`0301<C02TC0Pe54`00DQ<00`dC4`064`0301<000LC00<04a<00a<00`0C4`3L4`D0

0Q<00`0C4`0X4`033A<C04DC001C4`033A<C00HC00<04a<01Q<300<C00<04a<0gQ<00`0C4`024`03

01<C02HC0Pe84`00Da<00`dC4`0E4`0301<C0=PC0`034`0301<C008C0P0U4`8=BQ<005@C00<=4a<0

51<20=lC00<04a<00Q<00`0C4`0R4`8=C1<005DC00<=4a<04a<00`0C4`3N4`0301<C008C00<04a<0

81<23DhC001F4`033A<C018C00<04a<0gA<200@C00<04a<07Q<23E0C001F4`033A<C018C00<04a<0

ha<201`C0`eB4`00Ea<00`dC4`0A4`80i1<00`0C4`0H4`<=EA<005PC00<=4a<041<00`0C4`3S4`03

01<C01HC0PeH4`006Q<302DC1@0A4`033A<C010C00<04a<091<502@C0`2C4`0301<C01@C0PeJ4`00

6Q<00`0C4`0W4`0301<C018C00<=4a<03a<00`0C4`0V4`0301<C02@C00<04a<0Ta<00`0C4`0B4`8=

G1<001DC0`034`0301<C020C0`034`0301<C01<C00<=4a<03Q<202LC00<04a<09A<00`0C4`2B4`80

41<33EhC000K4`0301<C02HC00<04a<04a<00`dC4`0>4`0301<C02HC00<04a<09A<00`0C4`2B4`03

01<C00XC1@eQ4`006Q<00`0C000W4`0301<C01@C00<=4a<03A<00`0C4`0V4`0301<C02@C00<04`00

Ta<00`0C4`064`@=IQ<001/C00<04a<09A<201HC00<=4a<03A<00`0C4`0U4`809a<00`0C4`2B4`03

01<C008C10eZ4`00G1<00`dC4`0<4`80h1<93FhC001M4`033A<C00/C00<04a<0dA<>3@@C00<04a<0

L1<005dC00<=4a<02a<00`0C4`1K4`80AA<_3A8C00<04a<0L1<005hC00<=4a<02Q<00`0C4`1J4`03

01<C02`C6@e14`0301<C070C000E4dX000<=0000H0064`0301<C08HC00<04a<0L1<001TC00<04a<0

1Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`05

01<C4`d00a<00`0C4`054`0341<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C

4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<021<00`0C4`264`80>A<P3APC

001P4`033A<C00PC00<@4a<0FQ<00`0C00264`0301<C02HC4Pdh4`00HA<00`dC4`074`8@Fa<307LC

00<04a<00Q<00`0C4`024`0301<C008C00<04a<081<63DXC001Q4`033A<C00LC0Q3D4`0301<000LC

00<04`000a<00`0C4`0K4`D=D1<0068C00<=4a<01A<00a00403?4`<00Q<00`0C00094`0401<C4`80

6A<33EDC001R4`033A<C00DC00<@0100e1<00`0C00074`8011<00`0C4`0E4`<=F1<006<C00<=4a<0

11<00a00403D4`0301<000LC00<04a<00a<00`0C4`0C4`8=Fa<006@C00<=4a<00Q<01A0C000@0=@C

00<04a<01Q<300<C00<04a<04A<23EdC001T4`033A<C008C00D@4`0C403S4`0301<C00lC0PeO4`00

IA<02@dC4a<@4`0C403S4`803Q<23F4C001V4`063A<C41<00Q<00a0C4`3P4`0301<C00`C00<=4a<0

HA<006HC00D=4a<@4`0200034a0C0>4C00<04a<02a<00`dC4`1R4`00Ia<01@dC41<0008C00<@4a<0

h1<00`0C4`094`8=IA<006LC00D=41<C00034`0341<C0=lC0P094`033A<C06DC001X4`043A<C00<C

00<@4a<0ga<00`0C4`074`033A<C06HC001X4`0340dC00800Q<00a0C4`3O4`0301<C00HC00<=4a<0

Ia<006LC00D@4`dC00044`0341<C08DC0`0Y4`D0:1<00`0C4`054`033A<C01lC1@0Y4`<061<005`C

00<04a<00Q<00`0C4`024`06010C4`d011<00a0C4`254`0301<C02/C00<04a<0:1<00`0C4`044`03

3A<C028C00<04a<0:A<00`0C4`0H4`00Fa<00`0C00074`030100008C00<=01<00a<00a0C4`204`<0

0a<00`0C4`0T4`<00a<00`0C4`0X4`8011<00`dC4`0S4`0301<C02XC00<04a<05a<005/C00<04`00

21<00a004`024`033@0C00<C00<@4a<0QA<00`0C4`0Z4`0301<C02PC00<04a<00Q<00`dC4`0T4`03

01<C02XC00<04a<05a<005/C00<04`001a<00`0@4`034`0300dC00<C00<@4a<0Q1<00`0C000[4`03

01<C02PC00D04a<C3@0W4`0301<C02TC00<04`0061<005/C00<04`001a<00a0C4`034`0300dC00@C

00<@4a<0Q1<00`0C4`0Y4`80:Q<01@0C4a<=02HC0P0/4`0301<C01LC001L4`0301<C00HC00<@0000

0a<00`0C3@044`0341<C0=`C0P000a<=4`1^4`00I1<00a0C4`044`8000<C3A<00Q<00a0C4`3L4`03

01<=070C001T4`0341<C00@C00@04a<=11<00a0C4`3K4`0301<=070C001S4`0341<C00DC00D04a<C

3@034`0341<C0=/C00<03A<0I1<200XC001S4`0341<C00DC00D04a<C3@044`0341<C0=XC00<03A<0

Ha<00`0C4`0:4`00HQ<00a0C4`064`0301<C008C00D=4a<C401n4eh000<=0000G0074`0301<C00XC

001R4`0341<C00HC0P044`053A<C4a00PA<00`0C4`0Z4`0301<C02XC00<=4a<0:Q<00`0C4`0Z4`03

01<C00TC00<04a<02Q<0064C00<@4a<01a<00`0C4`034`053A<C4a00fQ<00`d04`1T4`0301<000XC

001Q4`0341<C00LC00<04a<011<010dC4a3J4`033@0C06@C0`0:4`00H1<00a0C4`084`0301<C00DC

00@=4a<@f1<010dC001a4`00H1<00a0C4`084`801Q<010dC4a3H4`033A<0078C001O4`0341<C00TC

00<04a<01Q<010dC4a3G4`033A<0078C001O4`0341<C00TC00<04a<01a<00`dC403G4`033A<0078C

001N4`0341<C00XC00<04a<01a<010dC4a3E4`043A<C078C001N4`0341<C00XC0P094`033A<@0=DC

00<=4a<00P1a4`00GA<00a0C4`0;4`0301<C00PC00@=4a<@e1<010dC4`1b4`00GA<00a0C4`044`D0

0Q<00`0C4`094`033A<@0=@C00@=4a<0LQ<005`C00<@4a<01a<00`0C4`024`0301<C00XC00<=4a00

da<010dC4`1b4`00Fa<00a0C4`084`0301<C008C0P0;4`043A<C4=4C00@=4a<C0P1a4`00Fa<00a0C

4`084`0301<C008C00<04a<02a<00`dC403A4`053A<C4`00LQ<005XC00<@4a<02A<00`0C4`024`03

01<C00`C00<=4a00d1<01@dC4a<0078C001J4`0341<C00PC0P044`0301<C00`C00@=4a<@ca<01@dC

4a<0078C001I4`0341<C00lC0P0>4`033A<@0<lC00D=4a<C001b4`00F1<00a0C4`0@4`0301<C00hC

00<=4a00cQ<010dC4a<2074C001H4`0341<C010C00<04a<03Q<010dC4a3>4`043A<C078C001G4`03

41<C014C00<04a<03a<00`dC40324`0301<C008C00<04a<00Q<00`0C3@024`0301<C070C001F4`03

41<C018C0P0@4`043A<C4<0C00<04`001a<0100C00d24`0301<C070C001F4`0341<C018C00<04a<0

41<010dC4a2o4`0301<000TC00@03A<C0P1a4`00EA<00a0C4`0C4`0301<C014C00<=4a00_a<00`0C

00074`8000DC3A<C001b4`00E1<00a0C4`0D4`0301<C014C00@=4a<@_Q<00`0C00074`0701<C4`dC

001b4`00Da<00a0C4`0E4`804a<00`dC402o4`0301<C00HC0`0011<=4`1b4`00Da<00a0C4`0E4`03

01<C01<C00<=4a00ba<00`dC001b4`00DQ<00a0C4`0F4`0301<C01<C00@=4a<@bQ<010dC001a4`00

DA<00a0C4`0G4`0301<C01@C00<=4a00ba<00`d04`1a4`00DA<00a0C4`0G4`805Q<00`dC403:4`03

3@0C074C001@4`0341<C01PC00<04a<05A<00`dC403;4`033A<C070C001?4`0341<C00PC1@024`03

01<C008C00<04a<00Q<00`0C4`0F4`033A<@0<XC00<=01<0L1<004lC00<@4a<02Q<00`0C4`064`03

01<000<C00<04a<05Q<010dC4a394`0300dC070C001>4`0341<C00/C00<04a<021<0100C4a<201PC

00@=4a<@b1<00`0=4`1`4`00CA<00a0C4`0<4`0301<C00HC0P044`0301<C01PC00<=4a00b1<00`0C

3@1`4`00C1<00a0C4`0=4`0301<C00HC00<04a<00a<00`0C4`0H4`043A<C4<LC00<04`d0L1<004`C

00<@4a<031<200PC0`034`0301<C01TC00@=4a<@aQ<200034`dC06hC001;4`0341<C01dC0P0K4`04

3A<C4<DC00D04a<C3@1^4`00BQ<00a0C4`0N4`0301<C01XC00@=4a<@aA<01@0C4a<=06hC001:4`03

41<C01hC00<04a<06a<010dC4a344`0301<C008C00<=4a<0Ja<004TC00<@4a<07a<00`0C4`0K4`05

3A<C4a00`a<200<C00<=4a<0Ja<004PC00<@4a<081<201dC00D=4a<C40324`0301<C00<C00<=4a<0

JQ<004LC00<@4a<08A<00`0C4`0M4`053A<C4a00`A<00`0C4`044`033A<C06TC00174`0341<C024C

00<04a<07A<01@dC4a<@0;XC1@024`0301<C00DC00<=4a<0J1<004HC00<@4a<08Q<00`0C4`0N4`05

3A<C4a00^a<00`0C4`024`0301<C00DC00<=4a<0J1<004DC00<@4a<08a<201lC00<=4a<00Q<00a0C

4`2h4`0301<C008C0P074`033A<C06LC00144`0341<C02@C00<04a<07a<00`dC4`024`0341<C0;LC

00<04a<00Q<00`0C4`074`033A<C06HC00144`0341<C02@C00<04a<081<01@dC4a<@0;TC00<04a<0

0Q<00`0C4`084`033A<C06DC00134`0341<C02DC00<04a<081<00`dC4`024`0341<C0;DC0P044`03

01<C00TC00<=4a<0I1<0048C00<@4a<09Q<00`0C4`0Q4`033A<C008C00<@4a<0^Q<200/C00<=4a<0

Ha<0044C00<@4a<09a<202<C00<=4a<00Q<00a0C4`2i4`0301<C00/C00<=4a<0HQ<0040C00<@4a<0

:1<00`0C4`0R4`033A<C00<C00<@4a<0^1<00`0C4`0<4`033A<C064C00104`0341<C028C0`034`03

01<C02<C00<=4a<00a<00a0C4`2g4`0301<C00dC00<=4a<0H1<003lC00<@4a<08a<00`0C4`034`03

01<C02<C00<=4a<00a<00a0C4`2g4`803a<23F0C000n4`0341<C02DC00<04a<00Q<202DC00<=4a<0

0a<00a0C4`2f4`0301<C010C00<=4a<0GA<003dC00<@4a<09Q<00`0C4`024`0301<C02DC00<=4a<0

0a<00a0C4`2e4`0301<C014C00<=4a<0G1<003dC00<@4a<09A<00`0C00034`0301<C02DC00<=4a<0

11<00a0C4`2d4`0301<C018C00<=4a<0Fa<003`C00<@4a<09a<00`0C4`024`0301<C02HC00<=4a<0

11<00a0C4`2c4`0301<C01<C00<=4a<0FQ<003/C00<@4a<0;A<202PC00<=4a<011<00a0C4`2b4`80

5A<00`dC4`1I4`00>Q<00a0C4`0^4`0301<C02LC00<=4a<011<00a0C4`2b4`0301<C01DC00<=4a<0

F1<003XC00<@4a<0;Q<00`0C4`0X4`033A<C00@C00<@4a<0/A<00`0C4`0F4`033A<C05LC000i4`03

41<C02lC00<04a<0:A<00`dC4`044`0341<C0;0C00<04a<05a<23ELC000h4`0341<C030C0P0Z4`03

3A<C00DC00<@4a<0[a<201XC00<=4a<0E1<003LC00<@4a<0<A<00`0C4`0Z4`033A<C00@C00<@4a<0

[a<00`0C4`0J4`8=E1<003LC00<@4a<0<A<00`0C4`0Z4`033A<C00DC00<@4a<0[Q<00`0C4`0L4`03

3A<C054C000f4`0341<C038C00<04a<0:a<00`dC4`054`0341<C09`C1@024`0301<C008C00<04a<0

0Q<00`0C4`0M4`8=DA<003DC00<@4a<0<a<202dC00<=4a<01A<00a0C4`2M4`0301<C00HC00<04`00

0a<00`0C4`0O4`033A<C04hC000d4`0341<C03@C00<04a<0;1<00`dC4`064`0341<C09`C00<04a<0

21<0100C4a<2024C0Pe>4`00<a<00a0C4`0e4`0301<C02dC00<=4a<01Q<00a0C4`2K4`0301<C00HC

0P044`0301<C028C00<=4a<0Ba<0038C00<@4a<0=Q<00`0C4`0^4`033A<C00DC00<@4a<0Va<00`0C

4`064`0301<C00<C00<04a<08a<23D/C000a4`0341<C03LC0P0_4`033A<C00HC00<@4a<0VA<200PC

0`034`0301<C02DC00<=4a<0B1<0030C00<@4a<0>1<00`0C4`0_4`033A<C00HC00<@4a<0Z1<202LC

0Pe84`00;a<00a0C4`0Y4`<00a<00`0C4`024`0301<C008C00<04a<0<1<00`dC4`064`0341<C0:LC

00<04a<0:1<00`dC4`154`00;Q<00a0C4`0Z4`0301<C00LC00<04`000a<00`0C4`0`4`033A<C00LC

00<@4a<0YQ<00`0C4`0Y4`8=AA<002dC00<@4a<0;1<00`0C4`084`0401<C4`80<Q<00`dC4`074`03

41<C0:DC00<04a<0:a<00`dC4`124`00;1<00a0C4`0]4`0301<C00HC0P044`0301<C034C00<=4a<0

21<00a0C4`2T4`0301<C02`C0Pe24`00:a<00a0C4`0]4`0301<000LC00<04a<00a<00`0C4`0b4`03

3A<C00PC00<@4a<0Xa<202lC00<=4a<0?a<002XC00<@4a<0;a<00`0C4`064`<00a<00`0C4`0c4`03

3A<C00PC00<@4a<0XQ<00`0C4`0_4`8=?a<002TC00<@4a<0?a<203@C00<=4a<02A<00a0C4`2Q4`03

01<C034C0Pdm4`00:1<00a0C4`104`0301<C03@C00<=4a<02A<00a0C4`2P4`0301<C03<C0Pdk4`00

9a<00a0C4`114`0301<C03DC00<=4a<02A<00a0C4`2O4`80=Q<23CTC000V4`0341<C048C00<04a<0

=A<00`dC4`0:4`0341<C09hC00<04a<0=a<23CLC000U4`0341<C04<C0P0g4`033A<C00XC00<@4a<0

WA<00`0C4`0i4`8==A<002@C00<@4a<0A1<00`0C4`0g4`033A<C00XC00<@4a<0W1<00`0C4`0k4`8=

<a<002<C00<@4a<0AA<00`0C4`0g4`033A<C00/C00<@4a<0Va<00`0C4`0m4`8=<A<002<C00<@4a<0

AA<00`0C4`0h4`033A<C00/C00<@4a<0VQ<2040C0Pd_4`008Q<00a0C4`164`80>A<00`dC4`0<4`03

41<C09TC00<04a<0@A<23BdC000Q4`0341<C04LC00<04a<0>A<00`dC4`0<4`0341<C098C0`034`03

01<C04<C0Pd[4`0081<00a0C4`184`0301<C03XC00<=4a<031<00a0C4`2A4`0301<C00<C00<04a<0

AA<23BTC000O4`0341<C04TC00<04a<0>Q<00`dC4`0=4`0341<C094C00<04a<00Q<204PC0PdW4`00

7Q<00a0C4`1:4`80?1<00`dC4`0=4`0341<C090C00<04a<00Q<00`0C4`194`033A<C02@C000M4`03

41<C04/C00<04a<0?1<00`dC4`0=4`0341<C08hC00<04`000a<00`0C4`1:4`8=91<001`C00<@4a<0

C1<00`0C4`0l4`033A<C00hC00<@4a<0SQ<00`0C4`024`0301<C04`C0`dQ4`006a<00a0C4`174`80

11<00`0C4`0m4`033A<C00hC00<@4a<0TQ<00`0C4`1?4`<=7Q<001XC00<@4a<0BQ<01@0C4a<003lC

00<=4a<03a<00a0C4`2A4`80Da<23A`C000I4`0341<C04XC00<04a<00Q<203lC00<=4a<03Q<00a0C

4`2A4`0301<C05@C0PdJ4`00Ia<00`0C4`3W4`0301<C05HC0PdH4`00IA<00`0C003Y4`0301<C070C

001V4`0301<C0>PC0P1a4`00:Q<30?lC9A<00`0C4`1`4`00:Q<00`0C4`3o4bDC00<04a<0L1<002/C

00<04a<011<00`0C4`3o4i0C000[4`0401<C4`@00a<30?lCS1<002XC00<04`000Q<200034`0C00@C

00<04a<0oa>:4`00:a<00`0C4`034`0301<000<C00<04a<0oa>;4`00<A<00`0C00044`0301<C00HC

00<04a<09a<302/C00<04a<0oa<Y4`006a<300034`00008031<300@C0`084`0301<C02HC00@04a<0

3a<300034`0000800Q<00`0C4`024`0301<C008C00<04a<01A<0100C4a<5008C00<04a<00Q<00`0C

4`024`0301<C008C00<04a<011<20<DC00<04a<0=a<00`0C4`064`006Q<0100C4`0T4`0301<C02DC

00@04a<03Q<0100C4`064`0301<000LC00<04`0011<500<C00<04a<01Q<00`0C00024`0301<0008C

00<04`0011<00`0C4`2m4`0301<C00@C00<04a<04a<00`0C4`0S4`0301<C00DC000J4`0501<C01<0

10000a<0000H02dC0`0>4`0501<C01<0100011<04`094`0301<C00@C00<04a<00a<00`0C4`084`06

01<C01<011<00`0C4`024`0301<C0:/C00@04a<C10024`801Q<00`0C4`034`0301<C008C00<04a<0

0Q<00`0C4`024`0301<C00DC00@04a<C1@024`0301<C008C00<04a<00Q<00`0C4`024`0301<C00@C

0P044`0401<C4`800A<001/C0`1?4`0301<C00dC0`064`0301<000LC0P074`0301<C00<C00<04a<0

1Q<200@C00@04a<C0P054`0301<C0:XC00<04`001a<00`0C4`044`D00a<01`0C4a<04`001a<00`0C

00044`D00a<00`0C4`064`0301<0008C00<04`000Q<00`0C00044`0301<C00@C00<04a<00Q<1004C

000M4`0301<C04`C0P0A4`0301<C00@C00<04`001a<00`0C4`0<4`0301<C00HC00<04a<00Q<00`0C

00024`0301<C00@C00<04`00ZQ<00`0C00024`@000<C01<01a<00`0C4`034`0701<C4`0C00094`03

01<C00@C00<04a<00a<00`0C4`084`0601<C01<011<00`0C4`024`0301<C00@C00<04a<00a<10000

71<2060C0P074`0301<C00HC0`0;4`8021<300<C00@04a<C0`044`<0Ta<200034`00018C00<04`00

1a<00`0C4`064`0301<C00<C00L04a<C01<000LC0P074`0301<C00<C00<04a<01Q<200@C00@04a<C

0P054`0301<C00@C00<04a<00a<10000oa=A4`0301<001<C00<04`001a<00`0C000=4`0601<C01<0

1a<00`0C4`0<4`0301<C00HC00<04a<00Q<00`0C00024`0301<C00@C00<04`000a<00`0C4`034`40

0A<002HC0P064`80oa<R4`0301<C01<C00<04a<01Q<300hC00@04a<021<300/C0P084`<00a<0100C

4a<300@C0`024`0301<C00<C0P014`00:1<00`0C4`024`0301<C0?lC8Q<00`0C4`1`4`009a<00`0C

4`034`0301<C00HC00<04a<0oa<H4`0301<0074C000X4`0301<C008C00<04a<00Q<300044`0C4`<0

oa<D4`8000<C0000L1<002HC00<04`0011<00`0C00024`800Q<00`0C4`024`0301<C0?lCQa<002LC

00<04a<00a<300@C00@04a<00Q<00`0C4`3o4hPC000d4`0401<C00<C00<04a<0oa>74`00<Q<300@C

0`3o4hTC003o4lDC003o4lDC003o4lDC003o4lDC003o4lDC0000\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.53265, -1.74079, 0.0223128, 0.0223128}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -82 0 ]

[.5 .96488 82 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -143 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.58) show

217.250000 19.500000 moveto

(C) show

222.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.27396 0 m

.30316 .04613 L

.34309 .10922 L

.3815 .16991 L

.42237 .23448 L

.46172 .29665 L

.49955 .35643 L

.53984 .42009 L

.57861 .48135 L

.61984 .54648 L

.65954 .60922 L

.69774 .66957 L

.73838 .73379 L

.77751 .79561 L

.81909 .86131 L

.85916 .92462 L

s

.85916 .92462 m

.87673 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.387463 0.238095 [

[.02381 .37496 -6 -9 ]

[.02381 .37496 6 0 ]

[.2619 .37496 -6 -9 ]

[.2619 .37496 6 0 ]

[.7381 .37496 -3 -9 ]

[.7381 .37496 3 0 ]

[.97619 .37496 -3 -9 ]

[.97619 .37496 3 0 ]

[1.025 .38746 0 -8 ]

[1.025 .38746 9 8 ]

[.4875 .03032 -24 -4.5 ]

[.4875 .03032 0 4.5 ]

[.4875 .14937 -12 -4.5 ]

[.4875 .14937 0 4.5 ]

[.4875 .26842 -24 -4.5 ]

[.4875 .26842 0 4.5 ]

[.4875 .50651 -18 -4.5 ]

[.4875 .50651 0 4.5 ]

[.4875 .62556 -6 -4.5 ]

[.4875 .62556 0 4.5 ]

[.4875 .74461 -18 -4.5 ]

[.4875 .74461 0 4.5 ]

[.4875 .86365 -6 -4.5 ]

[.4875 .86365 0 4.5 ]

[.5 .94464 -4.5 0 ]

[.5 .94464 4.5 16 ]

[.5 .93214 -134.5 0 ]

[.5 .93214 134.5 16 ]

[ 0 0 0 0 ]

[ 1 .91964 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .38746 m

.02381 .39371 L

s

[(-2)] .02381 .37496 0 1 Mshowa

.2619 .38746 m

.2619 .39371 L

s

[(-1)] .2619 .37496 0 1 Mshowa

.7381 .38746 m

.7381 .39371 L

s

[(1)] .7381 .37496 0 1 Mshowa

.97619 .38746 m

.97619 .39371 L

s

[(2)] .97619 .37496 0 1 Mshowa

.125 Mabswid

.07143 .38746 m

.07143 .39121 L

s

.11905 .38746 m

.11905 .39121 L

s

.16667 .38746 m

.16667 .39121 L

s

.21429 .38746 m

.21429 .39121 L

s

.30952 .38746 m

.30952 .39121 L

s

.35714 .38746 m

.35714 .39121 L

s

.40476 .38746 m

.40476 .39121 L

s

.45238 .38746 m

.45238 .39121 L

s

.54762 .38746 m

.54762 .39121 L

s

.59524 .38746 m

.59524 .39121 L

s

.64286 .38746 m

.64286 .39121 L

s

.69048 .38746 m

.69048 .39121 L

s

.78571 .38746 m

.78571 .39121 L

s

.83333 .38746 m

.83333 .39121 L

s

.88095 .38746 m

.88095 .39121 L

s

.92857 .38746 m

.92857 .39121 L

s

.25 Mabswid

0 .38746 m

1 .38746 L

s

gsave

1.025 .38746 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .03032 m

.50625 .03032 L

s

[(-1.5)] .4875 .03032 1 0 Mshowa

.5 .14937 m

.50625 .14937 L

s

[(-1)] .4875 .14937 1 0 Mshowa

.5 .26842 m

.50625 .26842 L

s

[(-0.5)] .4875 .26842 1 0 Mshowa

.5 .50651 m

.50625 .50651 L

s

[(0.5)] .4875 .50651 1 0 Mshowa

.5 .62556 m

.50625 .62556 L

s

[(1)] .4875 .62556 1 0 Mshowa

.5 .74461 m

.50625 .74461 L

s

[(1.5)] .4875 .74461 1 0 Mshowa

.5 .86365 m

.50625 .86365 L

s

[(2)] .4875 .86365 1 0 Mshowa

.125 Mabswid

.5 .05413 m

.50375 .05413 L

s

.5 .07794 m

.50375 .07794 L

s

.5 .10175 m

.50375 .10175 L

s

.5 .12556 m

.50375 .12556 L

s

.5 .17318 m

.50375 .17318 L

s

.5 .19699 m

.50375 .19699 L

s

.5 .2208 m

.50375 .2208 L

s

.5 .24461 m

.50375 .24461 L

s

.5 .29222 m

.50375 .29222 L

s

.5 .31603 m

.50375 .31603 L

s

.5 .33984 m

.50375 .33984 L

s

.5 .36365 m

.50375 .36365 L

s

.5 .41127 m

.50375 .41127 L

s

.5 .43508 m

.50375 .43508 L

s

.5 .45889 m

.50375 .45889 L

s

.5 .4827 m

.50375 .4827 L

s

.5 .53032 m

.50375 .53032 L

s

.5 .55413 m

.50375 .55413 L

s

.5 .57794 m

.50375 .57794 L

s

.5 .60175 m

.50375 .60175 L

s

.5 .64937 m

.50375 .64937 L

s

.5 .67318 m

.50375 .67318 L

s

.5 .69699 m

.50375 .69699 L

s

.5 .7208 m

.50375 .7208 L

s

.5 .76842 m

.50375 .76842 L

s

.5 .79222 m

.50375 .79222 L

s

.5 .81603 m

.50375 .81603 L

s

.5 .83984 m

.50375 .83984 L

s

.5 .00651 m

.50375 .00651 L

s

.5 .88746 m

.50375 .88746 L

s

.5 .91127 m

.50375 .91127 L

s

.25 Mabswid

.5 0 m

.5 .91964 L

s

gsave

.5 .94464 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .93214 -195.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.58) show

293.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

298.000000 15.000000 moveto

(L) show

305.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

312.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

319.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

324.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

328.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .91964 L

0 .91964 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .23292 m

.02576 .23291 L

.03158 .23287 L

.04116 .2328 L

.05435 .23271 L

.07092 .23259 L

.09058 .23243 L

.113 .23224 L

.13779 .232 L

.16454 .23172 L

.19277 .23139 L

.22202 .23099 L

.25178 .23053 L

.28153 .22998 L

.31078 .22934 L

.33902 .22861 L

.36576 .22777 L

.39055 .22684 L

.41297 .22582 L

.43263 .22476 L

.4492 .2237 L

.46239 .22273 L

.47198 .22193 L

.47779 .22141 L

.47974 .22123 L

s

.47974 .22123 m

.48187 .22103 L

.4882 .2204 L

.49864 .21926 L

.513 .21746 L

.53104 .21474 L

.55245 .21066 L

.57686 .20463 L

.60386 .19597 L

.63298 .18435 L

.66372 .17015 L

.69557 .15429 L

.72797 .13777 L

.76037 .12132 L

.79221 .10545 L

.82296 .0905 L

.85208 .07672 L

.87908 .06426 L

.90349 .05326 L

.9249 .04381 L

.94293 .03599 L

.9573 .02986 L

.96773 .02544 L

.97407 .02278 L

.97619 .0219 L

s

.47974 .47052 m

.48187 .44332 L

.4882 .41646 L

.49864 .39024 L

.513 .36495 L

.53104 .34099 L

.55245 .31892 L

.57686 .29947 L

.60386 .28343 L

.63298 .27124 L

.66372 .26264 L

.69557 .25678 L

.72797 .2528 L

.76037 .25004 L

.79221 .24807 L

.82296 .24664 L

.85208 .24556 L

.87908 .24475 L

.90349 .24414 L

.9249 .24367 L

.94293 .24331 L

.9573 .24306 L

.96773 .24288 L

.97407 .24278 L

.97619 .24275 L

s

.47974 .47064 m

.48187 .49804 L

.4882 .52553 L

.49864 .55289 L

.513 .57998 L

.53104 .60666 L

.55245 .63281 L

.57686 .65829 L

.60386 .68299 L

.63298 .7068 L

.66372 .72961 L

.69557 .75131 L

.72797 .77182 L

.76037 .79103 L

.79221 .80887 L

.82296 .82525 L

.85208 .84011 L

.87908 .85337 L

.90349 .86499 L

.9249 .87491 L

.94293 .88308 L

.9573 .88947 L

.96773 .89406 L

.97407 .89682 L

.97619 .89774 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<00`0C4`1`4`00oa=B4`80LA<006@C1@3X4`0301<C070C001V4`0301<C0=LC1@024`03

01<C008C00<04a<00Q<00`0C4`1`4`00A1<00`dC4`0I4`<00a<00`0C4`024`80eA<00`0C4`064`03

01<000<C00<04a<0EA<33APC00154`033A<C01hC00<04a<00Q<00`0C4`3>4`<00a<00`0C4`084`04

01<C4`80E1<23A/C00154`033A<C01hC00<04a<00Q<00`0C4`3D4`0301<C00HC0P044`0301<C054C

0PdM4`00AQ<00`dC4`0L4`8011<00`0C4`3D4`0301<C00HC00<04a<00a<00`0C4`1?4`8=7a<004HC

00<=4a<08Q<20=@C0P084`<00a<00`0C4`1=4`8=8A<004LC00<=4a<08A<00`0C4`3S4`0301<C04/C

0PdS4`00B1<00`dC4`0P4`0301<C0><C0P1:4`8=9A<004PC00<=4a<081<00`0C4`3S4`0301<C04LC

0PdW4`00BA<00`dC4`0O4`80i1<00`0C4`144`<=:A<004XC00<=4a<07Q<00`0C4`3S4`0301<C044C

0`d/4`00BQ<00`dC4`0N4`0301<C0><C0P104`8=;a<004/C00<=4a<07A<00`0C4`3S4`0301<C03dC

0Pda4`00C1<00`dC4`0L4`80i1<00`0C4`0k4`8=<a<004`C00<=4a<071<00`0C4`3S4`0301<C03TC

0Pde4`00CA<00`dC4`0K4`0301<C0><C00<04a<0=Q<33CLC001=4`033A<C01/C00<04a<0ha<203DC

0Pdj4`00CQ<00`dC4`0J4`80i1<00`0C4`0b4`8=?1<004lC00<=4a<06A<00`0C4`3S4`0301<C030C

0Pdn4`00Ca<00`dC4`0:4`0301<C008C00<04a<00Q<00`0C4`024`0301<C0><C00<04a<0;Q<23D0C

001@4`033A<C00PC00<04`001a<00`0C00034`0301<C0><C0P0]4`8=@Q<0054C00<=4a<00Q<3008C

00<04`002A<0100C4a<20>@C00<04a<0:a<00`dC4`124`00DA<00`dC4`074`0301<000LC0P044`03

01<C0><C00<04a<0:A<23DDC001B4`033A<C00HC00<04`001a<00`0C4`034`0301<C0=`C1@024`03

01<C02PC00<=4a<0AA<005<C00<=4a<01Q<00`0C4`064`<00a<00`0C4`3N4`0301<C008C00<04a<0

9Q<23DPC001C4`033A<C01DC00<04a<0f1<300<C00<04a<00Q<202DC0Pe:4`00E1<00`dC4`0D4`80

ga<00`0C4`024`0301<C028C0Pe<4`00EA<00`dC4`0C4`0301<C0=hC00<04a<00Q<00`0C4`0P4`8=

CQ<005HC00<=4a<04Q<00`0C4`3M4`8011<00`0C4`0N4`8=D1<005HC00<=4a<04Q<00`0C4`3S4`80

71<33E8C001G4`033A<C014C0P3T4`0301<C01PC0`eE4`00F1<00`dC4`0@4`0301<C0><C00<04a<0

5Q<23EPC000J4`<09A<5014C00<=4a<041<00`0C4`0T4`D091<309<C00<04a<051<23EXC000J4`03

01<C02LC00<04a<04Q<00`dC4`0?4`0301<C02HC00<04a<091<00`0C4`2C4`0301<C018C0PeL4`00

5A<300<C00<04a<081<300<C00<04a<04a<00`dC4`0>4`809a<00`0C4`0U4`0301<C098C0P0@4`<=

GQ<001/C00<04a<09Q<00`0C4`0C4`033A<C00hC00<04a<09Q<00`0C4`0U4`0301<C098C00<04a<0

2Q<53F4C000J4`0301<002LC00<04a<051<00`dC4`0=4`0301<C02HC00<04a<091<00`0C002C4`03

01<C00HC10eV4`006a<00`0C4`0U4`805Q<00`dC4`0=4`0301<C02DC0P0W4`0301<C098C00<04a<0

0Q<43FXC001L4`033A<C00`C0P3O4`X=KQ<005dC00<=4a<02a<00`0C4`3=4a4=1A<00`0C4`1`4`00

GA<00`dC4`0;4`0301<C05/C0P0/4d@=5Q<00`0C4`1`4`00GQ<00`dC4`0:4`0301<C05XC00<04a<0

QQ<00`0C4`1`4`005A=:00033@0006001Q<00`0C4`264`0301<C050C20dH4`006A<00`0C4`064`03

01<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00D04a<C

3@034`0301<C00DC00<@4a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00DC

00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`084`0301<C08HC0P0c4ah=81<0060C

00<=4a<021<00a0C4`1J4`0301<008HC00<04a<09Q<<3ChC001Q4`033A<C00LC0Q1K4`<0Ma<00`0C

4`024`0301<C008C00<04a<00Q<00`0C4`0P4`H=BQ<0064C00<=4a<01a<24=@C00<04`001a<00`0C

00034`0301<C01/C1@e@4`00HQ<00`dC4`054`03400@0<lC0`024`0301<000TC00@04a<C0P0I4`<=

EA<0068C00<=4a<01A<00a00403D4`0301<000LC0P044`0301<C01DC0`eH4`00Ha<00`dC4`044`03

400@0=@C00<04`001a<00`0C4`034`0301<C01<C0PeK4`00I1<00`dC4`024`0541<00100e1<00`0C

4`064`<00a<00`0C4`0A4`8=GA<006@C00<=4a<00Q<01A0C01<@0><C00<04a<03a<23ElC001U4`09

3A<C4a0C01<@0><C0P0>4`8=HA<006HC00H=4a<@4`024`0341<C0>0C00<04a<031<00`dC4`1Q4`00

IQ<01@dC4a0C008000<C41<0hA<00`0C4`0;4`033A<C068C001W4`053A<@4`000Q<00a0C4`3P4`03

01<C00TC0PeU4`00Ia<01@d@4a<000<C00<@4a<0ga<200TC00<=4a<0IA<006PC00@=4a<00a<00a0C

4`3O4`0301<C00LC00<=4a<0IQ<006PC00<@3A<00P024`0341<C0=lC00<04a<01Q<00`dC4`1W4`00

Ia<01A0C3A<000@C00<@4a<0QA<302TC1@0X4`0301<C00DC00<=4a<07a<502TC0`0H4`00G1<00`0C

4`024`0301<C008C00H041<C3@044`0341<C08DC00<04a<0:a<00`0C4`0X4`0301<C00@C00<=4a<0

8Q<00`0C4`0Y4`0301<C01PC001K4`0301<000LC00<040000Q<00`d04`034`0341<C080C0`034`03

01<C02@C0`034`0301<C02PC0P044`033A<C02<C00<04a<0:Q<00`0C4`0G4`00Fa<00`0C00084`03

400C008C00<=01<00a<00a0C4`254`0301<C02XC00<04a<0:1<00`0C4`024`033A<C02@C00<04a<0

:Q<00`0C4`0G4`00Fa<00`0C00074`03010C00<C00<03A<00a<00a0C4`244`0301<002/C00<04a<0

:1<01@0C4a<=02LC00<04a<0:A<00`0C000H4`00Fa<00`0C00074`0341<C00<C00<03A<011<00a0C

4`244`0301<C02TC0P0Z4`0501<C4`d09Q<202`C00<04a<05a<005`C00<04a<01Q<00a0000034`03

01<=00@C00<@4a<0g1<200034`dC06hC001T4`0341<C00@C0P000a<=4`024`0341<C0=`C00<04`d0

L1<006@C00<@4a<011<0100C4`d44`0341<C0=/C00<04`d0L1<006<C00<@4a<01A<01@0C4a<=00<C

00<@4a<0fa<00`0=4`1T4`802Q<006<C00<@4a<01A<01@0C4a<=00@C00<@4a<0fQ<00`0=4`1S4`03

01<C00XC001R4`0341<C00HC00<04a<00Q<01@dC4a<@07hCGP000`d0001L00LC00<04a<02Q<0068C

00<@4a<01Q<200@C00D=4a<C40214`0301<C02XC00<04a<0:Q<00`dC4`0Z4`0301<C02XC00<04a<0

2A<00`0C4`0:4`00HA<00a0C4`074`0301<C00<C00D=4a<C403J4`033@0C06@C00<04`002Q<0064C

00<@4a<01a<00`0C4`044`043A<C4=XC00<=01<0I1<300XC001P4`0341<C00PC00<04a<01A<010dC

4a3H4`043A<0074C001P4`0341<C00PC0P064`043A<C4=PC00<=4`00LQ<005lC00<@4a<02A<00`0C

4`064`043A<C4=LC00<=4`00LQ<005lC00<@4a<02A<00`0C4`074`033A<@0=LC00<=4`00LQ<005hC

00<@4a<02Q<00`0C4`074`043A<C4=DC00@=4a<0LQ<005hC00<@4a<02Q<200TC00<=4a00eA<00`dC

4`02074C001M4`0341<C00/C00<04a<021<010dC4a3D4`043A<C078C001M4`0341<C00@C1@024`03

01<C00TC00<=4a00e1<010dC4`1b4`00G1<00a0C4`074`0301<C008C00<04a<02Q<00`dC403C4`04

3A<C078C001K4`0341<C00PC00<04a<00Q<200/C00@=4a<@dA<010dC4a<2074C001K4`0341<C00PC

00<04a<00Q<00`0C4`0;4`033A<@0=4C00D=4a<C001b4`00FQ<00a0C4`094`0301<C008C00<04a<0

31<00`dC403@4`053A<C4`00LQ<005XC00<@4a<021<200@C00<04a<031<010dC4a3?4`053A<C4`00

LQ<005TC00<@4a<03a<200hC00<=4a00ca<01@dC4a<0078C001H4`0341<C010C00<04a<03Q<00`dC

403?4`033A<C0080LA<005PC00<@4a<041<00`0C4`0>4`043A<C4<hC00@=4a<0LQ<005LC00<@4a<0

4A<00`0C4`0?4`033A<@0<8C00<04a<00Q<00`0C4`024`0301<=008C00<04a<0L1<005HC00<@4a<0

4Q<2010C00@=4a<@`1<00`0C00074`0401<03@8C00<04a<0L1<005HC00<@4a<04Q<00`0C4`0@4`04

3A<C4;lC00<04`002A<0100=4a<2074C001E4`0341<C01<C00<04a<04A<00`dC402o4`0301<000LC

0P001A<=4a<0078C001D4`0341<C01@C00<04a<04A<010dC4a2n4`0301<000LC00L04a<C3A<0078C

001C4`0341<C01DC0P0C4`033A<@0;lC00<04a<01Q<300044`dC078C001C4`0341<C01DC00<04a<0

4a<00`dC403;4`033A<0078C001B4`0341<C01HC00<04a<04a<010dC4a3:4`043A<0074C001A4`03

41<C01LC00<04a<051<00`dC403;4`033@0C074C001A4`0341<C01LC0P0F4`033A<@0<XC00<=01<0

LA<0050C00<@4a<061<00`0C4`0E4`033A<@0</C00<=4a<0L1<004lC00<@4a<021<5008C00<04a<0

0Q<00`0C4`024`0301<C01HC00<=4a00bQ<00`d04`1`4`00Ca<00a0C4`0:4`0301<C00HC00<04`00

0a<00`0C4`0F4`043A<C4<TC00<03A<0L1<004hC00<@4a<02a<00`0C4`084`0401<C4`8061<010dC

4a384`0300dC070C001=4`0341<C00`C00<04a<01Q<200@C00<04a<061<00`dC40384`0301<=070C

001<4`0341<C00dC00<04a<01Q<00`0C4`034`0301<C01PC00@=4a<@aa<00`0C3@1`4`00C1<00a0C

4`0<4`8021<300<C00<04a<06A<010dC4a364`8000<C3A<0KQ<004/C00<@4a<07A<201/C00@=4a<@

aA<01@0C4a<=06hC001:4`0341<C01hC00<04a<06Q<010dC4a354`0501<C4`d0KQ<004XC00<@4a<0

7Q<00`0C4`0K4`043A<C4<@C00<04a<00Q<00`dC4`1[4`00BA<00a0C4`0O4`0301<C01/C00D=4a<C

40334`800a<00`dC4`1[4`00B1<00a0C4`0P4`807A<01@dC4a<@0<8C00<04a<00a<00`dC4`1Z4`00

Aa<00a0C4`0Q4`0301<C01dC00D=4a<C40314`0301<C00@C00<=4a<0JA<004LC00<@4a<08A<00`0C

4`0M4`053A<C4a00^Q<5008C00<04a<01A<00`dC4`1X4`00AQ<00a0C4`0R4`0301<C01hC00D=4a<C

402k4`0301<C008C00<04a<01A<00`dC4`1X4`00AA<00a0C4`0S4`807a<00`dC4`024`0341<C0;PC

00<04a<00Q<200LC00<=4a<0Ia<004@C00<@4a<091<00`0C4`0O4`033A<C008C00<@4a<0]a<00`0C

4`024`0301<C00LC00<=4a<0IQ<004@C00<@4a<091<00`0C4`0P4`053A<C4a00^A<00`0C4`024`03

01<C00PC00<=4a<0IA<004<C00<@4a<09A<00`0C4`0P4`033A<C008C00<@4a<0]A<200@C00<04a<0

2A<00`dC4`1T4`00@Q<00a0C4`0V4`0301<C024C00<=4a<00Q<00a0C4`2j4`802a<00`dC4`1S4`00

@A<00a0C4`0W4`808a<00`dC4`024`0341<C0;TC00<04a<02a<00`dC4`1R4`00@1<00a0C4`0X4`03

01<C028C00<=4a<00a<00a0C4`2h4`0301<C00`C00<=4a<0HA<0040C00<@4a<08Q<300<C00<04a<0

8a<00`dC4`034`0341<C0;LC00<04a<03A<00`dC4`1P4`00?a<00a0C4`0S4`0301<C00<C00<04a<0

8a<00`dC4`034`0341<C0;LC0P0?4`8=H1<003hC00<@4a<09A<00`0C4`024`809A<00`dC4`034`03

41<C0;HC00<04a<041<00`dC4`1M4`00?A<00a0C4`0V4`0301<C008C00<04a<09A<00`dC4`034`03

41<C0;DC00<04a<04A<00`dC4`1L4`00?A<00a0C4`0U4`0301<000<C00<04a<09A<00`dC4`044`03

41<C0;@C00<04a<04Q<00`dC4`1K4`00?1<00a0C4`0W4`0301<C008C00<04a<09Q<00`dC4`044`03

41<C0;<C00<04a<04a<00`dC4`1J4`00>a<00a0C4`0]4`80:1<00`dC4`044`0341<C0;8C0P0E4`03

3A<C05TC000j4`0341<C02hC00<04a<09a<00`dC4`044`0341<C0;8C00<04a<05A<00`dC4`1H4`00

>Q<00a0C4`0^4`0301<C02PC00<=4a<011<00a0C4`2a4`0301<C01HC00<=4a<0Ea<003TC00<@4a<0

;a<00`0C4`0Y4`033A<C00@C00<@4a<0/1<00`0C4`0G4`8=Ea<003PC00<@4a<0<1<202XC00<=4a<0

1A<00a0C4`2_4`806Q<00`dC4`1D4`00=a<00a0C4`0a4`0301<C02XC00<=4a<011<00a0C4`2_4`03

01<C01XC0PeD4`00=a<00a0C4`0a4`0301<C02XC00<=4a<01A<00a0C4`2^4`0301<C01`C00<=4a<0

DA<003HC00<@4a<0<Q<00`0C4`0[4`033A<C00DC00<@4a<0W1<5008C00<04a<00Q<00`0C4`024`03

01<C01dC0PeA4`00=A<00a0C4`0c4`80;A<00`dC4`054`0341<C09dC00<04a<01Q<00`0C00034`03

01<C01lC00<=4a<0CQ<003@C00<@4a<0=1<00`0C4`0/4`033A<C00HC00<@4a<0W1<00`0C4`084`04

01<C4`808A<23DhC000c4`0341<C03DC00<04a<0;A<00`dC4`064`0341<C09/C00<04a<01Q<200@C

00<04a<08Q<00`dC4`1;4`00<Q<00a0C4`0f4`0301<C02hC00<=4a<01A<00a0C4`2K4`0301<C00HC

00<04a<00a<00`0C4`0S4`8=Ba<0034C00<@4a<0=a<202lC00<=4a<01Q<00a0C4`2I4`8021<300<C

00<04a<09A<00`dC4`184`00<1<00a0C4`0h4`0301<C02lC00<=4a<01Q<00a0C4`2X4`809a<23DPC

000_4`0341<C02TC0`034`0301<C008C00<04a<00Q<00`0C4`0`4`033A<C00HC00<@4a<0Ya<00`0C

4`0X4`033A<C04DC000^4`0341<C02XC00<04a<01a<00`0C00034`0301<C030C00<=4a<01a<00a0C

4`2V4`0301<C02TC0Pe54`00;A<00a0C4`0/4`0301<C00PC00@04a<C0P0b4`033A<C00LC00<@4a<0

YA<00`0C4`0[4`033A<C048C000/4`0341<C02dC00<04a<01Q<200@C00<04a<0<A<00`dC4`084`03

41<C0:@C00<04a<0;1<23D8C000[4`0341<C02dC00<04`001a<00`0C4`034`0301<C038C00<=4a<0

21<00a0C4`2S4`80;a<00`dC4`0o4`00:Q<00a0C4`0_4`0301<C00HC0`034`0301<C03<C00<=4a<0

21<00a0C4`2R4`0301<C02lC0Pdo4`00:A<00a0C4`0o4`80=1<00`dC4`094`0341<C0:4C00<04a<0

<A<23CdC000X4`0341<C040C00<04a<0=1<00`dC4`094`0341<C0:0C00<04a<0<a<23C/C000W4`03

41<C044C00<04a<0=A<00`dC4`094`0341<C09lC0P0f4`8=>A<002HC00<@4a<0@Q<00`0C4`0e4`03

3A<C00XC00<@4a<0WQ<00`0C4`0g4`8==a<002DC00<@4a<0@a<203LC00<=4a<02Q<00a0C4`2M4`03

01<C03TC0Pde4`0091<00a0C4`144`0301<C03LC00<=4a<02Q<00a0C4`2L4`0301<C03/C0Pdc4`00

8a<00a0C4`154`0301<C03LC00<=4a<02a<00a0C4`2K4`0301<C03dC0Pda4`008a<00a0C4`154`03

01<C03PC00<=4a<02a<00a0C4`2J4`80@1<23BlC000R4`0341<C04HC0P0i4`033A<C00`C00<@4a<0

VA<00`0C4`114`<=;1<0024C00<@4a<0Aa<00`0C4`0i4`033A<C00`C00<@4a<0TQ<300<C00<04a<0

A1<23BXC000P4`0341<C04PC00<04a<0>Q<00`dC4`0<4`0341<C094C00<04a<00a<00`0C4`164`03

3A<C02LC000O4`0341<C04TC00<04a<0>Q<00`dC4`0=4`0341<C094C00<04a<00Q<204PC0PdW4`00

7Q<00a0C4`1:4`80?1<00`dC4`0=4`0341<C090C00<04a<00Q<00`0C4`194`033A<C02@C000M4`03

41<C04/C00<04a<0?1<00`dC4`0=4`0341<C08hC00<04`000a<00`0C4`1:4`8=91<001`C00<@4a<0

C1<00`0C4`0l4`033A<C00hC00<@4a<0SQ<00`0C4`024`0301<C04`C0`dQ4`006a<00a0C4`174`80

11<00`0C4`0m4`033A<C00hC00<@4a<0TQ<00`0C4`1?4`<=7Q<001XC00<@4a<0BQ<01@0C4a<003lC

00<=4a<03a<00a0C4`2A4`80Da<23A`C000I4`0341<C04XC00<04a<00Q<203lC00<=4a<03Q<00a0C

4`2A4`0301<C05@C0PdJ4`00Ia<00`0C4`3W4`0301<C05HC0PdH4`00IA<00`0C003Y4`0301<C070C

001V4`0301<C0>PC0P1a4`00;1<30?lC8a<00`0C4`1`4`00;1<00`0C4`3o4b<C00<04a<0L1<002dC

00<04a<01A<00`0C4`3o4hdC000]4`0401<C4`<000@C01<C0`3o4hXC000/4`0301<0008C0P024`03

01<C008C00<04a<0oa>84`00;A<00`0C4`034`0401<C008C00<04a<0oa>94`00<a<0100C4`034`03

01<C00HC00<04a<09A<302dC00<04a<0oa<W4`007A<300034`00008031<300@C0`084`0301<C02@C

00@04a<04A<300034`0000800Q<00`0C4`024`0301<C008C00<04a<01A<0100C4a<5008C00<04a<0

0Q<00`0C4`024`0301<C00@C0P3;4`0301<C038C00<04a<021<001`C00@04a<091<00`0C4`0S4`04

01<C010C00@04a<01Q<00`0C00074`0301<000@C1@034`0301<C00HC00<04`000Q<00`0C00044`03

01<C0<<C00<04a<011<00`0C4`0C4`0301<C01hC00<04a<01a<001`C00D04a<04`0400034`0001P0

:a<3010C00D04a<04`0400044`0C00TC00<04a<011<00`0C4`034`0301<C00PC00H04a<04`044`03

01<C0;4C00@04a<C10024`801Q<00`0C4`034`0301<C008C00<04a<00Q<00`0C4`024`0301<C00DC

00@04a<C1@024`0301<C008C00<04a<00Q<00`0C4`044`8011<0100C4a<2004C0@0100007A<304dC

00<04a<03a<300HC00<04`001a<200LC00<04a<00a<00`0C4`064`8011<00`0C4`034`0301<C0;0C

00<04`001a<00`0C4`044`D00a<01`0C4a<04`001a<00`0C00044`D00a<00`0C4`064`0301<0008C

00<04`0011<00`0C4`044`0301<C008C00<04`000A<001lC00<04a<0BQ<201<C00<04a<011<00`0C

00074`0301<C00`C00<04a<01Q<00`0C4`024`0301<000@C00<04`00/1<00`0C00024`@000<C01<0

1a<00`0C4`034`0701<C4`0C00094`0301<C00@C00<04a<00a<00`0C4`084`0601<C01<011<00`0C

4`044`0301<C00<C0@014`4C000N4`80H1<200LC00<04a<01Q<300/C0P084`<00a<00`0C4`034`<0

UQ<200034`0001DC00<04`001a<00`0C4`064`0301<C00<C00L04a<C01<000LC0P074`0301<C00<C

00<04a<01Q<200@C00<04a<00a<00`0C4`044`0301<C00<C0@014`4C003o4e4C00<04`005Q<00`0C

00074`0301<000dC00H04a<04`074`0301<C00`C00<04a<01Q<00`0C4`024`0301<000@C00<04`00

0a<00`0C4`034`0301<0004C000Y4`801Q<20?lC7a<00`0C4`0F4`0301<C00HC0`0>4`0401<C00PC

0`0;4`8021<300<C00<04a<00a<3008C00<04a<00a<2004C0@010000:a<00`0C4`024`0301<C0?lC

7a<00`0C4`1`4`00:Q<00`0C4`034`0301<C00DC00<04a<0oa<F4`0301<0074C000[4`0301<C008C

00<04a<00Q<400<C0`3o4a4C0P000a<0001`4`00:A<00`0C00044`0301<0008C0P000a<04`044`03

01<C0?lCQ1<002XC00<04a<00a<300@C00<04`000a<00`0C4`3o4hDC000g4`0301<000@C00<04a<0

oa>44`00=A<300@C0`3o4hHC003o4lDC003o4lDC003o4lDC003o4lDC003o4lDC0000\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.51952, -1.73595, 0.0222739, 0.0222739}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -84.5 0 ]

[.5 .96488 84.5 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -145.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.575) show

222.250000 19.500000 moveto

(C) show

227.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.27324 0 m

.30316 .04711 L

.34309 .11 L

.3815 .1705 L

.42237 .23487 L

.46172 .29685 L

.49955 .35644 L

.53984 .41989 L

.57861 .48096 L

.61984 .54588 L

.65954 .60842 L

.69774 .66858 L

.73838 .7326 L

.77751 .79422 L

.81909 .85972 L

.85916 .92282 L

s

.85916 .92282 m

.87793 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.386348 0.238095 [

[.02381 .37385 -6 -9 ]

[.02381 .37385 6 0 ]

[.2619 .37385 -6 -9 ]

[.2619 .37385 6 0 ]

[.7381 .37385 -3 -9 ]

[.7381 .37385 3 0 ]

[.97619 .37385 -3 -9 ]

[.97619 .37385 3 0 ]

[1.025 .38635 0 -8 ]

[1.025 .38635 9 8 ]

[.4875 .02921 -24 -4.5 ]

[.4875 .02921 0 4.5 ]

[.4875 .14825 -12 -4.5 ]

[.4875 .14825 0 4.5 ]

[.4875 .2673 -24 -4.5 ]

[.4875 .2673 0 4.5 ]

[.4875 .5054 -18 -4.5 ]

[.4875 .5054 0 4.5 ]

[.4875 .62444 -6 -4.5 ]

[.4875 .62444 0 4.5 ]

[.4875 .74349 -18 -4.5 ]

[.4875 .74349 0 4.5 ]

[.4875 .86254 -6 -4.5 ]

[.4875 .86254 0 4.5 ]

[.5 .94298 -4.5 0 ]

[.5 .94298 4.5 16 ]

[.5 .93048 -137 0 ]

[.5 .93048 137 16 ]

[ 0 0 0 0 ]

[ 1 .91798 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .38635 m

.02381 .3926 L

s

[(-2)] .02381 .37385 0 1 Mshowa

.2619 .38635 m

.2619 .3926 L

s

[(-1)] .2619 .37385 0 1 Mshowa

.7381 .38635 m

.7381 .3926 L

s

[(1)] .7381 .37385 0 1 Mshowa

.97619 .38635 m

.97619 .3926 L

s

[(2)] .97619 .37385 0 1 Mshowa

.125 Mabswid

.07143 .38635 m

.07143 .3901 L

s

.11905 .38635 m

.11905 .3901 L

s

.16667 .38635 m

.16667 .3901 L

s

.21429 .38635 m

.21429 .3901 L

s

.30952 .38635 m

.30952 .3901 L

s

.35714 .38635 m

.35714 .3901 L

s

.40476 .38635 m

.40476 .3901 L

s

.45238 .38635 m

.45238 .3901 L

s

.54762 .38635 m

.54762 .3901 L

s

.59524 .38635 m

.59524 .3901 L

s

.64286 .38635 m

.64286 .3901 L

s

.69048 .38635 m

.69048 .3901 L

s

.78571 .38635 m

.78571 .3901 L

s

.83333 .38635 m

.83333 .3901 L

s

.88095 .38635 m

.88095 .3901 L

s

.92857 .38635 m

.92857 .3901 L

s

.25 Mabswid

0 .38635 m

1 .38635 L

s

gsave

1.025 .38635 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .02921 m

.50625 .02921 L

s

[(-1.5)] .4875 .02921 1 0 Mshowa

.5 .14825 m

.50625 .14825 L

s

[(-1)] .4875 .14825 1 0 Mshowa

.5 .2673 m

.50625 .2673 L

s

[(-0.5)] .4875 .2673 1 0 Mshowa

.5 .5054 m

.50625 .5054 L

s

[(0.5)] .4875 .5054 1 0 Mshowa

.5 .62444 m

.50625 .62444 L

s

[(1)] .4875 .62444 1 0 Mshowa

.5 .74349 m

.50625 .74349 L

s

[(1.5)] .4875 .74349 1 0 Mshowa

.5 .86254 m

.50625 .86254 L

s

[(2)] .4875 .86254 1 0 Mshowa

.125 Mabswid

.5 .05302 m

.50375 .05302 L

s

.5 .07682 m

.50375 .07682 L

s

.5 .10063 m

.50375 .10063 L

s

.5 .12444 m

.50375 .12444 L

s

.5 .17206 m

.50375 .17206 L

s

.5 .19587 m

.50375 .19587 L

s

.5 .21968 m

.50375 .21968 L

s

.5 .24349 m

.50375 .24349 L

s

.5 .29111 m

.50375 .29111 L

s

.5 .31492 m

.50375 .31492 L

s

.5 .33873 m

.50375 .33873 L

s

.5 .36254 m

.50375 .36254 L

s

.5 .41016 m

.50375 .41016 L

s

.5 .43397 m

.50375 .43397 L

s

.5 .45778 m

.50375 .45778 L

s

.5 .48159 m

.50375 .48159 L

s

.5 .52921 m

.50375 .52921 L

s

.5 .55302 m

.50375 .55302 L

s

.5 .57682 m

.50375 .57682 L

s

.5 .60063 m

.50375 .60063 L

s

.5 .64825 m

.50375 .64825 L

s

.5 .67206 m

.50375 .67206 L

s

.5 .69587 m

.50375 .69587 L

s

.5 .71968 m

.50375 .71968 L

s

.5 .7673 m

.50375 .7673 L

s

.5 .79111 m

.50375 .79111 L

s

.5 .81492 m

.50375 .81492 L

s

.5 .83873 m

.50375 .83873 L

s

.5 .0054 m

.50375 .0054 L

s

.5 .88635 m

.50375 .88635 L

s

.5 .91016 m

.50375 .91016 L

s

.25 Mabswid

.5 0 m

.5 .91798 L

s

gsave

.5 .94298 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .93048 -198 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.575) show

298.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

303.000000 15.000000 moveto

(L) show

310.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

317.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

324.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

329.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

333.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .91798 L

0 .91798 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .23141 m

.02576 .2314 L

.03158 .23136 L

.04116 .2313 L

.05435 .23121 L

.07092 .23109 L

.09058 .23093 L

.11299 .23075 L

.13779 .23052 L

.16453 .23024 L

.19277 .22992 L

.22201 .22953 L

.25177 .22908 L

.28152 .22855 L

.31076 .22793 L

.339 .22721 L

.36574 .2264 L

.39054 .22549 L

.41295 .22451 L

.43261 .22347 L

.44918 .22245 L

.46237 .2215 L

.47195 .22074 L

.47777 .22023 L

.47972 .22006 L

s

.47972 .22006 m

.48184 .21986 L

.48818 .21925 L

.49862 .21815 L

.51298 .2164 L

.53102 .21376 L

.55243 .2098 L

.57684 .20391 L

.60384 .19542 L

.63296 .18395 L

.66371 .16986 L

.69555 .15408 L

.72796 .13759 L

.76036 .12117 L

.7922 .10532 L

.82295 .09039 L

.85207 .07662 L

.87907 .06418 L

.90348 .05319 L

.92489 .04375 L

.94293 .03594 L

.95729 .02981 L

.96773 .0254 L

.97407 .02274 L

.97619 .02186 L

s

.47972 .46944 m

.48184 .44225 L

.48818 .4154 L

.49862 .38917 L

.51298 .36385 L

.53102 .33985 L

.55243 .3177 L

.57684 .29813 L

.60384 .28195 L

.63296 .26964 L

.66371 .26096 L

.69555 .25507 L

.72796 .25107 L

.76036 .24831 L

.7922 .24635 L

.82295 .24492 L

.85207 .24385 L

.87907 .24305 L

.90348 .24244 L

.92489 .24197 L

.94293 .24162 L

.95729 .24137 L

.96773 .2412 L

.97407 .2411 L

.97619 .24107 L

s

.47972 .46955 m

.48184 .49693 L

.48818 .5244 L

.49862 .55173 L

.51298 .57879 L

.53102 .60544 L

.55243 .63155 L

.57684 .657 L

.60384 .68167 L

.63296 .70545 L

.66371 .72823 L

.69555 .7499 L

.72796 .77038 L

.76036 .78956 L

.7922 .80738 L

.82295 .82374 L

.85207 .83857 L

.87907 .85182 L

.90348 .86342 L

.92489 .87332 L

.94293 .88148 L

.95729 .88787 L

.96773 .89245 L

.97407 .8952 L

.97619 .89612 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<00`0C4`1`4`00oa=B4`80LA<006@C1@3X4`0301<C070C001V4`0301<C0=LC1@024`03

01<C008C00<04a<00Q<00`0C4`1`4`00A1<00`dC4`0I4`<00a<00`0C4`024`80eA<00`0C4`064`03

01<000<C00<04a<0EA<33APC00154`033A<C01hC00<04a<00Q<00`0C4`3>4`<00a<00`0C4`084`04

01<C4`80E1<23A/C00154`033A<C01hC00<04a<00Q<00`0C4`3D4`0301<C00HC0P044`0301<C054C

0PdM4`00AQ<00`dC4`0L4`8011<00`0C4`3D4`0301<C00HC00<04a<00a<00`0C4`1?4`8=7a<004HC

00<=4a<08Q<20=@C0P084`<00a<00`0C4`1=4`8=8A<004LC00<=4a<08A<00`0C4`3S4`0301<C04/C

0PdS4`00B1<00`dC4`0P4`0301<C0><C0P1:4`8=9A<004PC00<=4a<081<00`0C4`3S4`0301<C04LC

0PdW4`00BA<00`dC4`0O4`80i1<00`0C4`144`<=:A<004XC00<=4a<07Q<00`0C4`3S4`0301<C048C

0Pd/4`00BQ<00`dC4`0N4`0301<C0><C0P114`8=;Q<004/C00<=4a<07A<00`0C4`3S4`0301<C03hC

0Pd`4`00C1<00`dC4`0L4`80i1<00`0C4`0l4`8=<Q<004`C00<=4a<071<00`0C4`3S4`0301<C03TC

0`dd4`00CA<00`dC4`0K4`0301<C0><C00<04a<0=Q<33CLC001=4`033A<C01/C00<04a<0ha<203DC

0Pdj4`00CQ<00`dC4`0J4`80i1<00`0C4`0b4`8=?1<004lC00<=4a<06A<00`0C4`3S4`0301<C030C

0Pdn4`00Ca<00`dC4`0:4`0301<C008C00<04a<00Q<00`0C4`024`0301<C0><C00<04a<0;Q<23D0C

001@4`033A<C00PC00<04`001a<00`0C00034`0301<C0><C0P0]4`8=@Q<0054C00<=4a<00Q<3008C

00<04`002A<0100C4a<20>@C00<04a<0:a<00`dC4`124`00DA<00`dC4`074`0301<000LC0P044`03

01<C0><C00<04a<0:A<23DDC001B4`033A<C00HC00<04`001a<00`0C4`034`0301<C0=`C1@024`03

01<C02PC00<=4a<0AA<005<C00<=4a<01Q<00`0C4`064`<00a<00`0C4`3N4`0301<C008C00<04a<0

9Q<23DPC001C4`033A<C01DC00<04a<0f1<300<C00<04a<00Q<202DC0Pe:4`00E1<00`dC4`0D4`80

ga<00`0C4`024`0301<C028C0Pe<4`00EA<00`dC4`0C4`0301<C0=hC00<04a<00Q<00`0C4`0P4`8=

CQ<005HC00<=4a<04Q<00`0C4`3M4`8011<00`0C4`0N4`8=D1<005HC00<=4a<04Q<00`0C4`3S4`80

71<33E8C001G4`033A<C014C0P3T4`0301<C01PC0`eE4`00F1<00`dC4`0@4`0301<C0><C00<04a<0

5A<33EPC000J4`<09A<5014C00<=4a<041<00`0C4`0T4`D091<309<C00<04a<04a<23E/C000J4`03

01<C02LC00<04a<04Q<00`dC4`0?4`0301<C02HC00<04a<091<00`0C4`2C4`0301<C010C0`eM4`00

5A<300<C00<04a<081<300<C00<04a<04a<00`dC4`0>4`809a<00`0C4`0U4`0301<C098C0P0?4`8=

H1<001/C00<04a<09Q<00`0C4`0C4`033A<C00hC00<04a<09Q<00`0C4`0U4`0301<C098C00<04a<0

2Q<43F8C000J4`0301<002LC00<04a<051<00`dC4`0=4`0301<C02HC00<04a<091<00`0C002C4`03

01<C00HC10eV4`006a<00`0C4`0U4`805Q<00`dC4`0=4`0301<C02DC0P0W4`0301<C098C00<04`d0

1PeZ4`00G1<00`dC4`0<4`80g1<:3G4C001M4`033A<C00/C00<04a<0`a<H3@PC00<04a<0L1<005dC

00<=4a<02a<00`0C4`1K4`80;1<j3B0C00<04a<0L1<005hC00<=4a<02Q<00`0C4`1J4`0301<C08HC

00<04a<0L1<001DCBP000`d0001P00HC00<04a<0QQ<00`0C4`134aD=61<001TC00<04a<01Q<00`0C

4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0501<C4`d0

0a<00`0C4`054`0341<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`03

01<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<021<00`0C4`264`80;A<G3BdC001P4`03

3A<C00PC00<@4a<0FQ<00`0C00264`0301<C02HC1Pe44`00HA<00`dC4`074`8@Fa<307LC00<04a<0

0Q<00`0C4`024`0301<C008C00<04a<081<63DXC001Q4`033A<C00LC0Q3D4`0301<000LC00<04`00

0a<00`0C4`0J4`H=D1<0068C00<=4a<01A<00a00403?4`<00Q<00`0C00094`0401<C4`805a<43EHC

001R4`033A<C00DC00<@0100e1<00`0C00074`8011<00`0C4`0D4`8=FQ<006<C00<=4a<011<00a00

403D4`0301<000LC00<04a<00a<00`0C4`0B4`8=G1<006@C00<=4a<00Q<01A0C000@0=@C00<04a<0

1Q<300<C00<04a<04A<00`dC4`1L4`00I1<00`dC4`024`0541<04a00ha<00`0C4`0?4`8=Ga<006DC

00T=4a<C41<04a00ha<200hC0PeQ4`00IQ<01PdC4a0C008C00<@4a<0h1<00`0C4`0<4`033A<C064C

001V4`053A<C41<00P000a<@4`3Q4`0301<C00/C00<=4a<0HQ<006LC00D=4a0C00024`0341<C0>0C

00<04a<02A<23FDC001W4`053A0C4`000a<00a0C4`3O4`802A<00`dC4`1U4`00J1<010dC4`034`03

41<C0=lC00<04a<01a<00`dC4`1V4`00J1<00a0=4`02008C00<@4a<0ga<00`0C4`064`033A<C06LC

001W4`0541<=4`0011<00a0C4`254`<0:A<502PC00<04a<01A<00`dC4`0P4`D0:A<301LC001L4`03

01<C008C00<04a<00Q<01P0@4a<=00@C00<@4a<0QA<00`0C4`0[4`0301<C02PC00<04a<011<00`dC

4`0S4`0301<C02TC00<04a<05a<005/C00<04`001a<00`0@00024`033@0C00<C00<@4a<0P1<300<C

00<04a<091<300<C00<04a<0:1<200@C00<=4a<091<00`0C4`0Z4`0301<C01HC001K4`0301<000PC

00<@01<00Q<00`d04`034`0341<C08DC00<04a<0:Q<00`0C4`0X4`0301<C008C00<=4a<09A<00`0C

4`0Z4`0301<C01HC001K4`0301<000LC00<041<00a<00`0=4`034`0341<C08@C00<04`00:a<00`0C

4`0X4`0501<C4`d0:1<00`0C4`0Y4`0301<001LC001K4`0301<000LC00<@4a<00a<00`0=4`044`03

41<C08@C00<04a<0:A<202XC00D04a<C3@0W4`80;1<00`0C4`0F4`00G1<00`0C4`064`03400000<C

00<04`d011<00a0C4`3L4`8000<C3A<0KQ<006@C00<@4a<011<200034`dC008C00<@4a<0g1<00`0C

3@1`4`00I1<00a0C4`044`0401<C3@@C00<@4a<0fa<00`0C3@1`4`00Ha<00a0C4`054`0501<C4`d0

0a<00a0C4`3K4`0300dC06@C0P0:4`00Ha<00a0C4`054`0501<C4`d011<00a0C4`3J4`0300dC06<C

00<04a<02Q<0068C00<@4a<01Q<00`0C4`024`053A<C4a00OQ=N00033@0005d01Q<00`0C4`0:4`00

HQ<00a0C4`064`8011<01@dC4a<@084C00<04a<0:Q<00`0C4`0Z4`033A<C02XC00<04a<0:Q<00`0C

4`094`0301<C00XC001Q4`0341<C00LC00<04a<00a<01@dC4a<@0=XC00<=01<0I1<00`0C000:4`00

HA<00a0C4`074`0301<C00@C00@=4a<@fQ<00`d04`1T4`<02Q<0060C00<@4a<021<00`0C4`054`04

3A<C4=PC00@=4`00LA<0060C00<@4a<021<200HC00@=4a<@f1<00`dC001b4`00Ga<00a0C4`094`03

01<C00HC00@=4a<@ea<00`dC001b4`00Ga<00a0C4`094`0301<C00LC00<=4a00ea<00`dC001b4`00

GQ<00a0C4`0:4`0301<C00LC00@=4a<@eA<010dC4`1b4`00GQ<00a0C4`0:4`802A<00`dC403E4`03

3A<C0080LA<005dC00<@4a<02a<00`0C4`084`043A<C4=@C00@=4a<0LQ<005dC00<@4a<011<5008C

00<04a<02A<00`dC403D4`043A<C078C001L4`0341<C00LC00<04a<00Q<00`0C4`0:4`033A<@0=<C

00@=4a<0LQ<005/C00<@4a<021<00`0C4`024`802a<010dC4a3A4`043A<C4`80LA<005/C00<@4a<0

21<00`0C4`024`0301<C00/C00<=4a00dA<01@dC4a<0078C001J4`0341<C00TC00<04a<00Q<00`0C

4`0<4`033A<@0=0C00D=4a<C001b4`00FQ<00a0C4`084`8011<00`0C4`0<4`043A<C4<lC00D=4a<C

001b4`00FA<00a0C4`0?4`803Q<00`dC403?4`053A<C4`00LQ<005PC00<@4a<041<00`0C4`0>4`03

3A<@0<lC00<=4a<00P1a4`00F1<00a0C4`0@4`0301<C00hC00@=4a<@cQ<010dC4`1b4`00Ea<00a0C

4`0A4`0301<C00lC00<=4a00`Q<00`0C4`024`0301<C008C00<04`d00Q<00`0C4`1`4`00EQ<00a0C

4`0B4`8041<010dC4a304`0301<000LC00@04`0=0Q<00`0C4`1`4`00EQ<00a0C4`0B4`0301<C010C

00@=4a<@_a<00`0C00094`0400dC4`80LA<005DC00<@4a<04a<00`0C4`0A4`033A<@0;lC00<04`00

1a<200054`dC4`00LQ<005@C00<@4a<051<00`0C4`0A4`043A<C4;hC00<04`001a<01`0C4a<=4`00

LQ<005<C00<@4a<05A<201<C00<=4a00_a<00`0C4`064`<000@C3A<0LQ<005<C00<@4a<05A<00`0C

4`0C4`033A<@0</C00<=4`00LQ<0058C00<@4a<05Q<00`0C4`0C4`043A<C4<XC00@=4`00LA<0054C

00<@4a<05a<00`0C4`0D4`033A<@0</C00<=01<0LA<0054C00<@4a<05a<201HC00<=4a00bQ<00`d0

4`1a4`00D1<00a0C4`0H4`0301<C01DC00<=4a00ba<00`dC4`1`4`00Ca<00a0C4`084`D00Q<00`0C

4`024`0301<C008C00<04a<05Q<00`dC403:4`033@0C070C001?4`0341<C00XC00<04a<01Q<00`0C

00034`0301<C01LC00<=4a00bA<00`0=4`1`4`00CQ<00a0C4`0;4`0301<C00PC00@04a<C0P0I4`03

3A<@0<PC00<03A<0L1<004dC00<@4a<031<00`0C4`064`8011<00`0C4`0H4`033A<@0<PC00<04`d0

L1<004`C00<@4a<03A<00`0C4`064`0301<C00<C00<04a<06A<00`dC40374`0301<=070C001<4`03

41<C00`C0P084`<00a<00`0C4`0J4`033A<@0<HC0P000a<=4`1^4`00Ba<00a0C4`0M4`806a<010dC

4a354`0501<C4`d0KQ<004XC00<@4a<07Q<00`0C4`0K4`033A<@0<DC00D04a<C3@1^4`00BQ<00a0C

4`0N4`0301<C01/C00@=4a<@a1<00`0C4`024`033A<C06/C00194`0341<C01lC00<04a<071<010dC

4a334`800a<00`dC4`1[4`00B1<00a0C4`0P4`807A<01@dC4a<@0<8C00<04a<00a<00`dC4`1Z4`00

Aa<00a0C4`0Q4`0301<C01dC00D=4a<C40314`0301<C00@C00<=4a<0JA<004LC00<@4a<08A<00`0C

4`0M4`053A<C4a00^Q<5008C00<04a<01A<00`dC4`1X4`00AQ<00a0C4`0R4`0301<C01hC00D=4a<C

402k4`0301<C008C00<04a<01A<00`dC4`1X4`00AA<00a0C4`0S4`807a<00`dC4`024`0341<C0;PC

00<04a<00Q<200LC00<=4a<0Ia<004@C00<@4a<091<00`0C4`0O4`033A<C008C00<@4a<0]a<00`0C

4`024`0301<C00LC00<=4a<0IQ<004@C00<@4a<091<00`0C4`0P4`053A<C4a00^A<00`0C4`024`03

01<C00PC00<=4a<0IA<004<C00<@4a<09A<00`0C4`0P4`033A<C008C00<@4a<0]A<200@C00<04a<0

2A<00`dC4`1T4`00@Q<00a0C4`0V4`0301<C024C00<=4a<00Q<00a0C4`2j4`802a<00`dC4`1S4`00

@A<00a0C4`0W4`808a<00`dC4`024`0341<C0;TC00<04a<02a<00`dC4`1R4`00@1<00a0C4`0X4`03

01<C028C00<=4a<00a<00a0C4`2h4`0301<C00`C00<=4a<0HA<0040C00<@4a<08Q<300<C00<04a<0

8a<00`dC4`034`0341<C0;LC00<04a<03A<00`dC4`1P4`00?a<00a0C4`0S4`0301<C00<C00<04a<0

8a<00`dC4`034`0341<C0;LC00<04a<03Q<23F0C000n4`0341<C02DC00<04a<00Q<202DC00<=4a<0

0a<00a0C4`2f4`804A<00`dC4`1M4`00?A<00a0C4`0V4`0301<C008C00<04a<09A<00`dC4`034`03

41<C0;DC00<04a<04A<00`dC4`1L4`00?A<00a0C4`0U4`0301<000<C00<04a<09A<00`dC4`044`03

41<C0;@C00<04a<04Q<00`dC4`1K4`00?1<00a0C4`0W4`0301<C008C00<04a<09Q<00`dC4`044`03

41<C0;<C00<04a<04a<00`dC4`1J4`00>a<00a0C4`0]4`80:1<00`dC4`044`0341<C0;8C0P0E4`03

3A<C05TC000j4`0341<C02hC00<04a<09a<00`dC4`044`0341<C0;8C00<04a<05A<00`dC4`1H4`00

>Q<00a0C4`0^4`0301<C02PC00<=4a<011<00a0C4`2a4`0301<C01HC00<=4a<0Ea<003TC00<@4a<0

;a<00`0C4`0Y4`033A<C00@C00<@4a<0/1<00`0C4`0G4`8=Ea<003PC00<@4a<0<1<202XC00<=4a<0

1A<00a0C4`2_4`0301<C01TC00<=4a<0E1<003LC00<@4a<0<A<00`0C4`0Z4`033A<C00@C00<@4a<0

[a<201/C0PeD4`00=a<00a0C4`0a4`0301<C02/C00<=4a<011<00a0C4`2^4`0301<C01`C00<=4a<0

DA<003HC00<@4a<0<Q<00`0C4`0/4`033A<C00@C00<@4a<0W1<5008C00<04a<00Q<00`0C4`024`03

01<C01dC0PeA4`00=A<00a0C4`0c4`80;A<00`dC4`054`0341<C09dC00<04a<01Q<00`0C00034`03

01<C01lC00<=4a<0CQ<003@C00<@4a<0=1<00`0C4`0]4`033A<C00DC00<@4a<0W1<00`0C4`084`04

01<C4`808A<23DhC000c4`0341<C03DC00<04a<0;Q<00`dC4`054`0341<C09/C00<04a<01Q<200@C

00<04a<08Q<00`dC4`1;4`00<Q<00a0C4`0f4`0301<C02hC00<=4a<01A<00a0C4`2K4`0301<C00HC

00<04a<00a<00`0C4`0S4`8=Ba<0034C00<@4a<0=a<2030C00<=4a<01A<00a0C4`2I4`8021<300<C

00<04a<09A<00`dC4`184`00<1<00a0C4`0h4`0301<C02lC00<=4a<01Q<00a0C4`2X4`809a<23DPC

000_4`0341<C02TC0`034`0301<C008C00<04a<00Q<00`0C4`0`4`033A<C00HC00<@4a<0Ya<00`0C

4`0X4`033A<C04DC000^4`0341<C02XC00<04a<01a<00`0C00034`0301<C030C00<=4a<01a<00a0C

4`2V4`0301<C02TC0Pe54`00;A<00a0C4`0/4`0301<C00PC00@04a<C0P0b4`033A<C00LC00<@4a<0

YA<00`0C4`0[4`033A<C048C000/4`0341<C02dC00<04a<01Q<200@C00<04a<0<Q<00`dC4`074`03

41<C0:@C00<04a<0;1<23D8C000[4`0341<C02dC00<04`001a<00`0C4`034`0301<C038C00<=4a<0

21<00a0C4`2S4`80;a<00`dC4`0o4`00:Q<00a0C4`0_4`0301<C00HC0`034`0301<C03<C00<=4a<0

21<00a0C4`2R4`0301<C02lC0Pdo4`00:A<00a0C4`0o4`80=1<00`dC4`094`0341<C0:4C00<04a<0

<A<23CdC000X4`0341<C040C00<04a<0=1<00`dC4`094`0341<C0:0C00<04a<0<a<23C/C000W4`03

41<C044C00<04a<0=A<00`dC4`094`0341<C09lC0P0f4`8=>A<002HC00<@4a<0@Q<00`0C4`0e4`03

3A<C00XC00<@4a<0WQ<00`0C4`0g4`8==a<002DC00<@4a<0@a<203LC00<=4a<02Q<00a0C4`2M4`03

01<C03TC0Pde4`0091<00a0C4`144`0301<C03LC00<=4a<02Q<00a0C4`2L4`0301<C03/C0Pdc4`00

8a<00a0C4`154`0301<C03LC00<=4a<02a<00a0C4`2K4`0301<C03dC0Pda4`008a<00a0C4`154`03

01<C03PC00<=4a<02a<00a0C4`2J4`80@1<33BhC000R4`0341<C04HC0P0j4`033A<C00/C00<@4a<0

VA<00`0C4`124`8=;1<0024C00<@4a<0Aa<00`0C4`0j4`033A<C00/C00<@4a<0TQ<300<C00<04a<0

A1<23BXC000P4`0341<C04PC00<04a<0>Q<00`dC4`0<4`0341<C094C00<04a<00a<00`0C4`164`03

3A<C02LC000O4`0341<C04TC00<04a<0>a<00`dC4`0<4`0341<C094C00<04a<00Q<204PC0PdW4`00

7Q<00a0C4`1:4`80?1<00`dC4`0=4`0341<C090C00<04a<00Q<00`0C4`194`033A<C02@C000M4`03

41<C04/C00<04a<0?1<00`dC4`0=4`0341<C08hC00<04`000a<00`0C4`1:4`8=91<001`C00<@4a<0

C1<00`0C4`0l4`033A<C00hC00<@4a<0SQ<00`0C4`024`0301<C04`C0`dQ4`006a<00a0C4`174`80

11<00`0C4`0m4`033A<C00hC00<@4a<0TQ<00`0C4`1?4`<=7Q<001XC00<@4a<0BQ<01@0C4a<003lC

00<=4a<03a<00a0C4`2A4`80Da<23A`C000I4`0341<C04XC00<04a<00Q<203lC00<=4a<03Q<00a0C

4`2A4`0301<C05@C0PdJ4`00Ia<00`0C4`3W4`0301<C05HC0PdH4`00IA<00`0C003Y4`0301<C070C

001V4`0301<C0>PC0P1a4`00:Q<30?lC9A<00`0C4`1`4`00:Q<00`0C4`3o4bDC00<04a<0L1<002/C

00<04a<011<00`0C4`3o4i0C000[4`0401<C4`@00a<30?lCS1<002XC00<04`000Q<200034`0C00@C

00<04a<0oa>:4`00:a<00`0C4`034`0301<000<C00<04a<0oa>;4`00<A<00`0C00044`0301<C00HC

00<04a<09a<302/C00<04a<0oa<Y4`006a<300034`00008031<300@C0`084`0301<C02HC00@04a<0

3a<300034`0000800Q<00`0C4`024`0301<C008C00<04a<01A<0100C4a<5008C00<04a<00Q<00`0C

4`024`0301<C008C00<04a<011<20<DC00<04a<0=a<00`0C4`064`006Q<0100C4`0T4`0301<C02DC

00@04a<03Q<0100C4`064`0301<000LC00<04`0011<500<C00<04a<01Q<00`0C00034`0701<C4`0C

00044`0301<C0;dC00<04a<011<00`0C4`0C4`0301<C02<C00<04a<01A<001XC00D04a<04`040003

4`0001P0;A<300hC00D04a<04`0400044`0C00TC00<04a<011<00`0C4`034`0301<C00PC00D04a<C

00054`0301<C008C00<04a<0Za<0100C4a<4008C0P064`0301<C00<C00<04a<00Q<00`0C4`024`03

01<C008C00<04a<01A<0100C4a<5008C00<04a<00Q<00`0C4`024`0301<C008C00<04a<011<200@C

00@04a<C0P014`006a<304lC00<04a<03A<300HC00<04`001a<200LC00<04a<00a<00`0C4`064`80

1A<00`0C4`0200DC00<04a<0ZQ<00`0C00074`0301<C00@C1@034`0701<C4`0C00074`0301<000@C

1@034`0301<C00HC00<04`000a<01`0C4a<04`0011<00`0C4`044`0301<C008C0@014`007A<00`0C

4`1<4`804A<00`0C4`044`0301<000LC00<04a<031<00`0C4`064`0301<C008C00<04`000Q<00`0C

4`044`0301<00:XC00<04`000Q<400034`0C00LC00<04a<00a<01`0C4a<04`002A<00`0C4`044`03

01<C00<C00<04a<021<01@0C4a<000DC00<04a<00Q<00`0C4`044`0301<C00<C0@0001`C0P1P4`80

1a<00`0C4`064`<02a<200PC0`024`<00Q<300@C0`2C4`8000<C00004Q<00`0C00074`0301<C00HC

00<04a<00a<01`0C4a<04`001a<200LC00<04a<00a<00`0C4`064`801A<00`0C4`0200DC00<04a<0

11<00`0C4`034`40003o4e4C00<04`004a<00`0C00074`0301<000dC00H04a<04`074`0301<C00`C

00<04a<01Q<00`0C4`024`0301<0008C00<04a<011<00`0C00034`0301<C00<C0@014`009Q<200HC

0P3o4b8C00<04a<04a<00`0C4`064`<03Q<0100C4`084`<02a<200PC0`024`<00Q<300@C0`024`03

01<C00<C0P014`00:1<00`0C4`024`0301<C0?lC8Q<00`0C4`1`4`009a<00`0C4`034`0301<C00HC

00<04a<0oa<H4`0301<0074C000X4`0301<C008C00<04a<00Q<300044`0C4`<0oa<D4`8000<C0000

L1<002HC00<04`0011<00`0C00024`800Q<00`0C4`024`0301<C0?lCQa<002LC00<04a<00a<300@C

00@04a<00Q<00`0C4`3o4hPC000d4`0401<C00<C00<04a<0oa>74`00<Q<300@C0`3o4hTC003o4lDC

003o4lDC003o4lDC003o4lDC003o4lDC0000\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.5063, -1.73108, 0.0222347, 0.0222347}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -82 0 ]

[.5 .96488 82 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -143 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.57) show

217.250000 19.500000 moveto

(C) show

222.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.27252 0 m

.30316 .0481 L

.34309 .11079 L

.3815 .1711 L

.42237 .23526 L

.46172 .29704 L

.49955 .35644 L

.53984 .41969 L

.57861 .48056 L

.61984 .54528 L

.65954 .60763 L

.69774 .66759 L

.73838 .7314 L

.77751 .79284 L

.81909 .85812 L

.85916 .92103 L

s

.85916 .92103 m

.87913 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.385227 0.238095 [

[.02381 .37273 -6 -9 ]

[.02381 .37273 6 0 ]

[.2619 .37273 -6 -9 ]

[.2619 .37273 6 0 ]

[.7381 .37273 -3 -9 ]

[.7381 .37273 3 0 ]

[.97619 .37273 -3 -9 ]

[.97619 .37273 3 0 ]

[1.025 .38523 0 -8 ]

[1.025 .38523 9 8 ]

[.4875 .02808 -24 -4.5 ]

[.4875 .02808 0 4.5 ]

[.4875 .14713 -12 -4.5 ]

[.4875 .14713 0 4.5 ]

[.4875 .26618 -24 -4.5 ]

[.4875 .26618 0 4.5 ]

[.4875 .50427 -18 -4.5 ]

[.4875 .50427 0 4.5 ]

[.4875 .62332 -6 -4.5 ]

[.4875 .62332 0 4.5 ]

[.4875 .74237 -18 -4.5 ]

[.4875 .74237 0 4.5 ]

[.4875 .86142 -6 -4.5 ]

[.4875 .86142 0 4.5 ]

[.5 .94131 -4.5 0 ]

[.5 .94131 4.5 16 ]

[.5 .92881 -134.5 0 ]

[.5 .92881 134.5 16 ]

[ 0 0 0 0 ]

[ 1 .91631 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .38523 m

.02381 .39148 L

s

[(-2)] .02381 .37273 0 1 Mshowa

.2619 .38523 m

.2619 .39148 L

s

[(-1)] .2619 .37273 0 1 Mshowa

.7381 .38523 m

.7381 .39148 L

s

[(1)] .7381 .37273 0 1 Mshowa

.97619 .38523 m

.97619 .39148 L

s

[(2)] .97619 .37273 0 1 Mshowa

.125 Mabswid

.07143 .38523 m

.07143 .38898 L

s

.11905 .38523 m

.11905 .38898 L

s

.16667 .38523 m

.16667 .38898 L

s

.21429 .38523 m

.21429 .38898 L

s

.30952 .38523 m

.30952 .38898 L

s

.35714 .38523 m

.35714 .38898 L

s

.40476 .38523 m

.40476 .38898 L

s

.45238 .38523 m

.45238 .38898 L

s

.54762 .38523 m

.54762 .38898 L

s

.59524 .38523 m

.59524 .38898 L

s

.64286 .38523 m

.64286 .38898 L

s

.69048 .38523 m

.69048 .38898 L

s

.78571 .38523 m

.78571 .38898 L

s

.83333 .38523 m

.83333 .38898 L

s

.88095 .38523 m

.88095 .38898 L

s

.92857 .38523 m

.92857 .38898 L

s

.25 Mabswid

0 .38523 m

1 .38523 L

s

gsave

1.025 .38523 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .02808 m

.50625 .02808 L

s

[(-1.5)] .4875 .02808 1 0 Mshowa

.5 .14713 m

.50625 .14713 L

s

[(-1)] .4875 .14713 1 0 Mshowa

.5 .26618 m

.50625 .26618 L

s

[(-0.5)] .4875 .26618 1 0 Mshowa

.5 .50427 m

.50625 .50427 L

s

[(0.5)] .4875 .50427 1 0 Mshowa

.5 .62332 m

.50625 .62332 L

s

[(1)] .4875 .62332 1 0 Mshowa

.5 .74237 m

.50625 .74237 L

s

[(1.5)] .4875 .74237 1 0 Mshowa

.5 .86142 m

.50625 .86142 L

s

[(2)] .4875 .86142 1 0 Mshowa

.125 Mabswid

.5 .05189 m

.50375 .05189 L

s

.5 .0757 m

.50375 .0757 L

s

.5 .09951 m

.50375 .09951 L

s

.5 .12332 m

.50375 .12332 L

s

.5 .17094 m

.50375 .17094 L

s

.5 .19475 m

.50375 .19475 L

s

.5 .21856 m

.50375 .21856 L

s

.5 .24237 m

.50375 .24237 L

s

.5 .28999 m

.50375 .28999 L

s

.5 .3138 m

.50375 .3138 L

s

.5 .33761 m

.50375 .33761 L

s

.5 .36142 m

.50375 .36142 L

s

.5 .40904 m

.50375 .40904 L

s

.5 .43285 m

.50375 .43285 L

s

.5 .45666 m

.50375 .45666 L

s

.5 .48047 m

.50375 .48047 L

s

.5 .52808 m

.50375 .52808 L

s

.5 .55189 m

.50375 .55189 L

s

.5 .5757 m

.50375 .5757 L

s

.5 .59951 m

.50375 .59951 L

s

.5 .64713 m

.50375 .64713 L

s

.5 .67094 m

.50375 .67094 L

s

.5 .69475 m

.50375 .69475 L

s

.5 .71856 m

.50375 .71856 L

s

.5 .76618 m

.50375 .76618 L

s

.5 .78999 m

.50375 .78999 L

s

.5 .8138 m

.50375 .8138 L

s

.5 .83761 m

.50375 .83761 L

s

.5 .00427 m

.50375 .00427 L

s

.5 .88523 m

.50375 .88523 L

s

.5 .90904 m

.50375 .90904 L

s

.25 Mabswid

.5 0 m

.5 .91631 L

s

gsave

.5 .94131 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .92881 -195.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.57) show

293.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

298.000000 15.000000 moveto

(L) show

305.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

312.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

319.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

324.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

328.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .91631 L

0 .91631 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .22989 m

.02576 .22988 L

.03158 .22985 L

.04116 .22978 L

.05435 .2297 L

.07091 .22958 L

.09057 .22943 L

.11299 .22925 L

.13778 .22902 L

.16452 .22876 L

.19276 .22844 L

.222 .22806 L

.25175 .22762 L

.28151 .2271 L

.31075 .2265 L

.33898 .22581 L

.36573 .22502 L

.39052 .22414 L

.41293 .22318 L

.43259 .22218 L

.44916 .22119 L

.46235 .22027 L

.47193 .21953 L

.47775 .21904 L

.4797 .21887 L

s

.4797 .21887 m

.48182 .21868 L

.48816 .21809 L

.49859 .21702 L

.51296 .21533 L

.531 .21277 L

.55241 .20892 L

.57682 .20319 L

.60382 .19487 L

.63294 .18356 L

.66369 .16958 L

.69554 .15387 L

.72794 .13743 L

.76035 .12103 L

.79219 .10519 L

.82294 .09028 L

.85207 .07652 L

.87907 .06409 L

.90348 .05312 L

.92489 .04369 L

.94293 .03588 L

.95729 .02976 L

.96773 .02536 L

.97407 .0227 L

.97619 .02182 L

s

.4797 .46835 m

.48182 .44118 L

.48816 .41433 L

.49859 .38809 L

.51296 .36275 L

.531 .3387 L

.55241 .31647 L

.57682 .29678 L

.60382 .28046 L

.63294 .26803 L

.66369 .25926 L

.69554 .25333 L

.72794 .24932 L

.76035 .24656 L

.79219 .24461 L

.82294 .24319 L

.85207 .24213 L

.87907 .24133 L

.90348 .24073 L

.92489 .24026 L

.94293 .23992 L

.95729 .23967 L

.96773 .2395 L

.97407 .2394 L

.97619 .23937 L

s

.4797 .46846 m

.48182 .49582 L

.48816 .52326 L

.49859 .55057 L

.51296 .5776 L

.531 .60422 L

.55241 .63029 L

.57682 .65571 L

.60382 .68035 L

.63294 .70409 L

.66369 .72684 L

.69554 .74848 L

.72794 .76893 L

.76035 .78809 L

.79219 .80588 L

.82294 .82222 L

.85207 .83703 L

.87907 .85026 L

.90348 .86184 L

.92489 .87173 L

.94293 .87988 L

.95729 .88625 L

.96773 .89083 L

.97407 .89358 L

.97619 .8945 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<2074C003o4e8C00<04a<0L1<006@C1@3X4`0301<C070C001V4`0301<C0=LC1@024`03

01<C008C00<04a<00Q<00`0C4`1`4`00A1<00`dC4`0I4`<00a<00`0C4`024`80eA<00`0C4`064`03

01<000<C00<04a<0EQ<23APC00154`033A<C01hC00<04a<00Q<00`0C4`3>4`<00a<00`0C4`084`04

01<C4`80E1<33AXC00154`033A<C01hC00<04a<00Q<00`0C4`3D4`0301<C00HC0P044`0301<C054C

0PdM4`00AQ<00`dC4`0L4`8011<00`0C4`3D4`0301<C00HC00<04a<00a<00`0C4`1?4`8=7a<004HC

00<=4a<08Q<20=@C0P084`<00a<00`0C4`1=4`8=8A<004LC00<=4a<08A<00`0C4`3S4`80C1<23B<C

00184`033A<C020C00<04a<0ha<00`0C4`194`8=9A<004PC00<=4a<081<00`0C4`3S4`0301<C04LC

0PdW4`00BA<00`dC4`0O4`80i1<00`0C4`144`<=:A<004XC00<=4a<07Q<00`0C4`3S4`0301<C048C

0Pd/4`00BQ<00`dC4`0N4`0301<C0><C0P114`8=;Q<004/C00<=4a<07A<00`0C4`3S4`0301<C03hC

0Pd`4`00C1<00`dC4`0L4`80i1<00`0C4`0l4`8=<Q<004`C00<=4a<071<00`0C4`3S4`0301<C03TC

0`dd4`00CA<00`dC4`0K4`0301<C0><C0P0g4`<==a<004dC00<=4a<06a<00`0C4`3S4`0301<C03@C

0Pdj4`00CQ<00`dC4`0J4`80i1<00`0C4`0b4`8=?1<004lC00<=4a<06A<00`0C4`3S4`0301<C030C

0Pdn4`00Ca<00`dC4`0:4`0301<C008C00<04a<00Q<00`0C4`024`0301<C0><C00<04a<0;Q<23D0C

001@4`033A<C00PC00<04`001a<00`0C00034`0301<C0><C0P0]4`8=@Q<0054C00<=4a<00Q<3008C

00<04`002A<0100C4a<20>@C00<04a<0:a<00`dC4`124`00DA<00`dC4`074`0301<000LC0P044`03

01<C0=`C1@024`0301<C02TC0Pe54`00DQ<00`dC4`064`0301<000LC00<04a<00a<00`0C4`3N4`03

01<C008C00<04a<0:1<00`dC4`154`00Da<00`dC4`064`0301<C00HC0`034`0301<C0=PC0`034`03

01<C008C0P0W4`8=B1<005<C00<=4a<05A<00`0C4`3N4`0301<C008C00<04a<091<23DXC001D4`03

3A<C01@C0P3O4`0301<C008C00<04a<08Q<23D`C001E4`033A<C01<C00<04a<0gA<200@C00<04a<0

81<23DhC001F4`033A<C018C00<04a<0ha<00`0C4`0N4`8=D1<005HC00<=4a<04Q<00`0C4`3S4`80

71<33E8C001G4`033A<C014C0P3T4`0301<C01PC0`eE4`00F1<00`dC4`0@4`0301<C0><C00<04a<0

5A<33EPC000J4`<09A<5014C00<=4a<041<00`0C4`0T4`D091<309<C00<04a<04a<23E/C000J4`03

01<C02LC00<04a<04Q<00`dC4`0?4`0301<C02HC00<04a<091<00`0C4`2C4`804A<33EdC000E4`<0

0a<00`0C4`0P4`<00a<00`0C4`0C4`033A<C00hC0P0W4`0301<C02DC00<04a<0TQ<00`0C4`0>4`8=

H1<001/C00<04a<09Q<00`0C4`0C4`033A<C00hC00<04a<09Q<00`0C4`0U4`0301<C098C00<04a<0

2Q<43F8C000J4`0301<002LC00<04a<051<00`dC4`0=4`0301<C02HC00<04a<091<00`0C002C4`03

01<C00HC10eV4`006a<00`0C4`0U4`805Q<00`dC4`0=4`0301<C02DC0P0W4`0301<C098C00<04`d0

1PeZ4`00G1<00`dC4`0<4`80fA<=3G4C001M4`033A<C00/C00<04a<0_A<K3@/C00<04a<0L1<005dC

00<=4a<02a<00`0C4`1K4`80;1<d3BHC00<04a<0L1<005hC00<=4a<02Q<00`0C4`1J4`0301<C08HC

00<04a<0L1<001DCBP000`d0001P00HC00<04a<0QQ<203lC6PdH4`006A<00`0C4`064`0301<C00DC

00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00D04a<C3@034`03

01<C00DC00<@4a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<0

1A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`084`0301<C08HC00<04a<0;1<B3C8C001P4`03

3A<C00PC00<@4a<0FQ<00`0C00264`0301<C024C2`e44`00HA<00`dC4`074`8@Fa<307LC00<04a<0

0Q<00`0C4`024`0301<C008C00<04a<07Q<33DlC001Q4`033A<C00LC0Q3D4`0301<000LC00<04`00

0a<00`0C4`0J4`@=DQ<0068C00<=4a<01A<00a00403?4`<00Q<00`0C00094`0401<C4`805a<43EHC

001R4`033A<C00DC00<@0100e1<00`0C00074`8011<00`0C4`0D4`8=FQ<006<C00<=4a<011<00a00

403D4`0301<000LC00<04a<00a<00`0C4`0B4`8=G1<006@C00<=4a<00Q<01A0C000@0=@C00<04a<0

1Q<300<C00<04a<04A<00`dC4`1L4`00I1<00`dC4`024`0541<04a00ha<2010C0PeO4`00IA<02@dC

4a<@4`0C403S4`0301<C00dC0PeQ4`00IQ<01PdC4a0C008C00<@4a<0h1<00`0C4`0<4`033A<C064C

001V4`053A<C41<00P000a<@4`3Q4`0301<C00XC0PeT4`00Ia<01@dC41<0008C00<@4a<0h1<00`0C

4`084`8=IQ<006LC00D=41<C00034`0341<C0=lC0P084`033A<C06HC001X4`043A<C00<C00<@4a<0

ga<00`0C4`064`033A<C06LC001X4`0340dC00800Q<00a0C4`3O4`0301<C00DC00<=4a<0J1<006LC

00D@4`dC00044`0341<C08DC0`0Y4`D0:1<00`0C4`054`033A<C020C1@0Y4`<05a<005`C00<04a<0

0Q<00`0C4`024`06010C4`d011<00a0C4`254`0301<C02/C00<04a<0:1<200DC00<=4a<08a<00`0C

4`0Y4`0301<C01LC001K4`0301<000LC00<040000Q<00`d04`034`0341<C080C0`034`0301<C02@C

0`034`0301<C02PC00<04a<00a<00`dC4`0T4`0301<C02XC00<04a<05Q<005/C00<04`0021<00a00

4`024`033@0C00<C00<@4a<0QA<00`0C4`0Z4`0301<C02PC00<04a<00Q<00`dC4`0U4`0301<C02XC

00<04a<05Q<005/C00<04`001a<00`0@4`034`0300dC00<C00<@4a<0Q1<00`0C000[4`0301<C02PC

00D04a<C3@0X4`0301<C02TC00<04`005a<005/C00<04`001a<00a0C4`034`0300dC00@C00<@4a<0

Q1<00`0C4`0Y4`80:Q<01@0C4a<=02LC0P0/4`0301<C01HC001L4`0301<C00HC00<@00000a<00`0C

3@044`0341<C0=`C0P000a<=4`1^4`00I1<00a0C4`044`8000<C3A<00Q<00a0C4`3L4`0301<=070C

001T4`0341<C00@C00@04a<=11<00a0C4`3K4`0301<=06@C0P0:4`00Ha<00a0C4`054`0501<C4`d0

0a<00a0C4`3K4`0300dC06<C00<04a<02Q<006<C00<@4a<01A<01@0C4a<=00@C00<@4a<0Na=P0003

3@0005`01Q<00`0C4`0:4`00HQ<00a0C4`064`0301<C008C00D=4a<C40224`0301<C00HC00<04a<0

1Q<00`0C4`064`0301<C00HC00<04a<01Q<00`0C4`064`0301<C00HC00<04a<01Q<00`0C4`064`03

01<C00HC00<=4a<01Q<00`0C4`064`0301<C00HC00<04a<01Q<00`0C4`064`0301<C00HC00<04a<0

1Q<00`0C4`064`0301<C00HC00<04a<01Q<00`0C4`094`0301<C00XC001R4`0341<C00HC0P044`05

3A<C4a00PA<00`0C4`0Z4`0301<C02XC00<=4a<0:Q<00`0C4`0Z4`0301<C00TC00<04`002Q<0064C

00<@4a<01a<00`0C4`034`053A<C4a00fQ<00`d04`1T4`<02Q<0064C00<@4a<01a<00`0C4`044`04

3A<C4=XC00<=01<0LA<0060C00<@4a<021<00`0C4`054`043A<C4=PC00@=4`00LA<0060C00<@4a<0

21<200HC00@=4a<@f1<00`dC001b4`00Ga<00a0C4`094`0301<C00HC00@=4a<@ea<00`dC001b4`00

Ga<00a0C4`094`0301<C00LC00<=4a00ea<00`dC001b4`00GQ<00a0C4`0:4`0301<C00LC00@=4a<@

eA<00`dC4`02074C001N4`0341<C00XC0P094`033A<@0=DC00@=4a<0LQ<005dC00<@4a<02a<00`0C

4`084`043A<C4=@C00@=4a<0LQ<005dC00<@4a<011<5008C00<04a<02A<00`dC403D4`043A<C078C

001L4`0341<C00LC00<04a<00Q<00`0C4`0:4`033A<@0=<C00@=4a<0LQ<005/C00<@4a<021<00`0C

4`024`802a<010dC4a3A4`043A<C4`80LA<005/C00<@4a<021<00`0C4`024`0301<C00/C00<=4a00

dA<01@dC4a<0078C001J4`0341<C00TC00<04a<00Q<00`0C4`0<4`033A<@0=0C00D=4a<C001b4`00

FQ<00a0C4`084`8011<00`0C4`0<4`043A<C4<lC00D=4a<C001b4`00FA<00a0C4`0?4`803Q<00`dC

403?4`043A<C4`80LA<005PC00<@4a<041<00`0C4`0>4`033A<@0<lC00@=4a<0LQ<005PC00<@4a<0

41<00`0C4`0>4`043A<C4<hC00@=4a<0LQ<005LC00<@4a<04A<00`0C4`0?4`033A<@0<8C00<04a<0

0Q<00`0C4`024`0301<=008C00<04a<0L1<005HC00<@4a<04Q<2010C00@=4a<@`1<00`0C00074`04

01<03@8C00<04a<0L1<005HC00<@4a<04Q<00`0C4`0@4`043A<C4;lC00<04`002A<0100=4a<2074C

001E4`0341<C01<C00<04a<04A<00`dC402o4`0301<000LC0P001A<=4a<0078C001D4`0341<C01@C

00<04a<04A<010dC4a2n4`0301<000LC00L04a<C3A<0078C001C4`0341<C01DC0P0C4`033A<@0;lC

00<04a<01Q<300044`dC078C001C4`0341<C01DC00<04a<04a<00`dC403;4`043A<0074C001B4`03

41<C01HC00<04a<04a<010dC4a3:4`033A<0078C001A4`0341<C01LC00<04a<051<00`dC403;4`03

3@0C074C001A4`0341<C01LC0P0F4`033A<@0<XC00<=01<0LA<0050C00<@4a<061<00`0C4`0E4`03

3A<@0</C00<=4a<0L1<004lC00<@4a<021<5008C00<04a<00Q<00`0C4`024`0301<C01HC00<=4a00

bQ<00`d04`1`4`00Ca<00a0C4`0:4`0301<C00HC00<04`000a<00`0C4`0G4`033A<@0<TC00<03A<0

L1<004hC00<@4a<02a<00`0C4`084`0401<C4`806A<00`dC40384`0300dC070C001=4`0341<C00`C

00<04a<01Q<200@C00<04a<061<00`dC40384`0301<=070C001<4`0341<C00dC00<04a<01Q<00`0C

4`034`0301<C01TC00<=4a00aa<00`0C3@1`4`00C1<00a0C4`0<4`8021<300<C00<04a<06Q<00`dC

40364`8000<C3A<0KQ<004/C00<@4a<07A<201/C00@=4a<@aA<01@0C4a<=06hC001:4`0341<C01hC

00<04a<06a<00`dC40354`0501<C4`d0KQ<004XC00<@4a<07Q<00`0C4`0K4`043A<C4<@C00<04a<0

0Q<00`dC4`1[4`00BA<00a0C4`0O4`0301<C01`C00@=4a<@`a<200<C00<=4a<0Ja<004PC00<@4a<0

81<201dC00D=4a<C40324`0301<C00<C00<=4a<0JQ<004LC00<@4a<08A<00`0C4`0M4`053A<C4a00

`A<00`0C4`044`033A<C06TC00174`0341<C024C00<04a<07A<01@dC4a<@0;XC1@024`0301<C00DC

00<=4a<0J1<004HC00<@4a<08Q<00`0C4`0N4`053A<C4a00^a<00`0C4`024`0301<C00DC00<=4a<0

J1<004DC00<@4a<08a<201lC00<=4a<00Q<00a0C4`2h4`0301<C008C0P074`033A<C06LC00144`03

41<C02@C00<04a<07a<00`dC4`024`0341<C0;LC00<04a<00Q<00`0C4`074`033A<C06HC00144`03

41<C02@C00<04a<081<01@dC4a<@0;TC00<04a<00Q<00`0C4`084`033A<C06DC00134`0341<C02DC

00<04a<081<00`dC4`024`0341<C0;DC0P044`0301<C00TC00<=4a<0I1<0048C00<@4a<09Q<00`0C

4`0Q4`033A<C008C00<@4a<0^Q<200/C00<=4a<0Ha<0044C00<@4a<09a<202<C00<=4a<00Q<00a0C

4`2i4`0301<C00/C00<=4a<0HQ<0040C00<@4a<0:1<00`0C4`0R4`033A<C00<C00<@4a<0^1<00`0C

4`0<4`033A<C064C00104`0341<C028C0`034`0301<C02<C00<=4a<00a<00a0C4`2g4`0301<C00dC

00<=4a<0H1<003lC00<@4a<08a<00`0C4`034`0301<C02<C00<=4a<00a<00a0C4`2g4`0301<C00hC

0PeP4`00?Q<00a0C4`0U4`0301<C008C0P0U4`033A<C00<C00<@4a<0]Q<2014C00<=4a<0GA<003dC

00<@4a<09Q<00`0C4`024`0301<C02DC00<=4a<00a<00a0C4`2e4`0301<C014C00<=4a<0G1<003dC

00<@4a<09A<00`0C00034`0301<C02DC00<=4a<011<00a0C4`2d4`0301<C018C00<=4a<0Fa<003`C

00<@4a<09a<00`0C4`024`0301<C02HC00<=4a<011<00a0C4`2c4`0301<C01<C00<=4a<0FQ<003/C

00<@4a<0;A<202PC00<=4a<011<00a0C4`2b4`805A<00`dC4`1I4`00>Q<00a0C4`0^4`0301<C02LC

00<=4a<011<00a0C4`2b4`0301<C01DC00<=4a<0F1<003XC00<@4a<0;Q<00`0C4`0X4`033A<C00@C

00<@4a<0/A<00`0C4`0F4`033A<C05LC000i4`0341<C02lC00<04a<0:A<00`dC4`044`0341<C0;0C

00<04a<05a<23ELC000h4`0341<C030C0P0Z4`033A<C00DC00<@4a<0[a<00`0C4`0I4`033A<C05@C

000g4`0341<C034C00<04a<0:Q<00`dC4`044`0341<C0:lC0P0K4`8=E1<003LC00<@4a<0<A<00`0C

4`0[4`033A<C00@C00<@4a<0[Q<00`0C4`0L4`033A<C054C000f4`0341<C038C00<04a<0;1<00`dC

4`044`0341<C09`C1@024`0301<C008C00<04a<00Q<00`0C4`0M4`8=DA<003DC00<@4a<0<a<202dC

00<=4a<01A<00a0C4`2M4`0301<C00HC00<04`000a<00`0C4`0O4`033A<C04hC000d4`0341<C03@C

00<04a<0;A<00`dC4`054`0341<C09`C00<04a<021<0100C4a<2024C0Pe>4`00<a<00a0C4`0e4`03

01<C02hC00<=4a<01A<00a0C4`2K4`0301<C00HC0P044`0301<C028C00<=4a<0Ba<0038C00<@4a<0

=Q<00`0C4`0^4`033A<C00DC00<@4a<0Va<00`0C4`064`0301<C00<C00<04a<08a<23D/C000a4`03

41<C03LC0P0`4`033A<C00DC00<@4a<0VA<200PC0`034`0301<C02DC00<=4a<0B1<0030C00<@4a<0

>1<00`0C4`0`4`033A<C00DC00<@4a<0Z1<00`0C4`0V4`8=B1<002lC00<@4a<0:A<300<C00<04a<0

0Q<00`0C4`024`0301<C030C00<=4a<01Q<00a0C4`2W4`80:A<00`dC4`154`00;Q<00a0C4`0Z4`03

01<C00LC00<04`000a<00`0C4`0a4`033A<C00HC00<@4a<0YQ<00`0C4`0Y4`8=AA<002dC00<@4a<0

;1<00`0C4`084`0401<C4`80<Q<00`dC4`074`0341<C0:DC00<04a<0:a<00`dC4`124`00;1<00a0C

4`0]4`0301<C00HC0P044`0301<C038C00<=4a<01a<00a0C4`2T4`0301<C02`C0Pe24`00:a<00a0C

4`0]4`0301<000LC00<04a<00a<00`0C4`0c4`033A<C00LC00<@4a<0Xa<202lC00<=4a<0?a<002XC

00<@4a<0;a<00`0C4`064`<00a<00`0C4`0c4`033A<C00PC00<@4a<0XQ<00`0C4`0_4`8=?a<002TC

00<@4a<0?a<203DC00<=4a<021<00a0C4`2Q4`0301<C034C0Pdm4`00:1<00a0C4`104`0301<C03DC

00<=4a<021<00a0C4`2P4`0301<C03<C0Pdk4`009a<00a0C4`114`0301<C03DC00<=4a<02A<00a0C

4`2O4`0301<C03DC0Pdi4`009Q<00a0C4`124`0301<C03HC00<=4a<02A<00a0C4`2N4`80>1<23CLC

000U4`0341<C04<C0P0h4`033A<C00TC00<@4a<0WA<00`0C4`0i4`8==A<002@C00<@4a<0A1<00`0C

4`0g4`033A<C00XC00<@4a<0W1<00`0C4`0k4`8=<a<002<C00<@4a<0AA<00`0C4`0h4`033A<C00XC

00<@4a<0Va<00`0C4`0m4`8=<A<002<C00<@4a<0AA<00`0C4`0h4`033A<C00/C00<@4a<0VQ<2040C

0`d^4`008Q<00a0C4`164`80>Q<00`dC4`0;4`0341<C09TC00<04a<0@Q<23B`C000Q4`0341<C04LC

00<04a<0>Q<00`dC4`0;4`0341<C09PC00<04a<0A1<23BXC000P4`0341<C04PC00<04a<0>Q<00`dC

4`0<4`0341<C094C0`034`0301<C04HC00<=4a<09a<001lC00<@4a<0BA<00`0C4`0k4`033A<C00`C

00<@4a<0T1<00`0C4`034`0301<C04LC0PdW4`007Q<00a0C4`1:4`80?1<00`dC4`0=4`0341<C090C

00<04a<00Q<204XC00<=4a<091<001dC00<@4a<0Ba<00`0C4`0l4`033A<C00dC00<@4a<0Sa<00`0C

4`024`0301<C04XC0PdT4`0071<00a0C4`1<4`0301<C03`C00<=4a<03Q<00a0C4`2=4`0301<000<C

00<04a<0C1<33B4C000K4`0341<C04LC0P044`0301<C03dC00<=4a<03Q<00a0C4`2=4`0301<C008C

00<04a<0Ca<43AdC000J4`0341<C04XC00D04a<C000o4`033A<C00lC00<@4a<0TA<205@C0PdK4`00

6A<00a0C4`1:4`0301<C008C0P0o4`033A<C00hC00<@4a<0TA<00`0C4`1E4`8=6A<006LC00<04a<0

ia<00`0C4`1G4`033A<C01HC001U4`0301<00>TC00<04a<0L1<006HC00<04a<0j1<00`0C4`1`4`00

;1<30?lC8a<2074C000/4`0301<C0?lC8a<00`0C4`1`4`00;A<00`0C4`054`0301<C0?lCSA<002dC

00@04a<C0`0011<04a<30?lCRQ<002`C00<04`000Q<2008C00<04a<00Q<00`0C4`3o4hPC000]4`03

01<C00<C00@04a<00Q<00`0C4`3o4hTC000c4`0401<C00<C00<04a<01Q<00`0C4`0U4`<0;A<00`0C

4`3o4bLC000M4`<000<C00000P0<4`<011<300PC00<04a<091<0100C4`0A4`<000<C00000P024`03

01<C008C00<04a<00Q<00`0C4`054`0401<C4`D00Q<00`0C4`024`0301<C008C00<04a<011<20</C

00<04a<0<Q<00`0C4`084`0071<0100C4`0T4`0301<C02<C00@04a<041<0100C4`064`0301<000LC

00<04`0011<500<C00<04a<01Q<00`0C00034`0301<C00<C00<04a<0`a<00`0C4`044`0301<C01<C

00<04a<07Q<00`0C4`074`0071<01@0C4`0C00@000<C0000600[4`<041<01@0C4`0C00@000@C01<0

2A<00`0C4`044`0301<C00<C00<04a<021<01@0C4a<000DC00<04a<0/A<0100C4a<4008C0P064`03

01<C00<C00<04a<00Q<00`0C4`024`0301<C008C00<04a<01A<0100C4a<5008C00<04a<00Q<00`0C

4`024`0301<C00@C0P044`0401<C4`800A<10040000M4`<0CA<00`0C4`0?4`<01Q<00`0C00074`80

1a<00`0C4`034`0301<C00HC0P054`0301<C008C00<04a<0/1<00`0C00074`0301<C00@C1@034`07

01<C4`0C00074`0301<000@C1@034`0301<C00HC00<04`000a<00`0C4`034`0301<C00@C00<04a<0

0Q<00`0C00014`007a<00`0C4`1:4`804a<00`0C4`044`0301<000LC00<04a<031<00`0C4`064`03

01<C008C00<04`0011<00`0C002`4`0301<0008C10000a<04`074`0301<C00<C00L04a<C01<000TC

00<04a<011<00`0C4`034`0301<C00PC00D04a<C00054`0301<C00@C00<04a<00a<1004C0A<001hC

0P1P4`801a<00`0C4`064`<02a<200PC0`024`<011<309HC0P000a<0000E4`0301<000LC00<04a<0

1Q<00`0C4`034`0701<C4`0C00074`801a<00`0C4`034`0301<C00HC0P054`0301<C008C00<04a<0

11<00`0C4`034`400A<14`00oa=A4`0301<001HC00<04`001a<00`0C000=4`0601<C01<01a<00`0C

4`0<4`0301<C00HC00<04a<00Q<00`0C00044`0301<000<C00<04a<00a<00`0C00014`00:A<200HC

0P3o4alC00<04a<05Q<00`0C4`064`<03Q<0100C4`084`<02a<200PC0`024`<011<3008C00<04a<0

0a<2004C0@010000:a<00`0C4`024`0301<C0?lC7a<00`0C4`1`4`00:Q<00`0C4`034`0301<C00DC

00<04a<0oa<F4`0301<0074C000[4`0301<C008C00<04a<00Q<400<C0`3o4a4C0P000a<0001`4`00

:A<00`0C00044`0301<0008C0P000a<04`044`0301<C0?lCQ1<002XC00<04a<00a<300@C00<04`00

0a<00`0C4`3o4hDC000g4`0301<000@C00<04a<0oa>44`00=A<300@C0`3o4hHC003o4lDC003o4lDC

003o4lDC003o4lDC003o4lDC0000\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.49301, -1.72618, 0.0221953, 0.0221953}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -84.5 0 ]

[.5 .96488 84.5 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -145.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.565) show

222.250000 19.500000 moveto

(C) show

227.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.27179 0 m

.30316 .04908 L

.34309 .11157 L

.3815 .17169 L

.42237 .23565 L

.46172 .29723 L

.49955 .35644 L

.53984 .41949 L

.57861 .48017 L

.61984 .54469 L

.65954 .60683 L

.69774 .6666 L

.73838 .73021 L

.77751 .79145 L

.81909 .85653 L

.85916 .91923 L

s

.85916 .91923 m

.88034 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.384099 0.238095 [

[.02381 .3716 -6 -9 ]

[.02381 .3716 6 0 ]

[.2619 .3716 -6 -9 ]

[.2619 .3716 6 0 ]

[.7381 .3716 -3 -9 ]

[.7381 .3716 3 0 ]

[.97619 .3716 -3 -9 ]

[.97619 .3716 3 0 ]

[1.025 .3841 0 -8 ]

[1.025 .3841 9 8 ]

[.4875 .02696 -24 -4.5 ]

[.4875 .02696 0 4.5 ]

[.4875 .146 -12 -4.5 ]

[.4875 .146 0 4.5 ]

[.4875 .26505 -24 -4.5 ]

[.4875 .26505 0 4.5 ]

[.4875 .50315 -18 -4.5 ]

[.4875 .50315 0 4.5 ]

[.4875 .62219 -6 -4.5 ]

[.4875 .62219 0 4.5 ]

[.4875 .74124 -18 -4.5 ]

[.4875 .74124 0 4.5 ]

[.4875 .86029 -6 -4.5 ]

[.4875 .86029 0 4.5 ]

[.5 .93964 -4.5 0 ]

[.5 .93964 4.5 16 ]

[.5 .92714 -137 0 ]

[.5 .92714 137 16 ]

[ 0 0 0 0 ]

[ 1 .91464 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .3841 m

.02381 .39035 L

s

[(-2)] .02381 .3716 0 1 Mshowa

.2619 .3841 m

.2619 .39035 L

s

[(-1)] .2619 .3716 0 1 Mshowa

.7381 .3841 m

.7381 .39035 L

s

[(1)] .7381 .3716 0 1 Mshowa

.97619 .3841 m

.97619 .39035 L

s

[(2)] .97619 .3716 0 1 Mshowa

.125 Mabswid

.07143 .3841 m

.07143 .38785 L

s

.11905 .3841 m

.11905 .38785 L

s

.16667 .3841 m

.16667 .38785 L

s

.21429 .3841 m

.21429 .38785 L

s

.30952 .3841 m

.30952 .38785 L

s

.35714 .3841 m

.35714 .38785 L

s

.40476 .3841 m

.40476 .38785 L

s

.45238 .3841 m

.45238 .38785 L

s

.54762 .3841 m

.54762 .38785 L

s

.59524 .3841 m

.59524 .38785 L

s

.64286 .3841 m

.64286 .38785 L

s

.69048 .3841 m

.69048 .38785 L

s

.78571 .3841 m

.78571 .38785 L

s

.83333 .3841 m

.83333 .38785 L

s

.88095 .3841 m

.88095 .38785 L

s

.92857 .3841 m

.92857 .38785 L

s

.25 Mabswid

0 .3841 m

1 .3841 L

s

gsave

1.025 .3841 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .02696 m

.50625 .02696 L

s

[(-1.5)] .4875 .02696 1 0 Mshowa

.5 .146 m

.50625 .146 L

s

[(-1)] .4875 .146 1 0 Mshowa

.5 .26505 m

.50625 .26505 L

s

[(-0.5)] .4875 .26505 1 0 Mshowa

.5 .50315 m

.50625 .50315 L

s

[(0.5)] .4875 .50315 1 0 Mshowa

.5 .62219 m

.50625 .62219 L

s

[(1)] .4875 .62219 1 0 Mshowa

.5 .74124 m

.50625 .74124 L

s

[(1.5)] .4875 .74124 1 0 Mshowa

.5 .86029 m

.50625 .86029 L

s

[(2)] .4875 .86029 1 0 Mshowa

.125 Mabswid

.5 .05077 m

.50375 .05077 L

s

.5 .07457 m

.50375 .07457 L

s

.5 .09838 m

.50375 .09838 L

s

.5 .12219 m

.50375 .12219 L

s

.5 .16981 m

.50375 .16981 L

s

.5 .19362 m

.50375 .19362 L

s

.5 .21743 m

.50375 .21743 L

s

.5 .24124 m

.50375 .24124 L

s

.5 .28886 m

.50375 .28886 L

s

.5 .31267 m

.50375 .31267 L

s

.5 .33648 m

.50375 .33648 L

s

.5 .36029 m

.50375 .36029 L

s

.5 .40791 m

.50375 .40791 L

s

.5 .43172 m

.50375 .43172 L

s

.5 .45553 m

.50375 .45553 L

s

.5 .47934 m

.50375 .47934 L

s

.5 .52696 m

.50375 .52696 L

s

.5 .55077 m

.50375 .55077 L

s

.5 .57457 m

.50375 .57457 L

s

.5 .59838 m

.50375 .59838 L

s

.5 .646 m

.50375 .646 L

s

.5 .66981 m

.50375 .66981 L

s

.5 .69362 m

.50375 .69362 L

s

.5 .71743 m

.50375 .71743 L

s

.5 .76505 m

.50375 .76505 L

s

.5 .78886 m

.50375 .78886 L

s

.5 .81267 m

.50375 .81267 L

s

.5 .83648 m

.50375 .83648 L

s

.5 .00315 m

.50375 .00315 L

s

.5 .8841 m

.50375 .8841 L

s

.5 .90791 m

.50375 .90791 L

s

.25 Mabswid

.5 0 m

.5 .91464 L

s

gsave

.5 .93964 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .92714 -198 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.565) show

298.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

303.000000 15.000000 moveto

(L) show

310.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

317.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

324.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

329.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

333.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .91464 L

0 .91464 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .22837 m

.02576 .22836 L

.03158 .22832 L

.04116 .22826 L

.05435 .22817 L

.07091 .22806 L

.09057 .22792 L

.11299 .22774 L

.13778 .22752 L

.16452 .22726 L

.19275 .22695 L

.22199 .22659 L

.25174 .22616 L

.28149 .22566 L

.31074 .22507 L

.33897 .2244 L

.36571 .22364 L

.3905 .22278 L

.41291 .22185 L

.43257 .22088 L

.44914 .21992 L

.46232 .21904 L

.47191 .21832 L

.47772 .21785 L

.47967 .21768 L

s

.47967 .21768 m

.4818 .2175 L

.48813 .21693 L

.49857 .21589 L

.51294 .21425 L

.53098 .21177 L

.55239 .20804 L

.5768 .20246 L

.6038 .19432 L

.63293 .18317 L

.66368 .16931 L

.69553 .15366 L

.72793 .13726 L

.76034 .12089 L

.79219 .10507 L

.82294 .09017 L

.85206 .07643 L

.87906 .06401 L

.90348 .05304 L

.92489 .04363 L

.94293 .03583 L

.95729 .02971 L

.96773 .02531 L

.97407 .02266 L

.97619 .02178 L

s

.47967 .46725 m

.4818 .44009 L

.48813 .41325 L

.49857 .38701 L

.51294 .36165 L

.53098 .33754 L

.55239 .31523 L

.5768 .29542 L

.6038 .27896 L

.63293 .2664 L

.66368 .25754 L

.69553 .25157 L

.72793 .24756 L

.76034 .2448 L

.79219 .24285 L

.82294 .24144 L

.85206 .24039 L

.87906 .2396 L

.90348 .239 L

.92489 .23854 L

.94293 .2382 L

.95729 .23795 L

.96773 .23778 L

.97407 .23769 L

.97619 .23765 L

s

.47967 .46737 m

.4818 .4947 L

.48813 .52212 L

.49857 .5494 L

.51294 .57639 L

.53098 .60298 L

.55239 .62903 L

.5768 .65441 L

.6038 .67902 L

.63293 .70273 L

.66368 .72545 L

.69553 .74706 L

.72793 .76748 L

.76034 .78661 L

.79219 .80437 L

.82294 .82069 L

.85206 .83548 L

.87906 .84869 L

.90348 .86025 L

.92489 .87013 L

.94293 .87827 L

.95729 .88463 L

.96773 .8892 L

.97407 .89195 L

.97619 .89286 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<2074C003o4e8C00<04a<0L1<006@C1@3X4`0301<C070C001V4`0301<C0=LC1@024`03

01<C008C00<04a<00Q<00`0C4`1`4`00A1<00`dC4`0I4`<00a<00`0C4`024`80eA<00`0C4`064`03

01<000<C00<04a<0EQ<23APC00154`033A<C01hC00<04a<00Q<00`0C4`3>4`<00a<00`0C4`084`04

01<C4`80E1<33AXC00154`033A<C01hC00<04a<00Q<00`0C4`3D4`0301<C00HC0P044`0301<C054C

0PdM4`00AQ<00`dC4`0L4`8011<00`0C4`3D4`0301<C00HC00<04a<00a<00`0C4`1?4`8=7a<004HC

00<=4a<08Q<20=@C0P084`<00a<00`0C4`1>4`033A<C01lC00174`033A<C024C00<04a<0ha<204dC

0PdR4`00B1<00`dC4`0P4`0301<C0><C00<04a<0BA<33B@C00184`033A<C020C00<04a<0ha<00`0C

4`174`8=9a<004TC00<=4a<07a<20>@C00<04a<0A1<33BTC001:4`033A<C01hC00<04a<0ha<00`0C

4`124`8=;1<004XC00<=4a<07Q<00`0C4`3S4`80@A<23BhC001;4`033A<C01dC00<04a<0ha<00`0C

4`0n4`8=<1<004`C00<=4a<071<20>@C00<04a<0?1<23C8C001<4`033A<C01`C00<04a<0ha<00`0C

4`0i4`<==1<004dC00<=4a<06a<00`0C4`3S4`80=a<33CLC001=4`033A<C01/C00<04a<0ha<00`0C

4`0d4`8=>Q<004hC00<=4a<06Q<20>@C00<04a<0<Q<23C`C001?4`033A<C01TC00<04a<0ha<00`0C

4`0`4`8=?Q<004lC00<=4a<02Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`3S4`0301<C02hC

0Pe04`00D1<00`dC4`084`0301<000LC00<04`000a<00`0C4`3S4`80;A<23D8C001A4`033A<C008C

0`024`0301<000TC00@04a<C0P3T4`0301<C02/C00<=4a<0@Q<0054C00<=4a<01a<00`0C00074`80

11<00`0C4`3L4`D00Q<00`0C4`0Y4`8=AA<0058C00<=4a<01Q<00`0C00074`0301<C00<C00<04a<0

gQ<00`0C4`024`0301<C02PC00<=4a<0AA<005<C00<=4a<01Q<00`0C4`064`<00a<00`0C4`3H4`<0

0a<00`0C4`024`809a<23DPC001C4`033A<C01DC00<04a<0gQ<00`0C4`024`0301<C02@C0Pe:4`00

E1<00`dC4`0D4`80ga<00`0C4`024`0301<C028C0Pe<4`00E1<00`dC4`0D4`0301<C0=dC0P044`03

01<C020C0Pe>4`00EA<00`dC4`0C4`0301<C0><C00<04a<07Q<23E0C001F4`033A<C018C00<04a<0

ha<201`C0`eB4`00EQ<00`dC4`0B4`80i1<00`0C4`0H4`<=EA<005LC00<=4a<04A<00`0C4`3S4`03

01<C01DC0`eH4`006Q<302DC1@0A4`033A<C010C00<04a<091<502@C0`2C4`0301<C01<C0PeK4`00

6Q<00`0C4`0W4`0301<C014C00<=4a<041<00`0C4`0V4`0301<C02@C00<04a<0Ta<2014C0`eM4`00

5A<300<C00<04a<081<300<C00<04a<04Q<00`dC4`0?4`809a<00`0C4`0U4`0301<C098C00<04a<0

3Q<23F0C000K4`0301<C02HC00<04a<04a<00`dC4`0>4`0301<C02HC00<04a<09A<00`0C4`2B4`03

01<C00XC10eR4`006Q<00`0C000W4`0301<C01<C00<=4a<03Q<00`0C4`0V4`0301<C02@C00<04`00

Ta<00`0C4`064`@=IQ<001/C00<04a<09A<201HC00<=4a<03A<00`0C4`0U4`809a<00`0C4`2B4`T=

JQ<005/C00<=4a<03A<20=HC3Pd2074C001L4`033A<C00`C00<04a<0/Q<S3@hC00<04a<0L1<005dC

00<=4a<02a<00`0C4`1K4`80;1<Y3C4C00<04a<0L1<005dC00<=4a<02a<00`0C4`1J4`0301<C08HC

00<04a<0L1<001DCB@000`d0001Q00HC00<04a<0QQ<203TC80dH4`006A<00`0C4`064`0301<C00DC

00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00D04a<C3@034`03

01<C00DC00<@4a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<0

1A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`084`0301<C08HC00<04a<09Q<B3CPC001O4`03

3A<C00TC00<@4a<0FQ<00`0C00264`0301<C020C1Pe:4`00H1<00`dC4`084`8@Fa<307LC00<04a<0

0Q<00`0C4`024`0301<C008C00<04a<06a<53E0C001Q4`033A<C00LC0Q3D4`0301<000LC00<04`00

0a<00`0C4`0H4`<=EA<0064C00<=4a<01Q<00a00403?4`<00Q<00`0C00094`0401<C4`805Q<33EPC

001R4`033A<C00DC00<@0100e1<00`0C00074`8011<00`0C4`0C4`8=Fa<006<C00<=4a<011<00a00

403D4`0301<000LC00<04a<00a<00`0C4`0A4`8=GA<006@C00<=4a<00Q<01A0C000@0=@C00<04a<0

1Q<300<C00<04a<041<00`dC4`1M4`00I1<00`dC4`024`0541<04a00ha<200lC0PeP4`00IA<02@dC

4a<@4`0C403S4`0301<C00dC00<=4a<0H1<006HC00H=4a<@4`024`0341<C0>0C00<04a<031<00`dC

4`1Q4`00IQ<01@dC4a0C008000<C41<0hA<00`0C4`0:4`8=I1<006LC00D=4a0C00024`0341<C0>0C

00<04a<021<23FHC001W4`053A0C4`000a<00a0C4`3O4`8021<00`dC4`1V4`00J1<010dC4`034`03

41<C0=lC00<04a<01Q<00`dC4`1W4`00J1<00a0=4`02008C00<@4a<0ga<00`0C4`054`033A<C06PC

001W4`0541<=4`0011<00a0C4`254`<0:A<502PC00<04a<01A<00`dC4`0P4`D0:A<301LC001L4`03

01<C008C00<04a<00Q<01P0@4a<=00@C00<@4a<0QA<00`0C4`0[4`0301<C02PC0P054`033A<C02<C

00<04a<0:A<00`0C4`0G4`00Fa<00`0C00074`030100008C00<=01<00a<00a0C4`204`<00a<00`0C

4`0T4`<00a<00`0C4`0X4`0301<C00<C00<=4a<091<00`0C4`0Z4`0301<C01HC001K4`0301<000PC

00<@01<00Q<00`d04`034`0341<C08DC00<04a<0:Q<00`0C4`0X4`0301<C008C00<=4a<09A<00`0C

4`0Z4`0301<C01HC001K4`0301<000LC00<041<00a<00`0=4`034`0341<C08@C00<04`00:a<00`0C

4`0X4`0501<C4`d0:1<00`0C4`0Y4`0301<001LC001K4`0301<000LC00<@4a<00a<00`0=4`044`03

41<C08@C00<04a<0:A<202XC00D04a<C3@0W4`80;1<00`0C4`0F4`00G1<00`0C4`064`03400000<C

00<04`d011<00a0C4`3L4`8000<C3A<0KQ<006@C00<@4a<011<200034`dC008C00<@4a<0g1<00`0C

3@1`4`00I1<00a0C4`044`0401<C3@@C00<@4a<0fa<00`0C3@1U4`802A<006<C00<@4a<01A<01@0C

4a<=00<C00<@4a<0fa<00`0=4`1T4`0301<C00TC001S4`0341<C00DC00D04a<C3@044`0341<C07/C

H0000`d0001L00LC00<04a<02A<0068C00<@4a<01Q<00`0C4`024`053A<C4a00PQ<00`0C4`064`03

01<C00HC00<04a<01Q<00`0C4`064`0301<C00HC00<04a<01Q<00`0C4`064`0301<C00HC00<04a<0

1Q<00`0C4`064`033A<C00HC00<04a<01Q<00`0C4`064`0301<C00HC00<04a<01Q<00`0C4`064`03

01<C00HC00<04a<01Q<00`0C4`064`0301<C00HC00<04a<02Q<00`0C4`094`00HQ<00a0C4`064`80

11<01@dC4a<@084C00<04a<0:Q<00`0C4`0Z4`033A<C02XC00<04a<0:Q<00`0C4`0:4`0301<000TC

001Q4`0341<C00LC00<04a<00a<01@dC4a<@0=XC00<=01<0IA<300TC001Q4`0341<C00LC00<04a<0

11<010dC4a3J4`033@0C074C001P4`0341<C00PC00<04a<01A<010dC4a3H4`043A<0074C001P4`03

41<C00PC0P064`043A<C4=PC00<=4`00LQ<005lC00<@4a<02A<00`0C4`064`043A<C4=LC00<=4`00

LQ<005lC00<@4a<02A<00`0C4`074`033A<@0=LC00<=4`00LQ<005hC00<@4a<02Q<00`0C4`074`04

3A<C4=DC00<=4a<00P1a4`00GQ<00a0C4`0:4`802A<00`dC403E4`043A<C078C001M4`0341<C00/C

00<04a<02A<00`dC403D4`043A<C078C001M4`0341<C00@C1@024`0301<C00XC00<=41<0da<010dC

4`1b4`00G1<00a0C4`074`0301<C008C00<04a<02Q<00`dC403C4`043A<C078C001K4`0341<C00PC

00<04a<00Q<200`C00<=4a00dA<010dC4a<2074C001K4`0341<C00PC00<04a<00Q<00`0C4`0<4`03

3A0C0=0C00D=4a<C001b4`00FQ<00a0C4`094`0301<C008C00<04a<031<00`dC403@4`053A<C4`00

LQ<005XC00<@4a<021<200@C00<04a<03A<00`dC403?4`053A<C4`00LQ<005TC00<@4a<03a<200hC

00<=4a00ca<010dC4a<2074C001H4`0341<C010C00<04a<03Q<00`dC403?4`043A<C078C001H4`03

41<C010C00<04a<03Q<010dC4a3>4`043A<C078C001G4`0341<C014C00<04a<03a<00`dC40324`03

01<C008C00<04a<00Q<00`0C3@024`0301<C070C001F4`0341<C018C0P0A4`033A<@0<0C00<04`00

1a<0100C00d24`0301<C070C001F4`0341<C018C00<04a<041<010dC4a2o4`0301<000TC00@03A<C

0P1a4`00EA<00a0C4`0C4`0301<C014C00<=4a00_a<00`0C00074`8000DC3A<C001b4`00E1<00a0C

4`0D4`0301<C014C00@=4a<@_Q<00`0C00074`0701<C4`dC001b4`00Da<00a0C4`0E4`804a<00`dC

402o4`0301<C00HC0`0011<=4`1b4`00Da<00a0C4`0E4`0301<C01<C00<=4a00ba<010dC001a4`00

DQ<00a0C4`0F4`0301<C01<C00@=4a<@bQ<00`dC001b4`00DA<00a0C4`0G4`0301<C01@C00<=4a00

ba<00`d04`1a4`00DA<00a0C4`0G4`805Q<00`dC403:4`033@0C074C001@4`0341<C01PC00<04a<0

5A<00`dC403;4`033A<C070C001?4`0341<C00PC1@024`0301<C008C00<04a<00Q<00`0C4`0F4`03

3A<@0<XC00<=01<0L1<004lC00<@4a<02Q<00`0C4`064`0301<000<C00<04a<05a<00`dC40394`03

00dC070C001>4`0341<C00/C00<04a<021<0100C4a<201TC00<=4a00b1<00`0=4`1`4`00CA<00a0C

4`0<4`0301<C00HC0P044`0301<C01PC00<=4a00b1<00`0C3@1`4`00C1<00a0C4`0=4`0301<C00HC

00<04a<00a<00`0C4`0I4`033A<@0<LC0P000`dC4`1^4`00C1<00a0C4`0<4`8021<300<C00<04a<0

6Q<00`dC40364`0401<C3FlC001;4`0341<C01dC0P0K4`043A<C4<DC00D04a<C3@1^4`00BQ<00a0C

4`0N4`0301<C01/C00<=4a00aA<01@0C4a<=06hC001:4`0341<C01hC00<04a<06a<010dC4a344`03

01<C008C00<=4a<0Ja<004TC00<@4a<07a<00`0C4`0L4`043A<C4<<C0P034`033A<C06/C00184`03

41<C020C0P0N4`043A<C4<8C00<04a<00a<00`dC4`1Z4`00Aa<00a0C4`0Q4`0301<C01dC00D=4a<C

40314`0301<C00@C00<=4a<0JA<004LC00<@4a<08A<00`0C4`0N4`043A<C4;XC1@024`0301<C00DC

00<=4a<0J1<004HC00<@4a<08Q<00`0C4`0N4`053A<C4a00^a<00`0C4`024`0301<C00DC00<=4a<0

J1<004DC00<@4a<08a<2020C00D=4a<C402j4`0301<C008C0P074`033A<C06LC00144`0341<C02@C

00<04a<081<01@dC4a<@0;TC00<04a<00Q<00`0C4`074`033A<C06HC00144`0341<C02@C00<04a<0

81<01@dC4a<@0;TC00<04a<00Q<00`0C4`084`033A<C06DC00134`0341<C02DC00<04a<08A<01@dC

4a<@0;LC0P044`0301<C00TC00<=4a<0I1<0048C00<@4a<09Q<00`0C4`0R4`053A<C4a00_1<200/C

00<=4a<0Ha<0044C00<@4a<09a<202<C00<=4a<00Q<00a0C4`2i4`0301<C00/C00<=4a<0HQ<0040C

00<@4a<0:1<00`0C4`0S4`033A<C008C00<@4a<0^1<00`0C4`0<4`033A<C064C00104`0341<C028C

0`034`0301<C02<C00<=4a<00a<00a0C4`2g4`0301<C00dC00<=4a<0H1<003lC00<@4a<08a<00`0C

4`034`0301<C02@C00<=4a<00Q<00a0C4`2g4`0301<C00hC0PeP4`00?Q<00a0C4`0U4`0301<C008C

0P0V4`033A<C008C00<@4a<0]Q<2014C00<=4a<0GA<003dC00<@4a<09Q<00`0C4`024`0301<C02DC

00<=4a<00a<00a0C4`2e4`0301<C014C00<=4a<0G1<003dC00<@4a<09A<00`0C00034`0301<C02HC

00<=4a<00a<00a0C4`2d4`0301<C018C00<=4a<0Fa<003`C00<@4a<09a<00`0C4`024`0301<C02LC

00<=4a<00a<00a0C4`2c4`0301<C01<C00<=4a<0FQ<003/C00<@4a<0;A<202PC00<=4a<011<00a0C

4`2b4`805A<00`dC4`1I4`00>Q<00a0C4`0^4`0301<C02PC00<=4a<00a<00a0C4`2b4`0301<C01DC

00<=4a<0F1<003XC00<@4a<0;Q<00`0C4`0Y4`033A<C00<C00<@4a<0/A<00`0C4`0F4`033A<C05LC

000i4`0341<C02lC00<04a<0:A<00`dC4`044`0341<C0;0C00<04a<05a<23ELC000h4`0341<C030C

0P0[4`033A<C00@C00<@4a<0[a<00`0C4`0I4`033A<C05@C000g4`0341<C034C00<04a<0:Q<00`dC

4`044`0341<C0:lC0P0K4`8=E1<003LC00<@4a<0<A<00`0C4`0[4`033A<C00@C00<@4a<0[Q<00`0C

4`0L4`033A<C054C000f4`0341<C038C00<04a<0;1<00`dC4`044`0341<C09`C1@024`0301<C008C

00<04a<00Q<00`0C4`0M4`8=DA<003DC00<@4a<0<a<202dC00<=4a<01A<00a0C4`2M4`0301<C00HC

00<04`000a<00`0C4`0O4`033A<C04hC000d4`0341<C03@C00<04a<0;A<00`dC4`054`0341<C09`C

00<04a<021<0100C4a<2024C0Pe>4`00<a<00a0C4`0e4`0301<C02hC00<=4a<01A<00a0C4`2K4`03

01<C00HC0P044`0301<C028C00<=4a<0Ba<0038C00<@4a<0=Q<00`0C4`0^4`033A<C00DC00<@4a<0

Va<00`0C4`064`0301<C00<C00<04a<08a<23D/C000a4`0341<C03LC0P0`4`033A<C00DC00<@4a<0

VA<200PC0`034`0301<C02DC00<=4a<0B1<0030C00<@4a<0>1<00`0C4`0`4`033A<C00DC00<@4a<0

Z1<00`0C4`0V4`8=B1<002lC00<@4a<0:A<300<C00<04a<00Q<00`0C4`024`0301<C030C00<=4a<0

1Q<00a0C4`2W4`80:A<00`dC4`154`00;Q<00a0C4`0Z4`0301<C00LC00<04`000a<00`0C4`0a4`03

3A<C00HC00<@4a<0YQ<00`0C4`0Y4`8=AA<002dC00<@4a<0;1<00`0C4`084`0401<C4`80<Q<00`dC

4`074`0341<C0:DC00<04a<0:a<00`dC4`124`00;1<00a0C4`0]4`0301<C00HC0P044`0301<C038C

00<=4a<01a<00a0C4`2T4`0301<C02`C0Pe24`00:a<00a0C4`0]4`0301<000LC00<04a<00a<00`0C

4`0c4`033A<C00LC00<@4a<0Xa<202lC00<=4a<0?a<002XC00<@4a<0;a<00`0C4`064`<00a<00`0C

4`0c4`033A<C00PC00<@4a<0XQ<00`0C4`0_4`8=?a<002TC00<@4a<0?a<203DC00<=4a<021<00a0C

4`2Q4`0301<C034C0Pdm4`00:1<00a0C4`104`0301<C03DC00<=4a<021<00a0C4`2P4`0301<C03<C

0Pdk4`009a<00a0C4`114`0301<C03DC00<=4a<02A<00a0C4`2O4`0301<C03DC0Pdi4`009Q<00a0C

4`124`0301<C03HC00<=4a<02A<00a0C4`2N4`80>1<23CLC000U4`0341<C04<C0P0h4`033A<C00TC

00<@4a<0WA<00`0C4`0i4`8==A<002@C00<@4a<0A1<00`0C4`0g4`033A<C00XC00<@4a<0W1<00`0C

4`0k4`8=<a<002<C00<@4a<0AA<00`0C4`0h4`033A<C00XC00<@4a<0Va<00`0C4`0m4`8=<A<002<C

00<@4a<0AA<00`0C4`0h4`033A<C00/C00<@4a<0VQ<2040C0`d^4`008Q<00a0C4`164`80>Q<00`dC

4`0;4`0341<C09TC00<04a<0@Q<23B`C000Q4`0341<C04LC00<04a<0>Q<00`dC4`0;4`0341<C09PC

00<04a<0A1<23BXC000P4`0341<C04PC00<04a<0>Q<00`dC4`0<4`0341<C094C0`034`0301<C04HC

0PdX4`007a<00a0C4`194`0301<C03/C00<=4a<031<00a0C4`2@4`0301<C00<C00<04a<0B1<23BHC

000N4`0341<C04XC0P0l4`033A<C00dC00<@4a<0T1<00`0C4`024`80Ba<00`dC4`0S4`007A<00a0C

4`1;4`0301<C03`C00<=4a<03A<00a0C4`2?4`0301<C008C00<04a<0Ba<23B<C000L4`0341<C04`C

00<04a<0?1<00`dC4`0>4`0341<C08dC00<04`000a<00`0C4`1=4`<=81<001/C00<@4a<0Aa<200@C

00<04a<0?A<00`dC4`0>4`0341<C08dC00<04a<00Q<00`0C4`1@4`<=7A<001XC00<@4a<0BQ<01@0C

4a<003lC00<=4a<03a<00a0C4`2A4`80E1<23A/C000I4`0341<C04XC00<04a<00Q<203lC00<=4a<0

3Q<00a0C4`2A4`0301<C05DC0PdI4`00Ia<00`0C4`3W4`0301<C05LC00<=4a<05Q<006DC00<04`00

jA<00`0C4`1`4`00IQ<00`0C4`3X4`0301<C070C000Z4`<0oa<U4`80LA<002XC00<04a<0oa<U4`03

01<C070C000[4`0301<C00@C00<04a<0oa>@4`00:a<0100C4a<400<C0`3o4h`C000Z4`0301<0008C

0P000a<04`044`0301<C0?lCRQ<002/C00<04a<00a<00`0C00034`0301<C0?lCRa<0034C00<04`00

11<00`0C4`064`0301<C02LC0`0[4`0301<C0?lC:A<001/C0`000a<0000200`C0`044`<021<00`0C

4`0V4`0401<C00lC0`000a<00002008C00<04a<00Q<00`0C4`024`0301<C00DC00@04a<C1@024`03

01<C008C00@04a<C0P044`0301<C00@C0P354`0301<C03LC00<04a<01Q<001XC00@04a<091<00`0C

4`0U4`0401<C00hC00@04a<01Q<00`0C00074`0301<000@C1@034`0301<C00HC00<04`000Q<00`0C

00024`0301<000@C00<04a<0_A<00`0C4`044`0301<C01<C00<04a<08a<00`0C4`054`006Q<01@0C

4`0C00@000<C0000600]4`<03Q<01@0C4`0C00@000@C01<02A<00`0C4`044`0301<C00<C00<04a<0

21<01P0C4`0C00@C00<04a<00Q<00`0C4`2[4`0401<C4`@00Q<200HC00<04a<00a<00`0C4`024`03

01<C008C00<04a<00Q<00`0C4`054`0401<C4`D00Q<00`0C4`024`0401<C4`8011<00`0C4`044`80

11<0100C4a<2004C000K4`<0Ca<00`0C4`0=4`<01Q<00`0C00074`801a<00`0C4`034`0301<C00HC

0P034`800a<200DC00<04a<0ZQ<00`0C00074`0301<C00@C1@034`0701<C4`0C00074`0301<000@C

1@034`0301<C00HC00<04`000Q<00`0C00024`0301<000@C00<04a<011<00`0C4`024`400A<001dC

00<04a<0C1<2014C00<04a<011<00`0C00074`0301<C00`C00<04a<01Q<00`0C4`024`0301<C008C

00<04a<011<00`0C002Z4`0301<0008C10000a<04`074`0301<C00<C00L04a<C01<000TC00<04a<0

11<00`0C4`034`0301<C00PC00H04a<04`044`0301<C008C00<04a<011<00`0C4`034`40000L4`80

H1<200LC00<04a<01Q<300/C0P084`<00a<2008C0`044`<0Ta<200034`00018C00<04`001a<00`0C

4`064`0301<C00<C00L04a<C01<000LC0P074`0301<C00<C00<04a<01Q<200<C0P034`801A<00`0C

4`044`0301<C00<C0@000?lCDA<00`0C000C4`0301<000LC00<04`003A<01P0C4`0C00LC00<04a<0

31<00`0C4`064`0301<C008C00<04a<00Q<00`0C4`044`0301<000<C00<04a<00a<1004C000V4`80

1Q<20?lC8Q<00`0C4`0C4`0301<C00HC0`0>4`0401<C00PC0`0;4`8021<300<C0P024`<011<3008C

00<04a<00a<2004C000X4`0301<C008C00<04a<0oa<R4`0301<C070C000W4`0301<C00<C00<04a<0

1Q<00`0C4`3o4aPC00<04`00LA<002PC00<04a<00Q<00`0C4`024`<000@C01<C0`3o4a@C0P000a<0

001`4`009Q<00`0C00044`0301<0008C0P024`0301<C008C00<04a<0oa>74`009a<00`0C4`034`<0

11<0100C4`024`0301<C0?lCR1<003@C00@04a<00a<00`0C4`3o4hLC000b4`<011<30?lCRA<00?lC

aA<00?lCaA<00?lCaA<00?lCaA<00?lCaA<00001\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.47972, -1.72125, 0.022156, 0.022156}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -82 0 ]

[.5 .96488 82 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -143 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.56) show

217.250000 19.500000 moveto

(C) show

222.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.27106 0 m

.30316 .05007 L

.34309 .11236 L

.3815 .17228 L

.42237 .23603 L

.46172 .29742 L

.49955 .35644 L

.53984 .41929 L

.57861 .47978 L

.61984 .54409 L

.65954 .60603 L

.69774 .66561 L

.73838 .72902 L

.77751 .79006 L

.81909 .85493 L

.85916 .91743 L

s

.85916 .91743 m

.88156 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.382963 0.238095 [

[.02381 .37046 -6 -9 ]

[.02381 .37046 6 0 ]

[.2619 .37046 -6 -9 ]

[.2619 .37046 6 0 ]

[.7381 .37046 -3 -9 ]

[.7381 .37046 3 0 ]

[.97619 .37046 -3 -9 ]

[.97619 .37046 3 0 ]

[1.025 .38296 0 -8 ]

[1.025 .38296 9 8 ]

[.4875 .02582 -24 -4.5 ]

[.4875 .02582 0 4.5 ]

[.4875 .14487 -12 -4.5 ]

[.4875 .14487 0 4.5 ]

[.4875 .26392 -24 -4.5 ]

[.4875 .26392 0 4.5 ]

[.4875 .50201 -18 -4.5 ]

[.4875 .50201 0 4.5 ]

[.4875 .62106 -6 -4.5 ]

[.4875 .62106 0 4.5 ]

[.4875 .74011 -18 -4.5 ]

[.4875 .74011 0 4.5 ]

[.4875 .85915 -6 -4.5 ]

[.4875 .85915 0 4.5 ]

[.5 .93796 -4.5 0 ]

[.5 .93796 4.5 16 ]

[.5 .92546 -134.5 0 ]

[.5 .92546 134.5 16 ]

[ 0 0 0 0 ]

[ 1 .91296 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .38296 m

.02381 .38921 L

s

[(-2)] .02381 .37046 0 1 Mshowa

.2619 .38296 m

.2619 .38921 L

s

[(-1)] .2619 .37046 0 1 Mshowa

.7381 .38296 m

.7381 .38921 L

s

[(1)] .7381 .37046 0 1 Mshowa

.97619 .38296 m

.97619 .38921 L

s

[(2)] .97619 .37046 0 1 Mshowa

.125 Mabswid

.07143 .38296 m

.07143 .38671 L

s

.11905 .38296 m

.11905 .38671 L

s

.16667 .38296 m

.16667 .38671 L

s

.21429 .38296 m

.21429 .38671 L

s

.30952 .38296 m

.30952 .38671 L

s

.35714 .38296 m

.35714 .38671 L

s

.40476 .38296 m

.40476 .38671 L

s

.45238 .38296 m

.45238 .38671 L

s

.54762 .38296 m

.54762 .38671 L

s

.59524 .38296 m

.59524 .38671 L

s

.64286 .38296 m

.64286 .38671 L

s

.69048 .38296 m

.69048 .38671 L

s

.78571 .38296 m

.78571 .38671 L

s

.83333 .38296 m

.83333 .38671 L

s

.88095 .38296 m

.88095 .38671 L

s

.92857 .38296 m

.92857 .38671 L

s

.25 Mabswid

0 .38296 m

1 .38296 L

s

gsave

1.025 .38296 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .02582 m

.50625 .02582 L

s

[(-1.5)] .4875 .02582 1 0 Mshowa

.5 .14487 m

.50625 .14487 L

s

[(-1)] .4875 .14487 1 0 Mshowa

.5 .26392 m

.50625 .26392 L

s

[(-0.5)] .4875 .26392 1 0 Mshowa

.5 .50201 m

.50625 .50201 L

s

[(0.5)] .4875 .50201 1 0 Mshowa

.5 .62106 m

.50625 .62106 L

s

[(1)] .4875 .62106 1 0 Mshowa

.5 .74011 m

.50625 .74011 L

s

[(1.5)] .4875 .74011 1 0 Mshowa

.5 .85915 m

.50625 .85915 L

s

[(2)] .4875 .85915 1 0 Mshowa

.125 Mabswid

.5 .04963 m

.50375 .04963 L

s

.5 .07344 m

.50375 .07344 L

s

.5 .09725 m

.50375 .09725 L

s

.5 .12106 m

.50375 .12106 L

s

.5 .16868 m

.50375 .16868 L

s

.5 .19249 m

.50375 .19249 L

s

.5 .2163 m

.50375 .2163 L

s

.5 .24011 m

.50375 .24011 L

s

.5 .28772 m

.50375 .28772 L

s

.5 .31153 m

.50375 .31153 L

s

.5 .33534 m

.50375 .33534 L

s

.5 .35915 m

.50375 .35915 L

s

.5 .40677 m

.50375 .40677 L

s

.5 .43058 m

.50375 .43058 L

s

.5 .45439 m

.50375 .45439 L

s

.5 .4782 m

.50375 .4782 L

s

.5 .52582 m

.50375 .52582 L

s

.5 .54963 m

.50375 .54963 L

s

.5 .57344 m

.50375 .57344 L

s

.5 .59725 m

.50375 .59725 L

s

.5 .64487 m

.50375 .64487 L

s

.5 .66868 m

.50375 .66868 L

s

.5 .69249 m

.50375 .69249 L

s

.5 .7163 m

.50375 .7163 L

s

.5 .76392 m

.50375 .76392 L

s

.5 .78772 m

.50375 .78772 L

s

.5 .81153 m

.50375 .81153 L

s

.5 .83534 m

.50375 .83534 L

s

.5 .00201 m

.50375 .00201 L

s

.5 .88296 m

.50375 .88296 L

s

.5 .90677 m

.50375 .90677 L

s

.25 Mabswid

.5 0 m

.5 .91296 L

s

gsave

.5 .93796 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .92546 -195.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.56) show

293.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

298.000000 15.000000 moveto

(L) show

305.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

312.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

319.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

324.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

328.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .91296 L

0 .91296 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .22683 m

.02576 .22682 L

.03158 .22679 L

.04116 .22673 L

.05435 .22665 L

.07091 .22653 L

.09057 .22639 L

.11298 .22622 L

.13777 .22601 L

.16451 .22576 L

.19274 .22546 L

.22198 .2251 L

.25173 .22469 L

.28148 .2242 L

.31072 .22363 L

.33895 .22298 L

.36569 .22224 L

.39048 .22141 L

.4129 .22052 L

.43255 .21958 L

.44912 .21865 L

.4623 .21779 L

.47189 .2171 L

.4777 .21664 L

.47965 .21648 L

s

.47965 .21648 m

.48178 .21631 L

.48811 .21575 L

.49855 .21475 L

.51291 .21317 L

.53096 .21077 L

.55237 .20715 L

.57678 .20172 L

.60379 .19376 L

.63291 .18278 L

.66366 .16904 L

.69552 .15346 L

.72792 .1371 L

.76033 .12075 L

.79218 .10495 L

.82293 .09007 L

.85206 .07634 L

.87906 .06393 L

.90347 .05297 L

.92489 .04356 L

.94293 .03578 L

.95729 .02966 L

.96773 .02527 L

.97407 .02262 L

.97619 .02174 L

s

.47965 .46615 m

.48178 .439 L

.48811 .41217 L

.49855 .38592 L

.51291 .36053 L

.53096 .33638 L

.55237 .31398 L

.57678 .29406 L

.60379 .27745 L

.63291 .26475 L

.66366 .25581 L

.69552 .2498 L

.72792 .24577 L

.76033 .24302 L

.79218 .24107 L

.82293 .23967 L

.85206 .23863 L

.87906 .23785 L

.90347 .23725 L

.92489 .2368 L

.94293 .23647 L

.95729 .23622 L

.96773 .23606 L

.97407 .23596 L

.97619 .23593 L

s

.47965 .46626 m

.48178 .49358 L

.48811 .52097 L

.49855 .54822 L

.51291 .57519 L

.53096 .60174 L

.55237 .62775 L

.57678 .65311 L

.60379 .67768 L

.63291 .70136 L

.66366 .72404 L

.69552 .74563 L

.72792 .76602 L

.76033 .78512 L

.79218 .80286 L

.82293 .81915 L

.85206 .83392 L

.87906 .84711 L

.90347 .85866 L

.92489 .86852 L

.94293 .87665 L

.95729 .883 L

.96773 .88756 L

.97407 .89031 L

.97619 .89122 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<2074C003o4e8C00<04a<0L1<006@C1@3G4`D00Q<00`0C4`024`0301<C008C00<04a<0

L1<006HC00<04a<0fA<00`0C4`064`0301<000<C00<04a<0L1<004@C00<=4a<06A<300<C00<04a<0

0Q<20<lC0`034`0301<C00PC00@04a<C0P1G4`<=5a<004DC00<=4a<07Q<00`0C4`024`0301<C0=@C

00<04a<01Q<200@C00<04a<0Da<33AXC00154`033A<C01hC00<04a<00Q<00`0C4`3D4`0301<C00HC

00<04a<00a<00`0C4`1A4`8=7A<004HC00<=4a<071<200@C00<04a<0da<200PC0`034`0301<C04lC

0PdO4`00AQ<00`dC4`0R4`80i1<00`0C4`1>4`033A<C01lC00174`033A<C024C00<04a<0ha<204dC

0PdR4`00Aa<00`dC4`0Q4`0301<C0><C00<04a<0BA<33B@C00184`033A<C020C00<04a<0ha<00`0C

4`174`8=9a<004PC00<=4a<081<20>@C00<04a<0A1<33BTC00194`033A<C01lC00<04a<0ha<00`0C

4`124`8=;1<004XC00<=4a<07Q<00`0C4`3S4`80@A<23BhC001:4`033A<C01hC00<04a<0ha<00`0C

4`0n4`8=<1<004/C00<=4a<07A<20>@C00<04a<0?1<23C8C001<4`033A<C01`C00<04a<0ha<00`0C

4`0i4`<==1<004`C00<=4a<071<00`0C4`3S4`80>1<23CLC001=4`033A<C01/C00<04a<0ha<00`0C

4`0e4`8=>A<004hC00<=4a<06Q<20>@C00<04a<0<a<23C/C001?4`033A<C01TC00<04a<0ha<00`0C

4`0a4`8=?A<004lC00<=4a<02Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`3S4`0301<C02lC

0Pdo4`00D1<00`dC4`084`0301<000LC00<04`000a<00`0C4`3S4`80;Q<23D4C001A4`033A<C008C

0`024`0301<000TC00@04a<C0P3T4`0301<C02/C0Pe34`00DA<00`dC4`074`0301<000LC0P044`03

01<C0=`C1@024`0301<C02TC0Pe54`00DQ<00`dC4`064`0301<000LC00<04a<00a<00`0C4`3N4`03

01<C008C00<04a<0:1<00`dC4`154`00Da<00`dC4`064`0301<C00HC0`034`0301<C0=PC0`034`03

01<C008C0P0W4`8=B1<005<C00<=4a<05A<00`0C4`3N4`0301<C008C00<04a<091<23DXC001D4`03

3A<C01@C0P3O4`0301<C008C00<04a<08Q<23D`C001D4`033A<C01@C00<04a<0gA<200@C00<04a<0

81<23DhC001E4`033A<C01<C00<04a<0ha<00`0C4`0N4`8=D1<005HC00<=4a<04Q<00`0C4`3S4`80

71<33E8C001F4`033A<C018C0P3T4`0301<C01PC0`eE4`00Ea<00`dC4`0A4`0301<C0><C00<04a<0

5A<33EPC000J4`<09A<5014C00<=4a<041<00`0C4`0T4`D091<309<C00<04a<04a<23E/C000J4`03

01<C02LC00<04a<04A<00`dC4`0@4`0301<C02HC00<04a<091<00`0C4`2C4`804A<33EdC000E4`<0

0a<00`0C4`0P4`<00a<00`0C4`0B4`033A<C00lC0P0W4`0301<C02DC00<04a<0TQ<00`0C4`0>4`8=

H1<001/C00<04a<09Q<00`0C4`0C4`033A<C00hC00<04a<09Q<00`0C4`0U4`0301<C098C00<04a<0

2Q<43F8C000J4`0301<002LC00<04a<04a<00`dC4`0>4`0301<C02HC00<04a<091<00`0C002C4`03

01<C00HC10eV4`006a<00`0C4`0U4`805Q<00`dC4`0=4`0301<C02DC0P0W4`0301<C098C2@eZ4`00

Fa<00`dC4`0=4`80dQ<B3@80LA<005`C00<=4a<031<00`0C4`2M4c@=4Q<00`0C4`1`4`00GA<00`dC

4`0;4`0301<C05/C0P0/4a@=AQ<00`0C4`1`4`00GA<00`dC4`0;4`0301<C05XC00<04a<0QQ<00`0C

4`1@4`T=5a<001DCB@000`d0001Q00HC00<04a<0QQ<203@C7@dP4`006A<00`0C4`064`0301<C00DC

00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00D04a<C3@034`03

01<C00DC00<@4a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<0

1A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`084`0301<C08HC00<04a<09Q<=3CdC001O4`03

3A<C00TC00<@4a<0FQ<00`0C00264`0301<C020C1Pe:4`00H1<00`dC4`084`8@Fa<307LC00<04a<0

0Q<00`0C4`024`0301<C008C00<04a<06a<53E0C001Q4`033A<C00LC0Q3D4`0301<000LC00<04`00

0a<00`0C4`0H4`<=EA<0064C00<=4a<01Q<00a00403?4`<00Q<00`0C00094`0401<C4`805Q<33EPC

001R4`033A<C00DC00<@0100e1<00`0C00074`8011<00`0C4`0C4`8=Fa<006<C00<=4a<011<00a00

403D4`0301<000LC00<04a<00a<00`0C4`0A4`8=GA<006@C00<=4a<00Q<01A0C000@0=@C00<04a<0

1Q<300<C00<04a<03a<23ElC001T4`033A<C008C00D@4`0C403S4`803Q<23F4C001U4`093A<C4a0C

01<@0><C00<04a<031<00`dC4`1Q4`00IQ<01PdC4a0C008C00<@4a<0h1<00`0C4`0;4`033A<C068C

001V4`053A<C41<00P000a<@4`3Q4`0301<C00TC0PeU4`00Ia<01@dC41<0008C00<@4a<0h1<00`0C

4`084`033A<C06DC001W4`053A0C4`000a<00a0C4`3O4`8021<00`dC4`1V4`00J1<010dC4`034`03

41<C0=lC00<04a<01Q<00`dC4`1W4`00J1<00a0=4`02008C00<@4a<0ga<00`0C4`054`033A<C06PC

001W4`0541<=4`0011<00a0C4`254`<0:A<502PC00<04a<011<00`dC4`0Q4`D0:A<301LC001L4`03

01<C008C00<04a<00Q<01P0@4a<=00@C00<@4a<0QA<00`0C4`0[4`0301<C02PC0P044`033A<C02@C

00<04a<0:A<00`0C4`0G4`00Fa<00`0C00074`030100008C00<=01<00a<00a0C4`204`<00a<00`0C

4`0T4`<00a<00`0C4`0X4`0301<C008C00<=4a<09A<00`0C4`0Z4`0301<C01HC001K4`0301<000PC

00<@01<00Q<00`d04`034`0341<C08DC00<04a<0:Q<00`0C4`0X4`0301<C008C00<=4a<09A<00`0C

4`0Z4`0301<C01HC001K4`0301<000LC00<041<00a<00`0=4`034`0341<C08@C00<04`00:a<00`0C

4`0X4`0501<C4`d0:1<00`0C4`0Y4`0301<001LC001K4`0301<000LC00<@4a<00a<00`0=4`044`03

41<C08@C00<04a<0:A<202XC00D04a<C3@0W4`80;1<00`0C4`0F4`00G1<00`0C4`064`03400000<C

00<04`d011<00a0C4`3L4`8000<C3A<0KQ<006@C00<@4a<011<200034`dC008C00<@4a<0g1<00`0C

3@1`4`00I1<00a0C4`044`0401<C3@@C00<@4a<0fa<00`0C3@1U4`802A<006<C00<@4a<01A<01@0C

4a<=00<C00<@4a<0fa<00`0=4`1T4`0301<C00TC001S4`0341<C00DC00D04a<C3@044`0341<C07/C

H0000`d0001L00LC00<04a<02A<0068C00<@4a<01Q<00`0C4`024`053A<C4a00PQ<00`0C4`064`03

01<C00HC00<04a<01Q<00`0C4`064`0301<C00HC00<04a<01Q<00`0C4`064`0301<C00HC00<04a<0

1Q<00`0C4`064`033A<C00HC00<04a<01Q<00`0C4`064`0301<C00HC00<04a<01Q<00`0C4`064`03

01<C00HC00<04a<01Q<00`0C4`064`0301<C00LC00<04a<02A<00`0C4`094`00HQ<00a0C4`064`80

11<01@dC4a<@0=/C00<=4a<0I1<00`0C00094`00HA<00a0C4`074`0301<C00<C00D=4a<C403J4`03

3@0C06DC0`094`00HA<00a0C4`074`0301<C00@C00@=4a<@fQ<00`d04`1a4`00H1<00a0C4`084`03

01<C00DC00@=4a<@f1<010dC001a4`00H1<00a0C4`084`801Q<010dC4a3H4`033A<0078C001O4`03

41<C00TC00<04a<01Q<010dC4a3G4`033A<0078C001O4`0341<C00TC00<04a<01a<00`dC403G4`03

3A<0078C001N4`0341<C00XC00<04a<01a<010dC4a3E4`033A<C0080LA<005hC00<@4a<02Q<200TC

00<=4a00eA<010dC4`1b4`00GA<00a0C4`0;4`0301<C00TC00<=4a00e1<010dC4`1b4`00GA<00a0C

4`044`D00Q<00`0C4`0:4`033A0C0=<C00@=4a<0LQ<005`C00<@4a<01a<00`0C4`024`0301<C00XC

00<=4a00da<010dC4`1b4`00Fa<00a0C4`084`0301<C008C0P0<4`033A<@0=4C00@=4a<C0P1a4`00

Fa<00a0C4`084`0301<C008C00<04a<031<00`d@4`3@4`053A<C4`00LQ<005XC00<@4a<02A<00`0C

4`024`0301<C00`C00<=4a00d1<01@dC4a<0078C001J4`0341<C00PC0P044`0301<C00dC00<=4a00

ca<01@dC4a<0078C001I4`0341<C00lC0P0?4`033A0C0<hC00@=4a<C0P1a4`00F1<00a0C4`0@4`03

01<C00hC00<=4a00ca<010dC4`1b4`00F1<00a0C4`0@4`0301<C00lC00<=4a00cQ<010dC4`1b4`00

Ea<00a0C4`0A4`0301<C00lC00<=4a00`Q<00`0C4`024`0301<C008C00<04`d00Q<00`0C4`1`4`00

EQ<00a0C4`0B4`804A<00`dC40304`0301<000LC00@04`0=0Q<00`0C4`1`4`00EQ<00a0C4`0B4`03

01<C014C00<=4a00_a<00`0C00094`0400dC4`80LA<005DC00<@4a<04a<00`0C4`0A4`033A<@0;lC

00<04`001a<2008C00<=4`00LQ<005@C00<@4a<051<00`0C4`0B4`033A<@0;hC00<04`001a<01`0C

4a<=4`00LQ<005<C00<@4a<05A<201@C00<=41<0_Q<00`0C4`064`<000@C3A<0LQ<005<C00<@4a<0

5A<00`0C4`0C4`033A<@0</C00@=4`00LA<0058C00<@4a<05Q<00`0C4`0D4`033A<@0</C00<=01<0

LA<0054C00<@4a<05a<00`0C4`0E4`033A0C0<XC00<=01<0LA<0054C00<@4a<05a<201HC00<=4a00

bQ<00`d04`1a4`00D1<00a0C4`0H4`0301<C01HC00<=41<0bQ<00`dC4`1`4`00Ca<00a0C4`084`D0

0Q<00`0C4`024`0301<C008C00<04a<05Q<00`dC403:4`033@0C070C001?4`0341<C00XC00<04a<0

1Q<00`0C00034`0301<C01LC00<=4a00bA<00`0=4`1`4`00CQ<00a0C4`0;4`0301<C00PC00@04a<C

0P0I4`033A<@0<PC00<03A<0L1<004dC00<@4a<031<00`0C4`064`8011<00`0C4`0H4`033A<@0<PC

00<04`d0L1<004`C00<@4a<03A<00`0C4`064`0301<C00<C00<04a<06A<00`dC40374`8000<=4a<0

KQ<004`C00<@4a<031<200PC0`034`0301<C01XC00<=4a00aQ<0100C4`e_4`00Ba<00a0C4`0M4`80

6a<010dC4a354`0501<C4`d0KQ<004XC00<@4a<07Q<00`0C4`0K4`033A<@0<DC00D04a<C3@1^4`00

BQ<00a0C4`0N4`0301<C01/C00@=4a<@a1<00`0C4`024`033A<C06/C00194`0341<C01lC00<04a<0

71<010dC4a334`800a<00`dC4`1[4`00B1<00a0C4`0P4`807Q<010dC4a324`0301<C00<C00<=4a<0

JQ<004LC00<@4a<08A<00`0C4`0M4`053A<C4a00`A<00`0C4`044`033A<C06TC00174`0341<C024C

00<04a<07Q<010dC4a2j4`D00Q<00`0C4`054`033A<C06PC00164`0341<C028C00<04a<07Q<01@dC

4a<@0;/C00<04a<00Q<00`0C4`054`033A<C06PC00154`0341<C02<C0P0P4`053A<C4a00^Q<00`0C

4`024`801a<00`dC4`1W4`00A1<00a0C4`0T4`0301<C020C00D=4a<C402i4`0301<C008C00<04a<0

1a<00`dC4`1V4`00A1<00a0C4`0T4`0301<C020C00D=4a<C402i4`0301<C008C00<04a<021<00`dC

4`1U4`00@a<00a0C4`0U4`0301<C024C00D=4a<C402g4`8011<00`0C4`094`033A<C06@C00124`03

41<C02HC00<04a<08Q<01@dC4a<@0;`C0P0;4`033A<C06<C00114`0341<C02LC0P0S4`033A<C008C

00<@4a<0^A<00`0C4`0;4`033A<C068C00104`0341<C02PC00<04a<08a<00`dC4`024`0341<C0;PC

00<04a<031<00`dC4`1Q4`00@1<00a0C4`0R4`<00a<00`0C4`0S4`033A<C00<C00<@4a<0]a<00`0C

4`0=4`033A<C060C000o4`0341<C02<C00<04a<00a<00`0C4`0T4`033A<C008C00<@4a<0]a<00`0C

4`0>4`8=H1<003hC00<@4a<09A<00`0C4`024`809Q<00`dC4`024`0341<C0;HC0P0A4`033A<C05dC

000m4`0341<C02HC00<04a<00Q<00`0C4`0U4`033A<C00<C00<@4a<0]A<00`0C4`0A4`033A<C05`C

000m4`0341<C02DC00<04`000a<00`0C4`0V4`033A<C00<C00<@4a<0]1<00`0C4`0B4`033A<C05/C

000l4`0341<C02LC00<04a<00Q<00`0C4`0W4`033A<C00<C00<@4a<0/a<00`0C4`0C4`033A<C05XC

000k4`0341<C02dC0P0X4`033A<C00@C00<@4a<0/Q<201DC00<=4a<0FA<003XC00<@4a<0;Q<00`0C

4`0X4`033A<C00<C00<@4a<0/Q<00`0C4`0E4`033A<C05PC000j4`0341<C02hC00<04a<0:A<00`dC

4`034`0341<C0;4C00<04a<05Q<00`dC4`1G4`00>A<00a0C4`0_4`0301<C02TC00<=4a<011<00a0C

4`2`4`0301<C01LC0PeG4`00>1<00a0C4`0`4`80:a<00`dC4`044`0341<C0:lC00<04a<06A<00`dC

4`1D4`00=a<00a0C4`0a4`0301<C02XC00<=4a<011<00a0C4`2_4`806a<23E@C000g4`0341<C034C

00<04a<0:a<00`dC4`044`0341<C0:hC00<04a<071<00`dC4`1A4`00=Q<00a0C4`0b4`0301<C02`C

00<=4a<011<00a0C4`2L4`D00Q<00`0C4`024`0301<C008C00<04a<07A<23E4C000e4`0341<C03<C

0P0]4`033A<C00DC00<@4a<0WA<00`0C4`064`0301<000<C00<04a<07a<00`dC4`1>4`00=1<00a0C

4`0d4`0301<C02dC00<=4a<01A<00a0C4`2L4`0301<C00PC00@04a<C0P0Q4`8=CQ<003<C00<@4a<0

=A<00`0C4`0^4`033A<C00DC00<@4a<0Va<00`0C4`064`8011<00`0C4`0R4`033A<C04/C000b4`03

41<C03HC00<04a<0;Q<00`dC4`054`0341<C09/C00<04a<01Q<00`0C4`034`0301<C02<C0Pe;4`00

<A<00a0C4`0g4`80<1<00`dC4`054`0341<C09TC0P084`<00a<00`0C4`0U4`033A<C04PC000`4`03

41<C03PC00<04a<0<1<00`dC4`054`0341<C0:PC00<04a<09Q<23DPC000_4`0341<C02TC0`034`03

01<C008C00<04a<00Q<00`0C4`0`4`033A<C00HC00<@4a<0Ya<202TC00<=4a<0AA<002hC00<@4a<0

:Q<00`0C4`074`0301<000<C00<04a<0<A<00`dC4`064`0341<C0:HC00<04a<0:A<23DDC000]4`03

41<C02`C00<04a<021<0100C4a<2038C00<=4a<01a<00a0C4`2U4`0301<C02/C0Pe34`00;1<00a0C

4`0]4`0301<C00HC0P044`0301<C038C00<=4a<01a<00a0C4`2T4`0301<C02dC0Pe14`00:a<00a0C

4`0]4`0301<000LC00<04a<00a<00`0C4`0c4`033A<C00LC00<@4a<0Xa<2030C00<=4a<0?Q<002XC

00<@4a<0;a<00`0C4`064`<00a<00`0C4`0c4`033A<C00PC00<@4a<0XQ<00`0C4`0`4`8=?Q<002TC

00<@4a<0?a<203DC00<=4a<021<00a0C4`2Q4`0301<C038C0Pdl4`00:1<00a0C4`104`0301<C03DC

00<=4a<021<00a0C4`2P4`0301<C03@C0Pdj4`009a<00a0C4`114`0301<C03DC00<=4a<02A<00a0C

4`2O4`0301<C03HC0Pdh4`009Q<00a0C4`124`0301<C03HC00<=4a<02A<00a0C4`2N4`80>A<23CHC

000U4`0341<C04<C0P0h4`033A<C00TC00<@4a<0WA<00`0C4`0j4`033A<C03<C000T4`0341<C04@C

00<04a<0=a<00`dC4`0:4`0341<C09`C00<04a<0>a<23C<C000S4`0341<C04DC00<04a<0>1<00`dC

4`0:4`0341<C09/C00<04a<0?A<23C4C000S4`0341<C04DC00<04a<0>1<00`dC4`0;4`0341<C09XC

0P104`<=;Q<0028C00<@4a<0AQ<203XC00<=4a<02a<00a0C4`2I4`0301<C048C0Pd/4`008A<00a0C

4`174`0301<C03XC00<=4a<02a<00a0C4`2H4`0301<C04@C0PdZ4`0081<00a0C4`184`0301<C03XC

00<=4a<031<00a0C4`2A4`<00a<00`0C4`164`8=:1<001lC00<@4a<0BA<00`0C4`0k4`033A<C00`C

00<@4a<0T1<00`0C4`034`0301<C04PC0PdV4`007Q<00a0C4`1:4`80?A<00`dC4`0<4`0341<C090C

00<04a<00Q<204/C0PdT4`007A<00a0C4`1;4`0301<C03`C00<=4a<03A<00a0C4`2?4`0301<C008C

00<04a<0C1<33B4C000L4`0341<C04`C00<04a<0?A<00`dC4`0=4`0341<C08dC00<04`000a<00`0C

4`1?4`8=7a<001/C00<@4a<0Aa<200@C00<04a<0?Q<00`dC4`0=4`0341<C08dC00<04a<00Q<00`0C

4`1A4`8=7A<001XC00<@4a<0BQ<01@0C4a<0040C00<=4a<03Q<00a0C4`2A4`80E1<23A/C000I4`03

41<C04XC00<04a<00Q<2040C00<=4a<03A<00a0C4`2A4`0301<C05DC0PdI4`00Ia<00`0C4`3W4`03

01<C05LC0PdG4`00IA<00`0C003Y4`0301<C070C001V4`0301<C0>PC00<04a<0L1<002`C0`3o4b<C

0P1a4`00;1<00`0C4`3o4b<C00<04a<0L1<002dC00<04a<01A<00`0C4`3o4hdC000]4`0401<C4`<0

00@C01<C0`3o4hXC000/4`0301<0008C0P024`0301<C008C00<04a<0oa>84`00;A<00`0C4`034`04

01<C008C00<04a<0oa>94`00<a<0100C4`034`0301<C00HC00<04a<09A<302dC00<04a<0oa<W4`00

7A<300034`00008031<300@C0`084`0301<C02@C00@04a<04A<300034`0000800Q<00`0C4`024`03

01<C008C00<04a<01A<0100C4a<5008C00<04a<00Q<0100C4a<200HC0P3;4`0301<C038C00<04a<0

21<001`C00@04a<091<00`0C4`0S4`0401<C010C00@04a<01Q<00`0C00074`0301<000@C1@034`03

01<C00HC00<04`000Q<00`0C00044`0301<C0<<C00<04a<011<00`0C4`0C4`0301<C01hC00<04a<0

1a<001`C00D04a<04`0400034`0001P0:a<3010C00D04a<04`0400044`0C00TC00<04a<011<00`0C

4`034`0301<C00PC00H04a<04`044`0301<C0;4C00@04a<C10024`801Q<00`0C4`034`0301<C008C

00<04a<00Q<00`0C4`024`0301<C00DC00@04a<C1@024`0301<C008C00@04a<C0P064`8011<0100C

4a<2004C0@0100007A<304dC00<04a<03a<300HC00<04`001a<200LC00<04a<00a<00`0C4`064`80

0a<200DC00<04a<0/1<00`0C00074`0301<C00@C1@034`0701<C4`0C00074`0301<000@C1@034`03

01<C00HC00<04`000Q<00`0C00044`0301<C00@C00<04a<00Q<00`0C00014`007a<00`0C4`1:4`80

4a<00`0C4`044`0301<000LC00<04a<031<00`0C4`064`0301<C008C00<04a<011<00`0C002`4`03

01<0008C10000a<04`074`0301<C00<C00L04a<C01<000TC00<04a<011<00`0C4`034`0301<C00PC

00H04a<04`044`0301<C00@C00<04a<00a<1004C0A<001hC0P1P4`801a<00`0C4`064`<02a<200PC

0`034`8011<309HC0P000a<0000E4`0301<000LC00<04a<01Q<00`0C4`034`0701<C4`0C00074`80

1a<00`0C4`034`0301<C00HC0P034`801A<00`0C4`044`0301<C00<C0@014`4C003o4e4C00<04`00

5Q<00`0C00074`0301<000dC00H04a<04`074`0301<C00`C00<04a<01Q<00`0C4`024`0301<C00@C

00<04`000a<00`0C4`034`0301<0004C000Y4`801Q<20?lC7a<00`0C4`0F4`0301<C00HC0`0>4`04

01<C00PC0`0;4`8021<300<C0P044`<00Q<00`0C4`034`800A<10040000[4`0301<C008C00<04a<0

oa<O4`0301<C070C000Z4`0301<C00<C00<04a<01A<00`0C4`3o4aHC00<04`00LA<002/C00<04a<0

0Q<00`0C4`024`@00a<30?lC4A<200034`00070C000Y4`0301<000@C00<04`000Q<200034`0C00@C

00<04a<0oa>44`00:Q<00`0C4`034`<011<00`0C00034`0301<C0?lCQA<003LC00<04`0011<00`0C

4`3o4h@C000e4`<011<30?lCQQ<00?lCaA<00?lCaA<00?lCaA<00?lCaA<00?lCaA<00001\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.46634, -1.71628, 0.0221164, 0.0221164}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -84.5 0 ]

[.5 .96488 84.5 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -145.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.555) show

222.250000 19.500000 moveto

(C) show

227.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.27033 0 m

.30316 .05105 L

.34309 .11314 L

.3815 .17287 L

.42237 .23642 L

.46172 .29761 L

.49955 .35645 L

.53984 .41909 L

.57861 .47938 L

.61984 .54349 L

.65954 .60523 L

.69774 .66462 L

.73838 .72783 L

.77751 .78867 L

.81909 .85333 L

.85916 .91564 L

s

.85916 .91564 m

.88279 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.381819 0.238095 [

[.02381 .36932 -6 -9 ]

[.02381 .36932 6 0 ]

[.2619 .36932 -6 -9 ]

[.2619 .36932 6 0 ]

[.7381 .36932 -3 -9 ]

[.7381 .36932 3 0 ]

[.97619 .36932 -3 -9 ]

[.97619 .36932 3 0 ]

[1.025 .38182 0 -8 ]

[1.025 .38182 9 8 ]

[.4875 .02468 -24 -4.5 ]

[.4875 .02468 0 4.5 ]

[.4875 .14372 -12 -4.5 ]

[.4875 .14372 0 4.5 ]

[.4875 .26277 -24 -4.5 ]

[.4875 .26277 0 4.5 ]

[.4875 .50087 -18 -4.5 ]

[.4875 .50087 0 4.5 ]

[.4875 .61991 -6 -4.5 ]

[.4875 .61991 0 4.5 ]

[.4875 .73896 -18 -4.5 ]

[.4875 .73896 0 4.5 ]

[.4875 .85801 -6 -4.5 ]

[.4875 .85801 0 4.5 ]

[.5 .93627 -4.5 0 ]

[.5 .93627 4.5 16 ]

[.5 .92377 -137 0 ]

[.5 .92377 137 16 ]

[ 0 0 0 0 ]

[ 1 .91127 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .38182 m

.02381 .38807 L

s

[(-2)] .02381 .36932 0 1 Mshowa

.2619 .38182 m

.2619 .38807 L

s

[(-1)] .2619 .36932 0 1 Mshowa

.7381 .38182 m

.7381 .38807 L

s

[(1)] .7381 .36932 0 1 Mshowa

.97619 .38182 m

.97619 .38807 L

s

[(2)] .97619 .36932 0 1 Mshowa

.125 Mabswid

.07143 .38182 m

.07143 .38557 L

s

.11905 .38182 m

.11905 .38557 L

s

.16667 .38182 m

.16667 .38557 L

s

.21429 .38182 m

.21429 .38557 L

s

.30952 .38182 m

.30952 .38557 L

s

.35714 .38182 m

.35714 .38557 L

s

.40476 .38182 m

.40476 .38557 L

s

.45238 .38182 m

.45238 .38557 L

s

.54762 .38182 m

.54762 .38557 L

s

.59524 .38182 m

.59524 .38557 L

s

.64286 .38182 m

.64286 .38557 L

s

.69048 .38182 m

.69048 .38557 L

s

.78571 .38182 m

.78571 .38557 L

s

.83333 .38182 m

.83333 .38557 L

s

.88095 .38182 m

.88095 .38557 L

s

.92857 .38182 m

.92857 .38557 L

s

.25 Mabswid

0 .38182 m

1 .38182 L

s

gsave

1.025 .38182 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .02468 m

.50625 .02468 L

s

[(-1.5)] .4875 .02468 1 0 Mshowa

.5 .14372 m

.50625 .14372 L

s

[(-1)] .4875 .14372 1 0 Mshowa

.5 .26277 m

.50625 .26277 L

s

[(-0.5)] .4875 .26277 1 0 Mshowa

.5 .50087 m

.50625 .50087 L

s

[(0.5)] .4875 .50087 1 0 Mshowa

.5 .61991 m

.50625 .61991 L

s

[(1)] .4875 .61991 1 0 Mshowa

.5 .73896 m

.50625 .73896 L

s

[(1.5)] .4875 .73896 1 0 Mshowa

.5 .85801 m

.50625 .85801 L

s

[(2)] .4875 .85801 1 0 Mshowa

.125 Mabswid

.5 .04849 m

.50375 .04849 L

s

.5 .0723 m

.50375 .0723 L

s

.5 .0961 m

.50375 .0961 L

s

.5 .11991 m

.50375 .11991 L

s

.5 .16753 m

.50375 .16753 L

s

.5 .19134 m

.50375 .19134 L

s

.5 .21515 m

.50375 .21515 L

s

.5 .23896 m

.50375 .23896 L

s

.5 .28658 m

.50375 .28658 L

s

.5 .31039 m

.50375 .31039 L

s

.5 .3342 m

.50375 .3342 L

s

.5 .35801 m

.50375 .35801 L

s

.5 .40563 m

.50375 .40563 L

s

.5 .42944 m

.50375 .42944 L

s

.5 .45325 m

.50375 .45325 L

s

.5 .47706 m

.50375 .47706 L

s

.5 .52468 m

.50375 .52468 L

s

.5 .54849 m

.50375 .54849 L

s

.5 .5723 m

.50375 .5723 L

s

.5 .5961 m

.50375 .5961 L

s

.5 .64372 m

.50375 .64372 L

s

.5 .66753 m

.50375 .66753 L

s

.5 .69134 m

.50375 .69134 L

s

.5 .71515 m

.50375 .71515 L

s

.5 .76277 m

.50375 .76277 L

s

.5 .78658 m

.50375 .78658 L

s

.5 .81039 m

.50375 .81039 L

s

.5 .8342 m

.50375 .8342 L

s

.5 .00087 m

.50375 .00087 L

s

.5 .88182 m

.50375 .88182 L

s

.5 .90563 m

.50375 .90563 L

s

.25 Mabswid

.5 0 m

.5 .91127 L

s

gsave

.5 .93627 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .92377 -198 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.555) show

298.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

303.000000 15.000000 moveto

(L) show

310.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

317.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

324.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

329.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

333.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .91127 L

0 .91127 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .22529 m

.02576 .22528 L

.03158 .22525 L

.04116 .22519 L

.05434 .22511 L

.07091 .225 L

.09056 .22486 L

.11298 .22469 L

.13776 .22449 L

.1645 .22424 L

.19273 .22395 L

.22197 .22361 L

.25172 .22321 L

.28147 .22273 L

.31071 .22219 L

.33894 .22155 L

.36567 .22084 L

.39046 .22004 L

.41288 .21917 L

.43253 .21826 L

.44909 .21736 L

.46228 .21654 L

.47186 .21587 L

.47768 .21543 L

.47963 .21528 L

s

.47963 .21528 m

.48175 .21511 L

.48809 .21457 L

.49853 .21361 L

.51289 .21208 L

.53094 .20976 L

.55235 .20625 L

.57677 .20098 L

.60377 .1932 L

.6329 .18239 L

.66365 .16877 L

.6955 .15327 L

.72791 .13694 L

.76032 .12062 L

.79217 .10484 L

.82292 .08996 L

.85205 .07625 L

.87905 .06385 L

.90347 .0529 L

.92488 .0435 L

.94293 .03572 L

.95729 .02962 L

.96773 .02523 L

.97407 .02258 L

.97619 .0217 L

s

.47963 .46503 m

.48175 .43791 L

.48809 .41108 L

.49853 .38482 L

.51289 .35941 L

.53094 .33521 L

.55235 .31273 L

.57677 .29268 L

.60377 .27592 L

.6329 .26308 L

.66365 .25405 L

.6955 .248 L

.72791 .24396 L

.76032 .24121 L

.79217 .23928 L

.82292 .23789 L

.85205 .23686 L

.87905 .23608 L

.90347 .2355 L

.92488 .23505 L

.94293 .23472 L

.95729 .23448 L

.96773 .23431 L

.97407 .23422 L

.97619 .23419 L

s

.47963 .46515 m

.48175 .49245 L

.48809 .51981 L

.49853 .54703 L

.51289 .57397 L

.53094 .60049 L

.55235 .62647 L

.57677 .65179 L

.60377 .67633 L

.6329 .69998 L

.66365 .72263 L

.6955 .74419 L

.72791 .76455 L

.76032 .78363 L

.79217 .80134 L

.82292 .81761 L

.85205 .83236 L

.87905 .84553 L

.90347 .85706 L

.92488 .8669 L

.94293 .87502 L

.95729 .88136 L

.96773 .88592 L

.97407 .88866 L

.97619 .88957 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<2074C003o4e8C00<04a<0L1<006@C1@3G4`D00Q<00`0C4`024`0301<C008C00<04a<0

L1<006HC00<04a<0fA<00`0C4`064`0301<000<C00<04a<0L1<004@C00<=4a<06A<300<C00<04a<0

0Q<20<lC0`034`0301<C00PC00@04a<C0P1G4`<=5a<004DC00<=4a<07Q<00`0C4`024`0301<C0=@C

00<04a<01Q<200@C00<04a<0Da<33AXC00154`033A<C01hC00<04a<00Q<00`0C4`3D4`0301<C00HC

00<04a<00a<00`0C4`1A4`8=7A<004HC00<=4a<071<200@C00<04a<0da<200PC0`034`0301<C04lC

0PdO4`00AQ<00`dC4`0R4`80i1<00`0C4`1>4`033A<C01lC00174`033A<C024C00<04a<0ha<204dC

0PdR4`00Aa<00`dC4`0Q4`0301<C0><C00<04a<0BA<33B@C00184`033A<C020C00<04a<0ha<00`0C

4`174`8=9a<004PC00<=4a<081<20>@C00<04a<0A1<33BTC00194`033A<C01lC00<04a<0ha<204<C

0Pd/4`00BQ<00`dC4`0N4`0301<C0><C00<04a<0@1<23BhC001:4`033A<C01hC00<04a<0ha<00`0C

4`0n4`8=<1<004/C00<=4a<07A<20>@C00<04a<0?1<23C8C001<4`033A<C01`C00<04a<0ha<00`0C

4`0k4`033A<C038C001<4`033A<C01`C00<04a<0ha<203XC0Pde4`00CA<00`dC4`0K4`0301<C0><C

00<04a<0=a<23CLC001>4`033A<C01XC0P3T4`0301<C03DC0Pdi4`00Ca<00`dC4`0I4`0301<C0><C

00<04a<0<a<23C/C001?4`033A<C00XC00<04a<00Q<00`0C4`024`0301<C008C00<04a<0ha<2038C

0Pdm4`00D1<00`dC4`084`0301<000LC00<04`000a<00`0C4`3S4`0301<C02hC0`do4`00DA<00`dC

4`024`<00Q<00`0C00094`0401<C4`80i1<00`0C4`0/4`8=@Q<0054C00<=4a<01a<00`0C00074`80

11<00`0C4`3L4`D00Q<00`0C4`0Z4`8=A1<0058C00<=4a<01Q<00`0C00074`0301<C00<C00<04a<0

gQ<00`0C4`024`0301<C02PC0Pe64`00Da<00`dC4`064`0301<C00HC0`034`0301<C0=PC0`034`03

01<C008C0P0W4`8=B1<005<C00<=4a<05A<00`0C4`3N4`0301<C008C00<04a<091<23DXC001D4`03

3A<C01@C0P3O4`0301<C008C00<04a<08Q<23D`C001D4`033A<C01@C00<04a<0gA<200@C00<04a<0

81<23DhC001E4`033A<C01<C00<04a<0ha<201lC0Pe@4`00EQ<00`dC4`0B4`0301<C0><C00<04a<0

6a<33E8C001F4`033A<C018C0P3T4`0301<C01PC0`eE4`00Ea<00`dC4`0A4`0301<C0><C00<04a<0

5A<33EPC000J4`<09A<5014C00<=4a<041<00`0C4`0T4`D091<309<C00<04a<04a<23E/C000J4`03

01<C02LC00<04a<04A<00`dC4`0@4`0301<C02HC00<04a<091<00`0C4`2C4`804A<33EdC000E4`<0

0a<00`0C4`0P4`<00a<00`0C4`0B4`033A<C00lC0P0W4`0301<C02DC00<04a<0TQ<00`0C4`0>4`8=

H1<001/C00<04a<09Q<00`0C4`0C4`033A<C00hC00<04a<09Q<00`0C4`0U4`0301<C098C00<04a<0

2Q<43F8C000J4`0301<002LC00<04a<04a<00`dC4`0>4`0301<C02HC00<04a<091<00`0C002C4`03

01<C008C20eV4`006a<00`0C4`0U4`805Q<00`dC4`0=4`0301<C02DC0P0W4`0301<C08lC20e^4`00

Fa<00`dC4`0=4`80cQ<C3@<C00<04a<0L1<005`C00<=4a<031<00`0C4`294d@=5Q<00`0C4`1`4`00

GA<00`dC4`0;4`0301<C05/C0P264`0301<C070C001M4`033A<C00/C00<04a<0FQ<00`0C4`264`03

01<C04<C5PdG4`005A=900033@0006401Q<00`0C4`264`80;A<G3BdC000I4`0301<C00HC00<04a<0

1A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<01@0C4a<=00<C

00<04a<01A<00a0C4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C

4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00PC00<04a<0QQ<00`0C4`0V4`H=A1<005lC

00<=4a<02A<00a0C4`1J4`0301<008HC00<04a<081<63DXC001P4`033A<C00PC0Q1K4`<0Ma<00`0C

4`024`0301<C008C00<04a<00Q<00`0C4`0K4`D=D1<0064C00<=4a<01a<24=@C00<04`001a<00`0C

00034`0301<C01PC0`eE4`00HA<00`dC4`064`03400@0<lC0`024`0301<000TC00@04a<C0P0F4`<=

F1<0068C00<=4a<01A<00a00403D4`0301<000LC0P044`0301<C01<C0PeK4`00Ha<00`dC4`044`03

400@0=@C00<04`001a<00`0C4`034`0301<C014C0PeM4`00I1<00`dC4`024`0541<00100e1<00`0C

4`064`<00a<00`0C4`0?4`8=Ga<006@C00<=4a<00Q<01A0C01<@0><C0P0>4`8=HA<006DC00T=4a<C

41<04a00ha<00`0C4`0<4`033A<C064C001V4`063A<C41<00Q<00a0C4`3P4`0301<C00/C00<=4a<0

HQ<006HC00D=4a<@4`0200034a0C0>4C00<04a<02A<23FDC001W4`053A<@4`000Q<00a0C4`3P4`03

01<C00PC00<=4a<0IA<006LC00D=41<C00034`0341<C0=lC0P084`033A<C06HC001X4`043A<C00<C

00<@4a<0ga<00`0C4`064`033A<C06LC001X4`0340dC00800Q<00a0C4`3O4`0301<C00DC00<=4a<0

J1<006LC00D@4`dC00044`0341<C08DC0`0Y4`D0:1<00`0C4`044`033A<C024C1@0Y4`<05a<005`C

00<04a<00Q<00`0C4`024`06010C4`d011<00a0C4`254`0301<C02/C00<04a<0:1<200@C00<=4a<0

91<00`0C4`0Y4`0301<C01LC001K4`0301<000LC00<040000Q<00`d04`034`0341<C080C0`034`03

01<C02@C0`034`0301<C02PC00<04a<00Q<00`dC4`0U4`0301<C02XC00<04a<05Q<005/C00<04`00

21<00a004`024`033@0C00<C00<@4a<0QA<00`0C4`0Z4`0301<C02PC00<04a<00Q<00`dC4`0U4`03

01<C02XC00<04a<05Q<005/C00<04`001a<00`0@4`034`0300dC00<C00<@4a<0Q1<00`0C000[4`03

01<C02PC00D04a<C3@0X4`0301<C02TC00<04`005a<005/C00<04`001a<00a0C4`034`0300dC00@C

00<@4a<0Q1<00`0C4`0Y4`80:Q<01@0C4a<=02LC0P0/4`0301<C01HC001L4`0301<C00HC00<@0000

0a<00`0C3@044`0341<C0=`C0P000a<=4`1^4`00I1<00a0C4`044`8000<C3A<00Q<00a0C4`3L4`03

01<=070C001T4`0341<C00@C00@04a<=11<00a0C4`3K4`0301<=06DC0P094`00Ha<00a0C4`054`05

01<C4`d00a<00a0C4`3K4`0300dC06@C00<04a<02A<006<C00<@4a<01A<01@0C4a<=00@C00<@4a<0

Na=P00033@0005`01a<00`0C4`094`00HQ<00a0C4`064`0301<C008C00D=4a<C40224`0301<C00HC

00<04a<01Q<00`0C4`064`0301<C00HC00<04a<01Q<00`0C4`064`0301<C00HC00<04a<01Q<00`0C

4`064`0301<C00HC00<=4a<01Q<00`0C4`064`0301<C00HC00<04a<01Q<00`0C4`064`0301<C00HC

00<04a<01a<00`0C4`064`0301<C00HC00<04a<01Q<00`0C4`094`0301<C00TC001R4`0341<C00HC

0P044`053A<C4a00fa<00`dC4`1T4`0301<000TC001Q4`0341<C00LC00<04a<00a<01@dC4a<@0=XC

00<=01<0IA<300TC001Q4`0341<C00LC00<04a<011<010dC4a3J4`033@0C074C001P4`0341<C00PC

00<04a<01A<010dC4a3H4`043A<0074C001P4`0341<C00PC0P064`043A<C4=PC00<=4`00LQ<005lC

00<@4a<02A<00`0C4`064`043A<C4=LC00<=4`00LQ<005lC00<@4a<02A<00`0C4`074`033A<@0=LC

00<=4`00LQ<005hC00<@4a<02Q<00`0C4`074`043A<C4=DC00<=4a<00P1a4`00GQ<00a0C4`0:4`80

2A<00`dC403E4`043A<C078C001M4`0341<C00/C00<04a<02A<00`dC403D4`043A<C078C001M4`03

41<C00@C1@024`0301<C00XC00<=41<0da<010dC4`1b4`00G1<00a0C4`074`0301<C008C00<04a<0

2Q<00`dC403C4`043A<C078C001K4`0341<C00PC00<04a<00Q<200`C00<=4a00dA<010dC4a<2074C

001K4`0341<C00PC00<04a<00Q<00`0C4`0<4`033A0C0=0C00D=4a<C001b4`00FQ<00a0C4`094`03

01<C008C00<04a<031<00`dC403@4`053A<C4`00LQ<005XC00<@4a<021<200@C00<04a<03A<00`dC

403?4`053A<C4`00LQ<005TC00<@4a<03a<200lC00<=41<0cQ<010dC4a<2074C001H4`0341<C010C

00<04a<03Q<00`dC403?4`043A<C078C001H4`0341<C010C00<04a<03a<00`dC403>4`043A<C078C

001G4`0341<C014C00<04a<03a<00`dC40324`0301<C008C00<04a<00Q<00`0C3@024`0301<C070C

001F4`0341<C018C0P0A4`033A<@0<0C00<04`001a<0100C00d24`0301<C070C001F4`0341<C018C

00<04a<04A<00`dC402o4`0301<000TC00@03A<C0P1a4`00EA<00a0C4`0C4`0301<C014C00<=4a00

_a<00`0C00074`800Q<00`dC001b4`00E1<00a0C4`0D4`0301<C018C00<=4a00_Q<00`0C00074`07

01<C4`dC001b4`00Da<00a0C4`0E4`8051<00`d@4`2n4`0301<C00HC0`0011<=4`1b4`00Da<00a0C

4`0E4`0301<C01<C00<=4a00ba<010dC001a4`00DQ<00a0C4`0F4`0301<C01@C00<=4a00ba<00`d0

4`1a4`00DA<00a0C4`0G4`0301<C01DC00<=41<0bQ<00`d04`1a4`00DA<00a0C4`0G4`805Q<00`dC

403:4`033@0C074C001@4`0341<C01PC00<04a<05Q<00`d@4`3:4`033A<C070C001?4`0341<C00PC

1@024`0301<C008C00<04a<00Q<00`0C4`0F4`033A<@0<XC00<=01<0L1<004lC00<@4a<02Q<00`0C

4`064`0301<000<C00<04a<05a<00`dC40394`0300dC070C001>4`0341<C00/C00<04a<021<0100C

4a<201TC00<=4a00b1<00`0=4`1`4`00CA<00a0C4`0<4`0301<C00HC0P044`0301<C01PC00<=4a00

b1<00`0C3@1`4`00C1<00a0C4`0=4`0301<C00HC00<04a<00a<00`0C4`0I4`033A<@0<LC0P000`dC

4`1^4`00C1<00a0C4`0<4`8021<300<C00<04a<06Q<00`dC40364`0401<C3FlC001;4`0341<C01dC

0P0K4`043A<C4<DC00D04a<C3@1^4`00BQ<00a0C4`0N4`0301<C01/C00<=4a00aA<01@0C4a<=06hC

001:4`0341<C01hC00<04a<06a<010dC4a344`0301<C008C00<=4a<0Ja<004TC00<@4a<07a<00`0C

4`0L4`043A<C4<<C0P034`033A<C06/C00184`0341<C020C0P0N4`043A<C4<8C00<04a<00a<00`dC

4`1Z4`00Aa<00a0C4`0Q4`0301<C01dC00D=4a<C402j4`D00Q<00`0C4`044`033A<C06TC00174`03

41<C024C00<04a<07Q<010dC4a2l4`0301<C008C00<04a<01A<00`dC4`1X4`00AQ<00a0C4`0R4`03

01<C01hC00D=4a<C402k4`0301<C008C0P064`033A<C06PC00154`0341<C02<C0P0P4`053A<C4a00

^Q<00`0C4`024`0301<C00HC00<=4a<0Ia<004@C00<@4a<091<00`0C4`0P4`053A<C4a00^A<00`0C

4`024`0301<C00LC00<=4a<0IQ<004@C00<@4a<091<00`0C4`0P4`053A<C4a00^1<200@C00<04a<0

21<00`dC4`1U4`00@a<00a0C4`0U4`0301<C024C00D=4a<C402m4`0301<C00TC00<=4a<0I1<0048C

00<@4a<09Q<00`0C4`0R4`053A<C4a00_1<200/C00<=4a<0Ha<0044C00<@4a<09a<202<C00<=4a<0

0Q<00a0C4`2i4`0301<C00/C00<=4a<0HQ<0040C00<@4a<0:1<00`0C4`0S4`033A<C008C00<@4a<0

^1<00`0C4`0<4`033A<C064C00104`0341<C028C0`034`0301<C02<C00<=4a<00a<00a0C4`2g4`03

01<C00dC00<=4a<0H1<003lC00<@4a<08a<00`0C4`034`0301<C02@C00<=4a<00Q<00a0C4`2g4`03

01<C00hC0PeP4`00?Q<00a0C4`0U4`0301<C008C0P0V4`033A<C008C00<@4a<0]Q<2014C00<=4a<0

GA<003dC00<@4a<09Q<00`0C4`024`0301<C02DC00<=4a<00a<00a0C4`2e4`0301<C014C00<=4a<0

G1<003dC00<@4a<09A<00`0C00034`0301<C02HC00<=4a<00a<00a0C4`2d4`0301<C018C00<=4a<0

Fa<003`C00<@4a<09a<00`0C4`024`0301<C02LC00<=4a<00a<00a0C4`2c4`0301<C01<C00<=4a<0

FQ<003/C00<@4a<0;A<202PC00<=4a<011<00a0C4`2b4`805A<00`dC4`1I4`00>Q<00a0C4`0^4`03

01<C02PC00<=4a<00a<00a0C4`2b4`0301<C01DC00<=4a<0F1<003XC00<@4a<0;Q<00`0C4`0Y4`03

3A<C00<C00<@4a<0/A<00`0C4`0F4`033A<C05LC000i4`0341<C02lC00<04a<0:A<00`dC4`044`03

41<C0;0C00<04a<05a<23ELC000h4`0341<C030C0P0[4`033A<C00@C00<@4a<0[a<00`0C4`0I4`03

3A<C05@C000g4`0341<C034C00<04a<0:a<00`dC4`034`0341<C0:lC0P0K4`8=E1<003LC00<@4a<0

<A<00`0C4`0/4`033A<C00<C00<@4a<0[Q<00`0C4`0L4`033A<C054C000f4`0341<C038C00<04a<0

;1<00`dC4`044`0341<C09`C1@024`0301<C008C00<04a<00Q<00`0C4`0M4`8=DA<003DC00<@4a<0

<a<202hC00<=4a<011<00a0C4`2M4`0301<C00HC00<04`000a<00`0C4`0O4`033A<C04hC000d4`03

41<C03@C00<04a<0;Q<00`dC4`044`0341<C09`C00<04a<021<0100C4a<2024C0Pe>4`00<a<00a0C

4`0e4`0301<C02hC00<=4a<01A<00a0C4`2K4`0301<C00HC0P044`0301<C028C00<=4a<0Ba<0038C

00<@4a<0=Q<00`0C4`0_4`033A<C00@C00<@4a<0Va<00`0C4`064`0301<C00<C00<04a<08a<23D/C

000a4`0341<C03LC0P0`4`033A<C00DC00<@4a<0VA<200PC0`034`0301<C02DC00<=4a<0B1<0030C

00<@4a<0>1<00`0C4`0`4`033A<C00DC00<@4a<0Z1<00`0C4`0V4`8=B1<002lC00<@4a<0:A<300<C

00<04a<00Q<00`0C4`024`0301<C030C00<=4a<01Q<00a0C4`2W4`80:A<00`dC4`154`00;Q<00a0C

4`0Z4`0301<C00LC00<04`000a<00`0C4`0a4`033A<C00HC00<@4a<0YQ<00`0C4`0Y4`8=AA<002dC

00<@4a<0;1<00`0C4`084`0401<C4`80<a<00`dC4`064`0341<C0:DC00<04a<0:a<23D<C000/4`03

41<C02dC00<04a<01Q<200@C00<04a<0<Q<00`dC4`074`0341<C0:@C00<04a<0;A<23D4C000[4`03

41<C02dC00<04`001a<00`0C4`034`0301<C03<C00<=4a<01a<00a0C4`2S4`80<1<00`dC4`0n4`00

:Q<00a0C4`0_4`0301<C00HC0`034`0301<C03<C00<=4a<021<00a0C4`2R4`0301<C030C0Pdn4`00

:A<00a0C4`0o4`80=A<00`dC4`084`0341<C0:4C00<04a<0<Q<23C`C000X4`0341<C040C00<04a<0

=A<00`dC4`084`0341<C0:0C00<04a<0=1<23CXC000W4`0341<C044C00<04a<0=A<00`dC4`094`03

41<C09lC00<04a<0=Q<23CPC000V4`0341<C048C00<04a<0=Q<00`dC4`094`0341<C09hC0P0i4`8=

=Q<002DC00<@4a<0@a<203PC00<=4a<02A<00a0C4`2M4`0301<C03XC0Pdd4`0091<00a0C4`144`03

01<C03LC00<=4a<02Q<00a0C4`2L4`0301<C03`C0Pdb4`008a<00a0C4`154`0301<C03PC00<=4a<0

2Q<00a0C4`2K4`0301<C03hC0Pd`4`008a<00a0C4`154`0301<C03TC00<=4a<02Q<00a0C4`2J4`80

@A<23BhC000R4`0341<C04HC0P0k4`033A<C00XC00<@4a<0VA<00`0C4`124`8=;1<0024C00<@4a<0

Aa<00`0C4`0j4`033A<C00/C00<@4a<0V1<00`0C4`144`8=:Q<0020C00<@4a<0B1<00`0C4`0k4`03

3A<C00/C00<@4a<0TA<300<C00<04a<0AQ<23BPC000O4`0341<C04TC00<04a<0?1<00`dC4`0;4`03

41<C090C00<04a<00a<00`0C4`184`8=9Q<001hC00<@4a<0BQ<203dC00<=4a<031<00a0C4`2@4`03

01<C008C0P1;4`8=91<001dC00<@4a<0Ba<00`0C4`0m4`033A<C00`C00<@4a<0Sa<00`0C4`024`03

01<C04`C0`dQ4`0071<00a0C4`1<4`0301<C03dC00<=4a<03A<00a0C4`2=4`0301<000<C00<04a<0

Ca<23AlC000K4`0341<C04LC0P044`0301<C03hC00<=4a<03A<00a0C4`2=4`0301<C008C00<04a<0

DA<23AdC000J4`0341<C04XC00D04a<C00104`033A<C00hC00<@4a<0TA<205@C0PdK4`006A<00a0C

4`1:4`0301<C008C0P104`033A<C00dC00<@4a<0TA<00`0C4`1E4`8=6A<006LC00<04a<0ia<00`0C

4`1G4`8=5a<006DC00<04`00jA<00`0C4`1`4`00IQ<00`0C4`3X4`0301<C070C000Z4`<0oa<U4`80

LA<002XC00<04a<0oa<U4`0301<C070C000[4`0301<C00@C00<04a<0oa>@4`00:a<0100C4a<400<C

0`3o4h`C000Z4`0301<0008C0P000a<04`044`0301<C0?lCRQ<002/C00<04a<00a<00`0C00034`03

01<C0?lCRa<0034C00<04`0011<00`0C4`064`0301<C02LC0`0[4`0301<C0?lC:A<001/C0`000a<0

000200`C0`044`<021<00`0C4`0V4`0401<C00lC0`000a<00002008C00<04a<00Q<00`0C4`024`03

01<C00DC00@04a<C1@024`0301<C008C00<04a<00Q<00`0C4`024`0301<C00@C0P354`0301<C03LC

00<04a<01Q<001XC00@04a<091<00`0C4`0U4`0401<C00hC00@04a<01Q<00`0C00074`0301<000@C

1@034`0301<C00HC00<04`000Q<00`0C00024`0301<000@C00<04a<0_A<00`0C4`044`0301<C01<C

00<04a<08a<00`0C4`054`006Q<01@0C4`0C00@000<C0000600]4`<03Q<01@0C4`0C00@000@C01<0

2A<00`0C4`044`0301<C00<C00<04a<021<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`2[4`04

01<C4`@00Q<200HC00<04a<00a<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`054`0401<C4`D0

0Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`044`8011<0100C4a<2004C000K4`<0Ca<00`0C

4`0=4`<01Q<00`0C00074`801a<00`0C4`034`0301<C00HC0P034`800a<200DC00<04a<0ZQ<00`0C

00074`0301<C00@C1@034`0701<C4`0C00074`0301<000@C1@034`0301<C00HC00<04`000Q<00`0C

00024`0301<000@C00<04a<011<00`0C4`024`400A<001dC00<04a<0C1<2014C00<04a<011<00`0C

00074`0301<C00`C00<04a<01Q<00`0C4`024`0301<C008C00<04a<011<00`0C002Z4`0301<0008C

10000a<04`074`0301<C00<C00L04a<C01<000TC00<04a<011<00`0C4`034`0301<C00PC00<04a<0

0Q<00`0C4`024`0301<C008C00<04a<011<00`0C4`034`40000L4`80H1<200LC00<04a<01Q<300/C

0P084`<00Q<3008C0`044`<0Ta<200034`00018C00<04`001a<00`0C4`064`0301<C00<C00L04a<C

01<000LC0P074`0301<C00<C00<04a<01Q<200<C0P034`801A<00`0C4`044`0301<C00<C0@000?lC

DA<00`0C000C4`0301<000LC00<04`003A<01P0C4`0C00LC00<04a<031<00`0C4`064`0301<C008C

00<04a<00Q<00`0C4`044`0301<000<C00<04a<00a<1004C000V4`801Q<20?lC8Q<00`0C4`0C4`03

01<C00HC0`0>4`0401<C00PC0`0;4`8021<3008C0`024`<011<3008C00<04a<00a<2004C000X4`03

01<C008C00<04a<0oa<R4`0301<C070C000W4`0301<C00<C00<04a<01Q<00`0C4`3o4aPC00<04`00

LA<002PC00<04a<00Q<00`0C4`024`<000@C01<C0`3o4a@C0P000a<0001`4`009Q<00`0C00044`03

01<0008C0P024`0301<C008C00<04a<0oa>74`009a<00`0C4`034`<011<0100C4`024`0301<C0?lC

R1<003@C00@04a<00a<00`0C4`3o4hLC000b4`<011<30?lCRA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCaA<00001\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.45289, -1.71128, 0.0220765, 0.0220765}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -82 0 ]

[.5 .96488 82 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -143 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.55) show

217.250000 19.500000 moveto

(C) show

222.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.26959 0 m

.30316 .05203 L

.34309 .11392 L

.3815 .17347 L

.42237 .23681 L

.46172 .2978 L

.49955 .35645 L

.53984 .41889 L

.57861 .47899 L

.61984 .54289 L

.65954 .60444 L

.69774 .66364 L

.73838 .72664 L

.77751 .78729 L

.81909 .85174 L

.85916 .91384 L

s

.85916 .91384 m

.88402 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.380668 0.238095 [

[.02381 .36817 -6 -9 ]

[.02381 .36817 6 0 ]

[.2619 .36817 -6 -9 ]

[.2619 .36817 6 0 ]

[.7381 .36817 -3 -9 ]

[.7381 .36817 3 0 ]

[.97619 .36817 -3 -9 ]

[.97619 .36817 3 0 ]

[1.025 .38067 0 -8 ]

[1.025 .38067 9 8 ]

[.4875 .02353 -24 -4.5 ]

[.4875 .02353 0 4.5 ]

[.4875 .14257 -12 -4.5 ]

[.4875 .14257 0 4.5 ]

[.4875 .26162 -24 -4.5 ]

[.4875 .26162 0 4.5 ]

[.4875 .49972 -18 -4.5 ]

[.4875 .49972 0 4.5 ]

[.4875 .61876 -6 -4.5 ]

[.4875 .61876 0 4.5 ]

[.4875 .73781 -18 -4.5 ]

[.4875 .73781 0 4.5 ]

[.4875 .85686 -6 -4.5 ]

[.4875 .85686 0 4.5 ]

[.5 .93457 -4.5 0 ]

[.5 .93457 4.5 16 ]

[.5 .92207 -134.5 0 ]

[.5 .92207 134.5 16 ]

[ 0 0 0 0 ]

[ 1 .90957 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .38067 m

.02381 .38692 L

s

[(-2)] .02381 .36817 0 1 Mshowa

.2619 .38067 m

.2619 .38692 L

s

[(-1)] .2619 .36817 0 1 Mshowa

.7381 .38067 m

.7381 .38692 L

s

[(1)] .7381 .36817 0 1 Mshowa

.97619 .38067 m

.97619 .38692 L

s

[(2)] .97619 .36817 0 1 Mshowa

.125 Mabswid

.07143 .38067 m

.07143 .38442 L

s

.11905 .38067 m

.11905 .38442 L

s

.16667 .38067 m

.16667 .38442 L

s

.21429 .38067 m

.21429 .38442 L

s

.30952 .38067 m

.30952 .38442 L

s

.35714 .38067 m

.35714 .38442 L

s

.40476 .38067 m

.40476 .38442 L

s

.45238 .38067 m

.45238 .38442 L

s

.54762 .38067 m

.54762 .38442 L

s

.59524 .38067 m

.59524 .38442 L

s

.64286 .38067 m

.64286 .38442 L

s

.69048 .38067 m

.69048 .38442 L

s

.78571 .38067 m

.78571 .38442 L

s

.83333 .38067 m

.83333 .38442 L

s

.88095 .38067 m

.88095 .38442 L

s

.92857 .38067 m

.92857 .38442 L

s

.25 Mabswid

0 .38067 m

1 .38067 L

s

gsave

1.025 .38067 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .02353 m

.50625 .02353 L

s

[(-1.5)] .4875 .02353 1 0 Mshowa

.5 .14257 m

.50625 .14257 L

s

[(-1)] .4875 .14257 1 0 Mshowa

.5 .26162 m

.50625 .26162 L

s

[(-0.5)] .4875 .26162 1 0 Mshowa

.5 .49972 m

.50625 .49972 L

s

[(0.5)] .4875 .49972 1 0 Mshowa

.5 .61876 m

.50625 .61876 L

s

[(1)] .4875 .61876 1 0 Mshowa

.5 .73781 m

.50625 .73781 L

s

[(1.5)] .4875 .73781 1 0 Mshowa

.5 .85686 m

.50625 .85686 L

s

[(2)] .4875 .85686 1 0 Mshowa

.125 Mabswid

.5 .04733 m

.50375 .04733 L

s

.5 .07114 m

.50375 .07114 L

s

.5 .09495 m

.50375 .09495 L

s

.5 .11876 m

.50375 .11876 L

s

.5 .16638 m

.50375 .16638 L

s

.5 .19019 m

.50375 .19019 L

s

.5 .214 m

.50375 .214 L

s

.5 .23781 m

.50375 .23781 L

s

.5 .28543 m

.50375 .28543 L

s

.5 .30924 m

.50375 .30924 L

s

.5 .33305 m

.50375 .33305 L

s

.5 .35686 m

.50375 .35686 L

s

.5 .40448 m

.50375 .40448 L

s

.5 .42829 m

.50375 .42829 L

s

.5 .4521 m

.50375 .4521 L

s

.5 .47591 m

.50375 .47591 L

s

.5 .52353 m

.50375 .52353 L

s

.5 .54733 m

.50375 .54733 L

s

.5 .57114 m

.50375 .57114 L

s

.5 .59495 m

.50375 .59495 L

s

.5 .64257 m

.50375 .64257 L

s

.5 .66638 m

.50375 .66638 L

s

.5 .69019 m

.50375 .69019 L

s

.5 .714 m

.50375 .714 L

s

.5 .76162 m

.50375 .76162 L

s

.5 .78543 m

.50375 .78543 L

s

.5 .80924 m

.50375 .80924 L

s

.5 .83305 m

.50375 .83305 L

s

.5 .88067 m

.50375 .88067 L

s

.5 .90448 m

.50375 .90448 L

s

.25 Mabswid

.5 0 m

.5 .90957 L

s

gsave

.5 .93457 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .92207 -195.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.55) show

293.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

298.000000 15.000000 moveto

(L) show

305.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

312.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

319.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

324.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

328.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .90957 L

0 .90957 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .22374 m

.02576 .22373 L

.03157 .22369 L

.04116 .22364 L

.05434 .22356 L

.0709 .22346 L

.09056 .22332 L

.11297 .22316 L

.13776 .22296 L

.16449 .22272 L

.19272 .22244 L

.22196 .22211 L

.25171 .22172 L

.28145 .22126 L

.31069 .22073 L

.33892 .22012 L

.36566 .21943 L

.39044 .21866 L

.41286 .21782 L

.43251 .21694 L

.44907 .21608 L

.46226 .21528 L

.47184 .21463 L

.47766 .21421 L

.47961 .21406 L

s

.47961 .21406 m

.48173 .2139 L

.48807 .21338 L

.49851 .21245 L

.51287 .21098 L

.53091 .20874 L

.55233 .20535 L

.57675 .20024 L

.60375 .19265 L

.63288 .18201 L

.66364 .16851 L

.69549 .15308 L

.7279 .1368 L

.76031 .12049 L

.79216 .10472 L

.82292 .08986 L

.85204 .07616 L

.87905 .06377 L

.90347 .05283 L

.92488 .04344 L

.94293 .03567 L

.95729 .02957 L

.96773 .02518 L

.97407 .02254 L

.97619 .02166 L

s

.47961 .46391 m

.48173 .4368 L

.48807 .40998 L

.49851 .38372 L

.51287 .35828 L

.53091 .33403 L

.55233 .31147 L

.57675 .29129 L

.60375 .27438 L

.63288 .2614 L

.66364 .25227 L

.69549 .24618 L

.7279 .24213 L

.76031 .23939 L

.79216 .23747 L

.82292 .23609 L

.85204 .23506 L

.87905 .2343 L

.90347 .23372 L

.92488 .23328 L

.94293 .23296 L

.95729 .23272 L

.96773 .23256 L

.97407 .23246 L

.97619 .23243 L

s

.47961 .46403 m

.48173 .49131 L

.48807 .51864 L

.49851 .54584 L

.51287 .57274 L

.53091 .59924 L

.55233 .62518 L

.57675 .65047 L

.60375 .67498 L

.63288 .6986 L

.66364 .72122 L

.69549 .74274 L

.7279 .76307 L

.76031 .78213 L

.79216 .79981 L

.82292 .81605 L

.85204 .83078 L

.87905 .84393 L

.90347 .85545 L

.92488 .86528 L

.94293 .87338 L

.95729 .87972 L

.96773 .88427 L

.97407 .887 L

.97619 .88792 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<00`0C4`1`4`00oa=B4`0301<C070C001T4`D0ea<5008C00<04a<00Q<00`0C4`024`03

01<C070C001V4`0301<C0=TC00<04a<01Q<00`0C00034`0301<C070C00144`033A<C01TC0`034`03

01<C008C0P3?4`<00a<00`0C4`084`0401<C4`80Ea<33ALC00154`033A<C01hC00<04a<00Q<00`0C

4`3D4`0301<C00HC0P044`0301<C05@C0PdJ4`00AA<00`dC4`0N4`0301<C008C00<04a<0e1<00`0C

4`064`0301<C00<C00<04a<0DQ<23A`C00164`033A<C01`C0P044`0301<C0=<C0P084`<00a<00`0C

4`1@4`8=7Q<004HC00<=4a<08Q<20>@C00<04a<0CQ<23B0C00174`033A<C024C00<04a<0ha<204dC

0PdR4`00Aa<00`dC4`0Q4`0301<C0><C00<04a<0BA<33B@C00184`033A<C020C00<04a<0ha<00`0C

4`174`8=9a<004PC00<=4a<081<20>@C00<04a<0A1<33BTC00194`033A<C01lC00<04a<0ha<204<C

0Pd/4`00BQ<00`dC4`0N4`0301<C0><C00<04a<0@1<23BhC001:4`033A<C01hC00<04a<0ha<00`0C

4`0n4`8=<1<004/C00<=4a<07A<20>@C00<04a<0?1<23C8C001<4`033A<C01`C00<04a<0ha<00`0C

4`0k4`033A<C038C001<4`033A<C01`C00<04a<0ha<203XC0Pde4`00CA<00`dC4`0K4`0301<C0><C

00<04a<0=a<23CLC001=4`033A<C01/C0P3T4`0301<C03DC0Pdi4`00CQ<00`dC4`0J4`0301<C0><C

00<04a<0<a<23C/C001?4`033A<C00XC00<04a<00Q<00`0C4`024`0301<C008C00<04a<0ha<2038C

0Pdm4`00Ca<00`dC4`094`0301<000LC00<04`000a<00`0C4`3S4`0301<C02lC0Pdo4`00D1<00`dC

4`034`<00Q<00`0C00094`0401<C4`80i1<00`0C4`0]4`8=@A<0054C00<=4a<01a<00`0C00074`80

11<00`0C4`3L4`D00Q<00`0C4`0[4`8=@a<0054C00<=4a<01a<00`0C00074`0301<C00<C00<04a<0

gQ<00`0C4`024`0301<C02PC0`e54`00DQ<00`dC4`074`0301<C00HC0`034`0301<C0=PC0`034`03

01<C008C0P0W4`8=B1<005<C00<=4a<05A<00`0C4`3N4`0301<C008C00<04a<091<23DXC001C4`03

3A<C01DC0P3O4`0301<C008C00<04a<08Q<23D`C001D4`033A<C01@C00<04a<0gA<200@C00<04a<0

81<23DhC001E4`033A<C01<C00<04a<0ha<201lC0Pe@4`00EQ<00`dC4`0B4`0301<C0><C00<04a<0

6a<33E8C001F4`033A<C018C0P3T4`0301<C01PC0`eE4`00Ea<00`dC4`0A4`0301<C0><C00<04a<0

5A<33EPC000J4`<09A<5014C00<=4a<041<00`0C4`0T4`D091<309<C00<04a<04a<23E/C000J4`03

01<C02LC00<04a<04A<00`dC4`0@4`0301<C02HC00<04a<091<00`0C4`2C4`804A<33EdC000E4`<0

0a<00`0C4`0P4`<00a<00`0C4`0B4`033A<C00lC0P0W4`0301<C02DC00<04a<0TQ<00`0C4`0>4`8=

H1<001/C00<04a<09Q<00`0C4`0C4`033A<C00hC00<04a<09Q<00`0C4`0U4`0301<C098C00<04a<0

2Q<43F8C000J4`0301<002LC00<04a<04a<00`dC4`0>4`0301<C02HC00<04a<091<00`0C002C4`03

01<C008C20eV4`006a<00`0C4`0U4`805Q<00`dC4`0=4`0301<C02DC0P0W4`0301<C08dC2Pe^4`00

Fa<00`dC4`0=4`80b1<G3@DC00<04a<0L1<005`C00<=4a<031<00`0C4`284cl=71<00`0C4`1`4`00

GA<00`dC4`0;4`0301<C05/C0P264`0301<C070C001M4`033A<C00/C00<04a<0FQ<00`0C4`264`03

01<C03hC6`dG4`005A=900033@0006401Q<00`0C4`264`80;Q<A3C8C000I4`0301<C00HC00<04a<0

1A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<01@0C4a<=00<C

00<04a<01A<00a0C4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C

4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00PC00<04a<0QQ<00`0C4`0Q4``=@a<005lC

00<=4a<02A<00a0C4`1J4`0301<007LC00<04a<00Q<00`0C4`024`0301<C008C00<04a<07Q<33DlC

001P4`033A<C00PC0Q1K4`<0MQ<00`0C00074`0301<000<C00<04a<06Q<43E8C001Q4`033A<C00LC

0Q3?4`<00Q<00`0C00094`0401<C4`805a<43EHC001Q4`033A<C00HC00<@0100e1<00`0C00074`80

11<00`0C4`0D4`8=FQ<0068C00<=4a<01A<00a00403D4`0301<000LC00<04a<00a<00`0C4`0B4`8=

G1<006<C00<=4a<011<00a00403E4`0301<C00HC0`034`0301<C014C00<=4a<0G1<006@C00<=4a<0

0Q<01A0C000@0><C00<04a<03a<23ElC001T4`033A<C008C00D@4`0C403S4`803Q<23F4C001U4`09

3A<C4a0C01<@0><C00<04a<031<00`dC4`1Q4`00IQ<01PdC4a0C008C00<@4a<0h1<00`0C4`0;4`03

3A<C068C001V4`053A<C41<00P000a<@4`3Q4`0301<C00TC0PeU4`00Ia<01@dC41<0008C00<@4a<0

h1<00`0C4`084`033A<C06DC001W4`053A0C4`000a<00a0C4`3O4`8021<00`dC4`1V4`00J1<010dC

4`034`0341<C0=lC00<04a<01Q<00`dC4`1W4`00J1<00a0=4`02008C00<@4a<0ga<00`0C4`054`03

3A<C06PC001W4`0541<=4`0011<00a0C4`244`<0:Q<502PC00<04a<011<00`dC4`0Q4`D0:A<301LC

001L4`0301<C008C00<04a<00Q<01P0@4a<=00@C00<@4a<0Q1<00`0C4`0/4`0301<C02PC0P044`03

3A<C02@C00<04a<0:A<00`0C4`0G4`00Fa<00`0C00074`030100008C00<=01<00a<00a0C4`1o4`<0

0a<00`0C4`0U4`<00a<00`0C4`0X4`0301<C008C00<=4a<09A<00`0C4`0Z4`0301<C01HC001K4`03

01<000PC00<@01<00Q<00`d04`034`0341<C08@C00<04a<0:a<00`0C4`0X4`0301<C008C00<=4a<0

9A<00`0C4`0Z4`0301<C01HC001K4`0301<000LC00<041<00a<00`0=4`034`0341<C08<C00<04`00

;1<00`0C4`0X4`0501<C4`d0:1<00`0C4`0Y4`0301<001LC001K4`0301<000LC00<@4a<00a<00`0=

4`044`0341<C08<C00<04a<0:Q<202XC00D04a<C3@0W4`80;1<00`0C4`0F4`00G1<00`0C4`064`03

400000<C00<04`d011<00a0C4`3L4`8000<C3A<0KQ<006@C00<@4a<011<200034`dC008C00<@4a<0

g1<00`0C3@1`4`00I1<00a0C4`044`0401<C3@@C00<@4a<0fa<00`0C3@1U4`802A<006<C00<@4a<0

1A<01@0C4a<=00<C00<@4a<0fa<00`0=4`1T4`0301<C00TC001S4`0341<C00DC00D04a<C3@044`03

41<C07/CH0000`d0001L00LC00<04a<02A<0068C00<@4a<01Q<00`0C4`024`053A<C4a00PA<00`0C

4`064`0301<C00HC00<04a<01a<00`0C4`064`0301<C00HC00<04a<01Q<00`0C4`064`0301<C00HC

00<04a<01Q<00`0C4`064`033A<C00HC00<04a<01Q<00`0C4`064`0301<C00HC00<04a<01Q<00`0C

4`074`0301<C00HC00<04a<01Q<00`0C4`064`0301<C00HC00<04a<02A<00`0C4`094`00HQ<00a0C

4`064`8011<01@dC4a<@0=/C00<=4a<0I1<00`0C00094`00HA<00a0C4`074`0301<C00<C00D=4a<C

403J4`033@0C06DC0`094`00HA<00a0C4`074`0301<C00@C00@=4a<@fQ<00`d04`1a4`00H1<00a0C

4`084`0301<C00DC00@=4a<@f1<010dC001a4`00H1<00a0C4`084`801Q<010dC4a3H4`033A<0078C

001O4`0341<C00TC00<04a<01Q<010dC4a3G4`033A<0078C001O4`0341<C00TC00<04a<01a<00`dC

403G4`033A<0078C001N4`0341<C00XC00<04a<01a<010dC4a3E4`033A<C0080LA<005hC00<@4a<0

2Q<200TC00<=4a00eA<010dC4`1b4`00GA<00a0C4`0;4`0301<C00TC00<=4a00e1<010dC4`1b4`00

GA<00a0C4`044`D00Q<00`0C4`0:4`033A0C0=<C00@=4a<0LQ<005`C00<@4a<01a<00`0C4`024`03

01<C00XC00<=4a00da<010dC4`1b4`00Fa<00a0C4`084`0301<C008C0P0<4`033A<@0=4C00@=4a<C

0P1a4`00Fa<00a0C4`084`0301<C008C00<04a<031<00`d@4`3@4`053A<C4`00LQ<005XC00<@4a<0

2A<00`0C4`024`0301<C00`C00<=4a00d1<01@dC4a<0078C001J4`0341<C00PC0P044`0301<C00dC

00<=4a00ca<01@dC4a<0078C001I4`0341<C00lC0P0?4`033A0C0<hC00@=4a<C0P1a4`00F1<00a0C

4`0@4`0301<C00hC00<=4a00ca<010dC4`1b4`00F1<00a0C4`0@4`0301<C00lC00<=4a00cQ<010dC

4`1b4`00Ea<00a0C4`0A4`0301<C00lC00<=4a00`Q<00`0C4`024`0301<C008C00<04`d00Q<00`0C

4`1`4`00EQ<00a0C4`0B4`804A<00`dC40304`0301<000LC00@04`0=0Q<00`0C4`1`4`00EQ<00a0C

4`0B4`0301<C014C00<=4a00_a<00`0C00094`0400dC4`80LA<005DC00<@4a<04a<00`0C4`0A4`03

3A<@0;lC00<04`001a<2008C00<=4`00LQ<005@C00<@4a<051<00`0C4`0B4`033A<@0;hC00<04`00

1a<01`0C4a<=4`00LQ<005<C00<@4a<05A<201@C00<=41<0_Q<00`0C4`064`<000@C3A<0LQ<005<C

00<@4a<05A<00`0C4`0C4`033A<@0</C00@=4`00LA<0058C00<@4a<05Q<00`0C4`0D4`033A<@0</C

00<=01<0LA<0054C00<@4a<05a<00`0C4`0E4`033A0C0<XC00<=01<0LA<0054C00<@4a<05a<201HC

00<=4a00bQ<00`d04`1a4`00D1<00a0C4`0H4`0301<C01HC00<=41<0bQ<00`dC4`1`4`00Ca<00a0C

4`084`D00Q<00`0C4`024`0301<C008C00<04a<05Q<00`dC403:4`033@0C070C001?4`0341<C00XC

00<04a<01Q<00`0C00034`0301<C01LC00<=4a00bA<00`0=4`1`4`00CQ<00a0C4`0;4`0301<C00PC

00@04a<C0P0I4`033A<@0<PC00<03A<0L1<004dC00<@4a<031<00`0C4`064`8011<00`0C4`0H4`03

3A<@0<PC00<04`d0L1<004`C00<@4a<03A<00`0C4`064`0301<C00<C00<04a<06A<00`dC40374`80

00<=4a<0KQ<004`C00<@4a<031<200PC0`034`0301<C01XC00<=4a00aQ<0100C4`e_4`00Ba<00a0C

4`0M4`806a<010dC4a354`0501<C4`d0KQ<004XC00<@4a<07Q<00`0C4`0K4`033A<@0<DC00D04a<C

3@1^4`00BQ<00a0C4`0N4`0301<C01/C00@=4a<@a1<00`0C4`024`033A<C06/C00194`0341<C01lC

00<04a<071<010dC4a334`800a<00`dC4`1[4`00B1<00a0C4`0P4`807Q<010dC4a324`0301<C00<C

00<=4a<0JQ<004LC00<@4a<08A<00`0C4`0M4`053A<C4a00^Q<5008C00<04a<011<00`dC4`1Y4`00

Aa<00a0C4`0Q4`0301<C01hC00@=4a<@_1<00`0C4`024`0301<C00DC00<=4a<0J1<004HC00<@4a<0

8Q<00`0C4`0N4`053A<C4a00^a<00`0C4`024`801Q<00`dC4`1X4`00AA<00a0C4`0S4`8081<01@dC

4a<@0;XC00<04a<00Q<00`0C4`064`033A<C06LC00144`0341<C02@C00<04a<081<01@dC4a<@0;TC

00<04a<00Q<00`0C4`074`033A<C06HC00144`0341<C02@C00<04a<081<01@dC4a<@0;PC0P044`03

01<C00PC00<=4a<0IA<004<C00<@4a<09A<00`0C4`0Q4`053A<C4a00_A<00`0C4`094`033A<C06@C

00124`0341<C02HC00<04a<08Q<01@dC4a<@0;`C0P0;4`033A<C06<C00114`0341<C02LC0P0S4`03

3A<C008C00<@4a<0^A<00`0C4`0;4`033A<C068C00104`0341<C02PC00<04a<08a<00`dC4`024`03

41<C0;PC00<04a<031<00`dC4`1Q4`00@1<00a0C4`0R4`<00a<00`0C4`0S4`033A<C00<C00<@4a<0

]a<00`0C4`0=4`033A<C060C000o4`0341<C02<C00<04a<00a<00`0C4`0T4`033A<C008C00<@4a<0

]a<00`0C4`0>4`8=H1<003hC00<@4a<09A<00`0C4`024`809Q<00`dC4`024`0341<C0;HC0P0A4`03

3A<C05dC000m4`0341<C02HC00<04a<00Q<00`0C4`0U4`033A<C00<C00<@4a<0]A<00`0C4`0A4`03

3A<C05`C000m4`0341<C02DC00<04`000a<00`0C4`0V4`033A<C00<C00<@4a<0]1<00`0C4`0B4`03

3A<C05/C000l4`0341<C02LC00<04a<00Q<00`0C4`0W4`033A<C00<C00<@4a<0/a<00`0C4`0C4`03

3A<C05XC000k4`0341<C02dC0P0X4`033A<C00@C00<@4a<0/Q<201DC00<=4a<0FA<003XC00<@4a<0

;Q<00`0C4`0X4`033A<C00<C00<@4a<0/Q<00`0C4`0E4`033A<C05PC000j4`0341<C02hC00<04a<0

:A<00`dC4`034`0341<C0;4C00<04a<05Q<00`dC4`1G4`00>A<00a0C4`0_4`0301<C02TC00<=4a<0

11<00a0C4`2`4`0301<C01LC0PeG4`00>1<00a0C4`0`4`80:a<00`dC4`044`0341<C0:lC00<04a<0

6A<00`dC4`1D4`00=a<00a0C4`0a4`0301<C02/C00<=4a<00a<00a0C4`2_4`806a<23E@C000g4`03

41<C034C00<04a<0;1<00`dC4`034`0341<C0:hC00<04a<071<00`dC4`1A4`00=Q<00a0C4`0b4`03

01<C02`C00<=4a<011<00a0C4`2L4`D00Q<00`0C4`024`0301<C008C00<04a<07A<23E4C000e4`03

41<C03<C0P0^4`033A<C00@C00<@4a<0WA<00`0C4`064`0301<000<C00<04a<07a<00`dC4`1>4`00

=1<00a0C4`0d4`0301<C02hC00<=4a<011<00a0C4`2L4`0301<C00PC00@04a<C0P0Q4`8=CQ<003<C

00<@4a<0=A<00`0C4`0^4`033A<C00DC00<@4a<0Va<00`0C4`064`8011<00`0C4`0R4`033A<C04/C

000b4`0341<C03HC00<04a<0;a<00`dC4`044`0341<C09/C00<04a<01Q<00`0C4`034`0301<C02<C

0Pe;4`00<A<00a0C4`0g4`80<A<00`dC4`044`0341<C09TC0P084`<00a<00`0C4`0U4`8=BA<0030C

00<@4a<0>1<00`0C4`0`4`033A<C00DC00<@4a<0Z1<00`0C4`0W4`8=Aa<002lC00<@4a<0:A<300<C

00<04a<00Q<00`0C4`024`0301<C034C00<=4a<01A<00a0C4`2W4`80:Q<00`dC4`144`00;Q<00a0C

4`0Z4`0301<C00LC00<04`000a<00`0C4`0a4`033A<C00HC00<@4a<0YQ<00`0C4`0Z4`8=A1<002dC

00<@4a<0;1<00`0C4`084`0401<C4`80<a<00`dC4`064`0341<C0:DC00<04a<0;1<00`dC4`114`00

;1<00a0C4`0]4`0301<C00HC0P044`0301<C03<C00<=4a<01Q<00a0C4`2T4`0301<C02dC0Pe14`00

:a<00a0C4`0]4`0301<000LC00<04a<00a<00`0C4`0c4`033A<C00LC00<@4a<0Xa<2030C00<=4a<0

?Q<002XC00<@4a<0;a<00`0C4`064`<00a<00`0C4`0d4`033A<C00LC00<@4a<0XQ<00`0C4`0`4`8=

?Q<002TC00<@4a<0?a<203HC00<=4a<01a<00a0C4`2Q4`0301<C038C0Pdl4`00:1<00a0C4`104`03

01<C03DC00<=4a<021<00a0C4`2P4`0301<C03@C0Pdj4`009a<00a0C4`114`0301<C03HC00<=4a<0

21<00a0C4`2O4`0301<C03HC0Pdh4`009Q<00a0C4`124`0301<C03LC00<=4a<021<00a0C4`2N4`80

>A<23CHC000U4`0341<C04<C0P0h4`033A<C00TC00<@4a<0WA<00`0C4`0j4`8==1<002@C00<@4a<0

A1<00`0C4`0h4`033A<C00TC00<@4a<0W1<00`0C4`0l4`8=<Q<002<C00<@4a<0AA<00`0C4`0h4`03

3A<C00XC00<@4a<0Va<00`0C4`0n4`8=<1<002<C00<@4a<0AA<00`0C4`0i4`033A<C00XC00<@4a<0

VQ<2044C0Pd^4`008Q<00a0C4`164`80>a<00`dC4`0:4`0341<C09TC00<04a<0@Q<23B`C000Q4`03

41<C04LC00<04a<0>Q<00`dC4`0;4`0341<C09PC00<04a<0A1<23BXC000P4`0341<C04PC00<04a<0

>a<00`dC4`0;4`0341<C094C0`034`0301<C04HC0PdX4`007a<00a0C4`194`0301<C03`C00<=4a<0

2a<00a0C4`2@4`0301<C00<C00<04a<0B1<23BHC000N4`0341<C04XC0P0m4`033A<C00`C00<@4a<0

T1<00`0C4`024`80Ba<23B@C000M4`0341<C04/C00<04a<0?A<00`dC4`0<4`0341<C08lC00<04a<0

0Q<00`0C4`1<4`<=8A<001`C00<@4a<0C1<00`0C4`0m4`033A<C00dC00<@4a<0SA<00`0C00034`03

01<C04lC0PdO4`006a<00a0C4`174`8011<00`0C4`0n4`033A<C00dC00<@4a<0SA<00`0C4`024`03

01<C054C0PdM4`006Q<00a0C4`1:4`0501<C4`00@1<00`dC4`0>4`0341<C094C0P1D4`8=6a<001TC

00<@4a<0BQ<00`0C4`024`80@1<00`dC4`0=4`0341<C094C00<04a<0EA<23ATC001W4`0301<C0>LC

00<04a<0Ea<23ALC001U4`0301<00>TC00<04a<0L1<006HC00<04a<0j1<00`0C4`1`4`00;1<30?lC

8a<2074C000/4`0301<C0?lC8a<00`0C4`1`4`00;A<00`0C4`054`0301<C0?lCSA<002dC00@04a<C

0`0011<04a<30?lCRQ<002`C00<04`000Q<2008C00<04a<00Q<00`0C4`3o4hPC000]4`0301<C00<C

00@04a<00Q<00`0C4`3o4hTC000c4`0401<C00<C00<04a<01Q<00`0C4`0U4`<0;A<00`0C4`3o4bLC

000M4`<000<C00000P0<4`<011<300PC00<04a<091<0100C4`0A4`<000<C00000P024`0301<C008C

00<04a<00Q<00`0C4`054`0401<C4`D00Q<00`0C4`024`0301<C008C00<04a<011<20</C00<04a<0

<Q<00`0C4`084`0071<0100C4`0T4`0301<C02<C00@04a<041<0100C4`064`0301<000LC00<04`00

11<500<C00<04a<01Q<00`0C00024`0301<000@C00<04a<0`a<00`0C4`044`0301<C01<C00<04a<0

7Q<00`0C4`074`0071<01@0C4`0C00@000<C0000600[4`<041<01@0C4`0C00@000@C01<02A<00`0C

4`044`0301<C00<C00<04a<021<00`0C4`024`0301<C008C00<04a<0/A<0100C4a<4008C0P064`03

01<C00<C00<04a<00Q<00`0C4`024`0301<C008C00<04a<01A<0100C4a<5008C00<04a<00Q<00`0C

4`024`0301<C00@C0P044`0401<C4`800A<10040000M4`<0CA<00`0C4`0?4`<01Q<00`0C00074`80

1a<00`0C4`034`0301<C00HC0P034`801A<00`0C4`2`4`0301<000LC00<04a<011<500<C00L04a<C

01<000LC00<04`0011<500<C00<04a<01Q<00`0C00024`0301<000@C00<04a<011<00`0C4`024`03

01<0004C000O4`0301<C04XC0P0C4`0301<C00@C00<04`001a<00`0C4`0<4`0301<C00HC00<04a<0

0Q<00`0C4`044`0301<00;0C00<04`000Q<400034`0C00LC00<04a<00a<01`0C4a<04`002A<00`0C

4`044`0301<C00<C00<04a<021<00`0C4`024`0301<C008C00<04a<011<00`0C4`034`400A<14`00

7Q<2060C0P074`0301<C00HC0`0;4`8021<3008C0`044`<0UQ<200034`0001DC00<04`001a<00`0C

4`064`0301<C00<C00L04a<C01<000LC0P074`0301<C00<C00<04a<01Q<200<C0P054`0301<C00@C

00<04a<00a<1004C0A<00?lCDA<00`0C000F4`0301<000LC00<04`003A<01P0C4`0C00LC00<04a<0

31<00`0C4`064`0301<C008C00<04a<011<00`0C00034`0301<C00<C00<04`000A<002TC0P064`80

oa<O4`0301<C01HC00<04a<01Q<300hC00@04a<021<300/C0P084`<00Q<300@C0`024`0301<C00<C

0P014`400@0002/C00<04a<00Q<00`0C4`3o4alC00<04a<0L1<002XC00<04a<00a<00`0C4`054`03

01<C0?lC5Q<00`0C001a4`00:a<00`0C4`024`0301<C008C10034`<0oa<A4`8000<C0000L1<002TC

00<04`0011<00`0C00024`8000<C01<011<00`0C4`3o4h@C000Z4`0301<C00<C0`044`0301<000<C

00<04a<0oa>54`00=a<00`0C00044`0301<C0?lCQ1<003DC0`044`<0oa>64`00oa?54`00oa?54`00

oa?54`00oa?54`00oa?54`00\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.44001, -1.70661, 0.0220384, 0.0220384}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -84.5 0 ]

[.5 .96488 84.5 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -145.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.545) show

222.250000 19.500000 moveto

(C) show

227.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.26884 0 m

.30316 .05302 L

.34309 .11471 L

.3815 .17406 L

.42237 .2372 L

.46172 .29799 L

.49955 .35645 L

.53984 .41869 L

.57861 .4786 L

.61984 .54229 L

.65954 .60364 L

.69774 .66265 L

.73838 .72544 L

.77751 .7859 L

.81909 .85014 L

.85916 .91205 L

s

.85916 .91205 m

.88527 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.379509 0.238095 [

[.02381 .36701 -6 -9 ]

[.02381 .36701 6 0 ]

[.2619 .36701 -6 -9 ]

[.2619 .36701 6 0 ]

[.7381 .36701 -3 -9 ]

[.7381 .36701 3 0 ]

[.97619 .36701 -3 -9 ]

[.97619 .36701 3 0 ]

[1.025 .37951 0 -8 ]

[1.025 .37951 9 8 ]

[.4875 .02237 -24 -4.5 ]

[.4875 .02237 0 4.5 ]

[.4875 .14141 -12 -4.5 ]

[.4875 .14141 0 4.5 ]

[.4875 .26046 -24 -4.5 ]

[.4875 .26046 0 4.5 ]

[.4875 .49856 -18 -4.5 ]

[.4875 .49856 0 4.5 ]

[.4875 .6176 -6 -4.5 ]

[.4875 .6176 0 4.5 ]

[.4875 .73665 -18 -4.5 ]

[.4875 .73665 0 4.5 ]

[.4875 .8557 -6 -4.5 ]

[.4875 .8557 0 4.5 ]

[.5 .93287 -4.5 0 ]

[.5 .93287 4.5 16 ]

[.5 .92037 -137 0 ]

[.5 .92037 137 16 ]

[ 0 0 0 0 ]

[ 1 .90787 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .37951 m

.02381 .38576 L

s

[(-2)] .02381 .36701 0 1 Mshowa

.2619 .37951 m

.2619 .38576 L

s

[(-1)] .2619 .36701 0 1 Mshowa

.7381 .37951 m

.7381 .38576 L

s

[(1)] .7381 .36701 0 1 Mshowa

.97619 .37951 m

.97619 .38576 L

s

[(2)] .97619 .36701 0 1 Mshowa

.125 Mabswid

.07143 .37951 m

.07143 .38326 L

s

.11905 .37951 m

.11905 .38326 L

s

.16667 .37951 m

.16667 .38326 L

s

.21429 .37951 m

.21429 .38326 L

s

.30952 .37951 m

.30952 .38326 L

s

.35714 .37951 m

.35714 .38326 L

s

.40476 .37951 m

.40476 .38326 L

s

.45238 .37951 m

.45238 .38326 L

s

.54762 .37951 m

.54762 .38326 L

s

.59524 .37951 m

.59524 .38326 L

s

.64286 .37951 m

.64286 .38326 L

s

.69048 .37951 m

.69048 .38326 L

s

.78571 .37951 m

.78571 .38326 L

s

.83333 .37951 m

.83333 .38326 L

s

.88095 .37951 m

.88095 .38326 L

s

.92857 .37951 m

.92857 .38326 L

s

.25 Mabswid

0 .37951 m

1 .37951 L

s

gsave

1.025 .37951 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .02237 m

.50625 .02237 L

s

[(-1.5)] .4875 .02237 1 0 Mshowa

.5 .14141 m

.50625 .14141 L

s

[(-1)] .4875 .14141 1 0 Mshowa

.5 .26046 m

.50625 .26046 L

s

[(-0.5)] .4875 .26046 1 0 Mshowa

.5 .49856 m

.50625 .49856 L

s

[(0.5)] .4875 .49856 1 0 Mshowa

.5 .6176 m

.50625 .6176 L

s

[(1)] .4875 .6176 1 0 Mshowa

.5 .73665 m

.50625 .73665 L

s

[(1.5)] .4875 .73665 1 0 Mshowa

.5 .8557 m

.50625 .8557 L

s

[(2)] .4875 .8557 1 0 Mshowa

.125 Mabswid

.5 .04618 m

.50375 .04618 L

s

.5 .06998 m

.50375 .06998 L

s

.5 .09379 m

.50375 .09379 L

s

.5 .1176 m

.50375 .1176 L

s

.5 .16522 m

.50375 .16522 L

s

.5 .18903 m

.50375 .18903 L

s

.5 .21284 m

.50375 .21284 L

s

.5 .23665 m

.50375 .23665 L

s

.5 .28427 m

.50375 .28427 L

s

.5 .30808 m

.50375 .30808 L

s

.5 .33189 m

.50375 .33189 L

s

.5 .3557 m

.50375 .3557 L

s

.5 .40332 m

.50375 .40332 L

s

.5 .42713 m

.50375 .42713 L

s

.5 .45094 m

.50375 .45094 L

s

.5 .47475 m

.50375 .47475 L

s

.5 .52237 m

.50375 .52237 L

s

.5 .54618 m

.50375 .54618 L

s

.5 .56999 m

.50375 .56999 L

s

.5 .59379 m

.50375 .59379 L

s

.5 .64141 m

.50375 .64141 L

s

.5 .66522 m

.50375 .66522 L

s

.5 .68903 m

.50375 .68903 L

s

.5 .71284 m

.50375 .71284 L

s

.5 .76046 m

.50375 .76046 L

s

.5 .78427 m

.50375 .78427 L

s

.5 .80808 m

.50375 .80808 L

s

.5 .83189 m

.50375 .83189 L

s

.5 .87951 m

.50375 .87951 L

s

.5 .90332 m

.50375 .90332 L

s

.25 Mabswid

.5 0 m

.5 .90787 L

s

gsave

.5 .93287 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .92037 -198 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.545) show

298.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

303.000000 15.000000 moveto

(L) show

310.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

317.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

324.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

329.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

333.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .90787 L

0 .90787 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .22218 m

.02576 .22217 L

.03157 .22213 L

.04116 .22208 L

.05434 .222 L

.0709 .2219 L

.09056 .22177 L

.11297 .22162 L

.13775 .22142 L

.16449 .22119 L

.19271 .22092 L

.22195 .2206 L

.2517 .22022 L

.28144 .21978 L

.31068 .21927 L

.3389 .21868 L

.36564 .21801 L

.39042 .21726 L

.41284 .21646 L

.43249 .21561 L

.44905 .21478 L

.46224 .21401 L

.47182 .21339 L

.47763 .21298 L

.47958 .21284 L

s

.47958 .21284 m

.48171 .21268 L

.48804 .21219 L

.49848 .21129 L

.51285 .20987 L

.53089 .20771 L

.55231 .20444 L

.57673 .19949 L

.60373 .19208 L

.63286 .18163 L

.66362 .16826 L

.69548 .1529 L

.72789 .13665 L

.7603 .12037 L

.79215 .10462 L

.82291 .08977 L

.85204 .07607 L

.87904 .06369 L

.90346 .05276 L

.92488 .04338 L

.94292 .03561 L

.95729 .02952 L

.96773 .02514 L

.97407 .0225 L

.97619 .02162 L

s

.47958 .46279 m

.48171 .43569 L

.48804 .40887 L

.49848 .3826 L

.51285 .35715 L

.53089 .33285 L

.55231 .3102 L

.57673 .2899 L

.60373 .27283 L

.63286 .2597 L

.66362 .25047 L

.69548 .24434 L

.72789 .24028 L

.7603 .23755 L

.79215 .23564 L

.82291 .23427 L

.85204 .23326 L

.87904 .2325 L

.90346 .23193 L

.92488 .2315 L

.94292 .23118 L

.95729 .23094 L

.96773 .23078 L

.97407 .23069 L

.97619 .23066 L

s

.47958 .4629 m

.48171 .49016 L

.48804 .51747 L

.49848 .54463 L

.51285 .57151 L

.53089 .59797 L

.55231 .62389 L

.57673 .64914 L

.60373 .67362 L

.63286 .6972 L

.66362 .71979 L

.69548 .74129 L

.72789 .76159 L

.7603 .78061 L

.79215 .79827 L

.82291 .81449 L

.85204 .8292 L

.87904 .84233 L

.90346 .85383 L

.92488 .86365 L

.94292 .87174 L

.95729 .87807 L

.96773 .88261 L

.97407 .88534 L

.97619 .88625 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<00`0C4`1`4`00oa=B4`0301<C070C001T4`D0ea<5008C00<04a<00Q<00`0C4`024`03

01<C070C001V4`0301<C0=TC00<04a<01Q<00`0C00034`0301<C070C00134`033A<C01XC0`034`03

01<C008C0P3?4`<00a<00`0C4`084`0401<C4`80F1<23ALC00144`033A<C01lC00<04a<00Q<00`0C

4`3D4`0301<C00HC0P044`0301<C05@C0`dI4`00A1<00`dC4`0O4`0301<C008C00<04a<0e1<00`0C

4`064`0301<C00<C00<04a<0Da<00`dC4`0J4`00AA<00`dC4`0M4`8011<00`0C4`3C4`8021<300<C

00<04a<0DA<23AdC00164`033A<C028C0P3T4`0301<C04hC0`dO4`00AQ<00`dC4`0R4`0301<C0><C

0P1=4`8=8Q<004LC00<=4a<08A<00`0C4`3S4`0301<C04TC0`dT4`00B1<00`dC4`0P4`0301<C0><C

00<04a<0Aa<23BLC00184`033A<C020C0P3T4`0301<C04@C0`dY4`00BA<00`dC4`0O4`0301<C0><C

0P134`8=;1<004XC00<=4a<07Q<00`0C4`3S4`0301<C040C0Pd^4`00BQ<00`dC4`0N4`0301<C0><C

00<04a<0?Q<23C0C001;4`033A<C01dC0P3T4`0301<C03`C0Pdb4`00C1<00`dC4`0L4`0301<C0><C

00<04a<0>a<00`dC4`0b4`00C1<00`dC4`0L4`0301<C0><C0P0j4`8==A<004dC00<=4a<06a<00`0C

4`3S4`0301<C03LC0Pdg4`00CA<00`dC4`0K4`80i1<00`0C4`0e4`8=>A<004hC00<=4a<06Q<00`0C

4`3S4`0301<C03<C0Pdk4`00Ca<00`dC4`0:4`0301<C008C00<04a<00Q<00`0C4`024`0301<C0><C

0P0b4`8=?A<004lC00<=4a<02A<00`0C00074`0301<000<C00<04a<0ha<00`0C4`0_4`8=?a<0050C

00<=4a<00a<3008C00<04`002A<0100C4a<20>@C00<04a<0;A<23D4C001A4`033A<C00LC00<04`00

1a<200@C00<04a<0g1<5008C00<04a<0:a<23D<C001A4`033A<C00LC00<04`001a<00`0C4`034`03

01<C0=hC00<04a<00Q<00`0C4`0X4`<=AA<0058C00<=4a<01a<00`0C4`064`<00a<00`0C4`3H4`<0

0a<00`0C4`024`809a<23DPC001C4`033A<C01DC00<04a<0gQ<00`0C4`024`0301<C02@C0Pe:4`00

Da<00`dC4`0E4`80ga<00`0C4`024`0301<C028C0Pe<4`00E1<00`dC4`0D4`0301<C0=dC0P044`03

01<C020C0Pe>4`00EA<00`dC4`0C4`0301<C0><C0P0O4`8=D1<005HC00<=4a<04Q<00`0C4`3S4`03

01<C01/C0`eB4`00EQ<00`dC4`0B4`80i1<00`0C4`0H4`<=EA<005LC00<=4a<04A<00`0C4`3S4`03

01<C01DC0`eH4`006Q<302DC1@0A4`033A<C010C00<04a<091<502@C0`2C4`0301<C01<C0PeK4`00

6Q<00`0C4`0W4`0301<C014C00<=4a<041<00`0C4`0V4`0301<C02@C00<04a<0Ta<2014C0`eM4`00

5A<300<C00<04a<081<300<C00<04a<04Q<00`dC4`0?4`809a<00`0C4`0U4`0301<C098C00<04a<0

3Q<23F0C000K4`0301<C02HC00<04a<04a<00`dC4`0>4`0301<C02HC00<04a<09A<00`0C4`2B4`03

01<C00XC10eR4`006Q<00`0C000W4`0301<C01<C00<=4a<03Q<00`0C4`0V4`0301<C02@C00<04`00

Ta<00`0C4`024`P=IQ<001/C00<04a<09A<201HC00<=4a<03A<00`0C4`0U4`809a<00`0C4`2=4`X=

KQ<005/C00<=4a<03A<20<<C70d54`0301<C070C001L4`033A<C00`C00<04a<0R1<j3B4C00<04a<0

L1<005dC00<=4a<02a<00`0C4`1K4`80QQ<00`0C4`1`4`00GA<00`dC4`0;4`0301<C05XC00<04a<0

QQ<00`0C4`0i4b0=5a<001DCB@000`d0001Q00HC00<04a<0QQ<202hC30dg4`006A<00`0C4`064`03

01<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00D04a<C

3@034`0301<C00DC00<@4a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00DC

00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`084`0301<C08HC00<04a<08A<<3D<C

001O4`033A<C00TC00<@4a<0FQ<00`0C001g4`0301<C008C00<04a<00Q<00`0C4`024`0301<C01hC

0`e?4`00H1<00`dC4`084`8@Fa<307HC00<04`001a<00`0C00034`0301<C01XC10eB4`00HA<00`dC

4`074`8@ca<3008C00<04`002A<0100C4a<201LC10eF4`00HA<00`dC4`064`03400@0=@C00<04`00

1a<200@C00<04a<051<23EXC001R4`033A<C00DC00<@0100e1<00`0C00074`0301<C00<C00<04a<0

4Q<23E`C001S4`033A<C00@C00<@0100eA<00`0C4`064`<00a<00`0C4`0A4`033A<C05`C001T4`03

3A<C008C00D@4`00403S4`0301<C00lC0PeO4`00I1<00`dC4`024`0541<04a00ha<200hC0PeQ4`00

IA<02@dC4a<@4`0C403S4`0301<C00`C00<=4a<0HA<006HC00H=4a<@4`024`0341<C0>0C00<04a<0

2a<00`dC4`1R4`00IQ<01@dC4a0C008000<C41<0hA<00`0C4`094`8=IA<006LC00D=4a0C00024`03

41<C0>0C00<04a<021<00`dC4`1U4`00Ia<01@d@4a<000<C00<@4a<0ga<200PC00<=4a<0IQ<006PC

00@=4a<00a<00a0C4`3O4`0301<C00HC00<=4a<0Ia<006PC00<@3A<00P024`0341<C0=lC00<04a<0

1A<00`dC4`1X4`00Ia<01A0C3A<000@C00<@4a<0Q1<302XC1@0X4`0301<C00@C00<=4a<08A<502TC

0`0G4`00G1<00`0C4`024`0301<C008C00H041<C3@044`0341<C08@C00<04a<0;1<00`0C4`0X4`80

11<00`dC4`0T4`0301<C02TC00<04a<05a<005/C00<04`001a<00`0@00024`033@0C00<C00<@4a<0

Oa<300<C00<04a<09A<300<C00<04a<0:1<00`0C4`024`033A<C02DC00<04a<0:Q<00`0C4`0F4`00

Fa<00`0C00084`03400C008C00<=01<00a<00a0C4`244`0301<C02/C00<04a<0:1<00`0C4`024`03

3A<C02DC00<04a<0:Q<00`0C4`0F4`00Fa<00`0C00074`03010C00<C00<03A<00a<00a0C4`234`03

01<002`C00<04a<0:1<01@0C4a<=02PC00<04a<0:A<00`0C000G4`00Fa<00`0C00074`0341<C00<C

00<03A<011<00a0C4`234`0301<C02XC0P0Z4`0501<C4`d09a<202`C00<04a<05Q<005`C00<04a<0

1Q<00a0000034`0301<=00@C00<@4a<0g1<200034`dC06hC001T4`0341<C00@C0P000a<=4`024`03

41<C0=`C00<04`d0L1<006@C00<@4a<011<0100C4`d44`0341<C0=/C00<04`d0IA<200TC001S4`03

41<C00DC00D04a<C3@034`0341<C0=/C00<03A<0I1<00`0C4`094`00Ha<00a0C4`054`0501<C4`d0

11<00a0C4`1k4f0000<=0000G0074`0301<C00TC001R4`0341<C00HC00<04a<00Q<01@dC4a<@084C

00<04a<01Q<00`0C4`064`0301<C00LC00<04a<01Q<00`0C4`064`0301<C00HC00<04a<01Q<00`0C

4`064`0301<C00HC00<04a<01Q<00`dC4`064`0301<C00HC00<04a<01Q<00`0C4`064`0301<C00HC

00<04a<01a<00`0C4`064`0301<C00HC00<04a<01Q<00`0C4`064`0301<C00TC00<04a<02A<0068C

00<@4a<01Q<200@C00D=4a<C403K4`033A<C06@C00<04`002A<0064C00<@4a<01a<00`0C4`034`05

3A<C4a00fQ<00`d04`1U4`<02A<0064C00<@4a<01a<00`0C4`044`043A<C4=XC00<=01<0LA<0060C

00<@4a<021<00`0C4`054`043A<C4=PC00@=4`00LA<0060C00<@4a<021<200HC00@=4a<@f1<00`dC

001b4`00Ga<00a0C4`094`0301<C00HC00@=4a<@ea<00`dC001b4`00Ga<00a0C4`094`0301<C00LC

00<=4a00ea<00`dC001b4`00GQ<00a0C4`0:4`0301<C00LC00@=4a<@eA<00`dC4`02074C001N4`03

41<C00XC0P094`033A<@0=DC00@=4a<0LQ<005dC00<@4a<02a<00`0C4`094`033A<@0=@C00@=4a<0

LQ<005dC00<@4a<011<5008C00<04a<02Q<00`d@4`3C4`043A<C078C001L4`0341<C00LC00<04a<0

0Q<00`0C4`0:4`033A<@0=<C00@=4a<0LQ<005/C00<@4a<021<00`0C4`024`8031<00`dC403A4`04

3A<C4`80LA<005/C00<@4a<021<00`0C4`024`0301<C00`C00<=41<0d1<01@dC4a<0078C001J4`03

41<C00TC00<04a<00Q<00`0C4`0<4`033A<@0=0C00D=4a<C001b4`00FQ<00a0C4`084`8011<00`0C

4`0=4`033A<@0<lC00D=4a<C001b4`00FA<00a0C4`0?4`803a<00`d@4`3>4`043A<C4`80LA<005PC

00<@4a<041<00`0C4`0>4`033A<@0<lC00@=4a<0LQ<005PC00<@4a<041<00`0C4`0?4`033A<@0<hC

00@=4a<0LQ<005LC00<@4a<04A<00`0C4`0?4`033A<@0<8C00<04a<00Q<00`0C4`024`0301<=008C

00<04a<0L1<005HC00<@4a<04Q<2014C00<=4a00`1<00`0C00074`0401<03@8C00<04a<0L1<005HC

00<@4a<04Q<00`0C4`0A4`033A<@0;lC00<04`002A<0100=4a<2074C001E4`0341<C01<C00<04a<0

4A<00`dC402o4`0301<000LC0P024`033A<0078C001D4`0341<C01@C00<04a<04Q<00`dC402n4`03

01<000LC00L04a<C3A<0078C001C4`0341<C01DC0P0D4`033A0C0;hC00<04a<01Q<300044`dC078C

001C4`0341<C01DC00<04a<04a<00`dC403;4`043A<0074C001B4`0341<C01HC00<04a<051<00`dC

403;4`033@0C074C001A4`0341<C01LC00<04a<05A<00`d@4`3:4`033@0C074C001A4`0341<C01LC

0P0F4`033A<@0<XC00<=01<0LA<0050C00<@4a<061<00`0C4`0F4`033A0C0<XC00<=4a<0L1<004lC

00<@4a<021<5008C00<04a<00Q<00`0C4`024`0301<C01HC00<=4a00bQ<00`d04`1`4`00Ca<00a0C

4`0:4`0301<C00HC00<04`000a<00`0C4`0G4`033A<@0<TC00<03A<0L1<004hC00<@4a<02a<00`0C

4`084`0401<C4`806A<00`dC40384`0300dC070C001=4`0341<C00`C00<04a<01Q<200@C00<04a<0

61<00`dC40384`0301<=070C001<4`0341<C00dC00<04a<01Q<00`0C4`034`0301<C01TC00<=4a00

aa<200033A<C06hC001<4`0341<C00`C0P084`<00a<00`0C4`0J4`033A<@0<HC00@04a<=Ka<004/C

00<@4a<07A<201/C00@=4a<@aA<01@0C4a<=06hC001:4`0341<C01hC00<04a<06a<00`dC40354`05

01<C4`d0KQ<004XC00<@4a<07Q<00`0C4`0K4`043A<C4<@C00<04a<00Q<00`dC4`1[4`00BA<00a0C

4`0O4`0301<C01`C00@=4a<@`a<200<C00<=4a<0Ja<004PC00<@4a<081<201hC00@=4a<@`Q<00`0C

4`034`033A<C06XC00174`0341<C024C00<04a<07A<01@dC4a<@0<4C00<04a<011<00`dC4`1Y4`00

Aa<00a0C4`0Q4`0301<C01hC00@=4a<@^Q<5008C00<04a<01A<00`dC4`1X4`00AQ<00a0C4`0R4`03

01<C01hC00D=4a<C402k4`0301<C008C00<04a<01A<00`dC4`1X4`00AA<00a0C4`0S4`8081<01@dC

4a<@0;XC00<04a<00Q<200LC00<=4a<0Ia<004@C00<@4a<091<00`0C4`0P4`053A<C4a00^A<00`0C

4`024`0301<C00LC00<=4a<0IQ<004@C00<@4a<091<00`0C4`0P4`053A<C4a00^A<00`0C4`024`03

01<C00PC00<=4a<0IA<004<C00<@4a<09A<00`0C4`0Q4`053A<C4a00]a<200@C00<04a<02A<00`dC

4`1T4`00@Q<00a0C4`0V4`0301<C028C00D=4a<C402l4`802a<00`dC4`1S4`00@A<00a0C4`0W4`80

8a<00`dC4`024`0341<C0;TC00<04a<02a<00`dC4`1R4`00@1<00a0C4`0X4`0301<C02<C00<=4a<0

0Q<00a0C4`2h4`0301<C00`C00<=4a<0HA<0040C00<@4a<08Q<300<C00<04a<08a<00`dC4`034`03

41<C0;LC00<04a<03A<00`dC4`1P4`00?a<00a0C4`0S4`0301<C00<C00<04a<091<00`dC4`024`03

41<C0;LC00<04a<03Q<23F0C000n4`0341<C02DC00<04a<00Q<202HC00<=4a<00Q<00a0C4`2f4`80

4A<00`dC4`1M4`00?A<00a0C4`0V4`0301<C008C00<04a<09A<00`dC4`034`0341<C0;DC00<04a<0

4A<00`dC4`1L4`00?A<00a0C4`0U4`0301<000<C00<04a<09Q<00`dC4`034`0341<C0;@C00<04a<0

4Q<00`dC4`1K4`00?1<00a0C4`0W4`0301<C008C00<04a<09a<00`dC4`034`0341<C0;<C00<04a<0

4a<00`dC4`1J4`00>a<00a0C4`0]4`80:1<00`dC4`044`0341<C0;8C0P0E4`033A<C05TC000j4`03

41<C02hC00<04a<0:1<00`dC4`034`0341<C0;8C00<04a<05A<00`dC4`1H4`00>Q<00a0C4`0^4`03

01<C02TC00<=4a<00a<00a0C4`2a4`0301<C01HC00<=4a<0Ea<003TC00<@4a<0;a<00`0C4`0Y4`03

3A<C00@C00<@4a<0/1<00`0C4`0G4`8=Ea<003PC00<@4a<0<1<202/C00<=4a<011<00a0C4`2_4`03

01<C01TC00<=4a<0E1<003LC00<@4a<0<A<00`0C4`0[4`033A<C00<C00<@4a<0[a<201/C0PeD4`00

=a<00a0C4`0a4`0301<C02`C00<=4a<00a<00a0C4`2^4`0301<C01`C00<=4a<0DA<003HC00<@4a<0

<Q<00`0C4`0/4`033A<C00@C00<@4a<0W1<5008C00<04a<00Q<00`0C4`024`0301<C01dC0PeA4`00

=A<00a0C4`0c4`80;Q<00`dC4`044`0341<C09dC00<04a<01Q<00`0C00034`0301<C01lC00<=4a<0

CQ<003@C00<@4a<0=1<00`0C4`0^4`033A<C00@C00<@4a<0W1<00`0C4`084`0401<C4`808A<23DhC

000c4`0341<C03DC00<04a<0;Q<00`dC4`054`0341<C09/C00<04a<01Q<200@C00<04a<08Q<00`dC

4`1;4`00<Q<00a0C4`0f4`0301<C02lC00<=4a<011<00a0C4`2K4`0301<C00HC00<04a<00a<00`0C

4`0S4`8=Ba<0034C00<@4a<0=a<2034C00<=4a<011<00a0C4`2I4`8021<300<C00<04a<09A<23DTC

000`4`0341<C03PC00<04a<0<1<00`dC4`054`0341<C0:PC00<04a<09a<23DLC000_4`0341<C02TC

0`034`0301<C008C00<04a<00Q<00`0C4`0a4`033A<C00DC00<@4a<0Ya<202XC00<=4a<0A1<002hC

00<@4a<0:Q<00`0C4`074`0301<000<C00<04a<0<A<00`dC4`064`0341<C0:HC00<04a<0:Q<23D@C

000]4`0341<C02`C00<04a<021<0100C4a<203<C00<=4a<01Q<00a0C4`2U4`0301<C02`C00<=4a<0

@A<002`C00<@4a<0;A<00`0C4`064`8011<00`0C4`0c4`033A<C00HC00<@4a<0Y1<00`0C4`0]4`8=

@A<002/C00<@4a<0;A<00`0C00074`0301<C00<C00<04a<0<a<00`dC4`074`0341<C0:<C0P0`4`03

3A<C03hC000Z4`0341<C02lC00<04a<01Q<300<C00<04a<0=1<00`dC4`074`0341<C0:8C00<04a<0

<1<23ChC000Y4`0341<C03lC0P0f4`033A<C00LC00<@4a<0XA<00`0C4`0b4`8=?1<002PC00<@4a<0

@1<00`0C4`0e4`033A<C00PC00<@4a<0X1<00`0C4`0d4`8=>Q<002LC00<@4a<0@A<00`0C4`0f4`03

3A<C00PC00<@4a<0Wa<00`0C4`0f4`8=>1<002HC00<@4a<0@Q<00`0C4`0g4`033A<C00PC00<@4a<0

WQ<203TC0Pdf4`009A<00a0C4`134`80>1<00`dC4`094`0341<C09dC00<04a<0>Q<23C@C000T4`03

41<C04@C00<04a<0>1<00`dC4`094`0341<C09`C00<04a<0?1<23C8C000S4`0341<C04DC00<04a<0

>1<00`dC4`0:4`0341<C09/C00<04a<0?Q<23C0C000S4`0341<C04DC00<04a<0>A<00`dC4`0:4`03

41<C09XC0P114`8=;Q<0028C00<@4a<0AQ<203/C00<=4a<02Q<00a0C4`2I4`0301<C048C0Pd/4`00

8A<00a0C4`174`0301<C03XC00<=4a<02a<00a0C4`2H4`0301<C04@C0PdZ4`0081<00a0C4`184`03

01<C03/C00<=4a<02a<00a0C4`2A4`<00a<00`0C4`164`8=:1<001lC00<@4a<0BA<00`0C4`0l4`03

3A<C00/C00<@4a<0T1<00`0C4`034`0301<C04PC0PdV4`007Q<00a0C4`1:4`80?A<00`dC4`0<4`03

41<C090C00<04a<00Q<204/C0PdT4`007A<00a0C4`1;4`0301<C03dC00<=4a<031<00a0C4`2?4`03

01<C008C00<04a<0C1<33B4C000L4`0341<C04`C00<04a<0?A<00`dC4`0=4`0341<C08dC00<04`00

0a<00`0C4`1?4`8=7a<001/C00<@4a<0Aa<200@C00<04a<0?Q<00`dC4`0=4`0341<C08dC00<04a<0

0Q<00`0C4`1A4`8=7A<001XC00<@4a<0BQ<01@0C4a<0040C00<=4a<03Q<00a0C4`2A4`0301<C05<C

0PdK4`006A<00a0C4`1:4`0301<C008C0P104`033A<C00dC00<@4a<0TA<205HC0PdI4`00Ia<00`0C

4`3W4`0301<C05LC0PdG4`00IA<00`0C003Y4`0301<C070C001V4`0301<C0>PC00<04a<0L1<002XC

0`3o4bDC0P1a4`00:Q<00`0C4`3o4bDC00<04a<0L1<002/C00<04a<011<00`0C4`3o4i0C000[4`04

01<C4`@00a<30?lCS1<002XC00<04`000Q<200034`0C00@C00<04a<0oa>:4`00:a<00`0C4`034`03

01<000<C00<04a<0oa>;4`00<A<00`0C00044`0301<C00HC00<04a<09a<302/C00<04a<0oa<Y4`00

6a<300034`00008031<300@C0`084`0301<C02HC00@04a<03a<300034`0000800Q<00`0C4`024`03

01<C008C00<04a<01A<0100C4a<5008C00<04a<00Q<00`0C4`024`<00Q<00`0C4`044`80aA<00`0C

4`0g4`0301<C00HC000J4`0401<C02@C00<04a<09A<0100C4`0>4`0401<C00HC00<04`001a<00`0C

00044`D00a<00`0C4`064`0301<000@C00H04a<04`044`0301<C0;dC00<04a<011<00`0C4`0C4`03

01<C02<C00<04a<01A<001XC00D04a<04`0400034`0001P0;A<300hC00D04a<04`0400044`0C00TC

00<04a<011<00`0C4`034`0301<C00PC00<04a<010034`0301<C008C00<04a<0Za<0100C4a<4008C

0P064`0301<C00<C00<04a<00Q<00`0C4`024`0301<C008C00<04a<01A<0100C4a<5008C00<04a<0

0Q<00`0C4`024`<00Q<00`0C4`044`8011<0100C4a<2004C000K4`<0Ca<00`0C4`0=4`<01Q<00`0C

00074`801a<00`0C4`034`0301<C00HC0P034`0301<0008C0P054`0301<C0:XC00<04`001a<00`0C

4`044`D00a<01`0C4a<04`001a<00`0C00044`D00a<00`0C4`064`0301<000@C00H04a<04`044`03

01<C00@C00<04a<00Q<1004C000M4`0301<C04`C0P0A4`0301<C00@C00<04`001a<00`0C4`0<4`03

01<C00HC00<04a<00a<2008C00<04a<011<00`0C002Z4`0301<0008C10000a<04`074`0301<C00<C

00L04a<C01<000TC00<04a<011<00`0C4`034`0301<C00PC00<04a<010034`0301<C008C00<04a<0

11<00`0C4`034`40000L4`80H1<200LC00<04a<01Q<300/C0P084`<011<00`0C4`0300@C0`2C4`80

00<C00004Q<00`0C00074`0301<C00HC00<04a<00a<01`0C4a<04`001a<200LC00<04a<00a<00`0C

4`064`800a<00`0C00024`801A<00`0C4`044`0301<C00<C0@000?lCDA<00`0C000C4`0301<000LC

00<04`003A<01P0C4`0C00LC00<04a<031<00`0C4`064`0301<C00<C0P024`0301<C00@C00<04`00

0a<00`0C4`034`400A<002HC0P064`80oa<R4`0301<C01<C00<04a<01Q<300hC00@04a<021<300/C

0P084`<011<00`0C4`0300@C0`024`0301<C00<C0P014`00:1<00`0C4`024`0301<C0?lC8Q<00`0C

4`1`4`009a<00`0C4`034`0301<C00HC00<04a<0oa<H4`0301<0074C000X4`0301<C008C00<04a<0

0Q<300044`0C4`<0oa<D4`8000<C0000L1<002HC00<04`0011<00`0C00024`800Q<00`0C4`024`03

01<C0?lCQa<002LC00<04a<00a<300@C00@04a<00Q<00`0C4`3o4hPC000d4`0401<C00<C00<04a<0

oa>74`00<Q<300@C0`3o4hTC003o4lDC003o4lDC003o4lDC003o4lDC003o4lDC0000\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.4356, -1.70649, 0.0220253, 0.0220253}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -82 0 ]

[.5 .96488 82 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -143 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.54) show

217.250000 19.500000 moveto

(C) show

222.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.26809 0 m

.30316 .054 L

.34309 .11549 L

.3815 .17465 L

.42237 .23759 L

.46172 .29819 L

.49955 .35645 L

.53984 .4185 L

.57861 .4782 L

.61984 .54169 L

.65954 .60284 L

.69774 .66166 L

.73838 .72425 L

.77751 .78451 L

.81909 .84855 L

.85916 .91025 L

s

.85916 .91025 m

.88652 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.378341 0.238095 [

[.02381 .36584 -6 -9 ]

[.02381 .36584 6 0 ]

[.2619 .36584 -6 -9 ]

[.2619 .36584 6 0 ]

[.7381 .36584 -3 -9 ]

[.7381 .36584 3 0 ]

[.97619 .36584 -3 -9 ]

[.97619 .36584 3 0 ]

[1.025 .37834 0 -8 ]

[1.025 .37834 9 8 ]

[.4875 .0212 -24 -4.5 ]

[.4875 .0212 0 4.5 ]

[.4875 .14025 -12 -4.5 ]

[.4875 .14025 0 4.5 ]

[.4875 .25929 -24 -4.5 ]

[.4875 .25929 0 4.5 ]

[.4875 .49739 -18 -4.5 ]

[.4875 .49739 0 4.5 ]

[.4875 .61644 -6 -4.5 ]

[.4875 .61644 0 4.5 ]

[.4875 .73548 -18 -4.5 ]

[.4875 .73548 0 4.5 ]

[.4875 .85453 -6 -4.5 ]

[.4875 .85453 0 4.5 ]

[.5 .93115 -4.5 0 ]

[.5 .93115 4.5 16 ]

[.5 .91865 -134.5 0 ]

[.5 .91865 134.5 16 ]

[ 0 0 0 0 ]

[ 1 .90615 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .37834 m

.02381 .38459 L

s

[(-2)] .02381 .36584 0 1 Mshowa

.2619 .37834 m

.2619 .38459 L

s

[(-1)] .2619 .36584 0 1 Mshowa

.7381 .37834 m

.7381 .38459 L

s

[(1)] .7381 .36584 0 1 Mshowa

.97619 .37834 m

.97619 .38459 L

s

[(2)] .97619 .36584 0 1 Mshowa

.125 Mabswid

.07143 .37834 m

.07143 .38209 L

s

.11905 .37834 m

.11905 .38209 L

s

.16667 .37834 m

.16667 .38209 L

s

.21429 .37834 m

.21429 .38209 L

s

.30952 .37834 m

.30952 .38209 L

s

.35714 .37834 m

.35714 .38209 L

s

.40476 .37834 m

.40476 .38209 L

s

.45238 .37834 m

.45238 .38209 L

s

.54762 .37834 m

.54762 .38209 L

s

.59524 .37834 m

.59524 .38209 L

s

.64286 .37834 m

.64286 .38209 L

s

.69048 .37834 m

.69048 .38209 L

s

.78571 .37834 m

.78571 .38209 L

s

.83333 .37834 m

.83333 .38209 L

s

.88095 .37834 m

.88095 .38209 L

s

.92857 .37834 m

.92857 .38209 L

s

.25 Mabswid

0 .37834 m

1 .37834 L

s

gsave

1.025 .37834 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .0212 m

.50625 .0212 L

s

[(-1.5)] .4875 .0212 1 0 Mshowa

.5 .14025 m

.50625 .14025 L

s

[(-1)] .4875 .14025 1 0 Mshowa

.5 .25929 m

.50625 .25929 L

s

[(-0.5)] .4875 .25929 1 0 Mshowa

.5 .49739 m

.50625 .49739 L

s

[(0.5)] .4875 .49739 1 0 Mshowa

.5 .61644 m

.50625 .61644 L

s

[(1)] .4875 .61644 1 0 Mshowa

.5 .73548 m

.50625 .73548 L

s

[(1.5)] .4875 .73548 1 0 Mshowa

.5 .85453 m

.50625 .85453 L

s

[(2)] .4875 .85453 1 0 Mshowa

.125 Mabswid

.5 .04501 m

.50375 .04501 L

s

.5 .06882 m

.50375 .06882 L

s

.5 .09263 m

.50375 .09263 L

s

.5 .11644 m

.50375 .11644 L

s

.5 .16406 m

.50375 .16406 L

s

.5 .18787 m

.50375 .18787 L

s

.5 .21167 m

.50375 .21167 L

s

.5 .23548 m

.50375 .23548 L

s

.5 .2831 m

.50375 .2831 L

s

.5 .30691 m

.50375 .30691 L

s

.5 .33072 m

.50375 .33072 L

s

.5 .35453 m

.50375 .35453 L

s

.5 .40215 m

.50375 .40215 L

s

.5 .42596 m

.50375 .42596 L

s

.5 .44977 m

.50375 .44977 L

s

.5 .47358 m

.50375 .47358 L

s

.5 .5212 m

.50375 .5212 L

s

.5 .54501 m

.50375 .54501 L

s

.5 .56882 m

.50375 .56882 L

s

.5 .59263 m

.50375 .59263 L

s

.5 .64025 m

.50375 .64025 L

s

.5 .66406 m

.50375 .66406 L

s

.5 .68787 m

.50375 .68787 L

s

.5 .71167 m

.50375 .71167 L

s

.5 .75929 m

.50375 .75929 L

s

.5 .7831 m

.50375 .7831 L

s

.5 .80691 m

.50375 .80691 L

s

.5 .83072 m

.50375 .83072 L

s

.5 .87834 m

.50375 .87834 L

s

.5 .90215 m

.50375 .90215 L

s

.25 Mabswid

.5 0 m

.5 .90615 L

s

gsave

.5 .93115 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .91865 -195.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.54) show

293.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

298.000000 15.000000 moveto

(L) show

305.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

312.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

319.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

324.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

328.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .90615 L

0 .90615 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .2206 m

.02576 .22059 L

.03157 .22056 L

.04116 .22051 L

.05434 .22044 L

.0709 .22034 L

.09055 .22022 L

.11296 .22006 L

.13775 .21988 L

.16448 .21965 L

.19271 .21939 L

.22194 .21908 L

.25168 .21871 L

.28143 .21829 L

.31066 .21779 L

.33889 .21723 L

.36562 .21658 L

.39041 .21587 L

.41282 .21509 L

.43247 .21428 L

.44903 .21347 L

.46221 .21274 L

.47179 .21214 L

.47761 .21175 L

.47956 .21161 L

s

.47956 .21161 m

.48168 .21146 L

.48802 .21098 L

.49846 .21012 L

.51283 .20875 L

.53087 .20667 L

.55229 .20352 L

.57671 .19873 L

.60372 .19152 L

.63285 .18125 L

.66361 .16802 L

.69546 .15273 L

.72787 .13652 L

.76029 .12025 L

.79214 .10451 L

.8229 .08967 L

.85203 .07598 L

.87904 .06362 L

.90346 .0527 L

.92488 .04332 L

.94292 .03556 L

.95729 .02947 L

.96773 .02509 L

.97407 .02246 L

.97619 .02158 L

s

.47956 .46165 m

.48168 .43457 L

.48802 .40776 L

.49846 .38148 L

.51283 .356 L

.53087 .33165 L

.55229 .30892 L

.57671 .28849 L

.60372 .27126 L

.63285 .25797 L

.66361 .24865 L

.69546 .24247 L

.72787 .23841 L

.76029 .23568 L

.79214 .23379 L

.8229 .23243 L

.85203 .23143 L

.87904 .23068 L

.90346 .23012 L

.92488 .2297 L

.94292 .22938 L

.95729 .22915 L

.96773 .22899 L

.97407 .2289 L

.97619 .22887 L

s

.47956 .46177 m

.48168 .489 L

.48802 .51629 L

.49846 .54342 L

.51283 .57027 L

.53087 .5967 L

.55229 .62258 L

.57671 .6478 L

.60372 .67225 L

.63285 .6958 L

.66361 .71836 L

.69546 .73982 L

.72787 .7601 L

.76029 .77909 L

.79214 .79673 L

.8229 .81292 L

.85203 .82761 L

.87904 .84072 L

.90346 .85221 L

.92488 .86201 L

.94292 .87008 L

.95729 .8764 L

.96773 .88094 L

.97407 .88366 L

.97619 .88458 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<00`0C4`1`4`00oa=B4`0301<C070C001T4`D0ea<5008C00<04a<00Q<00`0C4`024`03

01<C070C001V4`0301<C0=TC00<04a<01Q<00`0C00034`0301<C070C00134`033A<C01XC0`034`03

01<C008C0P3?4`<00a<00`0C4`084`0401<C4`80FA<00`dC4`0E4`00A1<00`dC4`0O4`0301<C008C

00<04a<0e1<00`0C4`064`8011<00`0C4`1F4`8=61<004@C00<=4a<07a<00`0C4`024`0301<C0=@C

00<04a<01Q<00`0C4`034`0301<C05@C0PdJ4`00AA<00`dC4`0M4`8011<00`0C4`3C4`8021<300<C

00<04a<0DA<33A`C00164`033A<C028C0P3T4`0301<C04hC0`dO4`00AQ<00`dC4`0R4`0301<C0><C

0P1=4`8=8Q<004LC00<=4a<08A<00`0C4`3S4`0301<C04TC0`dT4`00B1<00`dC4`0P4`0301<C0><C

00<04a<0Aa<23BLC00184`033A<C020C0P3T4`0301<C04DC0PdY4`00BA<00`dC4`0O4`0301<C0><C

0P144`8=:a<004XC00<=4a<07Q<00`0C4`3S4`0301<C044C0Pd]4`00BQ<00`dC4`0N4`0301<C0><C

00<04a<0?a<23BlC001;4`033A<C01dC0P3T4`0301<C03dC0Pda4`00C1<00`dC4`0L4`0301<C0><C

00<04a<0>a<23C<C001<4`033A<C01`C00<04a<0ha<203XC0Pde4`00CA<00`dC4`0K4`0301<C0><C

00<04a<0=a<23CLC001=4`033A<C01/C0P3T4`0301<C03DC0Pdi4`00CQ<00`dC4`0J4`0301<C0><C

00<04a<0<a<23C/C001?4`033A<C00XC00<04a<00Q<00`0C4`024`0301<C008C00<04a<0ha<2038C

0Pdm4`00Ca<00`dC4`094`0301<000LC00<04`000a<00`0C4`3S4`0301<C02lC0Pdo4`00D1<00`dC

4`034`<00Q<00`0C00094`0401<C4`80i1<00`0C4`0]4`8=@A<0054C00<=4a<01a<00`0C00074`80

11<00`0C4`3L4`D00Q<00`0C4`0[4`8=@a<0054C00<=4a<01a<00`0C00074`0301<C00<C00<04a<0

gQ<00`0C4`024`0301<C02PC0`e54`00DQ<00`dC4`074`0301<C00HC0`034`0301<C0=PC0`034`03

01<C008C0P0W4`8=B1<005<C00<=4a<05A<00`0C4`3N4`0301<C008C00<04a<091<23DXC001C4`03

3A<C01DC0P3O4`0301<C008C00<04a<08Q<23D`C001D4`033A<C01@C00<04a<0gA<200@C00<04a<0

81<23DhC001E4`033A<C01<C00<04a<0ha<201lC0Pe@4`00EQ<00`dC4`0B4`0301<C0><C00<04a<0

71<23E8C001F4`033A<C018C0P3T4`0301<C01XC0PeD4`00Ea<00`dC4`0A4`0301<C0><C00<04a<0

61<23EHC000J4`<09A<5014C00<=4a<041<00`0C4`0T4`D091<309<C00<04a<05A<33EPC000J4`03

01<C02LC00<04a<04A<00`dC4`0@4`0301<C02HC00<04a<091<00`0C4`2C4`8051<23E/C000E4`<0

0a<00`0C4`0P4`<00a<00`0C4`0B4`033A<C00lC0P0W4`0301<C02DC00<04a<0TQ<00`0C4`0?4`@=

GA<001/C00<04a<09Q<00`0C4`0C4`033A<C00hC00<04a<09Q<00`0C4`0U4`0301<C098C00<04a<0

2Q<53F4C000J4`0301<002LC00<04a<04a<00`dC4`0>4`0301<C02HC00<04a<091<00`0C002C4`03

01<C008C20eV4`006a<00`0C4`0U4`805Q<00`dC4`0=4`0301<C02DC0P0W4`0301<C08dC2Pe^4`00

Fa<00`dC4`0=4`80`a<L3@DC00<04a<0L1<005`C00<=4a<031<00`0C4`284cX=8A<00`0C4`1`4`00

GA<00`dC4`0;4`0301<C05/C0P264`0301<C070C001M4`033A<C00/C00<04a<0FQ<00`0C4`264`03

01<C03TC80dG4`005A=900033@0006401Q<00`0C4`264`80;Q<<3CLC000I4`0301<C00HC00<04a<0

1A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<01@0C4a<=00<C

00<04a<01A<00a0C4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C

4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00PC00<04a<0QQ<00`0C4`0P4`d=@a<005lC

00<=4a<02A<00a0C4`1J4`0301<007LC00<04a<00Q<00`0C4`024`0301<C008C00<04a<06a<53E0C

001P4`033A<C00PC0Q1K4`<0MQ<00`0C00074`0301<000<C00<04a<061<33EDC001Q4`033A<C00LC

0Q3?4`<00Q<00`0C00094`0401<C4`805a<23EPC001Q4`033A<C00HC00<@0100e1<00`0C00074`80

11<00`0C4`0D4`8=FQ<0068C00<=4a<01A<00a00403D4`0301<000LC00<04a<00a<00`0C4`0B4`8=

G1<006<C00<=4a<011<00a00403E4`0301<C00HC0`034`0301<C014C00<=4a<0G1<006@C00<=4a<0

0Q<01A0C000@0><C00<04a<03a<23ElC001T4`033A<C008C00D@4`0C403S4`803Q<23F4C001U4`09

3A<C4a0C01<@0><C00<04a<031<00`dC4`1Q4`00IQ<01PdC4a0C008C00<@4a<0h1<00`0C4`0;4`03

3A<C068C001V4`053A<C41<00P000a<@4`3Q4`0301<C00TC0PeU4`00Ia<01@dC41<0008C00<@4a<0

h1<00`0C4`084`033A<C06DC001W4`053A0C4`000a<00a0C4`3O4`8021<00`dC4`1V4`00J1<010dC

4`034`0341<C0=lC00<04a<01Q<00`dC4`1W4`00J1<00a0=4`02008C00<@4a<0ga<00`0C4`054`03

3A<C06PC001W4`0541<=4`0011<00a0C4`244`<0:Q<502PC00<04a<011<00`dC4`0Q4`D0:A<301LC

001L4`0301<C008C00<04a<00Q<01P0@4a<=00@C00<@4a<0Q1<00`0C4`0/4`0301<C02PC0P044`03

3A<C02@C00<04a<0:A<00`0C4`0G4`00Fa<00`0C00074`030100008C00<=01<00a<00a0C4`1o4`<0

0a<00`0C4`0U4`<00a<00`0C4`0X4`0301<C008C00<=4a<09A<00`0C4`0Z4`0301<C01HC001K4`03

01<000PC00<@01<00Q<00`d04`034`0341<C08@C00<04a<0:a<00`0C4`0X4`0301<C008C00<=4a<0

9A<00`0C4`0Z4`0301<C01HC001K4`0301<000LC00<041<00a<00`0=4`034`0341<C08<C00<04`00

;1<00`0C4`0X4`0501<C4`d0:1<00`0C4`0Y4`0301<001LC001K4`0301<000LC00<@4a<00a<00`0=

4`044`0341<C08<C00<04a<0:Q<202XC00D04a<C3@0W4`80;1<00`0C4`0F4`00G1<00`0C4`064`03

400000<C00<04`d011<00a0C4`3L4`8000<C3A<0KQ<006@C00<@4a<011<200034`dC008C00<@4a<0

g1<00`0C3@1`4`00I1<00a0C4`044`0401<C3@@C00<@4a<0fa<00`0C3@1U4`802A<006<C00<@4a<0

1A<01@0C4a<=00<C00<@4a<0fa<00`0=4`1T4`0301<C00TC001S4`0341<C00DC00D04a<C3@044`03

41<C07/CH0000`d0001L00LC00<04a<02A<0068C00<@4a<01Q<00`0C4`024`053A<C4a00PA<00`0C

4`064`0301<C00HC00<04a<01Q<00`0C4`074`0301<C00HC00<04a<01Q<00`0C4`064`0301<C00HC

00<04a<01Q<00`0C4`064`033A<C00HC00<04a<01Q<00`0C4`064`0301<C00HC00<04a<01a<00`0C

4`064`0301<C00HC00<04a<01Q<00`0C4`064`0301<C00HC00<04a<02A<00`0C4`094`00HQ<00a0C

4`064`8011<01@dC4a<@0=/C00<=4a<0I1<00`0C00094`00HA<00a0C4`074`0301<C00<C00D=4a<C

403J4`033@0C06DC0`094`00HA<00a0C4`074`0301<C00@C00@=4a<@fQ<00`d04`1a4`00H1<00a0C

4`084`0301<C00DC00@=4a<@f1<010dC001a4`00H1<00a0C4`084`801Q<010dC4a3H4`033A<0078C

001O4`0341<C00TC00<04a<01Q<010dC4a3G4`033A<0078C001O4`0341<C00TC00<04a<01a<00`dC

403G4`033A<0078C001N4`0341<C00XC00<04a<01a<010dC4a3E4`033A<C0080LA<005hC00<@4a<0

2Q<200TC00<=4a00eA<010dC4`1b4`00GA<00a0C4`0;4`0301<C00TC00<=4a00e1<010dC4`1b4`00

GA<00a0C4`044`D00Q<00`0C4`0:4`033A0C0=<C00@=4a<0LQ<005`C00<@4a<01a<00`0C4`024`03

01<C00XC00<=4a00da<010dC4`1b4`00Fa<00a0C4`084`0301<C008C0P0<4`033A<@0=4C00@=4a<C

0P1a4`00Fa<00a0C4`084`0301<C008C00<04a<031<00`d@4`3@4`053A<C4`00LQ<005XC00<@4a<0

2A<00`0C4`024`0301<C00`C00<=4a00d1<01@dC4a<0078C001J4`0341<C00PC0P044`0301<C00dC

00<=4a00ca<01@dC4a<0078C001I4`0341<C00lC0P0?4`033A0C0<hC00@=4a<C0P1a4`00F1<00a0C

4`0@4`0301<C00hC00<=4a00ca<010dC4`1b4`00F1<00a0C4`0@4`0301<C00lC00<=4a00cQ<010dC

4`1b4`00Ea<00a0C4`0A4`0301<C00lC00<=4a00`Q<00`0C4`024`0301<C008C00<04`d00Q<00`0C

4`1`4`00EQ<00a0C4`0B4`804A<00`dC40304`0301<000LC00@04`0=0Q<00`0C4`1`4`00EQ<00a0C

4`0B4`0301<C014C00<=4a00_a<00`0C00094`0400dC4`80LA<005DC00<@4a<04a<00`0C4`0A4`03

3A<@0;lC00<04`001a<200054`dC4`00LQ<005@C00<@4a<051<00`0C4`0B4`033A<@0;hC00<04`00

1a<01`0C4a<=4`00LQ<005<C00<@4a<05A<201@C00<=41<0_Q<00`0C4`064`<000@C3A<0LQ<005<C

00<@4a<05A<00`0C4`0C4`033A<@0</C00@=4`00LA<0058C00<@4a<05Q<00`0C4`0D4`033A<@0<XC

00<=4`00LQ<0054C00<@4a<05a<00`0C4`0E4`033A0C0<XC00<=01<0LA<0054C00<@4a<05a<201HC

00<=4a00bQ<00`d04`1a4`00D1<00a0C4`0H4`0301<C01HC00<=41<0bQ<00`dC4`1`4`00Ca<00a0C

4`084`D00Q<00`0C4`024`0301<C008C00<04a<05Q<00`dC403:4`033@0C070C001?4`0341<C00XC

00<04a<01Q<00`0C00034`0301<C01LC00<=4a00bA<00`0=4`1`4`00CQ<00a0C4`0;4`0301<C00PC

00@04a<C0P0I4`033A<@0<PC00<03A<0L1<004dC00<@4a<031<00`0C4`064`8011<00`0C4`0H4`03

3A<@0<PC00<04`d0L1<004`C00<@4a<03A<00`0C4`064`0301<C00<C00<04a<06A<00`dC40374`03

01<=070C001<4`0341<C00`C0P084`<00a<00`0C4`0J4`033A<@0<HC0P000a<=4`1^4`00Ba<00a0C

4`0M4`806a<010dC4a354`0501<C4`d0KQ<004XC00<@4a<07Q<00`0C4`0K4`033A<@0<DC00D04a<C

3@1^4`00BQ<00a0C4`0N4`0301<C01/C00@=4a<@a1<00`0C4`024`033A<C06/C00194`0341<C01lC

00<04a<071<010dC4a334`800a<00`dC4`1[4`00B1<00a0C4`0P4`807Q<010dC4a324`0301<C00<C

00<=4a<0JQ<004LC00<@4a<08A<00`0C4`0M4`053A<C4a00`A<00`0C4`044`033A<C06TC00174`03

41<C024C00<04a<07Q<010dC4a2j4`D00Q<00`0C4`054`033A<C06PC00164`0341<C028C00<04a<0

7Q<01@dC4a<@0;/C00<04a<00Q<00`0C4`054`033A<C06PC00154`0341<C02<C0P0P4`053A<C4a00

^Q<00`0C4`024`801a<00`dC4`1W4`00A1<00a0C4`0T4`0301<C020C00D=4a<C402i4`0301<C008C

00<04a<01a<00`dC4`1V4`00A1<00a0C4`0T4`0301<C020C00D=4a<C402i4`0301<C008C00<04a<0

21<00`dC4`1U4`00@a<00a0C4`0U4`0301<C024C00D=4a<C402g4`8011<00`0C4`094`033A<C06@C

00124`0341<C02HC00<04a<08Q<01@dC4a<@0;`C0P0;4`033A<C06<C00114`0341<C02LC0P0S4`03

3A<C008C00<@4a<0^A<00`0C4`0;4`033A<C068C00104`0341<C02PC00<04a<08a<00`dC4`024`03

41<C0;PC00<04a<031<00`dC4`1Q4`00@1<00a0C4`0R4`<00a<00`0C4`0T4`033A<C008C00<@4a<0

]a<00`0C4`0=4`033A<C060C000o4`0341<C02<C00<04a<00a<00`0C4`0U4`053A<C4a00^A<00`0C

4`0>4`8=H1<003hC00<@4a<09A<00`0C4`024`809Q<00`dC4`024`0341<C0;HC0P0A4`033A<C05dC

000m4`0341<C02HC00<04a<00Q<00`0C4`0V4`033A<C008C00<@4a<0]A<00`0C4`0A4`033A<C05`C

000m4`0341<C02DC00<04`000a<00`0C4`0W4`033A<C008C00<@4a<0]1<00`0C4`0B4`033A<C05/C

000l4`0341<C02LC00<04a<00Q<00`0C4`0W4`033A<C00<C00<@4a<0/a<00`0C4`0C4`033A<C05XC

000k4`0341<C02dC0P0Y4`033A<C00<C00<@4a<0/Q<201DC00<=4a<0FA<003XC00<@4a<0;Q<00`0C

4`0Y4`033A<C008C00<@4a<0/Q<00`0C4`0E4`033A<C05PC000j4`0341<C02hC00<04a<0:A<00`dC

4`034`0341<C0;4C00<04a<05Q<00`dC4`1G4`00>A<00a0C4`0_4`0301<C02XC00<=4a<00a<00a0C

4`2`4`0301<C01LC0PeG4`00>1<00a0C4`0`4`80:a<00`dC4`044`0341<C0:lC00<04a<06A<00`dC

4`1D4`00=a<00a0C4`0a4`0301<C02/C00<=4a<00a<00a0C4`2_4`806a<23E@C000g4`0341<C034C

00<04a<0;1<00`dC4`034`0341<C0:hC00<04a<071<00`dC4`1A4`00=Q<00a0C4`0b4`0301<C02`C

00<=4a<011<00a0C4`2L4`D00Q<00`0C4`024`0301<C008C00<04a<07A<23E4C000e4`0341<C03<C

0P0^4`033A<C00@C00<@4a<0WA<00`0C4`064`0301<000<C00<04a<07a<00`dC4`1>4`00=1<00a0C

4`0d4`0301<C02hC00<=4a<011<00a0C4`2L4`0301<C00PC00@04a<C0P0Q4`8=CQ<003<C00<@4a<0

=A<00`0C4`0^4`033A<C00DC00<@4a<0Va<00`0C4`064`8011<00`0C4`0R4`033A<C04/C000b4`03

41<C03HC00<04a<0;a<00`dC4`044`0341<C09/C00<04a<01Q<00`0C4`034`0301<C02<C0Pe;4`00

<A<00a0C4`0g4`80<A<00`dC4`044`0341<C09TC0P084`<00a<00`0C4`0U4`8=BA<0030C00<@4a<0

>1<00`0C4`0`4`033A<C00DC00<@4a<0Z1<00`0C4`0W4`8=Aa<002lC00<@4a<0:A<300<C00<04a<0

0Q<00`0C4`024`0301<C034C00<=4a<01A<00a0C4`2W4`80:Q<00`dC4`144`00;Q<00a0C4`0Z4`03

01<C00LC00<04`000a<00`0C4`0a4`033A<C00HC00<@4a<0YQ<00`0C4`0Z4`8=A1<002dC00<@4a<0

;1<00`0C4`084`0401<C4`80<a<00`dC4`064`0341<C0:DC00<04a<0;1<00`dC4`114`00;1<00a0C

4`0]4`0301<C00HC0P044`0301<C03<C00<=4a<01Q<00a0C4`2T4`0301<C02dC0Pe14`00:a<00a0C

4`0]4`0301<000LC00<04a<00a<00`0C4`0c4`033A<C00LC00<@4a<0Xa<2030C00<=4a<0?Q<002XC

00<@4a<0;a<00`0C4`064`<00a<00`0C4`0d4`033A<C00LC00<@4a<0XQ<00`0C4`0`4`8=?Q<002TC

00<@4a<0?a<203HC00<=4a<01a<00a0C4`2Q4`0301<C038C0Pdl4`00:1<00a0C4`104`0301<C03DC

00<=4a<021<00a0C4`2P4`0301<C03@C0Pdj4`009a<00a0C4`114`0301<C03HC00<=4a<021<00a0C

4`2O4`0301<C03HC0Pdh4`009Q<00a0C4`124`0301<C03LC00<=4a<021<00a0C4`2N4`80>A<23CHC

000U4`0341<C04<C0P0h4`033A<C00TC00<@4a<0WA<00`0C4`0j4`8==1<002@C00<@4a<0A1<00`0C

4`0h4`033A<C00TC00<@4a<0W1<00`0C4`0l4`8=<Q<002<C00<@4a<0AA<00`0C4`0i4`033A<C00TC

00<@4a<0Va<00`0C4`0n4`8=<1<002<C00<@4a<0AA<00`0C4`0j4`033A<C00TC00<@4a<0VQ<00`0C

4`104`8=;Q<0028C00<@4a<0AQ<203/C00<=4a<02Q<00a0C4`2I4`80@a<23B`C000Q4`0341<C04LC

00<04a<0>a<00`dC4`0:4`0341<C09PC00<04a<0A1<23BXC000P4`0341<C04PC00<04a<0?1<00`dC

4`0:4`0341<C094C0`034`0301<C04HC0PdX4`007a<00a0C4`194`0301<C03`C00<=4a<02a<00a0C

4`2@4`0301<C00<C00<04a<0B1<23BHC000N4`0341<C04XC0P0n4`033A<C00/C00<@4a<0T1<00`0C

4`024`80Ba<23B@C000M4`0341<C04/C00<04a<0?A<00`dC4`0<4`0341<C08lC00<04a<00Q<00`0C

4`1<4`<=8A<001`C00<@4a<0C1<00`0C4`0n4`033A<C00`C00<@4a<0SA<00`0C00034`0301<C04lC

0PdO4`006a<00a0C4`174`8011<00`0C4`0o4`033A<C00`C00<@4a<0SA<00`0C4`024`0301<C054C

0PdM4`006Q<00a0C4`1:4`0501<C4`00@A<00`dC4`0=4`0341<C094C00<04a<0Da<23A/C000I4`03

41<C04XC00<04a<00Q<2044C00<=4a<031<00a0C4`2A4`80EQ<23ATC001W4`0301<C0>LC00<04a<0

Ea<23ALC001U4`0301<00>TC00<04a<0L1<006HC00<04a<0j1<00`0C4`1`4`00;1<30?lC8a<2074C

000/4`0301<C0?lC8a<00`0C4`1`4`00;A<00`0C4`054`0301<C0?lCSA<002dC00@04a<C0`0011<0

4a<30?lCRQ<002`C00<04`000Q<2008C00<04a<00Q<00`0C4`3o4hPC000]4`0301<C00<C00@04a<0

0Q<00`0C4`3o4hTC000c4`0401<C00<C00<04a<01Q<00`0C4`0U4`<0;A<00`0C4`3o4bLC000M4`<0

00<C00000P0<4`<011<300PC00<04a<091<0100C4`0A4`<000<C00000P024`0301<C008C00<04a<0

0Q<00`0C4`054`0401<C4`D00Q<00`0C4`024`0301<C008C0`044`80ba<00`0C4`0b4`0301<C00PC

000L4`0401<C02@C00<04a<08a<0100C4`0@4`0401<C00HC00<04`001a<00`0C00044`D00a<00`0C

4`064`0301<000@C00<04a<00Q<00`0C4`334`0301<C00@C00<04a<04a<00`0C4`0N4`0301<C00LC

000L4`0501<C01<010000a<0000H02/C0`0@4`0501<C01<0100011<04`094`0301<C00@C00<04a<0

0a<00`0C4`084`0301<C00@00a<00`0C4`2a4`0401<C4`@00Q<200HC00<04a<00a<00`0C4`024`03

01<C008C00<04a<00Q<00`0C4`054`0401<C4`D00Q<00`0C4`024`0301<C008C0`044`8011<0100C

4a<2004C0@0100007A<304dC00<04a<03a<300HC00<04`001a<200LC00<04a<00a<00`0C4`064`80

0a<00`0C00044`0301<C0;0C00<04`001a<00`0C4`044`D00a<01`0C4a<04`001a<00`0C00044`D0

0a<00`0C4`064`0301<000@C00<04a<00Q<00`0C4`044`0301<C008C00<04`000A<001lC00<04a<0

BQ<201<C00<04a<011<00`0C00074`0301<C00`C00<04a<01Q<00`0C4`034`8011<00`0C002`4`03

01<0008C10000a<04`074`0301<C00<C00L04a<C01<000TC00<04a<011<00`0C4`034`0301<C00PC

00<04a<010034`0301<C00@C00<04a<00a<1004C0A<001hC0P1P4`801a<00`0C4`064`<02a<200PC

0`044`0301<C008C0`2F4`8000<C00005A<00`0C00074`0301<C00HC00<04a<00a<01`0C4a<04`00

1a<200LC00<04a<00a<00`0C4`064`800a<00`0C00044`0301<C00@C00<04a<00a<1004C0A<00?lC

DA<00`0C000F4`0301<000LC00<04`003A<01P0C4`0C00LC00<04a<031<00`0C4`064`0301<C00<C

0P044`0301<000<C00<04a<00a<00`0C00014`00:A<200HC0P3o4alC00<04a<05Q<00`0C4`064`<0

3Q<0100C4`084`<02a<200PC0`044`0301<C008C0`024`0301<C00<C0P014`400@0002/C00<04a<0

0Q<00`0C4`3o4alC00<04a<0L1<002XC00<04a<00a<00`0C4`054`0301<C0?lC5Q<00`0C001a4`00

:a<00`0C4`024`0301<C008C10034`<0oa<A4`8000<C0000L1<002TC00<04`0011<00`0C00024`80

00<C01<011<00`0C4`3o4h@C000Z4`0301<C00<C0`044`0301<000<C00<04a<0oa>54`00=a<00`0C

00044`0301<C0?lCQ1<003DC0`044`<0oa>64`00oa?54`00oa?54`00oa?54`00oa?54`00oa?54`00

\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.43111, -1.70638, 0.022012, 0.022012}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -84.5 0 ]

[.5 .96488 84.5 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -145.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.535) show

222.250000 19.500000 moveto

(C) show

227.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.26733 0 m

.30316 .05499 L

.34309 .11628 L

.3815 .17524 L

.42237 .23797 L

.46172 .29838 L

.49955 .35645 L

.53984 .4183 L

.57861 .47781 L

.61984 .54109 L

.65954 .60204 L

.69774 .66067 L

.73838 .72306 L

.77751 .78312 L

.81909 .84695 L

.85916 .90845 L

s

.85916 .90845 m

.88778 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.377166 0.238095 [

[.02381 .36467 -6 -9 ]

[.02381 .36467 6 0 ]

[.2619 .36467 -6 -9 ]

[.2619 .36467 6 0 ]

[.7381 .36467 -3 -9 ]

[.7381 .36467 3 0 ]

[.97619 .36467 -3 -9 ]

[.97619 .36467 3 0 ]

[1.025 .37717 0 -8 ]

[1.025 .37717 9 8 ]

[.4875 .02002 -24 -4.5 ]

[.4875 .02002 0 4.5 ]

[.4875 .13907 -12 -4.5 ]

[.4875 .13907 0 4.5 ]

[.4875 .25812 -24 -4.5 ]

[.4875 .25812 0 4.5 ]

[.4875 .49621 -18 -4.5 ]

[.4875 .49621 0 4.5 ]

[.4875 .61526 -6 -4.5 ]

[.4875 .61526 0 4.5 ]

[.4875 .73431 -18 -4.5 ]

[.4875 .73431 0 4.5 ]

[.4875 .85336 -6 -4.5 ]

[.4875 .85336 0 4.5 ]

[.5 .92943 -4.5 0 ]

[.5 .92943 4.5 16 ]

[.5 .91693 -137 0 ]

[.5 .91693 137 16 ]

[ 0 0 0 0 ]

[ 1 .90443 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .37717 m

.02381 .38342 L

s

[(-2)] .02381 .36467 0 1 Mshowa

.2619 .37717 m

.2619 .38342 L

s

[(-1)] .2619 .36467 0 1 Mshowa

.7381 .37717 m

.7381 .38342 L

s

[(1)] .7381 .36467 0 1 Mshowa

.97619 .37717 m

.97619 .38342 L

s

[(2)] .97619 .36467 0 1 Mshowa

.125 Mabswid

.07143 .37717 m

.07143 .38092 L

s

.11905 .37717 m

.11905 .38092 L

s

.16667 .37717 m

.16667 .38092 L

s

.21429 .37717 m

.21429 .38092 L

s

.30952 .37717 m

.30952 .38092 L

s

.35714 .37717 m

.35714 .38092 L

s

.40476 .37717 m

.40476 .38092 L

s

.45238 .37717 m

.45238 .38092 L

s

.54762 .37717 m

.54762 .38092 L

s

.59524 .37717 m

.59524 .38092 L

s

.64286 .37717 m

.64286 .38092 L

s

.69048 .37717 m

.69048 .38092 L

s

.78571 .37717 m

.78571 .38092 L

s

.83333 .37717 m

.83333 .38092 L

s

.88095 .37717 m

.88095 .38092 L

s

.92857 .37717 m

.92857 .38092 L

s

.25 Mabswid

0 .37717 m

1 .37717 L

s

gsave

1.025 .37717 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .02002 m

.50625 .02002 L

s

[(-1.5)] .4875 .02002 1 0 Mshowa

.5 .13907 m

.50625 .13907 L

s

[(-1)] .4875 .13907 1 0 Mshowa

.5 .25812 m

.50625 .25812 L

s

[(-0.5)] .4875 .25812 1 0 Mshowa

.5 .49621 m

.50625 .49621 L

s

[(0.5)] .4875 .49621 1 0 Mshowa

.5 .61526 m

.50625 .61526 L

s

[(1)] .4875 .61526 1 0 Mshowa

.5 .73431 m

.50625 .73431 L

s

[(1.5)] .4875 .73431 1 0 Mshowa

.5 .85336 m

.50625 .85336 L

s

[(2)] .4875 .85336 1 0 Mshowa

.125 Mabswid

.5 .04383 m

.50375 .04383 L

s

.5 .06764 m

.50375 .06764 L

s

.5 .09145 m

.50375 .09145 L

s

.5 .11526 m

.50375 .11526 L

s

.5 .16288 m

.50375 .16288 L

s

.5 .18669 m

.50375 .18669 L

s

.5 .2105 m

.50375 .2105 L

s

.5 .23431 m

.50375 .23431 L

s

.5 .28193 m

.50375 .28193 L

s

.5 .30574 m

.50375 .30574 L

s

.5 .32955 m

.50375 .32955 L

s

.5 .35336 m

.50375 .35336 L

s

.5 .40098 m

.50375 .40098 L

s

.5 .42478 m

.50375 .42478 L

s

.5 .44859 m

.50375 .44859 L

s

.5 .4724 m

.50375 .4724 L

s

.5 .52002 m

.50375 .52002 L

s

.5 .54383 m

.50375 .54383 L

s

.5 .56764 m

.50375 .56764 L

s

.5 .59145 m

.50375 .59145 L

s

.5 .63907 m

.50375 .63907 L

s

.5 .66288 m

.50375 .66288 L

s

.5 .68669 m

.50375 .68669 L

s

.5 .7105 m

.50375 .7105 L

s

.5 .75812 m

.50375 .75812 L

s

.5 .78193 m

.50375 .78193 L

s

.5 .80574 m

.50375 .80574 L

s

.5 .82955 m

.50375 .82955 L

s

.5 .87717 m

.50375 .87717 L

s

.5 .90098 m

.50375 .90098 L

s

.25 Mabswid

.5 0 m

.5 .90443 L

s

gsave

.5 .92943 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .91693 -198 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.535) show

298.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

303.000000 15.000000 moveto

(L) show

310.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

317.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

324.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

329.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

333.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .90443 L

0 .90443 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .21902 m

.02576 .21901 L

.03157 .21898 L

.04115 .21893 L

.05434 .21886 L

.0709 .21877 L

.09055 .21865 L

.11296 .2185 L

.13774 .21832 L

.16447 .21811 L

.1927 .21785 L

.22193 .21755 L

.25167 .2172 L

.28141 .21679 L

.31065 .21631 L

.33887 .21577 L

.3656 .21515 L

.39039 .21446 L

.4128 .21371 L

.43245 .21293 L

.44901 .21216 L

.46219 .21145 L

.47177 .21088 L

.47759 .2105 L

.47954 .21037 L

s

.47954 .21037 m

.48166 .21022 L

.488 .20977 L

.49844 .20894 L

.51281 .20763 L

.53085 .20563 L

.55227 .2026 L

.57669 .19797 L

.6037 .19095 L

.63283 .18088 L

.66359 .16778 L

.69545 .15257 L

.72786 .13639 L

.76028 .12014 L

.79214 .10441 L

.82289 .08958 L

.85203 .0759 L

.87904 .06354 L

.90346 .05263 L

.92487 .04326 L

.94292 .03551 L

.95729 .02942 L

.96773 .02505 L

.97407 .02241 L

.97619 .02153 L

s

.47954 .46051 m

.48166 .43344 L

.488 .40663 L

.49844 .38035 L

.51281 .35485 L

.53085 .33045 L

.55227 .30763 L

.57669 .28707 L

.6037 .26968 L

.63283 .25623 L

.66359 .2468 L

.69545 .24058 L

.72786 .23652 L

.76028 .2338 L

.79214 .23191 L

.82289 .23057 L

.85203 .22959 L

.87904 .22885 L

.90346 .2283 L

.92487 .22788 L

.94292 .22757 L

.95729 .22734 L

.96773 .22719 L

.97407 .2271 L

.97619 .22707 L

s

.47954 .46062 m

.48166 .48784 L

.488 .5151 L

.49844 .5422 L

.51281 .56902 L

.53085 .59542 L

.55227 .62127 L

.57669 .64646 L

.6037 .67087 L

.63283 .69439 L

.66359 .71692 L

.69545 .73835 L

.72786 .7586 L

.76028 .77757 L

.79214 .79518 L

.82289 .81135 L

.85203 .82601 L

.87904 .83911 L

.90346 .85057 L

.92487 .86036 L

.94292 .86842 L

.95729 .87473 L

.96773 .87926 L

.97407 .88198 L

.97619 .88289 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<00`0C4`1`4`00oa=B4`0301<C070C001T4`D0ea<5008C00<04a<00Q<00`0C4`024`03

01<C070C001V4`0301<C0=TC00<04a<01Q<00`0C00034`0301<C070C00134`033A<C01XC0`034`03

01<C008C0P3?4`<00a<00`0C4`084`0401<C4`80FA<00`dC4`0E4`00A1<00`dC4`0O4`0301<C008C

00<04a<0e1<00`0C4`064`8011<00`0C4`1F4`<=5a<004@C00<=4a<07a<00`0C4`024`0301<C0=@C

00<04a<01Q<00`0C4`034`0301<C05@C0PdJ4`00AA<00`dC4`0M4`8011<00`0C4`3C4`8021<300<C

00<04a<0DA<33A`C00154`033A<C02<C0P3T4`0301<C04hC0`dO4`00AQ<00`dC4`0R4`0301<C0><C

0P1=4`8=8Q<004LC00<=4a<08A<00`0C4`3S4`0301<C04TC0`dT4`00Aa<00`dC4`0Q4`0301<C0><C

00<04a<0Aa<23BLC00184`033A<C020C0P3T4`0301<C04DC0PdY4`00B1<00`dC4`0P4`0301<C0><C

0P144`8=:a<004TC00<=4a<07a<00`0C4`3S4`0301<C044C0Pd]4`00BQ<00`dC4`0N4`0301<C0><C

00<04a<0?a<23BlC001:4`033A<C01hC0P3T4`0301<C03dC0Pda4`00Ba<00`dC4`0M4`0301<C0><C

00<04a<0>a<23C<C001<4`033A<C01`C00<04a<0ha<203XC0Pde4`00C1<00`dC4`0L4`0301<C0><C

00<04a<0=a<23CLC001=4`033A<C01/C0P3T4`0301<C03DC0Pdi4`00CQ<00`dC4`0J4`0301<C0><C

00<04a<0<a<23C/C001?4`033A<C00XC00<04a<00Q<00`0C4`024`0301<C008C00<04a<0ha<2038C

0Pdm4`00Ca<00`dC4`094`0301<000LC00<04`000a<00`0C4`3S4`0301<C02lC0Pdo4`00D1<00`dC

4`034`<00Q<00`0C00094`0401<C4`80i1<00`0C4`0]4`8=@A<0054C00<=4a<01a<00`0C00074`80

11<00`0C4`3L4`D00Q<00`0C4`0[4`8=@a<0054C00<=4a<01a<00`0C00074`0301<C00<C00<04a<0

gQ<00`0C4`024`0301<C02PC0`e54`00DQ<00`dC4`074`0301<C00HC0`034`0301<C0=PC0`034`03

01<C008C0P0W4`8=B1<005<C00<=4a<05A<00`0C4`3N4`0301<C008C00<04a<091<23DXC001C4`03

3A<C01DC0P3O4`0301<C008C00<04a<08Q<23D`C001D4`033A<C01@C00<04a<0gA<200@C00<04a<0

81<23DhC001E4`033A<C01<C00<04a<0ha<201lC0Pe@4`00EQ<00`dC4`0B4`0301<C0><C00<04a<0

71<23E8C001F4`033A<C018C0P3T4`0301<C01XC0PeD4`00Ea<00`dC4`0A4`0301<C0><C00<04a<0

61<23EHC000J4`<09A<5014C00<=4a<041<00`0C4`0T4`D091<309<C00<04a<05A<33EPC000J4`03

01<C02LC00<04a<04A<00`dC4`0@4`0301<C02HC00<04a<091<00`0C4`2C4`8051<23E/C000E4`<0

0a<00`0C4`0P4`<00a<00`0C4`0B4`033A<C00lC0P0W4`0301<C02DC00<04a<0TQ<00`0C4`0?4`@=

GA<001/C00<04a<09Q<00`0C4`0C4`033A<C00hC00<04a<09Q<00`0C4`0U4`0301<C098C00<04a<0

2Q<53F4C000J4`0301<002LC00<04a<04a<00`dC4`0>4`0301<C02HC00<04a<091<00`0C002C4`03

01<C008C20eV4`006a<00`0C4`0U4`805Q<00`dC4`0=4`0301<C02DC0P0W4`0301<C08hC2@e^4`00

Fa<00`dC4`0=4`80`a<M3@@C00<04a<0L1<005`C00<=4a<031<00`0C4`284cX=8A<00`0C4`1`4`00

GA<00`dC4`0;4`0301<C05/C0P264`0301<C070C001M4`033A<C00/C00<04a<0FQ<00`0C4`264`03

01<C03TC80dG4`005A=900033@0006401Q<00`0C4`264`809a<C3CLC000I4`0301<C00HC00<04a<0

1A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<01@0C4a<=00<C

00<04a<01A<00a0C4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C

4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00PC00<04a<0QQ<00`0C4`0P4`H=BQ<005lC

00<=4a<02A<00a0C4`1J4`0301<008HC00<04a<06a<53E0C001P4`033A<C00PC0Q1K4`<0Ma<00`0C

4`024`0301<C008C00<04a<00Q<00`0C4`0H4`<=EA<0064C00<=4a<01a<24=@C00<04`001a<00`0C

00034`0301<C01HC0PeH4`00HA<00`dC4`064`03400@0<lC0`024`0301<000TC00@04a<C0P0E4`8=

FQ<0068C00<=4a<01A<00a00403D4`0301<000LC0P044`0301<C018C0PeL4`00Ha<00`dC4`044`03

400@0=@C00<04`001a<00`0C4`034`0301<C014C00<=4a<0G1<006@C00<=4a<00Q<01A0C000@0=@C

00<04a<01Q<300<C00<04a<03a<23ElC001T4`033A<C008C00D@4`0C403S4`803Q<23F4C001U4`09

3A<C4a0C01<@0><C00<04a<031<00`dC4`1Q4`00IQ<01PdC4a0C008C00<@4a<0h1<00`0C4`0;4`03

3A<C068C001V4`053A<C41<00P000a<@4`3Q4`0301<C00TC0PeU4`00Ia<01@dC41<0008C00<@4a<0

h1<00`0C4`084`033A<C06DC001W4`053A0C4`000a<00a0C4`3O4`8021<00`dC4`1V4`00J1<010dC

4`034`0341<C0=lC00<04a<01Q<00`dC4`1W4`00J1<00a0=4`02008C00<@4a<0ga<00`0C4`054`03

3A<C06PC001W4`0541<=4`0011<00a0C4`244`<0:Q<502PC00<04a<011<00`dC4`0Q4`D0:Q<301HC

001L4`0301<C008C00<04a<00Q<01P0@4a<=00@C00<@4a<0Q1<00`0C4`0/4`0301<C02PC0P044`03

3A<C02@C00<04a<0:Q<00`0C4`0F4`00Fa<00`0C00074`030100008C00<=01<00a<00a0C4`1o4`<0

0a<00`0C4`0U4`<00a<00`0C4`0X4`0301<C008C00<=4a<09A<00`0C4`0[4`0301<C01DC001K4`03

01<000PC00<@01<00Q<00`d04`034`0341<C08@C00<04a<0:a<00`0C4`0X4`0301<C008C00<=4a<0

9A<00`0C4`0[4`0301<C01DC001K4`0301<000LC00<041<00a<00`0=4`034`0341<C08<C00<04`00

;1<00`0C4`0X4`0501<C4`d0:1<00`0C4`0Z4`0301<001HC001K4`0301<000LC00<@4a<00a<00`0=

4`044`0341<C08<C00<04a<0:Q<202XC00D04a<C3@0W4`80;A<00`0C4`0E4`00G1<00`0C4`064`03

400000<C00<04`d011<00a0C4`3L4`8000<C3A<0KQ<006@C00<@4a<011<200034`dC008C00<@4a<0

g1<00`0C3@1`4`00I1<00a0C4`044`0401<C3@@C00<@4a<0fa<00`0C3@1U4`802A<006<C00<@4a<0

1A<01@0C4a<=00<C00<@4a<0fa<00`0=4`1T4`0301<C00TC001S4`0341<C00DC00D04a<C3@044`03

41<C07/CH0000`d0001M00HC00<04a<02A<0068C00<@4a<01Q<00`0C4`024`053A<C4a00PA<00`0C

4`064`0301<C00HC00<04a<01Q<00`0C4`074`0301<C00HC00<04a<01Q<00`0C4`064`0301<C00HC

00<04a<01Q<00`0C4`064`033A<C00HC00<04a<01Q<00`0C4`064`0301<C00HC00<04a<01a<00`0C

4`064`0301<C00HC00<04a<01Q<00`0C4`064`0301<C00HC00<04a<02A<00`0C4`094`00HQ<00a0C

4`064`8011<01@dC4a<@0=/C00<=4a<0I1<00`0C00094`00HA<00a0C4`074`0301<C00<C00D=4a<C

403J4`033@0C06DC0`094`00HA<00a0C4`074`0301<C00@C00@=4a<@fQ<00`d04`1a4`00H1<00a0C

4`084`0301<C00DC00@=4a<@f1<010dC001a4`00H1<00a0C4`084`801Q<010dC4a3H4`033A<0078C

001O4`0341<C00TC00<04a<01Q<010dC4a3G4`033A<0078C001O4`0341<C00TC00<04a<01a<00`dC

403G4`033A<0078C001N4`0341<C00XC00<04a<01a<010dC4a3E4`033A<C0080LA<005hC00<@4a<0

2Q<200TC00<=4a00eA<010dC4`1b4`00GA<00a0C4`0;4`0301<C00TC00<=4a00e1<010dC4`1b4`00

GA<00a0C4`044`D00Q<00`0C4`0:4`033A0C0=<C00@=4a<0LQ<005`C00<@4a<01a<00`0C4`024`03

01<C00XC00<=4a00da<010dC4`1b4`00Fa<00a0C4`084`0301<C008C0P0<4`033A<@0=4C00@=4a<C

0P1a4`00Fa<00a0C4`084`0301<C008C00<04a<031<00`d@4`3@4`053A<C4`00LQ<005XC00<@4a<0

2A<00`0C4`024`0301<C00`C00<=4a00d1<01@dC4a<0078C001J4`0341<C00PC0P044`0301<C00dC

00<=4a00ca<01@dC4a<0078C001I4`0341<C00lC0P0?4`033A0C0<hC00@=4a<C0P1a4`00F1<00a0C

4`0@4`0301<C00hC00<=4a00ca<010dC4`1b4`00F1<00a0C4`0@4`0301<C00lC00<=4a00cQ<010dC

4`1b4`00Ea<00a0C4`0A4`0301<C00lC00<=4a00`Q<00`0C4`024`0301<C008C00<04`d00Q<00`0C

4`1`4`00EQ<00a0C4`0B4`804A<00`dC40304`0301<000LC00@04`0=0Q<00`0C4`1`4`00EQ<00a0C

4`0B4`0301<C014C00<=4a00_a<00`0C00094`0400dC4`80LA<005DC00<@4a<04a<00`0C4`0A4`03

3A<@0;lC00<04`001a<200054`dC4`00LQ<005@C00<@4a<051<00`0C4`0B4`033A<@0;hC00<04`00

1a<01`0C4a<=4`00LQ<005<C00<@4a<05A<201@C00<=41<0_Q<00`0C4`064`<000@C3A<0LQ<005<C

00<@4a<05A<00`0C4`0C4`033A<@0</C00<=4`00LQ<0058C00<@4a<05Q<00`0C4`0D4`033A<@0<XC

00@=4`00LA<0054C00<@4a<05a<00`0C4`0E4`033A0C0<XC00<=01<0LA<0054C00<@4a<05a<201HC

00<=4a00bQ<00`d04`1a4`00D1<00a0C4`0H4`0301<C01HC00<=41<0bQ<00`dC4`1`4`00Ca<00a0C

4`084`D00Q<00`0C4`024`0301<C008C00<04a<05a<00`d@4`394`033@0C070C001?4`0341<C00XC

00<04a<01Q<00`0C00034`0301<C01PC00<=41<0b1<00`0=4`1`4`00CQ<00a0C4`0;4`0301<C00PC

00@04a<C0P0I4`033A<@0<PC00<03A<0L1<004dC00<@4a<031<00`0C4`064`8011<00`0C4`0I4`03

3A0C0<LC00<04`d0L1<004`C00<@4a<03A<00`0C4`064`0301<C00<C00<04a<06Q<00`d@4`364`03

01<=070C001<4`0341<C00`C0P084`<00a<00`0C4`0J4`033A<@0<HC0P000a<=4`1^4`00Ba<00a0C

4`0M4`8071<00`dC40354`0501<C4`d0KQ<004XC00<@4a<07Q<00`0C4`0K4`033A<@0<DC00D04a<C

3@1^4`00BQ<00a0C4`0N4`0301<C01`C00<=4a00a1<00`0C4`024`033A<C06/C00194`0341<C01lC

00<04a<07A<00`dC40334`800a<00`dC4`1[4`00B1<00a0C4`0P4`807Q<010dC4a324`0301<C00<C

00<=4a<0JQ<004LC00<@4a<08A<00`0C4`0N4`043A<C4<4C00<04a<011<00`dC4`1Y4`00Aa<00a0C

4`0Q4`0301<C01hC00@=4a<@^Q<5008C00<04a<01A<00`dC4`1X4`00AQ<00a0C4`0R4`0301<C01lC

00@=4a<@^a<00`0C4`024`0301<C00DC00<=4a<0J1<004DC00<@4a<08a<2024C00@=4a<@^Q<00`0C

4`024`801a<00`dC4`1W4`00A1<00a0C4`0T4`0301<C020C00D=4a<C402i4`0301<C008C00<04a<0

1a<00`dC4`1V4`00A1<00a0C4`0T4`0301<C024C00@=4a<@^A<00`0C4`024`0301<C00PC00<=4a<0

IA<004<C00<@4a<09A<00`0C4`0R4`043A<C4;LC0P044`0301<C00TC00<=4a<0I1<0048C00<@4a<0

9Q<00`0C4`0R4`053A<C4a00_1<200/C00<=4a<0Ha<0044C00<@4a<09a<202@C00D=4a<C402k4`03

01<C00/C00<=4a<0HQ<0040C00<@4a<0:1<00`0C4`0S4`033A<C008C00<@4a<0^1<00`0C4`0<4`03

3A<C064C00104`0341<C028C0`034`0301<C02@C00<=4a<00Q<00a0C4`2g4`0301<C00dC00<=4a<0

H1<003lC00<@4a<08a<00`0C4`034`0301<C02DC00D=4a<C402i4`0301<C00hC0PeP4`00?Q<00a0C

4`0U4`0301<C008C0P0V4`033A<C008C00<@4a<0]Q<2014C00<=4a<0GA<003dC00<@4a<09Q<00`0C

4`024`0301<C02HC00<=4a<00Q<00a0C4`2e4`0301<C014C00<=4a<0G1<003dC00<@4a<09A<00`0C

00034`0301<C02LC00<=4a<00Q<00a0C4`2d4`0301<C018C00<=4a<0Fa<003`C00<@4a<09a<00`0C

4`024`0301<C02LC00<=4a<00a<00a0C4`2c4`0301<C01<C00<=4a<0FQ<003/C00<@4a<0;A<202TC

00<=4a<00a<00a0C4`2b4`805A<00`dC4`1I4`00>Q<00a0C4`0^4`0301<C02TC00<=4a<00Q<00a0C

4`2b4`0301<C01DC00<=4a<0F1<003XC00<@4a<0;Q<00`0C4`0Y4`033A<C00<C00<@4a<0/A<00`0C

4`0F4`033A<C05LC000i4`0341<C02lC00<04a<0:Q<00`dC4`034`0341<C0;0C00<04a<05a<23ELC

000h4`0341<C030C0P0/4`033A<C00<C00<@4a<0[a<00`0C4`0I4`033A<C05@C000g4`0341<C034C

00<04a<0;1<00`dC4`024`0341<C0:lC0P0K4`8=E1<003LC00<@4a<0<A<00`0C4`0/4`033A<C00<C

00<@4a<0[Q<00`0C4`0L4`033A<C054C000f4`0341<C038C00<04a<0;A<00`dC4`034`0341<C09`C

1@024`0301<C008C00<04a<00Q<00`0C4`0M4`8=DA<003DC00<@4a<0<a<202lC00<=4a<00a<00a0C

4`2M4`0301<C00HC00<04`000a<00`0C4`0O4`033A<C04hC000d4`0341<C03@C00<04a<0;Q<00`dC

4`044`0341<C09`C00<04a<021<0100C4a<2024C0Pe>4`00<a<00a0C4`0e4`0301<C02lC00<=4a<0

11<00a0C4`2K4`0301<C00HC0P044`0301<C028C00<=4a<0Ba<0038C00<@4a<0=Q<00`0C4`0`4`03

3A<C00<C00<@4a<0Va<00`0C4`064`0301<C00<C00<04a<08a<23D/C000a4`0341<C03LC0P0a4`03

3A<C00@C00<@4a<0VA<200PC0`034`0301<C02DC0Pe94`00<1<00a0C4`0h4`0301<C034C00<=4a<0

11<00a0C4`2X4`0301<C02LC0Pe74`00;a<00a0C4`0Y4`<00a<00`0C4`024`0301<C008C00<04a<0

<A<00`dC4`054`0341<C0:LC0P0Z4`033A<C04@C000^4`0341<C02XC00<04a<01a<00`0C00034`03

01<C038C00<=4a<01A<00a0C4`2V4`0301<C02XC0Pe44`00;A<00a0C4`0/4`0301<C00PC00@04a<C

0P0d4`033A<C00DC00<@4a<0YA<00`0C4`0/4`033A<C044C000/4`0341<C02dC00<04a<01Q<200@C

00<04a<0<a<00`dC4`064`0341<C0:@C00<04a<0;A<23D4C000[4`0341<C02dC00<04`001a<00`0C

4`034`0301<C03@C00<=4a<01Q<00a0C4`2S4`0301<C02lC00<=4a<0?Q<002XC00<@4a<0;a<00`0C

4`064`<00a<00`0C4`0e4`033A<C00HC00<@4a<0XQ<2034C0Pdn4`00:A<00a0C4`0o4`80=Q<00`dC

4`074`0341<C0:4C00<04a<0<Q<23C`C000X4`0341<C040C00<04a<0=Q<00`dC4`074`0341<C0:0C

00<04a<0=1<23CXC000W4`0341<C044C00<04a<0=a<00`dC4`074`0341<C09lC00<04a<0=Q<23CPC

000V4`0341<C048C00<04a<0=a<00`dC4`084`0341<C09hC0P0i4`8==Q<002DC00<@4a<0@a<203TC

00<=4a<021<00a0C4`2M4`0301<C03XC0Pdd4`0091<00a0C4`144`0301<C03PC00<=4a<02A<00a0C

4`2L4`0301<C03`C0Pdb4`008a<00a0C4`154`0301<C03TC00<=4a<02A<00a0C4`2K4`0301<C03hC

0Pd`4`008a<00a0C4`154`0301<C03XC00<=4a<02A<00a0C4`2J4`0301<C040C0Pd^4`008Q<00a0C

4`164`80>a<00`dC4`0:4`0341<C09TC0P134`8=;1<0024C00<@4a<0Aa<00`0C4`0k4`033A<C00XC

00<@4a<0V1<00`0C4`144`8=:Q<0020C00<@4a<0B1<00`0C4`0l4`033A<C00XC00<@4a<0TA<300<C

00<04a<0AQ<23BPC000O4`0341<C04TC00<04a<0?1<00`dC4`0;4`0341<C090C00<04a<00a<00`0C

4`184`8=9Q<001hC00<@4a<0BQ<203hC00<=4a<02a<00a0C4`2@4`0301<C008C0P1;4`8=91<001dC

00<@4a<0Ba<00`0C4`0m4`033A<C00`C00<@4a<0Sa<00`0C4`024`0301<C04`C0`dQ4`0071<00a0C

4`1<4`0301<C03hC00<=4a<031<00a0C4`2=4`0301<000<C00<04a<0Ca<23AlC000K4`0341<C04LC

0P044`0301<C03lC00<=4a<031<00a0C4`2=4`0301<C008C00<04a<0DA<23AdC000J4`0341<C04XC

00D04a<C00114`033A<C00dC00<@4a<0TA<00`0C4`1C4`8=6a<001TC00<@4a<0BQ<00`0C4`024`80

@A<00`dC4`0<4`0341<C094C0P1F4`8=6A<006LC00<04a<0ia<00`0C4`1G4`8=5a<006DC00<04`00

jA<00`0C4`1`4`00IQ<00`0C4`3X4`0301<C070C000Z4`<0oa<U4`80LA<002XC00<04a<0oa<U4`03

01<C070C000[4`0301<C00@C00<04a<0oa>@4`00:a<0100C4a<400<C0`3o4h`C000Z4`0301<0008C

0P000a<04`044`0301<C0?lCRQ<002/C00<04a<00a<00`0C00034`0301<C0?lCRa<0034C00<04`00

11<00`0C4`064`0301<C02LC0`0[4`0301<C0?lC:A<001/C0`000a<0000200`C0`044`<021<00`0C

4`0V4`0401<C00lC0`000a<00002008C00<04a<00Q<00`0C4`024`0301<C00DC00@04a<C1@024`03

01<C008C00@04a<C0P044`0301<C00@C0P354`0301<C03LC00<04a<01Q<001XC00@04a<091<00`0C

4`0U4`0401<C00hC00@04a<01Q<00`0C00074`0301<000@C1@034`0301<C00HC00<04`0011<01P0C

4`0C00@C00<04a<0_A<00`0C4`044`0301<C01<C00<04a<08a<00`0C4`054`006Q<01@0C4`0C00@0

00<C0000600]4`<03Q<01@0C4`0C00@000@C01<02A<00`0C4`044`0301<C00<C00<04a<021<01@0C

4a<000DC00<04a<00Q<00`0C4`2[4`0401<C4`@00Q<200HC00<04a<00a<00`0C4`024`0301<C008C

00<04a<00Q<00`0C4`054`0401<C4`D00Q<00`0C4`024`0401<C4`8011<00`0C4`044`8011<0100C

4a<2004C000K4`<0Ca<00`0C4`0=4`<01Q<00`0C00074`801a<00`0C4`034`0301<C00HC0P054`03

01<C00801A<00`0C4`2Z4`0301<000LC00<04a<011<500<C00L04a<C01<000LC00<04`0011<500<C

00<04a<01Q<00`0C00044`0601<C01<011<00`0C4`044`0301<C008C0@014`007A<00`0C4`1<4`80

4A<00`0C4`044`0301<000LC00<04a<031<00`0C4`064`0301<C008C00<04`000Q<00`0C4`044`03

01<00:XC00<04`000Q<400034`0C00LC00<04a<00a<01`0C4a<04`002A<00`0C4`044`0301<C00<C

00<04a<021<01@0C4a<000DC00<04a<00Q<00`0C4`044`0301<C00<C0@0001`C0P1P4`801a<00`0C

4`064`<02a<200PC0`034`0401<C4`<011<309<C0P000a<0000B4`0301<000LC00<04a<01Q<00`0C

4`034`0701<C4`0C00074`801a<00`0C4`034`0301<C00HC0P054`0301<C00801A<00`0C4`044`03

01<C00<C0@000?lCDA<00`0C000C4`0301<000LC00<04`003A<01P0C4`0C00LC00<04a<031<00`0C

4`064`0301<C008C00<04`000Q<00`0C4`044`0301<000<C00<04a<00a<1004C000V4`801Q<20?lC

8Q<00`0C4`0C4`0301<C00HC0`0>4`0401<C00PC0`0;4`8021<300<C00@04a<C0`044`<00Q<00`0C

4`034`800A<002PC00<04a<00Q<00`0C4`3o4b8C00<04a<0L1<002LC00<04a<00a<00`0C4`064`03

01<C0?lC61<00`0C001a4`00:1<00`0C4`024`0301<C008C0`0011<04a<30?lC51<200034`00070C

000V4`0301<000@C00<04`000Q<2008C00<04a<00Q<00`0C4`3o4hLC000W4`0301<C00<C0`044`04

01<C008C00<04a<0oa>84`00=1<0100C4`034`0301<C0?lCQa<0038C0`044`<0oa>94`00oa?54`00

oa?54`00oa?54`00oa?54`00oa?54`00\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.4267, -1.70627, 0.0219989, 0.0219989}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -82 0 ]

[.5 .96488 82 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -143 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.53) show

217.250000 19.500000 moveto

(C) show

222.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.26657 0 m

.30316 .05597 L

.34309 .11706 L

.3815 .17584 L

.42237 .23836 L

.46172 .29857 L

.49955 .35646 L

.53984 .4181 L

.57861 .47742 L

.61984 .54049 L

.65954 .60125 L

.69774 .65968 L

.73838 .72187 L

.77751 .78174 L

.81909 .84536 L

.85916 .90666 L

s

.85916 .90666 m

.88904 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.375982 0.238095 [

[.02381 .36348 -6 -9 ]

[.02381 .36348 6 0 ]

[.2619 .36348 -6 -9 ]

[.2619 .36348 6 0 ]

[.7381 .36348 -3 -9 ]

[.7381 .36348 3 0 ]

[.97619 .36348 -3 -9 ]

[.97619 .36348 3 0 ]

[1.025 .37598 0 -8 ]

[1.025 .37598 9 8 ]

[.4875 .01884 -24 -4.5 ]

[.4875 .01884 0 4.5 ]

[.4875 .13789 -12 -4.5 ]

[.4875 .13789 0 4.5 ]

[.4875 .25693 -24 -4.5 ]

[.4875 .25693 0 4.5 ]

[.4875 .49503 -18 -4.5 ]

[.4875 .49503 0 4.5 ]

[.4875 .61408 -6 -4.5 ]

[.4875 .61408 0 4.5 ]

[.4875 .73312 -18 -4.5 ]

[.4875 .73312 0 4.5 ]

[.4875 .85217 -6 -4.5 ]

[.4875 .85217 0 4.5 ]

[.5 .92769 -4.5 0 ]

[.5 .92769 4.5 16 ]

[.5 .91519 -134.5 0 ]

[.5 .91519 134.5 16 ]

[ 0 0 0 0 ]

[ 1 .90269 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .37598 m

.02381 .38223 L

s

[(-2)] .02381 .36348 0 1 Mshowa

.2619 .37598 m

.2619 .38223 L

s

[(-1)] .2619 .36348 0 1 Mshowa

.7381 .37598 m

.7381 .38223 L

s

[(1)] .7381 .36348 0 1 Mshowa

.97619 .37598 m

.97619 .38223 L

s

[(2)] .97619 .36348 0 1 Mshowa

.125 Mabswid

.07143 .37598 m

.07143 .37973 L

s

.11905 .37598 m

.11905 .37973 L

s

.16667 .37598 m

.16667 .37973 L

s

.21429 .37598 m

.21429 .37973 L

s

.30952 .37598 m

.30952 .37973 L

s

.35714 .37598 m

.35714 .37973 L

s

.40476 .37598 m

.40476 .37973 L

s

.45238 .37598 m

.45238 .37973 L

s

.54762 .37598 m

.54762 .37973 L

s

.59524 .37598 m

.59524 .37973 L

s

.64286 .37598 m

.64286 .37973 L

s

.69048 .37598 m

.69048 .37973 L

s

.78571 .37598 m

.78571 .37973 L

s

.83333 .37598 m

.83333 .37973 L

s

.88095 .37598 m

.88095 .37973 L

s

.92857 .37598 m

.92857 .37973 L

s

.25 Mabswid

0 .37598 m

1 .37598 L

s

gsave

1.025 .37598 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .01884 m

.50625 .01884 L

s

[(-1.5)] .4875 .01884 1 0 Mshowa

.5 .13789 m

.50625 .13789 L

s

[(-1)] .4875 .13789 1 0 Mshowa

.5 .25693 m

.50625 .25693 L

s

[(-0.5)] .4875 .25693 1 0 Mshowa

.5 .49503 m

.50625 .49503 L

s

[(0.5)] .4875 .49503 1 0 Mshowa

.5 .61408 m

.50625 .61408 L

s

[(1)] .4875 .61408 1 0 Mshowa

.5 .73312 m

.50625 .73312 L

s

[(1.5)] .4875 .73312 1 0 Mshowa

.5 .85217 m

.50625 .85217 L

s

[(2)] .4875 .85217 1 0 Mshowa

.125 Mabswid

.5 .04265 m

.50375 .04265 L

s

.5 .06646 m

.50375 .06646 L

s

.5 .09027 m

.50375 .09027 L

s

.5 .11408 m

.50375 .11408 L

s

.5 .1617 m

.50375 .1617 L

s

.5 .18551 m

.50375 .18551 L

s

.5 .20931 m

.50375 .20931 L

s

.5 .23312 m

.50375 .23312 L

s

.5 .28074 m

.50375 .28074 L

s

.5 .30455 m

.50375 .30455 L

s

.5 .32836 m

.50375 .32836 L

s

.5 .35217 m

.50375 .35217 L

s

.5 .39979 m

.50375 .39979 L

s

.5 .4236 m

.50375 .4236 L

s

.5 .44741 m

.50375 .44741 L

s

.5 .47122 m

.50375 .47122 L

s

.5 .51884 m

.50375 .51884 L

s

.5 .54265 m

.50375 .54265 L

s

.5 .56646 m

.50375 .56646 L

s

.5 .59027 m

.50375 .59027 L

s

.5 .63789 m

.50375 .63789 L

s

.5 .6617 m

.50375 .6617 L

s

.5 .68551 m

.50375 .68551 L

s

.5 .70931 m

.50375 .70931 L

s

.5 .75693 m

.50375 .75693 L

s

.5 .78074 m

.50375 .78074 L

s

.5 .80455 m

.50375 .80455 L

s

.5 .82836 m

.50375 .82836 L

s

.5 .87598 m

.50375 .87598 L

s

.5 .89979 m

.50375 .89979 L

s

.25 Mabswid

.5 0 m

.5 .90269 L

s

gsave

.5 .92769 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .91519 -195.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.53) show

293.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

298.000000 15.000000 moveto

(L) show

305.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

312.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

319.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

324.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

328.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .90269 L

0 .90269 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .21743 m

.02576 .21742 L

.03157 .21739 L

.04115 .21735 L

.05434 .21728 L

.07089 .21719 L

.09055 .21707 L

.11295 .21693 L

.13774 .21675 L

.16447 .21655 L

.19269 .2163 L

.22192 .21601 L

.25166 .21567 L

.2814 .21528 L

.31063 .21482 L

.33886 .2143 L

.36559 .2137 L

.39037 .21304 L

.41278 .21232 L

.43243 .21158 L

.44899 .21084 L

.46217 .21016 L

.47175 .20961 L

.47756 .20925 L

.47951 .20912 L

s

.47951 .20912 m

.48164 .20898 L

.48797 .20854 L

.49842 .20775 L

.51278 .20649 L

.53083 .20458 L

.55225 .20166 L

.57667 .1972 L

.60368 .19039 L

.63282 .18051 L

.66358 .16755 L

.69544 .15241 L

.72785 .13626 L

.76027 .12003 L

.79213 .10431 L

.82289 .08949 L

.85202 .07582 L

.87903 .06347 L

.90345 .05256 L

.92487 .0432 L

.94292 .03545 L

.95729 .02938 L

.96773 .02501 L

.97407 .02237 L

.97619 .02149 L

s

.47951 .45935 m

.48164 .4323 L

.48797 .4055 L

.49842 .37922 L

.51278 .35369 L

.53083 .32924 L

.55225 .30633 L

.57667 .28565 L

.60368 .26808 L

.63282 .25447 L

.66358 .24493 L

.69544 .23867 L

.72785 .23459 L

.76027 .23189 L

.79213 .23002 L

.82289 .22869 L

.85202 .22772 L

.87903 .227 L

.90345 .22645 L

.92487 .22604 L

.94292 .22574 L

.95729 .22552 L

.96773 .22537 L

.97407 .22528 L

.97619 .22525 L

s

.47951 .45947 m

.48164 .48666 L

.48797 .5139 L

.49842 .54098 L

.51278 .56776 L

.53083 .59413 L

.55225 .61995 L

.57667 .6451 L

.60368 .66948 L

.63282 .69297 L

.66358 .71546 L

.69544 .73687 L

.72785 .75709 L

.76027 .77603 L

.79213 .79361 L

.82289 .80976 L

.85202 .8244 L

.87903 .83748 L

.90345 .84893 L

.92487 .8587 L

.94292 .86675 L

.95729 .87305 L

.96773 .87757 L

.97407 .88029 L

.97619 .8812 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<00`0C4`1`4`00oa=B4`0301<C070C001T4`D0ea<5008C00<04a<00Q<00`0C4`024`03

01<C070C001V4`0301<C0=TC00<04a<01Q<00`0C00034`0301<C070C00134`033A<C01XC0`034`03

01<C008C0P3?4`<00a<00`0C4`084`0401<C4`80LA<004@C00<=4a<07a<00`0C4`024`0301<C0=@C

00<04a<01Q<200@C00<04a<0EQ<33ALC00144`033A<C01lC00<04a<00Q<00`0C4`3D4`0301<C00HC

00<04a<00a<00`0C4`1D4`8=6Q<004DC00<=4a<07A<200@C00<04a<0da<200PC0`034`0301<C058C

0PdL4`00AA<00`dC4`0S4`80i1<00`0C4`1@4`8=7Q<004HC00<=4a<08Q<00`0C4`3S4`80Ca<23B0C

00174`033A<C024C00<04a<0ha<00`0C4`1<4`8=8Q<004LC00<=4a<08A<00`0C4`3S4`0301<C04XC

0PdT4`00B1<00`dC4`0P4`80i1<00`0C4`184`8=9Q<004PC00<=4a<081<00`0C4`3S4`80AQ<33BPC

00194`033A<C01lC00<04a<0ha<00`0C4`124`<=:a<004XC00<=4a<07Q<00`0C4`3S4`0301<C040C

0Pd^4`00BQ<00`dC4`0N4`80i1<00`0C4`0n4`8=<1<004/C00<=4a<07A<00`0C4`3S4`0301<C03`C

0Pdb4`00C1<00`dC4`0L4`0301<C0><C0P0k4`8==1<004`C00<=4a<071<00`0C4`3S4`0301<C03LC

0`df4`00CA<00`dC4`0K4`80i1<00`0C4`0e4`8=>A<004hC00<=4a<06Q<00`0C4`3S4`0301<C03<C

0Pdk4`00Ca<00`dC4`0:4`0301<C008C00<04a<00Q<00`0C4`024`0301<C0><C0P0b4`8=?A<004lC

00<=4a<02A<00`0C00074`0301<000<C00<04a<0ha<00`0C4`0_4`8=?a<0050C00<=4a<00a<3008C

00<04`002A<0100C4a<20>@C00<04a<0;A<23D4C001A4`033A<C00LC00<04`001a<200@C00<04a<0

g1<5008C00<04a<0:a<23D<C001A4`033A<C00LC00<04`001a<00`0C4`034`0301<C0=hC00<04a<0

0Q<00`0C4`0Y4`8=AA<0058C00<=4a<01a<00`0C4`064`<00a<00`0C4`3H4`<00a<00`0C4`024`80

:1<23DLC001C4`033A<C01DC00<04a<0gQ<00`0C4`024`0301<C02DC0Pe94`00Da<00`dC4`0E4`80

ga<00`0C4`024`0301<C02<C0Pe;4`00E1<00`dC4`0D4`0301<C0=dC0P044`0301<C024C0Pe=4`00

EA<00`dC4`0C4`0301<C0><C0P0O4`<=Ca<005HC00<=4a<04Q<00`0C4`3S4`0301<C01`C0PeB4`00

EQ<00`dC4`0B4`80i1<00`0C4`0J4`8=E1<005LC00<=4a<04A<00`0C4`3S4`0301<C01PC0PeF4`00

6Q<302DC1@0A4`033A<C010C00<04a<091<502@C0`2C4`0301<C01DC0`eH4`006Q<00`0C4`0W4`03

01<C014C00<=4a<041<00`0C4`0V4`0301<C02@C00<04a<0Ta<201@C0PeK4`005A<300<C00<04a<0

81<300<C00<04a<04Q<00`dC4`0?4`809a<00`0C4`0U4`0301<C098C00<04a<03a<43EdC000K4`03

01<C02HC00<04a<04a<00`dC4`0>4`0301<C02HC00<04a<09A<00`0C4`2B4`0301<C00XC1@eQ4`00

6Q<00`0C000W4`0301<C01<C00<=4a<03Q<00`0C4`0V4`0301<C02@C00<04`00Ta<00`0C4`064`@=

IQ<001/C00<04a<09A<201HC00<=4a<03A<00`0C4`0U4`809a<00`0C4`2>4`d=JQ<005/C00<=4a<0

3A<20<<C7@d44`0301<C070C001L4`033A<C00`C00<04a<0R1<j3B4C00<04a<0L1<005dC00<=4a<0

2a<00`0C4`1K4`80QQ<00`0C4`1H4`033A<C01DC001M4`033A<C00/C00<04a<0FQ<00`0C4`264`03

01<C03<C9@dH4`005A=900033@0006401Q<00`0C4`264`809a<=3CdC000I4`0301<C00HC00<04a<0

1A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<01@0C4a<=00<C

00<04a<01A<00a0C4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C

4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00PC00<04a<0QQ<00`0C4`0P4`H=BQ<005lC

00<=4a<02A<00a0C4`1J4`0301<008HC00<04a<06a<53E0C001P4`033A<C00PC0Q1K4`<0Ma<00`0C

4`024`0301<C008C00<04a<00Q<00`0C4`0H4`<=EA<0064C00<=4a<01a<24=@C00<04`001a<00`0C

00034`0301<C01HC0PeH4`00HA<00`dC4`064`03400@0<lC0`024`0301<000TC00@04a<C0P0E4`8=

FQ<0068C00<=4a<01A<00a00403D4`0301<000LC0P044`0301<C018C0PeL4`00Ha<00`dC4`044`03

400@0=@C00<04`001a<00`0C4`034`0301<C014C00<=4a<0G1<006@C00<=4a<00Q<01A0C000@0=@C

00<04a<01Q<300<C00<04a<03a<23ElC001T4`033A<C008C00D@4`0C403S4`803Q<23F4C001U4`09

3A<C4a0C01<@0><C00<04a<031<00`dC4`1Q4`00IQ<01PdC4a0C008C00<@4a<0h1<00`0C4`0;4`03

3A<C068C001V4`053A<C41<00P000a<@4`3Q4`0301<C00TC0PeU4`00Ia<01@dC41<0008C00<@4a<0

h1<00`0C4`084`033A<C06DC001W4`053A0C4`000a<00a0C4`3O4`8021<00`dC4`1V4`00J1<010dC

4`034`0341<C0=lC00<04a<01Q<00`dC4`1W4`00J1<00a0=4`02008C00<@4a<0ga<00`0C4`054`03

3A<C06PC001W4`0541<=4`0011<00a0C4`244`<0:Q<502PC00<04a<011<00`dC4`0Q4`D0:Q<301HC

001L4`0301<C008C00<04a<00Q<01P0@4a<=00@C00<@4a<0Q1<00`0C4`0/4`0301<C02PC0P044`03

3A<C02@C00<04a<0:Q<00`0C4`0F4`00Fa<00`0C00074`030100008C00<=01<00a<00a0C4`1o4`<0

0a<00`0C4`0U4`<00a<00`0C4`0X4`0301<C008C00<=4a<09A<00`0C4`0[4`0301<C01DC001K4`03

01<000PC00<@01<00Q<00`d04`034`0341<C08@C00<04a<0:a<00`0C4`0X4`0301<C008C00<=4a<0

9A<00`0C4`0[4`0301<C01DC001K4`0301<000LC00<041<00a<00`0=4`034`0341<C08<C00<04`00

;1<00`0C4`0X4`0501<C4`d0:1<00`0C4`0Z4`0301<001HC001K4`0301<000LC00<@4a<00a<00`0=

4`044`0341<C08<C00<04a<0:Q<202XC00D04a<C3@0W4`80;A<00`0C4`0E4`00G1<00`0C4`064`03

400000<C00<04`d011<00a0C4`3L4`8000<C3A<0KQ<006@C00<@4a<011<200034`dC008C00<@4a<0

g1<00`0C3@1`4`00I1<00a0C4`044`0401<C3@@C00<@4a<0fa<00`0C3@1U4`802A<006<C00<@4a<0

1A<01@0C4a<=00<C00<@4a<0fa<00`0=4`1T4`0301<C00TC001S4`0341<C00DC00D04a<C3@044`03

41<C07/CH0000`d0001M00HC00<04a<02A<0068C00<@4a<01Q<00`0C4`024`053A<C4a00PA<00`0C

4`064`0301<C00HC00<04a<01Q<00`0C4`074`0301<C00HC00<04a<01Q<00`0C4`064`0301<C00HC

00<04a<01Q<00`0C4`064`033A<C00HC00<04a<01Q<00`0C4`064`0301<C00HC00<04a<01a<00`0C

4`064`0301<C00HC00<04a<01Q<00`0C4`064`0301<C00HC00<04a<02A<00`0C4`094`00HQ<00a0C

4`064`8011<01@dC4a<@0=/C00<=4a<0I1<00`0C00094`00HA<00a0C4`074`0301<C00<C00D=4a<C

403J4`033@0C06DC0`094`00HA<00a0C4`074`0301<C00@C00@=4a<@fQ<00`d04`1a4`00H1<00a0C

4`084`0301<C00DC00@=4a<@f1<010dC001a4`00H1<00a0C4`084`801Q<010dC4a3H4`033A<0078C

001O4`0341<C00TC00<04a<01Q<010dC4a3G4`033A<0078C001O4`0341<C00TC00<04a<01a<00`dC

403G4`033A<0078C001N4`0341<C00XC00<04a<01a<010dC4a3E4`033A<C0080LA<005hC00<@4a<0

2Q<200TC00<=4a00eA<010dC4`1b4`00GA<00a0C4`0;4`0301<C00TC00<=4a00e1<010dC4`1b4`00

GA<00a0C4`044`D00Q<00`0C4`0:4`033A0C0=<C00@=4a<0LQ<005`C00<@4a<01a<00`0C4`024`03

01<C00XC00<=4a00da<010dC4`1b4`00Fa<00a0C4`084`0301<C008C0P0<4`033A<@0=4C00@=4a<C

0P1a4`00Fa<00a0C4`084`0301<C008C00<04a<031<00`d@4`3@4`053A<C4`00LQ<005XC00<@4a<0

2A<00`0C4`024`0301<C00`C00<=4a00d1<01@dC4a<0078C001J4`0341<C00PC0P044`0301<C00dC

00<=4a00ca<01@dC4a<0078C001I4`0341<C00lC0P0?4`033A0C0<hC00@=4a<C0P1a4`00F1<00a0C

4`0@4`0301<C00hC00<=4a00ca<010dC4`1b4`00F1<00a0C4`0@4`0301<C00lC00<=4a00cQ<010dC

4`1b4`00Ea<00a0C4`0A4`0301<C00lC00<=4a00`Q<00`0C4`024`0301<C008C00<04`d00Q<00`0C

4`1`4`00EQ<00a0C4`0B4`804A<00`dC40304`0301<000LC00@04`0=0Q<00`0C4`1`4`00EQ<00a0C

4`0B4`0301<C014C00<=4a00_a<00`0C00094`0400dC4`80LA<005DC00<@4a<04a<00`0C4`0A4`03

3A<@0;lC00<04`001a<200054`dC4`00LQ<005@C00<@4a<051<00`0C4`0B4`033A<@0;hC00<04`00

1a<01`0C4a<=4`00LQ<005<C00<@4a<05A<201@C00<=41<0_Q<00`0C4`064`<000@C3A<0LQ<005<C

00<@4a<05A<00`0C4`0C4`033A<@0</C00<=4`00LQ<0058C00<@4a<05Q<00`0C4`0D4`033A<@0<XC

00@=4`00LA<0054C00<@4a<05a<00`0C4`0E4`033A0C0<XC00<=01<0LA<0054C00<@4a<05a<201HC

00<=4a00bQ<00`d04`1a4`00D1<00a0C4`0H4`0301<C01HC00<=41<0bQ<00`dC4`1`4`00Ca<00a0C

4`084`D00Q<00`0C4`024`0301<C008C00<04a<05a<00`d@4`394`033@0C070C001?4`0341<C00XC

00<04a<01Q<00`0C00034`0301<C01PC00<=41<0b1<00`0=4`1`4`00CQ<00a0C4`0;4`0301<C00PC

00@04a<C0P0I4`033A<@0<PC00<03A<0L1<004dC00<@4a<031<00`0C4`064`8011<00`0C4`0I4`03

3A0C0<LC00<04`d0L1<004`C00<@4a<03A<00`0C4`064`0301<C00<C00<04a<06Q<00`d@4`364`03

01<=070C001<4`0341<C00`C0P084`<00a<00`0C4`0J4`033A<@0<HC0P000a<=4`1^4`00Ba<00a0C

4`0M4`8071<00`dC40354`0501<C4`d0KQ<004XC00<@4a<07Q<00`0C4`0K4`033A<@0<DC00D04a<C

3@1^4`00BQ<00a0C4`0N4`0301<C01`C00<=4a00a1<00`0C4`024`033A<C06/C00194`0341<C01lC

00<04a<07A<00`dC40334`800a<00`dC4`1[4`00B1<00a0C4`0P4`807Q<010dC4a324`0301<C00<C

00<=4a<0JQ<004LC00<@4a<08A<00`0C4`0N4`043A<C4<4C00<04a<011<00`dC4`1Y4`00Aa<00a0C

4`0Q4`0301<C01hC00@=4a<@^Q<5008C00<04a<01A<00`dC4`1X4`00AQ<00a0C4`0R4`0301<C01lC

00@=4a<@^a<00`0C4`024`0301<C00DC00<=4a<0J1<004DC00<@4a<08a<2024C00@=4a<@^Q<00`0C

4`024`801a<00`dC4`1W4`00A1<00a0C4`0T4`0301<C020C00D=4a<C402i4`0301<C008C00<04a<0

1a<00`dC4`1V4`00A1<00a0C4`0T4`0301<C024C00@=4a<@^A<00`0C4`024`0301<C00PC00<=4a<0

IA<004<C00<@4a<09A<00`0C4`0R4`043A<C4;LC0P044`0301<C00TC00<=4a<0I1<0048C00<@4a<0

9Q<00`0C4`0R4`053A<C4a00_1<200/C00<=4a<0Ha<0044C00<@4a<09a<202@C00D=4a<C402k4`03

01<C00/C00<=4a<0HQ<0040C00<@4a<0:1<00`0C4`0S4`033A<C008C00<@4a<0^1<00`0C4`0<4`03

3A<C064C00104`0341<C028C0`034`0301<C02@C00<=4a<00Q<00a0C4`2g4`0301<C00dC00<=4a<0

H1<003lC00<@4a<08a<00`0C4`034`0301<C02DC00D=4a<C402i4`0301<C00hC0PeP4`00?Q<00a0C

4`0U4`0301<C008C0P0V4`033A<C008C00<@4a<0]Q<2014C00<=4a<0GA<003dC00<@4a<09Q<00`0C

4`024`0301<C02HC00<=4a<00Q<00a0C4`2e4`0301<C014C00<=4a<0G1<003dC00<@4a<09A<00`0C

00034`0301<C02LC00<=4a<00Q<00a0C4`2d4`0301<C018C00<=4a<0Fa<003`C00<@4a<09a<00`0C

4`024`0301<C02LC00<=4a<00a<00a0C4`2c4`0301<C01<C00<=4a<0FQ<003/C00<@4a<0;A<202TC

00<=4a<00a<00a0C4`2b4`805A<00`dC4`1I4`00>Q<00a0C4`0^4`0301<C02TC00<=4a<00Q<00a0C

4`2b4`0301<C01DC00<=4a<0F1<003XC00<@4a<0;Q<00`0C4`0Y4`033A<C00<C00<@4a<0/A<00`0C

4`0F4`033A<C05LC000i4`0341<C02lC00<04a<0:Q<00`dC4`034`0341<C0;0C00<04a<05a<23ELC

000h4`0341<C030C0P0/4`033A<C00<C00<@4a<0[a<00`0C4`0I4`033A<C05@C000g4`0341<C034C

00<04a<0;1<00`dC4`024`0341<C0:lC0P0K4`8=E1<003LC00<@4a<0<A<00`0C4`0/4`033A<C00<C

00<@4a<0[Q<00`0C4`0L4`033A<C054C000f4`0341<C038C00<04a<0;A<00`dC4`034`0341<C0:dC

00<04a<07A<23E4C000e4`0341<C03<C0P0_4`033A<C00<C00<@4a<0Va<5008C00<04a<00Q<00`0C

4`024`0301<C01lC00<=4a<0CQ<003@C00<@4a<0=1<00`0C4`0^4`033A<C00@C00<@4a<0W1<00`0C

4`064`0301<000<C00<04a<081<23DhC000c4`0341<C03DC00<04a<0;a<00`dC4`044`0341<C09/C

00<04a<021<0100C4a<202<C00<=4a<0Ba<0038C00<@4a<0=Q<00`0C4`0`4`033A<C00<C00<@4a<0

Va<00`0C4`064`8011<00`0C4`0S4`8=Ba<0034C00<@4a<0=a<2034C00<=4a<011<00a0C4`2J4`03

01<C00HC00<04a<00a<00`0C4`0U4`8=BA<0030C00<@4a<0>1<00`0C4`0a4`033A<C00@C00<@4a<0

V1<200PC0`034`0301<C02LC0Pe74`00;a<00a0C4`0Y4`<00a<00`0C4`024`0301<C008C00<04a<0

<A<00`dC4`054`0341<C0:LC0P0Z4`033A<C04@C000^4`0341<C02XC00<04a<01a<00`0C00034`03

01<C038C00<=4a<01A<00a0C4`2V4`0301<C02XC0Pe44`00;A<00a0C4`0/4`0301<C00PC00@04a<C

0P0d4`033A<C00DC00<@4a<0YA<00`0C4`0/4`033A<C044C000/4`0341<C02dC00<04a<01Q<200@C

00<04a<0<a<00`dC4`064`0341<C0:@C00<04a<0;A<23D4C000[4`0341<C02dC00<04`001a<00`0C

4`034`0301<C03@C00<=4a<01Q<00a0C4`2S4`0301<C02lC00<=4a<0?Q<002XC00<@4a<0;a<00`0C

4`064`<00a<00`0C4`0e4`033A<C00HC00<@4a<0XQ<2034C0Pdn4`00:A<00a0C4`0o4`80=Q<00`dC

4`074`0341<C0:4C00<04a<0<Q<23C`C000X4`0341<C040C00<04a<0=Q<00`dC4`074`0341<C0:0C

00<04a<0=1<23CXC000W4`0341<C044C00<04a<0=a<00`dC4`074`0341<C09lC00<04a<0=Q<23CPC

000V4`0341<C048C00<04a<0=a<00`dC4`084`0341<C09hC0P0i4`8==Q<002DC00<@4a<0@a<203TC

00<=4a<021<00a0C4`2M4`0301<C03XC0Pdd4`0091<00a0C4`144`0301<C03PC00<=4a<02A<00a0C

4`2L4`0301<C03`C0Pdb4`008a<00a0C4`154`0301<C03TC00<=4a<02A<00a0C4`2K4`0301<C03hC

0Pd`4`008a<00a0C4`154`0301<C03XC00<=4a<02A<00a0C4`2J4`0301<C040C0Pd^4`008Q<00a0C

4`164`80>a<00`dC4`0:4`0341<C09TC0P134`<=:a<0024C00<@4a<0Aa<00`0C4`0k4`033A<C00XC

00<@4a<0V1<00`0C4`154`8=:A<0020C00<@4a<0B1<00`0C4`0l4`033A<C00XC00<@4a<0TA<300<C

00<04a<0Aa<00`dC4`0V4`007a<00a0C4`194`0301<C03`C00<=4a<02a<00a0C4`2@4`0301<C00<C

00<04a<0B1<23BHC000N4`0341<C04XC0P0n4`033A<C00/C00<@4a<0T1<00`0C4`024`80Ba<00`dC

4`0S4`007A<00a0C4`1;4`0301<C03dC00<=4a<031<00a0C4`2?4`0301<C008C00<04a<0Ba<23B<C

000L4`0341<C04`C00<04a<0?Q<00`dC4`0<4`0341<C08dC00<04`000a<00`0C4`1=4`<=81<001/C

00<@4a<0Aa<200@C00<04a<0?a<00`dC4`0<4`0341<C08dC00<04a<00Q<00`0C4`1@4`<=7A<001XC

00<@4a<0BQ<01@0C4a<0044C00<=4a<03A<00a0C4`2A4`0301<C05<C0PdK4`006A<00a0C4`1:4`03

01<C008C0P114`033A<C00`C00<@4a<0TA<205HC0PdI4`00Ia<00`0C4`3W4`0301<C05LC0PdG4`00

IA<00`0C003Y4`0301<C070C001V4`0301<C0>PC00<04a<0L1<002`C0`3o4b<C0P1a4`00;1<00`0C

4`3o4b<C00<04a<0L1<002dC00<04a<01A<00`0C4`3o4hdC000]4`0401<C4`<000@C01<C0`3o4hXC

000/4`0301<0008C0P024`0301<C008C00<04a<0oa>84`00;A<00`0C4`034`0401<C008C00<04a<0

oa>94`00<a<0100C4`034`0301<C00HC00<04a<09A<302dC00<04a<0oa<W4`007A<300034`000080

31<300@C0`084`0301<C02@C00@04a<04A<300034`0000800Q<00`0C4`024`0301<C008C00<04a<0

1A<0100C4a<5008C00<04a<00Q<0100C4a<200HC0P3;4`0301<C038C00<04a<021<001`C00@04a<0

91<00`0C4`0S4`0401<C010C00@04a<01Q<00`0C00074`0301<000@C1@034`0301<C00HC00<04`00

11<00`0C4`024`0301<C0<<C00<04a<011<00`0C4`0C4`0301<C01hC00<04a<01a<001`C00D04a<0

4`0400034`0001P0:a<3010C00D04a<04`0400044`0C00TC00<04a<011<00`0C4`034`0301<C00PC

00D04a<C00054`0301<C0;4C00@04a<C10024`801Q<00`0C4`034`0301<C008C00<04a<00Q<00`0C

4`024`0301<C00DC00@04a<C1@024`0301<C008C00@04a<C0P064`8011<0100C4a<2004C0@010000

7A<304dC00<04a<03a<300HC00<04`001a<200LC00<04a<00a<00`0C4`064`801A<00`0C4`024`03

01<C0;0C00<04`001a<00`0C4`044`D00a<01`0C4a<04`001a<00`0C00044`D00a<00`0C4`064`03

01<000@C00<04a<00Q<00`0C4`044`0301<C008C00<04`000A<001lC00<04a<0BQ<201<C00<04a<0

11<00`0C00074`0301<C00`C00<04a<01Q<00`0C4`024`0301<000@C00<04`00/1<00`0C00024`@0

00<C01<01a<00`0C4`034`0701<C4`0C00094`0301<C00@C00<04a<00a<00`0C4`084`0501<C4`00

1A<00`0C4`044`0301<C00<C0@014`4C000N4`80H1<200LC00<04a<01Q<300/C0P084`<00a<00`0C

4`034`<0UQ<200034`0001DC00<04`001a<00`0C4`064`0301<C00<C00L04a<C01<000LC0P074`03

01<C00<C00<04a<01Q<200DC00<04a<00Q<00`0C4`044`0301<C00<C0@014`4C003o4e4C00<04`00

5Q<00`0C00074`0301<000dC00H04a<04`074`0301<C00`C00<04a<01Q<00`0C4`024`0301<000@C

00<04`000a<00`0C4`034`0301<0004C000Y4`801Q<20?lC7a<00`0C4`0F4`0301<C00HC0`0>4`04

01<C00PC0`0;4`8021<300<C00<04a<00a<3008C00<04a<00a<2004C0@010000:a<00`0C4`024`03

01<C0?lC7a<00`0C4`1`4`00:Q<00`0C4`034`0301<C00DC00<04a<0oa<F4`0301<0074C000[4`03

01<C008C00<04a<00Q<400<C0`3o4a4C0P000a<0001`4`00:A<00`0C00044`0301<0008C0P000a<0

4`044`0301<C0?lCQ1<002XC00<04a<00a<300@C00<04`000a<00`0C4`3o4hDC000g4`0301<000@C

00<04a<0oa>44`00=A<300@C0`3o4hHC003o4lDC003o4lDC003o4lDC003o4lDC003o4lDC0000\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.42213, -1.70613, 0.0219854, 0.0219854}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -84.5 0 ]

[.5 .96488 84.5 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -145.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.525) show

222.250000 19.500000 moveto

(C) show

227.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.26581 0 m

.30316 .05695 L

.34309 .11785 L

.3815 .17643 L

.42237 .23875 L

.46172 .29876 L

.49955 .35646 L

.53984 .4179 L

.57861 .47702 L

.61984 .53989 L

.65954 .60045 L

.69774 .65869 L

.73838 .72068 L

.77751 .78035 L

.81909 .84376 L

.85916 .90486 L

s

.85916 .90486 m

.89032 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.374789 0.238095 [

[.02381 .36229 -6 -9 ]

[.02381 .36229 6 0 ]

[.2619 .36229 -6 -9 ]

[.2619 .36229 6 0 ]

[.7381 .36229 -3 -9 ]

[.7381 .36229 3 0 ]

[.97619 .36229 -3 -9 ]

[.97619 .36229 3 0 ]

[1.025 .37479 0 -8 ]

[1.025 .37479 9 8 ]

[.4875 .01765 -24 -4.5 ]

[.4875 .01765 0 4.5 ]

[.4875 .13669 -12 -4.5 ]

[.4875 .13669 0 4.5 ]

[.4875 .25574 -24 -4.5 ]

[.4875 .25574 0 4.5 ]

[.4875 .49384 -18 -4.5 ]

[.4875 .49384 0 4.5 ]

[.4875 .61288 -6 -4.5 ]

[.4875 .61288 0 4.5 ]

[.4875 .73193 -18 -4.5 ]

[.4875 .73193 0 4.5 ]

[.4875 .85098 -6 -4.5 ]

[.4875 .85098 0 4.5 ]

[.5 .92595 -4.5 0 ]

[.5 .92595 4.5 16 ]

[.5 .91345 -137 0 ]

[.5 .91345 137 16 ]

[ 0 0 0 0 ]

[ 1 .90095 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .37479 m

.02381 .38104 L

s

[(-2)] .02381 .36229 0 1 Mshowa

.2619 .37479 m

.2619 .38104 L

s

[(-1)] .2619 .36229 0 1 Mshowa

.7381 .37479 m

.7381 .38104 L

s

[(1)] .7381 .36229 0 1 Mshowa

.97619 .37479 m

.97619 .38104 L

s

[(2)] .97619 .36229 0 1 Mshowa

.125 Mabswid

.07143 .37479 m

.07143 .37854 L

s

.11905 .37479 m

.11905 .37854 L

s

.16667 .37479 m

.16667 .37854 L

s

.21429 .37479 m

.21429 .37854 L

s

.30952 .37479 m

.30952 .37854 L

s

.35714 .37479 m

.35714 .37854 L

s

.40476 .37479 m

.40476 .37854 L

s

.45238 .37479 m

.45238 .37854 L

s

.54762 .37479 m

.54762 .37854 L

s

.59524 .37479 m

.59524 .37854 L

s

.64286 .37479 m

.64286 .37854 L

s

.69048 .37479 m

.69048 .37854 L

s

.78571 .37479 m

.78571 .37854 L

s

.83333 .37479 m

.83333 .37854 L

s

.88095 .37479 m

.88095 .37854 L

s

.92857 .37479 m

.92857 .37854 L

s

.25 Mabswid

0 .37479 m

1 .37479 L

s

gsave

1.025 .37479 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .01765 m

.50625 .01765 L

s

[(-1.5)] .4875 .01765 1 0 Mshowa

.5 .13669 m

.50625 .13669 L

s

[(-1)] .4875 .13669 1 0 Mshowa

.5 .25574 m

.50625 .25574 L

s

[(-0.5)] .4875 .25574 1 0 Mshowa

.5 .49384 m

.50625 .49384 L

s

[(0.5)] .4875 .49384 1 0 Mshowa

.5 .61288 m

.50625 .61288 L

s

[(1)] .4875 .61288 1 0 Mshowa

.5 .73193 m

.50625 .73193 L

s

[(1.5)] .4875 .73193 1 0 Mshowa

.5 .85098 m

.50625 .85098 L

s

[(2)] .4875 .85098 1 0 Mshowa

.125 Mabswid

.5 .04146 m

.50375 .04146 L

s

.5 .06526 m

.50375 .06526 L

s

.5 .08907 m

.50375 .08907 L

s

.5 .11288 m

.50375 .11288 L

s

.5 .1605 m

.50375 .1605 L

s

.5 .18431 m

.50375 .18431 L

s

.5 .20812 m

.50375 .20812 L

s

.5 .23193 m

.50375 .23193 L

s

.5 .27955 m

.50375 .27955 L

s

.5 .30336 m

.50375 .30336 L

s

.5 .32717 m

.50375 .32717 L

s

.5 .35098 m

.50375 .35098 L

s

.5 .3986 m

.50375 .3986 L

s

.5 .42241 m

.50375 .42241 L

s

.5 .44622 m

.50375 .44622 L

s

.5 .47003 m

.50375 .47003 L

s

.5 .51765 m

.50375 .51765 L

s

.5 .54146 m

.50375 .54146 L

s

.5 .56526 m

.50375 .56526 L

s

.5 .58907 m

.50375 .58907 L

s

.5 .63669 m

.50375 .63669 L

s

.5 .6605 m

.50375 .6605 L

s

.5 .68431 m

.50375 .68431 L

s

.5 .70812 m

.50375 .70812 L

s

.5 .75574 m

.50375 .75574 L

s

.5 .77955 m

.50375 .77955 L

s

.5 .80336 m

.50375 .80336 L

s

.5 .82717 m

.50375 .82717 L

s

.5 .87479 m

.50375 .87479 L

s

.5 .8986 m

.50375 .8986 L

s

.25 Mabswid

.5 0 m

.5 .90095 L

s

gsave

.5 .92595 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .91345 -198 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.525) show

298.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

303.000000 15.000000 moveto

(L) show

310.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

317.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

324.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

329.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

333.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .90095 L

0 .90095 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .21583 m

.02576 .21582 L

.03157 .21579 L

.04115 .21575 L

.05433 .21568 L

.07089 .21559 L

.09054 .21548 L

.11295 .21534 L

.13773 .21518 L

.16446 .21498 L

.19268 .21474 L

.22191 .21447 L

.25165 .21414 L

.28139 .21376 L

.31062 .21332 L

.33884 .21282 L

.36557 .21225 L

.39035 .21162 L

.41276 .21093 L

.43241 .21021 L

.44896 .20951 L

.46215 .20886 L

.47173 .20833 L

.47754 .20799 L

.47949 .20787 L

s

.47949 .20787 m

.48161 .20773 L

.48795 .20731 L

.49839 .20655 L

.51276 .20535 L

.53081 .20352 L

.55223 .20072 L

.57665 .19642 L

.60366 .18982 L

.6328 .18014 L

.66356 .16733 L

.69542 .15227 L

.72784 .13615 L

.76026 .11993 L

.79212 .10422 L

.82288 .08941 L

.85202 .07574 L

.87903 .0634 L

.90345 .0525 L

.92487 .04314 L

.94292 .0354 L

.95729 .02933 L

.96773 .02496 L

.97407 .02233 L

.97619 .02145 L

s

.47949 .45819 m

.48161 .43115 L

.48795 .40436 L

.49839 .37807 L

.51276 .35252 L

.53081 .32802 L

.55223 .30503 L

.57665 .28421 L

.60366 .26646 L

.6328 .25268 L

.66356 .24303 L

.69542 .23672 L

.72784 .23265 L

.76026 .22995 L

.79212 .2281 L

.82288 .22679 L

.85202 .22584 L

.87903 .22513 L

.90345 .22459 L

.92487 .22419 L

.94292 .22389 L

.95729 .22367 L

.96773 .22353 L

.97407 .22344 L

.97619 .22342 L

s

.47949 .45831 m

.48161 .48548 L

.48795 .51269 L

.49839 .53974 L

.51276 .5665 L

.53081 .59283 L

.55223 .61862 L

.57665 .64374 L

.60366 .66808 L

.6328 .69154 L

.66356 .714 L

.69542 .73538 L

.72784 .75557 L

.76026 .77448 L

.79212 .79204 L

.82288 .80817 L

.85202 .82279 L

.87903 .83584 L

.90345 .84727 L

.92487 .85703 L

.94292 .86507 L

.95729 .87136 L

.96773 .87588 L

.97407 .87859 L

.97619 .8795 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCaA<00?lCDQ<00`0C4`1`4`00I1<50=LC1@024`0301<C008C00<04a<00Q<00`0C4`1`4`00

IQ<00`0C4`3I4`0301<C00HC00<04`000a<00`0C4`1`4`00@a<00`dC4`0J4`<00a<00`0C4`024`80

ca<300<C00<04a<021<0100C4a<2074C00144`033A<C01lC00<04a<00Q<00`0C4`3D4`0301<C00HC

0P044`0301<C05LC0PdG4`00A1<00`dC4`0O4`0301<C008C00<04a<0e1<00`0C4`064`0301<C00<C

00<04a<0E1<33ATC00154`033A<C01dC0P044`0301<C0=<C0P084`<00a<00`0C4`1B4`8=71<004DC

00<=4a<08a<20>@C00<04a<0D1<23AhC00164`033A<C028C00<04a<0ha<204lC0PdP4`00Aa<00`dC

4`0Q4`0301<C0><C00<04a<0C1<23B8C00174`033A<C024C00<04a<0ha<00`0C4`1:4`8=91<004PC

00<=4a<081<20>@C00<04a<0B1<23BHC00184`033A<C020C00<04a<0ha<204HC0`dX4`00BA<00`dC

4`0O4`0301<C0><C00<04a<0@Q<33B/C001:4`033A<C01hC00<04a<0ha<00`0C4`104`8=;Q<004XC

00<=4a<07Q<20>@C00<04a<0?Q<23C0C001;4`033A<C01dC00<04a<0ha<00`0C4`0l4`8=<Q<004`C

00<=4a<071<00`0C4`3S4`80?1<00`dC4`0b4`00C1<00`dC4`0L4`0301<C0><C00<04a<0>A<23CDC

001=4`033A<C01/C0P3T4`0301<C03LC0Pdg4`00CQ<00`dC4`0J4`0301<C0><C00<04a<0=A<23CTC

001?4`033A<C00XC00<04a<00Q<00`0C4`024`0301<C008C00<04a<0ha<203@C0Pdk4`00Ca<00`dC

4`094`0301<000LC00<04`000a<00`0C4`3S4`0301<C034C0Pdm4`00D1<00`dC4`034`<00Q<00`0C

00094`0401<C4`80i1<00`0C4`0_4`8=?a<0054C00<=4a<01a<00`0C00074`8011<00`0C4`3L4`D0

0Q<00`0C4`0]4`8=@A<0054C00<=4a<01a<00`0C00074`0301<C00<C00<04a<0gQ<00`0C4`024`03

01<C02/C0Pe34`00DQ<00`dC4`074`0301<C00HC0`034`0301<C0=PC0`034`0301<C008C0P0Y4`<=

AA<005<C00<=4a<05A<00`0C4`3N4`0301<C008C00<04a<09Q<23DPC001C4`033A<C01DC0P3O4`03

01<C008C00<04a<091<23DXC001D4`033A<C01@C00<04a<0gA<200@C00<04a<08Q<23D`C001E4`03

3A<C01<C00<04a<0ha<2024C0Pe>4`00EQ<00`dC4`0B4`0301<C0><C00<04a<07Q<23E0C001F4`03

3A<C018C0P3T4`0301<C01/C0`eB4`00Ea<00`dC4`0A4`0301<C0><C00<04a<061<33EDC000J4`<0

9A<5014C00<=4a<041<00`0C4`0T4`D091<309<C00<04a<05A<33EPC000J4`0301<C02LC00<04a<0

4A<00`dC4`0@4`0301<C02HC00<04a<091<00`0C4`2C4`8051<23E/C000E4`<00a<00`0C4`0P4`<0

0a<00`0C4`0B4`033A<C00lC0P0W4`0301<C02DC00<04a<0TQ<00`0C4`0?4`@=GA<001/C00<04a<0

9Q<00`0C4`0C4`033A<C00hC00<04a<09Q<00`0C4`0U4`0301<C098C00<04a<02Q<53F4C000J4`03

01<002LC00<04a<04a<00`dC4`0>4`0301<C02HC00<04a<091<00`0C002C4`0301<C00HC10eV4`00

6a<00`0C4`0U4`805Q<00`dC4`0=4`0301<C02DC0P0W4`0301<C08hC3@eZ4`00Fa<00`dC4`0=4`80

_Q<R3@@C00<04a<0L1<005`C00<=4a<031<00`0C4`284cD=9Q<00`0C4`1`4`00GA<00`dC4`0;4`03

01<C05/C0P264`0301<C054C20dG4`00GA<00`dC4`0;4`0301<C05XC00<04a<0QQ<00`0C4`0c4ah=

7a<001DCB@000`d0001Q00HC00<04a<0QQ<202LC3@dm4`006A<00`0C4`064`0301<C00DC00<04a<0

1A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00D04a<C3@034`0301<C00DC

00<@4a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C

4`064`0301<C00DC00<04a<01A<00`0C4`084`0301<C08HC00<04a<081<63DXC001O4`033A<C00TC

00<@4a<0FQ<00`0C00264`0301<C01/C1@e@4`00H1<00`dC4`084`8@Fa<307LC00<04a<00Q<00`0C

4`024`0301<C008C00<04a<061<33EDC001Q4`033A<C00LC0Q3D4`0301<000LC00<04`000a<00`0C

4`0F4`8=F1<0064C00<=4a<01Q<00a00403?4`<00Q<00`0C00094`0401<C4`805A<23EXC001R4`03

3A<C00DC00<@0100e1<00`0C00074`8011<00`0C4`0B4`8=G1<006<C00<=4a<011<00a00403D4`03

01<000LC00<04a<00a<00`0C4`0A4`033A<C05`C001T4`033A<C008C00D@4`00403D4`0301<C00HC

0`034`0301<C00lC0PeO4`00I1<00`dC4`024`0541<04a00ha<200hC0PeQ4`00IA<02@dC4a<@4`0C

403S4`0301<C00`C00<=4a<0HA<006HC00H=4a<@4`024`0341<C0>0C00<04a<02a<00`dC4`1R4`00

IQ<01@dC4a0C008000<C41<0hA<00`0C4`094`8=IA<006LC00D=4a0C00024`0341<C0>0C00<04a<0

21<00`dC4`1U4`00Ia<01@d@4a<000<C00<@4a<0ga<200PC00<=4a<0IQ<006PC00@=4a<00a<00a0C

4`3O4`0301<C00HC00<=4a<0Ia<006PC00<@3A<00P024`0341<C0=lC00<04a<01A<00`dC4`1X4`00

Ia<01A0C3A<000@C00<@4a<0Q1<302XC1@0X4`0301<C00@C00<=4a<08A<502XC0`0F4`00G1<00`0C

4`024`0301<C008C00H041<C3@044`0341<C08@C00<04a<0;1<00`0C4`0X4`8011<00`dC4`0T4`03

01<C02XC00<04a<05Q<005/C00<04`001a<00`0@00024`033@0C00<C00<@4a<0Oa<300<C00<04a<0

9A<300<C00<04a<0:1<00`0C4`024`033A<C02DC00<04a<0:a<00`0C4`0E4`00Fa<00`0C00084`03

400C008C00<=01<00a<00a0C4`244`0301<C02/C00<04a<0:1<00`0C4`024`033A<C02DC00<04a<0

:a<00`0C4`0E4`00Fa<00`0C00074`03010C00<C00<03A<00a<00a0C4`234`0301<002`C00<04a<0

:1<01@0C4a<=02PC00<04a<0:Q<00`0C000F4`00Fa<00`0C00074`0341<C00<C00<03A<011<00a0C

4`234`0301<C02XC0P0Z4`0501<C4`d09a<202dC00<04a<05A<005`C00<04a<01Q<00a0000034`03

01<=00@C00<@4a<0g1<200034`dC06hC001T4`0341<C00@C0P000a<=4`024`0341<C0=`C00<04`d0

L1<006@C00<@4a<011<0100C4`d44`0341<C0=/C00<04`d0IA<200TC001S4`0341<C00DC00D04a<C

3@034`0341<C0=/C00<03A<0I1<00`0C4`094`00Ha<00a0C4`054`0501<C4`d011<00a0C4`1k4f00

00<=0000G@064`0301<C00TC001R4`0341<C00HC00<04a<00Q<01@dC4a<@084C00<04a<01Q<00`0C

4`064`0301<C00HC00<04a<01Q<00`0C4`074`0301<C00HC00<04a<01Q<00`0C4`064`0301<C00HC

00<04a<01Q<00`dC4`064`0301<C00HC00<04a<01Q<00`0C4`074`0301<C00HC00<04a<01Q<00`0C

4`064`0301<C00HC00<04a<01Q<00`0C4`064`0301<C00TC00<04a<02A<0068C00<@4a<01Q<200@C

00D=4a<C40204`0301<C02/C00<04a<0:Q<00`dC4`0[4`0301<C02XC00<04a<02A<00`0C00094`00

HA<00a0C4`074`0301<C00<C00D=4a<C403J4`033@0C06DC0`094`00HA<00a0C4`074`0301<C00@C

00@=4a<@fQ<00`d04`1a4`00H1<00a0C4`084`0301<C00DC00@=4a<@f1<010dC001a4`00H1<00a0C

4`084`801Q<010dC4a3H4`033A<0078C001O4`0341<C00TC00<04a<01Q<010dC4a3G4`033A<0078C

001O4`0341<C00TC00<04a<01a<00`dC403G4`033A<0078C001N4`0341<C00XC00<04a<01a<010dC

4a3E4`033A<C0080LA<005hC00<@4a<02Q<200TC00<=4a00eA<010dC4`1b4`00GA<00a0C4`0;4`03

01<C00TC00<=4a00e1<010dC4`1b4`00GA<00a0C4`044`D00Q<00`0C4`0:4`033A0C0=<C00@=4a<0

LQ<005`C00<@4a<01a<00`0C4`024`0301<C00XC00<=4a00da<010dC4`1b4`00Fa<00a0C4`084`03

01<C008C0P0<4`033A<@0=4C00@=4a<C0P1a4`00Fa<00a0C4`084`0301<C008C00<04a<031<00`d@

4`3@4`053A<C4`00LQ<005XC00<@4a<02A<00`0C4`024`0301<C00`C00<=4a00d1<01@dC4a<0078C

001J4`0341<C00PC0P044`0301<C00dC00<=4a00ca<01@dC4a<0078C001I4`0341<C00lC0P0?4`03

3A0C0<hC00D=4a<C001b4`00F1<00a0C4`0@4`0301<C00hC00<=4a00ca<00`dC4`02074C001H4`03

41<C010C00<04a<03a<00`dC403>4`043A<C078C001G4`0341<C014C00<04a<03a<00`dC40324`03

01<C008C00<04a<00Q<00`0C3@024`0301<C070C001F4`0341<C018C0P0A4`033A<@0<0C00<04`00

1a<0100C00d24`0301<C070C001F4`0341<C018C00<04a<04A<00`dC402o4`0301<000TC00@03A<C

0P1a4`00EA<00a0C4`0C4`0301<C014C00<=4a00_a<00`0C00074`8000DC3A<C001b4`00E1<00a0C

4`0D4`0301<C018C00<=4a00_Q<00`0C00074`0701<C4`dC001b4`00Da<00a0C4`0E4`8051<00`d@

4`2n4`0301<C00HC0`0011<=4`1b4`00Da<00a0C4`0E4`0301<C01<C00<=4a00ba<00`dC001b4`00

DQ<00a0C4`0F4`0301<C01@C00<=4a00bQ<010dC001a4`00DA<00a0C4`0G4`0301<C01DC00<=41<0

bQ<00`d04`1a4`00DA<00a0C4`0G4`805Q<00`dC403:4`033@0C074C001@4`0341<C01PC00<04a<0

5Q<00`d@4`3:4`033A<C070C001?4`0341<C00PC1@024`0301<C008C00<04a<00Q<00`0C4`0G4`03

3A0C0<TC00<=01<0L1<004lC00<@4a<02Q<00`0C4`064`0301<000<C00<04a<061<00`d@4`384`03

00dC070C001>4`0341<C00/C00<04a<021<0100C4a<201TC00<=4a00b1<00`0=4`1`4`00CA<00a0C

4`0<4`0301<C00HC0P044`0301<C01TC00<=41<0aa<00`0C3@1`4`00C1<00a0C4`0=4`0301<C00HC

00<04a<00a<00`0C4`0J4`033A0C0<HC00<04`d0L1<004`C00<@4a<031<200PC0`034`0301<C01XC

00<=4a00aQ<200034`dC06hC001;4`0341<C01dC0P0L4`033A<@0<DC00D04a<C3@1^4`00BQ<00a0C

4`0N4`0301<C01/C00<=4a00aA<01@0C4a<=06hC001:4`0341<C01hC00<04a<071<00`dC40344`03

01<C008C00<=4a<0Ja<004TC00<@4a<07a<00`0C4`0M4`033A<@0<<C0P034`033A<C06/C00184`03

41<C020C0P0N4`043A<C4<8C00<04a<00a<00`dC4`1Z4`00Aa<00a0C4`0Q4`0301<C01hC00@=4a<@

`A<00`0C4`044`033A<C06TC00174`0341<C024C00<04a<07Q<010dC4a2j4`D00Q<00`0C4`054`03

3A<C06PC00164`0341<C028C00<04a<07a<010dC4a2k4`0301<C008C00<04a<01A<00`dC4`1X4`00

AA<00a0C4`0S4`808A<010dC4a2j4`0301<C008C0P074`033A<C06LC00144`0341<C02@C00<04a<0

81<01@dC4a<@0;TC00<04a<00Q<00`0C4`074`033A<C06HC00144`0341<C02@C00<04a<08A<010dC

4a2i4`0301<C008C00<04a<021<00`dC4`1U4`00@a<00a0C4`0U4`0301<C028C00@=4a<@]a<200@C

00<04a<02A<00`dC4`1T4`00@Q<00a0C4`0V4`0301<C028C00D=4a<C402l4`802a<00`dC4`1S4`00

@A<00a0C4`0W4`8091<01@dC4a<@0;/C00<04a<02a<00`dC4`1R4`00@1<00a0C4`0X4`0301<C02<C

00<=4a<00Q<00a0C4`2h4`0301<C00`C00<=4a<0HA<0040C00<@4a<08Q<300<C00<04a<091<00`dC

4`024`0341<C0;LC00<04a<03A<00`dC4`1P4`00?a<00a0C4`0S4`0301<C00<C00<04a<09A<01@dC

4a<@0;TC00<04a<03Q<23F0C000n4`0341<C02DC00<04a<00Q<202HC00<=4a<00Q<00a0C4`2f4`80

4A<00`dC4`1M4`00?A<00a0C4`0V4`0301<C008C00<04a<09Q<00`dC4`024`0341<C0;DC00<04a<0

4A<00`dC4`1L4`00?A<00a0C4`0U4`0301<000<C00<04a<09a<00`dC4`024`0341<C0;@C00<04a<0

4Q<00`dC4`1K4`00?1<00a0C4`0W4`0301<C008C00<04a<09a<00`dC4`034`0341<C0;<C00<04a<0

4a<00`dC4`1J4`00>a<00a0C4`0]4`80:A<00`dC4`034`0341<C0;8C0P0E4`033A<C05TC000j4`03

41<C02hC00<04a<0:A<00`dC4`024`0341<C0;8C00<04a<05A<00`dC4`1H4`00>Q<00a0C4`0^4`03

01<C02TC00<=4a<00a<00a0C4`2a4`0301<C01HC00<=4a<0Ea<003TC00<@4a<0;a<00`0C4`0Z4`03

3A<C00<C00<@4a<0/1<00`0C4`0G4`8=Ea<003PC00<@4a<0<1<202`C00<=4a<00a<00a0C4`2_4`03

01<C01TC00<=4a<0E1<003LC00<@4a<0<A<00`0C4`0/4`033A<C008C00<@4a<0[a<201/C0PeD4`00

=a<00a0C4`0a4`0301<C02`C00<=4a<00a<00a0C4`2^4`0301<C01`C00<=4a<0DA<003HC00<@4a<0

<Q<00`0C4`0]4`033A<C00<C00<@4a<0[A<00`0C4`0M4`8=DA<003DC00<@4a<0<a<202lC00<=4a<0

0a<00a0C4`2K4`D00Q<00`0C4`024`0301<C008C00<04a<07a<00`dC4`1>4`00=1<00a0C4`0d4`03

01<C02hC00<=4a<011<00a0C4`2L4`0301<C00HC00<04`000a<00`0C4`0P4`8=CQ<003<C00<@4a<0

=A<00`0C4`0_4`033A<C00@C00<@4a<0Va<00`0C4`084`0401<C4`808a<00`dC4`1;4`00<Q<00a0C

4`0f4`0301<C030C00<=4a<00a<00a0C4`2K4`0301<C00HC0P044`0301<C02<C0Pe;4`00<A<00a0C

4`0g4`80<A<00`dC4`044`0341<C09XC00<04a<01Q<00`0C4`034`0301<C02DC0Pe94`00<1<00a0C

4`0h4`0301<C034C00<=4a<011<00a0C4`2H4`8021<300<C00<04a<09a<23DLC000_4`0341<C02TC

0`034`0301<C008C00<04a<00Q<00`0C4`0a4`033A<C00DC00<@4a<0Ya<202XC00<=4a<0A1<002hC

00<@4a<0:Q<00`0C4`074`0301<000<C00<04a<0<Q<00`dC4`054`0341<C0:HC00<04a<0:Q<23D@C

000]4`0341<C02`C00<04a<021<0100C4a<203@C00<=4a<01A<00a0C4`2U4`0301<C02`C00<=4a<0

@A<002`C00<@4a<0;A<00`0C4`064`8011<00`0C4`0c4`033A<C00HC00<@4a<0Y1<00`0C4`0]4`8=

@A<002/C00<@4a<0;A<00`0C00074`0301<C00<C00<04a<0=1<00`dC4`064`0341<C0:<C00<04a<0

;a<00`dC4`0n4`00:Q<00a0C4`0_4`0301<C00HC0`034`0301<C03DC00<=4a<01Q<00a0C4`2R4`80

<A<23ChC000Y4`0341<C03lC0P0f4`033A<C00LC00<@4a<0XA<00`0C4`0b4`8=?1<002PC00<@4a<0

@1<00`0C4`0f4`033A<C00LC00<@4a<0X1<00`0C4`0d4`8=>Q<002LC00<@4a<0@A<00`0C4`0g4`03

3A<C00LC00<@4a<0Wa<00`0C4`0f4`8=>1<002HC00<@4a<0@Q<00`0C4`0g4`033A<C00PC00<@4a<0

WQ<203TC0Pdf4`009A<00a0C4`134`80>A<00`dC4`084`0341<C09dC00<04a<0>Q<23C@C000T4`03

41<C04@C00<04a<0>A<00`dC4`084`0341<C09`C00<04a<0?1<23C8C000S4`0341<C04DC00<04a<0

>Q<00`dC4`084`0341<C09/C00<04a<0?Q<23C0C000S4`0341<C04DC00<04a<0>Q<00`dC4`094`03

41<C09XC00<04a<0@1<23BhC000R4`0341<C04HC0P0l4`033A<C00TC00<@4a<0VA<204<C0`d[4`00

8A<00a0C4`174`0301<C03`C00<=4a<02A<00a0C4`2H4`0301<C04DC0PdY4`0081<00a0C4`184`03

01<C03`C00<=4a<02Q<00a0C4`2A4`<00a<00`0C4`174`033A<C02HC000O4`0341<C04TC00<04a<0

?A<00`dC4`0:4`0341<C090C00<04a<00a<00`0C4`184`8=9Q<001hC00<@4a<0BQ<203hC00<=4a<0

2a<00a0C4`2@4`0301<C008C0P1;4`033A<C02<C000M4`0341<C04/C00<04a<0?Q<00`dC4`0;4`03

41<C08lC00<04a<00Q<00`0C4`1;4`8=8a<001`C00<@4a<0C1<00`0C4`0n4`033A<C00`C00<@4a<0

SA<00`0C00034`0301<C04dC0`dP4`006a<00a0C4`174`8011<00`0C4`0o4`033A<C00`C00<@4a<0

SA<00`0C4`024`0301<C050C10dL4`006Q<00a0C4`1:4`0501<C4`00@A<00`dC4`0=4`0341<C094C

00<04a<0E1<23AXC000I4`0341<C04XC00<04a<00Q<2044C00<=4a<031<00a0C4`2A4`80Ea<23APC

001W4`0301<C0>LC00<04a<0F1<00`dC4`0E4`00IA<00`0C003Y4`0301<C070C001V4`0301<C0>PC

00<04a<0L1<002XC0`3o4bDC0P1a4`00:Q<00`0C4`3o4bDC00<04a<0L1<002/C00<04a<011<00`0C

4`3o4i0C000[4`0401<C4`@00a<30?lCS1<002XC00<04`000Q<200034`0C00@C00<04a<0oa>:4`00

:a<00`0C4`034`0301<000<C00<04a<0oa>;4`00<A<00`0C00044`0301<C00HC00<04a<09a<302/C

00<04a<0oa<Y4`006a<300034`00008031<300@C0`084`0301<C02HC00@04a<03a<300034`000080

0Q<00`0C4`024`0301<C008C00<04a<01A<0100C4a<5008C00<04a<00Q<0100C4a<300<C00<04a<0

11<20<DC00<04a<0=a<00`0C4`064`006Q<0100C4`0T4`0301<C02DC00@04a<03Q<0100C4`064`03

01<000LC00<04`0011<500<C00<04a<01Q<00`0C00024`0301<C008C00<04`0011<00`0C4`2m4`03

01<C00@C00<04a<04a<00`0C4`0S4`0301<C00DC000J4`0501<C01<010000a<0000H02dC0`0>4`05

01<C01<0100011<04`094`0301<C00@C00<04a<00a<00`0C4`084`0501<C4`001A<00`0C4`024`03

01<C0:/C00@04a<C10024`801Q<00`0C4`034`0301<C008C00<04a<00Q<00`0C4`024`0301<C00DC

00@04a<C1@024`0301<C008C00@04a<C0`034`0301<C00@C0P044`0401<C4`800A<001/C0`1?4`03

01<C00dC0`064`0301<000LC0P074`0301<C00<C00<04a<01Q<200@C00@04a<C0P054`0301<C0:XC

00<04`001a<00`0C4`044`D00a<01`0C4a<04`001a<00`0C00044`D00a<00`0C4`064`0301<0008C

00<04a<00Q<00`0C00044`0301<C00@C00<04a<00Q<1004C000M4`0301<C04`C0P0A4`0301<C00@C

00<04`001a<00`0C4`0<4`0301<C00HC00<04a<00Q<00`0C00024`0301<C00@C00<04`00ZQ<00`0C

00024`@000<C01<01a<00`0C4`034`0701<C4`0C00094`0301<C00@C00<04a<00a<00`0C4`084`05

01<C4`001A<00`0C4`024`0301<C00@C00<04a<00a<1000071<2060C0P074`0301<C00HC0`0;4`80

21<300<C00@04a<C0`044`<0Ta<200034`00018C00<04`001a<00`0C4`064`0301<C00<C00L04a<C

01<000LC0P074`0301<C00<C00<04a<01Q<200@C00@04a<C0P054`0301<C00@C00<04a<00a<10000

oa=A4`0301<001<C00<04`001a<00`0C000=4`0601<C01<01a<00`0C4`0<4`0301<C00HC00<04a<0

0Q<00`0C00024`0301<C00@C00<04`000a<00`0C4`034`400A<002HC0P064`80oa<R4`0301<C01<C

00<04a<01Q<300hC00@04a<021<300/C0P084`<00a<0100C4a<300@C0`024`0301<C00<C0P014`00

:1<00`0C4`024`0301<C0?lC8Q<00`0C4`1`4`009a<00`0C4`034`0301<C00HC00<04a<0oa<H4`03

01<0074C000X4`0301<C008C00<04a<00Q<300044`0C4`<0oa<D4`8000<C0000L1<002HC00<04`00

11<00`0C00024`800Q<00`0C4`024`0301<C0?lCQa<002LC00<04a<00a<300@C00@04a<00Q<00`0C

4`3o4hPC000d4`0401<C00<C00<04a<0oa>74`00<Q<300@C0`3o4hTC003o4lDC003o4lDC003o4lDC

003o4lDC003o4lDC0000\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.41764, -1.70599, 0.0219721, 0.0219721}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -82 0 ]

[.5 .96488 82 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -143 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.52) show

217.250000 19.500000 moveto

(C) show

222.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.26504 0 m

.30316 .05794 L

.34309 .11863 L

.3815 .17702 L

.42237 .23914 L

.46172 .29895 L

.49955 .35646 L

.53984 .4177 L

.57861 .47663 L

.61984 .53929 L

.65954 .59965 L

.69774 .6577 L

.73838 .71948 L

.77751 .77896 L

.81909 .84217 L

.85916 .90307 L

s

.85916 .90307 m

.8916 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.373587 0.238095 [

[.02381 .36109 -6 -9 ]

[.02381 .36109 6 0 ]

[.2619 .36109 -6 -9 ]

[.2619 .36109 6 0 ]

[.7381 .36109 -3 -9 ]

[.7381 .36109 3 0 ]

[.97619 .36109 -3 -9 ]

[.97619 .36109 3 0 ]

[1.025 .37359 0 -8 ]

[1.025 .37359 9 8 ]

[.4875 .01644 -24 -4.5 ]

[.4875 .01644 0 4.5 ]

[.4875 .13549 -12 -4.5 ]

[.4875 .13549 0 4.5 ]

[.4875 .25454 -24 -4.5 ]

[.4875 .25454 0 4.5 ]

[.4875 .49263 -18 -4.5 ]

[.4875 .49263 0 4.5 ]

[.4875 .61168 -6 -4.5 ]

[.4875 .61168 0 4.5 ]

[.4875 .73073 -18 -4.5 ]

[.4875 .73073 0 4.5 ]

[.4875 .84978 -6 -4.5 ]

[.4875 .84978 0 4.5 ]

[.5 .9242 -4.5 0 ]

[.5 .9242 4.5 16 ]

[.5 .9117 -134.5 0 ]

[.5 .9117 134.5 16 ]

[ 0 0 0 0 ]

[ 1 .8992 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .37359 m

.02381 .37984 L

s

[(-2)] .02381 .36109 0 1 Mshowa

.2619 .37359 m

.2619 .37984 L

s

[(-1)] .2619 .36109 0 1 Mshowa

.7381 .37359 m

.7381 .37984 L

s

[(1)] .7381 .36109 0 1 Mshowa

.97619 .37359 m

.97619 .37984 L

s

[(2)] .97619 .36109 0 1 Mshowa

.125 Mabswid

.07143 .37359 m

.07143 .37734 L

s

.11905 .37359 m

.11905 .37734 L

s

.16667 .37359 m

.16667 .37734 L

s

.21429 .37359 m

.21429 .37734 L

s

.30952 .37359 m

.30952 .37734 L

s

.35714 .37359 m

.35714 .37734 L

s

.40476 .37359 m

.40476 .37734 L

s

.45238 .37359 m

.45238 .37734 L

s

.54762 .37359 m

.54762 .37734 L

s

.59524 .37359 m

.59524 .37734 L

s

.64286 .37359 m

.64286 .37734 L

s

.69048 .37359 m

.69048 .37734 L

s

.78571 .37359 m

.78571 .37734 L

s

.83333 .37359 m

.83333 .37734 L

s

.88095 .37359 m

.88095 .37734 L

s

.92857 .37359 m

.92857 .37734 L

s

.25 Mabswid

0 .37359 m

1 .37359 L

s

gsave

1.025 .37359 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .01644 m

.50625 .01644 L

s

[(-1.5)] .4875 .01644 1 0 Mshowa

.5 .13549 m

.50625 .13549 L

s

[(-1)] .4875 .13549 1 0 Mshowa

.5 .25454 m

.50625 .25454 L

s

[(-0.5)] .4875 .25454 1 0 Mshowa

.5 .49263 m

.50625 .49263 L

s

[(0.5)] .4875 .49263 1 0 Mshowa

.5 .61168 m

.50625 .61168 L

s

[(1)] .4875 .61168 1 0 Mshowa

.5 .73073 m

.50625 .73073 L

s

[(1.5)] .4875 .73073 1 0 Mshowa

.5 .84978 m

.50625 .84978 L

s

[(2)] .4875 .84978 1 0 Mshowa

.125 Mabswid

.5 .04025 m

.50375 .04025 L

s

.5 .06406 m

.50375 .06406 L

s

.5 .08787 m

.50375 .08787 L

s

.5 .11168 m

.50375 .11168 L

s

.5 .1593 m

.50375 .1593 L

s

.5 .18311 m

.50375 .18311 L

s

.5 .20692 m

.50375 .20692 L

s

.5 .23073 m

.50375 .23073 L

s

.5 .27835 m

.50375 .27835 L

s

.5 .30216 m

.50375 .30216 L

s

.5 .32597 m

.50375 .32597 L

s

.5 .34978 m

.50375 .34978 L

s

.5 .3974 m

.50375 .3974 L

s

.5 .42121 m

.50375 .42121 L

s

.5 .44502 m

.50375 .44502 L

s

.5 .46882 m

.50375 .46882 L

s

.5 .51644 m

.50375 .51644 L

s

.5 .54025 m

.50375 .54025 L

s

.5 .56406 m

.50375 .56406 L

s

.5 .58787 m

.50375 .58787 L

s

.5 .63549 m

.50375 .63549 L

s

.5 .6593 m

.50375 .6593 L

s

.5 .68311 m

.50375 .68311 L

s

.5 .70692 m

.50375 .70692 L

s

.5 .75454 m

.50375 .75454 L

s

.5 .77835 m

.50375 .77835 L

s

.5 .80216 m

.50375 .80216 L

s

.5 .82597 m

.50375 .82597 L

s

.5 .87359 m

.50375 .87359 L

s

.5 .8974 m

.50375 .8974 L

s

.25 Mabswid

.5 0 m

.5 .8992 L

s

gsave

.5 .9242 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .9117 -195.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.52) show

293.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

298.000000 15.000000 moveto

(L) show

305.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

312.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

319.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

324.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

328.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .8992 L

0 .8992 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .21422 m

.02576 .21421 L

.03157 .21418 L

.04115 .21414 L

.05433 .21408 L

.07089 .21399 L

.09054 .21388 L

.11294 .21375 L

.13772 .21359 L

.16445 .2134 L

.19267 .21318 L

.2219 .21291 L

.25164 .2126 L

.28138 .21223 L

.3106 .21181 L

.33882 .21133 L

.36555 .21079 L

.39033 .21018 L

.41274 .20952 L

.43239 .20884 L

.44894 .20817 L

.46212 .20755 L

.4717 .20705 L

.47752 .20672 L

.47947 .2066 L

s

.47947 .2066 m

.48159 .20647 L

.48793 .20607 L

.49837 .20535 L

.51274 .2042 L

.53079 .20245 L

.55221 .19977 L

.57663 .19564 L

.60365 .18925 L

.63278 .17979 L

.66355 .16712 L

.69541 .15213 L

.72783 .13605 L

.76025 .11984 L

.79211 .10414 L

.82287 .08933 L

.85201 .07567 L

.87902 .06333 L

.90345 .05244 L

.92487 .04309 L

.94292 .03535 L

.95729 .02928 L

.96773 .02492 L

.97407 .02229 L

.97619 .02141 L

s

.47947 .45702 m

.48159 .43 L

.48793 .40321 L

.49837 .37691 L

.51274 .35134 L

.53079 .32679 L

.55221 .30371 L

.57663 .28275 L

.60365 .26483 L

.63278 .25087 L

.66355 .2411 L

.69541 .23475 L

.72783 .23067 L

.76025 .22799 L

.79211 .22616 L

.82287 .22487 L

.85201 .22393 L

.87902 .22324 L

.90345 .22271 L

.92487 .22232 L

.94292 .22203 L

.95729 .22181 L

.96773 .22167 L

.97407 .22159 L

.97619 .22156 L

s

.47947 .45714 m

.48159 .48429 L

.48793 .51147 L

.49837 .5385 L

.51274 .56522 L

.53079 .59152 L

.55221 .61728 L

.57663 .64237 L

.60365 .66668 L

.63278 .6901 L

.66355 .71254 L

.69541 .73388 L

.72783 .75404 L

.76025 .77293 L

.79211 .79046 L

.82287 .80656 L

.85201 .82116 L

.87902 .8342 L

.90345 .84561 L

.92487 .85535 L

.94292 .86338 L

.95729 .86967 L

.96773 .87417 L

.97407 .87688 L

.97619 .87779 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCaA<00?lCDQ<00`0C4`1`4`00I1<50=LC1@024`0301<C008C00<04a<00Q<00`0C4`1`4`00

IQ<00`0C4`3I4`0301<C00HC00<04`000a<00`0C4`1`4`00@a<00`dC4`0J4`<00a<00`0C4`024`80

ca<300<C00<04a<021<0100C4a<2074C00144`033A<C01lC00<04a<00Q<00`0C4`3D4`0301<C00HC

0P044`0301<C05PC00<=4a<05A<004@C00<=4a<07a<00`0C4`024`0301<C0=@C00<04a<01Q<00`0C

4`034`0301<C05LC00<=4a<05Q<004DC00<=4a<07A<200@C00<04a<0da<200PC0`034`0301<C05@C

0`dI4`00AA<00`dC4`0S4`80i1<00`0C4`1A4`<=71<004HC00<=4a<08Q<00`0C4`3S4`80Ca<33AlC

00174`033A<C024C00<04a<0ha<00`0C4`1<4`8=8Q<004LC00<=4a<08A<00`0C4`3S4`0301<C04XC

0PdT4`00B1<00`dC4`0P4`80i1<00`0C4`184`8=9Q<004PC00<=4a<081<00`0C4`3S4`80AQ<33BPC

00194`033A<C01lC00<04a<0ha<00`0C4`124`<=:a<004XC00<=4a<07Q<00`0C4`3S4`0301<C040C

0Pd^4`00BQ<00`dC4`0N4`80i1<00`0C4`0n4`8=<1<004/C00<=4a<07A<00`0C4`3S4`0301<C03`C

0Pdb4`00C1<00`dC4`0L4`0301<C0><C0P0l4`033A<C038C001<4`033A<C01`C00<04a<0ha<00`0C

4`0i4`8==A<004dC00<=4a<06a<20>@C00<04a<0=a<23CLC001>4`033A<C01XC00<04a<0ha<00`0C

4`0e4`8=>A<004lC00<=4a<02Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`3S4`80=1<23C/C

001?4`033A<C00TC00<04`001a<00`0C00034`0301<C0><C00<04a<0<A<23CdC001@4`033A<C00<C

0`024`0301<000TC00@04a<C0P3T4`0301<C02lC0Pdo4`00DA<00`dC4`074`0301<000LC0P044`03

01<C0=`C1@024`0301<C02dC0Pe14`00DA<00`dC4`074`0301<000LC00<04a<00a<00`0C4`3N4`03

01<C008C00<04a<0:a<23D<C001B4`033A<C00LC00<04a<01Q<300<C00<04a<0f1<300<C00<04a<0

0Q<202TC0`e54`00Da<00`dC4`0E4`0301<C0=hC00<04a<00Q<00`0C4`0V4`8=B1<005<C00<=4a<0

5A<20=lC00<04a<00Q<00`0C4`0T4`8=BQ<005@C00<=4a<051<00`0C4`3M4`8011<00`0C4`0R4`8=

C1<005DC00<=4a<04a<00`0C4`3S4`808A<23DhC001F4`033A<C018C00<04a<0ha<00`0C4`0N4`8=

D1<005HC00<=4a<04Q<20>@C00<04a<06a<33E8C001G4`033A<C014C00<04a<0ha<00`0C4`0H4`<=

EA<001XC0`0U4`D04A<00`dC4`0@4`0301<C02@C1@0T4`<0Ta<00`0C4`0E4`<=F1<001XC00<04a<0

9a<00`0C4`0A4`033A<C010C00<04a<09Q<00`0C4`0T4`0301<C09<C0P0D4`8=Fa<001DC0`034`03

01<C020C0`034`0301<C018C00<=4a<03a<202LC00<04a<09A<00`0C4`2B4`0301<C00lC10eM4`00

6a<00`0C4`0V4`0301<C01<C00<=4a<03Q<00`0C4`0V4`0301<C02DC00<04a<0TQ<00`0C4`0:4`D=

HA<001XC00<04`009a<00`0C4`0C4`033A<C00hC00<04a<09Q<00`0C4`0T4`0301<009<C00<04a<0

1Q<43FHC000K4`0301<C02DC0P0F4`033A<C00dC00<04a<09A<202LC00<04a<0SQ<=3FXC001K4`03

3A<C00dC0P2n4b8=11<00`0C4`1`4`00G1<00`dC4`0<4`0301<C08PC=@dV4`0301<C070C001M4`03

3A<C00/C00<04a<0Fa<208HC00<04a<0CA<<3ALC001M4`033A<C00/C00<04a<0FQ<00`0C4`264`03

01<C03<C6PdS4`005A=900033@0006401Q<00`0C4`264`809a<=3CdC000I4`0301<C00HC00<04a<0

1A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<01@0C4a<=00<C

00<04a<01A<00a0C4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C

4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00PC00<04a<0QQ<00`0C4`0P4`H=BQ<005lC

00<=4a<02A<00a0C4`1J4`0301<008HC00<04a<06a<53E0C001P4`033A<C00PC0Q1K4`<0Ma<00`0C

4`024`0301<C008C00<04a<00Q<00`0C4`0H4`<=EA<0064C00<=4a<01a<24=@C00<04`001a<00`0C

00034`0301<C01HC0PeH4`00HA<00`dC4`064`03400@0<lC0`024`0301<000TC00@04a<C0P0E4`8=

FQ<0068C00<=4a<01A<00a00403D4`0301<000LC0P044`0301<C018C0PeL4`00Ha<00`dC4`044`03

400@0=@C00<04`001a<00`0C4`034`0301<C014C00<=4a<0G1<006@C00<=4a<00Q<01A0C000@0=@C

00<04a<01Q<300<C00<04a<03a<23ElC001T4`033A<C008C00D@4`0C403S4`803Q<23F4C001U4`09

3A<C4a0C01<@0><C00<04a<031<00`dC4`1Q4`00IQ<01PdC4a0C008C00<@4a<0h1<00`0C4`0;4`03

3A<C068C001V4`053A<C41<00P000a<@4`3Q4`0301<C00TC0PeU4`00Ia<01@dC41<0008C00<@4a<0

h1<00`0C4`084`033A<C06DC001W4`053A0C4`000a<00a0C4`3O4`8021<00`dC4`1V4`00J1<010dC

4`034`0341<C0=lC00<04a<01Q<00`dC4`1W4`00J1<00a0=4`02008C00<@4a<0ga<00`0C4`054`03

3A<C06PC001W4`0541<=4`0011<00a0C4`244`<0:Q<502PC00<04a<011<00`dC4`0Q4`D0:Q<301HC

001L4`0301<C008C00<04a<00Q<01P0@4a<=00@C00<@4a<0Q1<00`0C4`0/4`0301<C02PC0P044`03

3A<C02@C00<04a<0:Q<00`0C4`0F4`00Fa<00`0C00074`030100008C00<=01<00a<00a0C4`1o4`<0

0a<00`0C4`0U4`<00a<00`0C4`0X4`0301<C008C00<=4a<09A<00`0C4`0[4`0301<C01DC001K4`03

01<000PC00<@01<00Q<00`d04`034`0341<C08@C00<04a<0:a<00`0C4`0X4`0301<C008C00<=4a<0

9A<00`0C4`0[4`0301<C01DC001K4`0301<000LC00<041<00a<00`0=4`034`0341<C08<C00<04`00

;1<00`0C4`0X4`0501<C4`d0:1<00`0C4`0Z4`0301<001HC001K4`0301<000LC00<@4a<00a<00`0=

4`044`0341<C08<C00<04a<0:Q<202XC00D04a<C3@0W4`80;A<00`0C4`0E4`00G1<00`0C4`064`03

400000<C00<04`d011<00a0C4`3L4`8000<C3A<0KQ<006@C00<@4a<011<200034`dC008C00<@4a<0

g1<00`0C3@1`4`00I1<00a0C4`044`0401<C3@@C00<@4a<0fa<00`0C3@1V4`8021<006<C00<@4a<0

1A<01@0C4a<=00<C00<@4a<0fa<00`0=4`1U4`0301<C00PC001S4`0341<C00DC00D04a<C3@044`03

41<C07XCH@000`d0001M00LC00<04a<021<0068C00<@4a<01Q<00`0C4`024`053A<C4a00PA<00`0C

4`064`0301<C00HC00<04a<01Q<00`0C4`064`0301<C00LC00<04a<01Q<00`0C4`064`0301<C00HC

00<04a<01Q<00`0C4`064`033A<C00HC00<04a<01Q<00`0C4`064`0301<C00LC00<04a<01Q<00`0C

4`064`0301<C00HC00<04a<01Q<00`0C4`064`0301<C00HC00<04a<02Q<00`0C4`084`00HQ<00a0C

4`064`8011<01@dC4a<@080C00<04a<0:a<00`0C4`0Z4`033A<C02/C00<04a<0:Q<00`0C4`0:4`03

01<000PC001Q4`0341<C00LC00<04a<00a<01@dC4a<@0=XC00<=01<0IQ<300PC001Q4`0341<C00LC

00<04a<011<010dC4a3J4`033@0C074C001P4`0341<C00PC00<04a<01A<010dC4a3H4`043A<0074C

001P4`0341<C00PC0P064`043A<C4=PC00<=4`00LQ<005lC00<@4a<02A<00`0C4`064`043A<C4=LC

00<=4`00LQ<005lC00<@4a<02A<00`0C4`074`033A<@0=LC00<=4`00LQ<005hC00<@4a<02Q<00`0C

4`074`043A<C4=DC00<=4a<00P1a4`00GQ<00a0C4`0:4`802A<00`dC403E4`043A<C078C001M4`03

41<C00/C00<04a<02A<00`dC403D4`043A<C078C001M4`0341<C00@C1@024`0301<C00XC00<=41<0

da<010dC4`1b4`00G1<00a0C4`074`0301<C008C00<04a<02Q<00`dC403C4`043A<C078C001K4`03

41<C00PC00<04a<00Q<200`C00<=4a00dA<010dC4a<2074C001K4`0341<C00PC00<04a<00Q<00`0C

4`0<4`033A0C0=0C00D=4a<C001b4`00FQ<00a0C4`094`0301<C008C00<04a<031<00`dC403@4`05

3A<C4`00LQ<005XC00<@4a<021<200@C00<04a<03A<00`dC403?4`053A<C4`00LQ<005TC00<@4a<0

3a<200lC00<=41<0cQ<01@dC4a<0078C001H4`0341<C010C00<04a<03Q<00`dC403>4`043A<C4`80

LA<005PC00<@4a<041<00`0C4`0?4`033A<@0<hC00@=4a<0LQ<005LC00<@4a<04A<00`0C4`0?4`03

3A<@0<8C00<04a<00Q<00`0C4`024`0301<=008C00<04a<0L1<005HC00<@4a<04Q<2014C00<=4a00

`1<00`0C00074`0401<03@8C00<04a<0L1<005HC00<@4a<04Q<00`0C4`0A4`033A<@0;lC00<04`00

2A<0100=4a<2074C001E4`0341<C01<C00<04a<04A<00`dC402o4`0301<000LC0P001A<=4a<0078C

001D4`0341<C01@C00<04a<04Q<00`dC402n4`0301<000LC00L04a<C3A<0078C001C4`0341<C01DC

0P0D4`033A0C0;hC00<04a<01Q<300044`dC078C001C4`0341<C01DC00<04a<04a<00`dC403;4`03

3A<0078C001B4`0341<C01HC00<04a<051<00`dC403:4`043A<0074C001A4`0341<C01LC00<04a<0

5A<00`d@4`3:4`033@0C074C001A4`0341<C01LC0P0F4`033A<@0<XC00<=01<0LA<0050C00<@4a<0

61<00`0C4`0F4`033A0C0<XC00<=4a<0L1<004lC00<@4a<021<5008C00<04a<00Q<00`0C4`024`03

01<C01LC00<=41<0bA<00`d04`1`4`00Ca<00a0C4`0:4`0301<C00HC00<04`000a<00`0C4`0H4`03

3A0C0<PC00<03A<0L1<004hC00<@4a<02a<00`0C4`084`0401<C4`806A<00`dC40384`0300dC070C

001=4`0341<C00`C00<04a<01Q<200@C00<04a<06A<00`d@4`374`0301<=070C001<4`0341<C00dC

00<04a<01Q<00`0C4`034`0301<C01XC00<=41<0aQ<00`0C3@1`4`00C1<00a0C4`0<4`8021<300<C

00<04a<06Q<00`dC40364`8000<C3A<0KQ<004/C00<@4a<07A<201`C00<=4a00aA<01@0C4a<=06hC

001:4`0341<C01hC00<04a<06a<00`dC40354`0501<C4`d0KQ<004XC00<@4a<07Q<00`0C4`0L4`03

3A<@0<@C00<04a<00Q<00`dC4`1[4`00BA<00a0C4`0O4`0301<C01dC00<=4a00`a<200<C00<=4a<0

Ja<004PC00<@4a<081<201hC00@=4a<@`Q<00`0C4`034`033A<C06XC00174`0341<C024C00<04a<0

7Q<010dC4a314`0301<C00@C00<=4a<0JA<004LC00<@4a<08A<00`0C4`0N4`043A<C4;XC1@024`03

01<C00DC00<=4a<0J1<004HC00<@4a<08Q<00`0C4`0O4`043A<C4;/C00<04a<00Q<00`0C4`054`03

3A<C06PC00154`0341<C02<C0P0Q4`043A<C4;XC00<04a<00Q<200LC00<=4a<0Ia<004@C00<@4a<0

91<00`0C4`0P4`053A<C4a00^A<00`0C4`024`0301<C00LC00<=4a<0IQ<004@C00<@4a<091<00`0C

4`0Q4`043A<C4;TC00<04a<00Q<00`0C4`084`033A<C06DC00134`0341<C02DC00<04a<08Q<010dC

4a2g4`8011<00`0C4`094`033A<C06@C00124`0341<C02HC00<04a<08Q<01@dC4a<@0;`C0P0;4`03

3A<C06<C00114`0341<C02LC0P0T4`053A<C4a00^a<00`0C4`0;4`033A<C068C00104`0341<C02PC

00<04a<08a<00`dC4`024`0341<C0;PC00<04a<031<00`dC4`1Q4`00@1<00a0C4`0R4`<00a<00`0C

4`0T4`033A<C008C00<@4a<0]a<00`0C4`0=4`033A<C060C000o4`0341<C02<C00<04a<00a<00`0C

4`0U4`053A<C4a00^A<00`0C4`0>4`8=H1<003hC00<@4a<09A<00`0C4`024`809Q<00`dC4`024`03

41<C0;HC0P0A4`033A<C05dC000m4`0341<C02HC00<04a<00Q<00`0C4`0V4`033A<C008C00<@4a<0

]A<00`0C4`0A4`033A<C05`C000m4`0341<C02DC00<04`000a<00`0C4`0W4`033A<C008C00<@4a<0

]1<00`0C4`0B4`033A<C05/C000l4`0341<C02LC00<04a<00Q<00`0C4`0W4`033A<C00<C00<@4a<0

/a<00`0C4`0C4`033A<C05XC000k4`0341<C02dC0P0Y4`033A<C00<C00<@4a<0/Q<00`0C4`0D4`03

3A<C05TC000j4`0341<C02hC00<04a<0:A<00`dC4`024`0341<C0;8C0P0F4`033A<C05PC000j4`03

41<C02hC00<04a<0:A<00`dC4`034`0341<C0;4C00<04a<05Q<00`dC4`1G4`00>A<00a0C4`0_4`03

01<C02XC00<=4a<00a<00a0C4`2`4`0301<C01LC0PeG4`00>1<00a0C4`0`4`80;1<00`dC4`034`03

41<C0:lC00<04a<06A<00`dC4`1D4`00=a<00a0C4`0a4`0301<C02`C00<=4a<00Q<00a0C4`2_4`80

6a<23E@C000g4`0341<C034C00<04a<0;1<00`dC4`034`0341<C0:hC00<04a<071<00`dC4`1A4`00

=Q<00a0C4`0b4`0301<C02dC00<=4a<00a<00a0C4`2]4`0301<C01dC0PeA4`00=A<00a0C4`0c4`80

;a<00`dC4`034`0341<C09/C1@024`0301<C008C00<04a<00Q<00`0C4`0O4`033A<C04hC000d4`03

41<C03@C00<04a<0;Q<00`dC4`044`0341<C09`C00<04a<01Q<00`0C00034`0301<C020C0Pe>4`00

<a<00a0C4`0e4`0301<C02lC00<=4a<011<00a0C4`2K4`0301<C00PC00@04a<C0P0S4`033A<C04/C

000b4`0341<C03HC00<04a<0<1<00`dC4`034`0341<C09/C00<04a<01Q<200@C00<04a<08a<23D/C

000a4`0341<C03LC0P0a4`033A<C00@C00<@4a<0VQ<00`0C4`064`0301<C00<C00<04a<09A<23DTC

000`4`0341<C03PC00<04a<0<A<00`dC4`044`0341<C09PC0P084`<00a<00`0C4`0W4`8=Aa<002lC

00<@4a<0:A<300<C00<04a<00Q<00`0C4`024`0301<C034C00<=4a<01A<00a0C4`2W4`80:Q<00`dC

4`144`00;Q<00a0C4`0Z4`0301<C00LC00<04`000a<00`0C4`0b4`033A<C00DC00<@4a<0YQ<00`0C

4`0Z4`8=A1<002dC00<@4a<0;1<00`0C4`084`0401<C4`80=1<00`dC4`054`0341<C0:DC00<04a<0

;1<00`dC4`114`00;1<00a0C4`0]4`0301<C00HC0P044`0301<C03<C00<=4a<01Q<00a0C4`2T4`03

01<C02dC0Pe14`00:a<00a0C4`0]4`0301<000LC00<04a<00a<00`0C4`0d4`033A<C00HC00<@4a<0

Xa<00`0C4`0_4`033A<C03hC000Z4`0341<C02lC00<04a<01Q<300<C00<04a<0=A<00`dC4`064`03

41<C0:8C0P0a4`8=?Q<002TC00<@4a<0?a<203HC00<=4a<01a<00a0C4`2Q4`0301<C038C0Pdl4`00

:1<00a0C4`104`0301<C03HC00<=4a<01a<00a0C4`2P4`0301<C03@C0Pdj4`009a<00a0C4`114`03

01<C03LC00<=4a<01a<00a0C4`2O4`0301<C03HC0Pdh4`009Q<00a0C4`124`0301<C03LC00<=4a<0

21<00a0C4`2N4`80>A<23CHC000U4`0341<C04<C0P0i4`033A<C00PC00<@4a<0WA<00`0C4`0j4`8=

=1<002@C00<@4a<0A1<00`0C4`0i4`033A<C00PC00<@4a<0W1<00`0C4`0l4`8=<Q<002<C00<@4a<0

AA<00`0C4`0j4`033A<C00PC00<@4a<0Va<00`0C4`0n4`8=<1<002<C00<@4a<0AA<00`0C4`0j4`03

3A<C00TC00<@4a<0VQ<00`0C4`104`8=;Q<0028C00<@4a<0AQ<203`C00<=4a<02A<00a0C4`2I4`80

@a<33B/C000Q4`0341<C04LC00<04a<0?1<00`dC4`094`0341<C09PC00<04a<0AA<23BTC000P4`03

41<C04PC00<04a<0?1<00`dC4`0:4`0341<C094C0`034`0301<C04LC00<=4a<09Q<001lC00<@4a<0

BA<00`0C4`0m4`033A<C00XC00<@4a<0T1<00`0C4`034`0301<C04PC0PdV4`007Q<00a0C4`1:4`80

?Q<00`dC4`0;4`0341<C090C00<04a<00Q<204/C00<=4a<08a<001dC00<@4a<0Ba<00`0C4`0n4`03

3A<C00/C00<@4a<0Sa<00`0C4`024`0301<C04/C0PdS4`0071<00a0C4`1<4`0301<C03hC00<=4a<0

31<00a0C4`2=4`0301<000<C00<04a<0CA<33B0C000K4`0341<C04LC0P044`0301<C03lC00<=4a<0

31<00a0C4`2=4`0301<C008C00<04a<0D1<43A`C000J4`0341<C04XC00D04a<C00114`033A<C00dC

00<@4a<0TA<00`0C4`1D4`8=6Q<001TC00<@4a<0BQ<00`0C4`024`80@A<00`dC4`0<4`0341<C094C

0P1G4`8=61<006LC00<04a<0ia<00`0C4`1H4`033A<C01DC001U4`0301<00>TC00<04a<0L1<006HC

00<04a<0j1<00`0C4`1`4`00;1<30?lC8a<00`0C4`1`4`00;1<00`0C4`3o4b<C0P1a4`00;A<00`0C

4`054`0301<C0?lCSA<002dC00@04a<C0`0011<04a<30?lCRQ<002`C00<04`000Q<2008C00<04a<0

0Q<00`0C4`3o4hPC000]4`0301<C00<C00@04a<00Q<00`0C4`3o4hTC000c4`0401<C00<C00<04a<0

1Q<00`0C4`0U4`<0;A<00`0C4`3o4bLC000M4`<000<C00000P0<4`<011<300PC00<04a<091<0100C

4`0A4`<000<C00000P024`0301<C008C00<04a<00Q<00`0C4`054`0401<C4`D00Q<00`0C4`024`04

01<C4`<01A<20</C00<04a<0<Q<00`0C4`084`0071<0100C4`0T4`0301<C02<C00@04a<041<0100C

4`064`0301<000LC00<04`0011<500<C00<04a<01Q<00`0C00024`0301<C00@C00<04a<0`a<00`0C

4`044`0301<C01<C00<04a<07Q<00`0C4`074`0071<01@0C4`0C00@000<C0000600[4`<041<01@0C

4`0C00@000@C01<02A<00`0C4`044`0301<C00<C00<04a<021<01@0C4a<000DC00<04a<0/A<0100C

4a<4008C0P064`0301<C00<C00<04a<00Q<00`0C4`024`0301<C008C00<04a<01A<0100C4a<5008C

00<04a<00Q<0100C4a<300DC0P044`0401<C4`800A<10040000M4`<0CA<00`0C4`0?4`<01Q<00`0C

00074`801a<00`0C4`034`0301<C00HC0P044`0301<C00<C00<04a<0/1<00`0C00074`0301<C00@C

1@034`0701<C4`0C00074`0301<000@C1@034`0301<C00HC00<04`000Q<00`0C4`044`0301<C00@C

00<04a<00Q<00`0C00014`007a<00`0C4`1:4`804a<00`0C4`044`0301<000LC00<04a<031<00`0C

4`064`0301<C008C00<04`0011<00`0C002`4`0301<0008C10000a<04`074`0301<C00<C00L04a<C

01<000TC00<04a<011<00`0C4`034`0301<C00PC00D04a<C00054`0301<C00@C00<04a<00a<1004C

0A<001hC0P1P4`801a<00`0C4`064`<02a<200PC0`034`0301<C00<C0`2F4`8000<C00005A<00`0C

00074`0301<C00HC00<04a<00a<01`0C4a<04`001a<200LC00<04a<00a<00`0C4`064`8011<00`0C

4`034`0301<C00@C00<04a<00a<1004C0A<00?lCDA<00`0C000F4`0301<000LC00<04`003A<01P0C

4`0C00LC00<04a<031<00`0C4`064`0301<C008C00<04`0011<00`0C00034`0301<C00<C00<04`00

0A<002TC0P064`80oa<O4`0301<C01HC00<04a<01Q<300hC00@04a<021<300/C0P084`<00a<00`0C

4`034`<00Q<00`0C4`034`800A<10040000[4`0301<C008C00<04a<0oa<O4`0301<C070C000Z4`03

01<C00<C00<04a<01A<00`0C4`3o4aHC00<04`00LA<002/C00<04a<00Q<00`0C4`024`@00a<30?lC

4A<200034`00070C000Y4`0301<000@C00<04`000Q<200034`0C00@C00<04a<0oa>44`00:Q<00`0C

4`034`<011<00`0C00034`0301<C0?lCQA<003LC00<04`0011<00`0C4`3o4h@C000e4`<011<30?lC

QQ<00?lCaA<00?lCaA<00?lCaA<00?lCaA<00?lCaA<00001\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.41323, -1.7059, 0.021959, 0.021959}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -84.5 0 ]

[.5 .96488 84.5 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -145.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.515) show

222.250000 19.500000 moveto

(C) show

227.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.26426 0 m

.30316 .05892 L

.34309 .11942 L

.3815 .17761 L

.42237 .23953 L

.46172 .29914 L

.49955 .35646 L

.53984 .4175 L

.57861 .47624 L

.61984 .53869 L

.65954 .59885 L

.69774 .65671 L

.73838 .71829 L

.77751 .77757 L

.81909 .84057 L

.85916 .90127 L

s

.85916 .90127 m

.8929 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.372375 0.238095 [

[.02381 .35988 -6 -9 ]

[.02381 .35988 6 0 ]

[.2619 .35988 -6 -9 ]

[.2619 .35988 6 0 ]

[.7381 .35988 -3 -9 ]

[.7381 .35988 3 0 ]

[.97619 .35988 -3 -9 ]

[.97619 .35988 3 0 ]

[1.025 .37238 0 -8 ]

[1.025 .37238 9 8 ]

[.4875 .01523 -24 -4.5 ]

[.4875 .01523 0 4.5 ]

[.4875 .13428 -12 -4.5 ]

[.4875 .13428 0 4.5 ]

[.4875 .25333 -24 -4.5 ]

[.4875 .25333 0 4.5 ]

[.4875 .49142 -18 -4.5 ]

[.4875 .49142 0 4.5 ]

[.4875 .61047 -6 -4.5 ]

[.4875 .61047 0 4.5 ]

[.4875 .72952 -18 -4.5 ]

[.4875 .72952 0 4.5 ]

[.4875 .84857 -6 -4.5 ]

[.4875 .84857 0 4.5 ]

[.5 .92244 -4.5 0 ]

[.5 .92244 4.5 16 ]

[.5 .90994 -137 0 ]

[.5 .90994 137 16 ]

[ 0 0 0 0 ]

[ 1 .89744 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .37238 m

.02381 .37863 L

s

[(-2)] .02381 .35988 0 1 Mshowa

.2619 .37238 m

.2619 .37863 L

s

[(-1)] .2619 .35988 0 1 Mshowa

.7381 .37238 m

.7381 .37863 L

s

[(1)] .7381 .35988 0 1 Mshowa

.97619 .37238 m

.97619 .37863 L

s

[(2)] .97619 .35988 0 1 Mshowa

.125 Mabswid

.07143 .37238 m

.07143 .37613 L

s

.11905 .37238 m

.11905 .37613 L

s

.16667 .37238 m

.16667 .37613 L

s

.21429 .37238 m

.21429 .37613 L

s

.30952 .37238 m

.30952 .37613 L

s

.35714 .37238 m

.35714 .37613 L

s

.40476 .37238 m

.40476 .37613 L

s

.45238 .37238 m

.45238 .37613 L

s

.54762 .37238 m

.54762 .37613 L

s

.59524 .37238 m

.59524 .37613 L

s

.64286 .37238 m

.64286 .37613 L

s

.69048 .37238 m

.69048 .37613 L

s

.78571 .37238 m

.78571 .37613 L

s

.83333 .37238 m

.83333 .37613 L

s

.88095 .37238 m

.88095 .37613 L

s

.92857 .37238 m

.92857 .37613 L

s

.25 Mabswid

0 .37238 m

1 .37238 L

s

gsave

1.025 .37238 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .01523 m

.50625 .01523 L

s

[(-1.5)] .4875 .01523 1 0 Mshowa

.5 .13428 m

.50625 .13428 L

s

[(-1)] .4875 .13428 1 0 Mshowa

.5 .25333 m

.50625 .25333 L

s

[(-0.5)] .4875 .25333 1 0 Mshowa

.5 .49142 m

.50625 .49142 L

s

[(0.5)] .4875 .49142 1 0 Mshowa

.5 .61047 m

.50625 .61047 L

s

[(1)] .4875 .61047 1 0 Mshowa

.5 .72952 m

.50625 .72952 L

s

[(1.5)] .4875 .72952 1 0 Mshowa

.5 .84857 m

.50625 .84857 L

s

[(2)] .4875 .84857 1 0 Mshowa

.125 Mabswid

.5 .03904 m

.50375 .03904 L

s

.5 .06285 m

.50375 .06285 L

s

.5 .08666 m

.50375 .08666 L

s

.5 .11047 m

.50375 .11047 L

s

.5 .15809 m

.50375 .15809 L

s

.5 .1819 m

.50375 .1819 L

s

.5 .20571 m

.50375 .20571 L

s

.5 .22952 m

.50375 .22952 L

s

.5 .27714 m

.50375 .27714 L

s

.5 .30095 m

.50375 .30095 L

s

.5 .32476 m

.50375 .32476 L

s

.5 .34857 m

.50375 .34857 L

s

.5 .39618 m

.50375 .39618 L

s

.5 .41999 m

.50375 .41999 L

s

.5 .4438 m

.50375 .4438 L

s

.5 .46761 m

.50375 .46761 L

s

.5 .51523 m

.50375 .51523 L

s

.5 .53904 m

.50375 .53904 L

s

.5 .56285 m

.50375 .56285 L

s

.5 .58666 m

.50375 .58666 L

s

.5 .63428 m

.50375 .63428 L

s

.5 .65809 m

.50375 .65809 L

s

.5 .6819 m

.50375 .6819 L

s

.5 .70571 m

.50375 .70571 L

s

.5 .75333 m

.50375 .75333 L

s

.5 .77714 m

.50375 .77714 L

s

.5 .80095 m

.50375 .80095 L

s

.5 .82476 m

.50375 .82476 L

s

.5 .87238 m

.50375 .87238 L

s

.5 .89618 m

.50375 .89618 L

s

.25 Mabswid

.5 0 m

.5 .89744 L

s

gsave

.5 .92244 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .90994 -198 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.515) show

298.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

303.000000 15.000000 moveto

(L) show

310.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

317.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

324.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

329.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

333.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .89744 L

0 .89744 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .2126 m

.02576 .21259 L

.03157 .21256 L

.04115 .21252 L

.05433 .21246 L

.07089 .21238 L

.09054 .21228 L

.11294 .21215 L

.13772 .212 L

.16444 .21181 L

.19266 .2116 L

.22189 .21134 L

.25163 .21104 L

.28136 .2107 L

.31059 .2103 L

.33881 .20983 L

.36553 .20931 L

.39031 .20874 L

.41272 .20811 L

.43236 .20746 L

.44892 .20682 L

.4621 .20623 L

.47168 .20575 L

.47749 .20544 L

.47944 .20533 L

s

.47944 .20533 m

.48157 .2052 L

.48791 .20482 L

.49835 .20413 L

.51272 .20304 L

.53077 .20137 L

.55219 .19881 L

.57662 .19485 L

.60363 .18868 L

.63277 .17943 L

.66353 .16692 L

.6954 .15201 L

.72782 .13595 L

.76024 .11975 L

.7921 .10405 L

.82287 .08925 L

.852 .07559 L

.87902 .06326 L

.90344 .05237 L

.92486 .04303 L

.94291 .0353 L

.95728 .02923 L

.96773 .02487 L

.97407 .02224 L

.97619 .02137 L

s

.47944 .45584 m

.48157 .42883 L

.48791 .40206 L

.49835 .37575 L

.51272 .35015 L

.53077 .32555 L

.55219 .30239 L

.57662 .28129 L

.60363 .26319 L

.63277 .24904 L

.66353 .23914 L

.6954 .23275 L

.72782 .22867 L

.76024 .22601 L

.7921 .2242 L

.82287 .22293 L

.852 .22201 L

.87902 .22132 L

.90344 .22081 L

.92486 .22043 L

.94291 .22014 L

.95728 .21994 L

.96773 .2198 L

.97407 .21972 L

.97619 .21969 L

s

.47944 .45596 m

.48157 .48309 L

.48791 .51025 L

.49835 .53724 L

.51272 .56394 L

.53077 .59021 L

.55219 .61593 L

.57662 .64098 L

.60363 .66526 L

.63277 .68866 L

.66353 .71106 L

.6954 .73237 L

.72782 .7525 L

.76024 .77136 L

.7921 .78887 L

.82287 .80495 L

.852 .81953 L

.87902 .83254 L

.90344 .84394 L

.92486 .85367 L

.94291 .86169 L

.95728 .86796 L

.96773 .87246 L

.97407 .87517 L

.97619 .87607 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCaA<00?lCDQ<00`0C4`1`4`00I1<50=LC1@024`0301<C008C00<04a<00Q<00`0C4`1`4`00

IQ<00`0C4`3I4`0301<C00HC00<04`000a<00`0C4`1`4`00@a<00`dC4`0J4`<00a<00`0C4`024`80

ca<300<C00<04a<021<0100C4a<2074C00144`033A<C01lC00<04a<00Q<00`0C4`3D4`0301<C00HC

0P044`0301<C05PC00<=4a<05A<004@C00<=4a<07a<00`0C4`024`0301<C0=@C00<04a<01Q<00`0C

4`034`0301<C05LC00<=4a<05Q<004DC00<=4a<07A<200@C00<04a<0da<200PC0`034`0301<C05@C

0`dI4`00AA<00`dC4`0S4`80i1<00`0C4`1A4`<=71<004HC00<=4a<08Q<00`0C4`3S4`80Ca<33AlC

00174`033A<C024C00<04a<0ha<00`0C4`1<4`8=8Q<004LC00<=4a<08A<00`0C4`3S4`0301<C04XC

0PdT4`00B1<00`dC4`0P4`80i1<00`0C4`184`8=9Q<004PC00<=4a<081<00`0C4`3S4`80Aa<23BPC

00194`033A<C01lC00<04a<0ha<00`0C4`144`8=:Q<004XC00<=4a<07Q<00`0C4`3S4`0301<C048C

0Pd/4`00BQ<00`dC4`0N4`80i1<00`0C4`0o4`<=;Q<004/C00<=4a<07A<00`0C4`3S4`0301<C03dC

0Pda4`00C1<00`dC4`0L4`0301<C0><C0P0l4`8=<a<004`C00<=4a<071<00`0C4`3S4`0301<C03TC

0Pde4`00CA<00`dC4`0K4`80i1<00`0C4`0g4`8==a<004dC00<=4a<06a<00`0C4`3S4`0301<C03DC

0Pdi4`00CQ<00`dC4`0;4`0301<C008C00<04a<00Q<00`0C4`024`0301<C0><C0P0d4`8=>a<004lC

00<=4a<02A<00`0C00074`0301<000<C00<04a<0ha<00`0C4`0a4`8=?A<004lC00<=4a<011<3008C

00<04`002A<0100C4a<20>@C00<04a<0;a<23ClC001@4`033A<C00PC00<04`001a<200@C00<04a<0

g1<5008C00<04a<0;A<23D4C001A4`033A<C00LC00<04`001a<00`0C4`034`0301<C0=hC00<04a<0

0Q<00`0C4`0[4`8=@a<0054C00<=4a<021<00`0C4`064`<00a<00`0C4`3H4`<00a<00`0C4`024`80

:A<33DDC001B4`033A<C01HC00<04a<0gQ<00`0C4`024`0301<C02HC0Pe84`00Da<00`dC4`0E4`80

ga<00`0C4`024`0301<C02@C0Pe:4`00Da<00`dC4`0E4`0301<C0=dC0P044`0301<C028C0Pe<4`00

E1<00`dC4`0D4`0301<C0><C0P0Q4`8=CQ<005DC00<=4a<04a<00`0C4`3S4`0301<C01hC0Pe@4`00

EQ<00`dC4`0B4`80i1<00`0C4`0K4`<=DQ<005HC00<=4a<04Q<00`0C4`3S4`0301<C01TC0PeE4`00

6Q<302DC1@0@4`033A<C014C00<04a<091<502@C0`2C4`0301<C01HC0`eG4`006Q<00`0C4`0W4`03

01<C014C00<=4a<041<00`0C4`0V4`0301<C02@C00<04a<0Ta<201@C0`eJ4`005A<300<C00<04a<0

81<300<C00<04a<04A<00`dC4`0@4`809a<00`0C4`0U4`0301<C098C00<04a<03a<43EdC000K4`03

01<C02HC00<04a<04Q<00`dC4`0?4`0301<C02HC00<04a<09A<00`0C4`2B4`0301<C00XC1@eQ4`00

6Q<00`0C000W4`0301<C01<C00<=4a<03Q<00`0C4`0V4`0301<C02@C00<04`00Ta<00`0C4`064`@=

IQ<001/C00<04a<09A<201DC00<=4a<03Q<00`0C4`0U4`809a<00`0C4`2>4`d=JQ<005/C00<=4a<0

3A<20;PC:0d44`80LA<005`C00<=4a<031<00`0C4`284bl=;1<00`0C4`1`4`00GA<00`dC4`0;4`03

01<C05/C0P264`0301<C04TC40dG4`00GA<00`dC4`0;4`0301<C05XC00<04a<0QQ<00`0C4`0]4a`=

9a<001DCB@000`d0001Q00HC00<04a<0QQ<202LC1`e34`006A<00`0C4`064`0301<C00DC00<04a<0

1A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00D04a<C3@034`0301<C00DC

00<@4a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C

4`064`0301<C00DC00<04a<01A<00`0C4`084`0301<C08HC00<04a<081<63DXC001O4`033A<C00TC

00<@4a<0FQ<00`0C00264`0301<C01/C1@e@4`00H1<00`dC4`084`8@Fa<307LC00<04a<00Q<00`0C

4`024`0301<C008C00<04a<06A<23EDC001Q4`033A<C00LC0Q3D4`0301<000LC00<04`000a<00`0C

4`0G4`8=Ea<0064C00<=4a<01Q<00a00403?4`<00Q<00`0C00094`0401<C4`805Q<23ETC001R4`03

3A<C00DC00<@0100e1<00`0C00074`8011<00`0C4`0C4`8=Fa<006<C00<=4a<011<00a00403D4`03

01<000LC00<04a<00a<00`0C4`0A4`8=GA<006@C00<=4a<00Q<01A0C000@0=@C00<04a<01Q<300<C

00<04a<03a<23ElC001T4`033A<C008C00D@4`0C403S4`803Q<23F4C001U4`093A<C4a0C01<@0><C

00<04a<031<00`dC4`1Q4`00IQ<01PdC4a0C008C00<@4a<0h1<00`0C4`0;4`033A<C068C001V4`05

3A<C41<00P000a<@4`3Q4`0301<C00TC0PeU4`00Ia<01@dC41<0008C00<@4a<0h1<00`0C4`084`03

3A<C06DC001W4`053A0C4`000a<00a0C4`3O4`8021<00`dC4`1V4`00J1<010dC4`034`0341<C0=lC

00<04a<01Q<00`dC4`1W4`00J1<00a0=4`02008C00<@4a<0ga<00`0C4`054`033A<C06PC001W4`05

41<=4`0011<00a0C4`244`<0:Q<502PC00<04a<011<00`dC4`0Q4`D0:Q<301HC001L4`0301<C008C

00<04a<00Q<01P0@4a<=00@C00<@4a<0Q1<00`0C4`0/4`0301<C02PC0P044`033A<C02@C00<04a<0

:Q<00`0C4`0F4`00Fa<00`0C00074`030100008C00<=01<00a<00a0C4`1o4`<00a<00`0C4`0U4`<0

0a<00`0C4`0X4`0301<C008C00<=4a<09A<00`0C4`0[4`0301<C01DC001K4`0301<000PC00<@01<0

0Q<00`d04`034`0341<C08@C00<04a<0:a<00`0C4`0X4`0301<C008C00<=4a<09A<00`0C4`0[4`03

01<C01DC001K4`0301<000LC00<041<00a<00`0=4`034`0341<C08<C00<04`00;1<00`0C4`0X4`05

01<C4`d0:1<00`0C4`0Z4`0301<001HC001K4`0301<000LC00<@4a<00a<00`0=4`044`0341<C08<C

00<04a<0:Q<202XC00D04a<C3@0W4`80;A<00`0C4`0E4`00G1<00`0C4`064`03400000<C00<04`d0

11<00a0C4`3L4`8000<C3A<0KQ<006@C00<@4a<011<200034`dC008C00<@4a<0g1<00`0C3@1`4`00

I1<00a0C4`044`0401<C3@@C00<@4a<0fa<00`0C3@1V4`8021<006<C00<@4a<01A<01@0C4a<=00<C

00<@4a<0fa<00`0=4`1U4`0301<C00PC001S4`0341<C00DC00D04a<C3@044`0341<C07XCH@000`d0

001M00LC00<04a<021<0068C00<@4a<01Q<00`0C4`024`053A<C4a00PA<00`0C4`064`0301<C00HC

00<04a<01Q<00`0C4`064`0301<C00LC00<04a<01Q<00`0C4`064`0301<C00HC00<04a<01Q<00`0C

4`064`033A<C00HC00<04a<01Q<00`0C4`064`0301<C00LC00<04a<01Q<00`0C4`064`0301<C00HC

00<04a<01Q<00`0C4`064`0301<C00HC00<04a<02Q<00`0C4`084`00HQ<00a0C4`064`8011<01@dC

4a<@080C00<04a<0:a<00`0C4`0Z4`033A<C02/C00<04a<0:Q<00`0C4`0:4`0301<000PC001Q4`03

41<C00LC00<04a<00a<01@dC4a<@0=XC00<=01<0IQ<300PC001Q4`0341<C00LC00<04a<011<010dC

4a3J4`033@0C074C001P4`0341<C00PC00<04a<01A<010dC4a3H4`043A<0074C001P4`0341<C00PC

0P064`043A<C4=PC00<=4`00LQ<005lC00<@4a<02A<00`0C4`064`043A<C4=LC00<=4`00LQ<005lC

00<@4a<02A<00`0C4`074`033A<@0=LC00<=4`00LQ<005hC00<@4a<02Q<00`0C4`074`043A<C4=DC

00@=4a<0LQ<005hC00<@4a<02Q<200TC00<=4a00eA<00`dC4`02074C001M4`0341<C00/C00<04a<0

2A<00`dC403D4`043A<C078C001M4`0341<C00@C1@024`0301<C00XC00<=41<0da<010dC4`1b4`00

G1<00a0C4`074`0301<C008C00<04a<02Q<00`dC403C4`043A<C078C001K4`0341<C00PC00<04a<0

0Q<200`C00<=4a00dA<010dC4a<2074C001K4`0341<C00PC00<04a<00Q<00`0C4`0<4`033A0C0=0C

00D=4a<C001b4`00FQ<00a0C4`094`0301<C008C00<04a<031<00`dC403@4`053A<C4`00LQ<005XC

00<@4a<021<200@C00<04a<03A<00`dC403?4`053A<C4`00LQ<005TC00<@4a<03a<200lC00<=41<0

cQ<01@dC4a<0078C001H4`0341<C010C00<04a<03Q<00`dC403>4`043A<C4`80LA<005PC00<@4a<0

41<00`0C4`0?4`033A<@0<hC00@=4a<0LQ<005LC00<@4a<04A<00`0C4`0?4`033A<@0<8C00<04a<0

0Q<00`0C4`024`0301<=008C00<04a<0L1<005HC00<@4a<04Q<2014C00<=4a00`1<00`0C00074`04

01<03@8C00<04a<0L1<005HC00<@4a<04Q<00`0C4`0A4`033A<@0;lC00<04`002A<0100=4a<2074C

001E4`0341<C01<C00<04a<04A<00`dC402o4`0301<000LC0P001A<=4a<0078C001D4`0341<C01@C

00<04a<04Q<00`dC402n4`0301<000LC00L04a<C3A<0078C001C4`0341<C01DC0P0D4`033A0C0;hC

00<04a<01Q<300044`dC078C001C4`0341<C01DC00<04a<04a<00`dC403;4`033A<0078C001B4`03

41<C01HC00<04a<051<00`dC403:4`043A<0074C001A4`0341<C01LC00<04a<05A<00`d@4`3:4`03

3@0C074C001A4`0341<C01LC0P0F4`033A<@0<XC00<=01<0LA<0050C00<@4a<061<00`0C4`0F4`03

3A0C0<XC00<=4a<0L1<004lC00<@4a<021<5008C00<04a<00Q<00`0C4`024`0301<C01LC00<=41<0

bA<00`d04`1`4`00Ca<00a0C4`0:4`0301<C00HC00<04`000a<00`0C4`0H4`033A0C0<PC00<03A<0

L1<004hC00<@4a<02a<00`0C4`084`0401<C4`806A<00`dC40384`0300dC070C001=4`0341<C00`C

00<04a<01Q<200@C00<04a<06A<00`d@4`374`0301<=070C001<4`0341<C00dC00<04a<01Q<00`0C

4`034`0301<C01XC00<=41<0aQ<00`0C3@1`4`00C1<00a0C4`0<4`8021<300<C00<04a<06Q<00`dC

40364`8000<C3A<0KQ<004/C00<@4a<07A<201`C00<=4a00aA<01@0C4a<=06hC001:4`0341<C01hC

00<04a<06a<00`dC40354`0501<C4`d0KQ<004XC00<@4a<07Q<00`0C4`0L4`033A<@0<@C00<04a<0

0Q<00`dC4`1[4`00BA<00a0C4`0O4`0301<C01dC00<=4a00`a<200<C00<=4a<0Ja<004PC00<@4a<0

81<201hC00@=4a<@`Q<00`0C4`034`033A<C06XC00174`0341<C024C00<04a<07Q<010dC4a314`03

01<C00@C00<=4a<0JA<004LC00<@4a<08A<00`0C4`0N4`043A<C4;XC1@024`0301<C00DC00<=4a<0

J1<004HC00<@4a<08Q<00`0C4`0O4`043A<C4;/C00<04a<00Q<00`0C4`054`033A<C06PC00154`03

41<C02<C0P0Q4`043A<C4;XC00<04a<00Q<200LC00<=4a<0Ia<004@C00<@4a<091<00`0C4`0P4`05

3A<C4a00^A<00`0C4`024`0301<C00LC00<=4a<0IQ<004@C00<@4a<091<00`0C4`0Q4`043A<C4;TC

00<04a<00Q<00`0C4`084`033A<C06DC00134`0341<C02DC00<04a<08Q<010dC4a2g4`8011<00`0C

4`094`033A<C06@C00124`0341<C02HC00<04a<08Q<01@dC4a<@0;`C00<04a<02Q<00`dC4`1S4`00

@A<00a0C4`0W4`8091<01@dC4a<@0;/C0P0<4`033A<C068C00104`0341<C02PC00<04a<091<01@dC

4a<@0;XC00<04a<031<00`dC4`1Q4`00@1<00a0C4`0R4`<00a<00`0C4`0U4`053A<C4a00^A<00`0C

4`0=4`033A<C060C000o4`0341<C02<C00<04a<00a<00`0C4`0U4`053A<C4a00^A<00`0C4`0>4`8=

H1<003hC00<@4a<09A<00`0C4`024`809a<01@dC4a<@0;PC0P0A4`033A<C05dC000m4`0341<C02HC

00<04a<00Q<00`0C4`0W4`053A<C4a00]a<00`0C4`0A4`033A<C05`C000m4`0341<C02DC00<04`00

0a<00`0C4`0W4`033A<C008C00<@4a<0]1<00`0C4`0B4`033A<C05/C000l4`0341<C02LC00<04a<0

0Q<00`0C4`0X4`033A<C008C00<@4a<0/a<00`0C4`0C4`033A<C05XC000k4`0341<C02dC0P0Z4`03

3A<C008C00<@4a<0/Q<00`0C4`0D4`8=FQ<003XC00<@4a<0;Q<00`0C4`0Y4`033A<C008C00<@4a<0

/Q<201LC00<=4a<0Ea<003XC00<@4a<0;Q<00`0C4`0Z4`033A<C008C00<@4a<0/A<00`0C4`0G4`03

3A<C05HC000i4`0341<C02lC00<04a<0:Q<00`dC4`034`0341<C0;0C00<04a<061<00`dC4`1E4`00

>1<00a0C4`0`4`80;1<00`dC4`034`0341<C0:lC00<04a<06A<23EDC000g4`0341<C034C00<04a<0

;1<00`dC4`024`0341<C0:lC0P0L4`033A<C058C000g4`0341<C034C00<04a<0;1<00`dC4`034`03

41<C0:hC00<04a<071<00`dC4`1A4`00=Q<00a0C4`0b4`0301<C02dC00<=4a<00a<00a0C4`2]4`03

01<C01dC0PeA4`00=A<00a0C4`0c4`80;a<00`dC4`034`0341<C09/C1@024`0301<C008C00<04a<0

0Q<00`0C4`0O4`033A<C04hC000d4`0341<C03@C00<04a<0;Q<00`dC4`044`0341<C09`C00<04a<0

1Q<00`0C00034`0301<C020C0Pe>4`00<a<00a0C4`0e4`0301<C02lC00<=4a<011<00a0C4`2K4`03

01<C00PC00@04a<C0P0S4`033A<C04/C000b4`0341<C03HC00<04a<0<1<00`dC4`034`0341<C09/C

00<04a<01Q<200@C00<04a<08a<23D/C000a4`0341<C03LC0P0a4`033A<C00@C00<@4a<0VQ<00`0C

4`064`0301<C00<C00<04a<09A<23DTC000`4`0341<C03PC00<04a<0<A<00`dC4`044`0341<C09PC

0P084`<00a<00`0C4`0W4`8=Aa<002lC00<@4a<0:A<300<C00<04a<00Q<00`0C4`024`0301<C038C

00<=4a<011<00a0C4`2W4`80:Q<00`dC4`144`00;Q<00a0C4`0Z4`0301<C00LC00<04`000a<00`0C

4`0c4`033A<C00@C00<@4a<0YQ<00`0C4`0Z4`8=A1<002dC00<@4a<0;1<00`0C4`084`0401<C4`80

=1<00`dC4`054`0341<C0:DC00<04a<0;1<00`dC4`114`00;1<00a0C4`0]4`0301<C00HC0P044`03

01<C03@C00<=4a<01A<00a0C4`2T4`0301<C02dC0Pe14`00:a<00a0C4`0]4`0301<000LC00<04a<0

0a<00`0C4`0e4`033A<C00DC00<@4a<0Xa<00`0C4`0_4`033A<C03hC000Z4`0341<C02lC00<04a<0

1Q<300<C00<04a<0=A<00`dC4`064`0341<C0:8C0P0a4`8=?Q<002TC00<@4a<0?a<203LC00<=4a<0

1Q<00a0C4`2Q4`0301<C038C0Pdl4`00:1<00a0C4`104`0301<C03LC00<=4a<01Q<00a0C4`2P4`03

01<C03@C0Pdj4`009a<00a0C4`114`0301<C03LC00<=4a<01a<00a0C4`2O4`0301<C03HC0Pdh4`00

9Q<00a0C4`124`0301<C03PC00<=4a<01a<00a0C4`2N4`80>A<23CHC000U4`0341<C04<C0P0i4`03

3A<C00PC00<@4a<0WA<00`0C4`0j4`8==1<002@C00<@4a<0A1<00`0C4`0i4`033A<C00PC00<@4a<0

W1<00`0C4`0l4`8=<Q<002<C00<@4a<0AA<00`0C4`0j4`033A<C00PC00<@4a<0Va<00`0C4`0n4`8=

<1<002<C00<@4a<0AA<00`0C4`0j4`033A<C00TC00<@4a<0VQ<00`0C4`104`8=;Q<0028C00<@4a<0

AQ<203`C00<=4a<02A<00a0C4`2I4`80@a<33B/C000Q4`0341<C04LC00<04a<0?1<00`dC4`094`03

41<C09PC00<04a<0AA<23BTC000P4`0341<C04PC00<04a<0?1<00`dC4`0:4`0341<C09LC00<04a<0

Aa<00`dC4`0V4`007a<00a0C4`194`0301<C03dC00<=4a<02Q<00a0C4`2@4`<00a<00`0C4`184`8=

9Q<001hC00<@4a<0BQ<203lC00<=4a<02Q<00a0C4`2?4`0301<C00<C00<04a<0BQ<00`dC4`0S4`00

7A<00a0C4`1;4`0301<C03hC00<=4a<02a<00a0C4`2?4`0301<C008C0P1<4`8=8a<001`C00<@4a<0

C1<00`0C4`0o4`033A<C00/C00<@4a<0SQ<00`0C4`024`0301<C04dC0`dP4`006a<00a0C4`174`80

11<00`0C4`104`033A<C00/C00<@4a<0S1<00`0C00034`0301<C050C10dL4`006Q<00a0C4`1:4`05

01<C4`00@Q<00`dC4`0<4`0341<C08`C00<04a<00Q<00`0C4`1D4`8=6Q<001TC00<@4a<0BQ<00`0C

4`024`80@Q<00`dC4`0;4`0341<C094C0P1G4`8=61<006LC00<04a<0ia<00`0C4`1H4`033A<C01DC

001U4`0301<00>TC00<04a<0L1<006HC00<04a<0j1<00`0C4`1`4`00:Q<30?lC9A<00`0C4`1`4`00

:Q<00`0C4`3o4bDC0P1a4`00:a<00`0C4`044`0301<C0?lCT1<002/C00@04a<C10034`<0oa><4`00

:Q<00`0C00024`8000<C01<011<00`0C4`3o4hXC000[4`0301<C00<C00<04`000a<00`0C4`3o4h/C

000a4`0301<000@C00<04a<01Q<00`0C4`0W4`<0:a<00`0C4`3o4bTC000K4`<000<C00000P0<4`<0

11<300PC00<04a<09Q<0100C4`0?4`<000<C00000P024`0301<C008C00<04a<00Q<00`0C4`054`04

01<C4`D00Q<00`0C4`024`0301<C00D00Q<00`0C4`044`80aA<00`0C4`0g4`0301<C00HC000J4`04

01<C02@C00<04a<09A<0100C4`0>4`0401<C00HC00<04`001a<00`0C00044`D00a<00`0C4`064`03

01<000<C00L04a<C01<000@C00<04a<0_A<00`0C4`044`0301<C01<C00<04a<08a<00`0C4`054`00

6Q<01@0C4`0C00@000<C0000600]4`<03Q<01@0C4`0C00@000@C01<02A<00`0C4`044`0301<C00<C

00<04a<021<01@0C4a<000DC00<04a<00Q<00`0C4`2[4`0401<C4`@00Q<200HC00<04a<00a<00`0C

4`024`0301<C008C00<04a<00Q<00`0C4`054`0401<C4`D00Q<00`0C4`024`0301<C00D00Q<00`0C

4`044`8011<0100C4a<2004C000K4`<0Ca<00`0C4`0=4`<01Q<00`0C00074`801a<00`0C4`034`03

01<C00HC0P044`0401<C4`801A<00`0C4`2Z4`0301<000LC00<04a<011<500<C00L04a<C01<000LC

00<04`0011<500<C00<04a<01Q<00`0C00034`0701<C4`0C00044`0301<C00@C00<04a<00Q<1004C

000M4`0301<C04`C0P0A4`0301<C00@C00<04`001a<00`0C4`0<4`0301<C00HC00<04a<00a<01@0C

4a<000HC00<04`00ZQ<00`0C00024`@000<C01<01a<00`0C4`034`0701<C4`0C00094`0301<C00@C

00<04a<00a<00`0C4`084`0501<C4`001A<00`0C4`024`0301<C00@C00<04a<00a<1000071<2060C

0P074`0301<C00HC0`0;4`8021<3008C0P034`<011<309<C0P000a<0000B4`0301<000LC00<04a<0

1Q<00`0C4`034`0701<C4`0C00074`801a<00`0C4`034`0301<C00HC0P044`0401<C4`801A<00`0C

4`044`0301<C00<C0@000?lCDA<00`0C000C4`0301<000LC00<04`003A<01P0C4`0C00LC00<04a<0

31<00`0C4`064`0301<C00<C00D04a<C00064`0301<000<C00<04a<00a<1004C000V4`801Q<20?lC

8Q<00`0C4`0C4`0301<C00HC0`0>4`0401<C00PC0`0;4`8021<3008C0P034`<011<3008C00<04a<0

0a<2004C000X4`0301<C008C00<04a<0oa<R4`0301<C070C000W4`0301<C00<C00<04a<01Q<00`0C

4`3o4aPC00<04`00LA<002PC00<04a<00Q<00`0C4`024`<000@C01<C0`3o4a@C0P000a<0001`4`00

9Q<00`0C00044`0301<0008C0P024`0301<C008C00<04a<0oa>74`009a<00`0C4`034`<011<0100C

4`024`0301<C0?lCR1<003@C00@04a<00a<00`0C4`3o4hLC000b4`<011<30?lCRA<00?lCaA<00?lC

aA<00?lCaA<00?lCaA<00?lCaA<00001\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.40873, -1.70577, 0.0219457, 0.0219457}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -82 0 ]

[.5 .96488 82 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -143 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.51) show

217.250000 19.500000 moveto

(C) show

222.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.26348 0 m

.30316 .05991 L

.34309 .1202 L

.3815 .17821 L

.42237 .23992 L

.46172 .29933 L

.49955 .35647 L

.53984 .4173 L

.57861 .47585 L

.61984 .53809 L

.65954 .59805 L

.69774 .65573 L

.73838 .7171 L

.77751 .77619 L

.81909 .83898 L

.85916 .89948 L

s

.85916 .89948 m

.8942 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.371155 0.238095 [

[.02381 .35865 -6 -9 ]

[.02381 .35865 6 0 ]

[.2619 .35865 -6 -9 ]

[.2619 .35865 6 0 ]

[.7381 .35865 -3 -9 ]

[.7381 .35865 3 0 ]

[.97619 .35865 -3 -9 ]

[.97619 .35865 3 0 ]

[1.025 .37115 0 -8 ]

[1.025 .37115 9 8 ]

[.4875 .01401 -24 -4.5 ]

[.4875 .01401 0 4.5 ]

[.4875 .13306 -12 -4.5 ]

[.4875 .13306 0 4.5 ]

[.4875 .25211 -24 -4.5 ]

[.4875 .25211 0 4.5 ]

[.4875 .4902 -18 -4.5 ]

[.4875 .4902 0 4.5 ]

[.4875 .60925 -6 -4.5 ]

[.4875 .60925 0 4.5 ]

[.4875 .7283 -18 -4.5 ]

[.4875 .7283 0 4.5 ]

[.4875 .84735 -6 -4.5 ]

[.4875 .84735 0 4.5 ]

[.5 .92066 -4.5 0 ]

[.5 .92066 4.5 16 ]

[.5 .90816 -134.5 0 ]

[.5 .90816 134.5 16 ]

[ 0 0 0 0 ]

[ 1 .89566 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .37115 m

.02381 .3774 L

s

[(-2)] .02381 .35865 0 1 Mshowa

.2619 .37115 m

.2619 .3774 L

s

[(-1)] .2619 .35865 0 1 Mshowa

.7381 .37115 m

.7381 .3774 L

s

[(1)] .7381 .35865 0 1 Mshowa

.97619 .37115 m

.97619 .3774 L

s

[(2)] .97619 .35865 0 1 Mshowa

.125 Mabswid

.07143 .37115 m

.07143 .3749 L

s

.11905 .37115 m

.11905 .3749 L

s

.16667 .37115 m

.16667 .3749 L

s

.21429 .37115 m

.21429 .3749 L

s

.30952 .37115 m

.30952 .3749 L

s

.35714 .37115 m

.35714 .3749 L

s

.40476 .37115 m

.40476 .3749 L

s

.45238 .37115 m

.45238 .3749 L

s

.54762 .37115 m

.54762 .3749 L

s

.59524 .37115 m

.59524 .3749 L

s

.64286 .37115 m

.64286 .3749 L

s

.69048 .37115 m

.69048 .3749 L

s

.78571 .37115 m

.78571 .3749 L

s

.83333 .37115 m

.83333 .3749 L

s

.88095 .37115 m

.88095 .3749 L

s

.92857 .37115 m

.92857 .3749 L

s

.25 Mabswid

0 .37115 m

1 .37115 L

s

gsave

1.025 .37115 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .01401 m

.50625 .01401 L

s

[(-1.5)] .4875 .01401 1 0 Mshowa

.5 .13306 m

.50625 .13306 L

s

[(-1)] .4875 .13306 1 0 Mshowa

.5 .25211 m

.50625 .25211 L

s

[(-0.5)] .4875 .25211 1 0 Mshowa

.5 .4902 m

.50625 .4902 L

s

[(0.5)] .4875 .4902 1 0 Mshowa

.5 .60925 m

.50625 .60925 L

s

[(1)] .4875 .60925 1 0 Mshowa

.5 .7283 m

.50625 .7283 L

s

[(1.5)] .4875 .7283 1 0 Mshowa

.5 .84735 m

.50625 .84735 L

s

[(2)] .4875 .84735 1 0 Mshowa

.125 Mabswid

.5 .03782 m

.50375 .03782 L

s

.5 .06163 m

.50375 .06163 L

s

.5 .08544 m

.50375 .08544 L

s

.5 .10925 m

.50375 .10925 L

s

.5 .15687 m

.50375 .15687 L

s

.5 .18068 m

.50375 .18068 L

s

.5 .20449 m

.50375 .20449 L

s

.5 .2283 m

.50375 .2283 L

s

.5 .27592 m

.50375 .27592 L

s

.5 .29973 m

.50375 .29973 L

s

.5 .32354 m

.50375 .32354 L

s

.5 .34735 m

.50375 .34735 L

s

.5 .39496 m

.50375 .39496 L

s

.5 .41877 m

.50375 .41877 L

s

.5 .44258 m

.50375 .44258 L

s

.5 .46639 m

.50375 .46639 L

s

.5 .51401 m

.50375 .51401 L

s

.5 .53782 m

.50375 .53782 L

s

.5 .56163 m

.50375 .56163 L

s

.5 .58544 m

.50375 .58544 L

s

.5 .63306 m

.50375 .63306 L

s

.5 .65687 m

.50375 .65687 L

s

.5 .68068 m

.50375 .68068 L

s

.5 .70449 m

.50375 .70449 L

s

.5 .75211 m

.50375 .75211 L

s

.5 .77592 m

.50375 .77592 L

s

.5 .79973 m

.50375 .79973 L

s

.5 .82354 m

.50375 .82354 L

s

.5 .87115 m

.50375 .87115 L

s

.5 .89496 m

.50375 .89496 L

s

.25 Mabswid

.5 0 m

.5 .89566 L

s

gsave

.5 .92066 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .90816 -195.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.51) show

293.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

298.000000 15.000000 moveto

(L) show

305.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

312.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

319.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

324.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

328.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .89566 L

0 .89566 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .21096 m

.02576 .21096 L

.03157 .21093 L

.04115 .21089 L

.05433 .21083 L

.07088 .21076 L

.09053 .21066 L

.11294 .21054 L

.13771 .21039 L

.16444 .21022 L

.19265 .21001 L

.22188 .20977 L

.25161 .20948 L

.28135 .20915 L

.31057 .20877 L

.33879 .20833 L

.36552 .20783 L

.39029 .20728 L

.4127 .20669 L

.43234 .20607 L

.4489 .20546 L

.46208 .2049 L

.47166 .20444 L

.47747 .20415 L

.47942 .20404 L

s

.47942 .20404 m

.48154 .20393 L

.48788 .20356 L

.49833 .20291 L

.5127 .20187 L

.53075 .20028 L

.55217 .19784 L

.5766 .19405 L

.60361 .1881 L

.63275 .17909 L

.66352 .16674 L

.69538 .1519 L

.7278 .13587 L

.76023 .11968 L

.79209 .10398 L

.82286 .08918 L

.852 .07552 L

.87901 .06319 L

.90344 .05231 L

.92486 .04297 L

.94291 .03525 L

.95728 .02918 L

.96773 .02483 L

.97407 .0222 L

.97619 .02133 L

s

.47942 .45465 m

.48154 .42766 L

.48788 .40089 L

.49833 .37458 L

.5127 .34895 L

.53075 .3243 L

.55217 .30105 L

.5766 .27982 L

.60361 .26152 L

.63275 .24718 L

.66352 .23716 L

.69538 .23071 L

.7278 .22664 L

.76023 .224 L

.79209 .22221 L

.82286 .22096 L

.852 .22006 L

.87901 .21939 L

.90344 .21889 L

.92486 .21852 L

.94291 .21824 L

.95728 .21804 L

.96773 .2179 L

.97407 .21783 L

.97619 .2178 L

s

.47942 .45477 m

.48154 .48188 L

.48788 .50901 L

.49833 .53598 L

.5127 .56264 L

.53075 .58888 L

.55217 .61457 L

.5766 .63959 L

.60361 .66384 L

.63275 .6872 L

.66352 .70957 L

.69538 .73085 L

.7278 .75095 L

.76023 .76979 L

.79209 .78727 L

.82286 .80332 L

.852 .81788 L

.87901 .83088 L

.90344 .84226 L

.92486 .85197 L

.94291 .85998 L

.95728 .86624 L

.96773 .87073 L

.97407 .87344 L

.97619 .87434 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCaA<00?lCDQ<00`0C4`1`4`00I1<50=LC1@024`0301<C008C00<04a<00Q<00`0C4`1`4`00

IQ<00`0C4`3I4`0301<C00HC00<04`000a<00`0C4`1`4`00@a<00`dC4`0J4`<00a<00`0C4`024`80

ca<300<C00<04a<021<0100C4a<2074C00144`033A<C01lC00<04a<00Q<00`0C4`3D4`0301<C00HC

0P044`0301<C05PC00<=4a<05A<004@C00<=4a<07a<00`0C4`024`0301<C0=@C00<04a<01Q<00`0C

4`034`0301<C05LC0PdG4`00AA<00`dC4`0M4`8011<00`0C4`3C4`8021<300<C00<04a<0E1<33ATC

00154`033A<C02<C0P3T4`0301<C058C0PdL4`00AQ<00`dC4`0R4`0301<C0><C0P1A4`8=7Q<004LC

00<=4a<08A<00`0C4`3S4`0301<C04dC0`dP4`00Aa<00`dC4`0Q4`0301<C0><C00<04a<0BQ<33B<C

00184`033A<C020C0P3T4`0301<C04PC0PdV4`00B1<00`dC4`0P4`0301<C0><C0P174`8=:1<004TC

00<=4a<07a<00`0C4`3S4`0301<C04@C0PdZ4`00BQ<00`dC4`0N4`0301<C0><C00<04a<0@Q<23B`C

001:4`033A<C01hC0P3T4`0301<C040C0Pd^4`00Ba<00`dC4`0M4`0301<C0><C00<04a<0?A<33C0C

001<4`033A<C01`C00<04a<0ha<203`C0Pdc4`00C1<00`dC4`0L4`0301<C0><C00<04a<0>A<23CDC

001=4`033A<C01/C0P3T4`0301<C03LC0Pdg4`00CA<00`dC4`0K4`0301<C0><C00<04a<0=A<23CTC

001>4`033A<C00/C00<04a<00Q<00`0C4`024`0301<C008C00<04a<0ha<203@C0Pdk4`00Ca<00`dC

4`094`0301<000LC00<04`000a<00`0C4`3S4`0301<C034C0Pdm4`00Ca<00`dC4`044`<00Q<00`0C

00094`0401<C4`80i1<00`0C4`0_4`8=?a<0050C00<=4a<021<00`0C00074`8011<00`0C4`3L4`D0

0Q<00`0C4`0]4`8=@A<0054C00<=4a<01a<00`0C00074`0301<C00<C00<04a<0gQ<00`0C4`024`03

01<C02/C0Pe34`00DA<00`dC4`084`0301<C00HC0`034`0301<C0=PC0`034`0301<C008C0P0Z4`8=

AA<0058C00<=4a<05Q<00`0C4`3N4`0301<C008C00<04a<09a<23DLC001C4`033A<C01DC0P3O4`03

01<C008C00<04a<09A<23DTC001C4`033A<C01DC00<04a<0gA<200@C00<04a<08Q<33D/C001D4`03

3A<C01@C00<04a<0ha<2024C0Pe>4`00EA<00`dC4`0C4`0301<C0><C00<04a<07Q<23E0C001F4`03

3A<C018C0P3T4`0301<C01`C0PeB4`00EQ<00`dC4`0B4`0301<C0><C00<04a<06Q<23E@C000J4`<0

9A<5010C00<=4a<04A<00`0C4`0T4`D091<309<C00<04a<061<23EHC000J4`0301<C02LC00<04a<0

4A<00`dC4`0@4`0301<C02HC00<04a<091<00`0C4`2C4`805Q<33EPC000E4`<00a<00`0C4`0P4`<0

0a<00`0C4`0A4`033A<C010C0P0W4`0301<C02DC00<04a<0TQ<00`0C4`0@4`D=Fa<001/C00<04a<0

9Q<00`0C4`0B4`033A<C00lC00<04a<09Q<00`0C4`0U4`0301<C098C00<04a<03Q<23F0C000J4`03

01<002LC00<04a<04a<00`dC4`0>4`0301<C02HC00<04a<091<00`0C002C4`0301<C00HC20eR4`00

6a<00`0C4`0U4`805A<00`dC4`0>4`0301<C02DC0P0W4`0301<C08hC3@eZ4`00Fa<00`dC4`0=4`80

/a<]3@@C0P1a4`00G1<00`dC4`0<4`0301<C08PC:Pda4`0301<C070C001M4`033A<C00/C00<04a<0

Fa<208HC00<04a<0A1<E3ALC001M4`033A<C00/C00<04a<0FQ<00`0C4`264`0301<C02dC5`d/4`00

5A=900033@0006401Q<00`0C4`264`80:1<63D<C000I4`0301<C00HC00<04a<01A<00`0C4`054`03

01<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<01@0C4a<=00<C00<04a<01A<00a0C

4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC

00<04a<01A<00`0C4`054`0301<C00PC00<04a<0QQ<00`0C4`0P4`L=BA<005lC00<=4a<02A<00a0C

4`1J4`0301<008HC00<04a<06a<53E0C001P4`033A<C00PC0Q1K4`<0Ma<00`0C4`024`0301<C008C

00<04a<00Q<00`0C4`0I4`8=EA<0064C00<=4a<01a<24=@C00<04`001a<00`0C00034`0301<C01HC

0`eG4`00HA<00`dC4`064`03400@0<lC0`024`0301<000TC00@04a<C0P0D4`<=FQ<0068C00<=4a<0

1A<00a00403D4`0301<000LC0P044`0301<C014C0PeM4`00Ha<00`dC4`044`03400@0=@C00<04`00

1a<00`0C4`034`0301<C010C00<=4a<0GA<006@C00<=4a<00Q<01A0C000@0=@C00<04a<01Q<300<C

00<04a<03Q<23F0C001T4`033A<C008C00D@4`0C403S4`803Q<00`dC4`1P4`00IA<02@dC4a<@4`0C

403S4`0301<C00`C00<=4a<0HA<006HC00H=4a<@4`024`0341<C0>0C00<04a<02a<00`dC4`1R4`00

IQ<01@dC4a0C008000<C41<0hA<00`0C4`094`8=IA<006LC00D=4a0C00024`0341<C0>0C00<04a<0

21<00`dC4`1U4`00Ia<01@d@4a<000<C00<@4a<0ga<200PC00<=4a<0IQ<006PC00@=4a<00a<00a0C

4`3O4`0301<C00HC00<=4a<0Ia<006PC00<@3A<00P024`0341<C0=lC00<04a<01A<00`dC4`1X4`00

Ia<01A0C3A<000@C00<@4a<0Q1<302TC1@0Y4`0301<C00@C00<=4a<08A<502XC0`0F4`00G1<00`0C

4`024`0301<C008C00H041<C3@044`0341<C08@C00<04a<0:a<00`0C4`0Y4`8011<00`dC4`0T4`03

01<C02XC00<04a<05Q<005/C00<04`001a<00`0@00024`033@0C00<C00<@4a<0Oa<300<C00<04a<0

91<300<C00<04a<0:A<00`0C4`024`033A<C02DC00<04a<0:a<00`0C4`0E4`00Fa<00`0C00084`03

400C008C00<=01<00a<00a0C4`244`0301<C02XC00<04a<0:A<00`0C4`024`033A<C02DC00<04a<0

:a<00`0C4`0E4`00Fa<00`0C00074`03010C00<C00<03A<00a<00a0C4`234`0301<002/C00<04a<0

:A<01@0C4a<=02PC00<04a<0:Q<00`0C000F4`00Fa<00`0C00074`0341<C00<C00<03A<011<00a0C

4`234`0301<C02TC0P0[4`0501<C4`d09a<202dC00<04a<05A<005`C00<04a<01Q<00a0000034`03

01<=00@C00<@4a<0g1<200034`dC06hC001T4`0341<C00@C0P000a<=4`024`0341<C0=`C00<04`d0

L1<006@C00<@4a<011<0100C4`d44`0341<C0=/C00<04`d0IQ<200PC001S4`0341<C00DC00D04a<C

3@034`0341<C0=/C00<03A<0IA<00`0C4`084`00Ha<00a0C4`054`0501<C4`d011<00a0C4`1j4f40

00<=0000G@074`0301<C00PC001R4`0341<C00HC00<04a<00Q<01@dC4a<@084C00<04a<01Q<00`0C

4`064`0301<C00HC00<04a<01Q<00`0C4`064`0301<C00LC00<04a<01Q<00`0C4`064`0301<C00HC

00<04a<01Q<00`dC4`064`0301<C00HC00<04a<01Q<00`0C4`074`0301<C00HC00<04a<01Q<00`0C

4`064`0301<C00HC00<04a<01Q<00`0C4`064`0301<C00XC00<04a<021<0068C00<@4a<01Q<200@C

00D=4a<C40204`0301<C02XC00<04a<0:a<00`dC4`0[4`0301<C02XC00<04a<02Q<00`0C00084`00

HA<00a0C4`074`0301<C00<C00D=4a<C403J4`033@0C06HC0`084`00HA<00a0C4`074`0301<C00@C

00@=4a<@fQ<00`d04`1a4`00H1<00a0C4`084`0301<C00DC00@=4a<@f1<010dC001a4`00H1<00a0C

4`084`801Q<010dC4a3H4`033A<0078C001O4`0341<C00TC00<04a<01Q<010dC4a3G4`033A<0078C

001O4`0341<C00TC00<04a<01a<00`dC403G4`033A<0078C001N4`0341<C00XC00<04a<01a<010dC

4a3E4`043A<C078C001N4`0341<C00XC0P094`033A<@0=DC00<=4a<00P1a4`00GA<00a0C4`0;4`03

01<C00TC00<=4a00e1<010dC4`1b4`00GA<00a0C4`044`D00Q<00`0C4`0:4`033A0C0=<C00@=4a<0

LQ<005`C00<@4a<01a<00`0C4`024`0301<C00XC00<=4a00da<010dC4`1b4`00Fa<00a0C4`084`03

01<C008C0P0<4`033A<@0=4C00@=4a<C0P1a4`00Fa<00a0C4`084`0301<C008C00<04a<031<00`d@

4`3@4`053A<C4`00LQ<005XC00<@4a<02A<00`0C4`024`0301<C00`C00<=4a00d1<01@dC4a<0078C

001J4`0341<C00PC0P044`0301<C00dC00<=4a00ca<01@dC4a<0078C001I4`0341<C00lC0P0?4`03

3A0C0<hC00D=4a<C001b4`00F1<00a0C4`0@4`0301<C00hC00<=4a00cQ<010dC4a<2074C001H4`03

41<C010C00<04a<03a<00`dC403>4`043A<C078C001G4`0341<C014C00<04a<041<00`d@4`314`03

01<C008C00<04a<00Q<00`0C3@024`0301<C070C001F4`0341<C018C0P0B4`033A0C0;lC00<04`00

1a<0100C00d24`0301<C070C001F4`0341<C018C00<04a<04A<00`dC402o4`0301<000TC00@03A<C

0P1a4`00EA<00a0C4`0C4`0301<C018C00<=41<0_Q<00`0C00074`8000DC3A<C001b4`00E1<00a0C

4`0D4`0301<C01<C00<=41<0_A<00`0C00074`0701<C4`dC001b4`00Da<00a0C4`0E4`8051<00`d@

4`2n4`0301<C00HC0`0011<=4`1b4`00Da<00a0C4`0E4`0301<C01@C00<=41<0bQ<00`dC001b4`00

DQ<00a0C4`0F4`0301<C01DC00<=41<0bA<010dC001a4`00DA<00a0C4`0G4`0301<C01DC00<=41<0

bQ<00`d04`1a4`00DA<00a0C4`0G4`805a<00`d@4`394`033@0C074C001@4`0341<C01PC00<04a<0

5Q<00`d@4`3:4`033A<C070C001?4`0341<C00PC1@024`0301<C008C00<04a<00Q<00`0C4`0G4`03

3A0C0<TC00<=01<0L1<004lC00<@4a<02Q<00`0C4`064`0301<000<C00<04a<061<00`d@4`384`03

00dC070C001>4`0341<C00/C00<04a<021<0100C4a<201TC00<=4a00b1<00`0=4`1`4`00CA<00a0C

4`0<4`0301<C00HC0P044`0301<C01TC00<=41<0aa<00`0C3@1`4`00C1<00a0C4`0=4`0301<C00HC

00<04a<00a<00`0C4`0J4`033A0C0<HC00<04`d0L1<004`C00<@4a<031<200PC0`034`0301<C01XC

00<=4a00aQ<200034`dC06hC001;4`0341<C01dC0P0L4`033A<@0<DC00D04a<C3@1^4`00BQ<00a0C

4`0N4`0301<C01/C00<=4a00aA<01@0C4a<=06hC001:4`0341<C01hC00<04a<071<00`dC40344`03

01<C008C00<=4a<0Ja<004TC00<@4a<07a<00`0C4`0M4`033A<@0<<C0P034`033A<C06/C00184`03

41<C020C0P0N4`043A<C4<8C00<04a<00a<00`dC4`1Z4`00Aa<00a0C4`0Q4`0301<C01hC00@=4a<@

`A<00`0C4`044`033A<C06TC00174`0341<C024C00<04a<07Q<010dC4a2j4`D00Q<00`0C4`054`03

3A<C06PC00164`0341<C028C00<04a<07a<010dC4a2k4`0301<C008C00<04a<01A<00`dC4`1X4`00

AA<00a0C4`0S4`808A<010dC4a2j4`0301<C008C0P074`033A<C06LC00144`0341<C02@C00<04a<0

81<01@dC4a<@0;TC00<04a<00Q<00`0C4`074`033A<C06HC00144`0341<C02@C00<04a<08A<010dC

4a2i4`0301<C008C00<04a<021<00`dC4`1U4`00@a<00a0C4`0U4`0301<C028C00@=4a<@]a<200@C

00<04a<02A<00`dC4`1T4`00@Q<00a0C4`0V4`0301<C028C00D=4a<C402l4`0301<C00XC00<=4a<0

Ha<0044C00<@4a<09a<202@C00D=4a<C402k4`8031<00`dC4`1R4`00@1<00a0C4`0X4`0301<C02@C

00D=4a<C402j4`0301<C00`C00<=4a<0HA<0040C00<@4a<08Q<300<C00<04a<09A<01@dC4a<@0;TC

00<04a<03A<00`dC4`1P4`00?a<00a0C4`0S4`0301<C00<C00<04a<09A<01@dC4a<@0;TC00<04a<0

3Q<00`dC4`1O4`00?Q<00a0C4`0U4`0301<C008C0P0W4`053A<C4a00^1<2010C00<=4a<0GQ<003dC

00<@4a<09Q<00`0C4`024`0301<C02LC00D=4a<C402g4`0301<C010C00<=4a<0GA<003dC00<@4a<0

9A<00`0C00034`0301<C02LC00<=4a<00Q<00a0C4`2d4`0301<C014C00<=4a<0G1<003`C00<@4a<0

9a<00`0C4`024`0301<C02PC00<=4a<00Q<00a0C4`2c4`0301<C018C0PeL4`00>a<00a0C4`0]4`80

:Q<00`dC4`024`0341<C0;8C00<04a<051<00`dC4`1I4`00>Q<00a0C4`0^4`0301<C02TC00<=4a<0

0Q<00a0C4`2b4`805Q<23ETC000j4`0341<C02hC00<04a<0:Q<00`dC4`024`0341<C0;4C00<04a<0

5a<00`dC4`1F4`00>A<00a0C4`0_4`0301<C02/C00<=4a<00Q<00a0C4`2`4`0301<C01PC00<=4a<0

EA<003PC00<@4a<0<1<202dC00<=4a<00Q<00a0C4`2_4`0301<C01TC0PeE4`00=a<00a0C4`0a4`03

01<C02`C00<=4a<00Q<00a0C4`2_4`8071<00`dC4`1B4`00=a<00a0C4`0a4`0301<C02dC00<=4a<0

0Q<00a0C4`2^4`0301<C01`C00<=4a<0DA<003HC00<@4a<0<Q<00`0C4`0^4`033A<C008C00<@4a<0

[A<00`0C4`0M4`8=DA<003DC00<@4a<0<a<202lC00<=4a<00a<00a0C4`2K4`D00Q<00`0C4`024`03

01<C008C00<04a<07a<23DlC000d4`0341<C03@C00<04a<0;a<00`dC4`034`0341<C09`C00<04a<0

1Q<00`0C00034`0301<C024C0Pe=4`00<a<00a0C4`0e4`0301<C030C00<=4a<00a<00a0C4`2K4`03

01<C00PC00@04a<C0P0T4`033A<C04XC000b4`0341<C03HC00<04a<0<1<00`dC4`034`0341<C09/C

00<04a<01Q<200@C00<04a<091<23DXC000a4`0341<C03LC0P0b4`033A<C00<C00<@4a<0VQ<00`0C

4`064`0301<C00<C00<04a<09Q<00`dC4`174`00<1<00a0C4`0h4`0301<C034C00<=4a<011<00a0C

4`2H4`8021<300<C00<04a<09a<23DLC000_4`0341<C02TC0`034`0301<C008C00<04a<00Q<00`0C

4`0b4`033A<C00@C00<@4a<0Ya<202XC00<=4a<0A1<002hC00<@4a<0:Q<00`0C4`074`0301<000<C

00<04a<0<a<00`dC4`044`0341<C0:HC00<04a<0:Q<23D@C000]4`0341<C02`C00<04a<021<0100C

4a<203@C00<=4a<01A<00a0C4`2U4`0301<C02`C00<=4a<0@A<002`C00<@4a<0;A<00`0C4`064`80

11<00`0C4`0d4`033A<C00DC00<@4a<0Y1<00`0C4`0]4`8=@A<002/C00<@4a<0;A<00`0C00074`03

01<C00<C00<04a<0=A<00`dC4`054`0341<C0:<C00<04a<0;a<00`dC4`0n4`00:Q<00a0C4`0_4`03

01<C00HC0`034`0301<C03DC00<=4a<01Q<00a0C4`2R4`80<A<23ChC000Y4`0341<C03lC0P0g4`03

3A<C00HC00<@4a<0XA<00`0C4`0b4`8=?1<002PC00<@4a<0@1<00`0C4`0g4`033A<C00HC00<@4a<0

X1<00`0C4`0d4`8=>Q<002LC00<@4a<0@A<00`0C4`0g4`033A<C00LC00<@4a<0Wa<00`0C4`0f4`8=

>1<002HC00<@4a<0@Q<00`0C4`0h4`033A<C00LC00<@4a<0WQ<00`0C4`0h4`8==Q<002DC00<@4a<0

@a<203XC00<=4a<01a<00a0C4`2M4`80>a<23C@C000T4`0341<C04@C00<04a<0>Q<00`dC4`074`03

41<C09`C00<04a<0?1<23C8C000S4`0341<C04DC00<04a<0>Q<00`dC4`084`0341<C09/C00<04a<0

?Q<23C0C000S4`0341<C04DC00<04a<0>a<00`dC4`084`0341<C09XC00<04a<0@1<33BdC000R4`03

41<C04HC0P0m4`033A<C00PC00<@4a<0VA<204@C0Pd[4`008A<00a0C4`174`0301<C03`C00<=4a<0

2A<00a0C4`2H4`0301<C04DC0PdY4`0081<00a0C4`184`0301<C03dC00<=4a<02A<00a0C4`2G4`03

01<C04LC00<=4a<09Q<001lC00<@4a<0BA<00`0C4`0m4`033A<C00XC00<@4a<0T1<300<C00<04a<0

B1<23BHC000N4`0341<C04XC0P0o4`033A<C00XC00<@4a<0Sa<00`0C4`034`0301<C04XC00<=4a<0

8a<001dC00<@4a<0Ba<00`0C4`0o4`033A<C00XC00<@4a<0Sa<00`0C4`024`80C1<23B<C000L4`03

41<C04`C00<04a<0?a<00`dC4`0;4`0341<C08hC00<04a<00Q<00`0C4`1=4`<=81<001/C00<@4a<0

Aa<200@C00<04a<0@1<00`dC4`0;4`0341<C08`C00<04`000a<00`0C4`1@4`@=71<001XC00<@4a<0

BQ<01@0C4a<0048C00<=4a<031<00a0C4`2<4`0301<C008C00<04a<0E1<23AXC000I4`0341<C04XC

00<04a<00Q<2048C00<=4a<02a<00a0C4`2A4`80Ea<23APC001W4`0301<C0>LC00<04a<0F1<00`dC

4`0E4`00IA<00`0C003Y4`0301<C070C001V4`0301<C0>PC00<04a<0L1<002`C0`3o4b<C00<04a<0

L1<002`C00<04a<0oa<S4`80LA<002dC00<04a<01A<00`0C4`3o4hdC000]4`0401<C4`<000@C01<C

0`3o4hXC000/4`0301<0008C0P024`0301<C008C00<04a<0oa>84`00;A<00`0C4`034`0401<C008C

00<04a<0oa>94`00<a<0100C4`034`0301<C00HC00<04a<09A<302dC00<04a<0oa<W4`007A<30003

4`00008031<300@C0`084`0301<C02@C00@04a<04A<300034`0000800Q<00`0C4`024`0301<C008C

00<04a<01A<0100C4a<5008C00<04a<00Q<00`0C4`0500@C0P3;4`0301<C038C00<04a<021<001`C

00@04a<091<00`0C4`0S4`0401<C010C00@04a<01Q<00`0C00074`0301<000@C1@034`0301<C00HC

00<04`000a<00`0C4`034`0301<C0<<C00<04a<011<00`0C4`0C4`0301<C01hC00<04a<01a<001`C

00D04a<04`0400034`0001P0:a<3010C00D04a<04`0400044`0C00TC00<04a<011<00`0C4`034`03

01<C00PC00D04a<C00054`0301<C0;4C00@04a<C10024`801Q<00`0C4`034`0301<C008C00<04a<0

0Q<00`0C4`024`0301<C00DC00@04a<C1@024`0301<C008C00<04a<01@044`8011<0100C4a<2004C

0@0100007A<304dC00<04a<03a<300HC00<04`001a<200LC00<04a<00a<00`0C4`064`8011<00`0C

4`034`0301<C0;0C00<04`001a<00`0C4`044`D00a<01`0C4a<04`001a<00`0C00044`D00a<00`0C

4`064`0301<000<C00<04a<00a<00`0C4`044`0301<C008C00<04`000A<001lC00<04a<0BQ<201<C

00<04a<011<00`0C00074`0301<C00`C00<04a<01Q<00`0C4`034`0301<C00<C00<04`00/1<00`0C

00024`@000<C01<01a<00`0C4`034`0701<C4`0C00094`0301<C00@C00<04a<00a<00`0C4`084`05

01<C4`001A<00`0C4`044`0301<C00<C0@014`4C000N4`80H1<200LC00<04a<01Q<300/C0P084`<0

0Q<200DC0`2F4`8000<C00005A<00`0C00074`0301<C00HC00<04a<00a<01`0C4a<04`001a<200LC

00<04a<00a<00`0C4`064`8011<00`0C4`034`0301<C00@C00<04a<00a<1004C0A<00?lCDA<00`0C

000F4`0301<000LC00<04`003A<01P0C4`0C00LC00<04a<031<00`0C4`064`0301<C00<C00<04a<0

0a<00`0C00034`0301<C00<C00<04`000A<002TC0P064`80oa<O4`0301<C01HC00<04a<01Q<300hC

00@04a<021<300/C0P084`<00Q<200DC0`024`0301<C00<C0P014`400@0002/C00<04a<00Q<00`0C

4`3o4alC00<04a<0L1<002XC00<04a<00a<00`0C4`054`0301<C0?lC5Q<00`0C001a4`00:a<00`0C

4`024`0301<C008C10034`<0oa<A4`8000<C0000L1<002TC00<04`0011<00`0C00024`8000<C01<0

11<00`0C4`3o4h@C000Z4`0301<C00<C0`044`0301<000<C00<04a<0oa>54`00=a<00`0C00044`03

01<C0?lCQ1<003DC0`044`<0oa>64`00oa?54`00oa?54`00oa?54`00oa?54`00oa?54`00\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.40416, -1.70564, 0.0219322, 0.0219322}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -84.5 0 ]

[.5 .96488 84.5 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -145.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.505) show

222.250000 19.500000 moveto

(C) show

227.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.2627 0 m

.30316 .06089 L

.34309 .12099 L

.3815 .1788 L

.42237 .2403 L

.46172 .29953 L

.49955 .35647 L

.53984 .4171 L

.57861 .47545 L

.61984 .5375 L

.65954 .59726 L

.69774 .65474 L

.73838 .71591 L

.77751 .7748 L

.81909 .83738 L

.85916 .89768 L

s

.85916 .89768 m

.89551 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.369924 0.238095 [

[.02381 .35742 -6 -9 ]

[.02381 .35742 6 0 ]

[.2619 .35742 -6 -9 ]

[.2619 .35742 6 0 ]

[.7381 .35742 -3 -9 ]

[.7381 .35742 3 0 ]

[.97619 .35742 -3 -9 ]

[.97619 .35742 3 0 ]

[1.025 .36992 0 -8 ]

[1.025 .36992 9 8 ]

[.4875 .01278 -24 -4.5 ]

[.4875 .01278 0 4.5 ]

[.4875 .13183 -12 -4.5 ]

[.4875 .13183 0 4.5 ]

[.4875 .25088 -24 -4.5 ]

[.4875 .25088 0 4.5 ]

[.4875 .48897 -18 -4.5 ]

[.4875 .48897 0 4.5 ]

[.4875 .60802 -6 -4.5 ]

[.4875 .60802 0 4.5 ]

[.4875 .72707 -18 -4.5 ]

[.4875 .72707 0 4.5 ]

[.4875 .84611 -6 -4.5 ]

[.4875 .84611 0 4.5 ]

[.5 .91888 -4.5 0 ]

[.5 .91888 4.5 16 ]

[.5 .90638 -137 0 ]

[.5 .90638 137 16 ]

[ 0 0 0 0 ]

[ 1 .89388 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .36992 m

.02381 .37617 L

s

[(-2)] .02381 .35742 0 1 Mshowa

.2619 .36992 m

.2619 .37617 L

s

[(-1)] .2619 .35742 0 1 Mshowa

.7381 .36992 m

.7381 .37617 L

s

[(1)] .7381 .35742 0 1 Mshowa

.97619 .36992 m

.97619 .37617 L

s

[(2)] .97619 .35742 0 1 Mshowa

.125 Mabswid

.07143 .36992 m

.07143 .37367 L

s

.11905 .36992 m

.11905 .37367 L

s

.16667 .36992 m

.16667 .37367 L

s

.21429 .36992 m

.21429 .37367 L

s

.30952 .36992 m

.30952 .37367 L

s

.35714 .36992 m

.35714 .37367 L

s

.40476 .36992 m

.40476 .37367 L

s

.45238 .36992 m

.45238 .37367 L

s

.54762 .36992 m

.54762 .37367 L

s

.59524 .36992 m

.59524 .37367 L

s

.64286 .36992 m

.64286 .37367 L

s

.69048 .36992 m

.69048 .37367 L

s

.78571 .36992 m

.78571 .37367 L

s

.83333 .36992 m

.83333 .37367 L

s

.88095 .36992 m

.88095 .37367 L

s

.92857 .36992 m

.92857 .37367 L

s

.25 Mabswid

0 .36992 m

1 .36992 L

s

gsave

1.025 .36992 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .01278 m

.50625 .01278 L

s

[(-1.5)] .4875 .01278 1 0 Mshowa

.5 .13183 m

.50625 .13183 L

s

[(-1)] .4875 .13183 1 0 Mshowa

.5 .25088 m

.50625 .25088 L

s

[(-0.5)] .4875 .25088 1 0 Mshowa

.5 .48897 m

.50625 .48897 L

s

[(0.5)] .4875 .48897 1 0 Mshowa

.5 .60802 m

.50625 .60802 L

s

[(1)] .4875 .60802 1 0 Mshowa

.5 .72707 m

.50625 .72707 L

s

[(1.5)] .4875 .72707 1 0 Mshowa

.5 .84611 m

.50625 .84611 L

s

[(2)] .4875 .84611 1 0 Mshowa

.125 Mabswid

.5 .03659 m

.50375 .03659 L

s

.5 .0604 m

.50375 .0604 L

s

.5 .08421 m

.50375 .08421 L

s

.5 .10802 m

.50375 .10802 L

s

.5 .15564 m

.50375 .15564 L

s

.5 .17945 m

.50375 .17945 L

s

.5 .20326 m

.50375 .20326 L

s

.5 .22707 m

.50375 .22707 L

s

.5 .27469 m

.50375 .27469 L

s

.5 .2985 m

.50375 .2985 L

s

.5 .3223 m

.50375 .3223 L

s

.5 .34611 m

.50375 .34611 L

s

.5 .39373 m

.50375 .39373 L

s

.5 .41754 m

.50375 .41754 L

s

.5 .44135 m

.50375 .44135 L

s

.5 .46516 m

.50375 .46516 L

s

.5 .51278 m

.50375 .51278 L

s

.5 .53659 m

.50375 .53659 L

s

.5 .5604 m

.50375 .5604 L

s

.5 .58421 m

.50375 .58421 L

s

.5 .63183 m

.50375 .63183 L

s

.5 .65564 m

.50375 .65564 L

s

.5 .67945 m

.50375 .67945 L

s

.5 .70326 m

.50375 .70326 L

s

.5 .75088 m

.50375 .75088 L

s

.5 .77469 m

.50375 .77469 L

s

.5 .7985 m

.50375 .7985 L

s

.5 .8223 m

.50375 .8223 L

s

.5 .86992 m

.50375 .86992 L

s

.5 .89373 m

.50375 .89373 L

s

.25 Mabswid

.5 0 m

.5 .89388 L

s

gsave

.5 .91888 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .90638 -198 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.505) show

298.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

303.000000 15.000000 moveto

(L) show

310.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

317.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

324.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

329.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

333.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .89388 L

0 .89388 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .20932 m

.02576 .20931 L

.03157 .20929 L

.04115 .20925 L

.05433 .20919 L

.07088 .20912 L

.09053 .20903 L

.11293 .20891 L

.13771 .20877 L

.16443 .20861 L

.19265 .20841 L

.22187 .20818 L

.2516 .20791 L

.28134 .20759 L

.31056 .20723 L

.33877 .20681 L

.3655 .20634 L

.39027 .20582 L

.41268 .20525 L

.43232 .20467 L

.44888 .20409 L

.46206 .20356 L

.47163 .20313 L

.47745 .20285 L

.4794 .20275 L

s

.4794 .20275 m

.48152 .20264 L

.48786 .20229 L

.4983 .20167 L

.51267 .20069 L

.53073 .19918 L

.55215 .19687 L

.57658 .19325 L

.60359 .18753 L

.63274 .17875 L

.6635 .16657 L

.69537 .15181 L

.72779 .1358 L

.76022 .11961 L

.79208 .10391 L

.82285 .08911 L

.85199 .07546 L

.87901 .06313 L

.90344 .05225 L

.92486 .04292 L

.94291 .03519 L

.95728 .02914 L

.96773 .02478 L

.97407 .02216 L

.97619 .02128 L

s

.4794 .45346 m

.48152 .42648 L

.48786 .39971 L

.4983 .37339 L

.51267 .34774 L

.53073 .32305 L

.55215 .2997 L

.57658 .27833 L

.60359 .25984 L

.63274 .24529 L

.6635 .23513 L

.69537 .22864 L

.72779 .22457 L

.76022 .22196 L

.79208 .2202 L

.82285 .21897 L

.85199 .21809 L

.87901 .21744 L

.90344 .21695 L

.92486 .21659 L

.94291 .21632 L

.95728 .21612 L

.96773 .21599 L

.97407 .21592 L

.97619 .21589 L

s

.4794 .45357 m

.48152 .48066 L

.48786 .50777 L

.4983 .53471 L

.51267 .56134 L

.53073 .58754 L

.55215 .6132 L

.57658 .63819 L

.60359 .6624 L

.63274 .68573 L

.6635 .70807 L

.69537 .72932 L

.72779 .7494 L

.76022 .7682 L

.79208 .78566 L

.82285 .80169 L

.85199 .81623 L

.87901 .8292 L

.90344 .84057 L

.92486 .85027 L

.94291 .85826 L

.95728 .86451 L

.96773 .869 L

.97407 .8717 L

.97619 .8726 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCaA<00?lCaA<006@C1@3G4`D00Q<00`0C4`024`0301<C008C00<04a<0L1<006HC00<04a<0

fA<00`0C4`064`0301<000<C00<04a<0L1<0048C00<=4a<06a<300<C00<04a<00Q<20<lC0`034`03

01<C00PC00@04a<C0P1a4`00@a<00`dC4`0P4`0301<C008C00<04a<0e1<00`0C4`064`8011<00`0C

4`1`4`00@a<00`dC4`0P4`0301<C008C00<04a<0e1<00`0C4`064`0301<C00<C00<04a<0Ea<23ALC

00144`033A<C01hC0P044`0301<C0=<C0P084`<00a<00`0C4`1D4`<=6A<004DC00<=4a<08a<20>@C

00<04a<0DQ<23A`C00154`033A<C02<C00<04a<0ha<2054C0PdN4`00AQ<00`dC4`0R4`0301<C0><C

00<04a<0CQ<23B0C00164`033A<C028C00<04a<0ha<00`0C4`1<4`8=8Q<004LC00<=4a<08A<20>@C

00<04a<0BQ<23B@C00184`033A<C020C00<04a<0ha<204TC0PdV4`00B1<00`dC4`0P4`0301<C0><C

00<04a<0AA<33BPC00194`033A<C01lC00<04a<0ha<00`0C4`134`8=:a<004XC00<=4a<07Q<20>@C

00<04a<0@A<23BdC001:4`033A<C01hC00<04a<0ha<00`0C4`0o4`8=;a<004/C00<=4a<07A<00`0C

4`3S4`80?Q<23C4C001<4`033A<C01`C00<04a<0ha<00`0C4`0k4`8=<a<004`C00<=4a<071<20>@C

00<04a<0>A<23CDC001=4`033A<C01/C00<04a<0ha<00`0C4`0g4`8==a<004hC00<=4a<02a<00`0C

4`024`0301<C008C00<04a<00Q<00`0C4`3S4`80=Q<23CTC001?4`033A<C00TC00<04`001a<00`0C

00034`0301<C0><C00<04a<0<a<23C/C001?4`033A<C00@C0`024`0301<000TC00@04a<C0P3T4`03

01<C034C0Pdm4`00D1<00`dC4`084`0301<000LC0P044`0301<C0=`C1@024`0301<C02lC0Pdo4`00

DA<00`dC4`074`0301<000LC00<04a<00a<00`0C4`3N4`0301<C008C00<04a<0;A<23D4C001A4`03

3A<C00PC00<04a<01Q<300<C00<04a<0f1<300<C00<04a<00Q<202`C0Pe34`00DQ<00`dC4`0F4`03

01<C0=hC00<04a<00Q<00`0C4`0Y4`8=AA<005<C00<=4a<05A<20=lC00<04a<00Q<00`0C4`0W4`8=

Aa<005<C00<=4a<05A<00`0C4`3M4`8011<00`0C4`0U4`8=BA<005@C00<=4a<051<00`0C4`3S4`80

8a<33D/C001E4`033A<C01<C00<04a<0ha<00`0C4`0P4`8=CQ<005HC00<=4a<04Q<20>@C00<04a<0

7Q<23E0C001F4`033A<C018C00<04a<0ha<00`0C4`0K4`<=DQ<001XC0`0U4`D041<00`dC4`0A4`03

01<C02@C1@0T4`<0Ta<00`0C4`0I4`8=EA<001XC00<04a<09a<00`0C4`0A4`033A<C010C00<04a<0

9Q<00`0C4`0T4`0301<C09<C0P0G4`<=Ea<001DC0`034`0301<C020C0`034`0301<C014C00<=4a<0

41<202LC00<04a<09A<00`0C4`2B4`0301<C01<C0`eJ4`006a<00`0C4`0V4`0301<C018C00<=4a<0

3a<00`0C4`0V4`0301<C02DC00<04a<0TQ<00`0C4`0?4`@=GA<001XC00<04`009a<00`0C4`0C4`03

3A<C00hC00<04a<09Q<00`0C4`0T4`0301<009<C00<04a<01Q<93F4C000K4`0301<C02DC0P0E4`03

3A<C00hC00<04a<09A<202LC00<04a<0SQ<=3FXC001K4`033A<C00dC0P2b4bh=11<2074C001L4`03

3A<C00`C00<04a<0R1<Y3C8C00<04a<0L1<005dC00<=4a<02a<00`0C4`1K4`80QQ<00`0C4`0o4aX=

5a<005dC00<=4a<02a<00`0C4`1J4`0301<C08HC00<04a<0;A<B3C4C000E4dT000<=0000H@064`03

01<C08HC0P0S4`/=@a<001TC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`03

01<C00DC00<04a<01Q<00`0C4`054`0501<C4`d00a<00`0C4`054`0341<C00DC00<04a<01Q<00`0C

4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC

00<04a<021<00`0C4`264`0301<C01hC10e>4`00Ga<00`dC4`094`0341<C05XC00<04`00QQ<00`0C

4`0K4`<=DQ<0060C00<=4a<021<245/C0`1g4`0301<C008C00<04a<00Q<00`0C4`024`0301<C01TC

0PeE4`00HA<00`dC4`074`8@e1<00`0C00074`0301<000<C00<04a<05Q<33ELC001Q4`033A<C00HC

00<@0100ca<3008C00<04`002A<0100C4a<201@C0`eJ4`00HQ<00`dC4`054`03400@0=@C00<04`00

1a<200@C00<04a<04A<23EdC001S4`033A<C00@C00<@0100e1<00`0C00074`0301<C00<C00<04a<0

41<00`dC4`1M4`00I1<00`dC4`024`0541<00100e1<00`0C4`064`<00a<00`0C4`0>4`8=H1<006@C

00<=4a<00Q<01A0C01<@0><C0P0>4`033A<C060C001U4`093A<C4a0C01<@0><C00<04a<031<00`dC

4`1Q4`00IQ<01PdC4a0C008C00<@4a<0h1<00`0C4`0;4`033A<C068C001V4`053A<C41<00P000a<@

4`3Q4`0301<C00TC0PeU4`00Ia<01@dC41<0008C00<@4a<0h1<00`0C4`084`033A<C06DC001W4`05

3A0C4`000a<00a0C4`3O4`8021<00`dC4`1V4`00J1<010dC4`034`0341<C0=lC00<04a<01Q<00`dC

4`1W4`00J1<00a0=4`02008C00<@4a<0ga<00`0C4`054`033A<C06PC001W4`0541<=4`0011<00a0C

4`244`<0:A<502TC00<04a<01A<00`dC4`0P4`D0:Q<301HC001L4`0301<C008C00<04a<00Q<01P0@

4a<=00@C00<@4a<0Q1<00`0C4`0[4`0301<C02TC0P054`033A<C02<C00<04a<0:Q<00`0C4`0F4`00

Fa<00`0C00074`030100008C00<=01<00a<00a0C4`1o4`<00a<00`0C4`0T4`<00a<00`0C4`0Y4`03

01<C00<C00<=4a<091<00`0C4`0[4`0301<C01DC001K4`0301<000PC00<@01<00Q<00`d04`034`03

41<C08@C00<04a<0:Q<00`0C4`0Y4`0301<C008C00<=4a<09A<00`0C4`0[4`0301<C01DC001K4`03

01<000LC00<041<00a<00`0=4`034`0341<C08<C00<04`00:a<00`0C4`0Y4`0501<C4`d0:1<00`0C

4`0Z4`0301<001HC001K4`0301<000LC00<@4a<00a<00`0=4`044`0341<C08<C00<04a<0:A<202/C

00D04a<C3@0W4`80;A<00`0C4`0E4`00G1<00`0C4`064`03400000<C00<04`d011<00a0C4`3L4`80

00<C3A<0KQ<006@C00<@4a<011<200034`dC008C00<@4a<0g1<00`0C3@1`4`00I1<00a0C4`044`04

01<C3@@C00<@4a<0fa<00`0C3@1V4`8021<006<C00<@4a<01A<01@0C4a<=00<C00<@4a<0fa<00`0=

4`1U4`0301<C00PC001S4`0341<C00DC00D04a<C3@044`0341<C07XCH@000`d0001M00LC00<04a<0

21<0068C00<@4a<01Q<00`0C4`024`053A<C4a00PA<00`0C4`064`0301<C00HC00<04a<01Q<00`0C

4`064`0301<C00HC00<04a<01a<00`0C4`064`0301<C00HC00<04a<01Q<00`0C4`064`033A<C00HC

00<04a<01Q<00`0C4`064`0301<C00LC00<04a<01Q<00`0C4`064`0301<C00HC00<04a<01Q<00`0C

4`064`0301<C00HC00<04a<02Q<00`0C4`084`00HQ<00a0C4`064`8011<01@dC4a<@080C00<04a<0

:Q<00`0C4`0[4`033A<C02/C00<04a<0:Q<00`0C4`0:4`0301<000PC001Q4`0341<C00LC00<04a<0

0a<01@dC4a<@0=XC00<=01<0IQ<300PC001Q4`0341<C00LC00<04a<011<010dC4a3J4`033@0C074C

001P4`0341<C00PC00<04a<01A<010dC4a3H4`043A<0074C001P4`0341<C00PC0P064`043A<C4=PC

00<=4`00LQ<005lC00<@4a<02A<00`0C4`064`043A<C4=LC00<=4`00LQ<005lC00<@4a<02A<00`0C

4`074`033A<@0=LC00<=4`00LQ<005hC00<@4a<02Q<00`0C4`074`043A<C4=DC00@=4a<0LQ<005hC

00<@4a<02Q<200TC00<=4a00eA<00`dC4`02074C001M4`0341<C00/C00<04a<02A<00`dC403D4`04

3A<C078C001M4`0341<C00@C1@024`0301<C00XC00<=41<0da<010dC4`1b4`00G1<00a0C4`074`03

01<C008C00<04a<02Q<00`dC403C4`043A<C078C001K4`0341<C00PC00<04a<00Q<200`C00<=4a00

dA<010dC4a<2074C001K4`0341<C00PC00<04a<00Q<00`0C4`0<4`033A0C0=0C00D=4a<C001b4`00

FQ<00a0C4`094`0301<C008C00<04a<031<00`dC403@4`053A<C4`00LQ<005XC00<@4a<021<200@C

00<04a<03A<00`dC403?4`053A<C4`00LQ<005TC00<@4a<03a<200lC00<=41<0cQ<01@dC4a<0078C

001H4`0341<C010C00<04a<03Q<00`dC403>4`043A<C4`80LA<005PC00<@4a<041<00`0C4`0?4`03

3A<@0<hC00@=4a<0LQ<005LC00<@4a<04A<00`0C4`0@4`033A0C0<4C00<04a<00Q<00`0C4`024`03

01<=008C00<04a<0L1<005HC00<@4a<04Q<2018C00<=41<0_a<00`0C00074`0401<03@8C00<04a<0

L1<005HC00<@4a<04Q<00`0C4`0A4`033A<@0;lC00<04`002A<0100=4a<2074C001E4`0341<C01<C

00<04a<04Q<00`d@4`2n4`0301<000LC0P001A<=4a<0078C001D4`0341<C01@C00<04a<04a<00`d@

4`2m4`0301<000LC00L04a<C3A<0078C001C4`0341<C01DC0P0D4`033A0C0;hC00<04a<01Q<30004

4`dC078C001C4`0341<C01DC00<04a<051<00`d@4`3:4`033A<0078C001B4`0341<C01HC00<04a<0

5A<00`d@4`394`043A<0074C001A4`0341<C01LC00<04a<05A<00`d@4`3:4`033@0C074C001A4`03

41<C01LC0P0G4`033A0C0<TC00<=01<0LA<0050C00<@4a<061<00`0C4`0F4`033A0C0<XC00<=4a<0

L1<004lC00<@4a<021<5008C00<04a<00Q<00`0C4`024`0301<C01LC00<=41<0bA<00`d04`1`4`00

Ca<00a0C4`0:4`0301<C00HC00<04`000a<00`0C4`0H4`033A0C0<PC00<03A<0L1<004hC00<@4a<0

2a<00`0C4`084`0401<C4`806A<00`dC40384`0300dC070C001=4`0341<C00`C00<04a<01Q<200@C

00<04a<06A<00`d@4`374`0301<=070C001<4`0341<C00dC00<04a<01Q<00`0C4`034`0301<C01XC

00<=41<0aQ<00`0C3@1`4`00C1<00a0C4`0<4`8021<300<C00<04a<06Q<00`dC40364`8000<C3A<0

KQ<004/C00<@4a<07A<201`C00<=4a00aA<01@0C4a<=06hC001:4`0341<C01hC00<04a<071<00`d@

4`344`0501<C4`d0KQ<004XC00<@4a<07Q<00`0C4`0L4`033A<@0<@C00<04a<00Q<00`dC4`1[4`00

BA<00a0C4`0O4`0301<C01dC00<=4a00`a<00`0C4`024`033A<C06/C00184`0341<C020C0P0O4`03

3A<@0<8C0P044`033A<C06XC00174`0341<C024C00<04a<07Q<010dC4a314`0301<C00@C00<=4a<0

JA<004LC00<@4a<08A<00`0C4`0O4`033A<@0;XC1@024`0301<C00DC00<=4a<0J1<004HC00<@4a<0

8Q<00`0C4`0P4`033A<@0;/C00<04a<00Q<00`0C4`054`033A<C06PC00154`0341<C02<C0P0Q4`04

3A<C4;XC00<04a<00Q<200LC00<=4a<0Ia<004@C00<@4a<091<00`0C4`0Q4`043A<C4;TC00<04a<0

0Q<00`0C4`074`033A<C06HC00144`0341<C02@C00<04a<08Q<00`dC402i4`0301<C008C00<04a<0

21<00`dC4`1U4`00@a<00a0C4`0U4`0301<C028C00@=4a<@]a<200@C00<04a<02A<00`dC4`1T4`00

@Q<00a0C4`0V4`0301<C02<C00@=4a<@_1<00`0C4`0:4`033A<C06<C00114`0341<C02LC0P0T4`05

3A<C4a00^a<200`C00<=4a<0HQ<0040C00<@4a<0:1<00`0C4`0T4`053A<C4a00^Q<00`0C4`0<4`03

3A<C064C00104`0341<C028C0`034`0301<C02DC00D=4a<C402i4`0301<C00dC00<=4a<0H1<003lC

00<@4a<08a<00`0C4`034`0301<C02DC00D=4a<C402i4`0301<C00hC00<=4a<0Ga<003hC00<@4a<0

9A<00`0C4`024`809a<01@dC4a<@0;PC0P0@4`033A<C05hC000m4`0341<C02HC00<04a<00Q<00`0C

4`0W4`053A<C4a00]a<00`0C4`0@4`033A<C05dC000m4`0341<C02DC00<04`000a<00`0C4`0W4`03

3A<C008C00<@4a<0]1<00`0C4`0A4`033A<C05`C000l4`0341<C02LC00<04a<00Q<00`0C4`0X4`03

3A<C008C00<@4a<0/a<00`0C4`0B4`8=G1<003/C00<@4a<0;A<202XC00<=4a<00Q<00a0C4`2b4`03

01<C01@C00<=4a<0FA<003XC00<@4a<0;Q<00`0C4`0Y4`033A<C008C00<@4a<0/Q<201HC0PeI4`00

>Q<00a0C4`0^4`0301<C02XC00<=4a<00Q<00a0C4`2a4`0301<C01LC00<=4a<0EQ<003TC00<@4a<0

;a<00`0C4`0[4`033A<C008C00<@4a<0/1<00`0C4`0H4`033A<C05DC000h4`0341<C030C0P0]4`03

3A<C008C00<@4a<0[a<00`0C4`0I4`8=EA<003LC00<@4a<0<A<00`0C4`0/4`033A<C008C00<@4a<0

[a<201`C00<=4a<0DQ<003LC00<@4a<0<A<00`0C4`0]4`033A<C008C00<@4a<0[Q<00`0C4`0L4`03

3A<C054C000f4`0341<C038C00<04a<0;Q<00`dC4`024`0341<C0:dC00<04a<07A<23E4C000e4`03

41<C03<C0P0_4`033A<C00<C00<@4a<0Va<5008C00<04a<00Q<00`0C4`024`0301<C01lC0Pe?4`00

=1<00a0C4`0d4`0301<C02lC00<=4a<00a<00a0C4`2L4`0301<C00HC00<04`000a<00`0C4`0Q4`8=

CA<003<C00<@4a<0=A<00`0C4`0`4`033A<C00<C00<@4a<0Va<00`0C4`084`0401<C4`8091<00`dC

4`1:4`00<Q<00a0C4`0f4`0301<C030C00<=4a<00a<00a0C4`2K4`0301<C00HC0P044`0301<C02@C

0Pe:4`00<A<00a0C4`0g4`80<Q<00`dC4`034`0341<C09XC00<04a<01Q<00`0C4`034`0301<C02HC

00<=4a<0Aa<0030C00<@4a<0>1<00`0C4`0a4`033A<C00@C00<@4a<0V1<200PC0`034`0301<C02LC

0Pe74`00;a<00a0C4`0Y4`<00a<00`0C4`024`0301<C008C00<04a<0<Q<00`dC4`044`0341<C0:LC

0P0Z4`033A<C04@C000^4`0341<C02XC00<04a<01a<00`0C00034`0301<C03<C00<=4a<011<00a0C

4`2V4`0301<C02XC0Pe44`00;A<00a0C4`0/4`0301<C00PC00@04a<C0P0d4`033A<C00DC00<@4a<0

YA<00`0C4`0/4`033A<C044C000/4`0341<C02dC00<04a<01Q<200@C00<04a<0=1<00`dC4`054`03

41<C0:@C00<04a<0;A<23D4C000[4`0341<C02dC00<04`001a<00`0C4`034`0301<C03DC00<=4a<0

1A<00a0C4`2S4`0301<C02lC00<=4a<0?Q<002XC00<@4a<0;a<00`0C4`064`<00a<00`0C4`0e4`03

3A<C00HC00<@4a<0XQ<2034C0Pdn4`00:A<00a0C4`0o4`80=a<00`dC4`064`0341<C0:4C00<04a<0

<Q<23C`C000X4`0341<C040C00<04a<0=a<00`dC4`064`0341<C0:0C00<04a<0=1<23CXC000W4`03

41<C044C00<04a<0=a<00`dC4`074`0341<C09lC00<04a<0=Q<23CPC000V4`0341<C048C00<04a<0

>1<00`dC4`074`0341<C09hC00<04a<0>1<23CHC000U4`0341<C04<C0P0j4`033A<C00LC00<@4a<0

WA<203/C0Pdd4`0091<00a0C4`144`0301<C03XC00<=4a<01a<00a0C4`2L4`0301<C03`C0Pdb4`00

8a<00a0C4`154`0301<C03XC00<=4a<021<00a0C4`2K4`0301<C03hC0Pd`4`008a<00a0C4`154`03

01<C03/C00<=4a<021<00a0C4`2J4`0301<C040C0Pd^4`008Q<00a0C4`164`80?A<00`dC4`084`03

41<C09TC0P134`8=;1<0024C00<@4a<0Aa<00`0C4`0l4`033A<C00TC00<@4a<0V1<00`0C4`144`8=

:Q<0020C00<@4a<0B1<00`0C4`0m4`033A<C00TC00<@4a<0Ua<00`0C4`164`033A<C02LC000O4`03

41<C04TC00<04a<0?A<00`dC4`0:4`0341<C090C0`034`0301<C04LC0PdW4`007Q<00a0C4`1:4`80

?a<00`dC4`0:4`0341<C08lC00<04a<00a<00`0C4`194`<=91<001dC00<@4a<0Ba<00`0C4`0o4`03

3A<C00XC00<@4a<0Sa<00`0C4`024`80CA<23B8C000L4`0341<C04`C00<04a<0?a<00`dC4`0;4`03

41<C08hC00<04a<00Q<00`0C4`1>4`<=7a<001/C00<@4a<0Aa<200@C00<04a<0@1<00`dC4`0;4`03

41<C08`C00<04`000a<00`0C4`1A4`<=71<001XC00<@4a<0BQ<01@0C4a<0048C00<=4a<031<00a0C

4`2<4`0301<C008C00<04a<0E1<23AXC000I4`0341<C04XC00<04a<00Q<2048C00<=4a<02a<00a0C

4`2A4`80Ea<23APC001W4`0301<C0>LC00<04a<0F1<00`dC4`0E4`00IA<00`0C003Y4`0301<C070C

001V4`0301<C0>PC00<04a<0L1<002XC0`3o4bDC00<04a<0L1<002XC00<04a<0oa<U4`80LA<002/C

00<04a<011<00`0C4`3o4i0C000[4`0401<C4`@00a<30?lCS1<002XC00<04`000Q<200034`0C00@C

00<04a<0oa>:4`00:a<00`0C4`034`0301<000<C00<04a<0oa>;4`00<A<00`0C00044`0301<C00HC

00<04a<09a<302/C00<04a<0oa<Y4`006a<300034`00008031<300@C0`084`0301<C02HC00@04a<0

3a<300034`0000800Q<00`0C4`024`0301<C008C00<04a<01A<0100C4a<5008C00<04a<00Q<00`0C

4`024`0301<C008C00<04a<011<20<DC00<04a<0=a<00`0C4`064`006Q<0100C4`0T4`0301<C02DC

00@04a<03Q<0100C4`064`0301<000LC00<04`0011<500<C00<04a<01Q<00`0C00024`0301<0008C

00<04`0011<00`0C4`2m4`0301<C00@C00<04a<04a<00`0C4`0S4`0301<C00DC000J4`0501<C01<0

10000a<0000H02dC0`0>4`0501<C01<0100011<04`094`0301<C00@C00<04a<00a<00`0C4`084`06

01<C01<011<00`0C4`024`0301<C0:/C00@04a<C10024`801Q<00`0C4`034`0301<C008C00<04a<0

0Q<00`0C4`024`0301<C00DC00@04a<C1@024`0301<C008C00<04a<00Q<00`0C4`024`0301<C00@C

0P044`0401<C4`800A<001/C0`1?4`0301<C00dC0`064`0301<000LC0P074`0301<C00<C00<04a<0

1Q<200<C00<04`000Q<200DC00<04a<0ZQ<00`0C00074`0301<C00@C1@034`0701<C4`0C00074`03

01<000@C1@034`0301<C00HC00<04`000Q<00`0C00024`0301<000@C00<04a<011<00`0C4`024`40

0A<001dC00<04a<0C1<2014C00<04a<011<00`0C00074`0301<C00`C00<04a<01Q<00`0C4`024`03

01<0008C00<04a<011<00`0C002Z4`0301<0008C10000a<04`074`0301<C00<C00L04a<C01<000TC

00<04a<011<00`0C4`034`0301<C00PC00H04a<04`044`0301<C008C00<04a<011<00`0C4`034`40

000L4`80H1<200LC00<04a<01Q<300/C0P084`<00a<0100C4a<300@C0`2C4`8000<C00004Q<00`0C

00074`0301<C00HC00<04a<00a<01`0C4a<04`001a<200LC00<04a<00a<00`0C4`064`800a<00`0C

00024`801A<00`0C4`044`0301<C00<C0@000?lCDA<00`0C000C4`0301<000LC00<04`003A<01P0C

4`0C00LC00<04a<031<00`0C4`064`0301<C008C00<04`000Q<00`0C4`044`0301<000<C00<04a<0

0a<1004C000V4`801Q<20?lC8Q<00`0C4`0C4`0301<C00HC0`0>4`0401<C00PC0`0;4`8021<300<C

00@04a<C0`044`<00Q<00`0C4`034`800A<002PC00<04a<00Q<00`0C4`3o4b8C00<04a<0L1<002LC

00<04a<00a<00`0C4`064`0301<C0?lC61<00`0C001a4`00:1<00`0C4`024`0301<C008C0`0011<0

4a<30?lC51<200034`00070C000V4`0301<000@C00<04`000Q<2008C00<04a<00Q<00`0C4`3o4hLC

000W4`0301<C00<C0`044`0401<C008C00<04a<0oa>84`00=1<0100C4`034`0301<C0?lCQa<0038C

0`044`<0oa>94`00oa?54`00oa?54`00oa?54`00oa?54`00oa?54`00\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.39967, -1.70551, 0.0219189, 0.0219189}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -79.5 0 ]

[.5 .96488 79.5 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -140.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.5) show

212.250000 19.500000 moveto

(C) show

217.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.2619 0 m

.30316 .06188 L

.34309 .12177 L

.3815 .17939 L

.42237 .24069 L

.46172 .29972 L

.49955 .35647 L

.53984 .4169 L

.57861 .47506 L

.61984 .5369 L

.65954 .59646 L

.69774 .65375 L

.73838 .71472 L

.77751 .77341 L

.81909 .83578 L

.85916 .89588 L

s

.85916 .89588 m

.89683 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.368683 0.238095 [

[.02381 .35618 -6 -9 ]

[.02381 .35618 6 0 ]

[.2619 .35618 -6 -9 ]

[.2619 .35618 6 0 ]

[.7381 .35618 -3 -9 ]

[.7381 .35618 3 0 ]

[.97619 .35618 -3 -9 ]

[.97619 .35618 3 0 ]

[1.025 .36868 0 -8 ]

[1.025 .36868 9 8 ]

[.4875 .01154 -24 -4.5 ]

[.4875 .01154 0 4.5 ]

[.4875 .13059 -12 -4.5 ]

[.4875 .13059 0 4.5 ]

[.4875 .24964 -24 -4.5 ]

[.4875 .24964 0 4.5 ]

[.4875 .48773 -18 -4.5 ]

[.4875 .48773 0 4.5 ]

[.4875 .60678 -6 -4.5 ]

[.4875 .60678 0 4.5 ]

[.4875 .72583 -18 -4.5 ]

[.4875 .72583 0 4.5 ]

[.4875 .84487 -6 -4.5 ]

[.4875 .84487 0 4.5 ]

[.5 .91709 -4.5 0 ]

[.5 .91709 4.5 16 ]

[.5 .90459 -132 0 ]

[.5 .90459 132 16 ]

[ 0 0 0 0 ]

[ 1 .89209 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .36868 m

.02381 .37493 L

s

[(-2)] .02381 .35618 0 1 Mshowa

.2619 .36868 m

.2619 .37493 L

s

[(-1)] .2619 .35618 0 1 Mshowa

.7381 .36868 m

.7381 .37493 L

s

[(1)] .7381 .35618 0 1 Mshowa

.97619 .36868 m

.97619 .37493 L

s

[(2)] .97619 .35618 0 1 Mshowa

.125 Mabswid

.07143 .36868 m

.07143 .37243 L

s

.11905 .36868 m

.11905 .37243 L

s

.16667 .36868 m

.16667 .37243 L

s

.21429 .36868 m

.21429 .37243 L

s

.30952 .36868 m

.30952 .37243 L

s

.35714 .36868 m

.35714 .37243 L

s

.40476 .36868 m

.40476 .37243 L

s

.45238 .36868 m

.45238 .37243 L

s

.54762 .36868 m

.54762 .37243 L

s

.59524 .36868 m

.59524 .37243 L

s

.64286 .36868 m

.64286 .37243 L

s

.69048 .36868 m

.69048 .37243 L

s

.78571 .36868 m

.78571 .37243 L

s

.83333 .36868 m

.83333 .37243 L

s

.88095 .36868 m

.88095 .37243 L

s

.92857 .36868 m

.92857 .37243 L

s

.25 Mabswid

0 .36868 m

1 .36868 L

s

gsave

1.025 .36868 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .01154 m

.50625 .01154 L

s

[(-1.5)] .4875 .01154 1 0 Mshowa

.5 .13059 m

.50625 .13059 L

s

[(-1)] .4875 .13059 1 0 Mshowa

.5 .24964 m

.50625 .24964 L

s

[(-0.5)] .4875 .24964 1 0 Mshowa

.5 .48773 m

.50625 .48773 L

s

[(0.5)] .4875 .48773 1 0 Mshowa

.5 .60678 m

.50625 .60678 L

s

[(1)] .4875 .60678 1 0 Mshowa

.5 .72583 m

.50625 .72583 L

s

[(1.5)] .4875 .72583 1 0 Mshowa

.5 .84487 m

.50625 .84487 L

s

[(2)] .4875 .84487 1 0 Mshowa

.125 Mabswid

.5 .03535 m

.50375 .03535 L

s

.5 .05916 m

.50375 .05916 L

s

.5 .08297 m

.50375 .08297 L

s

.5 .10678 m

.50375 .10678 L

s

.5 .1544 m

.50375 .1544 L

s

.5 .17821 m

.50375 .17821 L

s

.5 .20202 m

.50375 .20202 L

s

.5 .22583 m

.50375 .22583 L

s

.5 .27345 m

.50375 .27345 L

s

.5 .29725 m

.50375 .29725 L

s

.5 .32106 m

.50375 .32106 L

s

.5 .34487 m

.50375 .34487 L

s

.5 .39249 m

.50375 .39249 L

s

.5 .4163 m

.50375 .4163 L

s

.5 .44011 m

.50375 .44011 L

s

.5 .46392 m

.50375 .46392 L

s

.5 .51154 m

.50375 .51154 L

s

.5 .53535 m

.50375 .53535 L

s

.5 .55916 m

.50375 .55916 L

s

.5 .58297 m

.50375 .58297 L

s

.5 .63059 m

.50375 .63059 L

s

.5 .6544 m

.50375 .6544 L

s

.5 .67821 m

.50375 .67821 L

s

.5 .70202 m

.50375 .70202 L

s

.5 .74964 m

.50375 .74964 L

s

.5 .77345 m

.50375 .77345 L

s

.5 .79725 m

.50375 .79725 L

s

.5 .82106 m

.50375 .82106 L

s

.5 .86868 m

.50375 .86868 L

s

.25 Mabswid

.5 0 m

.5 .89209 L

s

gsave

.5 .91709 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .90459 -193 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.5) show

288.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

293.000000 15.000000 moveto

(L) show

300.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

307.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

314.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

319.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

323.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .89209 L

0 .89209 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .20766 m

.02576 .20766 L

.03157 .20764 L

.04115 .2076 L

.05433 .20754 L

.07088 .20747 L

.09053 .20739 L

.11293 .20728 L

.1377 .20714 L

.16442 .20699 L

.19264 .2068 L

.22186 .20658 L

.25159 .20632 L

.28132 .20602 L

.31054 .20568 L

.33876 .20528 L

.36548 .20484 L

.39025 .20434 L

.41266 .20381 L

.4323 .20326 L

.44885 .20271 L

.46203 .20221 L

.47161 .2018 L

.47742 .20154 L

.47937 .20144 L

s

.47937 .20144 m

.4815 .20134 L

.48784 .20101 L

.49828 .20043 L

.51265 .1995 L

.5307 .19807 L

.55213 .19588 L

.57656 .19244 L

.60358 .18695 L

.63272 .17842 L

.66349 .16641 L

.69536 .15173 L

.72778 .13574 L

.7602 .11955 L

.79207 .10385 L

.82284 .08904 L

.85199 .07539 L

.879 .06307 L

.90343 .05219 L

.92486 .04286 L

.94291 .03514 L

.95728 .02909 L

.96773 .02474 L

.97407 .02212 L

.97619 .02124 L

s

.47937 .45225 m

.4815 .42528 L

.48784 .39852 L

.49828 .3722 L

.51265 .34653 L

.5307 .32178 L

.55213 .29835 L

.57656 .27683 L

.60358 .25814 L

.63272 .24338 L

.66349 .23307 L

.69536 .22653 L

.72778 .22248 L

.7602 .21989 L

.79207 .21816 L

.82284 .21696 L

.85199 .2161 L

.879 .21546 L

.90343 .21499 L

.92486 .21464 L

.94291 .21438 L

.95728 .21419 L

.96773 .21406 L

.97407 .21399 L

.97619 .21396 L

s

.47937 .45236 m

.4815 .47943 L

.48784 .50651 L

.49828 .53342 L

.51265 .56003 L

.5307 .5862 L

.55213 .61182 L

.57656 .63678 L

.60358 .66096 L

.63272 .68426 L

.66349 .70656 L

.69536 .72779 L

.72778 .74783 L

.7602 .76661 L

.79207 .78404 L

.82284 .80005 L

.85199 .81456 L

.879 .82752 L

.90343 .83886 L

.92486 .84855 L

.94291 .85653 L

.95728 .86277 L

.96773 .86725 L

.97407 .86995 L

.97619 .87085 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCaA<00?lCaA<006@C1@3G4`D00Q<00`0C4`024`0301<C008C00<04a<0L1<006HC00<04a<0

fA<00`0C4`064`0301<000<C00<04a<0L1<0048C00<=4a<06a<300<C00<04a<00Q<20<lC0`034`03

01<C00PC00@04a<C0P1a4`00@a<00`dC4`0P4`0301<C008C00<04a<0e1<00`0C4`064`8011<00`0C

4`1`4`00@a<00`dC4`0P4`0301<C008C00<04a<0e1<00`0C4`064`0301<C00<C00<04a<0F1<00`dC

4`0E4`00A1<00`dC4`0N4`8011<00`0C4`3C4`8021<300<C00<04a<0EA<33APC00154`033A<C02<C

0P3T4`0301<C05<C0PdK4`00AA<00`dC4`0S4`0301<C0><C0P1B4`8=7A<004HC00<=4a<08Q<00`0C

4`3S4`0301<C04hC0`dO4`00AQ<00`dC4`0R4`0301<C0><C00<04a<0C1<23B8C00174`033A<C024C

0P3T4`0301<C04XC0PdT4`00B1<00`dC4`0P4`0301<C0><C0P194`8=9Q<004PC00<=4a<081<00`0C

4`3S4`0301<C04DC0`dX4`00BA<00`dC4`0O4`0301<C0><C00<04a<0@a<23B/C001:4`033A<C01hC

0P3T4`0301<C044C0Pd]4`00BQ<00`dC4`0N4`0301<C0><C00<04a<0?a<23BlC001;4`033A<C01dC

00<04a<0ha<203hC0Pda4`00C1<00`dC4`0L4`0301<C0><C00<04a<0>a<23C<C001<4`033A<C01`C

0P3T4`0301<C03TC0Pde4`00CA<00`dC4`0K4`0301<C0><C00<04a<0=a<23CLC001>4`033A<C00/C

00<04a<00Q<00`0C4`024`0301<C008C00<04a<0ha<203HC0Pdi4`00Ca<00`dC4`094`0301<000LC

00<04`000a<00`0C4`3S4`0301<C03<C0Pdk4`00Ca<00`dC4`044`<00Q<00`0C00094`0401<C4`80

i1<00`0C4`0a4`8=?A<0050C00<=4a<021<00`0C00074`8011<00`0C4`3L4`D00Q<00`0C4`0_4`8=

?a<0054C00<=4a<01a<00`0C00074`0301<C00<C00<04a<0gQ<00`0C4`024`0301<C02dC0Pe14`00

DA<00`dC4`084`0301<C00HC0`034`0301<C0=PC0`034`0301<C008C0P0/4`8=@a<0058C00<=4a<0

5Q<00`0C4`3N4`0301<C008C00<04a<0:A<23DDC001C4`033A<C01DC0P3O4`0301<C008C00<04a<0

9a<23DLC001C4`033A<C01DC00<04a<0gA<200@C00<04a<09A<23DTC001D4`033A<C01@C00<04a<0

ha<202<C0`e;4`00EA<00`dC4`0C4`0301<C0><C00<04a<081<23DhC001F4`033A<C018C0P3T4`03

01<C01hC0Pe@4`00EQ<00`dC4`0B4`0301<C0><C00<04a<06a<33E8C000J4`<09A<5010C00<=4a<0

4A<00`0C4`0T4`D091<309<C00<04a<06A<23EDC000J4`0301<C02LC00<04a<04A<00`dC4`0@4`03

01<C02HC00<04a<091<00`0C4`2C4`805a<33ELC000E4`<00a<00`0C4`0P4`<00a<00`0C4`0A4`03

3A<C010C0P0W4`0301<C02DC00<04a<0TQ<00`0C4`0C4`<=FQ<001/C00<04a<09Q<00`0C4`0B4`03

3A<C00lC00<04a<09Q<00`0C4`0U4`0301<C098C00<04a<03a<43EdC000J4`0301<002LC00<04a<0

4a<00`dC4`0>4`0301<C02HC00<04a<091<00`0C002C4`0301<C00HC2@eQ4`006a<00`0C4`0U4`80

5A<00`dC4`0>4`0301<C02DC0P0W4`0301<C08hC3@eZ4`00Fa<00`dC4`0=4`80Ya<i3@@C0P1a4`00

G1<00`dC4`0<4`0301<C08PC7Pdm4`0301<C070C001M4`033A<C00/C00<04a<0Fa<208HC00<04a<0

>A<P3ALC001M4`033A<C00/C00<04a<0FQ<00`0C4`264`0301<C02dC30dg4`005A=900033@000640

1Q<00`0C4`264`808a<;3D<C000I4`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC00<04a<0

1A<00`0C4`054`0301<C00HC00<04a<01A<01@0C4a<=00<C00<04a<01A<00a0C4`054`0301<C00HC

00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C

4`054`0301<C00PC00<04a<0QQ<00`0C4`0N4`@=CQ<005lC00<=4a<02A<00a0C4`1J4`0301<008HC

00<04a<06a<33E8C001P4`033A<C00PC0Q1K4`<0Ma<00`0C4`024`0301<C008C00<04a<00Q<00`0C

4`0I4`8=EA<0064C00<=4a<01a<24=@C00<04`001a<00`0C00034`0301<C01HC0`eG4`00HA<00`dC

4`064`03400@0<lC0`024`0301<000TC00@04a<C0P0D4`<=FQ<0068C00<=4a<01A<00a00403D4`03

01<000LC0P044`0301<C014C0PeM4`00HQ<00`dC4`054`03400@0=@C00<04`001a<00`0C4`034`03

01<C010C00<=4a<0GA<006<C00<=4a<00a<01A0C000@0=@C00<04a<01Q<300<C00<04a<03Q<23F0C

001T4`033A<C008C00D@4`0C403S4`803Q<00`dC4`1P4`00I1<00`dC4`024`0541<04a00ha<00`0C

4`0<4`033A<C064C001U4`073A<C4a0C00024`0341<C0>0C00<04a<02a<00`dC4`1R4`00IQ<01@dC

4a0C008000<C41<0hA<00`0C4`094`8=IA<006HC00H=4a<@4`024`0341<C0>0C00<04a<021<00`dC

4`1U4`00Ia<01@d@4a<000<C00<@4a<0ga<200PC00<=4a<0IQ<006PC00@=4a<00a<00a0C4`3O4`03

01<C00HC00<=4a<0Ia<006PC00<=4a<00P024`0341<C0=lC00<04a<01A<00`dC4`1X4`00Ia<01A0C

3A<000@C00<@4a<0Q1<302TC1@0Y4`0301<C00DC00<=4a<081<502XC0`0F4`00G1<00`0C4`024`03

01<C008C00H041<C3@044`0341<C08@C00<04a<0:a<00`0C4`0Y4`801A<00`dC4`0S4`0301<C02XC

00<04a<05Q<005/C00<04`001a<00`0@00024`033@0C00<C00<@4a<0Oa<300<C00<04a<091<300<C

00<04a<0:A<00`0C4`034`033A<C02@C00<04a<0:a<00`0C4`0E4`00Fa<00`0C00084`03400C008C

00<=01<00a<00a0C4`244`0301<C02XC00<04a<0:A<00`0C4`024`033A<C02DC00<04a<0:a<00`0C

4`0E4`00Fa<00`0C00074`03010C00<C00<03A<00a<00a0C4`234`0301<002/C00<04a<0:A<01@0C

4a<=02PC00<04a<0:Q<00`0C000F4`00Fa<00`0C00074`0341<C00<C00<03A<011<00a0C4`234`03

01<C02TC0P0[4`0501<C4`d09a<202dC00<04a<05A<005`C00<04a<01Q<00a0000034`0301<=00@C

00<@4a<0g1<200034`dC06hC001T4`0341<C00@C0P000a<=4`024`0341<C0=`C00<04`d0L1<006@C

00<@4a<011<0100C4`d44`0341<C0=/C00<04`d0L1<006<C00<@4a<01A<01@0C4a<=00<C00<@4a<0

fa<00`0=4`1V4`8021<006<C00<@4a<01A<01@0C4a<=00@C00<@4a<0fQ<00`0=4`1U4`0301<C00PC

001R4`0341<C00HC00<04a<00Q<01@dC4a<@07`CH0000`d0001N00LC00<04a<021<0068C00<@4a<0

1Q<200@C00D=4a<C40204`0301<C02XC00<04a<0:a<00`dC4`0[4`0301<C02XC00<04a<02Q<00`0C

4`084`00HA<00a0C4`074`0301<C00<C00D=4a<C403J4`033@0C06HC00<04`0021<0064C00<@4a<0

1a<00`0C4`044`043A<C4=XC00<=01<0IQ<300PC001P4`0341<C00PC00<04a<01A<010dC4a3H4`04

3A<0074C001P4`0341<C00PC0P064`043A<C4=PC00<=4`00LQ<005lC00<@4a<02A<00`0C4`064`04

3A<C4=LC00<=4`00LQ<005lC00<@4a<02A<00`0C4`074`033A<@0=LC00<=4`00LQ<005hC00<@4a<0

2Q<00`0C4`074`043A<C4=DC00@=4a<0LQ<005hC00<@4a<02Q<200TC00<=4a00eA<00`dC4`02074C

001M4`0341<C00/C00<04a<02A<00`dC403D4`043A<C078C001M4`0341<C00@C1@024`0301<C00XC

00<=41<0da<010dC4`1b4`00G1<00a0C4`074`0301<C008C00<04a<02Q<00`dC403C4`043A<C078C

001K4`0341<C00PC00<04a<00Q<200`C00<=4a00dA<010dC4a<2074C001K4`0341<C00PC00<04a<0

0Q<00`0C4`0<4`033A0C0=0C00D=4a<C001b4`00FQ<00a0C4`094`0301<C008C00<04a<031<00`dC

403@4`053A<C4`00LQ<005XC00<@4a<021<200@C00<04a<03A<00`dC403?4`053A<C4`00LQ<005TC

00<@4a<03a<200lC00<=41<0cQ<01@dC4a<0078C001H4`0341<C010C00<04a<03Q<00`dC403>4`04

3A<C4`80LA<005PC00<@4a<041<00`0C4`0?4`033A<@0<hC00@=4a<0LQ<005LC00<@4a<04A<00`0C

4`0@4`033A0C0<4C00<04a<00Q<00`0C4`024`0301<=008C00<04a<0L1<005HC00<@4a<04Q<2018C

00<=41<0_a<00`0C00074`0401<03@8C00<04a<0L1<005HC00<@4a<04Q<00`0C4`0A4`033A<@0;lC

00<04`002A<0100=4a<2074C001E4`0341<C01<C00<04a<04Q<00`d@4`2n4`0301<000LC0P001A<=

4a<0078C001D4`0341<C01@C00<04a<04a<00`d@4`2m4`0301<000LC00L04a<C3A<0078C001C4`03

41<C01DC0P0D4`033A0C0;hC00<04a<01Q<300044`dC078C001C4`0341<C01DC00<04a<051<00`d@

4`3:4`033A<0078C001B4`0341<C01HC00<04a<05A<00`d@4`394`043A<0074C001A4`0341<C01LC

00<04a<05A<00`d@4`3:4`033@0C074C001A4`0341<C01LC0P0G4`033A0C0<TC00<=01<0LA<0050C

00<@4a<061<00`0C4`0G4`033A<C0<TC00<=4a<0L1<004lC00<@4a<021<5008C00<04a<00Q<00`0C

4`024`0301<C01PC00<=4a<0b1<00`d04`1`4`00Ca<00a0C4`0:4`0301<C00HC00<04`000a<00`0C

4`0H4`033A0C0<PC00<03A<0L1<004hC00<@4a<02a<00`0C4`084`0401<C4`806Q<00`d@4`374`03

00dC070C001=4`0341<C00`C00<04a<01Q<200@C00<04a<06Q<00`dC4`364`0301<=070C001<4`03

41<C00dC00<04a<01Q<00`0C4`034`0301<C01XC00<=41<0aQ<00`0C3@1`4`00C1<00a0C4`0<4`80

21<300<C00<04a<06a<00`d@4`354`8000<C3A<0KQ<004/C00<@4a<07A<201`C00<=4a00aA<01@0C

4a<=06hC001:4`0341<C01hC00<04a<071<00`d@4`344`0501<C4`d0KQ<004XC00<@4a<07Q<00`0C

4`0M4`033A0C0<<C00<04a<00Q<00`dC4`1[4`00BA<00a0C4`0O4`0301<C01dC00<=4a00`a<00`0C

4`024`033A<C06/C00184`0341<C020C0P0O4`033A<@0<8C0P044`033A<C06XC00174`0341<C024C

00<04a<07Q<010dC4a314`0301<C00@C00<=4a<0JA<004LC00<@4a<08A<00`0C4`0O4`033A<@0;XC

1@024`0301<C00DC00<=4a<0J1<004HC00<@4a<08Q<00`0C4`0P4`033A<@0;/C00<04a<00Q<00`0C

4`054`033A<C06PC00154`0341<C02<C0P0Q4`043A<C4;XC00<04a<00Q<200LC00<=4a<0Ia<004@C

00<@4a<091<00`0C4`0Q4`043A<C4;TC00<04a<00Q<00`0C4`074`033A<C06HC00144`0341<C02@C

00<04a<08Q<00`dC402i4`0301<C008C00<04a<021<00`dC4`1U4`00@a<00a0C4`0U4`0301<C028C

00@=4a<@]a<200@C00<04a<02A<00`dC4`1T4`00@Q<00a0C4`0V4`0301<C02<C00@=4a<@_1<00`0C

4`0:4`033A<C06<C00114`0341<C02LC0P0T4`053A<C4a00^a<200`C00<=4a<0HQ<0040C00<@4a<0

:1<00`0C4`0T4`053A<C4a00^Q<00`0C4`0<4`033A<C064C00104`0341<C028C0`034`0301<C02DC

00D=4a<C402i4`0301<C00dC00<=4a<0H1<003lC00<@4a<08a<00`0C4`034`0301<C02DC00D=4a<C

402i4`0301<C00hC00<=4a<0Ga<003hC00<@4a<09A<00`0C4`024`809a<01@dC4a<@0;PC0P0@4`03

3A<C05hC000m4`0341<C02HC00<04a<00Q<00`0C4`0W4`053A<C4a00]a<00`0C4`0@4`033A<C05dC

000m4`0341<C02DC00<04`000a<00`0C4`0W4`033A<C008C00<@4a<0]1<00`0C4`0A4`033A<C05`C

000l4`0341<C02LC00<04a<00Q<00`0C4`0X4`033A<C008C00<@4a<0/a<00`0C4`0B4`8=G1<003/C

00<@4a<0;A<202XC00<=4a<00Q<00a0C4`2b4`0301<C01@C00<=4a<0FA<003XC00<@4a<0;Q<00`0C

4`0Y4`033A<C008C00<@4a<0/Q<201HC0PeI4`00>Q<00a0C4`0^4`0301<C02XC00<=4a<00Q<00a0C

4`2a4`0301<C01LC00<=4a<0EQ<003TC00<@4a<0;a<00`0C4`0[4`033A<C008C00<@4a<0/1<00`0C

4`0H4`033A<C05DC000h4`0341<C030C0P0]4`033A<C008C00<@4a<0[a<00`0C4`0I4`8=EA<003LC

00<@4a<0<A<00`0C4`0/4`033A<C008C00<@4a<0[a<201`C00<=4a<0DQ<003LC00<@4a<0<A<00`0C

4`0]4`033A<C008C00<@4a<0[Q<00`0C4`0L4`033A<C054C000f4`0341<C038C00<04a<0;Q<00`dC

4`024`0341<C0:dC00<04a<07A<23E4C000e4`0341<C03<C0P0_4`033A<C00<C00<@4a<0Va<5008C

00<04a<00Q<00`0C4`024`0301<C01lC0Pe?4`00=1<00a0C4`0d4`0301<C02lC00<=4a<00a<00a0C

4`2L4`0301<C00HC00<04`000a<00`0C4`0Q4`8=CA<003<C00<@4a<0=A<00`0C4`0`4`033A<C00<C

00<@4a<0Va<00`0C4`084`0401<C4`8091<00`dC4`1:4`00<Q<00a0C4`0f4`0301<C030C00<=4a<0

0a<00a0C4`2K4`0301<C00HC0P044`0301<C02@C0Pe:4`00<A<00a0C4`0g4`80<Q<00`dC4`034`03

41<C09XC00<04a<01Q<00`0C4`034`0301<C02HC00<=4a<0Aa<0030C00<@4a<0>1<00`0C4`0a4`03

3A<C00@C00<@4a<0V1<200PC0`034`0301<C02LC0Pe74`00;a<00a0C4`0Y4`<00a<00`0C4`024`03

01<C008C00<04a<0<Q<00`dC4`044`0341<C0:LC00<04a<0:A<00`dC4`144`00;Q<00a0C4`0Z4`03

01<C00LC00<04`000a<00`0C4`0c4`033A<C00@C00<@4a<0YQ<202/C0Pe44`00;A<00a0C4`0/4`03

01<C00PC00@04a<C0P0d4`033A<C00DC00<@4a<0YA<00`0C4`0/4`033A<C044C000/4`0341<C02dC

00<04a<01Q<200@C00<04a<0=1<00`dC4`054`0341<C0:@C00<04a<0;A<23D4C000[4`0341<C02dC

00<04`001a<00`0C4`034`0301<C03DC00<=4a<01A<00a0C4`2S4`0301<C02lC00<=4a<0?Q<002XC

00<@4a<0;a<00`0C4`064`<00a<00`0C4`0e4`033A<C00HC00<@4a<0XQ<2034C0Pdn4`00:A<00a0C

4`0o4`80=a<00`dC4`064`0341<C0:4C00<04a<0<Q<23C`C000X4`0341<C040C00<04a<0=a<00`dC

4`064`0341<C0:0C00<04a<0=1<23CXC000W4`0341<C044C00<04a<0=a<00`dC4`074`0341<C09lC

00<04a<0=Q<23CPC000V4`0341<C048C00<04a<0>1<00`dC4`074`0341<C09hC00<04a<0>1<23CHC

000U4`0341<C04<C0P0j4`033A<C00LC00<@4a<0WA<203/C0Pdd4`0091<00a0C4`144`0301<C03XC

00<=4a<01a<00a0C4`2L4`0301<C03`C0Pdb4`008a<00a0C4`154`0301<C03XC00<=4a<021<00a0C

4`2K4`0301<C03hC0Pd`4`008a<00a0C4`154`0301<C03/C00<=4a<021<00a0C4`2J4`0301<C040C

0Pd^4`008Q<00a0C4`164`80?A<00`dC4`084`0341<C09TC0P134`8=;1<0024C00<@4a<0Aa<00`0C

4`0l4`033A<C00TC00<@4a<0V1<00`0C4`144`8=:Q<0020C00<@4a<0B1<00`0C4`0m4`033A<C00TC

00<@4a<0Ua<00`0C4`164`033A<C02LC000O4`0341<C04TC00<04a<0?A<00`dC4`0:4`0341<C090C

0`034`0301<C04LC0PdW4`007Q<00a0C4`1:4`80?a<00`dC4`0:4`0341<C08lC00<04a<00a<00`0C

4`194`<=91<001dC00<@4a<0Ba<00`0C4`0o4`033A<C00XC00<@4a<0Sa<00`0C4`024`80CA<23B8C

000L4`0341<C04`C00<04a<0?a<00`dC4`0;4`0341<C08hC00<04a<00Q<00`0C4`1>4`<=7a<001/C

00<@4a<0Aa<200@C00<04a<0@1<00`dC4`0;4`0341<C08`C00<04`000a<00`0C4`1A4`<=71<001XC

00<@4a<0BQ<01@0C4a<0048C00<=4a<031<00a0C4`2<4`0301<C008C00<04a<0E1<23AXC000I4`03

41<C04XC00<04a<00Q<2048C00<=4a<02a<00a0C4`2A4`80Ea<23APC001W4`0301<C0>LC00<04a<0

F1<00`dC4`0E4`00IA<00`0C003Y4`0301<C070C001V4`0301<C0>PC00<04a<0L1<002lC0`3o4b0C

00<04a<0L1<002lC00<04a<0oa<P4`0301<C070C000`4`0301<C00@C00<04a<0oa>;4`00<1<0100C

4a<400<C0`3o4hLC000_4`0301<0008C0P000a<04`044`0301<C0?lCQA<0030C00<04a<00a<00`0C

00034`0301<C0?lCQQ<003HC00<04`0011<00`0C4`064`0301<C028C0`0`4`0301<C0?lC91<0020C

0`000a<0000200`C0`044`<021<00`0C4`0Q4`0401<C01@C0`000a<00002008C00<04a<00Q<00`0C

4`024`0301<C00DC00@04a<C1@024`0301<C008C00<04a<011<20<lC00<04a<0;A<00`0C4`0;4`00

7a<0100C4`0T4`0301<C020C00@04a<04a<0100C4`064`0301<000LC00<04`0011<500<C00<04a<0

1Q<00`0C00044`0301<C0<LC00<04a<011<00`0C4`0C4`0301<C01TC00<04a<02Q<001lC00D04a<0

4`0400034`0001P0:1<301<C00D04a<04`0400044`0C00TC00<04a<011<00`0C4`034`0301<C00PC

00<04a<00Q<00`0C4`2e4`0401<C4`@00Q<200HC00<04a<00a<00`0C4`024`0301<C008C00<04a<0

0Q<00`0C4`054`0401<C4`D00Q<00`0C4`024`0301<C00@C0P044`0401<C4`8000<C00000a<0020C

0`1:4`0301<C018C0`064`0301<000LC0P074`0301<C00<C00<04a<01Q<200DC00<04a<0]1<00`0C

00074`0301<C00@C1@034`0701<C4`0C00074`0301<000@C1@034`0301<C00HC00<04`0011<00`0C

4`044`0301<C008C00<04`0011<0028C00<04a<0Aa<201HC00<04a<011<00`0C00074`0301<C00`C

00<04a<01Q<00`0C4`044`0301<00;@C00<04`000Q<400034`0C00LC00<04a<00a<01`0C4a<04`00

2A<00`0C4`044`0301<C00<C00<04a<021<00`0C4`024`0301<C00@C00<04a<00a<00`0C4`034`00

8A<2060C0P074`0301<C00HC0`0;4`8021<300@C0`2H4`8000<C00005a<00`0C00074`0301<C00HC

00<04a<00a<01`0C4a<04`001a<200LC00<04a<00a<00`0C4`064`801A<00`0C4`044`0301<C00<C

00<04a<00a<00?lCDA<00`0C000H4`0301<000LC00<04`003A<01P0C4`0C00LC00<04a<031<00`0C

4`064`0301<C00@C00<04`000a<00`0C4`034`0301<000@C000[4`801Q<20?lC7A<00`0C4`0H4`03

01<C00HC0`0>4`0401<C00PC0`0;4`8021<300@C0`024`0301<C00<C0P000a<000034`00;A<00`0C

4`024`0301<C0?lC7A<00`0C4`1`4`00;1<00`0C4`034`0301<C00HC00<04a<0oa<C4`0301<0074C

000]4`0301<C008C00<04a<00Q<300044`0C4`<0oa<?4`8000<C0000L1<002/C00<04`0011<00`0C

00024`800Q<00`0C4`024`0301<C0?lCPQ<002`C00<04a<00a<300@C00@04a<00Q<00`0C4`3o4h<C

000i4`0401<C00<C00<04a<0oa>24`00=a<300@C0`3o4h@C003o4lDC003o4lDC003o4lDC003o4lDC

003o4lDC0000\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.39518, -1.70539, 0.0219056, 0.0219056}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -84.5 0 ]

[.5 .96488 84.5 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -145.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.495) show

222.250000 19.500000 moveto

(C) show

227.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.26111 0 m

.26171 .0009 L

.30316 .06286 L

.34309 .12256 L

.3815 .17998 L

.42237 .24108 L

.46172 .29991 L

.49955 .35647 L

.53984 .4167 L

.57861 .47467 L

.61984 .5363 L

.65954 .59566 L

.69774 .65276 L

.73838 .71352 L

.77751 .77202 L

.81909 .83419 L

.85916 .89409 L

.89771 .95172 L

s

.89771 .95172 m

.89815 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.367432 0.238095 [

[.02381 .35493 -6 -9 ]

[.02381 .35493 6 0 ]

[.2619 .35493 -6 -9 ]

[.2619 .35493 6 0 ]

[.7381 .35493 -3 -9 ]

[.7381 .35493 3 0 ]

[.97619 .35493 -3 -9 ]

[.97619 .35493 3 0 ]

[1.025 .36743 0 -8 ]

[1.025 .36743 9 8 ]

[.4875 .01029 -24 -4.5 ]

[.4875 .01029 0 4.5 ]

[.4875 .12934 -12 -4.5 ]

[.4875 .12934 0 4.5 ]

[.4875 .24838 -24 -4.5 ]

[.4875 .24838 0 4.5 ]

[.4875 .48648 -18 -4.5 ]

[.4875 .48648 0 4.5 ]

[.4875 .60553 -6 -4.5 ]

[.4875 .60553 0 4.5 ]

[.4875 .72458 -18 -4.5 ]

[.4875 .72458 0 4.5 ]

[.4875 .84362 -6 -4.5 ]

[.4875 .84362 0 4.5 ]

[.5 .91528 -4.5 0 ]

[.5 .91528 4.5 16 ]

[.5 .90278 -137 0 ]

[.5 .90278 137 16 ]

[ 0 0 0 0 ]

[ 1 .89028 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .36743 m

.02381 .37368 L

s

[(-2)] .02381 .35493 0 1 Mshowa

.2619 .36743 m

.2619 .37368 L

s

[(-1)] .2619 .35493 0 1 Mshowa

.7381 .36743 m

.7381 .37368 L

s

[(1)] .7381 .35493 0 1 Mshowa

.97619 .36743 m

.97619 .37368 L

s

[(2)] .97619 .35493 0 1 Mshowa

.125 Mabswid

.07143 .36743 m

.07143 .37118 L

s

.11905 .36743 m

.11905 .37118 L

s

.16667 .36743 m

.16667 .37118 L

s

.21429 .36743 m

.21429 .37118 L

s

.30952 .36743 m

.30952 .37118 L

s

.35714 .36743 m

.35714 .37118 L

s

.40476 .36743 m

.40476 .37118 L

s

.45238 .36743 m

.45238 .37118 L

s

.54762 .36743 m

.54762 .37118 L

s

.59524 .36743 m

.59524 .37118 L

s

.64286 .36743 m

.64286 .37118 L

s

.69048 .36743 m

.69048 .37118 L

s

.78571 .36743 m

.78571 .37118 L

s

.83333 .36743 m

.83333 .37118 L

s

.88095 .36743 m

.88095 .37118 L

s

.92857 .36743 m

.92857 .37118 L

s

.25 Mabswid

0 .36743 m

1 .36743 L

s

gsave

1.025 .36743 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .01029 m

.50625 .01029 L

s

[(-1.5)] .4875 .01029 1 0 Mshowa

.5 .12934 m

.50625 .12934 L

s

[(-1)] .4875 .12934 1 0 Mshowa

.5 .24838 m

.50625 .24838 L

s

[(-0.5)] .4875 .24838 1 0 Mshowa

.5 .48648 m

.50625 .48648 L

s

[(0.5)] .4875 .48648 1 0 Mshowa

.5 .60553 m

.50625 .60553 L

s

[(1)] .4875 .60553 1 0 Mshowa

.5 .72458 m

.50625 .72458 L

s

[(1.5)] .4875 .72458 1 0 Mshowa

.5 .84362 m

.50625 .84362 L

s

[(2)] .4875 .84362 1 0 Mshowa

.125 Mabswid

.5 .0341 m

.50375 .0341 L

s

.5 .05791 m

.50375 .05791 L

s

.5 .08172 m

.50375 .08172 L

s

.5 .10553 m

.50375 .10553 L

s

.5 .15315 m

.50375 .15315 L

s

.5 .17696 m

.50375 .17696 L

s

.5 .20077 m

.50375 .20077 L

s

.5 .22458 m

.50375 .22458 L

s

.5 .27219 m

.50375 .27219 L

s

.5 .296 m

.50375 .296 L

s

.5 .31981 m

.50375 .31981 L

s

.5 .34362 m

.50375 .34362 L

s

.5 .39124 m

.50375 .39124 L

s

.5 .41505 m

.50375 .41505 L

s

.5 .43886 m

.50375 .43886 L

s

.5 .46267 m

.50375 .46267 L

s

.5 .51029 m

.50375 .51029 L

s

.5 .5341 m

.50375 .5341 L

s

.5 .55791 m

.50375 .55791 L

s

.5 .58172 m

.50375 .58172 L

s

.5 .62934 m

.50375 .62934 L

s

.5 .65315 m

.50375 .65315 L

s

.5 .67696 m

.50375 .67696 L

s

.5 .70077 m

.50375 .70077 L

s

.5 .74838 m

.50375 .74838 L

s

.5 .77219 m

.50375 .77219 L

s

.5 .796 m

.50375 .796 L

s

.5 .81981 m

.50375 .81981 L

s

.5 .86743 m

.50375 .86743 L

s

.25 Mabswid

.5 0 m

.5 .89028 L

s

gsave

.5 .91528 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .90278 -198 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.495) show

298.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

303.000000 15.000000 moveto

(L) show

310.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

317.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

324.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

329.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

333.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .89028 L

0 .89028 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .206 m

.02576 .20599 L

.03157 .20597 L

.04115 .20593 L

.05432 .20588 L

.07088 .20582 L

.09052 .20573 L

.11292 .20563 L

.13769 .2055 L

.16442 .20536 L

.19263 .20518 L

.22185 .20497 L

.25158 .20473 L

.28131 .20444 L

.31053 .20412 L

.33874 .20375 L

.36546 .20333 L

.39024 .20286 L

.41264 .20236 L

.43228 .20184 L

.44883 .20132 L

.46201 .20085 L

.47159 .20047 L

.4774 .20021 L

.47935 .20013 L

s

.47935 .20013 m

.48147 .20003 L

.48781 .19972 L

.49826 .19917 L

.51263 .1983 L

.53068 .19695 L

.55211 .19488 L

.57654 .19162 L

.60356 .18637 L

.6327 .1781 L

.66347 .16628 L

.69534 .15167 L

.72777 .1357 L

.76019 .11951 L

.79207 .1038 L

.82284 .08899 L

.85198 .07533 L

.879 .06301 L

.90343 .05214 L

.92486 .04281 L

.94291 .03509 L

.95728 .02904 L

.96773 .02469 L

.97407 .02207 L

.97619 .0212 L

s

.47935 .45103 m

.48147 .42408 L

.48781 .39733 L

.49826 .371 L

.51263 .3453 L

.53068 .3205 L

.55211 .29698 L

.57654 .27532 L

.60356 .25642 L

.6327 .24143 L

.66347 .23098 L

.69534 .22439 L

.72777 .22034 L

.76019 .21779 L

.79207 .21609 L

.82284 .21492 L

.85198 .21408 L

.879 .21347 L

.90343 .21301 L

.92486 .21267 L

.94291 .21241 L

.95728 .21223 L

.96773 .21211 L

.97407 .21204 L

.97619 .21201 L

s

.47935 .45114 m

.48147 .47819 L

.48781 .50525 L

.49826 .53213 L

.51263 .5587 L

.53068 .58484 L

.55211 .61043 L

.57654 .63536 L

.60356 .65951 L

.6327 .68277 L

.66347 .70505 L

.69534 .72624 L

.72777 .74625 L

.76019 .765 L

.79207 .78241 L

.82284 .79839 L

.85198 .81288 L

.879 .82582 L

.90343 .83715 L

.92486 .84682 L

.94291 .85479 L

.95728 .86102 L

.96773 .8655 L

.97407 .86819 L

.97619 .86909 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCaA<00?lCaA<006@C1@3G4`D00Q<00`0C4`024`0301<C008C00<04a<0L1<006HC00<04a<0

fA<00`0C4`064`0301<000<C00<04a<0L1<0048C00<=4a<06a<300<C00<04a<00Q<20<lC0`034`03

01<C00PC00@04a<C0P1a4`00@a<00`dC4`0P4`0301<C008C00<04a<0e1<00`0C4`064`8011<00`0C

4`1`4`00@a<00`dC4`0P4`0301<C008C00<04a<0e1<00`0C4`064`0301<C00<C00<04a<0F1<00`dC

4`0E4`00A1<00`dC4`0N4`8011<00`0C4`3C4`8021<300<C00<04a<0Ea<00`dC4`0F4`00AA<00`dC

4`0S4`80i1<00`0C4`1D4`<=6A<004DC00<=4a<08a<00`0C4`3S4`80DQ<33A`C00164`033A<C028C

00<04a<0ha<00`0C4`1>4`<=7a<004HC00<=4a<08Q<00`0C4`3S4`0301<C04`C0PdR4`00Aa<00`dC

4`0Q4`80i1<00`0C4`1:4`8=91<004PC00<=4a<081<00`0C4`3S4`80BA<23BHC00184`033A<C020C

00<04a<0ha<00`0C4`164`8=:1<004TC00<=4a<07a<00`0C4`3S4`0301<C04@C0PdZ4`00BQ<00`dC

4`0N4`80i1<00`0C4`124`8=;1<004XC00<=4a<07Q<00`0C4`3S4`0301<C040C0Pd^4`00Ba<00`dC

4`0M4`0301<C0><C0P0n4`<=<1<004`C00<=4a<071<00`0C4`3S4`0301<C03/C0Pdc4`00C1<00`dC

4`0L4`80i1<00`0C4`0i4`8==A<004dC00<=4a<06a<00`0C4`3S4`0301<C03LC0Pdg4`00CQ<00`dC

4`0;4`0301<C008C00<04a<00Q<00`0C4`024`0301<C0><C0P0f4`8=>A<004lC00<=4a<02A<00`0C

00074`0301<000<C00<04a<0ha<00`0C4`0c4`8=>a<004lC00<=4a<011<3008C00<04`002A<0100C

4a<20>@C00<04a<0<A<23CdC001@4`033A<C00PC00<04`001a<200@C00<04a<0g1<5008C00<04a<0

;a<23ClC001A4`033A<C00LC00<04`001a<00`0C4`034`0301<C0=hC00<04a<00Q<00`0C4`0]4`8=

@A<0054C00<=4a<021<00`0C4`064`<00a<00`0C4`3H4`<00a<00`0C4`024`80;1<23D<C001B4`03

3A<C01HC00<04a<0gQ<00`0C4`024`0301<C02TC0Pe54`00Da<00`dC4`0E4`80ga<00`0C4`024`03

01<C02LC0Pe74`00Da<00`dC4`0E4`0301<C0=dC0P044`0301<C02DC0Pe94`00E1<00`dC4`0D4`03

01<C0><C0P0S4`<=Ba<005DC00<=4a<04a<00`0C4`3S4`0301<C020C0Pe>4`00EQ<00`dC4`0B4`80

i1<00`0C4`0N4`8=D1<005HC00<=4a<04Q<00`0C4`3S4`0301<C01/C0`eB4`006Q<302DC1@0@4`03

3A<C014C00<04a<091<502@C0`2C4`0301<C01TC0PeE4`006Q<00`0C4`0W4`0301<C014C00<=4a<0

41<00`0C4`0V4`0301<C02@C00<04a<0Ta<201LC0`eG4`005A<300<C00<04a<081<300<C00<04a<0

4A<00`dC4`0@4`809a<00`0C4`0U4`0301<C098C00<04a<04a<33EXC000K4`0301<C02HC00<04a<0

4Q<00`dC4`0?4`0301<C02HC00<04a<09A<00`0C4`2B4`0301<C00lC10eM4`006Q<00`0C000W4`03

01<C01<C00<=4a<03Q<00`0C4`0V4`0301<C02@C00<04`00Ta<00`0C4`064`T=HA<001/C00<04a<0

9A<201DC00<=4a<03Q<00`0C4`0U4`809a<00`0C4`2>4`d=JQ<005/C00<=4a<03A<20:8C?Pd44`80

LA<005`C00<=4a<031<00`0C4`284aT=@Q<00`0C4`1`4`00GA<00`dC4`0;4`0301<C05/C0P264`03

01<C03TC80dG4`00GA<00`dC4`0;4`0301<C05XC00<04a<0QQ<00`0C4`0W4a8==a<001DCB@000`d0

001Q00HC00<04a<0QQ<2024C1`e94`006A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`03

01<C00DC00<04a<01A<00`0C4`064`0301<C00DC00D04a<C3@034`0301<C00DC00<@4a<01A<00`0C

4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC

00<04a<01A<00`0C4`084`0301<C08HC00<04a<06a<53E0C001O4`033A<C00TC00<@4a<0FQ<00`0C

00264`0301<C01TC0PeE4`00H1<00`dC4`084`8@Fa<307LC00<04a<00Q<00`0C4`024`0301<C008C

00<04a<05a<23ELC001Q4`033A<C00LC0Q3D4`0301<000LC00<04`000a<00`0C4`0E4`8=FA<0064C

00<=4a<01Q<00a00403?4`<00Q<00`0C00094`0401<C4`8051<23E/C001R4`033A<C00DC00<@0100

e1<00`0C00074`8011<00`0C4`0A4`8=GA<0068C00<=4a<01A<00a00403D4`0301<000LC00<04a<0

0a<00`0C4`0@4`033A<C05dC001S4`033A<C00<C00D@4`00403D4`0301<C00HC0`034`0301<C00hC

0PeP4`00I1<00`dC4`024`0541<04a00ha<200hC00<=4a<0H1<006@C00<=4a<00Q<01A0C01<@0><C

00<04a<031<00`dC4`1Q4`00IA<01`dC4a<@4`000Q<00a0C4`3P4`0301<C00/C00<=4a<0HQ<006HC

00D=4a<@4`0200034a0C0>4C00<04a<02A<23FDC001V4`063A<C41<00Q<00a0C4`3P4`0301<C00PC

00<=4a<0IA<006LC00D=41<C00034`0341<C0=lC0P084`033A<C06HC001X4`043A<C00<C00<@4a<0

ga<00`0C4`064`033A<C06LC001X4`033A<C00800Q<00a0C4`3O4`0301<C00DC00<=4a<0J1<006LC

00D@4`dC00044`0341<C08@C0`0Y4`D0:A<00`0C4`054`033A<C020C1@0Z4`<05Q<005`C00<04a<0

0Q<00`0C4`024`06010C4`d011<00a0C4`244`0301<C02/C00<04a<0:A<200DC00<=4a<08a<00`0C

4`0Z4`0301<C01HC001K4`0301<000LC00<040000Q<00`d04`034`0341<C07lC0`034`0301<C02@C

0`034`0301<C02TC00<04a<00a<00`dC4`0T4`0301<C02/C00<04a<05A<005/C00<04`0021<00a00

4`024`033@0C00<C00<@4a<0Q1<00`0C4`0Z4`0301<C02TC00<04a<00Q<00`dC4`0U4`0301<C02/C

00<04a<05A<005/C00<04`001a<00`0@4`034`0300dC00<C00<@4a<0Pa<00`0C000[4`0301<C02TC

00D04a<C3@0X4`0301<C02XC00<04`005Q<005/C00<04`001a<00a0C4`034`0300dC00@C00<@4a<0

Pa<00`0C4`0Y4`80:a<01@0C4a<=02LC0P0]4`0301<C01DC001L4`0301<C00HC00<@00000a<00`0C

3@044`0341<C0=`C0P000a<=4`1^4`00I1<00a0C4`044`8000<C3A<00Q<00a0C4`3L4`0301<=070C

001T4`0341<C00@C00@04a<=11<00a0C4`3K4`0301<=070C001S4`0341<C00DC00D04a<C3@034`03

41<C0=/C00<03A<0IQ<200PC001S4`0341<C00DC00D04a<C3@044`0341<C0=XC00<03A<0IA<00`0C

4`084`00HQ<00a0C4`064`0301<C008C00D=4a<C401l4f0000<=0000GP074`0301<C00PC001R4`03

41<C00HC0P044`053A<C4a00P1<00`0C4`0Z4`0301<C02/C00<=4a<0:a<00`0C4`0Z4`0301<C00XC

00<04a<021<0064C00<@4a<01a<00`0C4`034`053A<C4a00fQ<00`d04`1V4`0301<000PC001Q4`03

41<C00LC00<04a<011<010dC4a3J4`033@0C06HC0`084`00H1<00a0C4`084`0301<C00DC00@=4a<@

f1<010dC001a4`00H1<00a0C4`084`801Q<010dC4a3H4`033A<0078C001O4`0341<C00TC00<04a<0

1Q<010dC4a3G4`033A<0078C001O4`0341<C00TC00<04a<01a<00`dC403G4`033A<0078C001N4`03

41<C00XC00<04a<01a<010dC4a3E4`043A<C078C001N4`0341<C00XC0P094`033A<@0=DC00<=4a<0

0P1a4`00GA<00a0C4`0;4`0301<C00TC00<=4a00e1<010dC4`1b4`00GA<00a0C4`044`D00Q<00`0C

4`0:4`033A0C0=<C00@=4a<0LQ<005`C00<@4a<01a<00`0C4`024`0301<C00XC00<=4a00da<010dC

4`1b4`00Fa<00a0C4`084`0301<C008C0P0<4`033A<@0=4C00@=4a<C0P1a4`00Fa<00a0C4`084`03

01<C008C00<04a<031<00`d@4`3@4`053A<C4`00LQ<005XC00<@4a<02A<00`0C4`024`0301<C00`C

00<=4a00d1<01@dC4a<0078C001J4`0341<C00PC0P044`0301<C00dC00<=4a00ca<01@dC4a<0078C

001I4`0341<C00lC0P0?4`033A0C0<hC00D=4a<C001b4`00F1<00a0C4`0@4`0301<C00hC00<=4a00

cQ<010dC4a<2074C001H4`0341<C010C00<04a<03a<00`dC403>4`043A<C078C001G4`0341<C014C

00<04a<041<00`d@4`314`0301<C008C00<04a<00Q<00`0C3@024`0301<C070C001F4`0341<C018C

0P0B4`033A0C0;lC00<04`001a<0100C00d24`0301<C070C001F4`0341<C018C00<04a<04A<00`dC

402o4`0301<000TC00@03A<C0P1a4`00EA<00a0C4`0C4`0301<C018C00<=41<0_Q<00`0C00074`80

00DC3A<C001b4`00E1<00a0C4`0D4`0301<C01<C00<=41<0_A<00`0C00074`0701<C4`dC001b4`00

Da<00a0C4`0E4`8051<00`d@4`2n4`0301<C00HC0`0011<=4`1b4`00Da<00a0C4`0E4`0301<C01@C

00<=41<0bQ<00`dC001b4`00DQ<00a0C4`0F4`0301<C01DC00<=41<0bA<010dC001a4`00DA<00a0C

4`0G4`0301<C01DC00<=41<0bQ<00`d04`1a4`00DA<00a0C4`0G4`805a<00`d@4`394`033@0C074C

001@4`0341<C01PC00<04a<05a<00`dC4`394`033A<C070C001?4`0341<C00PC1@024`0301<C008C

00<04a<00Q<00`0C4`0H4`033A<C0<PC00<=4a<0L1<004lC00<@4a<02Q<00`0C4`064`0301<000<C

00<04a<061<00`d@4`384`0300dC070C001>4`0341<C00/C00<04a<021<0100C4a<201XC00<=41<0

aa<00`0=4`1`4`00CA<00a0C4`0<4`0301<C00HC0P044`0301<C01XC00<=4a<0aQ<00`0C3@1`4`00

C1<00a0C4`0=4`0301<C00HC00<04a<00a<00`0C4`0J4`033A0C0<HC00<04`d0L1<004`C00<@4a<0

31<200PC0`034`0301<C01/C00<=41<0aA<200034`dC06hC001;4`0341<C01dC0P0L4`033A<@0<DC

00D04a<C3@1^4`00BQ<00a0C4`0N4`0301<C01`C00<=41<0a1<01@0C4a<=06hC001:4`0341<C01hC

00<04a<07A<00`d@4`334`0301<C008C00<=4a<0Ja<004TC00<@4a<07a<00`0C4`0M4`033A<@0<<C

00<04a<00Q<00`dC4`1[4`00B1<00a0C4`0P4`807a<00`dC40324`8011<00`dC4`1Z4`00Aa<00a0C

4`0Q4`0301<C01hC00@=4a<@`A<00`0C4`044`033A<C06TC00174`0341<C024C00<04a<07a<00`dC

402j4`D00Q<00`0C4`054`033A<C06PC00164`0341<C028C00<04a<081<00`dC402k4`0301<C008C

00<04a<01A<00`dC4`1X4`00AA<00a0C4`0S4`808A<010dC4a2j4`0301<C008C0P074`033A<C06LC

00144`0341<C02@C00<04a<08A<010dC4a2i4`0301<C008C00<04a<01a<00`dC4`1V4`00A1<00a0C

4`0T4`0301<C028C00<=4a00^A<00`0C4`024`0301<C00PC00<=4a<0IA<004<C00<@4a<09A<00`0C

4`0R4`043A<C4;LC0P044`0301<C00TC00<=4a<0I1<0048C00<@4a<09Q<00`0C4`0S4`043A<C4;`C

00<04a<02Q<00`dC4`1S4`00@A<00a0C4`0W4`8091<01@dC4a<@0;/C0P0<4`033A<C068C00104`03

41<C02PC00<04a<091<01@dC4a<@0;XC00<04a<031<00`dC4`1Q4`00@1<00a0C4`0R4`<00a<00`0C

4`0U4`053A<C4a00^A<00`0C4`0=4`033A<C060C000o4`0341<C02<C00<04a<00a<00`0C4`0U4`05

3A<C4a00^A<00`0C4`0>4`033A<C05lC000n4`0341<C02DC00<04a<00Q<202LC00D=4a<C402h4`80

41<00`dC4`1N4`00?A<00a0C4`0V4`0301<C008C00<04a<09a<01@dC4a<@0;LC00<04a<041<00`dC

4`1M4`00?A<00a0C4`0U4`0301<000<C00<04a<09a<00`dC4`024`0341<C0;@C00<04a<04A<00`dC

4`1L4`00?1<00a0C4`0W4`0301<C008C00<04a<0:1<00`dC4`024`0341<C0;<C00<04a<04Q<23E`C

000k4`0341<C02dC0P0Z4`033A<C008C00<@4a<0/Q<00`0C4`0D4`033A<C05TC000j4`0341<C02hC

00<04a<0:A<00`dC4`024`0341<C0;8C0P0F4`8=FA<003XC00<@4a<0;Q<00`0C4`0Z4`033A<C008C

00<@4a<0/A<00`0C4`0G4`033A<C05HC000i4`0341<C02lC00<04a<0:a<00`dC4`024`0341<C0;0C

00<04a<061<00`dC4`1E4`00>1<00a0C4`0`4`80;A<00`dC4`024`0341<C0:lC00<04a<06A<23EDC

000g4`0341<C034C00<04a<0;1<00`dC4`024`0341<C0:lC00<04a<06a<00`dC4`1B4`00=a<00a0C

4`0a4`0301<C02dC00<=4a<00Q<00a0C4`2^4`807A<00`dC4`1A4`00=Q<00a0C4`0b4`0301<C02hC

00<=4a<00Q<00a0C4`2]4`0301<C01dC0PeA4`00=A<00a0C4`0c4`80;a<00`dC4`034`0341<C09/C

1@024`0301<C008C00<04a<00Q<00`0C4`0O4`8=Ca<003@C00<@4a<0=1<00`0C4`0_4`033A<C00<C

00<@4a<0W1<00`0C4`064`0301<000<C00<04a<08A<23DdC000c4`0341<C03DC00<04a<0<1<00`dC

4`034`0341<C09/C00<04a<021<0100C4a<202@C00<=4a<0BQ<0038C00<@4a<0=Q<00`0C4`0`4`03

3A<C00<C00<@4a<0Va<00`0C4`064`8011<00`0C4`0T4`8=BQ<0034C00<@4a<0=a<2038C00<=4a<0

0a<00a0C4`2J4`0301<C00HC00<04a<00a<00`0C4`0V4`033A<C04LC000`4`0341<C03PC00<04a<0

<Q<00`dC4`034`0341<C09PC0P084`<00a<00`0C4`0W4`8=Aa<002lC00<@4a<0:A<300<C00<04a<0

0Q<00`0C4`024`0301<C03<C00<=4a<00a<00a0C4`2W4`0301<C02TC00<=4a<0A1<002hC00<@4a<0

:Q<00`0C4`074`0301<000<C00<04a<0<a<00`dC4`044`0341<C0:HC0P0[4`8=A1<002dC00<@4a<0

;1<00`0C4`084`0401<C4`80=A<00`dC4`044`0341<C0:DC00<04a<0;1<00`dC4`114`00;1<00a0C

4`0]4`0301<C00HC0P044`0301<C03DC00<=4a<011<00a0C4`2T4`0301<C02dC0Pe14`00:a<00a0C

4`0]4`0301<000LC00<04a<00a<00`0C4`0e4`033A<C00DC00<@4a<0Xa<00`0C4`0_4`033A<C03hC

000Z4`0341<C02lC00<04a<01Q<300<C00<04a<0=Q<00`dC4`054`0341<C0:8C0P0a4`8=?Q<002TC

00<@4a<0?a<203PC00<=4a<01A<00a0C4`2Q4`0301<C038C0Pdl4`00:1<00a0C4`104`0301<C03LC

00<=4a<01Q<00a0C4`2P4`0301<C03@C0Pdj4`009a<00a0C4`114`0301<C03PC00<=4a<01Q<00a0C

4`2O4`0301<C03HC0Pdh4`009Q<00a0C4`124`0301<C03PC00<=4a<01a<00a0C4`2N4`0301<C03PC

0Pdf4`009A<00a0C4`134`80>Q<00`dC4`074`0341<C09dC0P0k4`8==1<002@C00<@4a<0A1<00`0C

4`0j4`033A<C00LC00<@4a<0W1<00`0C4`0l4`8=<Q<002<C00<@4a<0AA<00`0C4`0j4`033A<C00PC

00<@4a<0Va<00`0C4`0n4`8=<1<002<C00<@4a<0AA<00`0C4`0k4`033A<C00PC00<@4a<0VQ<00`0C

4`104`8=;Q<0028C00<@4a<0AQ<203dC00<=4a<021<00a0C4`2I4`80@a<23B`C000Q4`0341<C04LC

00<04a<0?1<00`dC4`094`0341<C09PC00<04a<0A1<23BXC000P4`0341<C04PC00<04a<0?A<00`dC

4`094`0341<C09LC00<04a<0AQ<00`dC4`0W4`007a<00a0C4`194`0301<C03hC00<=4a<02A<00a0C

4`2@4`<00a<00`0C4`174`8=9a<001hC00<@4a<0BQ<203lC00<=4a<02Q<00a0C4`2?4`0301<C00<C

00<04a<0BA<33B@C000M4`0341<C04/C00<04a<0?a<00`dC4`0:4`0341<C08lC00<04a<00Q<204dC

0PdR4`0071<00a0C4`1<4`0301<C040C00<=4a<02Q<00a0C4`2>4`0301<C008C00<04a<0CQ<33AlC

000K4`0341<C04LC0P044`0301<C040C00<=4a<02a<00a0C4`2<4`0301<000<C00<04a<0DA<33A`C

000J4`0341<C04XC00D04a<C00134`033A<C00/C00<@4a<0S1<00`0C4`024`0301<C05@C0PdJ4`00

6A<00a0C4`1:4`0301<C008C0P124`033A<C00/C00<@4a<0TA<00`0C4`1F4`8=61<006LC00<04a<0

ia<205TC00<=4a<05A<006DC00<04`00jA<00`0C4`1`4`00IQ<00`0C4`3X4`0301<C070C000Z4`<0

oa<U4`0301<C070C000Z4`0301<C0?lC9A<00`0C4`1`4`00:a<00`0C4`044`0301<C0?lCT1<002/C

00@04a<C10034`<0oa><4`00:Q<00`0C00024`8000<C01<011<00`0C4`3o4hXC000[4`0301<C00<C

00<04`000a<00`0C4`3o4h/C000a4`0301<000@C00<04a<01Q<00`0C4`0W4`<0:a<00`0C4`3o4bTC

000K4`<000<C00000P0<4`<011<300PC00<04a<09Q<0100C4`0?4`<000<C00000P024`0301<C008C

00<04a<00Q<00`0C4`054`0401<C4`D00Q<00`0C4`024`<000<C000011<00`0C4`044`80aA<00`0C

4`0g4`0301<C00HC000J4`0401<C02@C00<04a<09A<0100C4`0>4`0401<C00HC00<04`001a<00`0C

00044`D00a<00`0C4`084`0301<C008C00H04a<04`044`0301<C0;dC00<04a<011<00`0C4`0C4`03

01<C02<C00<04a<01A<001XC00D04a<04`0400034`0001P0;A<300hC00D04a<04`0400044`0C00TC

00<04a<011<00`0C4`034`0301<C00HC10024`8011<00`0C4`024`0301<C0:/C00@04a<C10024`80

1Q<00`0C4`034`0301<C008C00<04a<00Q<00`0C4`024`0301<C00DC00@04a<C1@024`0301<C008C

0`000a<000044`0301<C00@C0P044`0401<C4`800A<001/C0`1?4`0301<C00dC0`064`0301<000LC

0P074`0301<C00<C00<04a<01Q<00`0C00024`0301<0008C0P054`0301<C0:XC00<04`001a<00`0C

4`044`D00a<01`0C4a<04`001a<00`0C00044`D00a<00`0C4`084`0301<C008C00H04a<04`044`03

01<C00@C00<04a<00Q<1004C000M4`0301<C04`C0P0A4`0301<C00@C00<04`001a<00`0C4`0<4`03

01<C00LC0P024`0301<0008C00<04a<011<00`0C002Z4`0301<0008C10000a<04`074`0301<C00<C

00L04a<C01<000TC00<04a<011<00`0C4`034`0301<C00HC10024`8011<00`0C4`024`0301<C00@C

00<04a<00a<1000071<2060C0P074`0301<C00HC0`0;4`802Q<0100C4a<2008C0`044`<0Ta<20003

4`00018C00<04`001a<00`0C4`064`0301<C00<C00L04a<C01<000LC0P074`0301<C00<C00<04a<0

1Q<00`0C00024`0301<0008C0P054`0301<C00@C00<04a<00a<10000oa=A4`0301<001<C00<04`00

1a<00`0C000=4`0601<C01<01a<00`0C4`0<4`0301<C00LC0P024`0301<0008C00<04a<011<00`0C

00034`0301<C00<C0@014`009Q<200HC0P3o4b8C00<04a<04a<00`0C4`064`<03Q<0100C4`084`<0

2a<200XC00@04a<C0P024`<011<3008C00<04a<00a<2004C000X4`0301<C008C00<04a<0oa<R4`03

01<C070C000W4`0301<C00<C00<04a<01Q<00`0C4`3o4aPC00<04`00LA<002PC00<04a<00Q<00`0C

4`024`<000@C01<C0`3o4a@C0P000a<0001`4`009Q<00`0C00044`0301<0008C0P024`0301<C008C

00<04a<0oa>74`009a<00`0C4`034`<011<0100C4`024`0301<C0?lCR1<003@C00@04a<00a<00`0C

4`3o4hLC000b4`<011<30?lCRA<00?lCaA<00?lCaA<00?lCaA<00?lCaA<00?lCaA<00001\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.3906, -1.70525, 0.021892, 0.021892}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -82 0 ]

[.5 .96488 82 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -143 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.49) show

217.250000 19.500000 moveto

(C) show

222.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.26031 0 m

.26171 .00209 L

.30316 .06384 L

.34309 .12334 L

.3815 .18058 L

.42237 .24147 L

.46172 .3001 L

.49955 .35647 L

.53984 .4165 L

.57861 .47427 L

.61984 .5357 L

.65954 .59486 L

.69774 .65177 L

.73838 .71233 L

.77751 .77064 L

.81909 .83259 L

.85916 .89229 L

.89771 .94973 L

s

.89771 .94973 m

.89949 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.366171 0.238095 [

[.02381 .35367 -6 -9 ]

[.02381 .35367 6 0 ]

[.2619 .35367 -6 -9 ]

[.2619 .35367 6 0 ]

[.7381 .35367 -3 -9 ]

[.7381 .35367 3 0 ]

[.97619 .35367 -3 -9 ]

[.97619 .35367 3 0 ]

[1.025 .36617 0 -8 ]

[1.025 .36617 9 8 ]

[.4875 .00903 -24 -4.5 ]

[.4875 .00903 0 4.5 ]

[.4875 .12808 -12 -4.5 ]

[.4875 .12808 0 4.5 ]

[.4875 .24712 -24 -4.5 ]

[.4875 .24712 0 4.5 ]

[.4875 .48522 -18 -4.5 ]

[.4875 .48522 0 4.5 ]

[.4875 .60427 -6 -4.5 ]

[.4875 .60427 0 4.5 ]

[.4875 .72331 -18 -4.5 ]

[.4875 .72331 0 4.5 ]

[.4875 .84236 -6 -4.5 ]

[.4875 .84236 0 4.5 ]

[.5 .91347 -4.5 0 ]

[.5 .91347 4.5 16 ]

[.5 .90097 -134.5 0 ]

[.5 .90097 134.5 16 ]

[ 0 0 0 0 ]

[ 1 .88847 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .36617 m

.02381 .37242 L

s

[(-2)] .02381 .35367 0 1 Mshowa

.2619 .36617 m

.2619 .37242 L

s

[(-1)] .2619 .35367 0 1 Mshowa

.7381 .36617 m

.7381 .37242 L

s

[(1)] .7381 .35367 0 1 Mshowa

.97619 .36617 m

.97619 .37242 L

s

[(2)] .97619 .35367 0 1 Mshowa

.125 Mabswid

.07143 .36617 m

.07143 .36992 L

s

.11905 .36617 m

.11905 .36992 L

s

.16667 .36617 m

.16667 .36992 L

s

.21429 .36617 m

.21429 .36992 L

s

.30952 .36617 m

.30952 .36992 L

s

.35714 .36617 m

.35714 .36992 L

s

.40476 .36617 m

.40476 .36992 L

s

.45238 .36617 m

.45238 .36992 L

s

.54762 .36617 m

.54762 .36992 L

s

.59524 .36617 m

.59524 .36992 L

s

.64286 .36617 m

.64286 .36992 L

s

.69048 .36617 m

.69048 .36992 L

s

.78571 .36617 m

.78571 .36992 L

s

.83333 .36617 m

.83333 .36992 L

s

.88095 .36617 m

.88095 .36992 L

s

.92857 .36617 m

.92857 .36992 L

s

.25 Mabswid

0 .36617 m

1 .36617 L

s

gsave

1.025 .36617 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .00903 m

.50625 .00903 L

s

[(-1.5)] .4875 .00903 1 0 Mshowa

.5 .12808 m

.50625 .12808 L

s

[(-1)] .4875 .12808 1 0 Mshowa

.5 .24712 m

.50625 .24712 L

s

[(-0.5)] .4875 .24712 1 0 Mshowa

.5 .48522 m

.50625 .48522 L

s

[(0.5)] .4875 .48522 1 0 Mshowa

.5 .60427 m

.50625 .60427 L

s

[(1)] .4875 .60427 1 0 Mshowa

.5 .72331 m

.50625 .72331 L

s

[(1.5)] .4875 .72331 1 0 Mshowa

.5 .84236 m

.50625 .84236 L

s

[(2)] .4875 .84236 1 0 Mshowa

.125 Mabswid

.5 .03284 m

.50375 .03284 L

s

.5 .05665 m

.50375 .05665 L

s

.5 .08046 m

.50375 .08046 L

s

.5 .10427 m

.50375 .10427 L

s

.5 .15189 m

.50375 .15189 L

s

.5 .17569 m

.50375 .17569 L

s

.5 .1995 m

.50375 .1995 L

s

.5 .22331 m

.50375 .22331 L

s

.5 .27093 m

.50375 .27093 L

s

.5 .29474 m

.50375 .29474 L

s

.5 .31855 m

.50375 .31855 L

s

.5 .34236 m

.50375 .34236 L

s

.5 .38998 m

.50375 .38998 L

s

.5 .41379 m

.50375 .41379 L

s

.5 .4376 m

.50375 .4376 L

s

.5 .46141 m

.50375 .46141 L

s

.5 .50903 m

.50375 .50903 L

s

.5 .53284 m

.50375 .53284 L

s

.5 .55665 m

.50375 .55665 L

s

.5 .58046 m

.50375 .58046 L

s

.5 .62808 m

.50375 .62808 L

s

.5 .65189 m

.50375 .65189 L

s

.5 .67569 m

.50375 .67569 L

s

.5 .6995 m

.50375 .6995 L

s

.5 .74712 m

.50375 .74712 L

s

.5 .77093 m

.50375 .77093 L

s

.5 .79474 m

.50375 .79474 L

s

.5 .81855 m

.50375 .81855 L

s

.5 .86617 m

.50375 .86617 L

s

.25 Mabswid

.5 0 m

.5 .88847 L

s

gsave

.5 .91347 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .90097 -195.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.49) show

293.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

298.000000 15.000000 moveto

(L) show

305.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

312.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

319.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

324.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

328.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .88847 L

0 .88847 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .20432 m

.02576 .20431 L

.03157 .20429 L

.04115 .20426 L

.05432 .20421 L

.07087 .20415 L

.09052 .20407 L

.11292 .20397 L

.13769 .20385 L

.16441 .20371 L

.19262 .20355 L

.22184 .20335 L

.25157 .20312 L

.28129 .20285 L

.31051 .20255 L

.33873 .2022 L

.36545 .2018 L

.39022 .20137 L

.41262 .20089 L

.43226 .2004 L

.44881 .19992 L

.46199 .19948 L

.47156 .19912 L

.47738 .19888 L

.47932 .1988 L

s

.47932 .1988 m

.48145 .19871 L

.48779 .19842 L

.49823 .19791 L

.51261 .19708 L

.53066 .19582 L

.55209 .19388 L

.57652 .1908 L

.60354 .18579 L

.63269 .17779 L

.66346 .16616 L

.69533 .15163 L

.72776 .13567 L

.76018 .11947 L

.79206 .10375 L

.82283 .08893 L

.85197 .07528 L

.87899 .06295 L

.90343 .05208 L

.92485 .04276 L

.94291 .03504 L

.95728 .02899 L

.96773 .02465 L

.97407 .02203 L

.97619 .02115 L

s

.47932 .4498 m

.48145 .42286 L

.48779 .39612 L

.49823 .36978 L

.51261 .34406 L

.53066 .31921 L

.55209 .2956 L

.57652 .27379 L

.60354 .25468 L

.63269 .23945 L

.66346 .22884 L

.69533 .2222 L

.72776 .21817 L

.76018 .21565 L

.79206 .21399 L

.82283 .21285 L

.85197 .21204 L

.87899 .21144 L

.90343 .211 L

.92485 .21067 L

.94291 .21043 L

.95728 .21025 L

.96773 .21013 L

.97407 .21007 L

.97619 .21004 L

s

.47932 .44991 m

.48145 .47694 L

.48779 .50397 L

.49823 .53082 L

.51261 .55737 L

.53066 .58348 L

.55209 .60903 L

.57652 .63392 L

.60354 .65804 L

.63269 .68127 L

.66346 .70352 L

.69533 .72468 L

.72776 .74466 L

.76018 .76339 L

.79206 .78077 L

.82283 .79673 L

.85197 .8112 L

.87899 .82412 L

.90343 .83543 L

.92485 .84508 L

.94291 .85304 L

.95728 .85926 L

.96773 .86373 L

.97407 .86642 L

.97619 .86731 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCaA<00?lCaA<006@C1@3G4`D00Q<00`0C4`024`0301<C008C00<04a<0L1<006HC00<04a<0

fA<00`0C4`064`0301<000<C00<04a<0L1<0048C00<=4a<06a<300<C00<04a<00Q<20<lC0`034`03

01<C00PC00@04a<C0P1a4`00@a<00`dC4`0P4`0301<C008C00<04a<0e1<00`0C4`064`8011<00`0C

4`1`4`00@a<00`dC4`0P4`0301<C008C00<04a<0e1<00`0C4`064`0301<C00<C00<04a<0FA<00`dC

4`0D4`00A1<00`dC4`0N4`8011<00`0C4`3C4`8021<300<C00<04a<0Ea<23ALC00154`033A<C02<C

0P3T4`0301<C05@C0`dI4`00AA<00`dC4`0S4`0301<C0><C0P1C4`8=71<004HC00<=4a<08Q<00`0C

4`3S4`0301<C050C0PdN4`00AQ<00`dC4`0R4`0301<C0><C00<04a<0CQ<23B0C00174`033A<C024C

0P3T4`0301<C04XC10dR4`00B1<00`dC4`0P4`0301<C0><C0P194`8=9Q<004PC00<=4a<081<00`0C

4`3S4`0301<C04HC0PdX4`00BA<00`dC4`0O4`0301<C0><C00<04a<0A1<23BXC001:4`033A<C01hC

0P3T4`0301<C048C0Pd/4`00BQ<00`dC4`0N4`0301<C0><C00<04a<0@1<23BhC001;4`033A<C01dC

00<04a<0ha<203hC0`d`4`00C1<00`dC4`0L4`0301<C0><C00<04a<0>a<23C<C001<4`033A<C01`C

0P3T4`0301<C03TC0Pde4`00CA<00`dC4`0K4`0301<C0><C00<04a<0=a<23CLC001>4`033A<C00/C

00<04a<00Q<00`0C4`024`0301<C008C00<04a<0ha<203HC0Pdi4`00Ca<00`dC4`094`0301<000LC

00<04`000a<00`0C4`3S4`0301<C03<C0Pdk4`00Ca<00`dC4`044`<00Q<00`0C00094`0401<C4`80

i1<00`0C4`0a4`8=?A<0050C00<=4a<021<00`0C00074`8011<00`0C4`3L4`D00Q<00`0C4`0_4`8=

?a<0054C00<=4a<01a<00`0C00074`0301<C00<C00<04a<0gQ<00`0C4`024`0301<C02dC0Pe14`00

DA<00`dC4`084`0301<C00HC0`034`0301<C0=PC0`034`0301<C008C0P0/4`8=@a<0058C00<=4a<0

5Q<00`0C4`3N4`0301<C008C00<04a<0:A<23DDC001C4`033A<C01DC0P3O4`0301<C008C00<04a<0

9a<23DLC001C4`033A<C01DC00<04a<0gA<200@C00<04a<09A<23DTC001D4`033A<C01@C00<04a<0

ha<202<C0`e;4`00EA<00`dC4`0C4`0301<C0><C00<04a<081<23DhC001F4`033A<C018C0P3T4`03

01<C01hC0Pe@4`00EQ<00`dC4`0B4`0301<C0><C00<04a<06a<33E8C000J4`<09A<5010C00<=4a<0

4A<00`0C4`0T4`D091<309<C00<04a<06A<23EDC000J4`0301<C02LC00<04a<04A<00`dC4`0@4`03

01<C02HC00<04a<091<00`0C4`2C4`805a<33ELC000E4`<00a<00`0C4`0P4`<00a<00`0C4`0A4`03

3A<C010C0P0W4`0301<C02DC00<04a<0TQ<00`0C4`0C4`<=FQ<001/C00<04a<09Q<00`0C4`0B4`03

3A<C00lC00<04a<09Q<00`0C4`0U4`0301<C098C00<04a<03a<43EdC000J4`0301<002LC00<04a<0

4a<00`dC4`0>4`0301<C02HC00<04a<091<00`0C002C4`0301<C00XC1@eQ4`006a<00`0C4`0U4`80

5A<00`dC4`0>4`0301<C02DC0P0W4`0301<C08hC4@eV4`00Fa<00`dC4`0=4`80V1=93@<C0P1a4`00

Fa<00`dC4`0=4`0301<C08PC3`e<4`0301<C070C001L4`033A<C00`C00<04a<0Fa<208HC00<04a<0

<a<W3AHC001M4`033A<C00/C00<04a<0FQ<00`0C4`264`0301<C02LC30dm4`005A=800033@000680

1Q<00`0C4`264`808A<73DTC000I4`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC00<04a<0

1A<00`0C4`054`0301<C00HC00<04a<01A<0100C4`d44`0301<C00DC00<@4a<01A<00`0C4`064`03

01<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<0

1A<00`0C4`084`0301<C08HC00<04a<06a<53E0C001O4`033A<C00TC00<@4a<0FQ<00`0C00264`03

01<C01TC0PeE4`00Ga<00`dC4`094`8@Fa<307LC00<04a<00Q<00`0C4`024`0301<C008C00<04a<0

5a<23ELC001P4`033A<C00PC0Q3D4`0301<000LC00<04`000a<00`0C4`0E4`8=FA<0064C00<=4a<0

1Q<00a00403?4`<00Q<00`0C00094`0401<C4`8051<23E/C001Q4`033A<C00HC00<@0100e1<00`0C

00074`8011<00`0C4`0A4`8=GA<0068C00<=4a<01A<00a00403D4`0301<000LC00<04a<00a<00`0C

4`0@4`033A<C05dC001S4`033A<C00<C00D@4`00403D4`0301<C00HC0`034`0301<C00hC0PeP4`00

I1<00`dC4`024`0541<04a00ha<200hC00<=4a<0H1<006@C00<=4a<00Q<01A0C01<@0><C00<04a<0

31<00`dC4`1Q4`00IA<01`dC4a<@4`000Q<00a0C4`3P4`0301<C00/C00<=4a<0HQ<006HC00D=4a<@

4`0200034a0C0>4C00<04a<02A<23FDC001V4`063A<C41<00Q<00a0C4`3P4`0301<C00PC00<=4a<0

IA<006LC00D=41<C00034`0341<C0=lC0P084`033A<C06HC001X4`043A<C00<C00<@4a<0ga<00`0C

4`064`033A<C06LC001X4`033A<C00800Q<00a0C4`3O4`0301<C00DC00<=4a<0J1<006LC00D@4`dC

00044`0341<C08@C0`0Y4`D0:A<00`0C4`054`033A<C020C1@0Z4`<05Q<005`C00<04a<00Q<00`0C

4`024`06010C4`d011<00a0C4`244`0301<C02/C00<04a<0:A<200DC00<=4a<08a<00`0C4`0Z4`03

01<C01HC001K4`0301<000LC00<040000Q<00`d04`034`0341<C07lC0`034`0301<C02@C0`034`03

01<C02TC00<04a<00a<00`dC4`0T4`0301<C02/C00<04a<05A<005/C00<04`0021<00a004`024`03

3@0C00<C00<@4a<0Q1<00`0C4`0Z4`0301<C02TC00<04a<00Q<00`dC4`0U4`0301<C02/C00<04a<0

5A<005/C00<04`001a<00`0@4`034`0300dC00<C00<@4a<0Pa<00`0C000[4`0301<C02TC00D04a<C

3@0X4`0301<C02XC00<04`005Q<005/C00<04`001a<00a0C4`034`0300dC00@C00<@4a<0Pa<00`0C

4`0Y4`80:a<01@0C4a<=02LC0P0]4`0301<C01DC001L4`0301<C00HC00<@00000a<00`0C3@044`03

41<C0=`C0P000a<=4`1^4`00I1<00a0C4`044`8000<C3A<00Q<00a0C4`3L4`0301<=070C001T4`03

41<C00@C00@04a<=11<00a0C4`3K4`0301<=070C001S4`0341<C00DC00D04a<C3@034`0341<C0=/C

00<03A<0IQ<200PC001S4`0341<C00DC00D04a<C3@044`0341<C0=XC00<03A<0IA<00`0C4`084`00

HQ<00a0C4`064`0301<C008C00D=4a<C401l4f0000<=0000GP074`0301<C00PC001R4`0341<C00HC

0P044`053A<C4a00P1<00`0C4`0Z4`0301<C02/C00<=4a<0:a<00`0C4`0[4`0301<C00TC00<04a<0

21<0064C00<@4a<01a<00`0C4`034`053A<C4a00fQ<00`d04`1V4`0301<000PC001Q4`0341<C00LC

00<04a<011<010dC4a3J4`033@0C06HC0`084`00H1<00a0C4`084`0301<C00DC00@=4a<@f1<010dC

001a4`00H1<00a0C4`084`801a<00`dC403H4`033A<0078C001O4`0341<C00TC00<04a<01Q<010dC

4a3G4`033A<0078C001O4`0341<C00TC00<04a<01a<00`dC403G4`033A<0078C001N4`0341<C00XC

00<04a<021<00`dC403E4`043A<C078C001N4`0341<C00XC0P0:4`033A0C0=@C00<=4a<00P1a4`00

GA<00a0C4`0;4`0301<C00TC00<=4a00e1<010dC4`1b4`00GA<00a0C4`044`D00Q<00`0C4`0:4`03

3A0C0=<C00@=4a<0LQ<005`C00<@4a<01a<00`0C4`024`0301<C00/C00<=41<0dQ<010dC4`1b4`00

Fa<00a0C4`084`0301<C008C0P0=4`033A0C0=4C00<=4a<00P1a4`00Fa<00a0C4`084`0301<C008C

00<04a<031<00`d@4`3@4`053A<C4`00LQ<005XC00<@4a<02A<00`0C4`024`0301<C00dC00<=41<0

ca<01@dC4a<0078C001J4`0341<C00PC0P044`0301<C00hC00<=41<0cQ<01@dC4a<0078C001I4`03

41<C00lC0P0?4`033A0C0<hC00D=4a<C001b4`00F1<00a0C4`0@4`0301<C00lC00<=41<0cA<010dC

4a<2074C001H4`0341<C010C00<04a<03a<00`dC403>4`043A<C078C001G4`0341<C014C00<04a<0

41<00`d@4`314`0301<C008C00<04a<00Q<00`0C3@024`0301<C070C001F4`0341<C018C0P0B4`03

3A0C0;lC00<04`001a<0100C00d24`0301<C070C001F4`0341<C018C00<04a<04A<00`dC402o4`03

01<000TC00@03A<C0P1a4`00EA<00a0C4`0C4`0301<C018C00<=41<0_Q<00`0C00074`8000DC3A<C

001b4`00E1<00a0C4`0D4`0301<C01<C00<=41<0_A<00`0C00074`0701<C4`dC001b4`00Da<00a0C

4`0E4`8051<00`d@4`2n4`0301<C00HC0`0011<=4`1b4`00Da<00a0C4`0E4`0301<C01@C00<=41<0

bQ<00`dC001b4`00DQ<00a0C4`0F4`0301<C01DC00<=41<0bA<010dC001a4`00DA<00a0C4`0G4`03

01<C01DC00<=41<0bQ<00`d04`1a4`00DA<00a0C4`0G4`805a<00`d@4`394`033@0C074C001@4`03

41<C01PC00<04a<05a<00`dC4`394`033A<C070C001?4`0341<C00PC1@024`0301<C008C00<04a<0

0Q<00`0C4`0H4`033A<C0<PC00<=4a<0L1<004lC00<@4a<02Q<00`0C4`064`0301<000<C00<04a<0

61<00`d@4`384`0300dC070C001>4`0341<C00/C00<04a<021<0100C4a<201XC00<=41<0aa<00`0=

4`1`4`00CA<00a0C4`0<4`0301<C00HC0P044`0301<C01XC00<=4a<0aQ<00`0C3@1`4`00C1<00a0C

4`0=4`0301<C00HC00<04a<00a<00`0C4`0J4`033A0C0<HC00<04`d0L1<004`C00<@4a<031<200PC

0`034`0301<C01/C00<=41<0aA<200034`dC06hC001;4`0341<C01dC0P0L4`033A<@0<DC00D04a<C

3@1^4`00BQ<00a0C4`0N4`0301<C01`C00<=41<0a1<01@0C4a<=06hC001:4`0341<C01hC00<04a<0

7A<00`d@4`334`0301<C008C00<=4a<0Ja<004TC00<@4a<07a<00`0C4`0M4`033A<@0<<C00<04a<0

0Q<00`dC4`1[4`00B1<00a0C4`0P4`807a<00`dC40324`8011<00`dC4`1Z4`00Aa<00a0C4`0Q4`03

01<C01hC00@=4a<@`A<00`0C4`044`033A<C06TC00174`0341<C024C00<04a<07a<00`dC402j4`D0

0Q<00`0C4`054`033A<C06PC00164`0341<C028C00<04a<081<00`dC402k4`0301<C008C00<04a<0

1A<00`dC4`1X4`00AA<00a0C4`0S4`808A<010dC4a2j4`0301<C008C0P074`033A<C06LC00144`03

41<C02@C00<04a<08A<010dC4a2i4`0301<C008C00<04a<01a<00`dC4`1V4`00A1<00a0C4`0T4`03

01<C028C00<=4a00^A<00`0C4`024`0301<C00PC00<=4a<0IA<004<C00<@4a<09A<00`0C4`0R4`04

3A<C4;LC0P044`0301<C00TC00<=4a<0I1<0048C00<@4a<09Q<00`0C4`0S4`043A<C4;`C00<04a<0

2Q<00`dC4`1S4`00@A<00a0C4`0W4`809A<010dC4a2k4`8031<00`dC4`1R4`00@1<00a0C4`0X4`03

01<C02DC00@=4a<@^Q<00`0C4`0<4`033A<C064C00104`0341<C028C0`034`0301<C02DC00D=4a<C

402i4`0301<C00dC00<=4a<0H1<003lC00<@4a<08a<00`0C4`034`0301<C02HC00@=4a<@^A<00`0C

4`0>4`033A<C05lC000n4`0341<C02DC00<04a<00Q<202PC00@=4a<@^1<2010C00<=4a<0GQ<003dC

00<@4a<09Q<00`0C4`024`0301<C02LC00D=4a<C402g4`0301<C010C00<=4a<0GA<003dC00<@4a<0

9A<00`0C00034`0301<C02PC00D=4a<C402f4`0301<C014C00<=4a<0G1<003`C00<@4a<09a<00`0C

4`024`0301<C02TC00D=4a<C402e4`0301<C018C0PeL4`00>a<00a0C4`0]4`80:Q<00`dC4`024`03

41<C0;8C00<04a<051<00`dC4`1I4`00>Q<00a0C4`0^4`0301<C02XC00D=4a<C402d4`805Q<23ETC

000j4`0341<C02hC00<04a<0:a<01@dC4a<@0;<C00<04a<05a<00`dC4`1F4`00>A<00a0C4`0_4`03

01<C02`C00D=4a<C402b4`0301<C01PC00<=4a<0EA<003PC00<@4a<0<1<202dC00<=4a<00Q<00a0C

4`2_4`0301<C01TC0PeE4`00=a<00a0C4`0a4`0301<C02dC00D=4a<C402a4`0301<C01/C00<=4a<0

DQ<003LC00<@4a<0<A<00`0C4`0^4`053A<C4a00/1<201dC00<=4a<0DA<003HC00<@4a<0<Q<00`0C

4`0^4`033A<C008C00<@4a<0[A<00`0C4`0M4`8=DA<003DC00<@4a<0<a<2030C00<=4a<00Q<00a0C

4`2K4`D00Q<00`0C4`024`0301<C008C00<04a<07a<23DlC000d4`0341<C03@C00<04a<0<1<00`dC

4`024`0341<C09`C00<04a<01Q<00`0C00034`0301<C024C0Pe=4`00<a<00a0C4`0e4`0301<C030C

00<=4a<00a<00a0C4`2K4`0301<C00PC00@04a<C0P0T4`033A<C04XC000b4`0341<C03HC00<04a<0

<A<00`dC4`024`0341<C09/C00<04a<01Q<200@C00<04a<091<23DXC000a4`0341<C03LC0P0b4`03

3A<C00<C00<@4a<0VQ<00`0C4`064`0301<C00<C00<04a<09Q<00`dC4`174`00<1<00a0C4`0h4`03

01<C038C00<=4a<00a<00a0C4`2H4`8021<300<C00<04a<09a<23DLC000_4`0341<C02TC0`034`03

01<C008C00<04a<00Q<00`0C4`0c4`033A<C00<C00<@4a<0Ya<00`0C4`0Y4`033A<C04@C000^4`03

41<C02XC00<04a<01a<00`0C00034`0301<C03<C00<=4a<011<00a0C4`2V4`80:a<23D@C000]4`03

41<C02`C00<04a<021<0100C4a<203DC00<=4a<011<00a0C4`2U4`0301<C02`C00<=4a<0@A<002`C

00<@4a<0;A<00`0C4`064`8011<00`0C4`0e4`033A<C00@C00<@4a<0Y1<00`0C4`0]4`8=@A<002/C

00<@4a<0;A<00`0C00074`0301<C00<C00<04a<0=A<00`dC4`054`0341<C0:<C00<04a<0;a<00`dC

4`0n4`00:Q<00a0C4`0_4`0301<C00HC0`034`0301<C03HC00<=4a<01A<00a0C4`2R4`80<A<23ChC

000Y4`0341<C03lC0P0h4`033A<C00DC00<@4a<0XA<00`0C4`0b4`8=?1<002PC00<@4a<0@1<00`0C

4`0g4`033A<C00HC00<@4a<0X1<00`0C4`0d4`8=>Q<002LC00<@4a<0@A<00`0C4`0h4`033A<C00HC

00<@4a<0Wa<00`0C4`0f4`8=>1<002HC00<@4a<0@Q<00`0C4`0i4`033A<C00HC00<@4a<0WQ<00`0C

4`0h4`8==Q<002DC00<@4a<0@a<203/C00<=4a<01Q<00a0C4`2M4`80>a<23C@C000T4`0341<C04@C

00<04a<0>Q<00`dC4`074`0341<C09`C00<04a<0?1<23C8C000S4`0341<C04DC00<04a<0>a<00`dC

4`074`0341<C09/C00<04a<0?Q<23C0C000S4`0341<C04DC00<04a<0?1<00`dC4`074`0341<C09XC

00<04a<0@1<23BhC000R4`0341<C04HC0P0m4`033A<C00PC00<@4a<0VA<204<C0Pd/4`008A<00a0C

4`174`0301<C03dC00<=4a<021<00a0C4`2H4`0301<C04@C0PdZ4`0081<00a0C4`184`0301<C03dC

00<=4a<02A<00a0C4`2G4`0301<C04HC0PdX4`007a<00a0C4`194`0301<C03hC00<=4a<02A<00a0C

4`2@4`<00a<00`0C4`184`8=9Q<001hC00<@4a<0BQ<2040C00<=4a<02A<00a0C4`2?4`0301<C00<C

00<04a<0BQ<23B@C000M4`0341<C04/C00<04a<0?a<00`dC4`0:4`0341<C08lC00<04a<00Q<204dC

0PdR4`0071<00a0C4`1<4`0301<C040C00<=4a<02Q<00a0C4`2>4`0301<C008C00<04a<0CQ<33AlC

000K4`0341<C04LC0P044`0301<C040C00<=4a<02a<00a0C4`2<4`0301<000<C00<04a<0DA<33A`C

000J4`0341<C04XC00D04a<C00134`033A<C00/C00<@4a<0S1<00`0C4`024`0301<C05@C0PdJ4`00

6A<00a0C4`1:4`0301<C008C0P134`033A<C00XC00<@4a<0TA<00`0C4`1F4`8=61<006LC00<04a<0

ia<205TC0PdF4`00IA<00`0C003Y4`0301<C070C001V4`0301<C0>PC00<04a<0L1<002`C0`3o4b<C

00<04a<0L1<002`C00<04a<0oa<S4`0301<C070C000]4`0301<C00DC00<04a<0oa>=4`00;A<0100C

4a<300044`0C4`<0oa>:4`00;1<00`0C00024`800Q<00`0C4`024`0301<C0?lCR1<002dC00<04a<0

0a<0100C4`024`0301<C0?lCRA<003<C00@04a<00a<00`0C4`064`0301<C02DC0`0]4`0301<C0?lC

9a<001dC0`000a<0000200`C0`044`<021<00`0C4`0T4`0401<C014C0`000a<00002008C00<04a<0

0Q<00`0C4`024`0301<C00DC00@04a<C1@024`0301<C008C0`000a<000064`80ba<00`0C4`0b4`03

01<C00PC000L4`0401<C02@C00<04a<08a<0100C4`0@4`0401<C00HC00<04`001a<00`0C00044`D0

0a<00`0C4`084`0301<C008C00<04a<00Q<00`0C4`334`0301<C00@C00<04a<04a<00`0C4`0N4`03

01<C00LC000L4`0501<C01<010000a<0000H02/C0`0@4`0501<C01<0100011<04`094`0301<C00@C

00<04a<00a<00`0C4`064`@00Q<200@C00<04a<0/A<0100C4a<4008C0P064`0301<C00<C00<04a<0

0Q<00`0C4`024`0301<C008C00<04a<01A<0100C4a<5008C00<04a<00Q<300034`0000HC0P044`04

01<C4`800A<10040000M4`<0CA<00`0C4`0?4`<01Q<00`0C00074`801a<00`0C4`034`0301<C00HC

00<04`000Q<00`0C00044`0301<C0;0C00<04`001a<00`0C4`044`D00a<01`0C4a<04`001a<00`0C

00044`D00a<00`0C4`084`0301<C008C00<04a<00Q<00`0C4`044`0301<C008C00<04`000A<001lC

00<04a<0BQ<201<C00<04a<011<00`0C00074`0301<C00`C00<04a<01a<2008C00<04`0011<00`0C

002`4`0301<0008C10000a<04`074`0301<C00<C00L04a<C01<000TC00<04a<011<00`0C4`034`03

01<C00HC10024`8011<00`0C4`044`0301<C00<C0@014`4C000N4`80H1<200LC00<04a<01Q<300/C

0P0:4`0401<C4`8011<309HC0P000a<0000E4`0301<000LC00<04a<01Q<00`0C4`034`0701<C4`0C

00074`801a<00`0C4`034`0301<C00HC00<04`000Q<00`0C00044`0301<C00@C00<04a<00a<1004C

0A<00?lCDA<00`0C000F4`0301<000LC00<04`003A<01P0C4`0C00LC00<04a<031<00`0C4`074`80

0Q<00`0C00044`0301<000<C00<04a<00a<00`0C00014`00:A<200HC0P3o4alC00<04a<05Q<00`0C

4`064`<03Q<0100C4`084`<02a<200XC00@04a<C0P044`<00Q<00`0C4`034`800A<10040000[4`03

01<C008C00<04a<0oa<O4`0301<C070C000Z4`0301<C00<C00<04a<01A<00`0C4`3o4aHC00<04`00

LA<002/C00<04a<00Q<00`0C4`024`@00a<30?lC4A<200034`00070C000Y4`0301<000@C00<04`00

0Q<200034`0C00@C00<04a<0oa>44`00:Q<00`0C4`034`<011<00`0C00034`0301<C0?lCQA<003LC

00<04`0011<00`0C4`3o4h@C000e4`<011<30?lCQQ<00?lCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00001\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.38611, -1.70513, 0.0218787, 0.0218787}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -84.5 0 ]

[.5 .96488 84.5 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -145.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.485) show

222.250000 19.500000 moveto

(C) show

227.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.2595 0 m

.26171 .00328 L

.30316 .06483 L

.34309 .12412 L

.3815 .18117 L

.42237 .24186 L

.46172 .30029 L

.49955 .35648 L

.53984 .4163 L

.57861 .47388 L

.61984 .5351 L

.65954 .59407 L

.69774 .65078 L

.73838 .71114 L

.77751 .76925 L

.81909 .831 L

.85916 .8905 L

.89771 .94774 L

s

.89771 .94774 m

.90083 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.364898 0.238095 [

[.02381 .3524 -6 -9 ]

[.02381 .3524 6 0 ]

[.2619 .3524 -6 -9 ]

[.2619 .3524 6 0 ]

[.7381 .3524 -3 -9 ]

[.7381 .3524 3 0 ]

[.97619 .3524 -3 -9 ]

[.97619 .3524 3 0 ]

[1.025 .3649 0 -8 ]

[1.025 .3649 9 8 ]

[.4875 .00776 -24 -4.5 ]

[.4875 .00776 0 4.5 ]

[.4875 .1268 -12 -4.5 ]

[.4875 .1268 0 4.5 ]

[.4875 .24585 -24 -4.5 ]

[.4875 .24585 0 4.5 ]

[.4875 .48395 -18 -4.5 ]

[.4875 .48395 0 4.5 ]

[.4875 .60299 -6 -4.5 ]

[.4875 .60299 0 4.5 ]

[.4875 .72204 -18 -4.5 ]

[.4875 .72204 0 4.5 ]

[.4875 .84109 -6 -4.5 ]

[.4875 .84109 0 4.5 ]

[.5 .91164 -4.5 0 ]

[.5 .91164 4.5 16 ]

[.5 .89914 -137 0 ]

[.5 .89914 137 16 ]

[ 0 0 0 0 ]

[ 1 .88664 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .3649 m

.02381 .37115 L

s

[(-2)] .02381 .3524 0 1 Mshowa

.2619 .3649 m

.2619 .37115 L

s

[(-1)] .2619 .3524 0 1 Mshowa

.7381 .3649 m

.7381 .37115 L

s

[(1)] .7381 .3524 0 1 Mshowa

.97619 .3649 m

.97619 .37115 L

s

[(2)] .97619 .3524 0 1 Mshowa

.125 Mabswid

.07143 .3649 m

.07143 .36865 L

s

.11905 .3649 m

.11905 .36865 L

s

.16667 .3649 m

.16667 .36865 L

s

.21429 .3649 m

.21429 .36865 L

s

.30952 .3649 m

.30952 .36865 L

s

.35714 .3649 m

.35714 .36865 L

s

.40476 .3649 m

.40476 .36865 L

s

.45238 .3649 m

.45238 .36865 L

s

.54762 .3649 m

.54762 .36865 L

s

.59524 .3649 m

.59524 .36865 L

s

.64286 .3649 m

.64286 .36865 L

s

.69048 .3649 m

.69048 .36865 L

s

.78571 .3649 m

.78571 .36865 L

s

.83333 .3649 m

.83333 .36865 L

s

.88095 .3649 m

.88095 .36865 L

s

.92857 .3649 m

.92857 .36865 L

s

.25 Mabswid

0 .3649 m

1 .3649 L

s

gsave

1.025 .3649 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .00776 m

.50625 .00776 L

s

[(-1.5)] .4875 .00776 1 0 Mshowa

.5 .1268 m

.50625 .1268 L

s

[(-1)] .4875 .1268 1 0 Mshowa

.5 .24585 m

.50625 .24585 L

s

[(-0.5)] .4875 .24585 1 0 Mshowa

.5 .48395 m

.50625 .48395 L

s

[(0.5)] .4875 .48395 1 0 Mshowa

.5 .60299 m

.50625 .60299 L

s

[(1)] .4875 .60299 1 0 Mshowa

.5 .72204 m

.50625 .72204 L

s

[(1.5)] .4875 .72204 1 0 Mshowa

.5 .84109 m

.50625 .84109 L

s

[(2)] .4875 .84109 1 0 Mshowa

.125 Mabswid

.5 .03156 m

.50375 .03156 L

s

.5 .05537 m

.50375 .05537 L

s

.5 .07918 m

.50375 .07918 L

s

.5 .10299 m

.50375 .10299 L

s

.5 .15061 m

.50375 .15061 L

s

.5 .17442 m

.50375 .17442 L

s

.5 .19823 m

.50375 .19823 L

s

.5 .22204 m

.50375 .22204 L

s

.5 .26966 m

.50375 .26966 L

s

.5 .29347 m

.50375 .29347 L

s

.5 .31728 m

.50375 .31728 L

s

.5 .34109 m

.50375 .34109 L

s

.5 .38871 m

.50375 .38871 L

s

.5 .41252 m

.50375 .41252 L

s

.5 .43633 m

.50375 .43633 L

s

.5 .46014 m

.50375 .46014 L

s

.5 .50776 m

.50375 .50776 L

s

.5 .53156 m

.50375 .53156 L

s

.5 .55537 m

.50375 .55537 L

s

.5 .57918 m

.50375 .57918 L

s

.5 .6268 m

.50375 .6268 L

s

.5 .65061 m

.50375 .65061 L

s

.5 .67442 m

.50375 .67442 L

s

.5 .69823 m

.50375 .69823 L

s

.5 .74585 m

.50375 .74585 L

s

.5 .76966 m

.50375 .76966 L

s

.5 .79347 m

.50375 .79347 L

s

.5 .81728 m

.50375 .81728 L

s

.5 .8649 m

.50375 .8649 L

s

.25 Mabswid

.5 0 m

.5 .88664 L

s

gsave

.5 .91164 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .89914 -198 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.485) show

298.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

303.000000 15.000000 moveto

(L) show

310.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

317.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

324.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

329.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

333.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .88664 L

0 .88664 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .20263 m

.02576 .20262 L

.03157 .2026 L

.04115 .20257 L

.05432 .20252 L

.07087 .20247 L

.09051 .20239 L

.11291 .2023 L

.13768 .20219 L

.1644 .20206 L

.19261 .2019 L

.22183 .20172 L

.25155 .2015 L

.28128 .20125 L

.3105 .20097 L

.33871 .20064 L

.36543 .20027 L

.3902 .19986 L

.41259 .19942 L

.43224 .19896 L

.44879 .19851 L

.46196 .1981 L

.47154 .19776 L

.47735 .19754 L

.4793 .19746 L

s

.4793 .19746 m

.48143 .19738 L

.48777 .19711 L

.49821 .19663 L

.51259 .19586 L

.53064 .19468 L

.55207 .19286 L

.5765 .18996 L

.60352 .18521 L

.63267 .17749 L

.66344 .16607 L

.69532 .15162 L

.72775 .13567 L

.76017 .11945 L

.79205 .10372 L

.82282 .08889 L

.85197 .07523 L

.87899 .0629 L

.90342 .05203 L

.92485 .04271 L

.94291 .03499 L

.95728 .02895 L

.96772 .0246 L

.97406 .02198 L

.97619 .02111 L

s

.4793 .44856 m

.48143 .42164 L

.48777 .3949 L

.49821 .36856 L

.51259 .34281 L

.53064 .31792 L

.55207 .29421 L

.5765 .27225 L

.60352 .25292 L

.63267 .23744 L

.66344 .22665 L

.69532 .21997 L

.72775 .21596 L

.76017 .21348 L

.79205 .21186 L

.82282 .21076 L

.85197 .20997 L

.87899 .2094 L

.90342 .20897 L

.92485 .20866 L

.94291 .20842 L

.95728 .20825 L

.96772 .20814 L

.97406 .20807 L

.97619 .20805 L

s

.4793 .44867 m

.48143 .47568 L

.48777 .50269 L

.49821 .52951 L

.51259 .55602 L

.53064 .5821 L

.55207 .60762 L

.5765 .63248 L

.60352 .65656 L

.63267 .67976 L

.66344 .70198 L

.69532 .72311 L

.72775 .74306 L

.76017 .76176 L

.79205 .77911 L

.82282 .79505 L

.85197 .8095 L

.87899 .8224 L

.90342 .83369 L

.92485 .84333 L

.94291 .85128 L

.95728 .85749 L

.96772 .86195 L

.97406 .86464 L

.97619 .86553 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCaA<00?lCaA<006@C1@3G4`D00Q<00`0C4`024`0301<C07DC001V4`0301<C0=TC00<04a<0

1Q<00`0C00034`0301<C070C00124`033A<C01/C0`034`0301<C008C0P3?4`<00a<00`0C4`084`04

01<C4`80LA<0048C00<=4a<08A<00`0C4`024`0301<C0=@C00<04a<01Q<200@C00<04a<0L1<004<C

00<=4a<081<00`0C4`024`0301<C0=@C00<04a<01Q<00`0C4`034`0301<C070C00134`033A<C01lC

0P044`0301<C0=<C0P084`<00a<00`0C4`1G4`<=5Q<004@C00<=4a<091<20>@C00<04a<0E1<33ATC

00154`033A<C02<C00<04a<0ha<205<C0PdL4`00AA<00`dC4`0S4`0301<C0><C00<04a<0D1<23AhC

00164`033A<C028C00<04a<0ha<00`0C4`1?4`033A<C01hC00174`033A<C024C0P3T4`0301<C04dC

0PdQ4`00B1<00`dC4`0P4`0301<C0><C0P1;4`<=8a<004PC00<=4a<081<00`0C4`3S4`0301<C04PC

0PdV4`00BA<00`dC4`0O4`0301<C0><C00<04a<0AA<33BPC001:4`033A<C01hC0P3T4`0301<C04<C

0Pd[4`00BQ<00`dC4`0N4`0301<C0><C00<04a<0@A<23BdC001;4`033A<C01dC00<04a<0ha<2040C

0Pd_4`00C1<00`dC4`0L4`0301<C0><C00<04a<0?A<23C4C001<4`033A<C01`C0P3T4`0301<C03XC

0`dc4`00CA<00`dC4`0K4`0301<C0><C00<04a<0=a<33CHC001>4`033A<C00/C00<04a<00Q<00`0C

4`024`0301<C008C00<04a<0ha<203HC0Pdi4`00Ca<00`dC4`094`0301<000LC00<04`000a<00`0C

4`3S4`0301<C03<C0Pdk4`00Ca<00`dC4`044`<00Q<00`0C00094`0401<C4`80i1<00`0C4`0b4`03

3A<C03/C001@4`033A<C00PC00<04`001a<200@C00<04a<0g1<5008C00<04a<0<1<23ChC001A4`03

3A<C00LC00<04`001a<00`0C4`034`0301<C0=hC00<04a<00Q<00`0C4`0_4`033A<C03hC001A4`03

3A<C00PC00<04a<01Q<300<C00<04a<0f1<300<C00<04a<00Q<202hC0Pe14`00DQ<00`dC4`0F4`03

01<C0=hC00<04a<00Q<00`0C4`0[4`8=@a<005<C00<=4a<05A<20=lC00<04a<00Q<00`0C4`0Y4`8=

AA<005<C00<=4a<05A<00`0C4`3M4`8011<00`0C4`0W4`8=Aa<005@C00<=4a<051<00`0C4`3S4`03

01<C02DC0Pe94`00EA<00`dC4`0C4`0301<C0><C0P0S4`<=Ba<005HC00<=4a<04Q<20>@C00<04a<0

7Q<43DhC001F4`033A<C018C00<04a<0ha<00`0C4`0L4`8=DQ<001XC0`0U4`D041<00`dC4`0A4`03

01<C02@C1@0T4`<0Ta<00`0C4`0J4`8=E1<001XC00<04a<09a<00`0C4`0A4`033A<C010C00<04a<0

9Q<00`0C4`0T4`0301<C09<C0P0I4`8=EQ<001DC0`034`0301<C020C0`034`0301<C014C00<=4a<0

41<202LC00<04a<09A<00`0C4`2B4`0301<C01DC0`eH4`006a<00`0C4`0V4`0301<C018C00<=4a<0

3a<00`0C4`0V4`0301<C02DC00<04a<0TQ<00`0C4`0?4`H=Fa<001XC00<04`009a<00`0C4`0C4`03

3A<C00hC00<04a<09Q<00`0C4`0T4`0301<009<C00<04a<02Q<53F4C000K4`0301<C02DC0P0E4`03

3A<C00hC00<04a<09A<202LC00<04a<0Sa<@3FHC001K4`033A<C00dC0P294eP=0a<2074C001K4`03

3A<C00dC00<04a<0ha<00`0C4`1`4`00G1<00`dC4`0<4`0301<C05/C0P264`0301<C03<C9`dF4`00

GA<00`dC4`0;4`0301<C05XC00<04a<0QQ<00`0C4`0W4``=?A<001DCB0000`d0001R00HC00<04a<0

QQ<2024C1`e94`006A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<0

1A<00`0C4`064`0301<C00DC00@04a<=11<00`0C4`054`0341<C00DC00<04a<01Q<00`0C4`054`03

01<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<0

21<00`0C4`264`0301<C01/C1@e@4`00Ga<00`dC4`094`0341<C05XC00<04`00QQ<00`0C4`0I4`8=

EA<005lC00<=4a<02A<245/C0`1g4`0301<C008C00<04a<00Q<00`0C4`024`0301<C01LC0PeG4`00

H1<00`dC4`084`8@e1<00`0C00074`0301<000<C00<04a<05A<23ETC001Q4`033A<C00HC00<@0100

ca<3008C00<04`002A<0100C4a<201@C0PeK4`00HA<00`dC4`064`03400@0=@C00<04`001a<200@C

00<04a<04A<23EdC001R4`033A<C00DC00<@0100e1<00`0C00074`0301<C00<C00<04a<041<00`dC

4`1M4`00Ha<00`dC4`034`0541<00100e1<00`0C4`064`<00a<00`0C4`0>4`8=H1<006@C00<=4a<0

0Q<01A0C01<@0><C0P0>4`033A<C060C001T4`033A<C008C00D@4`0C403S4`0301<C00`C00<=4a<0

HA<006DC00L=4a<C41<0008C00<@4a<0h1<00`0C4`0;4`033A<C068C001V4`053A<C41<00P000a<@

4`3Q4`0301<C00TC0PeU4`00IQ<01PdC4a0C008C00<@4a<0h1<00`0C4`084`033A<C06DC001W4`05

3A0C4`000a<00a0C4`3O4`8021<00`dC4`1V4`00J1<010dC4`034`0341<C0=lC00<04a<01Q<00`dC

4`1W4`00J1<00`dC4`02008C00<@4a<0ga<00`0C4`054`033A<C06PC001W4`0541<=4`0011<00a0C

4`244`<0:A<502TC00<04a<01A<00`dC4`0P4`D0:Q<301HC001L4`0301<C008C00<04a<00Q<01P0@

4a<=00@C00<@4a<0Q1<00`0C4`0[4`0301<C02TC00<04a<011<00`dC4`0S4`0301<C02XC00<04a<0

5Q<005/C00<04`001a<00`0@00024`033@0C00<C00<@4a<0Oa<300<C00<04a<091<300<C00<04a<0

:A<200@C00<=4a<091<00`0C4`0[4`0301<C01DC001K4`0301<000PC00<@01<00Q<00`d04`034`03

41<C08@C00<04a<0:Q<00`0C4`0Y4`0301<C008C00<=4a<09A<00`0C4`0[4`0301<C01DC001K4`03

01<000LC00<041<00a<00`0=4`034`0341<C08<C00<04`00:a<00`0C4`0Y4`0501<C4`d0:1<00`0C

4`0Z4`0301<001HC001K4`0301<000LC00<@4a<00a<00`0=4`044`0341<C08<C00<04a<0:A<202/C

00D04a<C3@0W4`80;A<00`0C4`0E4`00G1<00`0C4`064`03400000<C00<04`d011<00a0C4`3L4`80

00<C3A<0KQ<006@C00<@4a<011<200034`dC008C00<@4a<0g1<00`0C3@1`4`00I1<00a0C4`044`04

01<C3@@C00<@4a<0fa<00`0C3@1`4`00Ha<00a0C4`054`0501<C4`d00a<00a0C4`3K4`0300dC06HC

0P084`00Ha<00a0C4`054`0501<C4`d011<00a0C4`3J4`0300dC06DC00<04a<021<0068C00<@4a<0

1Q<00`0C4`024`053A<C4a00O1=P00033@0005h01a<00`0C4`084`00HQ<00a0C4`064`8011<01@dC

4a<@080C00<04a<0:Q<00`0C4`0[4`033A<C02/C00<04a<0:a<00`0C4`094`0301<C00PC001Q4`03

41<C00LC00<04a<00a<01@dC4a<@0=XC00<=01<0IQ<00`0C00084`00HA<00a0C4`074`0301<C00@C

00@=4a<@fQ<00`d04`1V4`<021<0060C00<@4a<021<00`0C4`054`043A<C4=PC00@=4`00LA<0060C

00<@4a<021<200LC00<=4a00f1<00`dC001b4`00Ga<00a0C4`094`0301<C00HC00@=4a<@ea<00`dC

001b4`00Ga<00a0C4`094`0301<C00LC00<=4a00ea<00`dC001b4`00GQ<00a0C4`0:4`0301<C00PC

00<=4a00eA<010dC4`1b4`00GQ<00a0C4`0:4`802Q<00`d@4`3D4`033A<C0080LA<005dC00<@4a<0

2a<00`0C4`094`033A<@0=@C00@=4a<0LQ<005dC00<@4a<011<5008C00<04a<02Q<00`d@4`3C4`04

3A<C078C001L4`0341<C00LC00<04a<00Q<00`0C4`0;4`033A0C0=8C00@=4a<0LQ<005/C00<@4a<0

21<00`0C4`024`803A<00`d@4`3A4`033A<C0080LA<005/C00<@4a<021<00`0C4`024`0301<C00`C

00<=41<0d1<01@dC4a<0078C001J4`0341<C00TC00<04a<00Q<00`0C4`0=4`033A0C0<lC00D=4a<C

001b4`00FQ<00a0C4`084`8011<00`0C4`0>4`033A0C0<hC00D=4a<C001b4`00FA<00a0C4`0?4`80

3a<00`d@4`3>4`053A<C4`00LQ<005PC00<@4a<041<00`0C4`0?4`033A0C0<dC00@=4a<C0P1a4`00

F1<00a0C4`0@4`0301<C00lC00<=4a00cQ<010dC4`1b4`00Ea<00a0C4`0A4`0301<C010C00<=41<0

cA<010dC4`1b4`00EQ<00a0C4`0B4`804Q<00`d@4`304`0301<C008C00<04a<00Q<00`0C3@024`03

01<C070C001F4`0341<C018C00<04a<04A<00`dC402o4`0301<000LC00@04`0=0Q<00`0C4`1`4`00

EA<00a0C4`0C4`0301<C018C00<=41<0_Q<00`0C00094`0400dC4`80LA<005@C00<@4a<051<00`0C

4`0C4`033A0C0;dC00<04`001a<2008C00<=4`00LQ<005<C00<@4a<05A<201@C00<=41<0_A<00`0C

00074`0701<C4`dC001b4`00Da<00a0C4`0E4`0301<C01@C00<=41<0_A<00`0C4`064`<000@C3A<0

LQ<0058C00<@4a<05Q<00`0C4`0E4`033A0C0<TC00@=4`00LA<0054C00<@4a<05a<00`0C4`0E4`03

3A0C0<XC00<=01<0LA<0054C00<@4a<05a<201LC00<=41<0bA<00`d04`1a4`00D1<00a0C4`0H4`03

01<C01LC00<=4a<0bA<00`dC4`1`4`00Ca<00a0C4`084`D00Q<00`0C4`024`0301<C008C00<04a<0

61<00`dC4`384`033A<C070C001?4`0341<C00XC00<04a<01Q<00`0C00034`0301<C01PC00<=41<0

b1<00`0=4`1`4`00CQ<00a0C4`0;4`0301<C00PC00@04a<C0P0J4`033A0C0<LC00<03A<0L1<004dC

00<@4a<031<00`0C4`064`8011<00`0C4`0J4`033A<C0<HC00<04`d0L1<004`C00<@4a<03A<00`0C

4`064`0301<C00<C00<04a<06Q<00`d@4`364`0301<=070C001<4`0341<C00`C0P084`<00a<00`0C

4`0K4`033A0C0<DC0P000a<=4`1^4`00Ba<00a0C4`0M4`8071<00`dC40354`0501<C4`d0KQ<004XC

00<@4a<07Q<00`0C4`0L4`033A0C0<@C00D04a<C3@1^4`00BQ<00a0C4`0N4`0301<C01dC00<=41<0

`a<00`0C4`024`033A<C06/C00194`0341<C01lC00<04a<07A<00`dC40334`0301<C008C00<=4a<0

Ja<004PC00<@4a<081<201lC00<=4a00`Q<200@C00<=4a<0JQ<004LC00<@4a<08A<00`0C4`0N4`04

3A<C4<4C00<04a<011<00`dC4`1Y4`00Aa<00a0C4`0Q4`0301<C01lC00<=4a00^Q<5008C00<04a<0

1A<00`dC4`1X4`00AQ<00a0C4`0R4`0301<C020C00<=4a00^a<00`0C4`024`0301<C00DC00<=4a<0

J1<004DC00<@4a<08a<2024C00@=4a<@^Q<00`0C4`024`801a<00`dC4`1W4`00A1<00a0C4`0T4`03

01<C024C00@=4a<@^A<00`0C4`024`0301<C00LC00<=4a<0IQ<004@C00<@4a<091<00`0C4`0R4`03

3A<@0;TC00<04a<00Q<00`0C4`084`033A<C06DC00134`0341<C02DC00<04a<08Q<010dC4a2g4`80

11<00`0C4`094`033A<C06@C00124`0341<C02HC00<04a<08a<010dC4a2l4`0301<C00XC00<=4a<0

Ha<0044C00<@4a<09a<202DC00@=4a<@^a<200`C00<=4a<0HQ<0040C00<@4a<0:1<00`0C4`0U4`04

3A<C4;XC00<04a<031<00`dC4`1Q4`00@1<00a0C4`0R4`<00a<00`0C4`0U4`053A<C4a00^A<00`0C

4`0=4`033A<C060C000o4`0341<C02<C00<04a<00a<00`0C4`0V4`043A<C4;TC00<04a<03Q<00`dC

4`1O4`00?Q<00a0C4`0U4`0301<C008C0P0X4`043A<C4;PC00<04a<03a<00`dC4`1N4`00?A<00a0C

4`0V4`0301<C008C00<04a<09a<01@dC4a<@0;LC0P0A4`033A<C05dC000m4`0341<C02DC00<04`00

0a<00`0C4`0X4`053A<C4a00]Q<00`0C4`0A4`033A<C05`C000l4`0341<C02LC00<04a<00Q<00`0C

4`0Y4`053A<C4a00]A<00`0C4`0B4`8=G1<003/C00<@4a<0;A<202XC00<=4a<00Q<00a0C4`2b4`03

01<C01@C00<=4a<0FA<003XC00<@4a<0;Q<00`0C4`0Z4`053A<C4a00]1<201HC0PeI4`00>Q<00a0C

4`0^4`0301<C02/C00D=4a<C402c4`0301<C01LC00<=4a<0EQ<003TC00<@4a<0;a<00`0C4`0/4`05

3A<C4a00/Q<00`0C4`0H4`033A<C05DC000h4`0341<C030C0P0]4`033A<C008C00<@4a<0[a<00`0C

4`0I4`8=EA<003LC00<@4a<0<A<00`0C4`0]4`053A<C4a00/A<00`0C4`0K4`033A<C058C000g4`03

41<C034C00<04a<0;Q<01@dC4a<@0;0C0P0M4`033A<C054C000f4`0341<C038C00<04a<0;Q<00`dC

4`024`0341<C0:dC00<04a<07A<23E4C000e4`0341<C03<C0P0`4`033A<C008C00<@4a<0Va<5008C

00<04a<00Q<00`0C4`024`0301<C01lC0Pe?4`00=1<00a0C4`0d4`0301<C030C00<=4a<00Q<00a0C

4`2L4`0301<C00HC00<04`000a<00`0C4`0Q4`8=CA<003<C00<@4a<0=A<00`0C4`0`4`033A<C00<C

00<@4a<0Va<00`0C4`084`0401<C4`8091<00`dC4`1:4`00<Q<00a0C4`0f4`0301<C034C00<=4a<0

0Q<00a0C4`2K4`0301<C00HC0P044`0301<C02@C0Pe:4`00<A<00a0C4`0g4`80<Q<00`dC4`034`03

41<C09XC00<04a<01Q<00`0C4`034`0301<C02HC00<=4a<0Aa<0030C00<@4a<0>1<00`0C4`0b4`03

3A<C00<C00<@4a<0V1<200PC0`034`0301<C02LC0Pe74`00;a<00a0C4`0Y4`<00a<00`0C4`024`03

01<C008C00<04a<0<a<00`dC4`034`0341<C0:LC00<04a<0:A<00`dC4`144`00;Q<00a0C4`0Z4`03

01<C00LC00<04`000a<00`0C4`0c4`033A<C00@C00<@4a<0YQ<202/C0Pe44`00;A<00a0C4`0/4`03

01<C00PC00@04a<C0P0e4`033A<C00@C00<@4a<0YA<00`0C4`0/4`033A<C044C000/4`0341<C02dC

00<04a<01Q<200@C00<04a<0=A<00`dC4`044`0341<C0:@C00<04a<0;A<23D4C000[4`0341<C02dC

00<04`001a<00`0C4`034`0301<C03DC00<=4a<01A<00a0C4`2S4`0301<C02lC00<=4a<0?Q<002XC

00<@4a<0;a<00`0C4`064`<00a<00`0C4`0f4`033A<C00DC00<@4a<0XQ<2034C0Pdn4`00:A<00a0C

4`0o4`80>1<00`dC4`054`0341<C0:4C00<04a<0<Q<23C`C000X4`0341<C040C00<04a<0=a<00`dC

4`064`0341<C0:0C00<04a<0=1<23CXC000W4`0341<C044C00<04a<0>1<00`dC4`064`0341<C09lC

00<04a<0=Q<23CPC000V4`0341<C048C00<04a<0>A<00`dC4`064`0341<C09hC00<04a<0>1<23CHC

000U4`0341<C04<C0P0k4`033A<C00HC00<@4a<0WA<203/C0Pdd4`0091<00a0C4`144`0301<C03XC

00<=4a<01a<00a0C4`2L4`0301<C03`C0Pdb4`008a<00a0C4`154`0301<C03/C00<=4a<01a<00a0C

4`2K4`0301<C03hC0Pd`4`008a<00a0C4`154`0301<C03`C00<=4a<01a<00a0C4`2J4`0301<C040C

0Pd^4`008Q<00a0C4`164`80?A<00`dC4`084`0341<C09TC00<04a<0@Q<23B`C000Q4`0341<C04LC

00<04a<0?A<00`dC4`084`0341<C09PC0P154`8=:Q<0020C00<@4a<0B1<00`0C4`0m4`033A<C00TC

00<@4a<0Ua<00`0C4`164`8=:1<001lC00<@4a<0BA<00`0C4`0n4`033A<C00TC00<@4a<0T1<300<C

00<04a<0B1<23BHC000N4`0341<C04XC0P104`033A<C00TC00<@4a<0Sa<00`0C4`034`0301<C04XC

0PdT4`007A<00a0C4`1;4`0301<C03lC00<=4a<02Q<00a0C4`2?4`0301<C008C0P1=4`8=8Q<001`C

00<@4a<0C1<00`0C4`104`033A<C00XC00<@4a<0SQ<00`0C4`024`0301<C04hC0`dO4`006a<00a0C

4`174`8011<00`0C4`104`033A<C00/C00<@4a<0S1<00`0C00034`0301<C054C0`dL4`006Q<00a0C

4`1:4`0501<C4`00@a<00`dC4`0;4`0341<C08`C00<04a<00Q<00`0C4`1D4`8=6Q<001TC00<@4a<0

BQ<00`0C4`024`80@a<00`dC4`0:4`0341<C094C00<04a<0EQ<23APC001W4`0301<C0>LC0P1I4`8=

5Q<006DC00<04`00jA<00`0C4`1`4`00IQ<00`0C4`3X4`0301<C070C000Z4`<0oa<U4`0301<C070C

000Z4`0301<C0?lC9A<00`0C4`1`4`00:a<00`0C4`044`0301<C0?lCT1<002/C00@04a<C10034`<0

oa><4`00:Q<00`0C00024`8000<C01<011<00`0C4`3o4hXC000[4`0301<C00<C00<04`000a<00`0C

4`3o4h/C000a4`0301<000@C00<04a<01Q<00`0C4`0W4`<0:a<00`0C4`3o4bTC000K4`<000<C0000

0P0<4`<011<300PC00<04a<09Q<0100C4`0?4`<000<C00000P024`0301<C008C00<04a<00Q<00`0C

4`054`0401<C4`D00Q<00`0C4`024`<00Q<00`0C4`024`0301<C00@C0P354`0301<C03LC00<04a<0

1Q<001XC00@04a<091<00`0C4`0U4`0401<C00hC00@04a<01Q<00`0C00074`0301<000@C1@034`03

01<C00PC00H04a<04`024`0301<000@C00<04a<0_A<00`0C4`044`0301<C01<C00<04a<08a<00`0C

4`054`006Q<01@0C4`0C00@000<C0000600]4`<03Q<01@0C4`0C00@000@C01<02A<00`0C4`044`03

01<C00<C00<04a<01Q<400044`0C00@C00<04a<00Q<00`0C4`2[4`0401<C4`@00Q<200HC00<04a<0

0a<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`054`0401<C4`D00Q<00`0C4`024`<00Q<00`0C

4`024`0301<C00@C0P044`0401<C4`800A<001/C0`1?4`0301<C00dC0`064`0301<000LC0P074`03

01<C00<C00<04a<01Q<00`0C00034`0401<C4`801A<00`0C4`2Z4`0301<000LC00<04a<011<500<C

00L04a<C01<000LC00<04`0011<500<C00<04a<021<01P0C4`0C008C00<04`0011<00`0C4`044`03

01<C008C0@014`007A<00`0C4`1<4`804A<00`0C4`044`0301<000LC00<04a<031<00`0C4`074`80

0Q<00`0C00024`0301<C00@C00<04`00ZQ<00`0C00024`@000<C01<01a<00`0C4`034`0701<C4`0C

00094`0301<C00@C00<04a<00a<00`0C4`064`@000@C01<011<00`0C4`024`0301<C00@C00<04a<0

0a<1000071<2060C0P074`0301<C00HC0`0;4`802Q<01@0C4a<000<C0`044`<0Ta<200034`00018C

00<04`001a<00`0C4`064`0301<C00<C00L04a<C01<000LC0P074`0301<C00<C00<04a<01Q<00`0C

00034`0401<C4`801A<00`0C4`044`0301<C00<C0@000?lCDA<00`0C000C4`0301<000LC00<04`00

3A<01P0C4`0C00LC00<04a<031<00`0C4`074`800Q<00`0C00024`0301<C00@C00<04`000a<00`0C

4`034`400A<002HC0P064`80oa<R4`0301<C01<C00<04a<01Q<300hC00@04a<021<300/C0P0:4`05

01<C4`000a<300@C0`024`0301<C00<C0P014`00:1<00`0C4`024`0301<C0?lC8Q<00`0C4`1`4`00

9a<00`0C4`034`0301<C00HC00<04a<0oa<H4`0301<0074C000X4`0301<C008C00<04a<00Q<30004

4`0C4`<0oa<D4`8000<C0000L1<002HC00<04`0011<00`0C00024`800Q<00`0C4`024`0301<C0?lC

Qa<002LC00<04a<00a<300@C00@04a<00Q<00`0C4`3o4hPC000d4`0401<C00<C00<04a<0oa>74`00

<Q<300@C0`3o4hTC003o4lDC003o4lDC003o4lDC003o4lDC003o4lDC0000\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.38154, -1.70499, 0.0218652, 0.0218652}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -82 0 ]

[.5 .96488 82 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -143 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.48) show

217.250000 19.500000 moveto

(C) show

222.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.25869 0 m

.26171 .00447 L

.30316 .06581 L

.34309 .12491 L

.3815 .18176 L

.42237 .24224 L

.46172 .30048 L

.49955 .35648 L

.53984 .4161 L

.57861 .47349 L

.61984 .5345 L

.65954 .59327 L

.69774 .64979 L

.73838 .70995 L

.77751 .76786 L

.81909 .8294 L

.85916 .8887 L

.89771 .94576 L

s

.89771 .94576 m

.90219 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.363614 0.238095 [

[.02381 .35111 -6 -9 ]

[.02381 .35111 6 0 ]

[.2619 .35111 -6 -9 ]

[.2619 .35111 6 0 ]

[.7381 .35111 -3 -9 ]

[.7381 .35111 3 0 ]

[.97619 .35111 -3 -9 ]

[.97619 .35111 3 0 ]

[1.025 .36361 0 -8 ]

[1.025 .36361 9 8 ]

[.4875 .00647 -24 -4.5 ]

[.4875 .00647 0 4.5 ]

[.4875 .12552 -12 -4.5 ]

[.4875 .12552 0 4.5 ]

[.4875 .24457 -24 -4.5 ]

[.4875 .24457 0 4.5 ]

[.4875 .48266 -18 -4.5 ]

[.4875 .48266 0 4.5 ]

[.4875 .60171 -6 -4.5 ]

[.4875 .60171 0 4.5 ]

[.4875 .72076 -18 -4.5 ]

[.4875 .72076 0 4.5 ]

[.4875 .8398 -6 -4.5 ]

[.4875 .8398 0 4.5 ]

[.5 .9098 -4.5 0 ]

[.5 .9098 4.5 16 ]

[.5 .8973 -134.5 0 ]

[.5 .8973 134.5 16 ]

[ 0 0 0 0 ]

[ 1 .8848 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .36361 m

.02381 .36986 L

s

[(-2)] .02381 .35111 0 1 Mshowa

.2619 .36361 m

.2619 .36986 L

s

[(-1)] .2619 .35111 0 1 Mshowa

.7381 .36361 m

.7381 .36986 L

s

[(1)] .7381 .35111 0 1 Mshowa

.97619 .36361 m

.97619 .36986 L

s

[(2)] .97619 .35111 0 1 Mshowa

.125 Mabswid

.07143 .36361 m

.07143 .36736 L

s

.11905 .36361 m

.11905 .36736 L

s

.16667 .36361 m

.16667 .36736 L

s

.21429 .36361 m

.21429 .36736 L

s

.30952 .36361 m

.30952 .36736 L

s

.35714 .36361 m

.35714 .36736 L

s

.40476 .36361 m

.40476 .36736 L

s

.45238 .36361 m

.45238 .36736 L

s

.54762 .36361 m

.54762 .36736 L

s

.59524 .36361 m

.59524 .36736 L

s

.64286 .36361 m

.64286 .36736 L

s

.69048 .36361 m

.69048 .36736 L

s

.78571 .36361 m

.78571 .36736 L

s

.83333 .36361 m

.83333 .36736 L

s

.88095 .36361 m

.88095 .36736 L

s

.92857 .36361 m

.92857 .36736 L

s

.25 Mabswid

0 .36361 m

1 .36361 L

s

gsave

1.025 .36361 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .00647 m

.50625 .00647 L

s

[(-1.5)] .4875 .00647 1 0 Mshowa

.5 .12552 m

.50625 .12552 L

s

[(-1)] .4875 .12552 1 0 Mshowa

.5 .24457 m

.50625 .24457 L

s

[(-0.5)] .4875 .24457 1 0 Mshowa

.5 .48266 m

.50625 .48266 L

s

[(0.5)] .4875 .48266 1 0 Mshowa

.5 .60171 m

.50625 .60171 L

s

[(1)] .4875 .60171 1 0 Mshowa

.5 .72076 m

.50625 .72076 L

s

[(1.5)] .4875 .72076 1 0 Mshowa

.5 .8398 m

.50625 .8398 L

s

[(2)] .4875 .8398 1 0 Mshowa

.125 Mabswid

.5 .03028 m

.50375 .03028 L

s

.5 .05409 m

.50375 .05409 L

s

.5 .0779 m

.50375 .0779 L

s

.5 .10171 m

.50375 .10171 L

s

.5 .14933 m

.50375 .14933 L

s

.5 .17314 m

.50375 .17314 L

s

.5 .19695 m

.50375 .19695 L

s

.5 .22076 m

.50375 .22076 L

s

.5 .26838 m

.50375 .26838 L

s

.5 .29219 m

.50375 .29219 L

s

.5 .316 m

.50375 .316 L

s

.5 .3398 m

.50375 .3398 L

s

.5 .38742 m

.50375 .38742 L

s

.5 .41123 m

.50375 .41123 L

s

.5 .43504 m

.50375 .43504 L

s

.5 .45885 m

.50375 .45885 L

s

.5 .50647 m

.50375 .50647 L

s

.5 .53028 m

.50375 .53028 L

s

.5 .55409 m

.50375 .55409 L

s

.5 .5779 m

.50375 .5779 L

s

.5 .62552 m

.50375 .62552 L

s

.5 .64933 m

.50375 .64933 L

s

.5 .67314 m

.50375 .67314 L

s

.5 .69695 m

.50375 .69695 L

s

.5 .74457 m

.50375 .74457 L

s

.5 .76838 m

.50375 .76838 L

s

.5 .79219 m

.50375 .79219 L

s

.5 .816 m

.50375 .816 L

s

.5 .86361 m

.50375 .86361 L

s

.25 Mabswid

.5 0 m

.5 .8848 L

s

gsave

.5 .9098 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .8973 -195.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.48) show

293.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

298.000000 15.000000 moveto

(L) show

305.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

312.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

319.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

324.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

328.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .8848 L

0 .8848 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .20092 m

.02576 .20091 L

.03157 .2009 L

.04114 .20087 L

.05432 .20083 L

.07087 .20077 L

.09051 .2007 L

.11291 .20062 L

.13768 .20051 L

.16439 .20039 L

.1926 .20024 L

.22182 .20007 L

.25154 .19987 L

.28127 .19964 L

.31048 .19937 L

.33869 .19907 L

.36541 .19872 L

.39018 .19834 L

.41257 .19793 L

.43222 .19751 L

.44877 .19709 L

.46194 .1967 L

.47152 .19639 L

.47733 .19619 L

.47928 .19612 L

s

.47928 .19612 m

.4814 .19604 L

.48774 .19579 L

.49819 .19534 L

.51256 .19463 L

.53062 .19353 L

.55205 .19183 L

.57648 .18912 L

.6035 .18463 L

.63265 .17721 L

.66343 .166 L

.6953 .15163 L

.72773 .13568 L

.76016 .11945 L

.79204 .10369 L

.82281 .08885 L

.85196 .07518 L

.87898 .06285 L

.90342 .05198 L

.92485 .04266 L

.9429 .03495 L

.95728 .0289 L

.96772 .02456 L

.97406 .02194 L

.97619 .02107 L

s

.47928 .44731 m

.4814 .4204 L

.48774 .39367 L

.49819 .36732 L

.51256 .34155 L

.53062 .31661 L

.55205 .29281 L

.57648 .2707 L

.6035 .25113 L

.63265 .23539 L

.66343 .22442 L

.6953 .21769 L

.72773 .21371 L

.76016 .21128 L

.79204 .2097 L

.82281 .20863 L

.85196 .20787 L

.87898 .20732 L

.90342 .20692 L

.92485 .20661 L

.9429 .20639 L

.95728 .20623 L

.96772 .20612 L

.97406 .20606 L

.97619 .20604 L

s

.47928 .44742 m

.4814 .4744 L

.48774 .50139 L

.49819 .52818 L

.51256 .55466 L

.53062 .58071 L

.55205 .6062 L

.57648 .63103 L

.6035 .65508 L

.63265 .67824 L

.66343 .70042 L

.6953 .72152 L

.72773 .74145 L

.76016 .76012 L

.79204 .77745 L

.82281 .79336 L

.85196 .80779 L

.87898 .82067 L

.90342 .83195 L

.92485 .84157 L

.9429 .8495 L

.95728 .85571 L

.96772 .86016 L

.97406 .86284 L

.97619 .86374 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCaA<00?lCaA<006@C1@3G4`D00Q<00`0C4`024`0301<C07DC001V4`0301<C0=TC00<04a<0

1Q<00`0C00034`0301<C070C00124`033A<C01/C0`034`0301<C008C0P3?4`<00a<00`0C4`084`04

01<C4`80LA<0048C00<=4a<08A<00`0C4`024`0301<C0=@C00<04a<01Q<200@C00<04a<0L1<004<C

00<=4a<081<00`0C4`024`0301<C0=@C00<04a<01Q<00`0C4`034`0301<C070C00134`033A<C01lC

0P044`0301<C0=<C0P084`<00a<00`0C4`1H4`8=5Q<004@C00<=4a<091<20>@C00<04a<0EA<33APC

00154`033A<C02<C00<04a<0ha<205@C0PdK4`00AA<00`dC4`0S4`0301<C0><C00<04a<0DA<23AdC

00164`033A<C028C00<04a<0ha<00`0C4`1?4`8=7a<004LC00<=4a<08A<20>@C00<04a<0CA<23B4C

00184`033A<C020C00<04a<0ha<204/C0`dS4`00B1<00`dC4`0P4`0301<C0><C00<04a<0B1<23BHC

00194`033A<C01lC00<04a<0ha<00`0C4`154`<=:1<004XC00<=4a<07Q<20>@C00<04a<0@a<23B/C

001:4`033A<C01hC00<04a<0ha<00`0C4`114`8=;A<004/C00<=4a<07A<00`0C4`3S4`80@1<23BlC

001<4`033A<C01`C00<04a<0ha<00`0C4`0m4`8=<A<004`C00<=4a<071<20>@C00<04a<0>a<23C<C

001=4`033A<C01/C00<04a<0ha<00`0C4`0i4`8==A<004dC00<=4a<031<00`0C4`024`0301<C008C

00<04a<00Q<00`0C4`3S4`80>1<23CLC001>4`033A<C00XC00<04`001a<00`0C00034`0301<C0><C

00<04a<0=A<23CTC001?4`033A<C00@C0`024`0301<000TC00@04a<C0P3T4`0301<C03<C0Pdk4`00

Ca<00`dC4`094`0301<000LC0P044`0301<C0=`C1@024`0301<C034C0Pdm4`00D1<00`dC4`084`03

01<000LC00<04a<00a<00`0C4`3N4`0301<C008C00<04a<0;a<23ClC001A4`033A<C00PC00<04a<0

1Q<300<C00<04a<0f1<300<C00<04a<00Q<202hC0Pe14`00DQ<00`dC4`0F4`0301<C0=hC00<04a<0

0Q<00`0C4`0[4`8=@a<0058C00<=4a<05Q<20=lC00<04a<00Q<00`0C4`0Y4`8=AA<005<C00<=4a<0

5A<00`0C4`3M4`8011<00`0C4`0W4`8=Aa<005@C00<=4a<051<00`0C4`3S4`0301<C02DC0Pe94`00

EA<00`dC4`0C4`0301<C0><C0P0T4`8=Ba<005DC00<=4a<04a<20>@C00<04a<08A<23DdC001F4`03

3A<C018C00<04a<0ha<00`0C4`0O4`8=Ca<001XC0`0U4`D041<00`dC4`0A4`0301<C02@C1@0T4`<0

Ta<00`0C4`0L4`<=DA<001XC00<04a<09a<00`0C4`0A4`033A<C010C00<04a<09Q<00`0C4`0T4`03

01<C09<C0P0J4`<=E1<001DC0`034`0301<C020C0`034`0301<C014C00<=4a<041<202LC00<04a<0

9A<00`0C4`2B4`0301<C01DC10eG4`006a<00`0C4`0V4`0301<C018C00<=4a<03a<00`0C4`0V4`03

01<C02DC00<04a<0TQ<00`0C4`0?4`H=Fa<001XC00<04`009a<00`0C4`0C4`033A<C00hC00<04a<0

9Q<00`0C4`0T4`0301<009<C00<04a<02Q<53F4C000K4`0301<C02DC0P0E4`033A<C00hC00<04a<0

9A<202LC00<04a<0Sa<@3FHC001K4`033A<C00dC0P294eP=0a<2074C001K4`033A<C00dC00<04a<0

ha<00`0C4`1A4`T=5Q<005`C00<=4a<031<00`0C4`1K4`80QQ<00`0C4`0]4b@=7a<005dC00<=4a<0

2a<00`0C4`1J4`0301<C08HC00<04a<09a<63D<C000E4dP000<=0000HP064`0301<C08HC0P0R4`H=

BA<001TC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<0

1Q<00`0C4`054`0401<C3@@C00<04a<01A<00a0C4`054`0301<C00HC00<04a<01A<00`0C4`054`03

01<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00PC00<04a<0

QQ<00`0C4`0L4`D=Ca<005lC00<=4a<02A<00a0C4`1J4`0301<008HC00<04a<06A<33E@C001O4`03

3A<C00TC0Q1K4`<0Ma<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`0G4`8=Ea<0060C00<=4a<0

21<24=@C00<04`001a<00`0C00034`0301<C01DC0PeI4`00HA<00`dC4`064`03400@0<lC0`024`03

01<000TC00@04a<C0P0D4`8=Fa<0064C00<=4a<01Q<00a00403D4`0301<000LC0P044`0301<C014C

0PeM4`00HQ<00`dC4`054`03400@0=@C00<04`001a<00`0C4`034`0301<C010C00<=4a<0GA<006<C

00<=4a<00a<01A0C000@0=@C00<04a<01Q<300<C00<04a<03Q<23F0C001T4`033A<C008C00D@4`0C

403S4`803Q<00`dC4`1P4`00I1<00`dC4`024`0541<04a00ha<00`0C4`0<4`033A<C064C001U4`07

3A<C4a0C00024`0341<C0>0C00<04a<02a<00`dC4`1R4`00IQ<01@dC4a0C008000<C41<0hA<00`0C

4`094`8=IA<006HC00H=4a<@4`024`0341<C0>0C00<04a<021<00`dC4`1U4`00Ia<01@d@4a<000<C

00<@4a<0ga<200PC00<=4a<0IQ<006PC00@=4a<00a<00a0C4`3O4`0301<C00HC00<=4a<0Ia<006PC

00<=4a<00P024`0341<C0=lC00<04a<01A<00`dC4`1X4`00Ia<01A0C3A<000@C00<@4a<0Q1<302TC

1@0Y4`0301<C00DC00<=4a<081<502XC0`0F4`00G1<00`0C4`024`0301<C008C00H041<C3@044`03

41<C08@C00<04a<0:a<00`0C4`0Y4`0301<C00@C00<=4a<08a<00`0C4`0Z4`0301<C01HC001K4`03

01<000LC00<040000Q<00`d04`034`0341<C07lC0`034`0301<C02@C0`034`0301<C02TC0P044`03

3A<C02@C00<04a<0:a<00`0C4`0E4`00Fa<00`0C00084`03400C008C00<=01<00a<00a0C4`244`03

01<C02XC00<04a<0:A<00`0C4`024`033A<C02DC00<04a<0:a<00`0C4`0E4`00Fa<00`0C00074`03

010C00<C00<03A<00a<00a0C4`234`0301<002/C00<04a<0:A<01@0C4a<=02PC00<04a<0:Q<00`0C

000F4`00Fa<00`0C00074`0341<C00<C00<03A<011<00a0C4`234`0301<C02TC0P0[4`0501<C4`d0

9a<202dC00<04a<05A<005`C00<04a<01Q<00a0000034`0301<=00@C00<@4a<0g1<200034`dC06hC

001T4`0341<C00@C0P000a<=4`024`0341<C0=`C00<04`d0L1<006@C00<@4a<011<0100C4`d44`03

41<C0=/C00<04`d0L1<006<C00<@4a<01A<01@0C4a<=00<C00<@4a<0fa<00`0=4`1V4`8021<006<C

00<@4a<01A<00`0C4`024`053A<C4a00g1<00`0=4`1U4`0301<C00PC001R4`0341<C00HC00<04a<0

0a<010dC4a1l4f0000<=0000GP074`0301<C00PC001R4`0341<C00HC0P044`053A<C4a00P1<00`0C

4`0Z4`0301<C02/C00<=4a<0:a<00`0C4`0[4`0301<C00TC00<04a<021<0064C00<@4a<01a<00`0C

4`044`043A<C4=XC00<=01<0IQ<00`0C00084`00HA<00a0C4`074`0301<C00DC00<=4a00fQ<00`d0

4`1V4`<021<0060C00<@4a<021<00`0C4`054`043A<C4=PC00@=4`00LA<0060C00<@4a<021<200LC

00<=4a00f1<00`dC001b4`00Ga<00a0C4`094`0301<C00LC00<=4a00ea<00`dC001b4`00Ga<00a0C

4`094`0301<C00LC00<=4a00ea<00`dC001b4`00GQ<00a0C4`0:4`0301<C00PC00<=4a00eA<010dC

4`1b4`00GQ<00a0C4`0:4`802Q<00`d@4`3D4`033A<C0080LA<005dC00<@4a<02a<00`0C4`0:4`03

3A0C0=<C00@=4a<0LQ<005dC00<@4a<011<5008C00<04a<02Q<00`d@4`3C4`043A<C078C001L4`03

41<C00LC00<04a<00Q<00`0C4`0;4`033A0C0=8C00@=4a<0LQ<005/C00<@4a<021<00`0C4`024`80

3A<00`d@4`3A4`033A<C0080LA<005/C00<@4a<021<00`0C4`024`0301<C00`C00<=41<0d1<01@dC

4a<0078C001J4`0341<C00TC00<04a<00Q<00`0C4`0=4`033A0C0<lC00D=4a<C001b4`00FQ<00a0C

4`084`8011<00`0C4`0>4`033A0C0<hC00D=4a<C001b4`00FA<00a0C4`0?4`803a<00`d@4`3>4`05

3A<C4`00LQ<005PC00<@4a<041<00`0C4`0?4`033A0C0<dC00@=4a<C0P1a4`00F1<00a0C4`0@4`03

01<C00lC00<=4a00cQ<010dC4`1b4`00Ea<00a0C4`0A4`0301<C010C00<=41<0cA<010dC4`1b4`00

EQ<00a0C4`0B4`804Q<00`d@4`304`0301<C008C00<04a<00Q<00`0C3@024`0301<C070C001F4`03

41<C018C00<04a<04A<00`dC402o4`0301<000LC00@04`0=0Q<00`0C4`1`4`00EA<00a0C4`0C4`03

01<C018C00<=41<0_Q<00`0C00094`0400dC4`80LA<005@C00<@4a<051<00`0C4`0C4`033A0C0;dC

00<04`001a<2008C00<=4`00LQ<005<C00<@4a<05A<201@C00<=41<0_A<00`0C00074`0701<C4`dC

001b4`00Da<00a0C4`0E4`0301<C01@C00<=41<0_A<00`0C4`064`<000@C3A<0LQ<0058C00<@4a<0

5Q<00`0C4`0E4`033A0C0<TC00@=4`00LA<0054C00<@4a<05a<00`0C4`0E4`033A0C0<XC00<=01<0

LA<0054C00<@4a<05a<201LC00<=41<0bA<00`d04`1a4`00D1<00a0C4`0H4`0301<C01LC00<=4a<0

bA<00`dC4`1`4`00Ca<00a0C4`084`D00Q<00`0C4`024`0301<C008C00<04a<061<00`dC4`384`03

3A<C070C001?4`0341<C00XC00<04a<01Q<00`0C00034`0301<C01PC00<=41<0b1<00`0=4`1`4`00

CQ<00a0C4`0;4`0301<C00PC00@04a<C0P0J4`033A0C0<LC00<03A<0L1<004dC00<@4a<031<00`0C

4`064`8011<00`0C4`0J4`033A<C0<HC00<04`d0L1<004`C00<@4a<03A<00`0C4`064`0301<C00<C

00<04a<06Q<00`d@4`364`0301<=070C001<4`0341<C00`C0P084`<00a<00`0C4`0K4`033A0C0<DC

0P000a<=4`1^4`00Ba<00a0C4`0M4`8071<00`dC40354`0501<C4`d0KQ<004XC00<@4a<07Q<00`0C

4`0L4`033A0C0<@C00D04a<C3@1^4`00BQ<00a0C4`0N4`0301<C01dC00<=41<0`a<00`0C4`024`03

3A<C06/C00194`0341<C01lC00<04a<07A<00`dC40334`0301<C008C00<=4a<0Ja<004PC00<@4a<0

81<201lC00<=4a00`Q<200@C00<=4a<0JQ<004LC00<@4a<08A<00`0C4`0N4`043A<C4<4C00<04a<0

11<00`dC4`1Y4`00Aa<00a0C4`0Q4`0301<C01lC00<=4a00^Q<5008C00<04a<01A<00`dC4`1X4`00

AQ<00a0C4`0R4`0301<C020C00<=4a00^a<00`0C4`024`0301<C00DC00<=4a<0J1<004DC00<@4a<0

8a<2024C00@=4a<@^Q<00`0C4`024`801a<00`dC4`1W4`00A1<00a0C4`0T4`0301<C024C00@=4a<@

^A<00`0C4`024`0301<C00LC00<=4a<0IQ<004@C00<@4a<091<00`0C4`0R4`033A<@0;TC00<04a<0

0Q<00`0C4`084`033A<C06DC00134`0341<C02DC00<04a<08Q<010dC4a2g4`8011<00`0C4`094`03

3A<C06@C00124`0341<C02HC00<04a<08a<010dC4a2l4`0301<C00XC00<=4a<0Ha<0044C00<@4a<0

9a<202DC00@=4a<@^a<200`C00<=4a<0HQ<0040C00<@4a<0:1<00`0C4`0U4`043A<C4;XC00<04a<0

31<00`dC4`1Q4`00@1<00a0C4`0R4`<00a<00`0C4`0U4`053A<C4a00^A<00`0C4`0=4`033A<C060C

000o4`0341<C02<C00<04a<00a<00`0C4`0V4`043A<C4;TC00<04a<03Q<00`dC4`1O4`00?Q<00a0C

4`0U4`0301<C008C0P0X4`043A<C4;PC00<04a<03a<00`dC4`1N4`00?A<00a0C4`0V4`0301<C008C

00<04a<09a<01@dC4a<@0;LC0P0A4`033A<C05dC000m4`0341<C02DC00<04`000a<00`0C4`0X4`05

3A<C4a00]Q<00`0C4`0A4`033A<C05`C000l4`0341<C02LC00<04a<00Q<00`0C4`0Y4`053A<C4a00

]A<00`0C4`0B4`8=G1<003/C00<@4a<0;A<202XC00<=4a<00Q<00a0C4`2b4`0301<C01@C00<=4a<0

FA<003XC00<@4a<0;Q<00`0C4`0Z4`053A<C4a00]1<201HC0PeI4`00>Q<00a0C4`0^4`0301<C02/C

00D=4a<C402c4`0301<C01LC00<=4a<0EQ<003TC00<@4a<0;a<00`0C4`0/4`053A<C4a00/Q<00`0C

4`0H4`8=EQ<003PC00<@4a<0<1<202dC00<=4a<00Q<00a0C4`2_4`0301<C01XC00<=4a<0Da<003LC

00<@4a<0<A<00`0C4`0]4`053A<C4a00/A<00`0C4`0K4`8=Da<003LC00<@4a<0<A<00`0C4`0^4`05

3A<C4a00/1<201hC00<=4a<0D1<003HC00<@4a<0<Q<00`0C4`0^4`033A<C008C00<@4a<0[A<00`0C

4`0N4`8=D1<003DC00<@4a<0<a<2030C00<=4a<00Q<00a0C4`2K4`D00Q<00`0C4`024`0301<C008C

00<04a<081<00`dC4`1=4`00=1<00a0C4`0d4`0301<C030C00<=4a<00Q<00a0C4`2L4`0301<C00HC

00<04`000a<00`0C4`0Q4`8=CA<003<C00<@4a<0=A<00`0C4`0`4`033A<C00<C00<@4a<0Va<00`0C

4`084`0401<C4`8091<00`dC4`1:4`00<Q<00a0C4`0f4`0301<C034C00<=4a<00Q<00a0C4`2K4`03

01<C00HC0P044`0301<C02@C0Pe:4`00<A<00a0C4`0g4`80<a<00`dC4`024`0341<C09XC00<04a<0

1Q<00`0C4`034`0301<C02HC00<=4a<0Aa<0030C00<@4a<0>1<00`0C4`0c4`033A<C008C00<@4a<0

V1<200PC0`034`0301<C02LC0Pe74`00;a<00a0C4`0Y4`<00a<00`0C4`024`0301<C008C00<04a<0

<a<00`dC4`034`0341<C0:LC00<04a<0:A<00`dC4`144`00;Q<00a0C4`0Z4`0301<C00LC00<04`00

0a<00`0C4`0d4`033A<C00<C00<@4a<0YQ<202/C0Pe44`00;A<00a0C4`0/4`0301<C00PC00@04a<C

0P0f4`033A<C00<C00<@4a<0YA<00`0C4`0/4`033A<C044C000/4`0341<C02dC00<04a<01Q<200@C

00<04a<0=A<00`dC4`044`0341<C0:@C00<04a<0;A<23D4C000[4`0341<C02dC00<04`001a<00`0C

4`034`0301<C03HC00<=4a<011<00a0C4`2S4`0301<C02lC00<=4a<0?Q<002XC00<@4a<0;a<00`0C

4`064`<00a<00`0C4`0g4`033A<C00@C00<@4a<0XQ<00`0C4`0`4`8=?Q<002TC00<@4a<0?a<203PC

00<=4a<01A<00a0C4`2Q4`80<a<23C`C000X4`0341<C040C00<04a<0>1<00`dC4`054`0341<C0:0C

00<04a<0=1<23CXC000W4`0341<C044C00<04a<0>1<00`dC4`064`0341<C09lC00<04a<0=Q<23CPC

000V4`0341<C048C00<04a<0>A<00`dC4`064`0341<C09hC00<04a<0>1<23CHC000U4`0341<C04<C

0P0k4`033A<C00HC00<@4a<0WA<203/C0Pdd4`0091<00a0C4`144`0301<C03XC00<=4a<01a<00a0C

4`2L4`0301<C03`C0Pdb4`008a<00a0C4`154`0301<C03/C00<=4a<01a<00a0C4`2K4`0301<C03hC

0Pd`4`008a<00a0C4`154`0301<C03`C00<=4a<01a<00a0C4`2J4`0301<C040C0Pd^4`008Q<00a0C

4`164`80?A<00`dC4`084`0341<C09TC00<04a<0@Q<23B`C000Q4`0341<C04LC00<04a<0?A<00`dC

4`084`0341<C09PC0P154`8=:Q<0020C00<@4a<0B1<00`0C4`0n4`033A<C00PC00<@4a<0Ua<00`0C

4`164`8=:1<001lC00<@4a<0BA<00`0C4`0n4`033A<C00TC00<@4a<0T1<300<C00<04a<0B1<23BHC

000N4`0341<C04XC0P104`033A<C00TC00<@4a<0Sa<00`0C4`034`0301<C04XC0PdT4`007A<00a0C

4`1;4`0301<C040C00<=4a<02A<00a0C4`2?4`0301<C008C0P1=4`8=8Q<001`C00<@4a<0C1<00`0C

4`104`033A<C00XC00<@4a<0SQ<00`0C4`024`0301<C04hC0`dO4`006a<00a0C4`174`8011<00`0C

4`114`033A<C00XC00<@4a<0S1<00`0C00034`0301<C054C0`dL4`006Q<00a0C4`1:4`0501<C4`00

@a<00`dC4`0;4`0341<C08`C00<04a<00Q<00`0C4`1D4`8=6Q<001TC00<@4a<0BQ<00`0C4`024`80

@a<00`dC4`0:4`0341<C094C00<04a<0EQ<23APC001W4`0301<C0>LC0P1I4`8=5Q<006DC00<04`00

jA<00`0C4`1`4`00IQ<00`0C4`3X4`0301<C070C000/4`<0oa<S4`0301<C070C000/4`0301<C0?lC

8a<00`0C4`1`4`00;A<00`0C4`054`0301<C0?lCSA<002dC00@04a<C0`0011<04a<30?lCRQ<002`C

00<04`000Q<2008C00<04a<00Q<00`0C4`3o4hPC000]4`0301<C00<C00@04a<00Q<00`0C4`3o4hTC

000c4`0401<C00<C00<04a<01Q<00`0C4`0U4`<0;A<00`0C4`3o4bLC000M4`<000<C00000P0<4`<0

11<300PC00<04a<091<0100C4`0A4`<000<C00000P024`0301<C008C00<04a<00Q<00`0C4`054`04

01<C4`D00Q<00`0C4`024`<00Q<00`0C4`044`80ba<00`0C4`0b4`0301<C00PC000L4`0401<C02@C

00<04a<08a<0100C4`0@4`0401<C00HC00<04`001a<00`0C00044`D00a<00`0C4`084`0601<C01<0

11<00`0C4`334`0301<C00@C00<04a<04a<00`0C4`0N4`0301<C00LC000L4`0501<C01<010000a<0

000H02/C0`0@4`0501<C01<0100011<04`094`0301<C00@C00<04a<00a<00`0C4`064`@000@C01<0

11<00`0C4`2a4`0401<C4`@00Q<200HC00<04a<00a<00`0C4`024`0301<C008C00<04a<00Q<00`0C

4`054`0401<C4`D00Q<00`0C4`024`<00Q<00`0C4`044`8011<0100C4a<2004C0@0100007A<304dC

00<04a<03a<300HC00<04`001a<200LC00<04a<00a<00`0C4`064`0301<000<C00<04a<00a<00`0C

4`2`4`0301<000LC00<04a<011<500<C00L04a<C01<000LC00<04`0011<500<C00<04a<021<01P0C

4`0C00@C00<04a<011<00`0C4`024`0301<0004C000O4`0301<C04XC0P0C4`0301<C00@C00<04`00

1a<00`0C4`0<4`0301<C00LC0P024`0301<000@C00<04`00/1<00`0C00024`@000<C01<01a<00`0C

4`034`0701<C4`0C00094`0301<C00@C00<04a<00a<00`0C4`064`@000@C01<011<00`0C4`044`03

01<C00<C0@014`4C000N4`80H1<200LC00<04a<01Q<300/C0P0:4`0501<C4`001A<309HC0P000a<0

000E4`0301<000LC00<04a<01Q<00`0C4`034`0701<C4`0C00074`801a<00`0C4`034`0301<C00HC

00<04`000a<00`0C4`034`0301<C00@C00<04a<00a<1004C0A<00?lCDA<00`0C000F4`0301<000LC

00<04`003A<01P0C4`0C00LC00<04a<031<00`0C4`074`800Q<00`0C00044`0301<000<C00<04a<0

0a<00`0C00014`00:A<200HC0P3o4alC00<04a<05Q<00`0C4`064`<03Q<0100C4`084`<02a<200XC

00D04a<C00054`<00Q<00`0C4`034`800A<10040000[4`0301<C008C00<04a<0oa<O4`0301<C070C

000Z4`0301<C00<C00<04a<01A<00`0C4`3o4aHC00<04`00LA<002/C00<04a<00Q<00`0C4`024`@0

0a<30?lC4A<200034`00070C000Y4`0301<000@C00<04`000Q<200034`0C00@C00<04a<0oa>44`00

:Q<00`0C4`034`<011<00`0C00034`0301<C0?lCQA<003LC00<04`0011<00`0C4`3o4h@C000e4`<0

11<30?lCQQ<00?lCaA<00?lCaA<00?lCaA<00?lCaA<00?lCaA<00001\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.37705, -1.70489, 0.0218519, 0.0218519}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -84.5 0 ]

[.5 .96488 84.5 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -145.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.475) show

222.250000 19.500000 moveto

(C) show

227.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.25787 0 m

.26171 .00566 L

.30316 .0668 L

.34309 .12569 L

.3815 .18235 L

.42237 .24263 L

.46172 .30067 L

.49955 .35648 L

.53984 .41591 L

.57861 .47309 L

.61984 .5339 L

.65954 .59247 L

.69774 .6488 L

.73838 .70876 L

.77751 .76647 L

.81909 .82781 L

.85916 .88691 L

.89771 .94377 L

s

.89771 .94377 m

.90355 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.362318 0.238095 [

[.02381 .34982 -6 -9 ]

[.02381 .34982 6 0 ]

[.2619 .34982 -6 -9 ]

[.2619 .34982 6 0 ]

[.7381 .34982 -3 -9 ]

[.7381 .34982 3 0 ]

[.97619 .34982 -3 -9 ]

[.97619 .34982 3 0 ]

[1.025 .36232 0 -8 ]

[1.025 .36232 9 8 ]

[.4875 .00518 -24 -4.5 ]

[.4875 .00518 0 4.5 ]

[.4875 .12422 -12 -4.5 ]

[.4875 .12422 0 4.5 ]

[.4875 .24327 -24 -4.5 ]

[.4875 .24327 0 4.5 ]

[.4875 .48137 -18 -4.5 ]

[.4875 .48137 0 4.5 ]

[.4875 .60041 -6 -4.5 ]

[.4875 .60041 0 4.5 ]

[.4875 .71946 -18 -4.5 ]

[.4875 .71946 0 4.5 ]

[.4875 .83851 -6 -4.5 ]

[.4875 .83851 0 4.5 ]

[.5 .90795 -4.5 0 ]

[.5 .90795 4.5 16 ]

[.5 .89545 -137 0 ]

[.5 .89545 137 16 ]

[ 0 0 0 0 ]

[ 1 .88295 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .36232 m

.02381 .36857 L

s

[(-2)] .02381 .34982 0 1 Mshowa

.2619 .36232 m

.2619 .36857 L

s

[(-1)] .2619 .34982 0 1 Mshowa

.7381 .36232 m

.7381 .36857 L

s

[(1)] .7381 .34982 0 1 Mshowa

.97619 .36232 m

.97619 .36857 L

s

[(2)] .97619 .34982 0 1 Mshowa

.125 Mabswid

.07143 .36232 m

.07143 .36607 L

s

.11905 .36232 m

.11905 .36607 L

s

.16667 .36232 m

.16667 .36607 L

s

.21429 .36232 m

.21429 .36607 L

s

.30952 .36232 m

.30952 .36607 L

s

.35714 .36232 m

.35714 .36607 L

s

.40476 .36232 m

.40476 .36607 L

s

.45238 .36232 m

.45238 .36607 L

s

.54762 .36232 m

.54762 .36607 L

s

.59524 .36232 m

.59524 .36607 L

s

.64286 .36232 m

.64286 .36607 L

s

.69048 .36232 m

.69048 .36607 L

s

.78571 .36232 m

.78571 .36607 L

s

.83333 .36232 m

.83333 .36607 L

s

.88095 .36232 m

.88095 .36607 L

s

.92857 .36232 m

.92857 .36607 L

s

.25 Mabswid

0 .36232 m

1 .36232 L

s

gsave

1.025 .36232 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .00518 m

.50625 .00518 L

s

[(-1.5)] .4875 .00518 1 0 Mshowa

.5 .12422 m

.50625 .12422 L

s

[(-1)] .4875 .12422 1 0 Mshowa

.5 .24327 m

.50625 .24327 L

s

[(-0.5)] .4875 .24327 1 0 Mshowa

.5 .48137 m

.50625 .48137 L

s

[(0.5)] .4875 .48137 1 0 Mshowa

.5 .60041 m

.50625 .60041 L

s

[(1)] .4875 .60041 1 0 Mshowa

.5 .71946 m

.50625 .71946 L

s

[(1.5)] .4875 .71946 1 0 Mshowa

.5 .83851 m

.50625 .83851 L

s

[(2)] .4875 .83851 1 0 Mshowa

.125 Mabswid

.5 .02899 m

.50375 .02899 L

s

.5 .05279 m

.50375 .05279 L

s

.5 .0766 m

.50375 .0766 L

s

.5 .10041 m

.50375 .10041 L

s

.5 .14803 m

.50375 .14803 L

s

.5 .17184 m

.50375 .17184 L

s

.5 .19565 m

.50375 .19565 L

s

.5 .21946 m

.50375 .21946 L

s

.5 .26708 m

.50375 .26708 L

s

.5 .29089 m

.50375 .29089 L

s

.5 .3147 m

.50375 .3147 L

s

.5 .33851 m

.50375 .33851 L

s

.5 .38613 m

.50375 .38613 L

s

.5 .40994 m

.50375 .40994 L

s

.5 .43375 m

.50375 .43375 L

s

.5 .45756 m

.50375 .45756 L

s

.5 .50518 m

.50375 .50518 L

s

.5 .52899 m

.50375 .52899 L

s

.5 .55279 m

.50375 .55279 L

s

.5 .5766 m

.50375 .5766 L

s

.5 .62422 m

.50375 .62422 L

s

.5 .64803 m

.50375 .64803 L

s

.5 .67184 m

.50375 .67184 L

s

.5 .69565 m

.50375 .69565 L

s

.5 .74327 m

.50375 .74327 L

s

.5 .76708 m

.50375 .76708 L

s

.5 .79089 m

.50375 .79089 L

s

.5 .8147 m

.50375 .8147 L

s

.5 .86232 m

.50375 .86232 L

s

.25 Mabswid

.5 0 m

.5 .88295 L

s

gsave

.5 .90795 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .89545 -198 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.475) show

298.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

303.000000 15.000000 moveto

(L) show

310.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

317.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

324.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

329.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

333.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .88295 L

0 .88295 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .1992 m

.02576 .1992 L

.03157 .19918 L

.04114 .19915 L

.05432 .19912 L

.07087 .19906 L

.09051 .199 L

.1129 .19892 L

.13767 .19882 L

.16439 .19871 L

.19259 .19857 L

.22181 .19841 L

.25153 .19823 L

.28125 .19801 L

.31047 .19777 L

.33868 .19748 L

.36539 .19716 L

.39016 .19681 L

.41255 .19643 L

.43219 .19604 L

.44874 .19565 L

.46192 .1953 L

.47149 .19501 L

.4773 .19482 L

.47925 .19475 L

s

.47925 .19475 m

.48138 .19468 L

.48772 .19445 L

.49817 .19404 L

.51254 .19338 L

.5306 .19237 L

.55203 .19079 L

.57646 .18827 L

.60349 .18405 L

.63264 .17694 L

.66341 .16597 L

.69529 .15167 L

.72772 .13571 L

.76015 .11945 L

.79203 .10368 L

.82281 .08882 L

.85196 .07514 L

.87898 .0628 L

.90342 .05193 L

.92485 .04261 L

.9429 .0349 L

.95728 .02885 L

.96772 .02451 L

.97406 .0219 L

.97619 .02102 L

s

.47925 .44604 m

.48138 .41915 L

.48772 .39243 L

.49817 .36607 L

.51254 .34028 L

.5306 .31528 L

.55203 .2914 L

.57646 .26913 L

.60349 .24933 L

.63264 .2333 L

.66341 .22213 L

.69529 .21535 L

.72772 .21141 L

.76015 .20903 L

.79203 .20751 L

.82281 .20648 L

.85196 .20575 L

.87898 .20523 L

.90342 .20484 L

.92485 .20455 L

.9429 .20434 L

.95728 .20419 L

.96772 .20408 L

.97406 .20402 L

.97619 .204 L

s

.47925 .44616 m

.48138 .47312 L

.48772 .50008 L

.49817 .52684 L

.51254 .55329 L

.5306 .57931 L

.55203 .60477 L

.57646 .62956 L

.60349 .65358 L

.63264 .67671 L

.66341 .69886 L

.69529 .71993 L

.72772 .73983 L

.76015 .75847 L

.79203 .77577 L

.82281 .79166 L

.85196 .80607 L

.87898 .81893 L

.90342 .83019 L

.92485 .8398 L

.9429 .84772 L

.95728 .85392 L

.96772 .85836 L

.97406 .86104 L

.97619 .86193 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCaA<00?lCaA<006@C1@3G4`D00Q<00`0C4`024`0301<C07DC001V4`0301<C0=TC00<04a<0

1Q<00`0C00034`0301<C070C00124`033A<C01/C0`034`0301<C008C0P3?4`<00a<00`0C4`084`04

01<C4`80LA<0048C00<=4a<08A<00`0C4`024`0301<C0=@C00<04a<01Q<200@C00<04a<0L1<004<C

00<=4a<081<00`0C4`024`0301<C0=@C00<04a<01Q<00`0C4`034`0301<C070C00134`033A<C01lC

0P044`0301<C0=<C0P084`<00a<00`0C4`1H4`8=5Q<004@C00<=4a<091<20>@C00<04a<0Ea<00`dC

4`0F4`00AA<00`dC4`0S4`0301<C0><C0P1E4`<=6A<004DC00<=4a<08a<00`0C4`3S4`0301<C054C

0`dL4`00AQ<00`dC4`0R4`0301<C0><C00<04a<0Ca<23AlC00164`033A<C028C0P3T4`0301<C04dC

0PdQ4`00Aa<00`dC4`0Q4`0301<C0><C0P1;4`<=8a<004PC00<=4a<081<00`0C4`3S4`0301<C04PC

0PdV4`00B1<00`dC4`0P4`0301<C0><C00<04a<0AQ<23BPC00194`033A<C01lC0P3T4`0301<C04@C

0PdZ4`00BQ<00`dC4`0N4`0301<C0><C00<04a<0@Q<23B`C001:4`033A<C01hC00<04a<0ha<2044C

0Pd^4`00Ba<00`dC4`0M4`0301<C0><C00<04a<0?A<33C0C001<4`033A<C01`C0P3T4`0301<C03/C

0Pdc4`00C1<00`dC4`0L4`0301<C0><C00<04a<0>A<23CDC001=4`033A<C00`C00<04a<00Q<00`0C

4`024`0301<C008C00<04a<0ha<203PC0Pdg4`00CQ<00`dC4`0:4`0301<000LC00<04`000a<00`0C

4`3S4`0301<C03DC0Pdi4`00Ca<00`dC4`044`<00Q<00`0C00094`0401<C4`80i1<00`0C4`0c4`8=

>a<004lC00<=4a<02A<00`0C00074`8011<00`0C4`3L4`D00Q<00`0C4`0a4`8=?A<0050C00<=4a<0

21<00`0C00074`0301<C00<C00<04a<0gQ<00`0C4`024`0301<C02lC0Pdo4`00DA<00`dC4`084`03

01<C00HC0`034`0301<C0=PC0`034`0301<C008C0P0^4`8=@A<0058C00<=4a<05Q<00`0C4`3N4`03

01<C008C00<04a<0:a<23D<C001B4`033A<C01HC0P3O4`0301<C008C00<04a<0:A<23DDC001C4`03

3A<C01DC00<04a<0gA<200@C00<04a<09a<23DLC001D4`033A<C01@C00<04a<0ha<00`0C4`0U4`8=

BA<005DC00<=4a<04a<00`0C4`3S4`8091<23D/C001E4`033A<C01<C0P3T4`0301<C024C0Pe=4`00

EQ<00`dC4`0B4`0301<C0><C00<04a<07a<23DlC000J4`<09A<5010C00<=4a<04A<00`0C4`0T4`D0

91<309<C00<04a<071<33E4C000J4`0301<C02LC00<04a<04A<00`dC4`0@4`0301<C02HC00<04a<0

91<00`0C4`2C4`806Q<33E@C000E4`<00a<00`0C4`0P4`<00a<00`0C4`0A4`033A<C010C0P0W4`03

01<C02DC00<04a<0TQ<00`0C4`0E4`@=Ea<001/C00<04a<09Q<00`0C4`0B4`033A<C00lC00<04a<0

9Q<00`0C4`0U4`0301<C098C00<04a<03a<63E/C000J4`0301<002LC00<04a<04a<00`dC4`0>4`03

01<C02HC00<04a<091<00`0C002C4`0301<C00XC1@eQ4`006a<00`0C4`0U4`805A<00`dC4`0>4`03

01<C02DC0P0W4`0301<C090C3`eV4`00Fa<00`dC4`0=4`80RA=I3@8C0P1a4`00Fa<00`dC4`0=4`03

01<C0><C00<04a<0BA<A3AHC001L4`033A<C00`C00<04a<0Fa<208HC00<04a<0;A<L3BLC001M4`03

3A<C00/C00<04a<0FQ<00`0C4`264`0301<C028C2`e34`005A=800033@0006801Q<00`0C4`264`80

81<33DhC000I4`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`03

01<C00HC00<04a<01A<0100C4`d44`0301<C00DC00<@4a<01A<00`0C4`064`0301<C00DC00<04a<0

1A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`084`03

01<C08HC00<04a<071<33E4C001O4`033A<C00TC00<@4a<0FQ<00`0C00264`0301<C01TC0`eD4`00

Ga<00`dC4`094`8@Fa<307LC00<04a<00Q<00`0C4`024`0301<C008C00<04a<05a<23ELC001P4`03

3A<C00PC0Q3D4`0301<000LC00<04`000a<00`0C4`0E4`8=FA<0064C00<=4a<01Q<00a00403?4`<0

0Q<00`0C00094`0401<C4`8051<23E/C001Q4`033A<C00HC00<@0100e1<00`0C00074`8011<00`0C

4`0A4`8=GA<0068C00<=4a<01A<00a00403D4`0301<000LC00<04a<00a<00`0C4`0@4`033A<C05dC

001S4`033A<C00<C00D@4`00403D4`0301<C00HC0`034`0301<C00hC0PeP4`00I1<00`dC4`024`05

41<04a00ha<200hC00<=4a<0H1<006@C00<=4a<00Q<01A0C01<@0><C00<04a<031<00`dC4`1Q4`00

IA<01`dC4a<@4`000Q<00a0C4`3P4`0301<C00/C00<=4a<0HQ<006HC00D=4a<@4`0200034a0C0>4C

00<04a<02A<23FDC001V4`063A<C41<00Q<00a0C4`3P4`0301<C00PC00<=4a<0IA<006LC00D=41<C

00034`0341<C0=lC0P084`033A<C06HC001X4`043A<C00<C00<@4a<0ga<00`0C4`064`033A<C06LC

001X4`033A<C00800Q<00a0C4`3O4`0301<C00DC00<=4a<0J1<006LC00D@4`dC00044`0341<C08@C

0`0Y4`D0:A<00`0C4`054`033A<C020C1@0Z4`<05Q<005`C00<04a<00Q<00`0C4`024`06010C4`d0

11<00a0C4`244`0301<C02/C00<04a<0:A<00`0C4`044`033A<C02<C00<04a<0:Q<00`0C4`0F4`00

Fa<00`0C00074`030100008C00<=01<00a<00a0C4`1o4`<00a<00`0C4`0T4`<00a<00`0C4`0Y4`80

11<00`dC4`0T4`0301<C02/C00<04a<05A<005/C00<04`0021<00a004`024`033@0C00<C00<@4a<0

Q1<00`0C4`0Z4`0301<C02TC00<04a<00Q<00`dC4`0U4`0301<C02/C00<04a<05A<005/C00<04`00

1a<00`0@4`034`0300dC00<C00<@4a<0Pa<00`0C000[4`0301<C02TC00<04a<00Q<00`dC4`0U4`03

01<C02XC00<04`005Q<005/C00<04`001a<00a0C4`034`0300dC00@C00<@4a<0Pa<00`0C4`0Y4`80

:a<01@0C4a<=02LC0P0]4`0301<C01DC001L4`0301<C00HC00<@00000a<00`0C3@044`0341<C0=`C

0P024`033A<C06`C001T4`0341<C00@C0P000a<=4`024`0341<C0=`C00@04a<=Ka<006@C00<@4a<0

11<0100C4`d44`0341<C0=/C00<04`d0L1<006<C00<@4a<01A<01@0C4a<=00<C00<@4a<0fa<00`0=

4`1V4`8021<006<C00<@4a<01A<00`0C4`024`053A<C4a00g1<00`0=4`1U4`0301<C00PC001R4`03

41<C00HC00<04a<00a<010dC4a1l4f0000<=0000GP074`0301<C00PC001R4`0341<C00HC0P044`05

3A<C4a00P1<00`0C4`0Z4`0301<C02/C00<=4a<0:a<00`0C4`0[4`0301<C00TC00<04a<021<0064C

00<@4a<01a<00`0C4`044`043A<C4=XC00<=01<0IQ<00`0C00084`00HA<00a0C4`074`0301<C00DC

00<=4a00fQ<00`d04`1V4`<021<0060C00<@4a<021<00`0C4`054`043A<C4=TC00<=0000LA<0060C

00<@4a<021<200LC00<=4a00f1<00`dC001b4`00Ga<00a0C4`094`0301<C00LC00<=4a00ea<00`dC

001b4`00Ga<00a0C4`094`0301<C00LC00<=4a00ea<00`dC001b4`00GQ<00a0C4`0:4`0301<C00PC

00<=4a00eQ<00`dC001b4`00GQ<00a0C4`0:4`802Q<00`d@4`3D4`033A<C0080LA<005dC00<@4a<0

2a<00`0C4`0:4`033A0C0=<C00@=4a<0LQ<005dC00<@4a<011<5008C00<04a<02Q<00`d@4`3C4`04

3A<C078C001L4`0341<C00LC00<04a<00Q<00`0C4`0;4`033A0C0=8C00@=4a<0LQ<005/C00<@4a<0

21<00`0C4`024`803A<00`d@4`3A4`033A<C0080LA<005/C00<@4a<021<00`0C4`024`0301<C00`C

00<=41<0d1<01@dC4a<0078C001J4`0341<C00TC00<04a<00Q<00`0C4`0=4`033A0C0<lC00D=4a<C

001b4`00FQ<00a0C4`084`8011<00`0C4`0>4`033A0C0<hC00D=4a<C001b4`00FA<00a0C4`0?4`80

3a<00`d@4`3>4`053A<C4`00LQ<005PC00<@4a<041<00`0C4`0?4`033A0C0<dC00@=4a<C0P1a4`00

F1<00a0C4`0@4`0301<C00lC00<=4a00cQ<010dC4`1b4`00Ea<00a0C4`0A4`0301<C010C00<=41<0

cA<010dC4`1b4`00EQ<00a0C4`0B4`804Q<00`d@4`304`0301<C008C00<04a<00Q<00`0C3@024`03

01<C070C001F4`0341<C018C00<04a<04A<00`dC402o4`0301<000LC00@04`0=0Q<00`0C4`1`4`00

EA<00a0C4`0C4`0301<C018C00<=41<0_Q<00`0C00094`0400dC4`80LA<005@C00<@4a<051<00`0C

4`0C4`033A0C0;dC00<04`001a<2008C00<=4`00LQ<005<C00<@4a<05A<201@C00<=41<0_A<00`0C

00074`0701<C4`dC001b4`00Da<00a0C4`0E4`0301<C01@C00<=41<0_A<00`0C4`064`<000@C3A<0

LQ<0058C00<@4a<05Q<00`0C4`0E4`033A0C0<TC00@=4`00LA<0054C00<@4a<05a<00`0C4`0E4`03

3A0C0<XC00<=01<0LA<0054C00<@4a<05a<201LC00<=41<0bA<00`d04`1a4`00D1<00a0C4`0H4`03

01<C01LC00<=4a<0bA<00`dC4`1`4`00Ca<00a0C4`084`D00Q<00`0C4`024`0301<C008C00<04a<0

61<00`dC4`384`033A<C070C001?4`0341<C00XC00<04a<01Q<00`0C00034`0301<C01PC00<=41<0

b1<00`0=4`1`4`00CQ<00a0C4`0;4`0301<C00PC00@04a<C0P0J4`033A0C0<LC00<03A<0L1<004dC

00<@4a<031<00`0C4`064`8011<00`0C4`0J4`033A<C0<HC00<04`d0L1<004`C00<@4a<03A<00`0C

4`064`0301<C00<C00<04a<06Q<00`d@4`364`0301<=070C001<4`0341<C00`C0P084`<00a<00`0C

4`0K4`033A0C0<DC0P000a<=4`1^4`00Ba<00a0C4`0M4`807A<00`d@4`344`0501<C4`d0KQ<004XC

00<@4a<07Q<00`0C4`0L4`033A0C0<@C00D04a<C3@1^4`00BQ<00a0C4`0N4`0301<C01dC00<=41<0

`a<00`0C4`024`033A<C06/C00194`0341<C01lC00<04a<07Q<00`d@4`324`0301<C008C00<=4a<0

Ja<004PC00<@4a<081<201lC00<=4a00`Q<200@C00<=4a<0JQ<004LC00<@4a<08A<00`0C4`0O4`03

3A<@0<4C00<04a<011<00`dC4`1Y4`00Aa<00a0C4`0Q4`0301<C020C00<=41<0`1<00`0C4`054`03

3A<C06PC00164`0341<C028C00<04a<081<00`dC402i4`D00Q<00`0C4`054`033A<C06PC00154`03

41<C02<C0P0R4`033A<@0;XC00<04a<00Q<00`0C4`064`033A<C06LC00144`0341<C02@C00<04a<0

8Q<00`dC402i4`0301<C008C0P084`033A<C06HC00144`0341<C02@C00<04a<08Q<00`dC402i4`03

01<C008C00<04a<021<00`dC4`1U4`00@a<00a0C4`0U4`0301<C02<C00<=4a00^1<00`0C4`024`03

01<C00TC00<=4a<0I1<0048C00<@4a<09Q<00`0C4`0S4`043A<C4;HC0P044`0301<C00XC00<=4a<0

Ha<0044C00<@4a<09a<202DC00@=4a<@^a<200`C00<=4a<0HQ<0040C00<@4a<0:1<00`0C4`0U4`04

3A<C4;XC00<04a<031<00`dC4`1Q4`00@1<00a0C4`0R4`<00a<00`0C4`0U4`053A<C4a00^A<00`0C

4`0=4`033A<C060C000o4`0341<C02<C00<04a<00a<00`0C4`0V4`043A<C4;TC00<04a<03Q<00`dC

4`1O4`00?Q<00a0C4`0U4`0301<C008C0P0X4`043A<C4;PC00<04a<03a<00`dC4`1N4`00?A<00a0C

4`0V4`0301<C008C00<04a<09a<01@dC4a<@0;LC0P0A4`033A<C05dC000m4`0341<C02DC00<04`00

0a<00`0C4`0X4`053A<C4a00]Q<00`0C4`0A4`033A<C05`C000l4`0341<C02LC00<04a<00Q<00`0C

4`0Y4`053A<C4a00]A<00`0C4`0B4`8=G1<003/C00<@4a<0;A<202XC00<=4a<00Q<00a0C4`2b4`03

01<C01@C00<=4a<0FA<003XC00<@4a<0;Q<00`0C4`0Z4`053A<C4a00]1<201HC0PeI4`00>Q<00a0C

4`0^4`0301<C02/C00D=4a<C402c4`0301<C01LC00<=4a<0EQ<003TC00<@4a<0;a<00`0C4`0/4`05

3A<C4a00/Q<00`0C4`0H4`8=EQ<003PC00<@4a<0<1<202dC00<=4a<00Q<00a0C4`2_4`0301<C01XC

00<=4a<0Da<003LC00<@4a<0<A<00`0C4`0]4`053A<C4a00/A<00`0C4`0K4`8=Da<003LC00<@4a<0

<A<00`0C4`0^4`053A<C4a00/1<201hC00<=4a<0D1<003HC00<@4a<0<Q<00`0C4`0^4`033A<C008C

00<@4a<0[A<00`0C4`0N4`033A<C04lC000e4`0341<C03<C0P0`4`033A<C008C00<@4a<0Va<5008C

00<04a<00Q<00`0C4`024`0301<C01lC00<=4a<0CQ<003@C00<@4a<0=1<00`0C4`0`4`033A<C008C

00<@4a<0W1<00`0C4`064`0301<000<C00<04a<081<23DhC000c4`0341<C03DC00<04a<0<1<00`dC

4`034`0341<C09/C00<04a<021<0100C4a<202<C00<=4a<0Ba<0038C00<@4a<0=Q<00`0C4`0a4`03

3A<C008C00<@4a<0Va<00`0C4`064`8011<00`0C4`0S4`033A<C04XC000a4`0341<C03LC0P0c4`03

3A<C008C00<@4a<0VQ<00`0C4`064`0301<C00<C00<04a<091<23DXC000`4`0341<C03PC00<04a<0

<a<00`dC4`024`0341<C09PC0P084`<00a<00`0C4`0V4`8=B1<002lC00<@4a<0:A<300<C00<04a<0

0Q<00`0C4`024`0301<C03<C00<=4a<00a<00a0C4`2W4`0301<C02PC0Pe64`00;Q<00a0C4`0Z4`03

01<C00LC00<04`000a<00`0C4`0d4`033A<C00<C00<@4a<0YQ<202/C0Pe44`00;A<00a0C4`0/4`03

01<C00PC00@04a<C0P0f4`033A<C00<C00<@4a<0YA<00`0C4`0/4`033A<C044C000/4`0341<C02dC

00<04a<01Q<200@C00<04a<0=A<00`dC4`044`0341<C0:@C00<04a<0;A<23D4C000[4`0341<C02dC

00<04`001a<00`0C4`034`0301<C03HC00<=4a<011<00a0C4`2S4`0301<C02lC00<=4a<0?Q<002XC

00<@4a<0;a<00`0C4`064`<00a<00`0C4`0g4`033A<C00@C00<@4a<0XQ<00`0C4`0`4`8=?Q<002TC

00<@4a<0?a<203PC00<=4a<01A<00a0C4`2Q4`80<a<23C`C000X4`0341<C040C00<04a<0>1<00`dC

4`054`0341<C0:0C00<04a<0=1<23CXC000W4`0341<C044C00<04a<0>A<00`dC4`054`0341<C09lC

00<04a<0=Q<23CPC000V4`0341<C048C00<04a<0>Q<00`dC4`054`0341<C09hC00<04a<0>1<23CHC

000U4`0341<C04<C0P0k4`033A<C00HC00<@4a<0WA<203/C0Pdd4`0091<00a0C4`144`0301<C03/C

00<=4a<01Q<00a0C4`2L4`0301<C03`C0Pdb4`008a<00a0C4`154`0301<C03`C00<=4a<01Q<00a0C

4`2K4`0301<C03hC0Pd`4`008a<00a0C4`154`0301<C03`C00<=4a<01a<00a0C4`2J4`0301<C040C

0Pd^4`008Q<00a0C4`164`80?Q<00`dC4`074`0341<C09TC00<04a<0@Q<23B`C000Q4`0341<C04LC

00<04a<0?A<00`dC4`084`0341<C09PC0P154`8=:Q<0020C00<@4a<0B1<00`0C4`0n4`033A<C00PC

00<@4a<0Ua<00`0C4`164`8=:1<001lC00<@4a<0BA<00`0C4`0o4`033A<C00PC00<@4a<0T1<300<C

00<04a<0B1<23BHC000N4`0341<C04XC0P104`033A<C00TC00<@4a<0Sa<00`0C4`034`0301<C04XC

0PdT4`007A<00a0C4`1;4`0301<C040C00<=4a<02A<00a0C4`2?4`0301<C008C0P1=4`8=8Q<001`C

00<@4a<0C1<00`0C4`104`033A<C00XC00<@4a<0SQ<00`0C4`024`0301<C04hC0`dO4`006a<00a0C

4`174`8011<00`0C4`114`033A<C00XC00<@4a<0S1<00`0C00034`0301<C054C0`dL4`006Q<00a0C

4`1:4`0501<C4`00@a<00`dC4`0;4`0341<C08`C00<04a<00Q<00`0C4`1D4`8=6Q<001TC00<@4a<0

BQ<00`0C4`024`80@a<00`dC4`0:4`0341<C094C00<04a<0EQ<23APC001W4`0301<C0>LC0P1I4`8=

5Q<006DC00<04`00jA<00`0C4`1`4`00IQ<00`0C4`3X4`0301<C070C000Z4`<0oa<U4`0301<C070C

000Z4`0301<C0?lC9A<00`0C4`1`4`00:a<00`0C4`044`0301<C0?lCT1<002/C00@04a<C10034`<0

oa><4`00:Q<00`0C00024`8000<C01<011<00`0C4`3o4hXC000[4`0301<C00<C00<04`000a<00`0C

4`3o4h/C000a4`0301<000@C00<04a<01Q<00`0C4`0W4`<0:a<00`0C4`3o4bTC000K4`<000<C0000

0P0<4`<011<300PC00<04a<09Q<0100C4`0?4`<000<C00000P024`0301<C008C00<04a<00Q<00`0C

4`054`0401<C4`D00Q<00`0C4`024`<00Q<00`0C4`024`0301<C00@C0P354`0301<C03LC00<04a<0

1Q<001XC00@04a<091<00`0C4`0U4`0401<C00hC00@04a<01Q<00`0C00074`0301<000@C1@034`03

01<C00PC00D04a<C00034`0301<000@C00<04a<0_A<00`0C4`044`0301<C01<C00<04a<08a<00`0C

4`054`006Q<01@0C4`0C00@000<C0000600]4`<03Q<01@0C4`0C00@000@C01<02A<00`0C4`044`03

01<C00<C00<04a<01Q<4008C00<04a<00a<00`0C4`024`0301<C0:/C00@04a<C10024`801Q<00`0C

4`034`0301<C008C00<04a<00Q<00`0C4`024`0301<C00DC00@04a<C1@024`0301<C008C0`024`03

01<C008C00<04a<011<200@C00@04a<C0P014`006a<304lC00<04a<03A<300HC00<04`001a<200LC

00<04a<00a<00`0C4`064`0301<000@C00<04a<00P054`0301<C0:XC00<04`001a<00`0C4`044`D0

0a<01`0C4a<04`001a<00`0C00044`D00a<00`0C4`084`0501<C4`000a<00`0C00044`0301<C00@C

00<04a<00Q<1004C000M4`0301<C04`C0P0A4`0301<C00@C00<04`001a<00`0C4`0<4`0301<C00LC

0P024`0301<0008C00<04a<011<00`0C002Z4`0301<0008C10000a<04`074`0301<C00<C00L04a<C

01<000TC00<04a<011<00`0C4`034`0301<C00HC10024`0301<C00<C00<04a<00Q<00`0C4`044`03

01<C00<C0@0001`C0P1P4`801a<00`0C4`064`<02a<200XC00<04a<00`024`<011<309<C0P000a<0

000B4`0301<000LC00<04a<01Q<00`0C4`034`0701<C4`0C00074`801a<00`0C4`034`0301<C00HC

00<04`0011<00`0C4`0200DC00<04a<011<00`0C4`034`40003o4e4C00<04`004a<00`0C00074`03

01<000dC00H04a<04`074`0301<C00`C00<04a<01a<2008C00<04`000Q<00`0C4`044`0301<000<C

00<04a<00a<1004C000V4`801Q<20?lC8Q<00`0C4`0C4`0301<C00HC0`0>4`0401<C00PC0`0;4`80

2Q<00`0C4`03008C0`044`<00Q<00`0C4`034`800A<002PC00<04a<00Q<00`0C4`3o4b8C00<04a<0

L1<002LC00<04a<00a<00`0C4`064`0301<C0?lC61<00`0C001a4`00:1<00`0C4`024`0301<C008C

0`0011<04a<30?lC51<200034`00070C000V4`0301<000@C00<04`000Q<2008C00<04a<00Q<00`0C

4`3o4hLC000W4`0301<C00<C0`044`0401<C008C00<04a<0oa>84`00=1<0100C4`034`0301<C0?lC

Qa<0038C0`044`<0oa>94`00oa?54`00oa?54`00oa?54`00oa?54`00oa?54`00\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.37248, -1.70473, 0.0218383, 0.0218383}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -82 0 ]

[.5 .96488 82 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -143 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.47) show

217.250000 19.500000 moveto

(C) show

222.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.25705 0 m

.26171 .00686 L

.30316 .06778 L

.34309 .12648 L

.3815 .18295 L

.42237 .24302 L

.46172 .30087 L

.49955 .35648 L

.53984 .41571 L

.57861 .4727 L

.61984 .5333 L

.65954 .59167 L

.69774 .64782 L

.73838 .70757 L

.77751 .76509 L

.81909 .82621 L

.85916 .88511 L

.89771 .94178 L

s

.89771 .94178 m

.90492 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.361011 0.238095 [

[.02381 .34851 -6 -9 ]

[.02381 .34851 6 0 ]

[.2619 .34851 -6 -9 ]

[.2619 .34851 6 0 ]

[.7381 .34851 -3 -9 ]

[.7381 .34851 3 0 ]

[.97619 .34851 -3 -9 ]

[.97619 .34851 3 0 ]

[1.025 .36101 0 -8 ]

[1.025 .36101 9 8 ]

[.4875 .00387 -24 -4.5 ]

[.4875 .00387 0 4.5 ]

[.4875 .12292 -12 -4.5 ]

[.4875 .12292 0 4.5 ]

[.4875 .24196 -24 -4.5 ]

[.4875 .24196 0 4.5 ]

[.4875 .48006 -18 -4.5 ]

[.4875 .48006 0 4.5 ]

[.4875 .59911 -6 -4.5 ]

[.4875 .59911 0 4.5 ]

[.4875 .71815 -18 -4.5 ]

[.4875 .71815 0 4.5 ]

[.4875 .8372 -6 -4.5 ]

[.4875 .8372 0 4.5 ]

[.5 .90609 -4.5 0 ]

[.5 .90609 4.5 16 ]

[.5 .89359 -134.5 0 ]

[.5 .89359 134.5 16 ]

[ 0 0 0 0 ]

[ 1 .88109 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .36101 m

.02381 .36726 L

s

[(-2)] .02381 .34851 0 1 Mshowa

.2619 .36101 m

.2619 .36726 L

s

[(-1)] .2619 .34851 0 1 Mshowa

.7381 .36101 m

.7381 .36726 L

s

[(1)] .7381 .34851 0 1 Mshowa

.97619 .36101 m

.97619 .36726 L

s

[(2)] .97619 .34851 0 1 Mshowa

.125 Mabswid

.07143 .36101 m

.07143 .36476 L

s

.11905 .36101 m

.11905 .36476 L

s

.16667 .36101 m

.16667 .36476 L

s

.21429 .36101 m

.21429 .36476 L

s

.30952 .36101 m

.30952 .36476 L

s

.35714 .36101 m

.35714 .36476 L

s

.40476 .36101 m

.40476 .36476 L

s

.45238 .36101 m

.45238 .36476 L

s

.54762 .36101 m

.54762 .36476 L

s

.59524 .36101 m

.59524 .36476 L

s

.64286 .36101 m

.64286 .36476 L

s

.69048 .36101 m

.69048 .36476 L

s

.78571 .36101 m

.78571 .36476 L

s

.83333 .36101 m

.83333 .36476 L

s

.88095 .36101 m

.88095 .36476 L

s

.92857 .36101 m

.92857 .36476 L

s

.25 Mabswid

0 .36101 m

1 .36101 L

s

gsave

1.025 .36101 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .00387 m

.50625 .00387 L

s

[(-1.5)] .4875 .00387 1 0 Mshowa

.5 .12292 m

.50625 .12292 L

s

[(-1)] .4875 .12292 1 0 Mshowa

.5 .24196 m

.50625 .24196 L

s

[(-0.5)] .4875 .24196 1 0 Mshowa

.5 .48006 m

.50625 .48006 L

s

[(0.5)] .4875 .48006 1 0 Mshowa

.5 .59911 m

.50625 .59911 L

s

[(1)] .4875 .59911 1 0 Mshowa

.5 .71815 m

.50625 .71815 L

s

[(1.5)] .4875 .71815 1 0 Mshowa

.5 .8372 m

.50625 .8372 L

s

[(2)] .4875 .8372 1 0 Mshowa

.125 Mabswid

.5 .02768 m

.50375 .02768 L

s

.5 .05149 m

.50375 .05149 L

s

.5 .0753 m

.50375 .0753 L

s

.5 .09911 m

.50375 .09911 L

s

.5 .14673 m

.50375 .14673 L

s

.5 .17053 m

.50375 .17053 L

s

.5 .19434 m

.50375 .19434 L

s

.5 .21815 m

.50375 .21815 L

s

.5 .26577 m

.50375 .26577 L

s

.5 .28958 m

.50375 .28958 L

s

.5 .31339 m

.50375 .31339 L

s

.5 .3372 m

.50375 .3372 L

s

.5 .38482 m

.50375 .38482 L

s

.5 .40863 m

.50375 .40863 L

s

.5 .43244 m

.50375 .43244 L

s

.5 .45625 m

.50375 .45625 L

s

.5 .50387 m

.50375 .50387 L

s

.5 .52768 m

.50375 .52768 L

s

.5 .55149 m

.50375 .55149 L

s

.5 .5753 m

.50375 .5753 L

s

.5 .62292 m

.50375 .62292 L

s

.5 .64673 m

.50375 .64673 L

s

.5 .67053 m

.50375 .67053 L

s

.5 .69434 m

.50375 .69434 L

s

.5 .74196 m

.50375 .74196 L

s

.5 .76577 m

.50375 .76577 L

s

.5 .78958 m

.50375 .78958 L

s

.5 .81339 m

.50375 .81339 L

s

.5 .86101 m

.50375 .86101 L

s

.25 Mabswid

.5 0 m

.5 .88109 L

s

gsave

.5 .90609 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .89359 -195.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.47) show

293.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

298.000000 15.000000 moveto

(L) show

305.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

312.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

319.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

324.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

328.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .88109 L

0 .88109 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .19747 m

.02576 .19747 L

.03157 .19745 L

.04114 .19743 L

.05432 .19739 L

.07086 .19734 L

.0905 .19728 L

.1129 .19721 L

.13766 .19712 L

.16438 .19702 L

.19258 .19689 L

.2218 .19674 L

.25152 .19657 L

.28124 .19638 L

.31045 .19615 L

.33866 .19589 L

.36537 .19559 L

.39014 .19527 L

.41253 .19492 L

.43217 .19456 L

.44872 .1942 L

.46189 .19388 L

.47147 .19362 L

.47728 .19344 L

.47923 .19338 L

s

.47923 .19338 m

.48135 .19332 L

.48769 .1931 L

.49814 .19272 L

.51252 .19212 L

.53058 .19119 L

.55201 .18974 L

.57644 .18741 L

.60347 .18347 L

.63262 .1767 L

.6634 .16596 L

.69528 .15175 L

.72771 .13578 L

.76014 .11948 L

.79202 .10367 L

.8228 .0888 L

.85195 .0751 L

.87898 .06276 L

.90341 .05188 L

.92484 .04256 L

.9429 .03485 L

.95728 .02881 L

.96772 .02447 L

.97406 .02185 L

.97619 .02098 L

s

.47923 .44477 m

.48135 .41789 L

.48769 .39117 L

.49814 .36482 L

.51252 .339 L

.53058 .31395 L

.55201 .28997 L

.57644 .26754 L

.60347 .2475 L

.63262 .23117 L

.6634 .21978 L

.69528 .21296 L

.72771 .20906 L

.76014 .20674 L

.79202 .20527 L

.8228 .20429 L

.85195 .2036 L

.87898 .2031 L

.90341 .20273 L

.92484 .20246 L

.9429 .20226 L

.95728 .20212 L

.96772 .20202 L

.97406 .20196 L

.97619 .20195 L

s

.47923 .44488 m

.48135 .47182 L

.48769 .49876 L

.49814 .52549 L

.51252 .55191 L

.53058 .57789 L

.55201 .60332 L

.57644 .62808 L

.60347 .65206 L

.63262 .67516 L

.6634 .69728 L

.69528 .71832 L

.72771 .73819 L

.76014 .75681 L

.79202 .77408 L

.8228 .78995 L

.85195 .80433 L

.87898 .81717 L

.90341 .82842 L

.92484 .83801 L

.9429 .84592 L

.95728 .85211 L

.96772 .85655 L

.97406 .85922 L

.97619 .86011 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCaA<00?lCaA<006@C1@3G4`D00Q<00`0C4`024`0301<C07DC001V4`0301<C0=TC00<04a<0

1Q<00`0C00034`0301<C070C00114`033A<C01`C0`034`0301<C008C0P3?4`<00a<00`0C4`084`04

01<C4`80LA<0048C00<=4a<08A<00`0C4`024`0301<C0=@C00<04a<01Q<200@C00<04a<0L1<004<C

00<=4a<081<00`0C4`024`0301<C0=@C00<04a<01Q<00`0C4`034`0301<C070C00134`033A<C01lC

0P044`0301<C0=<C0P084`<00a<00`0C4`1I4`033A<C01@C00144`033A<C02@C0P3T4`0301<C05LC

0PdG4`00AA<00`dC4`0S4`0301<C0><C0P1E4`<=6A<004DC00<=4a<08a<00`0C4`3S4`0301<C058C

0PdL4`00AQ<00`dC4`0R4`0301<C0><C00<04a<0D1<23AhC00164`033A<C028C0P3T4`0301<C04hC

0PdP4`00Aa<00`dC4`0Q4`0301<C0><C0P1;4`@=8Q<004PC00<=4a<081<00`0C4`3S4`0301<C04PC

0PdV4`00B1<00`dC4`0P4`0301<C0><C00<04a<0AQ<23BPC00194`033A<C01lC0P3T4`0301<C04@C

0PdZ4`00BQ<00`dC4`0N4`0301<C0><C00<04a<0@Q<23B`C001:4`033A<C01hC00<04a<0ha<2044C

0Pd^4`00Ba<00`dC4`0M4`0301<C0><C00<04a<0?A<33C0C001<4`033A<C01`C0P3T4`0301<C03/C

0Pdc4`00C1<00`dC4`0L4`0301<C0><C00<04a<0>A<23CDC001=4`033A<C00`C00<04a<00Q<00`0C

4`024`0301<C008C00<04a<0ha<203PC0Pdg4`00CQ<00`dC4`0:4`0301<000LC00<04`000a<00`0C

4`3S4`0301<C03DC0Pdi4`00Ca<00`dC4`044`<00Q<00`0C00094`0401<C4`80i1<00`0C4`0c4`8=

>a<004lC00<=4a<02A<00`0C00074`8011<00`0C4`3L4`D00Q<00`0C4`0a4`8=?A<0050C00<=4a<0

21<00`0C00074`0301<C00<C00<04a<0gQ<00`0C4`024`0301<C02lC0Pdo4`00DA<00`dC4`084`03

01<C00HC0`034`0301<C0=PC0`034`0301<C008C0P0^4`8=@A<0058C00<=4a<05Q<00`0C4`3N4`03

01<C008C00<04a<0:a<23D<C001B4`033A<C01HC0P3O4`0301<C008C00<04a<0:A<23DDC001C4`03

3A<C01DC00<04a<0gA<200@C00<04a<09a<23DLC001D4`033A<C01@C00<04a<0ha<00`0C4`0V4`03

3A<C04LC001E4`033A<C01<C00<04a<0ha<202DC0Pe:4`00EA<00`dC4`0C4`80i1<00`0C4`0R4`8=

C1<005HC00<=4a<04Q<00`0C4`3S4`0301<C01lC0`e>4`006Q<302DC1@0@4`033A<C014C00<04a<0

91<502@C0`2C4`0301<C01`C0`eA4`006Q<00`0C4`0W4`0301<C014C00<=4a<041<00`0C4`0V4`03

01<C02@C00<04a<0Ta<201XC0`eD4`005A<300<C00<04a<081<300<C00<04a<04A<00`dC4`0@4`80

9a<00`0C4`0U4`0301<C098C00<04a<05Q<33ELC000K4`0301<C02HC00<04a<04Q<00`dC4`0?4`03

01<C02HC00<04a<09A<00`0C4`2B4`0301<C01<C0`eJ4`006Q<00`0C000W4`0301<C01<C00<=4a<0

3Q<00`0C4`0V4`0301<C02@C00<04`00Ta<00`0C4`0:4`T=GA<001/C00<04a<09A<201DC00<=4a<0

3Q<00`0C4`0U4`809a<00`0C4`2@4`l=IQ<005/C00<=4a<03A<208PCFPd24`80LA<005/C00<=4a<0

3A<00`0C4`3S4`0301<C03lC6`dF4`00G1<00`dC4`0<4`0301<C05/C0P264`0301<C02dC4Pda4`00

GA<00`dC4`0;4`0301<C05XC00<04a<0QQ<00`0C4`0R4`/=@a<001DCB0000`d0001R00HC00<04a<0

QQ<2020C0`e>4`006A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<0

1A<00`0C4`064`0301<C00DC00@04a<=11<00`0C4`054`0341<C00DC00<04a<01Q<00`0C4`054`03

01<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<0

21<00`0C4`264`0301<C01`C0`eA4`00Ga<00`dC4`094`0341<C05XC00<04`00QQ<00`0C4`0I4`<=

E1<005lC00<=4a<02A<245/C0`1g4`0301<C008C00<04a<00Q<00`0C4`024`0301<C01LC0PeG4`00

H1<00`dC4`084`8@e1<00`0C00074`0301<000<C00<04a<05A<23ETC001Q4`033A<C00HC00<@0100

ca<3008C00<04`002A<0100C4a<201@C0PeK4`00HA<00`dC4`064`03400@0=@C00<04`001a<200@C

00<04a<04A<23EdC001R4`033A<C00DC00<@0100e1<00`0C00074`0301<C00<C00<04a<041<00`dC

4`1M4`00Ha<00`dC4`034`0541<00100e1<00`0C4`064`<00a<00`0C4`0>4`8=H1<006@C00<=4a<0

0Q<01A0C01<@0><C0P0>4`033A<C060C001T4`033A<C008C00D@4`0C403S4`0301<C00`C00<=4a<0

HA<006DC00L=4a<C41<0008C00<@4a<0h1<00`0C4`0;4`033A<C068C001V4`053A<C41<00P000a<@

4`3Q4`0301<C00TC0PeU4`00IQ<01PdC4a0C008C00<@4a<0h1<00`0C4`084`033A<C06DC001W4`05

3A0C4`000a<00a0C4`3O4`8021<00`dC4`1V4`00J1<010dC4`034`0341<C0=lC00<04a<01Q<00`dC

4`1W4`00J1<00`dC4`02008C00<@4a<0ga<00`0C4`054`033A<C06PC001W4`0541<=4`0011<00a0C

4`234`<0:Q<502TC00<04a<01A<00`dC4`0P4`D0:Q<301HC001L4`0301<C008C00<04a<00Q<01P0@

4a<=00@C00<@4a<0Pa<00`0C4`0/4`0301<C02TC00<04a<011<00`dC4`0S4`0301<C02XC00<04a<0

5Q<005/C00<04`001a<00`0@00024`033@0C00<C00<@4a<0OQ<300<C00<04a<09A<300<C00<04a<0

:A<200@C00<=4a<091<00`0C4`0[4`0301<C01DC001K4`0301<000PC00<@01<00Q<00`d04`034`03

41<C08<C00<04a<0:a<00`0C4`0Y4`0301<C008C00<=4a<09A<00`0C4`0[4`0301<C01DC001K4`03

01<000LC00<041<00a<00`0=4`034`0341<C088C00<04`00;1<00`0C4`0Y4`0301<C008C00<=4a<0

9A<00`0C4`0Z4`0301<001HC001K4`0301<000LC00<@4a<00a<00`0=4`044`0341<C088C00<04a<0

:Q<202/C00D04a<C3@0W4`80;A<00`0C4`0E4`00G1<00`0C4`064`03400000<C00<04`d011<00a0C

4`3L4`800Q<00`dC4`1/4`00I1<00a0C4`044`8000<C3A<00Q<00a0C4`3L4`0401<C3FlC001T4`03

41<C00@C00@04a<=11<00a0C4`3K4`0301<=070C001S4`0341<C00DC00D04a<C3@034`0341<C0=/C

00<04`d0IQ<200PC001S4`0341<C00DC00<04a<00Q<01@dC4a<@0=`C00<03A<0IA<00`0C4`084`00

HQ<00a0C4`064`0301<C00<C00@=4a<@O1=Q00033@0005d01a<00`0C4`084`00HQ<00a0C4`064`80

11<01@dC4a<@07lC00<04a<01a<00`0C4`064`0301<C00HC00<04a<01Q<00`0C4`064`0301<C00HC

00<04a<01a<00`0C4`064`0301<C00HC00<04a<01Q<00`dC4`064`0301<C00HC00<04a<01a<00`0C

4`064`0301<C00HC00<04a<01Q<00`0C4`064`0301<C00HC00<04a<01a<00`0C4`064`0301<C00TC

00<04a<021<0064C00<@4a<01a<00`0C4`044`043A<C4=/C00<=4a<0IA<00`0C00084`00HA<00a0C

4`074`0301<C00DC00<=4a00fQ<00`d04`1V4`<021<0060C00<@4a<021<00`0C4`054`043A<C4=TC

00<=0000LA<0060C00<@4a<021<200LC00<=4a00f1<00`dC001b4`00Ga<00a0C4`094`0301<C00LC

00<=4a00ea<00`dC001b4`00Ga<00a0C4`094`0301<C00LC00<=4a00ea<00`dC001b4`00GQ<00a0C

4`0:4`0301<C00PC00<=4a00eQ<00`dC001b4`00GQ<00a0C4`0:4`802Q<00`d@4`3D4`033A<C0080

LA<005dC00<@4a<02a<00`0C4`0:4`033A0C0=<C00@=4a<0LQ<005dC00<@4a<011<5008C00<04a<0

2Q<00`d@4`3C4`043A<C078C001L4`0341<C00LC00<04a<00Q<00`0C4`0;4`033A0C0=8C00@=4a<0

LQ<005/C00<@4a<021<00`0C4`024`803A<00`d@4`3A4`043A<C078C001K4`0341<C00PC00<04a<0

0Q<00`0C4`0<4`033A0C0=0C00@=4a<C0P1a4`00FQ<00a0C4`094`0301<C008C00<04a<03A<00`d@

4`3?4`053A<C4`00LQ<005XC00<@4a<021<200@C00<04a<03Q<00`d@4`3>4`053A<C4`00LQ<005TC

00<@4a<03a<200lC00<=41<0cQ<01@dC4a<0078C001H4`0341<C010C00<04a<03a<00`d@4`3=4`04

3A<C4`80LA<005PC00<@4a<041<00`0C4`0?4`033A<@0<hC00@=4a<0LQ<005LC00<@4a<04A<00`0C

4`0@4`033A0C0<dC00@=4a<0LQ<005HC00<@4a<04Q<2018C00<=41<0`1<00`0C4`024`0301<C008C

00<04`d00Q<00`0C4`1`4`00EQ<00a0C4`0B4`0301<C014C00<=4a00_a<00`0C00074`0401<03@8C

00<04a<0L1<005DC00<@4a<04a<00`0C4`0B4`033A0C0;hC00<04`002A<0100=4a<2074C001D4`03

41<C01@C00<04a<04a<00`d@4`2m4`0301<000LC0P024`033A<0078C001C4`0341<C01DC0P0D4`03

3A0C0;dC00<04`001a<01`0C4a<=4`00LQ<005<C00<@4a<05A<00`0C4`0D4`033A0C0;dC00<04a<0

1Q<300044`dC078C001B4`0341<C01HC00<04a<05A<00`d@4`394`043A<0074C001A4`0341<C01LC

00<04a<05A<00`d@4`3:4`033@0C074C001A4`0341<C01LC0P0G4`033A0C0<TC00<=01<0LA<0050C

00<@4a<061<00`0C4`0G4`033A<C0<TC00<=4a<0L1<004lC00<@4a<021<5008C00<04a<00Q<00`0C

4`024`0301<C01PC00<=4a<0b1<00`dC4`1`4`00Ca<00a0C4`0:4`0301<C00HC00<04`000a<00`0C

4`0H4`033A0C0<PC00<=01<0L1<004hC00<@4a<02a<00`0C4`084`0401<C4`806Q<00`d@4`374`03

00dC070C001=4`0341<C00`C00<04a<01Q<200@C00<04a<06Q<00`dC4`364`0300dC070C001<4`03

41<C00dC00<04a<01Q<00`0C4`034`0301<C01XC00<=41<0aQ<00`0C3@1`4`00C1<00a0C4`0<4`80

21<300<C00<04a<06a<00`d@4`354`8000<=4a<0KQ<004/C00<@4a<07A<201dC00<=41<0a1<0100C

4`e_4`00BQ<00a0C4`0N4`0301<C01`C00<=41<0a1<01@0C4a<=06hC001:4`0341<C01hC00<04a<0

7A<00`d@4`334`0501<C4`d0KQ<004TC00<@4a<07a<00`0C4`0N4`033A0C0<8C00<04a<00Q<00`dC

4`1[4`00B1<00a0C4`0P4`807a<00`dC40324`800a<00`dC4`1[4`00Aa<00a0C4`0Q4`0301<C01lC

00<=4a00`A<00`0C4`034`033A<C06XC00174`0341<C024C00<04a<081<00`d@4`304`0301<C00@C

00<=4a<0JA<004HC00<@4a<08Q<00`0C4`0P4`033A<@0;TC1@024`0301<C00DC00<=4a<0J1<004DC

00<@4a<08a<2028C00<=4a00^Q<00`0C4`024`0301<C00HC00<=4a<0Ia<004@C00<@4a<091<00`0C

4`0R4`033A<@0;TC00<04a<00Q<200PC00<=4a<0IQ<004@C00<@4a<091<00`0C4`0R4`033A<@0;TC

00<04a<00Q<00`0C4`084`033A<C06DC00134`0341<C02DC00<04a<08a<00`dC402h4`0301<C008C

00<04a<02A<00`dC4`1T4`00@Q<00a0C4`0V4`0301<C02<C00@=4a<@]Q<200@C00<04a<02Q<00`dC

4`1S4`00@A<00a0C4`0W4`809A<010dC4a2k4`8031<00`dC4`1R4`00@1<00a0C4`0X4`0301<C02DC

00@=4a<@^Q<00`0C4`0<4`033A<C064C00104`0341<C028C0`034`0301<C02DC00D=4a<C402i4`03

01<C00dC00<=4a<0H1<003lC00<@4a<08a<00`0C4`034`0301<C02HC00@=4a<@^A<00`0C4`0>4`03

3A<C05lC000n4`0341<C02DC00<04a<00Q<202PC00@=4a<@^1<00`0C4`0?4`033A<C05hC000m4`03

41<C02HC00<04a<00Q<00`0C4`0X4`043A<C4;LC0P0A4`033A<C05dC000m4`0341<C02DC00<04`00

0a<00`0C4`0X4`053A<C4a00]Q<00`0C4`0A4`033A<C05`C000l4`0341<C02LC00<04a<00Q<00`0C

4`0Y4`053A<C4a00]A<00`0C4`0B4`8=G1<003/C00<@4a<0;A<202/C00D=4a<C402d4`0301<C01@C

00<=4a<0FA<003XC00<@4a<0;Q<00`0C4`0[4`043A<C4;@C0P0F4`8=FA<003XC00<@4a<0;Q<00`0C

4`0[4`053A<C4a00/a<00`0C4`0G4`033A<C05HC000i4`0341<C02lC00<04a<0;1<01@dC4a<@0;8C

00<04a<061<00`dC4`1E4`00>1<00a0C4`0`4`80;Q<01@dC4a<@0;4C00<04a<06A<00`dC4`1D4`00

=a<00a0C4`0a4`0301<C02hC00@=4a<@/A<00`0C4`0J4`8=E1<003LC00<@4a<0<A<00`0C4`0^4`05

3A<C4a00/1<201dC00<=4a<0DA<003HC00<@4a<0<Q<00`0C4`0_4`053A<C4a00[a<00`0C4`0M4`03

3A<C050C000e4`0341<C03<C0P0a4`053A<C4a00[Q<00`0C4`0N4`8=D1<003@C00<@4a<0=1<00`0C

4`0`4`033A<C008C00<@4a<0VQ<5008C00<04a<00Q<00`0C4`024`0301<C020C00<=4a<0CA<003<C

00<@4a<0=A<00`0C4`0a4`033A<C008C00<@4a<0Va<00`0C4`064`0301<000<C00<04a<08A<23DdC

000b4`0341<C03HC00<04a<0<A<00`dC4`024`0341<C09/C00<04a<021<0100C4a<202@C00<=4a<0

BQ<0034C00<@4a<0=a<203<C00<=4a<00Q<00a0C4`2J4`0301<C00HC0P044`0301<C02@C0Pe:4`00

<1<00a0C4`0h4`0301<C03<C00<=4a<00Q<00a0C4`2I4`0301<C00HC00<04a<00a<00`0C4`0V4`8=

B1<002lC00<@4a<0:A<300<C00<04a<00Q<00`0C4`024`0301<C03<C00<=4a<00a<00a0C4`2G4`80

21<300<C00<04a<0:1<23DHC000^4`0341<C02XC00<04a<01a<00`0C00034`0301<C03@C00<=4a<0

0a<00a0C4`2V4`80:a<23D@C000]4`0341<C02`C00<04a<021<0100C4a<203HC00<=4a<00a<00a0C

4`2U4`0301<C02`C00<=4a<0@A<002`C00<@4a<0;A<00`0C4`064`8011<00`0C4`0e4`033A<C00@C

00<@4a<0Y1<00`0C4`0]4`8=@A<002/C00<@4a<0;A<00`0C00074`0301<C00<C00<04a<0=Q<00`dC

4`044`0341<C0:<C00<04a<0;a<00`dC4`0n4`00:Q<00a0C4`0_4`0301<C00HC0`034`0301<C03LC

00<=4a<011<00a0C4`2R4`0301<C030C0Pdn4`00:A<00a0C4`0o4`80>1<00`dC4`054`0341<C0:4C

0P0c4`8=?1<002PC00<@4a<0@1<00`0C4`0h4`033A<C00DC00<@4a<0X1<00`0C4`0d4`8=>Q<002LC

00<@4a<0@A<00`0C4`0i4`033A<C00DC00<@4a<0Wa<00`0C4`0f4`8=>1<002HC00<@4a<0@Q<00`0C

4`0j4`033A<C00DC00<@4a<0WQ<00`0C4`0h4`8==Q<002DC00<@4a<0@a<203/C00<=4a<01Q<00a0C

4`2M4`80>a<23C@C000T4`0341<C04@C00<04a<0>a<00`dC4`064`0341<C09`C00<04a<0?1<23C8C

000S4`0341<C04DC00<04a<0?1<00`dC4`064`0341<C09/C00<04a<0?Q<23C0C000S4`0341<C04DC

00<04a<0?1<00`dC4`074`0341<C09XC00<04a<0@1<23BhC000R4`0341<C04HC0P0n4`033A<C00LC

00<@4a<0VA<00`0C4`124`8=;1<0024C00<@4a<0Aa<00`0C4`0m4`033A<C00PC00<@4a<0V1<204DC

0PdZ4`0081<00a0C4`184`0301<C03hC00<=4a<021<00a0C4`2G4`0301<C04HC0PdX4`007a<00a0C

4`194`0301<C03lC00<=4a<021<00a0C4`2@4`<00a<00`0C4`184`8=9Q<001hC00<@4a<0BQ<2040C

00<=4a<02A<00a0C4`2?4`0301<C00<C00<04a<0BQ<23B@C000M4`0341<C04/C00<04a<0@1<00`dC

4`094`0341<C08lC00<04a<00Q<204dC0PdR4`0071<00a0C4`1<4`0301<C040C00<=4a<02Q<00a0C

4`2>4`0301<C008C00<04a<0CQ<33AlC000K4`0341<C04LC0P044`0301<C044C00<=4a<02Q<00a0C

4`2<4`0301<000<C00<04a<0DA<33A`C000J4`0341<C04XC00D04a<C00144`033A<C00XC00<@4a<0

S1<00`0C4`024`0301<C05@C0PdJ4`006A<00a0C4`1:4`0301<C008C0P144`033A<C00TC00<@4a<0

TA<00`0C4`1F4`8=61<006LC00<04a<0ia<205TC0PdF4`00IA<00`0C003Y4`0301<C070C001V4`03

01<C0>PC00<04a<0L1<002`C0`3o4b<C00<04a<0L1<002`C00<04a<0oa<S4`0301<C070C000]4`03

01<C00DC00<04a<0oa>=4`00;A<0100C4a<300044`0C4`<0oa>:4`00;1<00`0C00024`800Q<00`0C

4`024`0301<C0?lCR1<002dC00<04a<00a<0100C4`024`0301<C0?lCRA<003<C00@04a<00a<00`0C

4`064`0301<C02DC0`0]4`0301<C0?lC9a<001dC0`000a<0000200`C0`044`<021<00`0C4`0T4`04

01<C014C0`000a<00002008C00<04a<00Q<00`0C4`024`0301<C00DC00@04a<C1@024`0301<C008C

0`024`0301<C00@C0P3;4`0301<C038C00<04a<021<001`C00@04a<091<00`0C4`0S4`0401<C010C

00@04a<01Q<00`0C00074`0301<000@C1@034`0301<C00PC00D04a<C00054`0301<C0<<C00<04a<0

11<00`0C4`0C4`0301<C01hC00<04a<01a<001`C00D04a<04`0400034`0001P0:a<3010C00D04a<0

4`0400044`0C00TC00<04a<011<00`0C4`034`0301<C00HC10024`0301<C00<C00<04a<0/A<0100C

4a<4008C0P064`0301<C00<C00<04a<00Q<00`0C4`024`0301<C008C00<04a<01A<0100C4a<5008C

00<04a<00Q<3008C00<04a<011<200@C00@04a<C0P014`400@0001dC0`1=4`0301<C00lC0`064`03

01<000LC0P074`0301<C00<C00<04a<01Q<00`0C00044`0301<C008C00<04a<0/1<00`0C00074`03

01<C00@C1@034`0701<C4`0C00074`0301<000@C1@034`0301<C00PC00D04a<C00054`0301<C00@C

00<04a<00Q<00`0C00014`007a<00`0C4`1:4`804a<00`0C4`044`0301<000LC00<04a<031<00`0C

4`074`800Q<00`0C00044`0301<00;0C00<04`000Q<400034`0C00LC00<04a<00a<01`0C4a<04`00

2A<00`0C4`044`0301<C00<C00<04a<01Q<4008C00<04a<00a<00`0C4`044`0301<C00<C0@014`4C

000N4`80H1<200LC00<04a<01Q<300/C0P0:4`0301<C00<011<309HC0P000a<0000E4`0301<000LC

00<04a<01Q<00`0C4`034`0701<C4`0C00074`801a<00`0C4`034`0301<C00HC00<04`0011<00`0C

4`024`0301<C00@C00<04a<00a<1004C0A<00?lCDA<00`0C000F4`0301<000LC00<04`003A<01P0C

4`0C00LC00<04a<031<00`0C4`074`800Q<00`0C00044`0301<000<C00<04a<00a<00`0C00014`00

:A<200HC0P3o4alC00<04a<05Q<00`0C4`064`<03Q<0100C4`084`<02a<200XC00<04a<00`044`<0

0Q<00`0C4`034`800A<10040000[4`0301<C008C00<04a<0oa<O4`0301<C070C000Z4`0301<C00<C

00<04a<01A<00`0C4`3o4aHC00<04`00LA<002/C00<04a<00Q<00`0C4`024`@00a<30?lC4A<20003

4`00070C000Y4`0301<000@C00<04`000Q<200034`0C00@C00<04a<0oa>44`00:Q<00`0C4`034`<0

11<00`0C00034`0301<C0?lCQA<003LC00<04`0011<00`0C4`3o4h@C000e4`<011<30?lCQQ<00?lC

aA<00?lCaA<00?lCaA<00?lCaA<00?lCaA<00001\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.36798, -1.70462, 0.021825, 0.021825}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -84.5 0 ]

[.5 .96488 84.5 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -145.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.465) show

222.250000 19.500000 moveto

(C) show

227.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.25622 0 m

.26171 .00805 L

.30316 .06877 L

.34309 .12726 L

.3815 .18354 L

.42237 .24341 L

.46172 .30106 L

.49955 .35649 L

.53984 .41551 L

.57861 .47231 L

.61984 .5327 L

.65954 .59087 L

.69774 .64683 L

.73838 .70637 L

.77751 .7637 L

.81909 .82462 L

.85916 .88331 L

.89771 .93979 L

s

.89771 .93979 m

.90631 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.35969 0.238095 [

[.02381 .34719 -6 -9 ]

[.02381 .34719 6 0 ]

[.2619 .34719 -6 -9 ]

[.2619 .34719 6 0 ]

[.7381 .34719 -3 -9 ]

[.7381 .34719 3 0 ]

[.97619 .34719 -3 -9 ]

[.97619 .34719 3 0 ]

[1.025 .35969 0 -8 ]

[1.025 .35969 9 8 ]

[.4875 .00255 -24 -4.5 ]

[.4875 .00255 0 4.5 ]

[.4875 .1216 -12 -4.5 ]

[.4875 .1216 0 4.5 ]

[.4875 .24064 -24 -4.5 ]

[.4875 .24064 0 4.5 ]

[.4875 .47874 -18 -4.5 ]

[.4875 .47874 0 4.5 ]

[.4875 .59779 -6 -4.5 ]

[.4875 .59779 0 4.5 ]

[.4875 .71683 -18 -4.5 ]

[.4875 .71683 0 4.5 ]

[.4875 .83588 -6 -4.5 ]

[.4875 .83588 0 4.5 ]

[.5 .90421 -4.5 0 ]

[.5 .90421 4.5 16 ]

[.5 .89171 -137 0 ]

[.5 .89171 137 16 ]

[ 0 0 0 0 ]

[ 1 .87921 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .35969 m

.02381 .36594 L

s

[(-2)] .02381 .34719 0 1 Mshowa

.2619 .35969 m

.2619 .36594 L

s

[(-1)] .2619 .34719 0 1 Mshowa

.7381 .35969 m

.7381 .36594 L

s

[(1)] .7381 .34719 0 1 Mshowa

.97619 .35969 m

.97619 .36594 L

s

[(2)] .97619 .34719 0 1 Mshowa

.125 Mabswid

.07143 .35969 m

.07143 .36344 L

s

.11905 .35969 m

.11905 .36344 L

s

.16667 .35969 m

.16667 .36344 L

s

.21429 .35969 m

.21429 .36344 L

s

.30952 .35969 m

.30952 .36344 L

s

.35714 .35969 m

.35714 .36344 L

s

.40476 .35969 m

.40476 .36344 L

s

.45238 .35969 m

.45238 .36344 L

s

.54762 .35969 m

.54762 .36344 L

s

.59524 .35969 m

.59524 .36344 L

s

.64286 .35969 m

.64286 .36344 L

s

.69048 .35969 m

.69048 .36344 L

s

.78571 .35969 m

.78571 .36344 L

s

.83333 .35969 m

.83333 .36344 L

s

.88095 .35969 m

.88095 .36344 L

s

.92857 .35969 m

.92857 .36344 L

s

.25 Mabswid

0 .35969 m

1 .35969 L

s

gsave

1.025 .35969 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .00255 m

.50625 .00255 L

s

[(-1.5)] .4875 .00255 1 0 Mshowa

.5 .1216 m

.50625 .1216 L

s

[(-1)] .4875 .1216 1 0 Mshowa

.5 .24064 m

.50625 .24064 L

s

[(-0.5)] .4875 .24064 1 0 Mshowa

.5 .47874 m

.50625 .47874 L

s

[(0.5)] .4875 .47874 1 0 Mshowa

.5 .59779 m

.50625 .59779 L

s

[(1)] .4875 .59779 1 0 Mshowa

.5 .71683 m

.50625 .71683 L

s

[(1.5)] .4875 .71683 1 0 Mshowa

.5 .83588 m

.50625 .83588 L

s

[(2)] .4875 .83588 1 0 Mshowa

.125 Mabswid

.5 .02636 m

.50375 .02636 L

s

.5 .05017 m

.50375 .05017 L

s

.5 .07398 m

.50375 .07398 L

s

.5 .09779 m

.50375 .09779 L

s

.5 .1454 m

.50375 .1454 L

s

.5 .16921 m

.50375 .16921 L

s

.5 .19302 m

.50375 .19302 L

s

.5 .21683 m

.50375 .21683 L

s

.5 .26445 m

.50375 .26445 L

s

.5 .28826 m

.50375 .28826 L

s

.5 .31207 m

.50375 .31207 L

s

.5 .33588 m

.50375 .33588 L

s

.5 .3835 m

.50375 .3835 L

s

.5 .40731 m

.50375 .40731 L

s

.5 .43112 m

.50375 .43112 L

s

.5 .45493 m

.50375 .45493 L

s

.5 .50255 m

.50375 .50255 L

s

.5 .52636 m

.50375 .52636 L

s

.5 .55017 m

.50375 .55017 L

s

.5 .57398 m

.50375 .57398 L

s

.5 .6216 m

.50375 .6216 L

s

.5 .6454 m

.50375 .6454 L

s

.5 .66921 m

.50375 .66921 L

s

.5 .69302 m

.50375 .69302 L

s

.5 .74064 m

.50375 .74064 L

s

.5 .76445 m

.50375 .76445 L

s

.5 .78826 m

.50375 .78826 L

s

.5 .81207 m

.50375 .81207 L

s

.5 .85969 m

.50375 .85969 L

s

.25 Mabswid

.5 0 m

.5 .87921 L

s

gsave

.5 .90421 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .89171 -198 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.465) show

298.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

303.000000 15.000000 moveto

(L) show

310.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

317.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

324.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

329.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

333.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .87921 L

0 .87921 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .19573 m

.02576 .19572 L

.03157 .19571 L

.04114 .19569 L

.05432 .19565 L

.07086 .19561 L

.0905 .19555 L

.11289 .19549 L

.13766 .19541 L

.16437 .19531 L

.19257 .1952 L

.22179 .19506 L

.25151 .1949 L

.28123 .19472 L

.31044 .19452 L

.33864 .19428 L

.36536 .19401 L

.39012 .19372 L

.41251 .1934 L

.43215 .19307 L

.4487 .19275 L

.46187 .19245 L

.47145 .19221 L

.47726 .19205 L

.4792 .192 L

s

.4792 .192 m

.48133 .19194 L

.48767 .19174 L

.49812 .1914 L

.5125 .19085 L

.53055 .19 L

.55199 .18868 L

.57642 .18654 L

.60345 .18289 L

.6326 .17647 L

.66338 .16601 L

.69526 .15186 L

.7277 .13587 L

.76013 .11953 L

.79201 .10369 L

.82279 .08878 L

.85194 .07507 L

.87897 .06272 L

.90341 .05184 L

.92484 .04251 L

.9429 .03481 L

.95728 .02876 L

.96772 .02442 L

.97406 .02181 L

.97619 .02093 L

s

.4792 .44348 m

.48133 .41662 L

.48767 .38991 L

.49812 .36354 L

.5125 .33771 L

.53055 .3126 L

.55199 .28853 L

.57642 .26594 L

.60345 .24565 L

.6326 .22899 L

.66338 .21737 L

.69526 .2105 L

.7277 .20666 L

.76013 .20441 L

.79201 .203 L

.82279 .20207 L

.85194 .20141 L

.87897 .20094 L

.90341 .2006 L

.92484 .20034 L

.9429 .20016 L

.95728 .20002 L

.96772 .19993 L

.97406 .19988 L

.97619 .19986 L

s

.4792 .44359 m

.48133 .47051 L

.48767 .49742 L

.49812 .52413 L

.5125 .55052 L

.53055 .57647 L

.55199 .60186 L

.57642 .62659 L

.60345 .65054 L

.6326 .67361 L

.66338 .6957 L

.69526 .7167 L

.7277 .73655 L

.76013 .75513 L

.79201 .77238 L

.82279 .78822 L

.85194 .80258 L

.87897 .81541 L

.90341 .82663 L

.92484 .83621 L

.9429 .84411 L

.95728 .85029 L

.96772 .85472 L

.97406 .85739 L

.97619 .85828 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCaA<00?lCaA<006@C1@3G4`D00Q<00`0C4`024`0301<C07DC001V4`0301<C0=TC00<04a<0

1Q<00`0C001f4`00@A<00`dC4`0L4`<00a<00`0C4`024`80ca<300<C00<04a<021<0100C4a<2074C

00124`033A<C024C00<04a<00Q<00`0C4`3D4`0301<C00HC0P044`0301<C070C00134`033A<C020C

00<04a<00Q<00`0C4`3D4`0301<C00HC00<04a<00a<00`0C4`1`4`00@a<00`dC4`0O4`8011<00`0C

4`3C4`8021<300<C00<04a<0L1<004@C00<=4a<091<20>@C00<04a<0Ea<33AHC00154`033A<C02<C

00<04a<0ha<205DC0`dI4`00AA<00`dC4`0S4`0301<C0><C00<04a<0DQ<23A`C00164`033A<C028C

00<04a<0ha<00`0C4`1@4`8=7Q<004HC00<=4a<08Q<20>@C00<04a<0Ca<00`dC4`0N4`00Aa<00`dC

4`0Q4`0301<C0><C0P1>4`8=8A<004PC00<=4a<081<00`0C4`3S4`0301<C04XC0`dS4`00B1<00`dC

4`0P4`0301<C0><C00<04a<0B1<23BHC00194`033A<C01lC0P3T4`0301<C04DC0`dX4`00BQ<00`dC

4`0N4`0301<C0><C00<04a<0@a<23B/C001:4`033A<C01hC00<04a<0ha<2048C0Pd]4`00Ba<00`dC

4`0M4`0301<C0><C00<04a<0?a<23BlC001<4`033A<C01`C0P3T4`0301<C03dC0Pda4`00C1<00`dC

4`0L4`0301<C0><C00<04a<0>a<23C<C001=4`033A<C00`C00<04a<00Q<00`0C4`024`0301<C008C

00<04a<0ha<203XC0Pde4`00CQ<00`dC4`0:4`0301<000LC00<04`000a<00`0C4`3S4`0301<C03LC

0Pdg4`00Ca<00`dC4`044`<00Q<00`0C00094`0401<C4`80i1<00`0C4`0e4`8=>A<004lC00<=4a<0

2A<00`0C00074`8011<00`0C4`3L4`D00Q<00`0C4`0c4`8=>a<0050C00<=4a<021<00`0C00074`03

01<C00<C00<04a<0gQ<00`0C4`024`0301<C034C0Pdm4`00DA<00`dC4`084`0301<C00HC0`034`03

01<C0=PC0`034`0301<C008C0P0`4`8=?a<0054C00<=4a<05a<00`0C4`3N4`0301<C008C00<04a<0

;A<23D4C001B4`033A<C01HC0P3O4`0301<C008C00<04a<0:a<23D<C001C4`033A<C01DC00<04a<0

gA<200@C00<04a<0:A<23DDC001C4`033A<C01DC00<04a<0ha<00`0C4`0W4`8=Aa<005@C00<=4a<0

51<00`0C4`3S4`809Q<23DTC001E4`033A<C01<C0P3T4`0301<C02<C0Pe;4`00EQ<00`dC4`0B4`03

01<C0><C00<04a<08A<23DdC000J4`<09A<500lC00<=4a<04Q<00`0C4`0T4`D091<309<C00<04a<0

7a<23DlC000J4`0301<C02LC00<04a<041<00`dC4`0A4`0301<C02HC00<04a<091<00`0C4`2C4`80

7A<33E4C000E4`<00a<00`0C4`0P4`<00a<00`0C4`0A4`033A<C010C0P0W4`0301<C02DC00<04a<0

TQ<00`0C4`0I4`<=E1<001/C00<04a<09Q<00`0C4`0A4`033A<C010C00<04a<09Q<00`0C4`0U4`03

01<C098C00<04a<05A<43ELC000J4`0301<002LC00<04a<04Q<00`dC4`0?4`0301<C02HC00<04a<0

91<00`0C002C4`0301<C00XC2`eK4`006a<00`0C4`0U4`805A<00`dC4`0>4`0301<C02DC0P0W4`03

01<C090C3`eV4`00FQ<00`dC4`0>4`80R1=J3@8C0P1a4`00Fa<00`dC4`0=4`0301<C0><C00<04a<0

>A<Q3AHC001L4`033A<C00`C00<04a<0Fa<208HC00<04a<09a<B3CLC001M4`033A<C00/C00<04a<0

FQ<00`0C4`264`0301<C024C1Pe94`005A=800033@0006801Q<00`0C4`264`807Q<43DlC000I4`03

01<C00HC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<0

1A<0100C4`d44`0301<C00DC00<@4a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`03

01<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`084`0301<C08HC00<04a<0

6a<23E<C001O4`033A<C00TC00<@4a<0FQ<00`0C00264`0301<C01TC0PeE4`00Ga<00`dC4`094`8@

Fa<307LC00<04a<00Q<00`0C4`024`0301<C008C00<04a<05a<23ELC001P4`033A<C00PC0Q3D4`03

01<000LC00<04`000a<00`0C4`0E4`8=FA<0064C00<=4a<01Q<00a00403?4`<00Q<00`0C00094`04

01<C4`8051<23E/C001Q4`033A<C00HC00<@0100e1<00`0C00074`8011<00`0C4`0A4`8=GA<0068C

00<=4a<01A<00a00403D4`0301<000LC00<04a<00a<00`0C4`0@4`033A<C05dC001S4`033A<C00<C

00D@4`00403D4`0301<C00HC0`034`0301<C00hC0PeP4`00I1<00`dC4`024`0541<04a00ha<200hC

00<=4a<0H1<006@C00<=4a<00Q<01A0C01<@0><C00<04a<031<00`dC4`1Q4`00IA<01`dC4a<@4`00

0Q<00a0C4`3P4`0301<C00/C00<=4a<0HQ<006HC00D=4a<@4`0200034a0C0>4C00<04a<02A<23FDC

001V4`063A<C41<00Q<00a0C4`3P4`0301<C00PC00<=4a<0IA<006LC00D=41<C00034`0341<C0=lC

0P084`033A<C06HC001X4`043A<C00<C00<@4a<0ga<00`0C4`064`033A<C06LC001X4`033A<C0080

0Q<00a0C4`3O4`0301<C00DC00<=4a<0J1<006LC00D@4`dC00044`0341<C08<C0`0Z4`D0:A<00`0C

4`054`033A<C020C1@0Z4`<05Q<005`C00<04a<00Q<00`0C4`024`06010C4`d011<00a0C4`234`03

01<C02`C00<04a<0:A<00`0C4`044`033A<C02<C00<04a<0:Q<00`0C4`0F4`00Fa<00`0C00074`03

0100008C00<=01<00a<00a0C4`1n4`<00a<00`0C4`0U4`<00a<00`0C4`0Y4`8011<00`dC4`0T4`03

01<C02/C00<04a<05A<005/C00<04`0021<00a004`024`033@0C00<C00<@4a<0Pa<00`0C4`0[4`03

01<C02TC00<04a<00Q<00`dC4`0U4`0301<C02/C00<04a<05A<005/C00<04`001a<00`0@4`034`03

00dC00<C00<@4a<0PQ<00`0C000/4`0301<C02TC00<04a<00Q<00`dC4`0U4`0301<C02XC00<04`00

5Q<005/C00<04`001a<00a0C4`034`0300dC00@C00<@4a<0PQ<00`0C4`0Z4`80:a<01@0C4a<=02LC

0P0]4`0301<C01DC001L4`0301<C00HC00<@00000a<00`0C3@044`0341<C0=`C0P024`033A<C06`C

001T4`0341<C00@C0P000a<=4`024`0341<C0=`C00@04a<=Ka<006@C00<@4a<011<0100C4`d44`03

41<C0=/C00<04`d0L1<006<C00<@4a<01A<01@0C4a<=00<C00<@4a<0fa<00`0C3@1V4`8021<006<C

00<@4a<01A<00`0C4`024`053A<C4a00g1<00`0=4`1U4`0301<C00PC001R4`0341<C00HC00<04a<0

0a<010dC4a1l4f4000<=0000G@074`0301<C00PC001R4`0341<C00HC0P044`053A<C4a00Oa<00`0C

4`074`0301<C00HC00<04a<01Q<00`0C4`064`0301<C00HC00<04a<01Q<00`0C4`074`0301<C00HC

00<04a<01Q<00`0C4`064`033A<C00HC00<04a<01Q<00`0C4`074`0301<C00HC00<04a<01Q<00`0C

4`064`0301<C00HC00<04a<01Q<00`0C4`074`0301<C00HC00<04a<02A<00`0C4`084`00HA<00a0C

4`074`0301<C00@C00@=4a<@fa<00`dC4`1U4`0301<000PC001Q4`0341<C00LC00<04a<01A<00`dC

403J4`033@0C06HC0`084`00H1<00a0C4`084`0301<C00DC00@=4a<@fA<00`d0001a4`00H1<00a0C

4`084`801a<00`dC403H4`033A<0078C001O4`0341<C00TC00<04a<01a<00`dC403G4`033A<0078C

001O4`0341<C00TC00<04a<01a<00`dC403G4`033A<0078C001N4`0341<C00XC00<04a<021<00`dC

403F4`033A<0078C001N4`0341<C00XC0P0:4`033A0C0=@C00<=4a<00P1a4`00GA<00a0C4`0;4`03

01<C00XC00<=41<0da<010dC4`1b4`00GA<00a0C4`044`D00Q<00`0C4`0:4`033A0C0=<C00@=4a<0

LQ<005`C00<@4a<01a<00`0C4`024`0301<C00/C00<=41<0dQ<010dC4`1b4`00Fa<00a0C4`084`03

01<C008C0P0=4`033A0C0=4C00@=4a<0LQ<005/C00<@4a<021<00`0C4`024`0301<C00`C00<=41<0

d1<010dC4a<2074C001J4`0341<C00TC00<04a<00Q<00`0C4`0=4`033A0C0<lC00D=4a<C001b4`00

FQ<00a0C4`084`8011<00`0C4`0>4`033A0C0<hC00D=4a<C001b4`00FA<00a0C4`0?4`803a<00`d@

4`3>4`053A<C4`00LQ<005PC00<@4a<041<00`0C4`0?4`033A0C0<dC00@=4a<C0P1a4`00F1<00a0C

4`0@4`0301<C00lC00<=4a00cQ<010dC4`1b4`00Ea<00a0C4`0A4`0301<C010C00<=41<0cA<010dC

4`1b4`00EQ<00a0C4`0B4`804Q<00`d@4`304`0301<C008C00<04a<00Q<00`0C3@024`0301<C070C

001F4`0341<C018C00<04a<04A<00`dC402o4`0301<000LC00@04`0=0Q<00`0C4`1`4`00EA<00a0C

4`0C4`0301<C018C00<=41<0_Q<00`0C00094`0400dC4`80LA<005@C00<@4a<051<00`0C4`0C4`03

3A0C0;dC00<04`001a<2008C00<=4`00LQ<005<C00<@4a<05A<201DC00<=4a<0_1<00`0C00074`07

01<C4`dC001b4`00Da<00a0C4`0E4`0301<C01@C00<=41<0_A<00`0C4`064`<000@C3A<0LQ<0058C

00<@4a<05Q<00`0C4`0E4`033A0C0<TC00@=4`00LA<0054C00<@4a<05a<00`0C4`0F4`033A<C0<TC

00<=01<0LA<0054C00<@4a<05a<201PC00<=4a<0b1<00`d04`1a4`00D1<00a0C4`0H4`0301<C01LC

00<=4a<0bA<00`dC4`1`4`00Ca<00a0C4`084`D00Q<00`0C4`024`0301<C008C00<04a<061<00`dC

4`384`033A<C070C001?4`0341<C00XC00<04a<01Q<00`0C00034`0301<C01TC00<=4a<0aa<00`d0

4`1`4`00CQ<00a0C4`0;4`0301<C00PC00@04a<C0P0K4`033A<C0<HC00<03A<0L1<004dC00<@4a<0

31<00`0C4`064`8011<00`0C4`0J4`033A<C0<HC00<03A<0L1<004`C00<@4a<03A<00`0C4`064`03

01<C00<C00<04a<06a<00`dC4`354`0301<=070C001<4`0341<C00`C0P084`<00a<00`0C4`0K4`03

3A0C0<DC00<04`d0L1<004/C00<@4a<07A<201dC00<=41<0a1<200034`dC06hC001:4`0341<C01hC

00<04a<07A<00`dC4`334`0501<C4`d0KQ<004XC00<@4a<07Q<00`0C4`0M4`033A0C0<<C00D04a<C

3@1^4`00BA<00a0C4`0O4`0301<C01hC00<=41<0`Q<00`0C4`024`033A<C06/C00184`0341<C020C

0P0O4`033A<@0<8C0P034`033A<C06/C00174`0341<C024C00<04a<07a<00`dC40314`0301<C00<C

00<=4a<0JQ<004LC00<@4a<08A<00`0C4`0P4`033A0C0<0C00<04a<011<00`dC4`1Y4`00AQ<00a0C

4`0R4`0301<C020C00<=4a00^A<5008C00<04a<01A<00`dC4`1X4`00AA<00a0C4`0S4`808Q<00`dC

402j4`0301<C008C00<04a<01Q<00`dC4`1W4`00A1<00a0C4`0T4`0301<C028C00<=4a00^A<00`0C

4`024`8021<00`dC4`1V4`00A1<00a0C4`0T4`0301<C028C00<=4a00^A<00`0C4`024`0301<C00PC

00<=4a<0IA<004<C00<@4a<09A<00`0C4`0S4`033A<@0;PC00<04a<00Q<00`0C4`094`033A<C06@C

00124`0341<C02HC00<04a<091<00`dC402f4`8011<00`0C4`0:4`033A<C06<C00114`0341<C02LC

0P0V4`033A<@0;/C0P0<4`033A<C068C00104`0341<C02PC00<04a<09A<010dC4a2j4`0301<C00`C

00<=4a<0HA<0040C00<@4a<08Q<300<C00<04a<09Q<010dC4a2i4`0301<C00dC00<=4a<0H1<003lC

00<@4a<08a<00`0C4`034`0301<C02LC00<=4a00^A<00`0C4`0>4`033A<C05lC000n4`0341<C02DC

00<04a<00Q<202PC00@=4a<@^1<00`0C4`0?4`033A<C05hC000m4`0341<C02HC00<04a<00Q<00`0C

4`0X4`043A<C4;LC0P0A4`033A<C05dC000m4`0341<C02DC00<04`000a<00`0C4`0Y4`043A<C4;HC

00<04a<04A<00`dC4`1L4`00?1<00a0C4`0W4`0301<C008C00<04a<0:A<01@dC4a<@0;DC00<04a<0

4Q<23E`C000k4`0341<C02dC0P0[4`053A<C4a00]1<00`0C4`0D4`033A<C05TC000j4`0341<C02hC

00<04a<0:a<010dC4a2d4`805Q<23ETC000j4`0341<C02hC00<04a<0;1<010dC4a2c4`0301<C01LC

00<=4a<0EQ<003TC00<@4a<0;a<00`0C4`0/4`053A<C4a00/Q<00`0C4`0H4`033A<C05DC000h4`03

41<C030C0P0^4`053A<C4a00/A<00`0C4`0I4`033A<C05@C000g4`0341<C034C00<04a<0;Q<010dC

4a2a4`0301<C01XC0PeD4`00=a<00a0C4`0a4`0301<C02hC00D=4a<C402`4`807A<00`dC4`1A4`00

=Q<00a0C4`0b4`0301<C02lC00D=4a<C402_4`0301<C01dC00<=4a<0D1<003DC00<@4a<0<a<2034C

00D=4a<C402^4`0301<C01hC0Pe@4`00=1<00a0C4`0d4`0301<C030C00<=4a<00Q<00a0C4`2J4`D0

0Q<00`0C4`024`0301<C008C00<04a<081<00`dC4`1=4`00<a<00a0C4`0e4`0301<C034C00<=4a<0

0Q<00a0C4`2K4`0301<C00HC00<04`000a<00`0C4`0Q4`8=CA<0038C00<@4a<0=Q<00`0C4`0a4`03

3A<C008C00<@4a<0Va<00`0C4`084`0401<C4`8091<00`dC4`1:4`00<A<00a0C4`0g4`80<a<00`dC

4`024`0341<C09XC00<04a<01Q<200@C00<04a<091<23DXC000`4`0341<C03PC00<04a<0<a<00`dC

4`024`0341<C09TC00<04a<01Q<00`0C4`034`0301<C02HC0Pe84`00;a<00a0C4`0Y4`<00a<00`0C

4`024`0301<C008C00<04a<0<a<00`dC4`034`0341<C09LC0P084`<00a<00`0C4`0X4`8=AQ<002hC

00<@4a<0:Q<00`0C4`074`0301<000<C00<04a<0=1<00`dC4`034`0341<C0:HC0P0[4`8=A1<002dC

00<@4a<0;1<00`0C4`084`0401<C4`80=Q<00`dC4`034`0341<C0:DC00<04a<0;1<00`dC4`114`00

;1<00a0C4`0]4`0301<C00HC0P044`0301<C03DC00<=4a<011<00a0C4`2T4`0301<C02dC0Pe14`00

:a<00a0C4`0]4`0301<000LC00<04a<00a<00`0C4`0f4`033A<C00@C00<@4a<0Xa<00`0C4`0_4`03

3A<C03hC000Z4`0341<C02lC00<04a<01Q<300<C00<04a<0=a<00`dC4`044`0341<C0:8C00<04a<0

<1<23ChC000Y4`0341<C03lC0P0h4`033A<C00DC00<@4a<0XA<203<C0Pdl4`00:1<00a0C4`104`03

01<C03PC00<=4a<01A<00a0C4`2P4`0301<C03@C0Pdj4`009a<00a0C4`114`0301<C03TC00<=4a<0

1A<00a0C4`2O4`0301<C03HC0Pdh4`009Q<00a0C4`124`0301<C03XC00<=4a<01A<00a0C4`2N4`03

01<C03PC0Pdf4`009A<00a0C4`134`80>a<00`dC4`064`0341<C09dC0P0k4`8==1<002@C00<@4a<0

A1<00`0C4`0k4`033A<C00HC00<@4a<0W1<00`0C4`0l4`8=<Q<002<C00<@4a<0AA<00`0C4`0l4`03

3A<C00HC00<@4a<0Va<00`0C4`0n4`8=<1<002<C00<@4a<0AA<00`0C4`0l4`033A<C00LC00<@4a<0

VQ<00`0C4`104`8=;Q<0028C00<@4a<0AQ<203hC00<=4a<01a<00a0C4`2I4`0301<C048C0Pd/4`00

8A<00a0C4`174`0301<C03hC00<=4a<01a<00a0C4`2H4`80AA<23BXC000P4`0341<C04PC00<04a<0

?Q<00`dC4`084`0341<C09LC00<04a<0AQ<23BPC000O4`0341<C04TC00<04a<0?a<00`dC4`084`03

41<C09HC00<04a<0B1<23BHC000N4`0341<C04XC0P114`033A<C00PC00<@4a<0Sa<300<C00<04a<0

BQ<23B@C000M4`0341<C04/C00<04a<0@1<00`dC4`094`0341<C08hC00<04a<00a<00`0C4`1<4`8=

8Q<001`C00<@4a<0C1<00`0C4`114`033A<C00TC00<@4a<0SQ<00`0C4`024`80Ca<33AlC000K4`03

41<C04LC0P044`0301<C048C00<=4a<02A<00a0C4`2=4`0301<C008C00<04a<0DA<33A`C000J4`03

41<C04XC00D04a<C00144`033A<C00XC00<@4a<0Ra<00`0C00034`0301<C05@C0PdJ4`006A<00a0C

4`1:4`0301<C008C0P144`033A<C00TC00<@4a<0S1<00`0C4`024`0301<C05HC0PdH4`00Ia<00`0C

4`3W4`80FA<23AHC001U4`0301<00>TC00<04a<0L1<006HC00<04a<0j1<00`0C4`1`4`00:Q<30?lC

9A<00`0C4`1`4`00:Q<00`0C4`3o4bDC00<04a<0L1<002/C00<04a<011<00`0C4`3o4i0C000[4`04

01<C4`@00a<30?lCS1<002XC00<04`000Q<200034`0C00@C00<04a<0oa>:4`00:a<00`0C4`034`03

01<000<C00<04a<0oa>;4`00<A<00`0C00044`0301<C00HC00<04a<09a<302/C00<04a<0oa<Y4`00

6a<300034`00008031<300@C0`084`0301<C02HC00@04a<03a<300034`0000800Q<00`0C4`024`03

01<C008C00<04a<01A<0100C4a<5008C00<04a<00Q<300034`0000@C00<04a<011<20<DC00<04a<0

=a<00`0C4`064`006Q<0100C4`0T4`0301<C02DC00@04a<03Q<0100C4`064`0301<000LC00<04`00

11<500<C00<04a<021<01P0C4`0C008C00<04`0011<00`0C4`2m4`0301<C00@C00<04a<04a<00`0C

4`0S4`0301<C00DC000J4`0501<C01<010000a<0000H02dC0`0>4`0501<C01<0100011<04`094`03

01<C00@C00<04a<00a<00`0C4`064`@000@C01<011<00`0C4`024`0301<C0:/C00@04a<C10024`80

1Q<00`0C4`034`0301<C008C00<04a<00Q<00`0C4`024`0301<C00DC00@04a<C1@024`0301<C008C

0`000a<000044`0301<C00@C0P044`0401<C4`800A<001/C0`1?4`0301<C00dC0`064`0301<000LC

0P074`0301<C00<C00<04a<01Q<00`0C00024`800a<200DC00<04a<0ZQ<00`0C00074`0301<C00@C

1@034`0701<C4`0C00074`0301<000@C1@034`0301<C00PC00H04a<04`024`0301<000@C00<04a<0

11<00`0C4`024`400A<001dC00<04a<0C1<2014C00<04a<011<00`0C00074`0301<C00`C00<04a<0

1a<2008C00<04a<00Q<00`0C4`044`0301<00:XC00<04`000Q<400034`0C00LC00<04a<00a<01`0C

4a<04`002A<00`0C4`044`0301<C00<C00<04a<01Q<400044`0C00@C00<04a<00Q<00`0C4`044`03

01<C00<C0@0001`C0P1P4`801a<00`0C4`064`<02a<200XC00@04a<C0P024`<011<309<C0P000a<0

000B4`0301<000LC00<04a<01Q<00`0C4`034`0701<C4`0C00074`801a<00`0C4`034`0301<C00HC

00<04`000Q<200<C0P054`0301<C00@C00<04a<00a<10000oa=A4`0301<001<C00<04`001a<00`0C

000=4`0601<C01<01a<00`0C4`0<4`0301<C00LC0P024`0301<C008C00<04a<011<00`0C00034`03

01<C00<C0@014`009Q<200HC0P3o4b8C00<04a<04a<00`0C4`064`<03Q<0100C4`084`<02a<200XC

00@04a<C0P024`<011<3008C00<04a<00a<2004C000X4`0301<C008C00<04a<0oa<R4`0301<C070C

000W4`0301<C00<C00<04a<01Q<00`0C4`3o4aPC00<04`00LA<002PC00<04a<00Q<00`0C4`024`<0

00@C01<C0`3o4a@C0P000a<0001`4`009Q<00`0C00044`0301<0008C0P024`0301<C008C00<04a<0

oa>74`009a<00`0C4`034`<011<0100C4`024`0301<C0?lCR1<003@C00@04a<00a<00`0C4`3o4hLC

000b4`<011<30?lCRA<00?lCaA<00?lCaA<00?lCaA<00?lCaA<00?lCaA<00001\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.36341, -1.70449, 0.0218115, 0.0218115}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -82 0 ]

[.5 .96488 82 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -143 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.46) show

217.250000 19.500000 moveto

(C) show

222.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.25538 0 m

.26171 .00924 L

.30316 .06975 L

.34309 .12805 L

.3815 .18413 L

.42237 .2438 L

.46172 .30125 L

.49955 .35649 L

.53984 .41531 L

.57861 .47192 L

.61984 .5321 L

.65954 .59008 L

.69774 .64584 L

.73838 .70518 L

.77751 .76231 L

.81909 .82302 L

.85916 .88152 L

.89771 .9378 L

s

.89771 .9378 m

.9077 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.358357 0.238095 [

[.02381 .34586 -6 -9 ]

[.02381 .34586 6 0 ]

[.2619 .34586 -6 -9 ]

[.2619 .34586 6 0 ]

[.7381 .34586 -3 -9 ]

[.7381 .34586 3 0 ]

[.97619 .34586 -3 -9 ]

[.97619 .34586 3 0 ]

[1.025 .35836 0 -8 ]

[1.025 .35836 9 8 ]

[.4875 .00121 -24 -4.5 ]

[.4875 .00121 0 4.5 ]

[.4875 .12026 -12 -4.5 ]

[.4875 .12026 0 4.5 ]

[.4875 .23931 -24 -4.5 ]

[.4875 .23931 0 4.5 ]

[.4875 .4774 -18 -4.5 ]

[.4875 .4774 0 4.5 ]

[.4875 .59645 -6 -4.5 ]

[.4875 .59645 0 4.5 ]

[.4875 .7155 -18 -4.5 ]

[.4875 .7155 0 4.5 ]

[.4875 .83455 -6 -4.5 ]

[.4875 .83455 0 4.5 ]

[.5 .90232 -4.5 0 ]

[.5 .90232 4.5 16 ]

[.5 .88982 -134.5 0 ]

[.5 .88982 134.5 16 ]

[ 0 0 0 0 ]

[ 1 .87732 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .35836 m

.02381 .36461 L

s

[(-2)] .02381 .34586 0 1 Mshowa

.2619 .35836 m

.2619 .36461 L

s

[(-1)] .2619 .34586 0 1 Mshowa

.7381 .35836 m

.7381 .36461 L

s

[(1)] .7381 .34586 0 1 Mshowa

.97619 .35836 m

.97619 .36461 L

s

[(2)] .97619 .34586 0 1 Mshowa

.125 Mabswid

.07143 .35836 m

.07143 .36211 L

s

.11905 .35836 m

.11905 .36211 L

s

.16667 .35836 m

.16667 .36211 L

s

.21429 .35836 m

.21429 .36211 L

s

.30952 .35836 m

.30952 .36211 L

s

.35714 .35836 m

.35714 .36211 L

s

.40476 .35836 m

.40476 .36211 L

s

.45238 .35836 m

.45238 .36211 L

s

.54762 .35836 m

.54762 .36211 L

s

.59524 .35836 m

.59524 .36211 L

s

.64286 .35836 m

.64286 .36211 L

s

.69048 .35836 m

.69048 .36211 L

s

.78571 .35836 m

.78571 .36211 L

s

.83333 .35836 m

.83333 .36211 L

s

.88095 .35836 m

.88095 .36211 L

s

.92857 .35836 m

.92857 .36211 L

s

.25 Mabswid

0 .35836 m

1 .35836 L

s

gsave

1.025 .35836 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .00121 m

.50625 .00121 L

s

[(-1.5)] .4875 .00121 1 0 Mshowa

.5 .12026 m

.50625 .12026 L

s

[(-1)] .4875 .12026 1 0 Mshowa

.5 .23931 m

.50625 .23931 L

s

[(-0.5)] .4875 .23931 1 0 Mshowa

.5 .4774 m

.50625 .4774 L

s

[(0.5)] .4875 .4774 1 0 Mshowa

.5 .59645 m

.50625 .59645 L

s

[(1)] .4875 .59645 1 0 Mshowa

.5 .7155 m

.50625 .7155 L

s

[(1.5)] .4875 .7155 1 0 Mshowa

.5 .83455 m

.50625 .83455 L

s

[(2)] .4875 .83455 1 0 Mshowa

.125 Mabswid

.5 .02502 m

.50375 .02502 L

s

.5 .04883 m

.50375 .04883 L

s

.5 .07264 m

.50375 .07264 L

s

.5 .09645 m

.50375 .09645 L

s

.5 .14407 m

.50375 .14407 L

s

.5 .16788 m

.50375 .16788 L

s

.5 .19169 m

.50375 .19169 L

s

.5 .2155 m

.50375 .2155 L

s

.5 .26312 m

.50375 .26312 L

s

.5 .28693 m

.50375 .28693 L

s

.5 .31074 m

.50375 .31074 L

s

.5 .33455 m

.50375 .33455 L

s

.5 .38217 m

.50375 .38217 L

s

.5 .40598 m

.50375 .40598 L

s

.5 .42979 m

.50375 .42979 L

s

.5 .4536 m

.50375 .4536 L

s

.5 .50121 m

.50375 .50121 L

s

.5 .52502 m

.50375 .52502 L

s

.5 .54883 m

.50375 .54883 L

s

.5 .57264 m

.50375 .57264 L

s

.5 .62026 m

.50375 .62026 L

s

.5 .64407 m

.50375 .64407 L

s

.5 .66788 m

.50375 .66788 L

s

.5 .69169 m

.50375 .69169 L

s

.5 .73931 m

.50375 .73931 L

s

.5 .76312 m

.50375 .76312 L

s

.5 .78693 m

.50375 .78693 L

s

.5 .81074 m

.50375 .81074 L

s

.5 .85836 m

.50375 .85836 L

s

.25 Mabswid

.5 0 m

.5 .87732 L

s

gsave

.5 .90232 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .88982 -195.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.46) show

293.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

298.000000 15.000000 moveto

(L) show

305.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

312.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

319.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

324.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

328.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .87732 L

0 .87732 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .19397 m

.02576 .19396 L

.03157 .19395 L

.04114 .19393 L

.05431 .1939 L

.07086 .19386 L

.0905 .19381 L

.11289 .19375 L

.13765 .19368 L

.16436 .19359 L

.19257 .19349 L

.22178 .19336 L

.25149 .19322 L

.28121 .19306 L

.31042 .19287 L

.33863 .19266 L

.36534 .19241 L

.3901 .19215 L

.41249 .19186 L

.43213 .19157 L

.44868 .19127 L

.46185 .19101 L

.47142 .19079 L

.47723 .19065 L

.47918 .1906 L

s

.47918 .1906 m

.48131 .19054 L

.48765 .19037 L

.4981 .19006 L

.51247 .18956 L

.53053 .1888 L

.55197 .1876 L

.5764 .18566 L

.60343 .18231 L

.63259 .17627 L

.66337 .1661 L

.69525 .15203 L

.72769 .13599 L

.76012 .1196 L

.792 .10371 L

.82278 .08878 L

.85194 .07505 L

.87897 .06269 L

.9034 .0518 L

.92484 .04247 L

.9429 .03476 L

.95727 .02872 L

.96772 .02438 L

.97406 .02176 L

.97619 .02089 L

s

.47918 .44218 m

.48131 .41534 L

.48765 .38863 L

.4981 .36226 L

.51247 .3364 L

.53053 .31124 L

.55197 .28708 L

.5764 .26433 L

.60343 .24376 L

.63259 .22677 L

.66337 .21488 L

.69525 .20797 L

.72769 .2042 L

.76012 .20203 L

.792 .20069 L

.82278 .19981 L

.85194 .1992 L

.87897 .19876 L

.9034 .19844 L

.92484 .1982 L

.9429 .19803 L

.95727 .1979 L

.96772 .19782 L

.97406 .19777 L

.97619 .19775 L

s

.47918 .44229 m

.48131 .46919 L

.48765 .49607 L

.4981 .52275 L

.51247 .54911 L

.53053 .57503 L

.55197 .60039 L

.5764 .62508 L

.60343 .649 L

.63259 .67204 L

.66337 .69409 L

.69525 .71507 L

.72769 .73488 L

.76012 .75344 L

.792 .77067 L

.82278 .78648 L

.85194 .80082 L

.87897 .81362 L

.9034 .82483 L

.92484 .8344 L

.9429 .84229 L

.95727 .84845 L

.96772 .85288 L

.97406 .85554 L

.97619 .85643 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCaA<00?lCaA<006@C1@3G4`D00Q<00`0C4`024`0301<C07DC001V4`0301<C0=TC00<04a<0

1Q<00`0C001f4`00@A<00`dC4`0L4`<00a<00`0C4`024`80ca<300<C00<04a<021<0100C4a<2074C

00114`033A<C028C00<04a<00Q<00`0C4`3D4`0301<C00HC0P044`0301<C070C00124`033A<C024C

00<04a<00Q<00`0C4`3D4`0301<C00HC00<04a<00a<00`0C4`1`4`00@a<00`dC4`0O4`8011<00`0C

4`3C4`8021<300<C00<04a<0L1<004<C00<=4a<09A<20>@C00<04a<0F1<23AHC00144`033A<C02@C

00<04a<0ha<205HC0`dH4`00AA<00`dC4`0S4`0301<C0><C00<04a<0Da<23A/C00154`033A<C02<C

00<04a<0ha<00`0C4`1A4`8=7A<004HC00<=4a<08Q<20>@C00<04a<0Ca<23AlC00174`033A<C024C

00<04a<0ha<204hC0PdQ4`00B1<00`dC4`0P4`0301<C0><C00<04a<0BQ<33B<C00184`033A<C020C

00<04a<0ha<00`0C4`184`8=9Q<004TC00<=4a<07a<20>@C00<04a<0AA<33BPC001:4`033A<C01hC

00<04a<0ha<00`0C4`134`8=:a<004XC00<=4a<07Q<00`0C4`3S4`80@Q<23BdC001;4`033A<C01dC

00<04a<0ha<00`0C4`0o4`8=;a<004`C00<=4a<071<20>@C00<04a<0?A<23C4C001<4`033A<C01`C

00<04a<0ha<00`0C4`0k4`8=<a<004dC00<=4a<031<00`0C4`024`0301<C008C00<04a<00Q<00`0C

4`3S4`80>Q<23CDC001>4`033A<C00XC00<04`001a<00`0C00034`0301<C0><C00<04a<0=a<23CLC

001?4`033A<C00@C0`024`0301<000TC00@04a<C0P3T4`0301<C03DC0Pdi4`00Ca<00`dC4`094`03

01<000LC0P044`0301<C0=`C1@024`0301<C03<C0Pdk4`00D1<00`dC4`084`0301<000LC00<04a<0

0a<00`0C4`3N4`0301<C008C00<04a<0<A<23CdC001A4`033A<C00PC00<04a<01Q<300<C00<04a<0

f1<300<C00<04a<00Q<2030C0Pdo4`00DA<00`dC4`0G4`0301<C0=hC00<04a<00Q<00`0C4`0]4`8=

@A<0058C00<=4a<05Q<20=lC00<04a<00Q<00`0C4`0[4`8=@a<005<C00<=4a<05A<00`0C4`3M4`80

11<00`0C4`0Y4`8=AA<005<C00<=4a<05A<00`0C4`3S4`0301<C02LC0Pe74`00E1<00`dC4`0D4`03

01<C0><C0P0V4`8=BA<005DC00<=4a<04a<20>@C00<04a<08a<23D/C001F4`033A<C018C00<04a<0

ha<00`0C4`0Q4`8=CA<001XC0`0U4`D03a<00`dC4`0B4`0301<C02@C1@0T4`<0Ta<00`0C4`0O4`8=

Ca<001XC00<04a<09a<00`0C4`0@4`033A<C014C00<04a<09Q<00`0C4`0T4`0301<C09<C0P0M4`<=

DA<001DC0`034`0301<C020C0`034`0301<C014C00<=4a<041<202LC00<04a<09A<00`0C4`2B4`03

01<C01TC0`eD4`006a<00`0C4`0V4`0301<C014C00<=4a<041<00`0C4`0V4`0301<C02DC00<04a<0

TQ<00`0C4`0E4`@=Ea<001XC00<04`009a<00`0C4`0B4`033A<C00lC00<04a<09Q<00`0C4`0T4`03

01<009<C00<04a<03a<63E/C000K4`0301<C02DC0P0E4`033A<C00hC00<04a<09A<202LC00<04a<0

TQ<B3F4C001J4`033A<C00hC0P284e`=0P1a4`00Fa<00`dC4`0=4`0301<C0><C00<04a<0<a<W3AHC

001L4`033A<C00`C00<04a<0Fa<208HC00<04a<09a<<3CdC001M4`033A<C00/C00<04a<0FQ<00`0C

4`264`0301<C024C1Pe94`005A=800033@0006801Q<00`0C4`264`807Q<43DlC000I4`0301<C00HC

00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<0100C

4`d44`0301<C00DC00<@4a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00DC

00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`084`0301<C08HC00<04a<06a<23E<C

001O4`033A<C00TC00<@4a<0FQ<00`0C00264`0301<C01TC0PeE4`00Ga<00`dC4`094`8@Fa<307LC

00<04a<00Q<00`0C4`024`0301<C008C00<04a<05a<23ELC001P4`033A<C00PC0Q3D4`0301<000LC

00<04`000a<00`0C4`0E4`8=FA<0064C00<=4a<01Q<00a00403?4`<00Q<00`0C00094`0401<C4`80

51<23E/C001Q4`033A<C00HC00<@0100e1<00`0C00074`8011<00`0C4`0A4`8=GA<0068C00<=4a<0

1A<00a00403D4`0301<000LC00<04a<00a<00`0C4`0@4`033A<C05dC001S4`033A<C00<C00D@4`00

403D4`0301<C00HC0`034`0301<C00hC0PeP4`00I1<00`dC4`024`0541<04a00ha<00`0C4`0=4`03

3A<C060C001T4`033A<C008C00D@4`0C403S4`803A<00`dC4`1Q4`00IA<01`dC4a<@4`000Q<00a0C

4`3P4`0301<C00/C00<=4a<0HQ<006HC00D=4a<@4`0200034a0C0>4C00<04a<02A<23FDC001V4`06

3A<C41<00Q<00a0C4`3P4`0301<C00PC00<=4a<0IA<006LC00D=41<C00034`0341<C0=lC0P084`03

3A<C06HC001X4`043A<C00<C00<@4a<0ga<00`0C4`064`033A<C06LC001X4`033A<C00800Q<00a0C

4`3O4`0301<C00DC00<=4a<0J1<006LC00D@4`dC00044`0341<C08<C0`0Z4`D0:A<00`0C4`054`03

3A<C020C1@0Z4`<05Q<005`C00<04a<00Q<00`0C4`024`06010C4`d011<00a0C4`234`0301<C02`C

00<04a<0:A<00`0C4`044`033A<C02<C00<04a<0:Q<00`0C4`0F4`00Fa<00`0C00074`030100008C

00<=01<00a<00a0C4`1n4`<00a<00`0C4`0U4`<00a<00`0C4`0Y4`8011<00`dC4`0T4`0301<C02/C

00<04a<05A<005/C00<04`0021<00a004`024`033@0C00<C00<@4a<0Pa<00`0C4`0[4`0301<C02TC

00<04a<00Q<00`dC4`0U4`0301<C02/C00<04a<05A<005/C00<04`001a<00`0@4`034`0300dC00<C

00<@4a<0PQ<00`0C000/4`0301<C02TC00D04a<C3@0X4`0301<C02XC00<04`005Q<005/C00<04`00

1a<00a0C4`034`0300dC00@C00<@4a<0PQ<00`0C4`0Z4`80:a<01@0C4a<=02LC0P0]4`0301<C01DC

001L4`0301<C00HC00<@00000a<00`0C3@044`0341<C0=`C0P000a<=4`1^4`00I1<00a0C4`044`80

00<C3A<00Q<00a0C4`3L4`0301<=070C001T4`0341<C00@C00@04a<=11<00a0C4`3K4`0301<=070C

001S4`0341<C00DC00D04a<C3@034`0341<C0=/C00<03A<0IQ<200PC001S4`0341<C00DC00<04a<0

0Q<01@dC4a<@0=`C00<03A<0IA<00`0C4`084`00HQ<00a0C4`064`0301<C00<C00@=4a<@O1=P0003

3@0005h01a<00`0C4`084`00HQ<00a0C4`064`8011<01@dC4a<@07lC00<04a<01a<00`0C4`064`03

01<C00HC00<04a<01Q<00`0C4`064`0301<C00HC00<04a<01a<00`0C4`064`0301<C00HC00<04a<0

1Q<00`dC4`064`0301<C00HC00<04a<01a<00`0C4`064`0301<C00HC00<04a<01Q<00`0C4`064`03

01<C00HC00<04a<01a<00`0C4`064`0301<C00TC00<04a<021<0064C00<@4a<01a<00`0C4`044`04

3A<C4=/C00<=4a<0IA<00`0C00084`00HA<00a0C4`074`0301<C00DC00<=4a00fQ<00`d04`1V4`<0

21<0060C00<@4a<021<00`0C4`054`043A<C4=TC00<=0000LA<0060C00<@4a<021<200LC00<=4a00

f1<00`dC001b4`00Ga<00a0C4`094`0301<C00LC00<=4a00ea<00`dC001b4`00Ga<00a0C4`094`03

01<C00LC00<=4a00ea<00`dC001b4`00GQ<00a0C4`0:4`0301<C00PC00<=4a00eA<010dC4`1b4`00

GQ<00a0C4`0:4`802Q<00`d@4`3D4`033A<C0080LA<005dC00<@4a<02a<00`0C4`0:4`033A0C0=8C

00D=4a<C001b4`00GA<00a0C4`044`D00Q<00`0C4`0:4`033A0C0=8C00D=4a<C001b4`00G1<00a0C

4`074`0301<C008C00<04a<02a<00`d@4`3A4`053A<C4`00LQ<005/C00<@4a<021<00`0C4`024`80

3A<00`d@4`3@4`053A<C4`00LQ<005/C00<@4a<021<00`0C4`024`0301<C00`C00<=41<0d1<010dC

4a<2074C001J4`0341<C00TC00<04a<00Q<00`0C4`0=4`033A0C0<lC00D=4a<C001b4`00FQ<00a0C

4`084`8011<00`0C4`0>4`033A0C0<hC00D=4a<C001b4`00FA<00a0C4`0?4`803a<00`d@4`3>4`05

3A<C4`00LQ<005PC00<@4a<041<00`0C4`0?4`033A0C0<dC00@=4a<C0P1a4`00F1<00a0C4`0@4`03

01<C010C00<=41<0c1<01@dC4a<0078C001G4`0341<C014C00<04a<04A<00`dC4`3;4`053A<C4`00

LQ<005HC00<@4a<04Q<2018C00<=41<0`1<00`0C4`024`0301<C008C00<03A<00Q<00`0C4`1`4`00

EQ<00a0C4`0B4`0301<C018C00<=41<0_Q<00`0C00074`0301<=00<C00<04a<0L1<005DC00<@4a<0

4a<00`0C4`0C4`033A<C0;dC00<04`002A<0100=4a<2074C001D4`0341<C01@C00<04a<04a<00`d@

4`2m4`0301<000LC0P001A<=4a<0078C001C4`0341<C01DC0P0E4`033A<C0;`C00<04`001a<01`0C

4a<=4`00LQ<005<C00<@4a<05A<00`0C4`0E4`033A<C0;`C00<04a<01Q<300044`dC078C001B4`03

41<C01HC00<04a<05A<00`d@4`394`043A<0074C001A4`0341<C01LC00<04a<05Q<00`dC4`394`03

3@0C074C001A4`0341<C01LC0P0H4`033A<C0<PC00<=01<0LA<0050C00<@4a<061<00`0C4`0G4`03

40dC0<PC00<=01<0LA<004lC00<@4a<021<5008C00<04a<00Q<00`0C4`024`0301<C01PC00<=4a<0

b1<00`dC4`1`4`00Ca<00a0C4`0:4`0301<C00HC00<04`000a<00`0C4`0I4`033A<C0<LC00<=01<0

L1<004hC00<@4a<02a<00`0C4`084`0401<C4`806a<00`dC4`364`033A<C070C001=4`0341<C00`C

00<04a<01Q<200@C00<04a<06Q<00`dC4`364`0300dC070C001<4`0341<C00dC00<04a<01Q<00`0C

4`034`0301<C01/C00<=4a<0aA<00`0=4`1`4`00C1<00a0C4`0<4`8021<300<C00<04a<06a<00`d@

4`354`0301<=070C001;4`0341<C01dC0P0M4`033A0C0<@C0P000`dC4`1^4`00BQ<00a0C4`0N4`03

01<C01dC00<=4a<0`a<0100C4`e_4`00BQ<00a0C4`0N4`0301<C01dC00<=41<0`a<01@0C4a<=06hC

00194`0341<C01lC00<04a<07Q<00`d@4`324`0501<C4`d0KQ<004PC00<@4a<081<201lC00<=4a00

`Q<200<C00<=4a<0Ja<004LC00<@4a<08A<00`0C4`0O4`033A<@0<4C00<04a<00a<00`dC4`1Z4`00

Aa<00a0C4`0Q4`0301<C020C00<=41<0`1<00`0C4`044`033A<C06TC00164`0341<C028C00<04a<0

81<00`dC402i4`D00Q<00`0C4`054`033A<C06PC00154`0341<C02<C0P0R4`033A<@0;XC00<04a<0

0Q<00`0C4`054`033A<C06PC00144`0341<C02@C00<04a<08Q<00`dC402i4`0301<C008C0P074`03

3A<C06LC00144`0341<C02@C00<04a<08Q<00`dC402i4`0301<C008C00<04a<01a<00`dC4`1V4`00

@a<00a0C4`0U4`0301<C02<C00<=4a00^1<00`0C4`024`0301<C00PC00<=4a<0IA<0048C00<@4a<0

9Q<00`0C4`0T4`033A<@0;HC0P044`0301<C00TC0PeU4`00@A<00a0C4`0W4`809Q<00`dC402k4`80

31<00`dC4`1R4`00@1<00a0C4`0X4`0301<C02DC00@=4a<@^Q<00`0C4`0<4`033A<C064C00104`03

41<C028C0`034`0301<C02HC00@=4a<@^A<00`0C4`0=4`033A<C060C000o4`0341<C02<C00<04a<0

0a<00`0C4`0W4`033A<@0;TC00<04a<03Q<00`dC4`1O4`00?Q<00a0C4`0U4`0301<C008C0P0X4`04

3A<C4;PC00<04a<03a<00`dC4`1N4`00?A<00a0C4`0V4`0301<C008C00<04a<0:1<010dC4a2g4`80

4A<00`dC4`1M4`00?A<00a0C4`0U4`0301<000<C00<04a<0:A<010dC4a2f4`0301<C014C00<=4a<0

G1<003`C00<@4a<09a<00`0C4`024`0301<C02TC00D=4a<C402e4`0301<C018C0PeL4`00>a<00a0C

4`0]4`80:a<01@dC4a<@0;@C00<04a<051<00`dC4`1I4`00>Q<00a0C4`0^4`0301<C02/C00@=4a<@

]1<00`0C4`0E4`8=FA<003XC00<@4a<0;Q<00`0C4`0/4`043A<C4;<C0P0H4`033A<C05HC000i4`03

41<C02lC00<04a<0;1<01@dC4a<@0;8C00<04a<061<00`dC4`1E4`00>1<00a0C4`0`4`80;Q<01@dC

4a<@0;4C00<04a<06A<00`dC4`1D4`00=a<00a0C4`0a4`0301<C02hC00@=4a<@/A<00`0C4`0J4`8=

E1<003LC00<@4a<0<A<00`0C4`0^4`053A<C4a00/1<201dC00<=4a<0DA<003HC00<@4a<0<Q<00`0C

4`0_4`053A<C4a00[a<00`0C4`0M4`033A<C050C000e4`0341<C03<C0P0a4`053A<C4a00[Q<00`0C

4`0N4`8=D1<003@C00<@4a<0=1<00`0C4`0`4`033A<C008C00<@4a<0VQ<5008C00<04a<00Q<00`0C

4`024`0301<C020C00<=4a<0CA<003<C00<@4a<0=A<00`0C4`0a4`033A<C008C00<@4a<0Va<00`0C

4`064`0301<000<C00<04a<08A<23DdC000b4`0341<C03HC00<04a<0<Q<01@dC4a<@09dC00<04a<0

21<0100C4a<202@C00<=4a<0BQ<0034C00<@4a<0=a<203@C00D=4a<C402L4`0301<C00HC0P044`03

01<C02@C0Pe:4`00<1<00a0C4`0h4`0301<C03<C00<=4a<00Q<00a0C4`2I4`0301<C00HC00<04a<0

0a<00`0C4`0V4`8=B1<002lC00<@4a<0:A<300<C00<04a<00Q<00`0C4`024`0301<C03@C00<=4a<0

0Q<00a0C4`2G4`8021<300<C00<04a<0:1<23DHC000^4`0341<C02XC00<04a<01a<00`0C00034`03

01<C03DC00<=4a<00Q<00a0C4`2V4`80:a<23D@C000]4`0341<C02`C00<04a<021<0100C4a<203HC

00<=4a<00a<00a0C4`2U4`0301<C02`C00<=4a<0@A<002`C00<@4a<0;A<00`0C4`064`8011<00`0C

4`0f4`033A<C00<C00<@4a<0Y1<00`0C4`0]4`8=@A<002/C00<@4a<0;A<00`0C00074`0301<C00<C

00<04a<0=a<00`dC4`034`0341<C0:<C00<04a<0;a<00`dC4`0n4`00:Q<00a0C4`0_4`0301<C00HC

0`034`0301<C03LC00<=4a<011<00a0C4`2R4`0301<C030C0Pdn4`00:A<00a0C4`0o4`80>A<00`dC

4`044`0341<C0:4C0P0c4`8=?1<002PC00<@4a<0@1<00`0C4`0i4`033A<C00@C00<@4a<0X1<00`0C

4`0d4`8=>Q<002LC00<@4a<0@A<00`0C4`0j4`033A<C00@C00<@4a<0Wa<00`0C4`0f4`8=>1<002HC

00<@4a<0@Q<00`0C4`0j4`033A<C00DC00<@4a<0WQ<00`0C4`0h4`8==Q<002DC00<@4a<0@a<203`C

00<=4a<01A<00a0C4`2M4`80>a<23C@C000T4`0341<C04@C00<04a<0?1<00`dC4`054`0341<C09`C

00<04a<0?1<23C8C000S4`0341<C04DC00<04a<0?1<00`dC4`064`0341<C09/C00<04a<0?Q<23C0C

000S4`0341<C04DC00<04a<0?A<00`dC4`064`0341<C09XC00<04a<0@1<23BhC000R4`0341<C04HC

0P0n4`033A<C00LC00<@4a<0VA<00`0C4`124`8=;1<0024C00<@4a<0Aa<00`0C4`0n4`033A<C00LC

00<@4a<0V1<204DC0PdZ4`0081<00a0C4`184`0301<C03lC00<=4a<01a<00a0C4`2G4`0301<C04HC

0PdX4`007a<00a0C4`194`0301<C03lC00<=4a<021<00a0C4`2F4`0301<C04PC0PdV4`007Q<00a0C

4`1:4`80@A<00`dC4`084`0341<C08lC0`034`0301<C04XC0PdT4`007A<00a0C4`1;4`0301<C040C

00<=4a<02A<00a0C4`2>4`0301<C00<C00<04a<0C1<23B8C000L4`0341<C04`C00<04a<0@A<00`dC

4`094`0341<C08hC00<04a<00Q<204lC0`dO4`006a<00a0C4`174`8011<00`0C4`124`033A<C00TC

00<@4a<0SA<00`0C4`024`0301<C054C0`dL4`006Q<00a0C4`1:4`0501<C4`00A1<00`dC4`0:4`03

41<C08/C00<04`000a<00`0C4`1D4`8=6Q<001TC00<@4a<0BQ<00`0C4`024`80A1<00`dC4`094`03

41<C08`C00<04a<00Q<00`0C4`1F4`8=61<006LC00<04a<0ia<205TC0PdF4`00IA<00`0C003Y4`03

01<C070C001V4`0301<C0>PC00<04a<0L1<002`C0`3o4b<C00<04a<0L1<002`C00<04a<0oa<S4`03

01<C070C000]4`0301<C00DC00<04a<0oa>=4`00;A<0100C4a<300044`0C4`<0oa>:4`00;1<00`0C

00024`800Q<00`0C4`024`0301<C0?lCR1<002dC00<04a<00a<0100C4`024`0301<C0?lCRA<003<C

00@04a<00a<00`0C4`064`0301<C02DC0`0]4`0301<C0?lC9a<001dC0`000a<0000200`C0`044`<0

21<00`0C4`0T4`0401<C014C0`000a<00002008C00<04a<00Q<00`0C4`024`0301<C00DC00@04a<C

1@024`0301<C008C0`000a<000064`80ba<00`0C4`0b4`0301<C00PC000L4`0401<C02@C00<04a<0

8a<0100C4`0@4`0401<C00HC00<04`001a<00`0C00044`D00a<00`0C4`084`0601<C01<011<00`0C

4`334`0301<C00@C00<04a<04a<00`0C4`0N4`0301<C00LC000L4`0501<C01<010000a<0000H02/C

0`0@4`0501<C01<0100011<04`094`0301<C00@C00<04a<00a<00`0C4`064`@000@C01<011<00`0C

4`2a4`0401<C4`@00Q<200HC00<04a<00a<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`054`04

01<C4`D00Q<00`0C4`024`<000<C00001Q<200@C00@04a<C0P014`400@0001dC0`1=4`0301<C00lC

0`064`0301<000LC0P074`0301<C00<C00<04a<01Q<00`0C00024`801A<00`0C4`2`4`0301<000LC

00<04a<011<500<C00L04a<C01<000LC00<04`0011<500<C00<04a<021<01P0C4`0C00@C00<04a<0

11<00`0C4`024`0301<0004C000O4`0301<C04XC0P0C4`0301<C00@C00<04`001a<00`0C4`0<4`03

01<C00LC0P024`0301<C00@C00<04`00/1<00`0C00024`@000<C01<01a<00`0C4`034`0701<C4`0C

00094`0301<C00@C00<04a<00a<00`0C4`064`@000@C01<011<00`0C4`044`0301<C00<C0@014`4C

000N4`80H1<200LC00<04a<01Q<300/C0P0:4`0401<C4`8011<309HC0P000a<0000E4`0301<000LC

00<04a<01Q<00`0C4`034`0701<C4`0C00074`801a<00`0C4`034`0301<C00HC00<04`000Q<200DC

00<04a<011<00`0C4`034`400A<14`00oa=A4`0301<001HC00<04`001a<00`0C000=4`0601<C01<0

1a<00`0C4`0<4`0301<C00LC0P024`0301<C00@C00<04`000a<00`0C4`034`0301<0004C000Y4`80

1Q<20?lC7a<00`0C4`0F4`0301<C00HC0`0>4`0401<C00PC0`0;4`802Q<0100C4a<200@C0`024`03

01<C00<C0P014`400@0002/C00<04a<00Q<00`0C4`3o4alC00<04a<0L1<002XC00<04a<00a<00`0C

4`054`0301<C0?lC5Q<00`0C001a4`00:a<00`0C4`024`0301<C008C10034`<0oa<A4`8000<C0000

L1<002TC00<04`0011<00`0C00024`8000<C01<011<00`0C4`3o4h@C000Z4`0301<C00<C0`044`03

01<000<C00<04a<0oa>54`00=a<00`0C00044`0301<C0?lCQ1<003DC0`044`<0oa>64`00oa?54`00

oa?54`00oa?54`00oa?54`00oa?54`00\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.35892, -1.7044, 0.0217981, 0.0217981}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -84.5 0 ]

[.5 .96488 84.5 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -145.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.455) show

222.250000 19.500000 moveto

(C) show

227.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.25454 0 m

.26171 .01043 L

.30316 .07073 L

.34309 .12883 L

.3815 .18472 L

.42237 .24418 L

.46172 .30144 L

.49955 .35649 L

.53984 .41511 L

.57861 .47152 L

.61984 .5315 L

.65954 .58928 L

.69774 .64485 L

.73838 .70399 L

.77751 .76092 L

.81909 .82143 L

.85916 .87972 L

.89771 .93581 L

s

.89771 .93581 m

.9091 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.357011 0.238095 [

[.02381 .34451 -6 -9 ]

[.02381 .34451 6 0 ]

[.2619 .34451 -6 -9 ]

[.2619 .34451 6 0 ]

[.7381 .34451 -3 -9 ]

[.7381 .34451 3 0 ]

[.97619 .34451 -3 -9 ]

[.97619 .34451 3 0 ]

[1.025 .35701 0 -8 ]

[1.025 .35701 9 8 ]

[.4875 .11892 -12 -4.5 ]

[.4875 .11892 0 4.5 ]

[.4875 .23796 -24 -4.5 ]

[.4875 .23796 0 4.5 ]

[.4875 .47606 -18 -4.5 ]

[.4875 .47606 0 4.5 ]

[.4875 .59511 -6 -4.5 ]

[.4875 .59511 0 4.5 ]

[.4875 .71415 -18 -4.5 ]

[.4875 .71415 0 4.5 ]

[.4875 .8332 -6 -4.5 ]

[.4875 .8332 0 4.5 ]

[.5 .90041 -4.5 0 ]

[.5 .90041 4.5 16 ]

[.5 .88791 -137 0 ]

[.5 .88791 137 16 ]

[ 0 0 0 0 ]

[ 1 .87541 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .35701 m

.02381 .36326 L

s

[(-2)] .02381 .34451 0 1 Mshowa

.2619 .35701 m

.2619 .36326 L

s

[(-1)] .2619 .34451 0 1 Mshowa

.7381 .35701 m

.7381 .36326 L

s

[(1)] .7381 .34451 0 1 Mshowa

.97619 .35701 m

.97619 .36326 L

s

[(2)] .97619 .34451 0 1 Mshowa

.125 Mabswid

.07143 .35701 m

.07143 .36076 L

s

.11905 .35701 m

.11905 .36076 L

s

.16667 .35701 m

.16667 .36076 L

s

.21429 .35701 m

.21429 .36076 L

s

.30952 .35701 m

.30952 .36076 L

s

.35714 .35701 m

.35714 .36076 L

s

.40476 .35701 m

.40476 .36076 L

s

.45238 .35701 m

.45238 .36076 L

s

.54762 .35701 m

.54762 .36076 L

s

.59524 .35701 m

.59524 .36076 L

s

.64286 .35701 m

.64286 .36076 L

s

.69048 .35701 m

.69048 .36076 L

s

.78571 .35701 m

.78571 .36076 L

s

.83333 .35701 m

.83333 .36076 L

s

.88095 .35701 m

.88095 .36076 L

s

.92857 .35701 m

.92857 .36076 L

s

.25 Mabswid

0 .35701 m

1 .35701 L

s

gsave

1.025 .35701 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .11892 m

.50625 .11892 L

s

[(-1)] .4875 .11892 1 0 Mshowa

.5 .23796 m

.50625 .23796 L

s

[(-0.5)] .4875 .23796 1 0 Mshowa

.5 .47606 m

.50625 .47606 L

s

[(0.5)] .4875 .47606 1 0 Mshowa

.5 .59511 m

.50625 .59511 L

s

[(1)] .4875 .59511 1 0 Mshowa

.5 .71415 m

.50625 .71415 L

s

[(1.5)] .4875 .71415 1 0 Mshowa

.5 .8332 m

.50625 .8332 L

s

[(2)] .4875 .8332 1 0 Mshowa

.125 Mabswid

.5 .02368 m

.50375 .02368 L

s

.5 .04749 m

.50375 .04749 L

s

.5 .0713 m

.50375 .0713 L

s

.5 .09511 m

.50375 .09511 L

s

.5 .14273 m

.50375 .14273 L

s

.5 .16653 m

.50375 .16653 L

s

.5 .19034 m

.50375 .19034 L

s

.5 .21415 m

.50375 .21415 L

s

.5 .26177 m

.50375 .26177 L

s

.5 .28558 m

.50375 .28558 L

s

.5 .30939 m

.50375 .30939 L

s

.5 .3332 m

.50375 .3332 L

s

.5 .38082 m

.50375 .38082 L

s

.5 .40463 m

.50375 .40463 L

s

.5 .42844 m

.50375 .42844 L

s

.5 .45225 m

.50375 .45225 L

s

.5 .49987 m

.50375 .49987 L

s

.5 .52368 m

.50375 .52368 L

s

.5 .54749 m

.50375 .54749 L

s

.5 .5713 m

.50375 .5713 L

s

.5 .61892 m

.50375 .61892 L

s

.5 .64273 m

.50375 .64273 L

s

.5 .66653 m

.50375 .66653 L

s

.5 .69034 m

.50375 .69034 L

s

.5 .73796 m

.50375 .73796 L

s

.5 .76177 m

.50375 .76177 L

s

.5 .78558 m

.50375 .78558 L

s

.5 .80939 m

.50375 .80939 L

s

.5 .85701 m

.50375 .85701 L

s

.25 Mabswid

.5 0 m

.5 .87541 L

s

gsave

.5 .90041 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .88791 -198 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.455) show

298.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

303.000000 15.000000 moveto

(L) show

310.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

317.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

324.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

329.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

333.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .87541 L

0 .87541 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .19219 m

.02576 .19219 L

.03157 .19218 L

.04114 .19216 L

.05431 .19213 L

.07086 .1921 L

.09049 .19205 L

.11288 .192 L

.13765 .19193 L

.16436 .19185 L

.19256 .19176 L

.22177 .19165 L

.25148 .19153 L

.2812 .19138 L

.31041 .19121 L

.33861 .19102 L

.36532 .19081 L

.39008 .19057 L

.41247 .19031 L

.43211 .19005 L

.44865 .18979 L

.46182 .18955 L

.4714 .18936 L

.47721 .18923 L

.47916 .18919 L

s

.47916 .18919 m

.48128 .18914 L

.48762 .18898 L

.49807 .18871 L

.51245 .18826 L

.53051 .18758 L

.55194 .18652 L

.57638 .18477 L

.60341 .18173 L

.63257 .1761 L

.66335 .16624 L

.69523 .15225 L

.72767 .13615 L

.76011 .11969 L

.79199 .10375 L

.82278 .08879 L

.85193 .07503 L

.87896 .06266 L

.9034 .05176 L

.92484 .04243 L

.9429 .03472 L

.95727 .02867 L

.96772 .02433 L

.97406 .02172 L

.97619 .02084 L

s

.47916 .44087 m

.48128 .41404 L

.48762 .38733 L

.49807 .36096 L

.51245 .33508 L

.53051 .30987 L

.55194 .28561 L

.57638 .26269 L

.60341 .24186 L

.63257 .22448 L

.66335 .21231 L

.69523 .20536 L

.72767 .20167 L

.76011 .1996 L

.79199 .19834 L

.82278 .19752 L

.85193 .19695 L

.87896 .19654 L

.9034 .19625 L

.92484 .19603 L

.9429 .19587 L

.95727 .19575 L

.96772 .19568 L

.97406 .19563 L

.97619 .19562 L

s

.47916 .44098 m

.48128 .46786 L

.48762 .49471 L

.49807 .52136 L

.51245 .54769 L

.53051 .57358 L

.55194 .59891 L

.57638 .62357 L

.60341 .64745 L

.63257 .67045 L

.66335 .69248 L

.69523 .71343 L

.72767 .73321 L

.76011 .75174 L

.79199 .76894 L

.82278 .78473 L

.85193 .79905 L

.87896 .81183 L

.9034 .82302 L

.92484 .83258 L

.9429 .84045 L

.95727 .84661 L

.96772 .85102 L

.97406 .85368 L

.97619 .85457 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<00`0C4`1`4`00oa=B4`0301<C070C001T4`D0j1<00`0C4`1`4`00IQ<00`0C4`3X4`03

01<C070C00114`033A<C01`C0`034`0301<C008C0P3T4`80Fa<23A@C00114`033A<C028C00<04a<0

0Q<00`0C4`3S4`0301<C05LC0`dF4`00@Q<00`dC4`0Q4`0301<C008C00<04a<0ha<00`0C4`1E4`8=

6A<004<C00<=4a<07a<200@C00<04a<0ha<00`0C4`1C4`8=6a<004<C00<=4a<09A<20>@C00<04a<0

DA<23AdC00144`033A<C02@C00<04a<0ha<2050C0PdO4`00AA<00`dC4`0S4`0301<C0><C00<04a<0

C1<33B4C00154`033A<C02<C00<04a<0ha<00`0C4`1:4`8=91<004HC00<=4a<08Q<20>@C00<04a<0

Aa<33BHC00174`033A<C024C00<04a<0ha<00`0C4`154`8=:A<004PC00<=4a<081<00`0C4`3S4`80

A1<23B/C00184`033A<C020C00<04a<0ha<00`0C4`114`8=;A<004TC00<=4a<07a<20>@C00<04a<0

?a<23BlC001:4`033A<C01hC00<04a<0ha<00`0C4`0m4`8=<A<004XC00<=4a<07Q<00`0C4`3S4`80

?1<23C<C001;4`033A<C01dC00<04a<0ha<00`0C4`0i4`8==A<004`C00<=4a<071<20>@C00<04a<0

=a<23CLC001<4`033A<C01`C00<04a<0g1<5008C00<04a<0=A<23CTC001=4`033A<C00`C00<04a<0

0Q<00`0C4`024`0301<C008C00<04a<0gQ<00`0C4`024`0301<C03<C0Pdk4`00CQ<00`dC4`0:4`03

01<000LC00<04`000a<00`0C4`3H4`<00a<00`0C4`024`80<A<33CdC001?4`033A<C00@C0`024`03

01<000TC00@04a<C0P3O4`0301<C008C00<04a<0;Q<23D0C001?4`033A<C00TC00<04`001a<200@C

00<04a<0gQ<00`0C4`024`0301<C02`C0Pe24`00D1<00`dC4`084`0301<000LC00<04a<00a<00`0C

4`3M4`8011<00`0C4`0Z4`8=A1<0054C00<=4a<021<00`0C4`064`<00a<00`0C4`3S4`0301<C02PC

0Pe64`00DA<00`dC4`0G4`0301<C0><C0P0X4`033A<C04HC001B4`033A<C01HC0P3T4`0301<C02DC

0Pe94`00Da<00`dC4`0E4`0301<C0><C00<04a<08a<23D/C001C4`033A<C01DC00<04a<0ha<00`0C

4`0O4`@=CA<005@C00<=4a<051<00`0C4`3S4`0301<C01`C0`eA4`00EA<00`dC4`0C4`80i1<201XC

0`eD4`00EQ<00`dC4`0B4`0301<C0><C00<04a<05Q<33ELC000J4`<09A<500lC00<=4a<04Q<00`0C

4`0T4`D091<309<C00<04a<051<23EXC000J4`0301<C02LC00<04a<041<00`dC4`0A4`0301<C02HC

00<04a<091<00`0C4`2C4`0301<C00HC3PeL4`005A<300<C00<04a<081<300<C00<04a<04A<00`dC

4`0@4`809a<00`0C4`0U4`0301<C05<CB0eZ4`006a<00`0C4`0V4`0301<C014C00<=4a<041<00`0C

4`0V4`0301<C02DC00<04a<0=1<O3ClC00<04a<0AQ<F3A@C000J4`0301<002LC00<04a<04Q<00`dC

4`0?4`0301<C02HC00<04a<091<00`0C002C4`0301<C02PC7PdZ4`006a<00`0C4`0U4`805A<00`dC

4`0>4`0301<C02DC0P0W4`0301<C098C00<04a<08a<53DPC001J4`033A<C00hC0P3T4`0301<C01lC

10e=4`00Fa<00`dC4`0=4`0301<C0><C0P0M4`<=DA<005`C00<=4a<031<00`0C4`1K4`80QQ<00`0C

4`0I4`<=E1<005dC00<=4a<02a<00`0C4`1J4`0301<C08HC00<04a<05a<23ELC000E4dP000<=0000

HP064`0301<C07LC00<04a<00Q<00`0C4`024`0301<C008C00<04a<05A<23ETC000I4`0301<C00HC

00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<0100C

4`d44`0301<C00DC00<@4a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00DC

00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`084`0301<C07HC00<04`001a<00`0C

00034`0301<C01<C0PeK4`00Ga<00`dC4`094`0341<C05XC00<04`00LA<3008C00<04`002A<0100C

4a<201<C00<=4a<0Fa<005lC00<=4a<02A<245/C0`1f4`0301<000LC0P044`0301<C014C00<=4a<0

G1<0060C00<=4a<021<24=@C00<04`001a<00`0C4`034`0301<C010C00<=4a<0GA<0064C00<=4a<0

1Q<00a00403E4`0301<C00HC0`034`0301<C00hC0PeP4`00HA<00`dC4`064`03400@0>@C0P0>4`03

3A<C060C001R4`033A<C00DC00<@0100i1<00`0C4`0<4`033A<C064C001S4`033A<C00<C00D@4`00

403S4`0301<C00/C00<=4a<0HQ<006@C00<=4a<00Q<01A0C01<@0><C00<04a<02A<23FDC001T4`03

3A<C008C00D@4`0C403S4`0301<C00PC00<=4a<0IA<006DC00L=4a<C41<0008C00<@4a<0h1<200PC

00<=4a<0IQ<006HC00D=4a<@4`0200034a0C0>4C00<04a<01Q<00`dC4`1W4`00IQ<01PdC4a0C008C

00<@4a<0h1<00`0C4`054`033A<C06PC001W4`053A0C4`000a<00a0C4`3O4`0301<C00DC00<=4a<0

J1<006PC00@=4a<00a<00a0C4`224`<0:a<502XC00<04a<011<00`dC4`0S4`D0:a<301<C001X4`03

3A<C00800Q<00a0C4`224`0301<C02dC00<04a<0:Q<200@C00<=4a<09Q<00`0C4`0[4`0301<C01<C

001W4`0541<=4`0011<00a0C4`1l4`<00a<00`0C4`0V4`<00a<00`0C4`0Z4`0301<C008C00<=4a<0

9a<00`0C4`0/4`0301<C018C001L4`0301<C008C00<04a<00Q<01P0@4a<=00@C00<@4a<0PQ<00`0C

4`0/4`0301<C02XC00<04a<00Q<00`dC4`0W4`0301<C02`C00<04a<04Q<005/C00<04`001a<00`0@

00024`033@0C00<C00<@4a<0PA<00`0C000]4`0301<C02XC00D04a<C3@0Z4`0301<C02/C00<04`00

4a<005/C00<04`0021<00a004`024`033@0C00<C00<@4a<0PA<00`0C4`0[4`80;1<2008C00<=4a<0

9a<202hC00<04a<04Q<005/C00<04`001a<00`0@4`034`0300dC00<C00<@4a<0gA<0100C4`e_4`00

Fa<00`0C00074`0341<C00<C00<03A<011<00a0C4`3L4`0301<=070C001L4`0301<C00HC00<@0000

0a<00`0C3@044`0341<C0=`C00<04`d0JA<200DC001T4`0341<C00@C0P000a<=4`024`0341<C0=`C

00<03A<0J1<00`0C4`054`00I1<00a0C4`044`0401<C3@@C00<@4a<0N1=T00033@0006001a<00`0C

4`054`00Ha<00a0C4`054`0501<C4`d00a<00a0C4`1m4`0301<C00HC00<04a<01a<00`0C4`064`03

01<C00LC00<04a<01Q<00`0C4`064`0301<C00LC00<04a<01Q<00`0C4`074`0301<C00HC00<=4a<0

1a<00`0C4`064`0301<C00HC00<04a<01a<00`0C4`064`0301<C00LC00<04a<01Q<00`0C4`064`03

01<C00LC00<04a<01Q<00`0C4`0:4`0301<C00DC001S4`0341<C00DC00<04a<00Q<01@dC4a<@0=`C

00<=4a<0J1<00`0C00054`00HQ<00a0C4`064`0301<C00<C00@=4a<@fa<00`d04`1Y4`<01A<0068C

00<@4a<01Q<200@C00D=4a<C403J4`033@0C074C001Q4`0341<C00LC00<04a<011<010dC4a3I4`04

3A<0074C001Q4`0341<C00LC00<04a<01A<00`dC403I4`033A<0078C001P4`0341<C00PC00<04a<0

1A<010dC4a3H4`033A<0078C001P4`0341<C00PC0P074`033A<@0=LC00@=4a<0LQ<005lC00<@4a<0

2A<00`0C4`074`033A<@0=HC00@=4a<0LQ<005lC00<@4a<02A<00`0C4`074`033A<@0=DC00@=4a<C

0P1a4`00GQ<00a0C4`0:4`0301<C00PC00<=4a00e1<01@dC4a<0078C001N4`0341<C00XC0P0:4`03

3A0C0=<C00D=4a<C001b4`00GA<00a0C4`0;4`0301<C00XC00<=41<0dQ<01@dC4a<0078C001M4`03

41<C00@C1@024`0301<C00XC00<=41<0dQ<010dC4a<2074C001L4`0341<C00LC00<04a<00Q<00`0C

4`0;4`033A0C0=4C00D=4a<C001b4`00Fa<00a0C4`084`0301<C008C0P0=4`033A0C0=0C00D=4a<C

001b4`00Fa<00a0C4`084`0301<C008C00<04a<031<00`d@4`3@4`053A<C4`00LQ<005XC00<@4a<0

2A<00`0C4`024`0301<C00dC00<=41<0ca<01@dC4a<0078C001J4`0341<C00PC0P044`0301<C00hC

00<=41<0cQ<010dC4a<2074C001I4`0341<C00lC0P0?4`033A0C0<hC00D=4a<C001b4`00F1<00a0C

4`0@4`0301<C00lC00<=41<0cA<01@dC4a<0078C001H4`0341<C010C00<04a<041<00`d@4`314`03

01<C008C00<04a<00Q<00`0=4`024`0301<C070C001G4`0341<C014C00<04a<04A<00`dC4`2o4`03

01<000LC00<04`d00a<00`0C4`1`4`00EQ<00a0C4`0B4`804Q<00`d@4`2o4`0301<000TC00@03A<C

0P1a4`00EQ<00a0C4`0B4`0301<C018C00<=41<0_Q<00`0C00074`8000DC3A<C001b4`00EA<00a0C

4`0C4`0301<C01<C00<=4a<0_A<00`0C00074`0701<C4`dC001b4`00E1<00a0C4`0D4`0301<C01<C

00<=41<0_Q<00`0C4`064`<000@C3A<0LQ<005<C00<@4a<05A<201DC00<=4a<0bQ<010dC001a4`00

Da<00a0C4`0E4`0301<C01DC00<=4a<0bQ<00`d04`1a4`00DQ<00a0C4`0F4`0301<C01DC00<=41<0

bQ<00`d04`1a4`00DA<00a0C4`0G4`0301<C01HC00<=4a<0bA<00`d04`1a4`00DA<00a0C4`0G4`80

61<00`dC4`394`033A<C070C001@4`0341<C01PC00<04a<05a<00a0=4`394`033@0C070C001?4`03

41<C00PC1@024`0301<C008C00<04a<00Q<00`0C4`0H4`033A<C0<PC00<03A<0L1<004lC00<@4a<0

2Q<00`0C4`064`0301<000<C00<04a<06A<00`dC4`374`0300dC070C001>4`0341<C00/C00<04a<0

21<0100C4a<201/C00<=4a<0aQ<00`0C3@1`4`00CA<00a0C4`0<4`0301<C00HC0P044`0301<C01XC

00<=4a<0aQ<00`0C3@1`4`00C1<00a0C4`0=4`0301<C00HC00<04a<00a<00`0C4`0K4`033A<C0<DC

0P000a<=4`1^4`00C1<00a0C4`0<4`8021<300<C00<04a<06a<00`d@4`354`0501<C4`d0KQ<004/C

00<@4a<07A<201dC00<=41<0a1<01@0C4a<=06hC001:4`0341<C01hC00<04a<07A<00`dC4`334`03

01<C008C00<=4a<0Ja<004XC00<@4a<07Q<00`0C4`0M4`033A0C0<<C00<04a<00Q<00`dC4`1[4`00

BA<00a0C4`0O4`0301<C01hC00<=41<0`Q<200@C00<=4a<0JQ<004PC00<@4a<081<201lC00<=4a00

`Q<00`0C4`044`033A<C06TC00174`0341<C024C00<04a<07a<00`dC402j4`D00Q<00`0C4`054`03

3A<C06PC00174`0341<C024C00<04a<081<00`d@4`2k4`0301<C008C00<04a<01A<00`dC4`1X4`00

AQ<00a0C4`0R4`0301<C020C00<=4a00^a<00`0C4`024`801a<00`dC4`1W4`00AA<00a0C4`0S4`80

8Q<00`dC402j4`0301<C008C00<04a<01a<00`dC4`1V4`00A1<00a0C4`0T4`0301<C028C00<=4a00

^A<00`0C4`024`0301<C00PC00<=4a<0IA<004@C00<@4a<091<00`0C4`0R4`033A<@0;PC0P044`03

01<C00TC00<=4a<0I1<004<C00<@4a<09A<00`0C4`0S4`033A<@0;dC00<04a<02Q<00`dC4`1S4`00

@Q<00a0C4`0V4`0301<C02@C00<=4a00_1<200`C00<=4a<0HQ<0044C00<@4a<09a<202HC00<=4a00

^a<00`0C4`0<4`033A<C064C00104`0341<C02PC00<04a<09A<010dC4a2j4`0301<C00dC00<=4a<0

H1<0040C00<@4a<08Q<300<C00<04a<09Q<010dC4a2i4`0301<C00hC00<=4a<0Ga<003lC00<@4a<0

8a<00`0C4`034`0301<C02LC00<=4a00^A<00`0C4`0?4`8=Ga<003hC00<@4a<09A<00`0C4`024`80

:1<010dC4a2h4`804Q<00`dC4`1L4`00?A<00a0C4`0V4`0301<C008C00<04a<0:1<010dC4a2g4`03

01<C018C00<=4a<0Fa<003dC00<@4a<09A<00`0C00034`0301<C02TC00@=4a<@]Q<00`0C4`0C4`03

3A<C05XC000l4`0341<C02LC00<04a<00Q<00`0C4`0Y4`053A<C4a00]A<00`0C4`0D4`8=FQ<003/C

00<@4a<0;A<202/C00D=4a<C402d4`805a<00`dC4`1G4`00>Q<00a0C4`0^4`0301<C02/C00@=4a<@

]1<00`0C4`0G4`033A<C05HC000j4`0341<C02hC00<04a<0;1<010dC4a2c4`0301<C01PC00<=4a<0

EA<003TC00<@4a<0;a<00`0C4`0/4`053A<C4a00/Q<00`0C4`0I4`033A<C05@C000h4`0341<C030C

0P0^4`053A<C4a00/A<00`0C4`0J4`8=E1<003LC00<@4a<0<A<00`0C4`0^4`043A<C4;4C0P0M4`03

3A<C054C000g4`0341<C034C00<04a<0;Q<01@dC4a<@0;0C00<04a<07A<00`dC4`1@4`00=Q<00a0C

4`0b4`0301<C02lC00D=4a<C402_4`0301<C01hC0Pe@4`00=A<00a0C4`0c4`80<A<01@dC4a<@09dC

1@024`0301<C008C00<04a<00Q<00`0C4`0P4`8=CQ<003@C00<@4a<0=1<00`0C4`0`4`033A<C008C

00<@4a<0W1<00`0C4`064`0301<000<C00<04a<08Q<23D`C000c4`0341<C03DC00<04a<0<A<00`dC

4`024`0341<C09/C00<04a<021<0100C4a<202DC00<=4a<0BA<0038C00<@4a<0=Q<00`0C4`0b4`05

3A<C4a00WA<00`0C4`064`8011<00`0C4`0U4`8=BA<0034C00<@4a<0=a<203@C00D=4a<C402L4`03

01<C00HC00<04a<00a<00`0C4`0W4`033A<C04HC000`4`0341<C03PC00<04a<0<a<00`dC4`024`03

41<C09PC0P084`<00a<00`0C4`0X4`8=AQ<002lC00<@4a<0:A<300<C00<04a<00Q<00`0C4`024`03

01<C03@C00<=4a<00Q<00a0C4`2W4`0301<C02XC0Pe44`00;Q<00a0C4`0Z4`0301<C00LC00<04`00

0a<00`0C4`0e4`033A<C008C00<@4a<0YQ<202dC0Pe24`00;A<00a0C4`0/4`0301<C00PC00@04a<C

0P0f4`033A<C00<C00<@4a<0YA<00`0C4`0^4`8=@1<002`C00<@4a<0;A<00`0C4`064`8011<00`0C

4`0f4`033A<C00<C00<@4a<0Y1<00`0C4`0`4`8=?Q<002/C00<@4a<0;A<00`0C00074`0301<C00<C

00<04a<0=a<00`dC4`034`0341<C0:<C00<04a<0<Q<23C`C000Z4`0341<C02lC00<04a<01Q<300<C

00<04a<0=a<00`dC4`044`0341<C0:8C0P0e4`033A<C03TC000Y4`0341<C03lC0P0i4`033A<C00@C

00<@4a<0XA<00`0C4`0e4`8=>A<002PC00<@4a<0@1<00`0C4`0i4`033A<C00@C00<@4a<0X1<00`0C

4`0g4`033A<C03HC000W4`0341<C044C00<04a<0>Q<00`dC4`044`0341<C09lC00<04a<0>1<23CHC

000V4`0341<C048C00<04a<0>Q<00`dC4`054`0341<C09hC00<04a<0>Q<23C@C000U4`0341<C04<C

0P0l4`033A<C00DC00<@4a<0WA<203dC0Pdb4`0091<00a0C4`144`0301<C03`C00<=4a<01A<00a0C

4`2L4`0301<C03hC0Pd`4`008a<00a0C4`154`0301<C03`C00<=4a<01Q<00a0C4`2K4`0301<C040C

0Pd^4`008a<00a0C4`154`0301<C03dC00<=4a<01Q<00a0C4`2J4`0301<C048C0`d[4`008Q<00a0C

4`164`80?Q<00`dC4`074`0341<C09TC00<04a<0AA<23BTC000Q4`0341<C04LC00<04a<0?Q<00`dC

4`074`0341<C09PC0P184`<=9Q<0020C00<@4a<0B1<00`0C4`0o4`033A<C00LC00<@4a<0Ua<00`0C

4`1:4`8=91<001lC00<@4a<0BA<00`0C4`0o4`033A<C00PC00<@4a<0T1<300<C00<04a<0C1<23B8C

000N4`0341<C04XC0P114`033A<C00PC00<@4a<0Sa<00`0C4`034`0301<C04hC0PdP4`007A<00a0C

4`1;4`0301<C040C00<=4a<02A<00a0C4`2?4`0301<C008C0P1A4`8=7Q<001`C00<@4a<0C1<00`0C

4`114`033A<C00TC00<@4a<0SQ<00`0C4`024`0301<C058C0PdL4`006a<00a0C4`174`8011<00`0C

4`124`033A<C00TC00<@4a<0S1<00`0C00034`0301<C05@C0`dI4`006Q<00a0C4`1:4`0501<C4`00

A1<00`dC4`0:4`0341<C08`C00<04a<00Q<00`0C4`1G4`8=5a<001TC00<@4a<0BQ<00`0C4`024`80

A1<00`dC4`094`0341<C094C00<04a<0FA<33A@C001W4`0301<C0>LC0P1L4`033A<C018C001U4`03

01<00>TC00<04a<0L1<006HC00<04a<0j1<00`0C4`1`4`00:Q<30?lC9A<00`0C4`1`4`00:Q<00`0C

4`3o4bDC00<04a<0L1<002/C00<04a<011<00`0C4`3o4i0C000[4`0401<C4`@00a<30?lCS1<002XC

00<04`000Q<200034`0C00@C00<04a<0oa>:4`00:a<00`0C4`034`0301<000<C00<04a<0oa>;4`00

<A<00`0C00044`0301<C00HC00<04a<09a<302/C00<04a<0oa<Y4`006a<300034`00008031<300@C

0`084`0301<C02HC00@04a<03a<300034`0000800Q<00`0C4`024`0301<C008C00<04a<01A<0100C

4a<5008C00<04a<00Q<3008C00<04a<00Q<00`0C4`044`80aA<00`0C4`0g4`0301<C00HC000J4`04

01<C02@C00<04a<09A<0100C4`0>4`0401<C00HC00<04`001a<00`0C00044`D00a<00`0C4`084`06

01<C01<00Q<00`0C00044`0301<C0;dC00<04a<011<00`0C4`0C4`0301<C02<C00<04a<01A<001XC

00D04a<04`0400034`0001P0;A<300hC00D04a<04`0400044`0C00TC00<04a<011<00`0C4`034`03

01<C00HC10034`0301<C008C00<04a<00Q<00`0C4`2[4`0401<C4`@00Q<200HC00<04a<00a<00`0C

4`024`0301<C008C00<04a<00Q<00`0C4`054`0401<C4`D00Q<00`0C4`024`<00Q<00`0C4`024`03

01<C00@C0P044`0401<C4`800A<001/C0`1?4`0301<C00dC0`064`0301<000LC0P074`0301<C00<C

00<04a<01Q<00`0C00024`800a<200DC00<04a<0ZQ<00`0C00074`0301<C00@C1@034`0701<C4`0C

00074`0301<000@C1@034`0301<C00PC00H04a<04`024`0301<000@C00<04a<011<00`0C4`024`40

0A<001dC00<04a<0C1<2014C00<04a<011<00`0C00074`0301<C00`C00<04a<01a<2008C00<04a<0

0Q<00`0C4`044`0301<00:XC00<04`000Q<400034`0C00LC00<04a<00a<01`0C4a<04`002A<00`0C

4`044`0301<C00<C00<04a<01Q<400<C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<00a<10000

71<2060C0P074`0301<C00HC0`0;4`802Q<00`0C4`03008C0`044`<0Ta<200034`00018C00<04`00

1a<00`0C4`064`0301<C00<C00L04a<C01<000LC0P074`0301<C00<C00<04a<01Q<00`0C00024`80

0a<200DC00<04a<011<00`0C4`034`40003o4e4C00<04`004a<00`0C00074`0301<000dC00H04a<0

4`074`0301<C00`C00<04a<01a<2008C00<04a<00Q<00`0C4`044`0301<000<C00<04a<00a<1004C

000V4`801Q<20?lC8Q<00`0C4`0C4`0301<C00HC0`0>4`0401<C00PC0`0;4`802Q<00`0C4`03008C

0`044`<00Q<00`0C4`034`800A<002PC00<04a<00Q<00`0C4`3o4b8C00<04a<0L1<002LC00<04a<0

0a<00`0C4`064`0301<C0?lC61<00`0C001a4`00:1<00`0C4`024`0301<C008C0`0011<04a<30?lC

51<200034`00070C000V4`0301<000@C00<04`000Q<2008C00<04a<00Q<00`0C4`3o4hLC000W4`03

01<C00<C0`044`0401<C008C00<04a<0oa>84`00=1<0100C4`034`0301<C0?lCQa<0038C0`044`<0

oa>94`00oa?54`00oa?54`00oa?54`00oa?54`00oa?54`00\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.16744, -1.60297, 0.021231, 0.021231}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -82 0 ]

[.5 .96488 82 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -143 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.45) show

217.250000 19.500000 moveto

(C) show

222.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.25369 0 m

.26171 .01162 L

.30316 .07172 L

.34309 .12962 L

.3815 .18532 L

.42237 .24457 L

.46172 .30163 L

.49955 .35649 L

.53984 .41491 L

.57861 .47113 L

.61984 .5309 L

.65954 .58848 L

.69774 .64386 L

.73838 .7028 L

.77751 .75954 L

.81909 .81983 L

.85916 .87793 L

.89771 .93382 L

s

.89771 .93382 m

.91051 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.35565 0.238095 [

[.02381 .34315 -6 -9 ]

[.02381 .34315 6 0 ]

[.2619 .34315 -6 -9 ]

[.2619 .34315 6 0 ]

[.7381 .34315 -3 -9 ]

[.7381 .34315 3 0 ]

[.97619 .34315 -3 -9 ]

[.97619 .34315 3 0 ]

[1.025 .35565 0 -8 ]

[1.025 .35565 9 8 ]

[.4875 .11756 -12 -4.5 ]

[.4875 .11756 0 4.5 ]

[.4875 .2366 -24 -4.5 ]

[.4875 .2366 0 4.5 ]

[.4875 .4747 -18 -4.5 ]

[.4875 .4747 0 4.5 ]

[.4875 .59375 -6 -4.5 ]

[.4875 .59375 0 4.5 ]

[.4875 .71279 -18 -4.5 ]

[.4875 .71279 0 4.5 ]

[.4875 .83184 -6 -4.5 ]

[.4875 .83184 0 4.5 ]

[.5 .89849 -4.5 0 ]

[.5 .89849 4.5 16 ]

[.5 .88599 -134.5 0 ]

[.5 .88599 134.5 16 ]

[ 0 0 0 0 ]

[ 1 .87349 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .35565 m

.02381 .3619 L

s

[(-2)] .02381 .34315 0 1 Mshowa

.2619 .35565 m

.2619 .3619 L

s

[(-1)] .2619 .34315 0 1 Mshowa

.7381 .35565 m

.7381 .3619 L

s

[(1)] .7381 .34315 0 1 Mshowa

.97619 .35565 m

.97619 .3619 L

s

[(2)] .97619 .34315 0 1 Mshowa

.125 Mabswid

.07143 .35565 m

.07143 .3594 L

s

.11905 .35565 m

.11905 .3594 L

s

.16667 .35565 m

.16667 .3594 L

s

.21429 .35565 m

.21429 .3594 L

s

.30952 .35565 m

.30952 .3594 L

s

.35714 .35565 m

.35714 .3594 L

s

.40476 .35565 m

.40476 .3594 L

s

.45238 .35565 m

.45238 .3594 L

s

.54762 .35565 m

.54762 .3594 L

s

.59524 .35565 m

.59524 .3594 L

s

.64286 .35565 m

.64286 .3594 L

s

.69048 .35565 m

.69048 .3594 L

s

.78571 .35565 m

.78571 .3594 L

s

.83333 .35565 m

.83333 .3594 L

s

.88095 .35565 m

.88095 .3594 L

s

.92857 .35565 m

.92857 .3594 L

s

.25 Mabswid

0 .35565 m

1 .35565 L

s

gsave

1.025 .35565 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .11756 m

.50625 .11756 L

s

[(-1)] .4875 .11756 1 0 Mshowa

.5 .2366 m

.50625 .2366 L

s

[(-0.5)] .4875 .2366 1 0 Mshowa

.5 .4747 m

.50625 .4747 L

s

[(0.5)] .4875 .4747 1 0 Mshowa

.5 .59375 m

.50625 .59375 L

s

[(1)] .4875 .59375 1 0 Mshowa

.5 .71279 m

.50625 .71279 L

s

[(1.5)] .4875 .71279 1 0 Mshowa

.5 .83184 m

.50625 .83184 L

s

[(2)] .4875 .83184 1 0 Mshowa

.125 Mabswid

.5 .02232 m

.50375 .02232 L

s

.5 .04613 m

.50375 .04613 L

s

.5 .06994 m

.50375 .06994 L

s

.5 .09375 m

.50375 .09375 L

s

.5 .14136 m

.50375 .14136 L

s

.5 .16517 m

.50375 .16517 L

s

.5 .18898 m

.50375 .18898 L

s

.5 .21279 m

.50375 .21279 L

s

.5 .26041 m

.50375 .26041 L

s

.5 .28422 m

.50375 .28422 L

s

.5 .30803 m

.50375 .30803 L

s

.5 .33184 m

.50375 .33184 L

s

.5 .37946 m

.50375 .37946 L

s

.5 .40327 m

.50375 .40327 L

s

.5 .42708 m

.50375 .42708 L

s

.5 .45089 m

.50375 .45089 L

s

.5 .49851 m

.50375 .49851 L

s

.5 .52232 m

.50375 .52232 L

s

.5 .54613 m

.50375 .54613 L

s

.5 .56994 m

.50375 .56994 L

s

.5 .61756 m

.50375 .61756 L

s

.5 .64136 m

.50375 .64136 L

s

.5 .66517 m

.50375 .66517 L

s

.5 .68898 m

.50375 .68898 L

s

.5 .7366 m

.50375 .7366 L

s

.5 .76041 m

.50375 .76041 L

s

.5 .78422 m

.50375 .78422 L

s

.5 .80803 m

.50375 .80803 L

s

.5 .85565 m

.50375 .85565 L

s

.25 Mabswid

.5 0 m

.5 .87349 L

s

gsave

.5 .89849 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .88599 -195.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.45) show

293.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

298.000000 15.000000 moveto

(L) show

305.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

312.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

319.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

324.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

328.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .87349 L

0 .87349 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .1904 m

.02576 .1904 L

.03157 .19039 L

.04114 .19037 L

.05431 .19035 L

.07085 .19032 L

.09049 .19028 L

.11288 .19023 L

.13764 .19017 L

.16435 .1901 L

.19255 .19002 L

.22175 .18993 L

.25147 .18982 L

.28119 .18969 L

.31039 .18954 L

.33859 .18937 L

.3653 .18918 L

.39006 .18897 L

.41245 .18875 L

.43209 .18852 L

.44863 .18829 L

.4618 .18808 L

.47137 .18791 L

.47718 .1878 L

.47913 .18776 L

s

.47913 .18776 m

.48126 .18772 L

.4876 .18758 L

.49805 .18734 L

.51243 .18695 L

.53049 .18635 L

.55192 .18542 L

.57637 .18388 L

.6034 .18115 L

.63255 .17596 L

.66334 .16647 L

.69522 .15253 L

.72766 .13636 L

.7601 .11981 L

.79198 .10381 L

.82277 .0888 L

.85193 .07503 L

.87896 .06263 L

.9034 .05173 L

.92483 .04239 L

.94289 .03467 L

.95727 .02863 L

.96772 .02428 L

.97406 .02167 L

.97619 .0208 L

s

.47913 .43954 m

.48126 .41272 L

.4876 .38603 L

.49805 .35965 L

.51243 .33374 L

.53049 .30849 L

.55192 .28413 L

.57637 .26104 L

.6034 .23992 L

.63255 .22213 L

.66334 .20964 L

.69522 .20265 L

.72766 .19907 L

.7601 .19712 L

.79198 .19594 L

.82277 .19518 L

.85193 .19466 L

.87896 .19429 L

.9034 .19403 L

.92483 .19383 L

.94289 .19368 L

.95727 .19358 L

.96772 .19351 L

.97406 .19347 L

.97619 .19346 L

s

.47913 .43965 m

.48126 .46651 L

.4876 .49334 L

.49805 .51996 L

.51243 .54626 L

.53049 .57211 L

.55192 .59741 L

.57637 .62203 L

.6034 .64589 L

.63255 .66886 L

.66334 .69085 L

.69522 .71177 L

.72766 .73152 L

.7601 .75002 L

.79198 .7672 L

.82277 .78296 L

.85193 .79726 L

.87896 .81002 L

.9034 .8212 L

.92483 .83074 L

.94289 .8386 L

.95727 .84474 L

.96772 .84916 L

.97406 .85181 L

.97619 .8527 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<00`0C4`1`4`00oa=B4`0301<C070C001T4`D0j1<00`0C4`1`4`00IQ<00`0C4`3X4`03

01<C070C00114`033A<C01`C0`034`0301<C008C0P3T4`80Fa<23A@C00114`033A<C028C00<04a<0

0Q<00`0C4`3S4`0301<C05LC0`dF4`00@Q<00`dC4`0Q4`0301<C008C00<04a<0ha<00`0C4`1E4`8=

6A<004<C00<=4a<07a<200@C00<04a<0ha<00`0C4`1C4`8=6a<004<C00<=4a<09A<20>@C00<04a<0

DA<23AdC00144`033A<C02@C00<04a<0ha<2050C0PdO4`00AA<00`dC4`0S4`0301<C0><C00<04a<0

C1<33B4C00154`033A<C02<C00<04a<0ha<00`0C4`1:4`8=91<004HC00<=4a<08Q<20>@C00<04a<0

Aa<33BHC00174`033A<C024C00<04a<0ha<204HC0PdY4`00B1<00`dC4`0P4`0301<C0><C00<04a<0

@a<23B/C00184`033A<C020C00<04a<0ha<00`0C4`114`8=;A<004TC00<=4a<07a<20>@C00<04a<0

?a<23BlC001:4`033A<C01hC00<04a<0ha<00`0C4`0m4`8=<A<004XC00<=4a<07Q<00`0C4`3S4`80

?1<23C<C001;4`033A<C01dC00<04a<0ha<00`0C4`0i4`8==A<004`C00<=4a<071<20>@C00<04a<0

=a<23CLC001<4`033A<C01`C00<04a<0g1<5008C00<04a<0=A<23CTC001=4`033A<C00`C00<04a<0

0Q<00`0C4`024`0301<C008C00<04a<0gQ<00`0C4`024`0301<C03<C0Pdk4`00CQ<00`dC4`0:4`03

01<000LC00<04`000a<00`0C4`3H4`<00a<00`0C4`024`80<Q<23CdC001?4`033A<C00@C0`024`03

01<000TC00@04a<C0P3O4`0301<C008C00<04a<0;a<23ClC001?4`033A<C00TC00<04`001a<200@C

00<04a<0gQ<00`0C4`024`0301<C02dC0Pe14`00D1<00`dC4`084`0301<000LC00<04a<00a<00`0C

4`3M4`8011<00`0C4`0[4`8=@a<0054C00<=4a<021<00`0C4`064`<00a<00`0C4`3S4`0301<C02XC

00<=4a<0@a<0054C00<=4a<05a<00`0C4`3S4`80:A<23DHC001B4`033A<C01HC0P3T4`0301<C02HC

0Pe84`00Da<00`dC4`0E4`0301<C0><C00<04a<08a<33DXC001C4`033A<C01DC00<04a<0ha<00`0C

4`0Q4`8=CA<005@C00<=4a<051<00`0C4`3S4`8081<23DlC001E4`033A<C01<C0P3T4`0301<C01/C

10eA4`00EQ<00`dC4`0B4`0301<C0><C00<04a<05A<63EDC000J4`<09A<500lC00<=4a<04Q<00`0C

4`0T4`D091<309<C00<04a<041<53E/C000J4`0301<C02LC00<04a<041<00`dC4`0A4`0301<C02HC

00<04a<091<00`0C4`2C4`0301<C00HC2PeP4`005A<300<C00<04a<081<300<C00<04a<04A<00`dC

4`0@4`809a<00`0C4`0U4`0301<C03@CI`eZ4`006a<00`0C4`0V4`0301<C014C00<=4a<041<00`0C

4`0V4`0301<C02DC00<04a<0TQ<00`0C4`0e4bL=51<001XC00<04`009a<00`0C4`0B4`033A<C00lC

00<04a<09Q<00`0C4`0T4`0301<009<C00<04a<0:1<=3C/C000K4`0301<C02DC0P0E4`033A<C00hC

00<04a<09A<202LC00<04a<0TQ<00`0C4`0Q4`L=B1<005XC00<=4a<03Q<20>@C00<04a<07A<43DlC

001K4`033A<C00dC00<04a<0ha<201`C0PeC4`00G1<00`dC4`0<4`0301<C05/C0P264`0301<C01TC

0PeE4`00GA<00`dC4`0;4`0301<C05XC00<04a<0Ma<00`0C4`024`0301<C008C00<04a<00Q<00`0C

4`0G4`8=Ea<001DCB0000`d0001R00HC00<04a<0MQ<00`0C00074`0301<000<C00<04a<05A<23ETC

000I4`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC

00<04a<01A<0100C4`d44`0301<C00DC00<@4a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C

4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`084`0301<C074C

0`024`0301<000TC00@04a<C0P0D4`8=Fa<005lC00<=4a<02A<00a0C4`1J4`0301<007HC00<04`00

1a<200@C00<04a<04Q<00`dC4`1K4`00Ga<00`dC4`094`8@Fa<307HC00<04`001a<00`0C4`034`03

01<C010C0PeN4`00H1<00`dC4`084`8@eA<00`0C4`064`<00a<00`0C4`0?4`033A<C05hC001Q4`03

3A<C00HC00<@0100i1<00`0C4`0=4`8=HA<0064C00<=4a<01Q<00a00403T4`803A<00`dC4`1Q4`00

HQ<00`dC4`054`03400@0>@C00<04a<02a<00`dC4`1R4`00Ha<00`dC4`034`0541<00100ha<00`0C

4`0:4`033A<C06<C001T4`033A<C008C00D@4`0C403S4`0301<C00TC00<=4a<0I1<006@C00<=4a<0

0Q<01A0C01<@0><C00<04a<021<00`dC4`1U4`00IA<01`dC4a<@4`000Q<00a0C4`3P4`8021<00`dC

4`1V4`00IQ<01@dC4a0C008000<C41<0hA<00`0C4`064`033A<C06LC001V4`063A<C41<00Q<00a0C

4`3P4`0301<C00DC00<=4a<0J1<006LC00D=41<C00034`0341<C0=lC00<04a<01A<00`dC4`1X4`00

J1<010dC4`034`0341<C088C0`0[4`D0:Q<00`0C4`044`033A<C02<C1@0[4`<04a<006PC00<=4a<0

0P024`0341<C088C00<04a<0;A<00`0C4`0Z4`8011<00`dC4`0V4`0301<C02/C00<04a<04a<006LC

00D@4`dC00044`0341<C07`C0`034`0301<C02HC0`034`0301<C02XC00<04a<00Q<00`dC4`0W4`03

01<C02`C00<04a<04Q<005`C00<04a<00Q<00`0C4`024`06010C4`d011<00a0C4`224`0301<C02`C

00<04a<0:Q<00`0C4`024`033A<C02LC00<04a<0;1<00`0C4`0B4`00Fa<00`0C00074`030100008C

00<=01<00a<00a0C4`214`0301<002dC00<04a<0:Q<01@0C4a<=02XC00<04a<0:a<00`0C000C4`00

Fa<00`0C00084`03400C008C00<=01<00a<00a0C4`214`0301<C02/C0P0/4`800Q<00`dC4`0W4`80

;Q<00`0C4`0B4`00Fa<00`0C00074`03010C00<C00<03A<00a<00a0C4`3M4`0401<C3FlC001K4`03

01<000LC00<@4a<00a<00`0=4`044`0341<C0=`C00<04`d0L1<005`C00<04a<01Q<00a0000034`03

01<=00@C00<@4a<0g1<00`0C3@1Y4`801A<006@C00<@4a<011<200034`dC008C00<@4a<0g1<00`0=

4`1X4`0301<C00DC001T4`0341<C00@C00@04a<=11<00a0C4`1h4f@000<=0000H0074`0301<C00DC

001S4`0341<C00DC00D04a<C3@034`0341<C07dC00<04a<01Q<00`0C4`074`0301<C00HC00<04a<0

1Q<00`0C4`074`0301<C00HC00<04a<01a<00`0C4`064`0301<C00LC00<04a<01Q<00`dC4`074`03

01<C00HC00<04a<01Q<00`0C4`074`0301<C00HC00<04a<01a<00`0C4`064`0301<C00LC00<04a<0

1Q<00`0C4`064`0301<C00XC00<04a<01A<006<C00<@4a<01A<00`0C4`024`053A<C4a00g1<00`dC

4`1X4`0301<000DC001R4`0341<C00HC00<04a<00a<010dC4a3K4`033@0C06TC0`054`00HQ<00a0C

4`064`8011<01@dC4a<@0=XC00<=01<0LA<0064C00<@4a<01a<00`0C4`044`043A<C4=TC00@=4`00

LA<0064C00<@4a<01a<00`0C4`054`033A<@0=TC00<=4`00LQ<0060C00<@4a<021<00`0C4`054`04

3A<C4=PC00<=4`00LQ<0060C00<@4a<021<200LC00<=4a00ea<010dC4`1b4`00Ga<00a0C4`094`03

01<C00LC00<=4a00eQ<010dC4`1b4`00Ga<00a0C4`094`0301<C00LC00<=4a00eA<010dC4a<2074C

001N4`0341<C00XC00<04a<021<00`dC403D4`053A<C4`00LQ<005hC00<@4a<02Q<200XC00<=41<0

da<01@dC4a<0078C001M4`0341<C00/C00<04a<02Q<00`d@4`3B4`053A<C4`00LQ<005dC00<@4a<0

11<5008C00<04a<02Q<00`d@4`3B4`043A<C4`80LA<005`C00<@4a<01a<00`0C4`024`0301<C00/C

00<=41<0dA<01@dC4a<0078C001K4`0341<C00PC00<04a<00Q<200dC00<=41<0d1<01@dC4a<0078C

001K4`0341<C00PC00<04a<00Q<00`0C4`0<4`033A0C0=0C00D=4a<C001b4`00FQ<00a0C4`094`03

01<C008C00<04a<03A<00`d@4`3?4`053A<C4`00LQ<005XC00<@4a<021<200@C00<04a<03Q<00`d@

4`3>4`043A<C4`80LA<005TC00<@4a<03a<200lC00<=41<0cQ<01@dC4a<0078C001H4`0341<C010C

00<04a<03a<00`d@4`3=4`053A<C4`00LQ<005PC00<@4a<041<00`0C4`0@4`033A0C0<4C00<04a<0

0Q<00`0C4`024`0300dC008C00<04a<0L1<005LC00<@4a<04A<00`0C4`0A4`033A<C0;lC00<04`00

1a<00`0C3@034`0301<C070C001F4`0341<C018C0P0B4`033A0C0;lC00<04`002A<0100=4a<2074C

001F4`0341<C018C00<04a<04Q<00`d@4`2n4`0301<000LC0P001A<=4a<0078C001E4`0341<C01<C

00<04a<04a<00`dC4`2m4`0301<000LC00L04a<C3A<0078C001D4`0341<C01@C00<04a<04a<00`d@

4`2n4`0301<C00HC0`0011<=4`1b4`00Da<00a0C4`0E4`805A<00`dC4`3:4`043A<0074C001C4`03

41<C01DC00<04a<05A<00`dC4`3:4`033@0C074C001B4`0341<C01HC00<04a<05A<00`d@4`3:4`03

3@0C074C001A4`0341<C01LC00<04a<05Q<00`dC4`394`033@0C074C001A4`0341<C01LC0P0H4`03

3A<C0<TC00<=4a<0L1<0050C00<@4a<061<00`0C4`0G4`0340dC0<TC00<=01<0L1<004lC00<@4a<0

21<5008C00<04a<00Q<00`0C4`024`0301<C01PC00<=4a<0b1<00`0=4`1`4`00Ca<00a0C4`0:4`03

01<C00HC00<04`000a<00`0C4`0I4`033A<C0<LC00<03A<0L1<004hC00<@4a<02a<00`0C4`084`04

01<C4`806a<00`dC4`364`0301<=070C001=4`0341<C00`C00<04a<01Q<200@C00<04a<06Q<00`dC

4`364`0301<=070C001<4`0341<C00dC00<04a<01Q<00`0C4`034`0301<C01/C00<=4a<0aA<20003

4`dC06hC001<4`0341<C00`C0P084`<00a<00`0C4`0K4`033A0C0<DC00D04a<C3@1^4`00Ba<00a0C

4`0M4`807A<00`d@4`344`0501<C4`d0KQ<004XC00<@4a<07Q<00`0C4`0M4`033A<C0<<C00<04a<0

0Q<00`dC4`1[4`00BQ<00a0C4`0N4`0301<C01dC00<=41<0`a<00`0C4`024`033A<C06/C00194`03

41<C01lC00<04a<07Q<00`d@4`324`8011<00`dC4`1Z4`00B1<00a0C4`0P4`807a<00`dC40324`03

01<C00@C00<=4a<0JA<004LC00<@4a<08A<00`0C4`0O4`033A<@0;XC1@024`0301<C00DC00<=4a<0

J1<004LC00<@4a<08A<00`0C4`0P4`033A0C0;/C00<04a<00Q<00`0C4`054`033A<C06PC00164`03

41<C028C00<04a<081<00`dC402k4`0301<C008C0P074`033A<C06LC00154`0341<C02<C0P0R4`03

3A<@0;XC00<04a<00Q<00`0C4`074`033A<C06HC00144`0341<C02@C00<04a<08Q<00`dC402i4`03

01<C008C00<04a<021<00`dC4`1U4`00A1<00a0C4`0T4`0301<C028C00<=4a00^1<200@C00<04a<0

2A<00`dC4`1T4`00@a<00a0C4`0U4`0301<C02<C00<=4a00_A<00`0C4`0:4`033A<C06<C00124`03

41<C02HC00<04a<091<00`dC402l4`8031<00`dC4`1R4`00@A<00a0C4`0W4`809Q<00`dC402k4`03

01<C00`C00<=4a<0HA<0040C00<@4a<0:1<00`0C4`0U4`043A<C4;XC00<04a<03A<00`dC4`1P4`00

@1<00a0C4`0R4`<00a<00`0C4`0V4`043A<C4;TC00<04a<03Q<00`dC4`1O4`00?a<00a0C4`0S4`03

01<C00<C00<04a<09a<00`dC402i4`0301<C00lC0PeO4`00?Q<00a0C4`0U4`0301<C008C0P0Y4`03

3A<@0;PC0P0B4`033A<C05`C000m4`0341<C02HC00<04a<00Q<00`0C4`0X4`043A<C4;LC00<04a<0

4Q<00`dC4`1K4`00?A<00a0C4`0U4`0301<000<C00<04a<0:A<010dC4a2f4`0301<C01<C00<=4a<0

FQ<003`C00<@4a<09a<00`0C4`024`0301<C02XC00@=4a<@]A<00`0C4`0D4`8=FQ<003/C00<@4a<0

;A<202`C00@=4a<@]1<201LC00<=4a<0Ea<003XC00<@4a<0;Q<00`0C4`0[4`043A<C4;@C00<04a<0

5a<00`dC4`1F4`00>Q<00a0C4`0^4`0301<C02`C00@=4a<@/a<00`0C4`0H4`033A<C05DC000i4`03

41<C02lC00<04a<0;A<010dC4a2b4`0301<C01TC00<=4a<0E1<003PC00<@4a<0<1<202lC00@=4a<@

/A<00`0C4`0J4`8=E1<003LC00<@4a<0<A<00`0C4`0^4`043A<C4;4C0P0M4`033A<C054C000g4`03

41<C034C00<04a<0;a<010dC4a2`4`0301<C01dC00<=4a<0D1<003HC00<@4a<0<Q<00`0C4`0`4`04

3A<C4:lC00<04a<07Q<23E0C000e4`0341<C03<C0P0a4`053A<C4a00WA<5008C00<04a<00Q<00`0C

4`024`0301<C020C0Pe>4`00=1<00a0C4`0d4`0301<C034C00D=4a<C402N4`0301<C00HC00<04`00

0a<00`0C4`0R4`8=C1<003<C00<@4a<0=A<00`0C4`0a4`033A<C008C00<@4a<0Va<00`0C4`084`04

01<C4`809A<00`dC4`194`00<Q<00a0C4`0f4`0301<C038C00D=4a<C402M4`0301<C00HC0P044`03

01<C02DC0Pe94`00<A<00a0C4`0g4`80=1<01@dC4a<@09`C00<04a<01Q<00`0C4`034`0301<C02LC

00<=4a<0AQ<0030C00<@4a<0>1<00`0C4`0c4`033A<C008C00<@4a<0V1<200PC0`034`0301<C02PC

0Pe64`00;a<00a0C4`0Y4`<00a<00`0C4`024`0301<C008C00<04a<0=1<00`dC4`024`0341<C0:LC

00<04a<0:Q<23D@C000^4`0341<C02XC00<04a<01a<00`0C00034`0301<C03DC00<=4a<00Q<00a0C

4`2V4`80;A<23D8C000]4`0341<C02`C00<04a<021<0100C4a<203HC00<=4a<00a<00a0C4`2U4`03

01<C02hC0Pe04`00;1<00a0C4`0]4`0301<C00HC0P044`0301<C03HC00<=4a<00a<00a0C4`2T4`03

01<C030C0Pdn4`00:a<00a0C4`0]4`0301<000LC00<04a<00a<00`0C4`0g4`033A<C00<C00<@4a<0

Xa<00`0C4`0b4`8=?1<002XC00<@4a<0;a<00`0C4`064`<00a<00`0C4`0g4`033A<C00@C00<@4a<0

XQ<203DC00<=4a<0>A<002TC00<@4a<0?a<203TC00<=4a<011<00a0C4`2Q4`0301<C03DC0Pdi4`00

:1<00a0C4`104`0301<C03TC00<=4a<011<00a0C4`2P4`0301<C03LC00<=4a<0=Q<002LC00<@4a<0

@A<00`0C4`0j4`033A<C00@C00<@4a<0Wa<00`0C4`0h4`8==Q<002HC00<@4a<0@Q<00`0C4`0j4`03

3A<C00DC00<@4a<0WQ<00`0C4`0j4`8==1<002DC00<@4a<0@a<203`C00<=4a<01A<00a0C4`2M4`80

?A<23C8C000T4`0341<C04@C00<04a<0?1<00`dC4`054`0341<C09`C00<04a<0?Q<23C0C000S4`03

41<C04DC00<04a<0?1<00`dC4`064`0341<C09/C00<04a<0@1<23BhC000S4`0341<C04DC00<04a<0

?A<00`dC4`064`0341<C09XC00<04a<0@Q<33B/C000R4`0341<C04HC0P0o4`033A<C00HC00<@4a<0

VA<00`0C4`154`8=:A<0024C00<@4a<0Aa<00`0C4`0n4`033A<C00LC00<@4a<0V1<204PC0`dV4`00

81<00a0C4`184`0301<C03lC00<=4a<01a<00a0C4`2G4`0301<C04XC0PdT4`007a<00a0C4`194`03

01<C040C00<=4a<01a<00a0C4`2@4`<00a<00`0C4`1<4`8=8Q<001hC00<@4a<0BQ<2044C00<=4a<0

21<00a0C4`2?4`0301<C00<C00<04a<0CQ<23B0C000M4`0341<C04/C00<04a<0@A<00`dC4`084`03

41<C08lC00<04a<00Q<2054C0PdN4`0071<00a0C4`1<4`0301<C048C00<=4a<021<00a0C4`2>4`03

01<C008C00<04a<0DQ<23A`C000K4`0341<C04LC0P044`0301<C048C00<=4a<02A<00a0C4`2<4`03

01<000<C00<04a<0E1<33ATC000J4`0341<C04XC00D04a<C00154`033A<C00TC00<@4a<0S1<00`0C

4`024`0301<C05LC0PdG4`006A<00a0C4`1:4`0301<C008C0P154`033A<C00PC00<@4a<0TA<00`0C

4`1I4`<=51<006LC00<04a<0ia<205`C00<=4a<04Q<006DC00<04`00jA<00`0C4`1`4`00IQ<00`0C

4`3X4`0301<C070C000/4`<0oa<S4`0301<C070C000/4`0301<C0?lC8a<00`0C4`1`4`00;A<00`0C

4`054`0301<C0?lCSA<002dC00@04a<C0`0011<04a<30?lCRQ<002`C00<04`000Q<2008C00<04a<0

0Q<00`0C4`3o4hPC000]4`0301<C00<C00@04a<00Q<00`0C4`3o4hTC000c4`0401<C00<C00<04a<0

1Q<00`0C4`0U4`<0;A<00`0C4`3o4bLC000M4`<000<C00000P0<4`<011<300PC00<04a<091<0100C

4`0A4`<000<C00000P024`0301<C008C00<04a<00Q<00`0C4`054`0401<C4`D00Q<00`0C4`024`<0

0Q<00`0C4`044`80ba<00`0C4`0b4`0301<C00PC000L4`0401<C02@C00<04a<08a<0100C4`0@4`04

01<C00HC00<04`001a<00`0C00044`D00a<00`0C4`084`0601<C01<011<00`0C4`334`0301<C00@C

00<04a<04a<00`0C4`0N4`0301<C00LC000L4`0501<C01<010000a<0000H02/C0`0@4`0501<C01<0

100011<04`094`0301<C00@C00<04a<00a<00`0C4`064`@00a<00`0C4`024`0301<C0;4C00@04a<C

10024`801Q<00`0C4`034`0301<C008C00<04a<00Q<00`0C4`024`0301<C00DC00@04a<C1@024`03

01<C008C0`024`0301<C00@C0P044`0401<C4`800A<10040000M4`<0CA<00`0C4`0?4`<01Q<00`0C

00074`801a<00`0C4`034`0301<C00HC00<04`000Q<200DC00<04a<0/1<00`0C00074`0301<C00@C

1@034`0701<C4`0C00074`0301<000@C1@034`0301<C00PC00H04a<04`044`0301<C00@C00<04a<0

0Q<00`0C00014`007a<00`0C4`1:4`804a<00`0C4`044`0301<000LC00<04a<031<00`0C4`074`80

0Q<00`0C4`044`0301<00;0C00<04`000Q<400034`0C00LC00<04a<00a<01`0C4a<04`002A<00`0C

4`044`0301<C00<C00<04a<01Q<400<C00<04a<00Q<00`0C4`044`0301<C00<C0@014`4C000N4`80

H1<200LC00<04a<01Q<300/C0P0:4`0301<C00<011<309HC0P000a<0000E4`0301<000LC00<04a<0

1Q<00`0C4`034`0701<C4`0C00074`801a<00`0C4`034`0301<C00HC00<04`000Q<200DC00<04a<0

11<00`0C4`034`400A<14`00oa=A4`0301<001HC00<04`001a<00`0C000=4`0601<C01<01a<00`0C

4`0<4`0301<C00LC0P024`0301<C00@C00<04`000a<00`0C4`034`0301<0004C000Y4`801Q<20?lC

7a<00`0C4`0F4`0301<C00HC0`0>4`0401<C00PC0`0;4`802Q<00`0C4`0300@C0`024`0301<C00<C

0P014`400@0002/C00<04a<00Q<00`0C4`3o4alC00<04a<0L1<002XC00<04a<00a<00`0C4`054`03

01<C0?lC5Q<00`0C001a4`00:a<00`0C4`024`0301<C008C10034`<0oa<A4`8000<C0000L1<002TC

00<04`0011<00`0C00024`8000<C01<011<00`0C4`3o4h@C000Z4`0301<C00<C0`044`0301<000<C

00<04a<0oa>54`00=a<00`0C00044`0301<C0?lCQ1<003DC0`044`<0oa>64`00oa?54`00oa?54`00

oa?54`00oa?54`00oa?54`00\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.15215, -1.59703, 0.0211857, 0.0211857}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -84.5 0 ]

[.5 .96488 84.5 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -145.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.445) show

222.250000 19.500000 moveto

(C) show

227.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.25284 0 m

.26171 .01281 L

.30316 .0727 L

.34309 .1304 L

.3815 .18591 L

.42237 .24496 L

.46172 .30182 L

.49955 .35649 L

.53984 .41471 L

.57861 .47074 L

.61984 .53031 L

.65954 .58768 L

.69774 .64287 L

.73838 .70161 L

.77751 .75815 L

.81909 .81823 L

.85916 .87613 L

.89771 .93184 L

s

.89771 .93184 m

.91193 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.354276 0.238095 [

[.02381 .34178 -6 -9 ]

[.02381 .34178 6 0 ]

[.2619 .34178 -6 -9 ]

[.2619 .34178 6 0 ]

[.7381 .34178 -3 -9 ]

[.7381 .34178 3 0 ]

[.97619 .34178 -3 -9 ]

[.97619 .34178 3 0 ]

[1.025 .35428 0 -8 ]

[1.025 .35428 9 8 ]

[.4875 .11618 -12 -4.5 ]

[.4875 .11618 0 4.5 ]

[.4875 .23523 -24 -4.5 ]

[.4875 .23523 0 4.5 ]

[.4875 .47332 -18 -4.5 ]

[.4875 .47332 0 4.5 ]

[.4875 .59237 -6 -4.5 ]

[.4875 .59237 0 4.5 ]

[.4875 .71142 -18 -4.5 ]

[.4875 .71142 0 4.5 ]

[.4875 .83047 -6 -4.5 ]

[.4875 .83047 0 4.5 ]

[.5 .89656 -4.5 0 ]

[.5 .89656 4.5 16 ]

[.5 .88406 -137 0 ]

[.5 .88406 137 16 ]

[ 0 0 0 0 ]

[ 1 .87156 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .35428 m

.02381 .36053 L

s

[(-2)] .02381 .34178 0 1 Mshowa

.2619 .35428 m

.2619 .36053 L

s

[(-1)] .2619 .34178 0 1 Mshowa

.7381 .35428 m

.7381 .36053 L

s

[(1)] .7381 .34178 0 1 Mshowa

.97619 .35428 m

.97619 .36053 L

s

[(2)] .97619 .34178 0 1 Mshowa

.125 Mabswid

.07143 .35428 m

.07143 .35803 L

s

.11905 .35428 m

.11905 .35803 L

s

.16667 .35428 m

.16667 .35803 L

s

.21429 .35428 m

.21429 .35803 L

s

.30952 .35428 m

.30952 .35803 L

s

.35714 .35428 m

.35714 .35803 L

s

.40476 .35428 m

.40476 .35803 L

s

.45238 .35428 m

.45238 .35803 L

s

.54762 .35428 m

.54762 .35803 L

s

.59524 .35428 m

.59524 .35803 L

s

.64286 .35428 m

.64286 .35803 L

s

.69048 .35428 m

.69048 .35803 L

s

.78571 .35428 m

.78571 .35803 L

s

.83333 .35428 m

.83333 .35803 L

s

.88095 .35428 m

.88095 .35803 L

s

.92857 .35428 m

.92857 .35803 L

s

.25 Mabswid

0 .35428 m

1 .35428 L

s

gsave

1.025 .35428 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .11618 m

.50625 .11618 L

s

[(-1)] .4875 .11618 1 0 Mshowa

.5 .23523 m

.50625 .23523 L

s

[(-0.5)] .4875 .23523 1 0 Mshowa

.5 .47332 m

.50625 .47332 L

s

[(0.5)] .4875 .47332 1 0 Mshowa

.5 .59237 m

.50625 .59237 L

s

[(1)] .4875 .59237 1 0 Mshowa

.5 .71142 m

.50625 .71142 L

s

[(1.5)] .4875 .71142 1 0 Mshowa

.5 .83047 m

.50625 .83047 L

s

[(2)] .4875 .83047 1 0 Mshowa

.125 Mabswid

.5 .02094 m

.50375 .02094 L

s

.5 .04475 m

.50375 .04475 L

s

.5 .06856 m

.50375 .06856 L

s

.5 .09237 m

.50375 .09237 L

s

.5 .13999 m

.50375 .13999 L

s

.5 .1638 m

.50375 .1638 L

s

.5 .18761 m

.50375 .18761 L

s

.5 .21142 m

.50375 .21142 L

s

.5 .25904 m

.50375 .25904 L

s

.5 .28285 m

.50375 .28285 L

s

.5 .30666 m

.50375 .30666 L

s

.5 .33047 m

.50375 .33047 L

s

.5 .37809 m

.50375 .37809 L

s

.5 .40189 m

.50375 .40189 L

s

.5 .4257 m

.50375 .4257 L

s

.5 .44951 m

.50375 .44951 L

s

.5 .49713 m

.50375 .49713 L

s

.5 .52094 m

.50375 .52094 L

s

.5 .54475 m

.50375 .54475 L

s

.5 .56856 m

.50375 .56856 L

s

.5 .61618 m

.50375 .61618 L

s

.5 .63999 m

.50375 .63999 L

s

.5 .6638 m

.50375 .6638 L

s

.5 .68761 m

.50375 .68761 L

s

.5 .73523 m

.50375 .73523 L

s

.5 .75904 m

.50375 .75904 L

s

.5 .78285 m

.50375 .78285 L

s

.5 .80666 m

.50375 .80666 L

s

.5 .85428 m

.50375 .85428 L

s

.25 Mabswid

.5 0 m

.5 .87156 L

s

gsave

.5 .89656 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .88406 -198 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.445) show

298.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

303.000000 15.000000 moveto

(L) show

310.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

317.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

324.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

329.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

333.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .87156 L

0 .87156 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .1886 m

.02576 .1886 L

.03157 .18859 L

.04114 .18857 L

.05431 .18855 L

.07085 .18853 L

.09049 .18849 L

.11287 .18845 L

.13763 .1884 L

.16434 .18834 L

.19254 .18827 L

.22174 .18819 L

.25146 .18809 L

.28117 .18798 L

.31038 .18785 L

.33858 .18771 L

.36528 .18754 L

.39004 .18736 L

.41243 .18717 L

.43206 .18697 L

.44861 .18677 L

.46178 .1866 L

.47135 .18645 L

.47716 .18636 L

.47911 .18632 L

s

.47911 .18632 m

.48123 .18628 L

.48758 .18617 L

.49803 .18596 L

.5124 .18563 L

.53047 .18511 L

.5519 .1843 L

.57635 .18297 L

.60338 .18057 L

.63254 .17586 L

.66332 .16678 L

.69521 .1529 L

.72765 .13662 L

.76009 .11996 L

.79198 .10389 L

.82276 .08883 L

.85192 .07503 L

.87895 .06261 L

.90339 .0517 L

.92483 .04235 L

.94289 .03463 L

.95727 .02858 L

.96772 .02424 L

.97406 .02162 L

.97619 .02075 L

s

.47911 .4382 m

.48123 .4114 L

.48758 .38471 L

.49803 .35832 L

.5124 .33239 L

.53047 .30709 L

.5519 .28263 L

.57635 .25937 L

.60338 .23795 L

.63254 .21972 L

.66332 .20684 L

.69521 .19984 L

.72765 .19639 L

.76009 .19457 L

.79198 .1935 L

.82276 .19281 L

.85192 .19234 L

.87895 .19201 L

.90339 .19177 L

.92483 .1916 L

.94289 .19147 L

.95727 .19138 L

.96772 .19132 L

.97406 .19128 L

.97619 .19127 L

s

.47911 .43831 m

.48123 .46515 L

.48758 .49195 L

.49803 .51854 L

.5124 .54481 L

.53047 .57063 L

.5519 .59589 L

.57635 .62049 L

.60338 .64431 L

.63254 .66725 L

.66332 .68921 L

.69521 .71009 L

.72765 .72982 L

.76009 .74829 L

.79198 .76544 L

.82276 .78118 L

.85192 .79546 L

.87895 .8082 L

.90339 .81936 L

.92483 .82888 L

.94289 .83673 L

.95727 .84287 L

.96772 .84727 L

.97406 .84992 L

.97619 .85081 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<00`0C4`1`4`00oa=B4`0301<C070C001T4`D0j1<00`0C4`1`4`00IQ<00`0C4`3X4`03

01<C070C00114`033A<C01`C0`034`0301<C008C0P3T4`80Fa<33A<C00114`033A<C028C00<04a<0

0Q<00`0C4`3S4`0301<C05LC0`dF4`00@Q<00`dC4`0Q4`0301<C008C00<04a<0ha<00`0C4`1E4`8=

6A<004<C00<=4a<07a<200@C00<04a<0ha<00`0C4`1C4`8=6a<004<C00<=4a<09A<20>@C0P1B4`8=

7A<004@C00<=4a<091<00`0C4`3S4`0301<C04lC0PdO4`00AA<00`dC4`0S4`0301<C0><C00<04a<0

C1<33B4C00154`033A<C02<C00<04a<0ha<00`0C4`1:4`8=91<004HC00<=4a<08Q<20>@C00<04a<0

Aa<33BHC00164`033A<C028C00<04a<0ha<204HC0PdY4`00Aa<00`dC4`0Q4`0301<C0><C00<04a<0

@a<23B/C00184`033A<C020C00<04a<0ha<00`0C4`114`8=;A<004PC00<=4a<081<20>@C00<04a<0

?a<23BlC00194`033A<C01lC00<04a<0ha<00`0C4`0m4`8=<A<004XC00<=4a<07Q<00`0C4`3S4`80

?1<23C<C001;4`033A<C01dC00<04a<0ha<00`0C4`0i4`8==A<004/C00<=4a<07A<20>@C00<04a<0

=a<23CLC001<4`033A<C01`C00<04a<0g1<5008C00<04a<0=A<23CTC001=4`033A<C00`C00<04a<0

0Q<00`0C4`024`0301<C008C00<04a<0gQ<00`0C4`024`0301<C03<C0Pdk4`00CQ<00`dC4`0:4`03

01<000LC00<04`000a<00`0C4`3H4`<00a<00`0C4`024`80<Q<23CdC001>4`033A<C00DC0`024`03

01<000TC00@04a<C0P3O4`0301<C008C00<04a<0;a<23ClC001?4`033A<C00TC00<04`001a<200@C

00<04a<0gQ<00`0C4`024`0301<C02dC0Pe14`00D1<00`dC4`084`0301<000LC00<04a<00a<00`0C

4`3M4`8011<00`0C4`0[4`8=@a<0054C00<=4a<021<00`0C4`064`<00a<00`0C4`3S4`80:a<00`dC

4`134`00DA<00`dC4`0G4`0301<C0><C00<04a<0:1<23DHC001B4`033A<C01HC0P3T4`0301<C02HC

0Pe84`00Da<00`dC4`0E4`0301<C0><C00<04a<091<23DXC001C4`033A<C01DC00<04a<0ha<00`0C

4`0R4`8=C1<005@C00<=4a<051<00`0C4`3S4`808A<23DhC001E4`033A<C01<C0P3T4`0301<C01dC

0`e@4`00EQ<00`dC4`0B4`0301<C0><C00<04a<06A<43E<C000J4`<09A<500lC00<=4a<04Q<00`0C

4`0T4`D091<309<C00<04a<041<93ELC000J4`0301<C02LC00<04a<041<00`dC4`0A4`0301<C02HC

00<04a<091<00`0C4`2C4`0301<=010=H1<001DC0`034`0301<C020C0`034`0301<C014C00<=4a<0

41<202LC00<04a<09A<00`0C4`0c4f4=LA<001/C00<04a<09Q<00`0C4`0A4`033A<C010C00<04a<0

9Q<00`0C4`0U4`0301<C098C00<04a<0;Q<_3A<C000J4`0301<002LC00<04a<04Q<00`dC4`0?4`03

01<C02HC00<04a<091<00`0C002C4`0301<C02<C2`e24`006a<00`0C4`0U4`805A<00`dC4`0>4`03

01<C02DC0P0W4`0301<C098C00<04a<081<33DdC001J4`033A<C00hC0P3T4`0301<C01dC0`e@4`00

Fa<00`dC4`0=4`0301<C0><C0P0J4`@=Da<005`C00<=4a<031<00`0C4`1K4`80QQ<00`0C4`0G4`8=

Ea<005dC00<=4a<02a<00`0C4`1J4`0301<C07LC00<04a<00Q<00`0C4`024`0301<C008C00<04a<0

5Q<00`dC4`1G4`005A=800033@0006801Q<00`0C4`1f4`0301<000LC00<04`000a<00`0C4`0D4`8=

FQ<001TC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<0

1Q<00`0C4`054`0401<C3@@C00<04a<01A<00a0C4`054`0301<C00HC00<04a<01A<00`0C4`054`03

01<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00PC00<04a<0

LA<3008C00<04`002A<0100C4a<201@C00<=4a<0FQ<005lC00<=4a<02A<00a0C4`1J4`0301<007HC

00<04`001a<200@C00<04a<04Q<00`dC4`1K4`00Ga<00`dC4`094`8@Fa<307HC00<04`001a<00`0C

4`034`0301<C010C0PeN4`00H1<00`dC4`084`8@eA<00`0C4`064`<00a<00`0C4`0?4`033A<C05hC

001Q4`033A<C00HC00<@0100i1<00`0C4`0=4`8=HA<0064C00<=4a<01Q<00a00403T4`803A<00`dC

4`1Q4`00HQ<00`dC4`054`03400@0>@C00<04a<02a<00`dC4`1R4`00Ha<00`dC4`034`0541<00100

ha<00`0C4`0:4`033A<C06<C001T4`033A<C008C00D@4`0C403S4`0301<C00TC00<=4a<0I1<006@C

00<=4a<00Q<01A0C01<@0><C00<04a<021<00`dC4`1U4`00IA<01`dC4a<@4`000Q<00a0C4`3P4`80

21<00`dC4`1V4`00IQ<01@dC4a0C008000<C41<0hA<00`0C4`064`033A<C06LC001V4`063A<C41<0

0Q<00a0C4`3P4`0301<C00DC00<=4a<0J1<006LC00D=41<C00034`0341<C084C0`0/4`D0:Q<00`0C

4`054`033A<C028C1@0[4`<04a<006PC00@=4a<00a<00a0C4`214`0301<C02hC00<04a<0:Q<200DC

00<=4a<09A<00`0C4`0[4`0301<C01<C001X4`033A<C00800Q<00a0C4`1l4`<00a<00`0C4`0W4`<0

0a<00`0C4`0Z4`0301<C00<C00<=4a<09Q<00`0C4`0/4`0301<C018C001W4`0541<=4`0011<00a0C

4`214`0301<C02dC00<04a<0:Q<00`0C4`024`033A<C02LC00<04a<0;1<00`0C4`0B4`00G1<00`0C

4`024`0301<C008C00H041<C3@044`0341<C080C00<04`00;Q<00`0C4`0Z4`0301<C008C00<=4a<0

9a<00`0C4`0[4`0301<001<C001K4`0301<000LC00<040000Q<00`d04`034`0341<C084C00<04a<0

;1<202`C00D04a<C3@0Y4`80;Q<00`0C4`0B4`00Fa<00`0C00084`03400C008C00<=01<00a<00a0C

4`3M4`800Q<00`dC4`1/4`00Fa<00`0C00074`03010C00<C00<03A<00a<00a0C4`3M4`0401<C3FlC

001K4`0301<000LC00<@4a<00a<00`0=4`044`0341<C0=`C00<04`d0L1<005`C00<04a<01Q<00a00

00034`0301<=00@C00<@4a<0g1<00`0C3@1Y4`801A<006@C00<@4a<011<200034`dC008C00<@4a<0

g1<00`0=4`1X4`0301<C00DC001T4`0341<C00@C00@04a<=11<00a0C4`1h4f@000<=0000H0074`03

01<C00DC001S4`0341<C00DC00D04a<C3@034`0341<C07`C00<04a<01a<00`0C4`064`0301<C00LC

00<04a<01Q<00`0C4`074`0301<C00HC00<04a<01a<00`0C4`064`0301<C00LC00<04a<01Q<00`dC

4`074`0301<C00HC00<04a<01Q<00`0C4`074`0301<C00HC00<04a<01a<00`0C4`064`0301<C00LC

00<04a<01Q<00`0C4`074`0301<C00TC00<04a<01A<006<C00<@4a<01A<00`0C4`024`053A<C4a00

g1<00`dC4`1X4`0301<000DC001R4`0341<C00HC00<04a<00a<010dC4a3K4`033@0C06TC0`054`00

HQ<00a0C4`064`8011<01@dC4a<@0=XC00<=01<0LA<0064C00<@4a<01a<00`0C4`044`043A<C4=TC

00@=4`00LA<0064C00<@4a<01a<00`0C4`054`033A<@0=TC00<=4`00LQ<0060C00<@4a<021<00`0C

4`054`043A<C4=PC00<=4`00LQ<0060C00<@4a<021<200LC00<=4a00ea<010dC4`1b4`00Ga<00a0C

4`094`0301<C00LC00<=4a00eQ<00`dC4`02074C001O4`0341<C00TC00<04a<01a<00`dC403E4`05

3A<C4`00LQ<005hC00<@4a<02Q<00`0C4`084`033A<@0=@C00D=4a<C001b4`00GQ<00a0C4`0:4`80

2Q<00`d@4`3C4`053A<C4`00LQ<005dC00<@4a<02a<00`0C4`0:4`033A0C0=8C00D=4a<C001b4`00

GA<00a0C4`044`D00Q<00`0C4`0:4`033A0C0=8C00@=4a<C0P1a4`00G1<00a0C4`074`0301<C008C

00<04a<02a<00`d@4`3A4`053A<C4`00LQ<005/C00<@4a<021<00`0C4`024`803A<00`d@4`3@4`05

3A<C4`00LQ<005/C00<@4a<021<00`0C4`024`0301<C00`C00<=41<0d1<01@dC4a<0078C001J4`03

41<C00TC00<04a<00Q<00`0C4`0=4`033A0C0<lC00D=4a<C001b4`00FQ<00a0C4`084`8011<00`0C

4`0>4`033A0C0<hC00@=4a<C0P1a4`00FA<00a0C4`0?4`803a<00`d@4`3>4`053A<C4`00LQ<005PC

00<@4a<041<00`0C4`0?4`033A0C0<dC00D=4a<C001b4`00F1<00a0C4`0@4`0301<C010C00<=41<0

`A<00`0C4`024`0301<C008C00<03A<00Q<00`0C4`1`4`00Ea<00a0C4`0A4`0301<C014C00<=4a<0

_a<00`0C00074`0301<=00<C00<04a<0L1<005HC00<@4a<04Q<2018C00<=41<0_a<00`0C00094`04

00dC4`80LA<005HC00<@4a<04Q<00`0C4`0B4`033A0C0;hC00<04`001a<200054`dC4`00LQ<005DC

00<@4a<04a<00`0C4`0C4`033A<C0;dC00<04`001a<01`0C4a<=4`00LQ<005@C00<@4a<051<00`0C

4`0C4`033A0C0;hC00<04a<01Q<300044`dC078C001C4`0341<C01DC0P0E4`033A<C0<XC00@=4`00

LA<005<C00<@4a<05A<00`0C4`0E4`033A<C0<XC00<=01<0LA<0058C00<@4a<05Q<00`0C4`0E4`03

3A0C0<XC00<=01<0LA<0054C00<@4a<05a<00`0C4`0F4`033A<C0<TC00<=01<0LA<0054C00<@4a<0

5a<201PC00<=4a<0bA<00`dC4`1`4`00D1<00a0C4`0H4`0301<C01LC00<@3A<0bA<00`d04`1`4`00

Ca<00a0C4`084`D00Q<00`0C4`024`0301<C008C00<04a<061<00`dC4`384`0300dC070C001?4`03

41<C00XC00<04a<01Q<00`0C00034`0301<C01TC00<=4a<0aa<00`0=4`1`4`00CQ<00a0C4`0;4`03

01<C00PC00@04a<C0P0K4`033A<C0<HC00<04`d0L1<004dC00<@4a<031<00`0C4`064`8011<00`0C

4`0J4`033A<C0<HC00<04`d0L1<004`C00<@4a<03A<00`0C4`064`0301<C00<C00<04a<06a<00`dC

4`354`8000<C3A<0KQ<004`C00<@4a<031<200PC0`034`0301<C01`C00<=4a<0a1<01@0C4a<=06hC

001;4`0341<C01dC0P0M4`033A0C0<@C00D04a<C3@1^4`00BQ<00a0C4`0N4`0301<C01dC00<=4a<0

`a<00`0C4`024`033A<C06/C001:4`0341<C01hC00<04a<07Q<00`dC4`324`0301<C008C00<=4a<0

Ja<004TC00<@4a<07a<00`0C4`0N4`033A0C0<8C0P044`033A<C06XC00184`0341<C020C0P0P4`03

3A0C0<4C00<04a<011<00`dC4`1Y4`00Aa<00a0C4`0Q4`0301<C020C00<=41<0^A<5008C00<04a<0

1A<00`dC4`1X4`00Aa<00a0C4`0Q4`0301<C020C00<=41<0^a<00`0C4`024`0301<C00DC00<=4a<0

J1<004HC00<@4a<08Q<00`0C4`0Q4`033A0C0;XC00<04a<00Q<200LC00<=4a<0Ia<004DC00<@4a<0

8a<202<C00<=41<0^A<00`0C4`024`0301<C00LC00<=4a<0IQ<004@C00<@4a<091<00`0C4`0R4`03

3A<@0;TC00<04a<00Q<00`0C4`084`033A<C06DC00144`0341<C02@C00<04a<08a<00`d@4`2g4`80

11<00`0C4`094`033A<C06@C00134`0341<C02DC00<04a<091<00`d@4`2l4`0301<C00XC00<=4a<0

Ha<0048C00<@4a<09Q<00`0C4`0U4`033A0C0;/C0P0<4`033A<C068C00114`0341<C02LC0P0V4`03

3A<@0;/C00<04a<031<00`dC4`1Q4`00@1<00a0C4`0X4`0301<C02HC00<=4a00^Q<00`0C4`0=4`03

3A<C060C00104`0341<C028C0`034`0301<C02LC00<=4a00^A<00`0C4`0>4`033A<C05lC000o4`03

41<C02<C00<04a<00a<00`0C4`0W4`033A<@0;TC00<04a<03a<23ElC000n4`0341<C02DC00<04a<0

0Q<202TC00<=4a00^1<2018C00<=4a<0G1<003dC00<@4a<09Q<00`0C4`024`0301<C02TC00<=4a00

]a<00`0C4`0B4`033A<C05/C000m4`0341<C02DC00<04`000a<00`0C4`0Y4`043A<C4;HC00<04a<0

4a<00`dC4`1J4`00?1<00a0C4`0W4`0301<C008C00<04a<0:Q<010dC4a2e4`0301<C01@C0PeJ4`00

>a<00a0C4`0]4`80;1<010dC4a2d4`805a<00`dC4`1G4`00>Q<00a0C4`0^4`0301<C02`C00<=4a00

]1<00`0C4`0G4`033A<C05HC000j4`0341<C02hC00<04a<0;1<010dC4a2c4`0301<C01PC0PeF4`00

>A<00a0C4`0_4`0301<C02dC00@=4a<@/Q<00`0C4`0J4`8=E1<003PC00<@4a<0<1<202lC00@=4a<@

/A<00`0C4`0L4`8=DQ<003LC00<@4a<0<A<00`0C4`0^4`043A<C4;4C0P0O4`033A<C04lC000g4`03

41<C034C00<04a<0;a<010dC4a2`4`0301<C01lC00<=4a<0CQ<003HC00<@4a<0<Q<00`0C4`0`4`04

3A<C4:lC00<04a<081<00`dC4`1=4`00=A<00a0C4`0c4`80<A<01@dC4a<@09dC1@024`0301<C008C

00<04a<00Q<00`0C4`0Q4`8=CA<003@C00<@4a<0=1<00`0C4`0a4`053A<C4a00WQ<00`0C4`064`03

01<000<C00<04a<08a<00`dC4`1:4`00<a<00a0C4`0e4`0301<C034C00<=4a<00Q<00a0C4`2K4`03

01<C00PC00@04a<C0P0U4`033A<C04TC000b4`0341<C03HC00<04a<0<Q<01@dC4a<@09dC00<04a<0

1Q<200@C00<04a<09A<23DTC000a4`0341<C03LC0P0d4`053A<C4a00W1<00`0C4`064`0301<C00<C

00<04a<09a<00`dC4`164`00<1<00a0C4`0h4`0301<C03<C00<=4a<00Q<00a0C4`2H4`8021<300<C

00<04a<0:1<23DHC000_4`0341<C02TC0`034`0301<C008C00<04a<00Q<00`0C4`0d4`033A<C008C

00<@4a<0Ya<00`0C4`0Z4`8=A1<002hC00<@4a<0:Q<00`0C4`074`0301<000<C00<04a<0=A<00`dC

4`024`0341<C0:HC0P0]4`8=@Q<002dC00<@4a<0;1<00`0C4`084`0401<C4`80=a<00`dC4`024`03

41<C0:DC00<04a<0;Q<23D0C000/4`0341<C02dC00<04a<01Q<200@C00<04a<0=Q<00`dC4`034`03

41<C0:@C00<04a<0<1<23ChC000[4`0341<C02dC00<04`001a<00`0C4`034`0301<C03LC00<=4a<0

0a<00a0C4`2S4`0301<C038C0Pdl4`00:Q<00a0C4`0_4`0301<C00HC0`034`0301<C03PC00<=4a<0

0a<00a0C4`2R4`80=A<00`dC4`0i4`00:A<00a0C4`0o4`80>Q<00`dC4`034`0341<C0:4C00<04a<0

=A<23CTC000X4`0341<C040C00<04a<0>A<00`dC4`044`0341<C0:0C00<04a<0=a<00`dC4`0f4`00

9a<00a0C4`114`0301<C03XC00<=4a<011<00a0C4`2O4`0301<C03PC0Pdf4`009Q<00a0C4`124`03

01<C03/C00<=4a<011<00a0C4`2N4`0301<C03XC0Pdd4`009A<00a0C4`134`80?A<00`dC4`044`03

41<C09dC0P0m4`8=<Q<002@C00<@4a<0A1<00`0C4`0l4`033A<C00DC00<@4a<0W1<00`0C4`0n4`8=

<1<002<C00<@4a<0AA<00`0C4`0m4`033A<C00DC00<@4a<0Va<00`0C4`104`8=;Q<002<C00<@4a<0

AA<00`0C4`0m4`033A<C00HC00<@4a<0VQ<00`0C4`124`<=:a<0028C00<@4a<0AQ<203lC00<=4a<0

1Q<00a0C4`2I4`0301<C04DC0PdY4`008A<00a0C4`174`0301<C03lC00<=4a<01Q<00a0C4`2H4`80

B1<33BHC000P4`0341<C04PC00<04a<0?a<00`dC4`074`0341<C09LC00<04a<0BQ<23B@C000O4`03

41<C04TC00<04a<0@1<00`dC4`074`0341<C09HC00<04a<0C1<23B8C000N4`0341<C04XC0P114`03

3A<C00PC00<@4a<0Sa<300<C00<04a<0CQ<23B0C000M4`0341<C04/C00<04a<0@A<00`dC4`084`03

41<C08hC00<04a<00a<00`0C4`1@4`8=7Q<001`C00<@4a<0C1<00`0C4`124`033A<C00PC00<@4a<0

SQ<00`0C4`024`80Da<23A`C000K4`0341<C04LC0P044`0301<C048C00<=4a<02A<00a0C4`2=4`03

01<C008C00<04a<0E1<33ATC000J4`0341<C04XC00D04a<C00154`033A<C00TC00<@4a<0Ra<00`0C

00034`0301<C05LC0PdG4`006A<00a0C4`1:4`0301<C008C0P154`033A<C00PC00<@4a<0S1<00`0C

4`024`0301<C05TC0`dD4`00Ia<00`0C4`3W4`80GA<00`dC4`0A4`00IA<00`0C003Y4`0301<C070C

001V4`0301<C0>PC00<04a<0L1<002XC0`3o4bDC00<04a<0L1<002XC00<04a<0oa<U4`0301<C070C

000[4`0301<C00@C00<04a<0oa>@4`00:a<0100C4a<400<C0`3o4h`C000Z4`0301<0008C0P000a<0

4`044`0301<C0?lCRQ<002/C00<04a<00a<00`0C00034`0301<C0?lCRa<0034C00<04`0011<00`0C

4`064`0301<C02LC0`0[4`0301<C0?lC:A<001/C0`000a<0000200`C0`044`<021<00`0C4`0V4`04

01<C00lC0`000a<00002008C00<04a<00Q<00`0C4`024`0301<C00DC00@04a<C1@024`0301<C008C

0`024`<00Q<00`0C4`044`80aA<00`0C4`0g4`0301<C00HC000J4`0401<C02@C00<04a<09A<0100C

4`0>4`0401<C00HC00<04`001a<00`0C00044`D00a<00`0C4`084`0301<C008C00H04a<04`044`03

01<C0;dC00<04a<011<00`0C4`0C4`0301<C02<C00<04a<01A<001XC00D04a<04`0400034`0001P0

;A<300hC00D04a<04`0400044`0C00TC00<04a<011<00`0C4`034`0301<C00HC10000a<0000200<C

00<04a<00Q<00`0C4`2[4`0401<C4`@00Q<200HC00<04a<00a<00`0C4`024`0301<C008C00<04a<0

0Q<00`0C4`054`0401<C4`D00Q<00`0C4`024`<00Q<3008C00<04a<011<200@C00@04a<C0P014`00

6a<304lC00<04a<03A<300HC00<04`001a<200LC00<04a<00a<00`0C4`064`0301<0008C00<04`00

0Q<200DC00<04a<0ZQ<00`0C00074`0301<C00@C1@034`0701<C4`0C00074`0301<000@C1@034`03

01<C00PC00<04a<00Q<01P0C4`0C00@C00<04a<011<00`0C4`024`400A<001dC00<04a<0C1<2014C

00<04a<011<00`0C00074`0301<C00`C00<04a<01a<200<C0P024`0301<C00@C00<04`00ZQ<00`0C

00024`@000<C01<01a<00`0C4`034`0701<C4`0C00094`0301<C00@C00<04a<00a<00`0C4`064`@0

00<C00000P034`0301<C008C00<04a<011<00`0C4`034`40000L4`80H1<200LC00<04a<01Q<300/C

0P0:4`0301<C008C00<04a<00`044`<0Ta<200034`00018C00<04`001a<00`0C4`064`0301<C00<C

00L04a<C01<000LC0P074`0301<C00<C00<04a<01Q<00`0C00024`0301<0008C0P054`0301<C00@C

00<04a<00a<10000oa=A4`0301<001<C00<04`001a<00`0C000=4`0601<C01<01a<00`0C4`0<4`03

01<C00LC0P034`800Q<00`0C4`044`0301<000<C00<04a<00a<1004C000V4`801Q<20?lC8Q<00`0C

4`0C4`0301<C00HC0`0>4`0401<C00PC0`0;4`802Q<00`0C4`024`0301<C00<011<3008C00<04a<0

0a<2004C000X4`0301<C008C00<04a<0oa<R4`0301<C070C000W4`0301<C00<C00<04a<01Q<00`0C

4`3o4aPC00<04`00LA<002PC00<04a<00Q<00`0C4`024`<000@C01<C0`3o4a@C0P000a<0001`4`00

9Q<00`0C00044`0301<0008C0P024`0301<C008C00<04a<0oa>74`009a<00`0C4`034`<011<0100C

4`024`0301<C0?lCR1<003@C00@04a<00a<00`0C4`3o4hLC000b4`<011<30?lCRA<00?lCaA<00?lC

aA<00?lCaA<00?lCaA<00?lCaA<00001\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.13679, -1.59104, 0.0211402, 0.0211402}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -82 0 ]

[.5 .96488 82 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -143 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.44) show

217.250000 19.500000 moveto

(C) show

222.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.25198 0 m

.26171 .014 L

.30316 .07369 L

.34309 .13119 L

.3815 .1865 L

.42237 .24535 L

.46172 .30201 L

.49955 .3565 L

.53984 .41451 L

.57861 .47034 L

.61984 .52971 L

.65954 .58689 L

.69774 .64188 L

.73838 .70041 L

.77751 .75676 L

.81909 .81664 L

.85916 .87433 L

.89771 .92985 L

s

.89771 .92985 m

.91336 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.352886 0.238095 [

[.02381 .34039 -6 -9 ]

[.02381 .34039 6 0 ]

[.2619 .34039 -6 -9 ]

[.2619 .34039 6 0 ]

[.7381 .34039 -3 -9 ]

[.7381 .34039 3 0 ]

[.97619 .34039 -3 -9 ]

[.97619 .34039 3 0 ]

[1.025 .35289 0 -8 ]

[1.025 .35289 9 8 ]

[.4875 .11479 -12 -4.5 ]

[.4875 .11479 0 4.5 ]

[.4875 .23384 -24 -4.5 ]

[.4875 .23384 0 4.5 ]

[.4875 .47193 -18 -4.5 ]

[.4875 .47193 0 4.5 ]

[.4875 .59098 -6 -4.5 ]

[.4875 .59098 0 4.5 ]

[.4875 .71003 -18 -4.5 ]

[.4875 .71003 0 4.5 ]

[.4875 .82908 -6 -4.5 ]

[.4875 .82908 0 4.5 ]

[.5 .89461 -4.5 0 ]

[.5 .89461 4.5 16 ]

[.5 .88211 -134.5 0 ]

[.5 .88211 134.5 16 ]

[ 0 0 0 0 ]

[ 1 .86961 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .35289 m

.02381 .35914 L

s

[(-2)] .02381 .34039 0 1 Mshowa

.2619 .35289 m

.2619 .35914 L

s

[(-1)] .2619 .34039 0 1 Mshowa

.7381 .35289 m

.7381 .35914 L

s

[(1)] .7381 .34039 0 1 Mshowa

.97619 .35289 m

.97619 .35914 L

s

[(2)] .97619 .34039 0 1 Mshowa

.125 Mabswid

.07143 .35289 m

.07143 .35664 L

s

.11905 .35289 m

.11905 .35664 L

s

.16667 .35289 m

.16667 .35664 L

s

.21429 .35289 m

.21429 .35664 L

s

.30952 .35289 m

.30952 .35664 L

s

.35714 .35289 m

.35714 .35664 L

s

.40476 .35289 m

.40476 .35664 L

s

.45238 .35289 m

.45238 .35664 L

s

.54762 .35289 m

.54762 .35664 L

s

.59524 .35289 m

.59524 .35664 L

s

.64286 .35289 m

.64286 .35664 L

s

.69048 .35289 m

.69048 .35664 L

s

.78571 .35289 m

.78571 .35664 L

s

.83333 .35289 m

.83333 .35664 L

s

.88095 .35289 m

.88095 .35664 L

s

.92857 .35289 m

.92857 .35664 L

s

.25 Mabswid

0 .35289 m

1 .35289 L

s

gsave

1.025 .35289 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .11479 m

.50625 .11479 L

s

[(-1)] .4875 .11479 1 0 Mshowa

.5 .23384 m

.50625 .23384 L

s

[(-0.5)] .4875 .23384 1 0 Mshowa

.5 .47193 m

.50625 .47193 L

s

[(0.5)] .4875 .47193 1 0 Mshowa

.5 .59098 m

.50625 .59098 L

s

[(1)] .4875 .59098 1 0 Mshowa

.5 .71003 m

.50625 .71003 L

s

[(1.5)] .4875 .71003 1 0 Mshowa

.5 .82908 m

.50625 .82908 L

s

[(2)] .4875 .82908 1 0 Mshowa

.125 Mabswid

.5 .01955 m

.50375 .01955 L

s

.5 .04336 m

.50375 .04336 L

s

.5 .06717 m

.50375 .06717 L

s

.5 .09098 m

.50375 .09098 L

s

.5 .1386 m

.50375 .1386 L

s

.5 .16241 m

.50375 .16241 L

s

.5 .18622 m

.50375 .18622 L

s

.5 .21003 m

.50375 .21003 L

s

.5 .25765 m

.50375 .25765 L

s

.5 .28146 m

.50375 .28146 L

s

.5 .30527 m

.50375 .30527 L

s

.5 .32908 m

.50375 .32908 L

s

.5 .3767 m

.50375 .3767 L

s

.5 .40051 m

.50375 .40051 L

s

.5 .42431 m

.50375 .42431 L

s

.5 .44812 m

.50375 .44812 L

s

.5 .49574 m

.50375 .49574 L

s

.5 .51955 m

.50375 .51955 L

s

.5 .54336 m

.50375 .54336 L

s

.5 .56717 m

.50375 .56717 L

s

.5 .61479 m

.50375 .61479 L

s

.5 .6386 m

.50375 .6386 L

s

.5 .66241 m

.50375 .66241 L

s

.5 .68622 m

.50375 .68622 L

s

.5 .73384 m

.50375 .73384 L

s

.5 .75765 m

.50375 .75765 L

s

.5 .78146 m

.50375 .78146 L

s

.5 .80527 m

.50375 .80527 L

s

.5 .85289 m

.50375 .85289 L

s

.25 Mabswid

.5 0 m

.5 .86961 L

s

gsave

.5 .89461 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .88211 -195.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.44) show

293.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

298.000000 15.000000 moveto

(L) show

305.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

312.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

319.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

324.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

328.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .86961 L

0 .86961 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .18678 m

.02576 .18677 L

.03157 .18677 L

.04114 .18676 L

.05431 .18674 L

.07085 .18672 L

.09048 .18669 L

.11287 .18665 L

.13763 .18661 L

.16433 .18656 L

.19253 .1865 L

.22173 .18643 L

.25145 .18635 L

.28116 .18626 L

.31036 .18615 L

.33856 .18603 L

.36526 .18589 L

.39002 .18574 L

.41241 .18558 L

.43204 .18541 L

.44858 .18525 L

.46175 .1851 L

.47133 .18497 L

.47713 .18489 L

.47908 .18487 L

s

.47908 .18487 m

.48121 .18484 L

.48755 .18474 L

.498 .18456 L

.51238 .18428 L

.53045 .18385 L

.55188 .18317 L

.57633 .18204 L

.60336 .17999 L

.63252 .17582 L

.66331 .16721 L

.69519 .15337 L

.72764 .13694 L

.76008 .12015 L

.79197 .10399 L

.82275 .08888 L

.85191 .07504 L

.87895 .0626 L

.90339 .05167 L

.92483 .04231 L

.94289 .03459 L

.95727 .02854 L

.96772 .02419 L

.97406 .02158 L

.97619 .0207 L

s

.47908 .43684 m

.48121 .41006 L

.48755 .38337 L

.498 .35698 L

.51238 .33103 L

.53045 .30567 L

.55188 .28112 L

.57633 .25769 L

.60336 .23595 L

.63252 .21722 L

.66331 .2039 L

.69519 .19689 L

.72764 .19362 L

.76008 .19196 L

.79197 .191 L

.82275 .19039 L

.85191 .18998 L

.87895 .18969 L

.90339 .18949 L

.92483 .18933 L

.94289 .18922 L

.95727 .18914 L

.96772 .18909 L

.97406 .18906 L

.97619 .18905 L

s

.47908 .43695 m

.48121 .46377 L

.48755 .49055 L

.498 .51711 L

.51238 .54335 L

.53045 .56914 L

.55188 .59437 L

.57633 .61893 L

.60336 .64271 L

.63252 .66562 L

.66331 .68755 L

.69519 .7084 L

.72764 .7281 L

.76008 .74655 L

.79197 .76367 L

.82275 .77939 L

.85191 .79364 L

.87895 .80636 L

.90339 .8175 L

.92483 .82701 L

.94289 .83485 L

.95727 .84098 L

.96772 .84537 L

.97406 .84802 L

.97619 .8489 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<00`0C4`1`4`00oa=B4`0301<C070C001T4`D0j1<00`0C4`1`4`00IQ<00`0C4`3X4`80

LA<0044C00<=4a<071<300<C00<04a<00Q<20>@C00<04a<0FQ<33A<C00114`033A<C028C00<04a<0

0Q<00`0C4`3S4`0301<C05LC0`dF4`00@Q<00`dC4`0Q4`0301<C008C00<04a<0ha<00`0C4`1E4`8=

6A<004<C00<=4a<07a<200@C00<04a<0ha<00`0C4`1C4`8=6a<004<C00<=4a<09A<20>@C0P1B4`8=

7A<004@C00<=4a<091<00`0C4`3S4`0301<C04lC0PdO4`00AA<00`dC4`0S4`0301<C0><C00<04a<0

CA<23B4C00154`033A<C02<C00<04a<0ha<00`0C4`1;4`8=8a<004HC00<=4a<08Q<20>@C00<04a<0

BA<23BDC00164`033A<C028C00<04a<0ha<204PC0PdW4`00Aa<00`dC4`0Q4`0301<C0><C00<04a<0

AA<23BTC00184`033A<C020C00<04a<0ha<00`0C4`124`<=:a<004PC00<=4a<081<20>@C00<04a<0

?a<33BhC00194`033A<C01lC00<04a<0ha<00`0C4`0m4`8=<A<004XC00<=4a<07Q<00`0C4`3S4`80

?1<23C<C001:4`033A<C01hC00<04a<0ha<00`0C4`0i4`8==A<004/C00<=4a<07A<20=dC1@024`03

01<C03LC0Pdg4`00C1<00`dC4`0L4`0301<C0=hC00<04a<00Q<00`0C4`0e4`8=>A<004`C00<=4a<0

3A<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`3H4`<00a<00`0C4`024`80=1<23C/C001=4`03

3A<C00/C00<04`001a<00`0C00034`0301<C0=hC00<04a<00Q<00`0C4`0a4`8=?A<004hC00<=4a<0

1A<3008C00<04`002A<0100C4a<20=lC00<04a<00Q<00`0C4`0_4`8=?a<004lC00<=4a<02A<00`0C

00074`8011<00`0C4`3M4`8011<00`0C4`0]4`8=@A<004lC00<=4a<02A<00`0C00074`0301<C00<C

00<04a<0ha<00`0C4`0[4`8=@a<0050C00<=4a<02A<00`0C4`064`<00a<00`0C4`3S4`80:a<00`dC

4`134`00DA<00`dC4`0G4`0301<C0><C00<04a<0:1<23DHC001B4`033A<C01HC0P3T4`0301<C02HC

0Pe84`00DQ<00`dC4`0F4`0301<C0><C00<04a<091<23DXC001C4`033A<C01DC00<04a<0ha<00`0C

4`0R4`8=C1<005@C00<=4a<051<00`0C4`3S4`808A<23DhC001E4`033A<C01<C0P3T4`0301<C01dC

0`e@4`00EA<00`dC4`0C4`0301<C0><C00<04a<06A<43E<C000J4`<09A<500lC00<=4a<04Q<00`0C

4`0T4`D091<309<C00<04a<041<93ELC000J4`0301<C02LC00<04a<041<00`dC4`0A4`0301<C02HC

00<04a<091<00`0C4`254b4=H1<001DC0`034`0301<C020C0`034`0301<C014C00<=4a<041<202LC

00<04a<09A<00`0C4`0c4e4=3Q<203`C8PdC4`006a<00`0C4`0V4`0301<C014C00<=4a<041<00`0C

4`0V4`0301<C02DC00<04a<0TQ<00`0C4`0X4a<==A<001XC00<04`009a<00`0C4`0B4`033A<C00lC

00<04a<09Q<00`0C4`0T4`0301<009<C00<04a<08Q<63DPC000K4`0301<C02DC0P0E4`033A<C00hC

00<04a<09A<202LC00<04a<0TQ<00`0C4`0M4`D=CQ<005XC00<=4a<03Q<20>@C0P0L4`8=Da<005/C

00<=4a<03A<00`0C4`3S4`0301<C01TC0PeE4`00G1<00`dC4`0<4`0301<C05/C0P264`0301<C01LC

0PeG4`00GA<00`dC4`0;4`0301<C05XC00<04a<0Ma<00`0C4`024`0301<C008C00<04a<00Q<00`0C

4`0F4`033A<C05LC000E4dP000<=0000HP064`0301<C07HC00<04`001a<00`0C00034`0301<C01@C

0PeJ4`006A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C

4`064`0301<C00DC00@04a<=11<00`0C4`054`0341<C00DC00<04a<01Q<00`0C4`054`0301<C00DC

00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<021<00`0C

4`1a4`<00Q<00`0C00094`0401<C4`8051<00`dC4`1J4`00Ga<00`dC4`094`0341<C05XC00<04`00

MQ<00`0C00074`8011<00`0C4`0B4`033A<C05/C001O4`033A<C00TC0Q1K4`<0MQ<00`0C00074`03

01<C00<C00<04a<041<23EhC001P4`033A<C00PC0Q3E4`0301<C00HC0`034`0301<C00lC00<=4a<0

GQ<0064C00<=4a<01Q<00a00403T4`0301<C00dC0PeQ4`00HA<00`dC4`064`03400@0>@C0P0=4`03

3A<C064C001R4`033A<C00DC00<@0100i1<00`0C4`0;4`033A<C068C001S4`033A<C00<C00D@4`00

403S4`0301<C00XC00<=4a<0Ha<006@C00<=4a<00Q<01A0C01<@0><C00<04a<02A<00`dC4`1T4`00

I1<00`dC4`024`0541<04a00ha<00`0C4`084`033A<C06DC001U4`073A<C4a0C00024`0341<C0>0C

0P084`033A<C06HC001V4`053A<C41<00P000a<@4`3Q4`0301<C00HC00<=4a<0Ia<006HC00H=4a<@

4`024`0341<C0>0C00<04a<01A<00`dC4`1X4`00Ia<01@d@4a<000<C00<@4a<0PA<302`C1@0Z4`03

01<C00@C00<=4a<08a<502/C0`0C4`00J1<010dC4`034`0341<C084C00<04a<0;Q<00`0C4`0Z4`80

11<00`dC4`0V4`0301<C02/C00<04a<04a<006PC00<=4a<00P024`0341<C07`C0`034`0301<C02LC

0`034`0301<C02XC00<04a<00Q<00`dC4`0W4`0301<C02`C00<04a<04Q<006LC00D@4`dC00044`03

41<C084C00<04a<0;A<00`0C4`0Z4`0301<C008C00<=4a<09a<00`0C4`0/4`0301<C018C001L4`03

01<C008C00<04a<00Q<01P0@4a<=00@C00<@4a<0P1<00`0C000^4`0301<C02XC00D04a<C3@0Z4`03

01<C02/C00<04`004a<005/C00<04`001a<00`0@00024`033@0C00<C00<@4a<0PA<00`0C4`0/4`80

;1<01@0C4a<=02TC0P0^4`0301<C018C001K4`0301<000PC00<@01<00Q<00`d04`034`0341<C0=dC

0P000a<=4`1^4`00Fa<00`0C00074`03010C00<C00<03A<00a<00a0C4`3M4`0301<=070C001K4`03

01<000LC00<@4a<00a<00`0=4`044`0341<C0=`C00<04`d0L1<005`C00<04a<01Q<00a0000034`03

01<=00@C00<@4a<0g1<00`0=4`1Z4`8011<006@C00<@4a<011<200034`dC008C00<@4a<0g1<00`0=

4`1Y4`0301<C00@C001T4`0341<C00@C00@04a<=11<00a0C4`1h4f<000<=0000HP074`0301<C00@C

001S4`0341<C00DC00D04a<C3@034`0341<C07`C00<04a<01a<00`0C4`064`0301<C00LC00<04a<0

1Q<00`0C4`074`0301<C00HC00<04a<01a<00`0C4`064`0301<C00LC00<04a<01Q<00`dC4`074`03

01<C00HC00<04a<01a<00`0C4`064`0301<C00LC00<04a<01Q<00`0C4`064`0301<C00LC00<04a<0

1Q<00`0C4`074`0301<C00XC00<04a<011<006<C00<@4a<01A<00`0C4`024`053A<C4a00g1<00`dC

4`1Y4`0301<000@C001R4`0341<C00HC00<04a<00a<010dC4a3K4`033@0C06XC0`044`00HQ<00a0C

4`064`8011<01@dC4a<@0=XC00<=01<0LA<0064C00<@4a<01a<00`0C4`044`043A<C4=TC00@=4`00

LA<0064C00<@4a<01a<00`0C4`054`033A<@0=TC00<=4`00LQ<0060C00<@4a<021<00`0C4`054`04

3A<C4=PC00<=4`00LQ<0060C00<@4a<021<200LC00<=4a00ea<010dC4`1b4`00Ga<00a0C4`094`03

01<C00LC00<=4a00eQ<00`dC4`02074C001O4`0341<C00TC00<04a<01a<00`dC403E4`053A<C4`00

LQ<005hC00<@4a<02Q<00`0C4`084`033A<@0=@C00D=4a<C001b4`00GQ<00a0C4`0:4`802Q<00`d@

4`3C4`053A<C4`00LQ<005dC00<@4a<02a<00`0C4`0:4`033A0C0=8C00D=4a<C001b4`00GA<00a0C

4`044`D00Q<00`0C4`0:4`033A0C0=8C00@=4a<C0P1a4`00G1<00a0C4`074`0301<C008C00<04a<0

2a<00`d@4`3A4`053A<C4`00LQ<005/C00<@4a<021<00`0C4`024`803A<00`d@4`3@4`053A<C4`00

LQ<005/C00<@4a<021<00`0C4`024`0301<C00`C00<=41<0d1<01@dC4a<0078C001J4`0341<C00TC

00<04a<00Q<00`0C4`0=4`033A0C0<lC00D=4a<C001b4`00FQ<00a0C4`084`8011<00`0C4`0>4`03

3A0C0<hC00@=4a<C0P1a4`00FA<00a0C4`0?4`803a<00`d@4`3>4`053A<C4`00LQ<005PC00<@4a<0

41<00`0C4`0?4`033A0C0<dC00D=4a<C001b4`00F1<00a0C4`0@4`0301<C010C00<=41<0`A<00`0C

4`024`0301<C008C00<03A<00Q<00`0C4`1`4`00Ea<00a0C4`0A4`0301<C014C00<=4a<0_a<00`0C

00074`0301<=00<C00<04a<0L1<005HC00<@4a<04Q<2018C00<=41<0_a<00`0C00094`0400dC4`80

LA<005HC00<@4a<04Q<00`0C4`0B4`033A0C0;hC00<04`001a<200054`dC4`00LQ<005DC00<@4a<0

4a<00`0C4`0C4`033A<C0;dC00<04`001a<01`0C4a<=4`00LQ<005@C00<@4a<051<00`0C4`0C4`03

3A0C0;hC00<04a<01Q<300044`dC078C001C4`0341<C01DC0P0E4`033A<C0<XC00@=4`00LA<005<C

00<@4a<05A<00`0C4`0E4`033A<C0<XC00<=01<0LA<0058C00<@4a<05Q<00`0C4`0E4`033A0C0<XC

00<=01<0LA<0054C00<@4a<05a<00`0C4`0F4`033A<C0<TC00<=01<0LA<0054C00<@4a<05a<201PC

00<=4a<0bA<00`dC4`1`4`00D1<00a0C4`0H4`0301<C01LC00<@3A<0bA<00`d04`1`4`00Ca<00a0C

4`084`D00Q<00`0C4`024`0301<C008C00<04a<061<00`dC4`384`0300dC070C001?4`0341<C00XC

00<04a<01Q<00`0C00034`0301<C01TC00<=4a<0aa<00`0=4`1`4`00CQ<00a0C4`0;4`0301<C00PC

00@04a<C0P0K4`033A<C0<HC00<04`d0L1<004dC00<@4a<031<00`0C4`064`8011<00`0C4`0J4`03

3A<C0<HC00<04`d0L1<004`C00<@4a<03A<00`0C4`064`0301<C00<C00<04a<06a<00`dC4`354`80

00<C3A<0KQ<004`C00<@4a<031<200PC0`034`0301<C01`C00<=4a<0a1<01@0C4a<=06hC001;4`03

41<C01dC0P0M4`033A0C0<@C00D04a<C3@1^4`00BQ<00a0C4`0N4`0301<C01dC00<=4a<0`a<00`0C

4`024`033A<C06/C001:4`0341<C01hC00<04a<07Q<00`dC4`324`800a<00`dC4`1[4`00BA<00a0C

4`0O4`0301<C01hC00<=41<0`Q<00`0C4`034`033A<C06XC00184`0341<C020C0P0P4`033A0C0<4C

00<04a<011<00`dC4`1Y4`00Aa<00a0C4`0Q4`0301<C020C00<=41<0^A<5008C00<04a<01A<00`dC

4`1X4`00Aa<00a0C4`0Q4`0301<C020C00<=41<0^a<00`0C4`024`0301<C00DC00<=4a<0J1<004HC

00<@4a<08Q<00`0C4`0Q4`033A0C0;XC00<04a<00Q<200LC00<=4a<0Ia<004DC00<@4a<08a<202<C

00<=41<0^A<00`0C4`024`0301<C00LC00<=4a<0IQ<004@C00<@4a<091<00`0C4`0R4`033A<@0;TC

00<04a<00Q<00`0C4`084`033A<C06DC00144`0341<C02@C00<04a<08a<00`d@4`2g4`8011<00`0C

4`094`033A<C06@C00134`0341<C02DC00<04a<091<00`d@4`2l4`0301<C00XC00<=4a<0Ha<0048C

00<@4a<09Q<00`0C4`0U4`033A0C0;/C0P0<4`033A<C068C00114`0341<C02LC0P0V4`033A<@0;/C

00<04a<031<00`dC4`1Q4`00@1<00a0C4`0X4`0301<C02HC00<=4a00^Q<00`0C4`0=4`033A<C060C

00104`0341<C028C0`034`0301<C02LC00<=4a00^A<00`0C4`0>4`033A<C05lC000o4`0341<C02<C

00<04a<00a<00`0C4`0W4`033A<@0;TC00<04a<03a<23ElC000n4`0341<C02DC00<04a<00Q<202TC

00<=4a00^1<2018C00<=4a<0G1<003dC00<@4a<09Q<00`0C4`024`0301<C02TC00<=4a00]a<00`0C

4`0B4`033A<C05/C000m4`0341<C02DC00<04`000a<00`0C4`0Y4`043A<C4;HC00<04a<04a<00`dC

4`1J4`00?1<00a0C4`0W4`0301<C008C00<04a<0:Q<010dC4a2e4`0301<C01@C0PeJ4`00>a<00a0C

4`0]4`80;1<010dC4a2d4`805a<00`dC4`1G4`00>Q<00a0C4`0^4`0301<C02`C00<=4a00]1<00`0C

4`0G4`033A<C05HC000j4`0341<C02hC00<04a<0;1<010dC4a2c4`0301<C01PC0PeF4`00>A<00a0C

4`0_4`0301<C02dC00@=4a<@/Q<00`0C4`0J4`8=E1<003PC00<@4a<0<1<202lC00@=4a<@/A<00`0C

4`0L4`8=DQ<003LC00<@4a<0<A<00`0C4`0^4`043A<C4;4C0P0O4`033A<C04lC000g4`0341<C034C

00<04a<0;a<010dC4a2`4`0301<C01lC00<=4a<0CQ<003HC00<@4a<0<Q<00`0C4`0`4`043A<C4:lC

00<04a<081<00`dC4`1=4`00=A<00a0C4`0c4`80<A<01@dC4a<@09dC1@024`0301<C008C00<04a<0

0Q<00`0C4`0Q4`8=CA<003@C00<@4a<0=1<00`0C4`0a4`053A<C4a00WQ<00`0C4`064`0301<000<C

00<04a<08a<00`dC4`1:4`00<a<00a0C4`0e4`0301<C038C00D=4a<C402M4`0301<C00PC00@04a<C

0P0U4`033A<C04TC000b4`0341<C03HC00<04a<0<a<010dC4a2M4`0301<C00HC0P044`0301<C02DC

0Pe94`00<A<00a0C4`0g4`80=1<01@dC4a<@09`C00<04a<01Q<00`0C4`034`0301<C02LC00<=4a<0

AQ<0030C00<@4a<0>1<00`0C4`0d4`053A<C4a00VQ<200PC0`034`0301<C02PC0Pe64`00;a<00a0C

4`0Y4`<00a<00`0C4`024`0301<C008C00<04a<0=A<01@dC4a<@0:TC00<04a<0:Q<23D@C000^4`03

41<C02XC00<04a<01a<00`0C00034`0301<C03DC00<=4a<00Q<00a0C4`2V4`80;A<23D8C000]4`03

41<C02`C00<04a<021<0100C4a<203LC00<=4a<00Q<00a0C4`2U4`0301<C02hC0Pe04`00;1<00a0C

4`0]4`0301<C00HC0P044`0301<C03LC00<=4a<00Q<00a0C4`2T4`0301<C030C0Pdn4`00:a<00a0C

4`0]4`0301<000LC00<04a<00a<00`0C4`0g4`033A<C00<C00<@4a<0Xa<00`0C4`0b4`8=?1<002XC

00<@4a<0;a<00`0C4`064`<00a<00`0C4`0h4`033A<C00<C00<@4a<0XQ<203DC00<=4a<0>A<002TC

00<@4a<0?a<203XC00<=4a<00a<00a0C4`2Q4`0301<C03DC0Pdi4`00:1<00a0C4`104`0301<C03XC

00<=4a<00a<00a0C4`2P4`0301<C03LC00<=4a<0=Q<002LC00<@4a<0@A<00`0C4`0j4`033A<C00@C

00<@4a<0Wa<00`0C4`0h4`8==Q<002HC00<@4a<0@Q<00`0C4`0k4`033A<C00@C00<@4a<0WQ<00`0C

4`0j4`8==1<002DC00<@4a<0@a<203dC00<=4a<011<00a0C4`2M4`80?A<23C8C000T4`0341<C04@C

00<04a<0?1<00`dC4`054`0341<C09`C00<04a<0?Q<23C0C000S4`0341<C04DC00<04a<0?A<00`dC

4`054`0341<C09/C00<04a<0@1<23BhC000S4`0341<C04DC00<04a<0?A<00`dC4`064`0341<C09XC

00<04a<0@Q<33B/C000R4`0341<C04HC0P0o4`033A<C00HC00<@4a<0VA<00`0C4`154`<=:1<0024C

00<@4a<0Aa<00`0C4`0o4`033A<C00HC00<@4a<0V1<204TC0PdV4`0081<00a0C4`184`0301<C03lC

00<=4a<01a<00a0C4`2G4`0301<C04XC0PdT4`007a<00a0C4`194`0301<C040C00<=4a<01a<00a0C

4`2F4`0301<C04`C0`dQ4`007Q<00a0C4`1:4`80@A<00`dC4`084`0341<C08lC0`034`0301<C04lC

0PdO4`007A<00a0C4`1;4`0301<C044C00<=4a<021<00a0C4`2>4`0301<C00<C00<04a<0DA<23AdC

000L4`0341<C04`C00<04a<0@Q<00`dC4`084`0341<C08hC00<04a<00Q<205@C0PdK4`006a<00a0C

4`174`8011<00`0C4`124`033A<C00TC00<@4a<0SA<00`0C4`024`0301<C05DC0PdI4`006Q<00a0C

4`1:4`0501<C4`00AA<00`dC4`094`0341<C08/C00<04`000a<00`0C4`1G4`8=5a<001TC00<@4a<0

BQ<00`0C4`024`80AA<00`dC4`084`0341<C08`C00<04a<00Q<00`0C4`1I4`<=51<006LC00<04a<0

ia<205dC00<=4a<04A<006DC00<04`00jA<00`0C4`1`4`00IQ<00`0C4`3X4`0301<C070C000/4`<0

oa<S4`0301<C070C000/4`0301<C0?lC8a<00`0C4`1`4`00;A<00`0C4`054`0301<C0?lCSA<002dC

00@04a<C0`0011<04a<30?lCRQ<002`C00<04`000Q<2008C00<04a<00Q<00`0C4`3o4hPC000]4`03

01<C00<C00@04a<00Q<00`0C4`3o4hTC000c4`0401<C00<C00<04a<01Q<00`0C4`0U4`<0;A<00`0C

4`3o4bLC000M4`<000<C00000P0<4`<011<300PC00<04a<091<0100C4`0A4`<000<C00000P024`03

01<C008C00<04a<00Q<00`0C4`054`0401<C4`D00Q<00`0C4`024`<00Q<300@C0P3;4`0301<C038C

00<04a<021<001`C00@04a<091<00`0C4`0S4`0401<C010C00@04a<01Q<00`0C00074`0301<000@C

1@034`0301<C00PC00<04a<00Q<00`0C4`024`0301<C0<<C00<04a<011<00`0C4`0C4`0301<C01hC

00<04a<01a<001`C00D04a<04`0400034`0001P0:a<3010C00D04a<04`0400044`0C00TC00<04a<0

11<00`0C4`034`0301<C00HC10000a<0000200<C00<04a<0/A<0100C4a<4008C0P064`0301<C00<C

00<04a<00Q<00`0C4`024`0301<C008C00<04a<01A<0100C4a<5008C00<04a<00Q<3008C0`044`80

11<0100C4a<2004C0@0100007A<304dC00<04a<03a<300HC00<04`001a<200LC00<04a<00a<00`0C

4`064`0301<0008C00<04`0011<00`0C4`2`4`0301<000LC00<04a<011<500<C00L04a<C01<000LC

00<04`0011<500<C00<04a<021<00`0C4`024`0301<C008C00<04a<011<00`0C4`024`0301<0004C

000O4`0301<C04XC0P0C4`0301<C00@C00<04`001a<00`0C4`0<4`0301<C00LC0P034`8011<00`0C

002`4`0301<0008C10000a<04`074`0301<C00<C00L04a<C01<000TC00<04a<011<00`0C4`034`03

01<C00HC10000a<0000200<C00<04a<011<00`0C4`034`400A<14`007Q<2060C0P074`0301<C00HC

0`0;4`802Q<00`0C4`024`0301<C008C0`2F4`8000<C00005A<00`0C00074`0301<C00HC00<04a<0

0a<01`0C4a<04`001a<200LC00<04a<00a<00`0C4`064`0301<0008C00<04`0011<00`0C4`044`03

01<C00<C0@014`4C003o4e4C00<04`005Q<00`0C00074`0301<000dC00H04a<04`074`0301<C00`C

00<04a<01a<200<C0P044`0301<000<C00<04a<00a<00`0C00014`00:A<200HC0P3o4alC00<04a<0

5Q<00`0C4`064`<03Q<0100C4`084`<02a<200XC00<04a<00Q<00`0C4`024`<00Q<00`0C4`034`80

0A<10040000[4`0301<C008C00<04a<0oa<O4`0301<C070C000Z4`0301<C00<C00<04a<01A<00`0C

4`3o4aHC00<04`00LA<002/C00<04a<00Q<00`0C4`024`@00a<30?lC4A<200034`00070C000Y4`03

01<000@C00<04`000Q<200034`0C00@C00<04a<0oa>44`00:Q<00`0C4`034`<011<00`0C00034`03

01<C0?lCQA<003LC00<04`0011<00`0C4`3o4h@C000e4`<011<30?lCQQ<00?lCaA<00?lCaA<00?lC

aA<00?lCaA<00?lCaA<00001\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.12127, -1.58498, 0.0210942, 0.0210942}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -84.5 0 ]

[.5 .96488 84.5 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -145.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.435) show

222.250000 19.500000 moveto

(C) show

227.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.25112 0 m

.26171 .0152 L

.30316 .07467 L

.34309 .13197 L

.3815 .18709 L

.42237 .24574 L

.46172 .30221 L

.49955 .3565 L

.53984 .41431 L

.57861 .46995 L

.61984 .52911 L

.65954 .58609 L

.69774 .6409 L

.73838 .69922 L

.77751 .75537 L

.81909 .81504 L

.85916 .87254 L

.89771 .92786 L

s

.89771 .92786 m

.9148 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.351481 0.238095 [

[.02381 .33898 -6 -9 ]

[.02381 .33898 6 0 ]

[.2619 .33898 -6 -9 ]

[.2619 .33898 6 0 ]

[.7381 .33898 -3 -9 ]

[.7381 .33898 3 0 ]

[.97619 .33898 -3 -9 ]

[.97619 .33898 3 0 ]

[1.025 .35148 0 -8 ]

[1.025 .35148 9 8 ]

[.4875 .11339 -12 -4.5 ]

[.4875 .11339 0 4.5 ]

[.4875 .23243 -24 -4.5 ]

[.4875 .23243 0 4.5 ]

[.4875 .47053 -18 -4.5 ]

[.4875 .47053 0 4.5 ]

[.4875 .58958 -6 -4.5 ]

[.4875 .58958 0 4.5 ]

[.4875 .70862 -18 -4.5 ]

[.4875 .70862 0 4.5 ]

[.4875 .82767 -6 -4.5 ]

[.4875 .82767 0 4.5 ]

[.5 .89264 -4.5 0 ]

[.5 .89264 4.5 16 ]

[.5 .88014 -137 0 ]

[.5 .88014 137 16 ]

[ 0 0 0 0 ]

[ 1 .86764 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .35148 m

.02381 .35773 L

s

[(-2)] .02381 .33898 0 1 Mshowa

.2619 .35148 m

.2619 .35773 L

s

[(-1)] .2619 .33898 0 1 Mshowa

.7381 .35148 m

.7381 .35773 L

s

[(1)] .7381 .33898 0 1 Mshowa

.97619 .35148 m

.97619 .35773 L

s

[(2)] .97619 .33898 0 1 Mshowa

.125 Mabswid

.07143 .35148 m

.07143 .35523 L

s

.11905 .35148 m

.11905 .35523 L

s

.16667 .35148 m

.16667 .35523 L

s

.21429 .35148 m

.21429 .35523 L

s

.30952 .35148 m

.30952 .35523 L

s

.35714 .35148 m

.35714 .35523 L

s

.40476 .35148 m

.40476 .35523 L

s

.45238 .35148 m

.45238 .35523 L

s

.54762 .35148 m

.54762 .35523 L

s

.59524 .35148 m

.59524 .35523 L

s

.64286 .35148 m

.64286 .35523 L

s

.69048 .35148 m

.69048 .35523 L

s

.78571 .35148 m

.78571 .35523 L

s

.83333 .35148 m

.83333 .35523 L

s

.88095 .35148 m

.88095 .35523 L

s

.92857 .35148 m

.92857 .35523 L

s

.25 Mabswid

0 .35148 m

1 .35148 L

s

gsave

1.025 .35148 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .11339 m

.50625 .11339 L

s

[(-1)] .4875 .11339 1 0 Mshowa

.5 .23243 m

.50625 .23243 L

s

[(-0.5)] .4875 .23243 1 0 Mshowa

.5 .47053 m

.50625 .47053 L

s

[(0.5)] .4875 .47053 1 0 Mshowa

.5 .58958 m

.50625 .58958 L

s

[(1)] .4875 .58958 1 0 Mshowa

.5 .70862 m

.50625 .70862 L

s

[(1.5)] .4875 .70862 1 0 Mshowa

.5 .82767 m

.50625 .82767 L

s

[(2)] .4875 .82767 1 0 Mshowa

.125 Mabswid

.5 .01815 m

.50375 .01815 L

s

.5 .04196 m

.50375 .04196 L

s

.5 .06577 m

.50375 .06577 L

s

.5 .08958 m

.50375 .08958 L

s

.5 .1372 m

.50375 .1372 L

s

.5 .161 m

.50375 .161 L

s

.5 .18481 m

.50375 .18481 L

s

.5 .20862 m

.50375 .20862 L

s

.5 .25624 m

.50375 .25624 L

s

.5 .28005 m

.50375 .28005 L

s

.5 .30386 m

.50375 .30386 L

s

.5 .32767 m

.50375 .32767 L

s

.5 .37529 m

.50375 .37529 L

s

.5 .3991 m

.50375 .3991 L

s

.5 .42291 m

.50375 .42291 L

s

.5 .44672 m

.50375 .44672 L

s

.5 .49434 m

.50375 .49434 L

s

.5 .51815 m

.50375 .51815 L

s

.5 .54196 m

.50375 .54196 L

s

.5 .56577 m

.50375 .56577 L

s

.5 .61339 m

.50375 .61339 L

s

.5 .6372 m

.50375 .6372 L

s

.5 .661 m

.50375 .661 L

s

.5 .68481 m

.50375 .68481 L

s

.5 .73243 m

.50375 .73243 L

s

.5 .75624 m

.50375 .75624 L

s

.5 .78005 m

.50375 .78005 L

s

.5 .80386 m

.50375 .80386 L

s

.5 .85148 m

.50375 .85148 L

s

.25 Mabswid

.5 0 m

.5 .86764 L

s

gsave

.5 .89264 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .88014 -198 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.435) show

298.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

303.000000 15.000000 moveto

(L) show

310.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

317.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

324.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

329.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

333.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .86764 L

0 .86764 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .18494 m

.02576 .18494 L

.03157 .18493 L

.04114 .18492 L

.05431 .18491 L

.07085 .18489 L

.09048 .18487 L

.11286 .18484 L

.13762 .1848 L

.16433 .18476 L

.19252 .18471 L

.22172 .18466 L

.25143 .18459 L

.28114 .18452 L

.31035 .18443 L

.33854 .18433 L

.36525 .18422 L

.39 .1841 L

.41239 .18397 L

.43202 .18383 L

.44856 .1837 L

.46173 .18358 L

.4713 .18348 L

.47711 .18342 L

.47906 .1834 L

s

.47906 .1834 m

.48118 .18337 L

.48753 .18329 L

.49798 .18315 L

.51236 .18293 L

.53042 .18258 L

.55186 .18203 L

.57631 .18111 L

.60334 .17942 L

.6325 .17584 L

.66329 .16779 L

.69518 .15397 L

.72762 .13733 L

.76007 .12039 L

.79196 .10412 L

.82275 .08894 L

.85191 .07506 L

.87894 .0626 L

.90339 .05165 L

.92483 .04228 L

.94289 .03455 L

.95727 .02849 L

.96772 .02415 L

.97406 .02153 L

.97619 .02066 L

s

.47906 .43547 m

.48118 .4087 L

.48753 .38202 L

.49798 .35563 L

.51236 .32965 L

.53042 .30424 L

.55186 .27959 L

.57631 .25598 L

.60334 .23392 L

.6325 .21463 L

.66329 .20078 L

.69518 .19378 L

.72762 .19075 L

.76007 .18927 L

.79196 .18844 L

.82275 .18793 L

.85191 .18758 L

.87894 .18734 L

.90339 .18716 L

.92483 .18704 L

.94289 .18694 L

.95727 .18688 L

.96772 .18683 L

.97406 .18681 L

.97619 .1868 L

s

.47906 .43558 m

.48118 .46237 L

.48753 .48913 L

.49798 .51566 L

.51236 .54187 L

.53042 .56763 L

.55186 .59282 L

.57631 .61735 L

.60334 .6411 L

.6325 .66398 L

.66329 .68587 L

.69518 .7067 L

.72762 .72636 L

.76007 .74478 L

.79196 .76188 L

.82275 .77757 L

.85191 .79181 L

.87894 .80451 L

.90339 .81563 L

.92483 .82513 L

.94289 .83295 L

.95727 .83907 L

.96772 .84346 L

.97406 .8461 L

.97619 .84698 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<00`0C4`1`4`00oa=B4`0301<C070C001T4`D0j1<00`0C4`1`4`00IQ<00`0C4`3X4`80

LA<0040C00<=4a<07A<300<C00<04a<00Q<20>@C00<04a<0FQ<33A<C00114`033A<C028C00<04a<0

0Q<00`0C4`3S4`0301<C05LC0`dF4`00@A<00`dC4`0R4`0301<C008C00<04a<0ha<00`0C4`1E4`8=

6A<0048C00<=4a<081<200@C00<04a<0ha<00`0C4`1C4`8=6a<004<C00<=4a<09A<20>@C0P1C4`03

3A<C01/C00134`033A<C02DC00<04a<0ha<00`0C4`1@4`8=7Q<004@C00<=4a<091<00`0C4`3S4`03

01<C04dC0`dP4`00AA<00`dC4`0S4`0301<C0><C00<04a<0Ba<23B<C00154`033A<C02<C0P3T4`03

01<C04TC0PdU4`00AQ<00`dC4`0R4`0301<C0><C0P184`8=9a<004LC00<=4a<08A<00`0C4`3S4`03

01<C04DC0PdY4`00B1<00`dC4`0P4`0301<C0><C00<04a<0@Q<33B/C00184`033A<C020C0P3T4`03

01<C03lC0`d^4`00BA<00`dC4`0O4`0301<C0><C0P0n4`8=<A<004XC00<=4a<07Q<00`0C4`3S4`03

01<C03/C0Pdc4`00BQ<00`dC4`0N4`0301<C0><C00<04a<0>A<23CDC001;4`033A<C01dC0P3M4`D0

0Q<00`0C4`0g4`8==a<004`C00<=4a<071<00`0C4`3N4`0301<C008C00<04a<0=A<23CTC001<4`03

3A<C00dC00<04a<00Q<00`0C4`024`0301<C008C00<04a<0f1<300<C00<04a<00Q<203DC00<=4a<0

>A<004dC00<=4a<02a<00`0C00074`0301<000<C00<04a<0gQ<00`0C4`024`0301<C038C0Pdl4`00

CQ<00`dC4`054`<00Q<00`0C00094`0401<C4`80ga<00`0C4`024`0301<C034C00<=4a<0?1<004lC

00<=4a<02A<00`0C00074`8011<00`0C4`3M4`8011<00`0C4`0_4`8=?a<004lC00<=4a<02A<00`0C

00074`0301<C00<C00<04a<0ha<00`0C4`0]4`8=@A<0050C00<=4a<02A<00`0C4`064`<00a<00`0C

4`3S4`80:a<33D<C001A4`033A<C01LC00<04a<0ha<00`0C4`0X4`8=AQ<0058C00<=4a<05Q<20>@C

00<04a<09Q<23DPC001B4`033A<C01HC00<04a<0ha<00`0C4`0T4`8=BQ<005<C00<=4a<05A<00`0C

4`3S4`0301<C028C0Pe<4`00E1<00`dC4`0D4`0301<C0><C0P0Q4`8=CQ<005DC00<=4a<04a<20>@C

00<04a<07A<33E0C001E4`033A<C01<C00<04a<0ha<00`0C4`0J4`<=Da<001XC0`0U4`D03a<00`dC

4`0B4`0301<C02@C1@0T4`<0Ta<00`0C4`0@4`X=EQ<001XC00<04a<09a<00`0C4`0@4`033A<C014C

00<04a<09Q<00`0C4`0T4`0301<C03@CLPeP4`005A<300<C00<04a<081<300<C00<04a<04A<00`dC

4`0@4`809a<00`0C4`0U4`0301<C098C00<04a<0;a<^3A<C000K4`0301<C02HC00<04a<04A<00`dC

4`0@4`0301<C02HC00<04a<09A<00`0C4`2B4`0301<C02<C30e14`006Q<00`0C000W4`0301<C018C

00<=4a<03a<00`0C4`0V4`0301<C02@C00<04`00Ta<00`0C4`0P4`<=CA<001/C00<04a<09A<201DC

00<=4a<03Q<00`0C4`0U4`809a<00`0C4`2B4`0301<C01dC0`e@4`00FQ<00`dC4`0>4`80i1<201/C

0`eC4`00Fa<00`dC4`0=4`0301<C0><C00<04a<061<23EHC001L4`033A<C00`C00<04a<0Fa<208HC

00<04a<05Q<23EPC001M4`033A<C00/C00<04a<0FQ<00`0C4`1g4`0301<C008C00<04a<00Q<00`0C

4`024`0301<C01DC00<=4a<0F1<001DCB0000`d0001R00HC00<04a<0MQ<00`0C00074`0301<000<C

00<04a<04a<23E/C000I4`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C

4`054`0301<C00HC00<04a<01A<0100C4`d44`0301<C00DC00<@4a<01A<00`0C4`064`0301<C00DC

00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C

4`084`0301<C074C0`024`0301<000TC00@04a<C0P0C4`033A<C05/C001O4`033A<C00TC00<@4a<0

FQ<00`0C001f4`0301<000LC0P044`0301<C014C00<=4a<0G1<005lC00<=4a<02A<245/C0`1f4`03

01<000LC00<04a<00a<00`0C4`0@4`033A<C05dC001P4`033A<C00PC0Q3E4`0301<C00HC0`034`03

01<C00hC0PeP4`00HA<00`dC4`064`03400@0>@C00<04a<03A<00`dC4`1P4`00HA<00`dC4`064`03

400@0>@C0P0=4`033A<C064C001R4`033A<C00DC00<@0100i1<00`0C4`0;4`033A<C068C001S4`03

3A<C00<C00D@4`00403S4`0301<C00TC0PeU4`00I1<00`dC4`024`0541<04a00ha<00`0C4`084`03

3A<C06DC001T4`033A<C008C00D@4`0C403S4`8021<00`dC4`1V4`00IA<01`dC4a<@4`000Q<00a0C

4`3P4`0301<C00HC00<=4a<0Ia<006HC00D=4a<@4`0200034a0C0>4C00<04a<01A<00`dC4`1X4`00

IQ<01PdC4a0C008C00<@4a<0h1<00`0C4`054`033A<C06PC001W4`053A0C4`000a<00a0C4`214`<0

;1<502XC00<04a<011<00`dC4`0S4`D0;1<3018C001X4`043A<C00<C00<@4a<0PA<00`0C4`0^4`03

01<C02XC0P044`033A<C02HC00<04a<0;1<00`0C4`0B4`00J1<00`dC4`02008C00<@4a<0O1<300<C

00<04a<09a<300<C00<04a<0:Q<00`0C4`024`033A<C02LC00<04a<0;A<00`0C4`0A4`00Ia<01A0C

3A<000@C00<@4a<0PA<00`0C4`0]4`0301<C02XC00<04a<00Q<00`dC4`0W4`0301<C02dC00<04a<0

4A<005`C00<04a<00Q<00`0C4`024`06010C4`d011<00a0C4`204`0301<002hC00<04a<0:Q<01@0C

4a<=02XC00<04a<0;1<00`0C000B4`00Fa<00`0C00074`030100008C00<=01<00a<00a0C4`214`03

01<C02`C0P0/4`0501<C4`d0:A<202lC00<04a<04A<005/C00<04`0021<00a004`024`033@0C00<C

00<@4a<0gA<200034`dC06hC001K4`0301<000LC00<041<00a<00`0=4`034`0341<C0=dC00<04`d0

L1<005/C00<04`001a<00a0C4`034`0300dC00@C00<@4a<0g1<00`0C3@1`4`00G1<00`0C4`064`03

400000<C00<04`d011<00a0C4`3L4`0300dC06XC0P044`00I1<00a0C4`044`8000<C3A<00Q<00a0C

4`3L4`0300dC06TC00<04a<011<006@C00<@4a<011<0100C4`d44`0341<C07LCI0000`d0001R00LC

00<04a<011<006<C00<@4a<01A<01@0C4a<=00<C00<@4a<0O1<00`0C4`0]4`0301<C02`C00<=4a<0

;A<00`0C4`0/4`0301<C00XC00<04a<011<006<C00<@4a<01A<00`0C4`024`053A<C4a00g1<00`dC

4`1Y4`0301<000@C001R4`0341<C00HC00<04a<00a<010dC4a3K4`033@0C06XC0`044`00HQ<00a0C

4`064`8011<01@dC4a<@0=XC00<=0000LA<0064C00<@4a<01a<00`0C4`044`043A<C4=TC00<=4`00

LQ<0064C00<@4a<01a<00`0C4`054`033A<@0=TC00<=4`00LQ<0060C00<@4a<021<00`0C4`054`04

3A<C4=PC00<=4`00LQ<0060C00<@4a<021<200LC00<=4a00ea<010dC4`1b4`00Ga<00a0C4`094`03

01<C00LC00<=4a00eQ<00`dC4`02074C001O4`0341<C00TC00<04a<01a<00`dC403E4`053A<C4`00

LQ<005hC00<@4a<02Q<00`0C4`084`033A<@0=@C00D=4a<C001b4`00GQ<00a0C4`0:4`802Q<00`d@

4`3C4`053A<C4`00LQ<005dC00<@4a<02a<00`0C4`0:4`033A0C0=8C00D=4a<C001b4`00GA<00a0C

4`044`D00Q<00`0C4`0:4`033A0C0=8C00@=4a<C0P1a4`00G1<00a0C4`074`0301<C008C00<04a<0

2a<00`d@4`3A4`053A<C4`00LQ<005/C00<@4a<021<00`0C4`024`803A<00`d@4`3@4`053A<C4`00

LQ<005/C00<@4a<021<00`0C4`024`0301<C00`C00<=41<0d1<01@dC4a<0078C001J4`0341<C00TC

00<04a<00Q<00`0C4`0=4`033A0C0<lC00D=4a<C001b4`00FQ<00a0C4`084`8011<00`0C4`0>4`03

3A0C0<hC00@=4a<C0P1a4`00FA<00a0C4`0?4`803a<00`d@4`3>4`053A<C4`00LQ<005PC00<@4a<0

41<00`0C4`0?4`033A0C0<8C00<04a<00Q<00`0C4`024`0300dC008C00<04a<0L1<005PC00<@4a<0

41<00`0C4`0@4`033A0C0<0C00<04`001a<00`0C3@034`0301<C070C001G4`0341<C014C00<04a<0

4A<00`dC4`2o4`0301<000TC00@=4a<C0P1a4`00EQ<00a0C4`0B4`804Q<00`d@4`2o4`0301<000LC

0P001A<=4a<0078C001F4`0341<C018C00<04a<04Q<00`d@4`2n4`0301<000LC00@04a<=0Q<00`0C

4`1`4`00EA<00a0C4`0C4`0301<C01<C00<=4a<0_Q<00`0C4`064`<000@C3A<0LQ<005@C00<@4a<0

51<00`0C4`0C4`033A0C0</C00<=4`00LQ<005<C00<@4a<05A<201DC00<=4a<0bQ<010dC001a4`00

Da<00a0C4`0E4`0301<C01DC00<=4a<0bQ<00`d04`1a4`00DQ<00a0C4`0F4`0301<C01DC00<=41<0

bQ<00`d04`1a4`00DA<00a0C4`0G4`0301<C01HC00<=4a<0bQ<00`dC4`1`4`00DA<00a0C4`0G4`80

61<00`dC4`394`033A<C070C001@4`0341<C01PC00<04a<05a<00a0=4`394`033@0C070C001?4`03

41<C00PC1@024`0301<C008C00<04a<00Q<00`0C4`0H4`033A<C0<PC00<03A<0L1<004lC00<@4a<0

2Q<00`0C4`064`0301<000<C00<04a<06A<00`dC4`374`0300dC070C001>4`0341<C00/C00<04a<0

21<0100C4a<201/C00<=4a<0aQ<00`0C3@1`4`00CA<00a0C4`0<4`0301<C00HC0P044`0301<C01XC

00<=4a<0aQ<00`0C3@1`4`00C1<00a0C4`0=4`0301<C00HC00<04a<00a<00`0C4`0K4`033A<C0<DC

0P000a<=4`1^4`00C1<00a0C4`0<4`8021<300<C00<04a<071<00`dC4`344`0501<C4`d0KQ<004/C

00<@4a<07A<201dC00<=41<0a1<01@0C4a<=06hC001:4`0341<C01hC00<04a<07A<00`dC4`334`03

01<C008C00<=4a<0Ja<004XC00<@4a<07Q<00`0C4`0N4`033A<C0<8C0P034`033A<C06/C00194`03

41<C01lC00<04a<07Q<00`d@4`324`0301<C00<C00<=4a<0JQ<004PC00<@4a<081<2020C00<=41<0

`A<00`0C4`044`033A<C06TC00174`0341<C024C00<04a<081<00`d@4`2i4`D00Q<00`0C4`054`03

3A<C06PC00174`0341<C024C00<04a<081<00`d@4`2k4`0301<C008C00<04a<01A<00`dC4`1X4`00

AQ<00a0C4`0R4`0301<C024C00<=41<0^Q<00`0C4`024`801a<00`dC4`1W4`00AA<00a0C4`0S4`80

8a<00`d@4`2i4`0301<C008C00<04a<01a<00`dC4`1V4`00A1<00a0C4`0T4`0301<C028C00<=4a00

^A<00`0C4`024`0301<C00PC00<=4a<0IA<004@C00<@4a<091<00`0C4`0S4`033A0C0;LC0P044`03

01<C00TC00<=4a<0I1<004<C00<@4a<09A<00`0C4`0T4`033A0C0;`C00<04a<02Q<00`dC4`1S4`00

@Q<00a0C4`0V4`0301<C02DC00<=41<0^a<200`C00<=4a<0HQ<0044C00<@4a<09a<202HC00<=4a00

^a<00`0C4`0<4`033A<C064C00104`0341<C02PC00<04a<09Q<00`dC402j4`0301<C00dC0PeQ4`00

@1<00a0C4`0R4`<00a<00`0C4`0W4`033A<@0;TC00<04a<03a<00`dC4`1N4`00?a<00a0C4`0S4`03

01<C00<C00<04a<09a<00`dC402i4`0301<C010C0PeN4`00?Q<00a0C4`0U4`0301<C008C0P0Y4`03

3A<@0;PC0P0C4`033A<C05/C000m4`0341<C02HC00<04a<00Q<00`0C4`0Y4`033A<@0;LC00<04a<0

4a<00`dC4`1J4`00?A<00a0C4`0U4`0301<000<C00<04a<0:A<010dC4a2f4`0301<C01@C00<=4a<0

FA<003`C00<@4a<09a<00`0C4`024`0301<C02XC00@=4a<@]A<00`0C4`0E4`8=FA<003/C00<@4a<0

;A<202`C00@=4a<@]1<201PC00<=4a<0EQ<003XC00<@4a<0;Q<00`0C4`0/4`033A<@0;@C00<04a<0

61<00`dC4`1E4`00>Q<00a0C4`0^4`0301<C02`C00@=4a<@/a<00`0C4`0I4`8=EA<003TC00<@4a<0

;a<00`0C4`0]4`043A<C4;8C00<04a<06a<00`dC4`1B4`00>1<00a0C4`0`4`80;a<010dC4a2a4`03

01<C01`C0PeB4`00=a<00a0C4`0a4`0301<C02hC00@=4a<@/A<201lC00<=4a<0Ca<003LC00<@4a<0

<A<00`0C4`0_4`043A<C4;0C00<04a<07a<00`dC4`1>4`00=Q<00a0C4`0b4`0301<C030C00@=4a<@

[a<00`0C4`0P4`033A<C04dC000e4`0341<C03<C0P0a4`053A<C4a00WA<5008C00<04a<00Q<00`0C

4`024`0301<C024C0Pe=4`00=1<00a0C4`0d4`0301<C034C00D=4a<C402N4`0301<C00HC00<04`00

0a<00`0C4`0S4`033A<C04XC000c4`0341<C03DC00<04a<0<Q<01@dC4a<@09dC00<04a<021<0100C

4a<202DC00<=4a<0BA<0038C00<@4a<0=Q<00`0C4`0c4`043A<C49dC00<04a<01Q<200@C00<04a<0

9A<23DTC000a4`0341<C03LC0P0d4`053A<C4a00W1<00`0C4`064`0301<C00<C00<04a<09a<23DLC

000`4`0341<C03PC00<04a<0=1<01@dC4a<@09XC0P084`<00a<00`0C4`0Y4`8=AA<002lC00<@4a<0

:A<300<C00<04a<00Q<00`0C4`024`0301<C03DC00D=4a<C402Y4`0301<C02/C00<=4a<0@Q<002hC

00<@4a<0:Q<00`0C4`074`0301<000<C00<04a<0=A<00`dC4`024`0341<C0:HC0P0]4`8=@Q<002dC

00<@4a<0;1<00`0C4`084`0401<C4`80=a<00`dC4`024`0341<C0:DC00<04a<0;Q<23D0C000/4`03

41<C02dC00<04a<01Q<200@C00<04a<0=a<00`dC4`024`0341<C0:@C00<04a<0<1<23ChC000[4`03

41<C02dC00<04`001a<00`0C4`034`0301<C03LC00<=4a<00a<00a0C4`2S4`0301<C038C0Pdl4`00

:Q<00a0C4`0_4`0301<C00HC0`034`0301<C03PC00<=4a<00a<00a0C4`2R4`80=A<00`dC4`0i4`00

:A<00a0C4`0o4`80>Q<00`dC4`034`0341<C0:4C00<04a<0=A<23CTC000X4`0341<C040C00<04a<0

>Q<00`dC4`034`0341<C0:0C00<04a<0=a<00`dC4`0f4`009a<00a0C4`114`0301<C03XC00<=4a<0

11<00a0C4`2O4`0301<C03PC0Pdf4`009Q<00a0C4`124`0301<C03/C00<=4a<011<00a0C4`2N4`03

01<C03XC0Pdd4`009A<00a0C4`134`80?A<00`dC4`044`0341<C09dC0P0m4`8=<Q<002@C00<@4a<0

A1<00`0C4`0l4`033A<C00DC00<@4a<0W1<00`0C4`0n4`8=<1<002<C00<@4a<0AA<00`0C4`0m4`03

3A<C00DC00<@4a<0Va<00`0C4`104`8=;Q<002<C00<@4a<0AA<00`0C4`0n4`033A<C00DC00<@4a<0

VQ<00`0C4`124`<=:a<0028C00<@4a<0AQ<203lC00<=4a<01Q<00a0C4`2I4`0301<C04DC0`dX4`00

8A<00a0C4`174`0301<C03lC00<=4a<01Q<00a0C4`2H4`80BA<33BDC000P4`0341<C04PC00<04a<0

@1<00`dC4`064`0341<C09LC00<04a<0Ba<23B<C000O4`0341<C04TC00<04a<0@1<00`dC4`074`03

41<C09HC00<04a<0CA<23B4C000N4`0341<C04XC0P124`033A<C00LC00<@4a<0Sa<300<C00<04a<0

Ca<23AlC000M4`0341<C04/C00<04a<0@Q<00`dC4`074`0341<C08hC00<04a<00a<00`0C4`1A4`8=

7A<001`C00<@4a<0C1<00`0C4`124`033A<C00PC00<@4a<0SQ<00`0C4`024`80E1<23A/C000K4`03

41<C04LC0P044`0301<C04<C00<=4a<021<00a0C4`2=4`0301<C008C00<04a<0EA<23ATC000J4`03

41<C04XC00D04a<C00154`033A<C00TC00<@4a<0Ra<00`0C00034`0301<C05LC0PdG4`006A<00a0C

4`1:4`0301<C008C0P154`033A<C00PC00<@4a<0S1<00`0C4`024`0301<C05TC10dC4`00Ia<00`0C

4`3W4`80GA<00`dC4`0A4`00IA<00`0C003Y4`0301<C070C001V4`0301<C0>PC00<04a<0L1<002XC

0`3o4bDC00<04a<0L1<002XC00<04a<0oa<U4`0301<C070C000[4`0301<C00@C00<04a<0oa>@4`00

:a<0100C4a<400<C0`3o4h`C000Z4`0301<0008C0P000a<04`044`0301<C0?lCRQ<002/C00<04a<0

0a<00`0C00034`0301<C0?lCRa<0034C00<04`0011<00`0C4`064`0301<C02LC0`0[4`0301<C0?lC

:A<001/C0`000a<0000200`C0`044`<021<00`0C4`0V4`0401<C00lC0`000a<00002008C00<04a<0

0Q<00`0C4`024`0301<C00DC00@04a<C1@024`0301<C008C0`000a<000044`0301<C00@C0P354`03

01<C03LC00<04a<01Q<001XC00@04a<091<00`0C4`0U4`0401<C00hC00@04a<01Q<00`0C00074`03

01<000@C1@034`0301<C00PC00<04a<00Q<01P0C4`0C00@C00<04a<0_A<00`0C4`044`0301<C01<C

00<04a<08a<00`0C4`054`006Q<01@0C4`0C00@000<C0000600]4`<03Q<01@0C4`0C00@000@C01<0

2A<00`0C4`044`0301<C00<C00<04a<01Q<4008C00<04a<00a<00`0C4`024`0301<C0:/C00@04a<C

10024`801Q<00`0C4`034`0301<C008C00<04a<00Q<00`0C4`024`0301<C00DC00@04a<C1@024`03

01<C008C0`000a<000044`0301<C00@C0P044`0401<C4`800A<001/C0`1?4`0301<C00dC0`064`03

01<000LC0P074`0301<C00<C00<04a<01Q<00`0C00044`0301<C00801A<00`0C4`2Z4`0301<000LC

00<04a<011<500<C00L04a<C01<000LC00<04`0011<500<C00<04a<021<00`0C4`024`0601<C01<0

11<00`0C4`044`0301<C008C0@014`007A<00`0C4`1<4`804A<00`0C4`044`0301<000LC00<04a<0

31<00`0C4`074`800Q<00`0C00024`0301<C00@C00<04`00ZQ<00`0C00024`@000<C01<01a<00`0C

4`034`0701<C4`0C00094`0301<C00@C00<04a<00a<00`0C4`064`@00Q<00`0C4`034`0301<C008C

00<04a<011<00`0C4`034`40000L4`80H1<200LC00<04a<01Q<300/C0P0:4`0501<C4`000a<300@C

0`2C4`8000<C00004Q<00`0C00074`0301<C00HC00<04a<00a<01`0C4a<04`001a<200LC00<04a<0

0a<00`0C4`064`0301<000@C00<04a<00P054`0301<C00@C00<04a<00a<10000oa=A4`0301<001<C

00<04`001a<00`0C000=4`0601<C01<01a<00`0C4`0<4`0301<C00LC0P024`0301<0008C00<04a<0

11<00`0C00034`0301<C00<C0@014`009Q<200HC0P3o4b8C00<04a<04a<00`0C4`064`<03Q<0100C

4`084`<02a<200XC00D04a<C00034`<011<3008C00<04a<00a<2004C000X4`0301<C008C00<04a<0

oa<R4`0301<C070C000W4`0301<C00<C00<04a<01Q<00`0C4`3o4aPC00<04`00LA<002PC00<04a<0

0Q<00`0C4`024`<000@C01<C0`3o4a@C0P000a<0001`4`009Q<00`0C00044`0301<0008C0P024`03

01<C008C00<04a<0oa>74`009a<00`0C4`034`<011<0100C4`024`0301<C0?lCR1<003@C00@04a<0

0a<00`0C4`3o4hLC000b4`<011<30?lCRA<00?lCaA<00?lCaA<00?lCaA<00?lCaA<00?lCaA<00001

\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.10559, -1.57885, 0.0210477, 0.0210477}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -82 0 ]

[.5 .96488 82 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -143 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.43) show

217.250000 19.500000 moveto

(C) show

222.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.25025 0 m

.26171 .01639 L

.30316 .07565 L

.34309 .13275 L

.3815 .18769 L

.42237 .24613 L

.46172 .3024 L

.49955 .3565 L

.53984 .41411 L

.57861 .46956 L

.61984 .52851 L

.65954 .58529 L

.69774 .63991 L

.73838 .69803 L

.77751 .75399 L

.81909 .81345 L

.85916 .87074 L

.89771 .92587 L

s

.89771 .92587 m

.91625 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.35006 0.238095 [

[.02381 .33756 -6 -9 ]

[.02381 .33756 6 0 ]

[.2619 .33756 -6 -9 ]

[.2619 .33756 6 0 ]

[.7381 .33756 -3 -9 ]

[.7381 .33756 3 0 ]

[.97619 .33756 -3 -9 ]

[.97619 .33756 3 0 ]

[1.025 .35006 0 -8 ]

[1.025 .35006 9 8 ]

[.4875 .11196 -12 -4.5 ]

[.4875 .11196 0 4.5 ]

[.4875 .23101 -24 -4.5 ]

[.4875 .23101 0 4.5 ]

[.4875 .46911 -18 -4.5 ]

[.4875 .46911 0 4.5 ]

[.4875 .58815 -6 -4.5 ]

[.4875 .58815 0 4.5 ]

[.4875 .7072 -18 -4.5 ]

[.4875 .7072 0 4.5 ]

[.4875 .82625 -6 -4.5 ]

[.4875 .82625 0 4.5 ]

[.5 .89066 -4.5 0 ]

[.5 .89066 4.5 16 ]

[.5 .87816 -134.5 0 ]

[.5 .87816 134.5 16 ]

[ 0 0 0 0 ]

[ 1 .86566 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .35006 m

.02381 .35631 L

s

[(-2)] .02381 .33756 0 1 Mshowa

.2619 .35006 m

.2619 .35631 L

s

[(-1)] .2619 .33756 0 1 Mshowa

.7381 .35006 m

.7381 .35631 L

s

[(1)] .7381 .33756 0 1 Mshowa

.97619 .35006 m

.97619 .35631 L

s

[(2)] .97619 .33756 0 1 Mshowa

.125 Mabswid

.07143 .35006 m

.07143 .35381 L

s

.11905 .35006 m

.11905 .35381 L

s

.16667 .35006 m

.16667 .35381 L

s

.21429 .35006 m

.21429 .35381 L

s

.30952 .35006 m

.30952 .35381 L

s

.35714 .35006 m

.35714 .35381 L

s

.40476 .35006 m

.40476 .35381 L

s

.45238 .35006 m

.45238 .35381 L

s

.54762 .35006 m

.54762 .35381 L

s

.59524 .35006 m

.59524 .35381 L

s

.64286 .35006 m

.64286 .35381 L

s

.69048 .35006 m

.69048 .35381 L

s

.78571 .35006 m

.78571 .35381 L

s

.83333 .35006 m

.83333 .35381 L

s

.88095 .35006 m

.88095 .35381 L

s

.92857 .35006 m

.92857 .35381 L

s

.25 Mabswid

0 .35006 m

1 .35006 L

s

gsave

1.025 .35006 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .11196 m

.50625 .11196 L

s

[(-1)] .4875 .11196 1 0 Mshowa

.5 .23101 m

.50625 .23101 L

s

[(-0.5)] .4875 .23101 1 0 Mshowa

.5 .46911 m

.50625 .46911 L

s

[(0.5)] .4875 .46911 1 0 Mshowa

.5 .58815 m

.50625 .58815 L

s

[(1)] .4875 .58815 1 0 Mshowa

.5 .7072 m

.50625 .7072 L

s

[(1.5)] .4875 .7072 1 0 Mshowa

.5 .82625 m

.50625 .82625 L

s

[(2)] .4875 .82625 1 0 Mshowa

.125 Mabswid

.5 .13577 m

.50375 .13577 L

s

.5 .15958 m

.50375 .15958 L

s

.5 .18339 m

.50375 .18339 L

s

.5 .2072 m

.50375 .2072 L

s

.5 .25482 m

.50375 .25482 L

s

.5 .27863 m

.50375 .27863 L

s

.5 .30244 m

.50375 .30244 L

s

.5 .32625 m

.50375 .32625 L

s

.5 .37387 m

.50375 .37387 L

s

.5 .39768 m

.50375 .39768 L

s

.5 .42149 m

.50375 .42149 L

s

.5 .4453 m

.50375 .4453 L

s

.5 .49292 m

.50375 .49292 L

s

.5 .51673 m

.50375 .51673 L

s

.5 .54054 m

.50375 .54054 L

s

.5 .56435 m

.50375 .56435 L

s

.5 .61196 m

.50375 .61196 L

s

.5 .63577 m

.50375 .63577 L

s

.5 .65958 m

.50375 .65958 L

s

.5 .68339 m

.50375 .68339 L

s

.5 .73101 m

.50375 .73101 L

s

.5 .75482 m

.50375 .75482 L

s

.5 .77863 m

.50375 .77863 L

s

.5 .80244 m

.50375 .80244 L

s

.5 .08815 m

.50375 .08815 L

s

.5 .06435 m

.50375 .06435 L

s

.5 .04054 m

.50375 .04054 L

s

.5 .01673 m

.50375 .01673 L

s

.5 .85006 m

.50375 .85006 L

s

.25 Mabswid

.5 0 m

.5 .86566 L

s

gsave

.5 .89066 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .87816 -195.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.43) show

293.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

298.000000 15.000000 moveto

(L) show

305.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

312.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

319.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

324.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

328.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .86566 L

0 .86566 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .18308 m

.02576 .18308 L

.03157 .18308 L

.04114 .18307 L

.0543 .18306 L

.07084 .18304 L

.09048 .18303 L

.11286 .18301 L

.13762 .18298 L

.16432 .18295 L

.19251 .18291 L

.22171 .18287 L

.25142 .18282 L

.28113 .18276 L

.31033 .18269 L

.33852 .18262 L

.36523 .18254 L

.38998 .18244 L

.41237 .18234 L

.432 .18224 L

.44854 .18214 L

.46171 .18205 L

.47128 .18198 L

.47709 .18193 L

.47903 .18191 L

s

.47903 .18191 m

.48116 .18189 L

.4875 .18183 L

.49796 .18172 L

.51234 .18155 L

.5304 .18129 L

.55184 .18087 L

.57629 .18017 L

.60332 .17885 L

.63248 .17593 L

.66327 .1686 L

.69517 .15474 L

.72761 .13782 L

.76006 .12067 L

.79195 .10428 L

.82274 .08902 L

.8519 .07509 L

.87894 .0626 L

.90338 .05163 L

.92482 .04225 L

.94289 .03451 L

.95727 .02845 L

.96772 .0241 L

.97406 .02148 L

.97619 .02061 L

s

.47903 .43408 m

.48116 .40733 L

.4875 .38066 L

.49796 .35426 L

.51234 .32825 L

.5304 .30279 L

.55184 .27805 L

.57629 .25425 L

.60332 .23185 L

.63248 .21193 L

.66327 .1974 L

.69517 .19046 L

.72761 .18775 L

.76006 .1865 L

.79195 .18583 L

.82274 .18541 L

.8519 .18513 L

.87894 .18494 L

.90338 .18481 L

.92482 .18471 L

.94289 .18463 L

.95727 .18458 L

.96772 .18455 L

.97406 .18453 L

.97619 .18452 L

s

.47903 .43419 m

.48116 .46096 L

.4875 .48769 L

.49796 .5142 L

.51234 .54037 L

.5304 .5661 L

.55184 .59126 L

.57629 .61576 L

.60332 .63948 L

.63248 .66232 L

.66327 .68418 L

.69517 .70498 L

.72761 .72461 L

.76006 .74301 L

.79195 .76007 L

.82274 .77575 L

.8519 .78996 L

.87894 .80264 L

.90338 .81375 L

.92482 .82322 L

.94289 .83104 L

.95727 .83715 L

.96772 .84153 L

.97406 .84417 L

.97619 .84505 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<00`0C4`1`4`00oa=B4`0301<C070C001T4`D0j1<00`0C4`1`4`00IQ<00`0C4`3X4`80

LA<0040C00<=4a<07A<300<C00<04a<00Q<20>@C00<04a<0Fa<23A<C00114`033A<C028C00<04a<0

0Q<00`0C4`3S4`0301<C05PC0`dE4`00@A<00`dC4`0R4`0301<C008C00<04a<0ha<00`0C4`1F4`8=

61<0048C00<=4a<081<200@C00<04a<0ha<00`0C4`1D4`8=6Q<004<C00<=4a<09A<20>@C0P1C4`8=

71<004<C00<=4a<09A<00`0C4`3S4`0301<C050C0PdN4`00A1<00`dC4`0T4`0301<C0><C00<04a<0

CA<33B0C00154`033A<C02<C00<04a<0ha<00`0C4`1;4`8=8a<004DC00<=4a<08a<20>@C0P1:4`8=

9A<004HC00<=4a<08Q<00`0C4`3S4`0301<C04LC0PdW4`00Aa<00`dC4`0Q4`0301<C0><C00<04a<0

AA<23BTC00184`033A<C020C00<04a<0ha<00`0C4`124`<=:a<004PC00<=4a<081<20>@C00<04a<0

@1<23BhC00194`033A<C01lC00<04a<0ha<203hC0`d`4`00BQ<00`dC4`0N4`0301<C0><C00<04a<0

>a<23C<C001:4`033A<C01hC00<04a<0ha<00`0C4`0i4`8==A<004/C00<=4a<07A<20=dC1@024`03

01<C03LC0Pdg4`00C1<00`dC4`0L4`0301<C0=hC00<04a<00Q<00`0C4`0e4`8=>A<004`C00<=4a<0

3A<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`3H4`<00a<00`0C4`024`80=A<00`dC4`0i4`00

CA<00`dC4`0;4`0301<000LC00<04`000a<00`0C4`3N4`0301<C008C00<04a<0<Q<23C`C001>4`03

3A<C00DC0`024`0301<000TC00@04a<C0P3O4`0301<C008C00<04a<0<A<00`dC4`0l4`00Ca<00`dC

4`094`0301<000LC0P044`0301<C0=dC0P044`0301<C02lC0Pdo4`00Ca<00`dC4`094`0301<000LC

00<04a<00a<00`0C4`3S4`0301<C02dC0Pe14`00D1<00`dC4`094`0301<C00HC0`034`0301<C0><C

0P0/4`8=@a<0054C00<=4a<05a<00`0C4`3S4`0301<C02TC0Pe54`00DQ<00`dC4`0F4`80i1<00`0C

4`0W4`8=Aa<0058C00<=4a<05Q<00`0C4`3S4`0301<C02DC0Pe94`00Da<00`dC4`0E4`0301<C0><C

0P0T4`8=Ba<005@C00<=4a<051<00`0C4`3S4`0301<C020C0`e=4`00EA<00`dC4`0C4`80i1<00`0C

4`0M4`<=D1<005DC00<=4a<04a<00`0C4`3S4`0301<C01XC0`eC4`006Q<302DC1@0?4`033A<C018C

00<04a<091<502@C0`2C4`0301<C010C2PeF4`006Q<00`0C4`0W4`0301<C010C00<=4a<04A<00`0C

4`0V4`0301<C02@C00<04a<0=1=b3DDC20dC4`005A<300<C00<04a<081<300<C00<04a<04A<00`dC

4`0@4`809a<00`0C4`0U4`0301<C098C00<04a<0:1<]3A/C000K4`0301<C02HC00<04a<04A<00`dC

4`0@4`0301<C02HC00<04a<09A<00`0C4`2B4`0301<C028C1Pe84`006Q<00`0C000W4`0301<C018C

00<=4a<03a<00`0C4`0V4`0301<C02@C00<04`00Ta<00`0C4`0N4`@=CQ<001/C00<04a<09A<201DC

00<=4a<03Q<00`0C4`0U4`809a<00`0C4`2B4`0301<C01`C0PeB4`00FQ<00`dC4`0>4`80i1<201/C

0PeD4`00Fa<00`dC4`0=4`0301<C0><C00<04a<061<23EHC001L4`033A<C00`C00<04a<0Fa<208HC

00<04a<05Q<23EPC001M4`033A<C00/C00<04a<0FQ<00`0C4`1g4`0301<C008C00<04a<00Q<00`0C

4`024`0301<C01DC00<=4a<0F1<001DCB0000`d0001R00HC00<04a<0MQ<00`0C00074`0301<000<C

00<04a<04a<23E/C000I4`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C

4`054`0301<C00HC00<04a<01A<0100C4`d44`0301<C00DC00<@4a<01A<00`0C4`064`0301<C00DC

00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C

4`084`0301<C074C0`024`0301<000TC00@04a<C0P0C4`033A<C05/C001O4`033A<C00TC00<@4a<0

FQ<00`0C001f4`0301<000LC0P044`0301<C010C0PeN4`00Ga<00`dC4`094`8@Fa<307HC00<04`00

1a<00`0C4`034`0301<C00lC00<=4a<0GQ<0060C00<=4a<021<24=DC00<04a<01Q<300<C00<04a<0

3A<23F4C001Q4`033A<C00HC00<@0100i1<00`0C4`0<4`033A<C064C001Q4`033A<C00HC00<@0100

i1<200`C00<=4a<0HQ<0068C00<=4a<01A<00a00403T4`0301<C00XC00<=4a<0Ha<006<C00<=4a<0

0a<01A0C000@0><C00<04a<02A<00`dC4`1T4`00I1<00`dC4`024`0541<04a00ha<00`0C4`084`03

3A<C06DC001T4`033A<C008C00D@4`0C403S4`8021<00`dC4`1V4`00IA<01`dC4a<@4`000Q<00a0C

4`3P4`0301<C00HC00<=4a<0Ia<006HC00D=4a<@4`0200034a0C0>4C00<04a<01A<00`dC4`1X4`00

IQ<01PdC4a0C008C00<@4a<0h1<00`0C4`054`033A<C06PC001W4`053A0C4`000a<00a0C4`214`<0

:a<502/C00<04a<011<00`dC4`0S4`D0;1<3018C001X4`043A<C00<C00<@4a<0PA<00`0C4`0]4`03

01<C02/C0P044`033A<C02HC00<04a<0;1<00`0C4`0B4`00J1<00`dC4`02008C00<@4a<0O1<300<C

00<04a<09Q<300<C00<04a<0:a<00`0C4`024`033A<C02LC00<04a<0;A<00`0C4`0A4`00Ia<01A0C

3A<000@C00<@4a<0PA<00`0C4`0/4`0301<C02/C00<04a<00Q<00`dC4`0W4`0301<C02dC00<04a<0

4A<005`C00<04a<00Q<00`0C4`024`06010C4`d011<00a0C4`204`0301<002dC00<04a<0:a<01@0C

4a<=02XC00<04a<0;1<00`0C000B4`00Fa<00`0C00074`030100008C00<=01<00a<00a0C4`214`03

01<C02/C0P0]4`0501<C4`d0:A<202lC00<04a<04A<005/C00<04`0021<00a004`024`033@0C00<C

00<@4a<0gA<200034`dC06hC001K4`0301<000LC00<041<00a<00`0=4`034`0341<C0=dC00<04`d0

L1<005/C00<04`001a<00a0C4`034`0300dC00@C00<@4a<0g1<00`0C3@1`4`00G1<00`0C4`064`03

400000<C00<04`d011<00a0C4`3L4`0300dC06XC0P044`00I1<00a0C4`044`8000<C3A<00Q<00a0C

4`3L4`0300dC06TC00<04a<011<006@C00<@4a<011<0100C4`d44`0341<C07LCI0000`d0001R00LC

00<04a<011<006<C00<@4a<01A<01@0C4a<=00<C00<@4a<0O1<00`0C4`0/4`0301<C02dC00<=4a<0

;A<00`0C4`0/4`0301<C00XC00<04a<011<006<C00<@4a<01A<00`0C4`024`053A<C4a00fa<00`d0

4`1Z4`0301<000@C001R4`0341<C00HC00<04a<00a<010dC4a3K4`033@0C06XC0`044`00HQ<00a0C

4`064`8011<01@dC4a<@0=XC00<=0000LA<0064C00<@4a<01a<00`0C4`044`043A<C4=TC00<=4`00

LQ<0064C00<@4a<01a<00`0C4`054`033A<@0=TC00<=4`00LQ<0060C00<@4a<021<00`0C4`054`04

3A<C4=PC00<=4`00LQ<0060C00<@4a<021<200LC00<=4a00ea<010dC4`1b4`00Ga<00a0C4`094`03

01<C00LC00<=4a00eQ<00`dC4`02074C001O4`0341<C00TC00<04a<01a<00`dC403E4`053A<C4`00

LQ<005hC00<@4a<02Q<00`0C4`084`033A<@0=@C00D=4a<C001b4`00GQ<00a0C4`0:4`802Q<00`d@

4`3C4`053A<C4`00LQ<005dC00<@4a<02a<00`0C4`0:4`033A0C0=8C00D=4a<C001b4`00GA<00a0C

4`044`D00Q<00`0C4`0:4`033A0C0=8C00@=4a<C0P1a4`00G1<00a0C4`074`0301<C008C00<04a<0

2a<00`d@4`3A4`053A<C4`00LQ<005/C00<@4a<021<00`0C4`024`803A<00`d@4`3@4`053A<C4`00

LQ<005/C00<@4a<021<00`0C4`024`0301<C00`C00<=41<0d1<01@dC4a<0078C001J4`0341<C00TC

00<04a<00Q<00`0C4`0=4`033A0C0<lC00D=4a<C001b4`00FQ<00a0C4`084`8011<00`0C4`0>4`03

3A0C0<hC00@=4a<C0P1a4`00FA<00a0C4`0?4`803a<00`d@4`3>4`053A<C4`00LQ<005PC00<@4a<0

41<00`0C4`0?4`033A0C0<8C00<04a<00Q<00`0C4`024`0300dC008C00<04a<0L1<005PC00<@4a<0

41<00`0C4`0@4`033A0C0<0C00<04`001a<00`0C3@034`0301<C070C001G4`0341<C014C00<04a<0

4A<00`dC4`2o4`0301<000TC00@=4a<C0P1a4`00EQ<00a0C4`0B4`804Q<00`d@4`2o4`0301<000LC

0P001A<=4a<0078C001F4`0341<C018C00<04a<04Q<00`d@4`2n4`0301<000LC00@04a<=0Q<00`0C

4`1`4`00EA<00a0C4`0C4`0301<C01<C00<=4a<0_Q<00`0C4`064`<000@C3A<0LQ<005@C00<@4a<0

51<00`0C4`0C4`033A0C0</C00<=4`00LQ<005<C00<@4a<05A<201DC00<=4a<0bQ<010dC001a4`00

Da<00a0C4`0E4`0301<C01DC00<=4a<0bQ<00`d04`1a4`00DQ<00a0C4`0F4`0301<C01DC00<=41<0

bQ<00`d04`1a4`00DA<00a0C4`0G4`0301<C01HC00<=4a<0bQ<00`dC4`1`4`00DA<00a0C4`0G4`80

61<00`dC4`394`033A<C070C001@4`0341<C01PC00<04a<05a<00a0=4`394`033@0C070C001?4`03

41<C00PC1@024`0301<C008C00<04a<00Q<00`0C4`0H4`033A<C0<PC00<03A<0L1<004lC00<@4a<0

2Q<00`0C4`064`0301<000<C00<04a<06A<00`dC4`374`0300dC070C001>4`0341<C00/C00<04a<0

21<0100C4a<201/C00<=4a<0aQ<00`0C3@1`4`00CA<00a0C4`0<4`0301<C00HC0P044`0301<C01XC

00<=4a<0aQ<00`0C3@1`4`00C1<00a0C4`0=4`0301<C00HC00<04a<00a<00`0C4`0K4`033A<C0<DC

0P000a<=4`1^4`00C1<00a0C4`0<4`8021<300<C00<04a<071<00`dC4`344`0501<C4`d0KQ<004/C

00<@4a<07A<201dC00<=41<0a1<01@0C4a<=06hC001:4`0341<C01hC00<04a<07A<00`dC4`334`03

01<C008C00<=4a<0Ja<004XC00<@4a<07Q<00`0C4`0N4`033A<C0<8C0P034`033A<C06/C00194`03

41<C01lC00<04a<07Q<00`d@4`324`0301<C00<C00<=4a<0JQ<004PC00<@4a<081<2020C00<=41<0

`A<00`0C4`044`033A<C06TC00174`0341<C024C00<04a<081<00`d@4`2i4`D00Q<00`0C4`054`03

3A<C06PC00174`0341<C024C00<04a<081<00`d@4`2k4`0301<C008C00<04a<01A<00`dC4`1X4`00

AQ<00a0C4`0R4`0301<C024C00<=41<0^Q<00`0C4`024`801a<00`dC4`1W4`00AA<00a0C4`0S4`80

8a<00`d@4`2i4`0301<C008C00<04a<01a<00`dC4`1V4`00A1<00a0C4`0T4`0301<C028C00<=4a00

^A<00`0C4`024`0301<C00PC00<=4a<0IA<004@C00<@4a<091<00`0C4`0S4`033A0C0;LC0P044`03

01<C00TC00<=4a<0I1<004<C00<@4a<09A<00`0C4`0T4`033A0C0;`C00<04a<02Q<00`dC4`1S4`00

@Q<00a0C4`0V4`0301<C02DC00<=41<0^a<200`C00<=4a<0HQ<0044C00<@4a<09a<202HC00<=4a00

^a<00`0C4`0<4`033A<C064C00104`0341<C02PC00<04a<09Q<00`dC402j4`0301<C00dC0PeQ4`00

@1<00a0C4`0R4`<00a<00`0C4`0W4`033A<@0;TC00<04a<03a<00`dC4`1N4`00?a<00a0C4`0S4`03

01<C00<C00<04a<0:1<00`d@4`2h4`0301<C010C0PeN4`00?Q<00a0C4`0U4`0301<C008C0P0Y4`03

3A<@0;PC0P0C4`033A<C05/C000m4`0341<C02HC00<04a<00Q<00`0C4`0Y4`033A<@0;LC00<04a<0

4a<00`dC4`1J4`00?A<00a0C4`0U4`0301<000<C00<04a<0:Q<00`dC402f4`0301<C01@C00<=4a<0

FA<003`C00<@4a<09a<00`0C4`024`0301<C02/C00<=4a00]A<00`0C4`0E4`8=FA<003/C00<@4a<0

;A<202`C00@=4a<@]1<201PC00<=4a<0EQ<003XC00<@4a<0;Q<00`0C4`0/4`033A<@0;@C00<04a<0

61<00`dC4`1E4`00>Q<00a0C4`0^4`0301<C02dC00<=4a00/a<00`0C4`0I4`8=EA<003TC00<@4a<0

;a<00`0C4`0^4`033A<@0;8C00<04a<06a<00`dC4`1B4`00>1<00a0C4`0`4`80;a<010dC4a2a4`03

01<C01`C0PeB4`00=a<00a0C4`0a4`0301<C02lC00<=4a00/A<201lC00<=4a<0Ca<003LC00<@4a<0

<A<00`0C4`0`4`033A<@0;0C00<04a<07a<00`dC4`1>4`00=Q<00a0C4`0b4`0301<C030C00@=4a<@

[a<00`0C4`0P4`033A<C04dC000e4`0341<C03<C0P0b4`043A<C49dC1@024`0301<C008C00<04a<0

0Q<00`0C4`0Q4`8=CA<003@C00<@4a<0=1<00`0C4`0a4`053A<C4a00WQ<00`0C4`064`0301<000<C

00<04a<08a<00`dC4`1:4`00<a<00a0C4`0e4`0301<C038C00D=4a<C402M4`0301<C00PC00@04a<C

0P0U4`8=BQ<0038C00<@4a<0=Q<00`0C4`0c4`043A<C49dC00<04a<01Q<200@C00<04a<09Q<23DPC

000a4`0341<C03LC0P0d4`053A<C4a00W1<00`0C4`064`0301<C00<C00<04a<0:1<23DHC000`4`03

41<C03PC00<04a<0=1<01@dC4a<@09XC0P084`<00a<00`0C4`0Z4`8=A1<002lC00<@4a<0:A<300<C

00<04a<00Q<00`0C4`024`0301<C03DC00D=4a<C402Y4`0301<C02`C0Pe24`00;Q<00a0C4`0Z4`03

01<C00LC00<04`000a<00`0C4`0e4`033A<C008C00<@4a<0YQ<202lC00<=4a<0?a<002dC00<@4a<0

;1<00`0C4`084`0401<C4`80=a<00`dC4`024`0341<C0:DC00<04a<0;a<23ClC000/4`0341<C02dC

00<04a<01Q<200@C00<04a<0=a<00`dC4`024`0341<C0:@C00<04a<0<A<00`dC4`0l4`00:a<00a0C

4`0]4`0301<000LC00<04a<00a<00`0C4`0g4`033A<C00<C00<@4a<0Xa<00`0C4`0b4`8=?1<002XC

00<@4a<0;a<00`0C4`064`<00a<00`0C4`0h4`033A<C00<C00<@4a<0XQ<00`0C4`0d4`033A<C03TC

000Y4`0341<C03lC0P0j4`033A<C00<C00<@4a<0XA<203HC0Pdi4`00:1<00a0C4`104`0301<C03XC

00<=4a<00a<00a0C4`2P4`0301<C03LC0Pdg4`009a<00a0C4`114`0301<C03XC00<=4a<011<00a0C

4`2O4`0301<C03TC0Pde4`009Q<00a0C4`124`0301<C03/C00<=4a<011<00a0C4`2N4`0301<C03/C

0Pdc4`009A<00a0C4`134`80?A<00`dC4`044`0341<C09dC0P0n4`8=<A<002@C00<@4a<0A1<00`0C

4`0l4`033A<C00DC00<@4a<0W1<00`0C4`0o4`8=;a<002<C00<@4a<0AA<00`0C4`0m4`033A<C00DC

00<@4a<0Va<00`0C4`114`8=;A<002<C00<@4a<0AA<00`0C4`0n4`033A<C00DC00<@4a<0VQ<00`0C

4`134`8=:a<0028C00<@4a<0AQ<203lC00<=4a<01Q<00a0C4`2I4`0301<C04DC0`dX4`008A<00a0C

4`174`0301<C03lC00<=4a<01Q<00a0C4`2H4`80BA<33BDC000P4`0341<C04PC00<04a<0@1<00`dC

4`064`0341<C09LC00<04a<0Ba<23B<C000O4`0341<C04TC00<04a<0@1<00`dC4`074`0341<C09HC

00<04a<0CA<23B4C000N4`0341<C04XC0P124`033A<C00LC00<@4a<0Sa<300<C00<04a<0Ca<23AlC

000M4`0341<C04/C00<04a<0@Q<00`dC4`074`0341<C08hC00<04a<00a<00`0C4`1A4`8=7A<001`C

00<@4a<0C1<00`0C4`134`033A<C00LC00<@4a<0SQ<00`0C4`024`80E1<23A/C000K4`0341<C04LC

0P044`0301<C04<C00<=4a<021<00a0C4`2=4`0301<C008C00<04a<0EA<33APC000J4`0341<C04XC

00D04a<C00164`033A<C00PC00<@4a<0Ra<00`0C00034`0301<C05PC0PdF4`006A<00a0C4`1:4`03

01<C008C0P164`033A<C00LC00<@4a<0S1<00`0C4`024`0301<C05XC0`dC4`00Ia<00`0C4`3W4`03

01<C05`C00<=4a<04A<006DC00<04`00jA<2074C001V4`0301<C0>PC00<04a<0L1<002`C0`3o4b<C

00<04a<0L1<002`C00<04a<0oa<S4`0301<C070C000]4`0301<C00DC00<04a<0oa>=4`00;A<0100C

4a<300044`0C4`<0oa>:4`00;1<00`0C00024`800Q<00`0C4`024`0301<C0?lCR1<002dC00<04a<0

0a<0100C4`024`0301<C0?lCRA<003<C00@04a<00a<00`0C4`064`0301<C02DC0`0]4`0301<C0?lC

9a<001dC0`000a<0000200`C0`044`<021<00`0C4`0T4`0401<C014C0`000a<00002008C00<04a<0

0Q<00`0C4`024`0301<C00DC00@04a<C1@024`0301<C008C0`000a<000064`80ba<00`0C4`0b4`03

01<C00PC000L4`0401<C02@C00<04a<08a<0100C4`0@4`0401<C00HC00<04`001a<00`0C00044`D0

0a<00`0C4`084`0301<C008C00<04a<00Q<00`0C4`334`0301<C00@C00<04a<04a<00`0C4`0N4`03

01<C00LC000L4`0501<C01<010000a<0000H02/C0`0@4`0501<C01<0100011<04`094`0301<C00@C

00<04a<00a<00`0C4`064`@00Q<00`0C4`034`0301<C0;4C00@04a<C10024`801Q<00`0C4`034`03

01<C008C00<04a<00Q<00`0C4`024`0301<C00DC00@04a<C1@024`0301<C008C0`000a<000064`80

11<0100C4a<2004C0@0100007A<304dC00<04a<03a<300HC00<04`001a<200LC00<04a<00a<00`0C

4`064`0301<000@C00<04a<00Q<00`0C4`2`4`0301<000LC00<04a<011<500<C00L04a<C01<000LC

00<04`0011<500<C00<04a<021<00`0C4`024`0301<C008C00<04a<011<00`0C4`024`0301<0004C

000O4`0301<C04XC0P0C4`0301<C00@C00<04`001a<00`0C4`0<4`0301<C00LC0P024`0301<000@C

00<04`00/1<00`0C00024`@000<C01<01a<00`0C4`034`0701<C4`0C00094`0301<C00@C00<04a<0

0a<00`0C4`064`@00Q<00`0C4`034`0301<C00@C00<04a<00a<1004C0A<001hC0P1P4`801a<00`0C

4`064`<02a<200XC00D04a<C00054`<0UQ<200034`0001DC00<04`001a<00`0C4`064`0301<C00<C

00L04a<C01<000LC0P074`0301<C00<C00<04a<01Q<00`0C00044`0301<C008C00<04a<011<00`0C

4`034`400A<14`00oa=A4`0301<001HC00<04`001a<00`0C000=4`0601<C01<01a<00`0C4`0<4`03

01<C00LC0P024`0301<000@C00<04`000a<00`0C4`034`0301<0004C000Y4`801Q<20?lC7a<00`0C

4`0F4`0301<C00HC0`0>4`0401<C00PC0`0;4`802Q<01@0C4a<000DC0`024`0301<C00<C0P014`40

0@0002/C00<04a<00Q<00`0C4`3o4alC00<04a<0L1<002XC00<04a<00a<00`0C4`054`0301<C0?lC

5Q<00`0C001a4`00:a<00`0C4`024`0301<C008C10034`<0oa<A4`8000<C0000L1<002TC00<04`00

11<00`0C00024`8000<C01<011<00`0C4`3o4h@C000Z4`0301<C00<C0`044`0301<000<C00<04a<0

oa>54`00=a<00`0C00044`0301<C0?lCQ1<003DC0`044`<0oa>64`00oa?54`00oa?54`00oa?54`00

oa?54`00oa?54`00\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.08983, -1.57265, 0.0210011, 0.0210011}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -84.5 0 ]

[.5 .96488 84.5 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -145.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.425) show

222.250000 19.500000 moveto

(C) show

227.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.24937 0 m

.26171 .01758 L

.30316 .07664 L

.34309 .13354 L

.3815 .18828 L

.42237 .24651 L

.46172 .30259 L

.49955 .3565 L

.53984 .41391 L

.57861 .46916 L

.61984 .52791 L

.65954 .58449 L

.69774 .63892 L

.73838 .69684 L

.77751 .7526 L

.81909 .81185 L

.85916 .86895 L

.89771 .92388 L

s

.89771 .92388 m

.91771 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.348622 0.238095 [

[.02381 .33612 -6 -9 ]

[.02381 .33612 6 0 ]

[.2619 .33612 -6 -9 ]

[.2619 .33612 6 0 ]

[.7381 .33612 -3 -9 ]

[.7381 .33612 3 0 ]

[.97619 .33612 -3 -9 ]

[.97619 .33612 3 0 ]

[1.025 .34862 0 -8 ]

[1.025 .34862 9 8 ]

[.4875 .11053 -12 -4.5 ]

[.4875 .11053 0 4.5 ]

[.4875 .22957 -24 -4.5 ]

[.4875 .22957 0 4.5 ]

[.4875 .46767 -18 -4.5 ]

[.4875 .46767 0 4.5 ]

[.4875 .58672 -6 -4.5 ]

[.4875 .58672 0 4.5 ]

[.4875 .70576 -18 -4.5 ]

[.4875 .70576 0 4.5 ]

[.4875 .82481 -6 -4.5 ]

[.4875 .82481 0 4.5 ]

[.5 .88866 -4.5 0 ]

[.5 .88866 4.5 16 ]

[.5 .87616 -137 0 ]

[.5 .87616 137 16 ]

[ 0 0 0 0 ]

[ 1 .86366 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .34862 m

.02381 .35487 L

s

[(-2)] .02381 .33612 0 1 Mshowa

.2619 .34862 m

.2619 .35487 L

s

[(-1)] .2619 .33612 0 1 Mshowa

.7381 .34862 m

.7381 .35487 L

s

[(1)] .7381 .33612 0 1 Mshowa

.97619 .34862 m

.97619 .35487 L

s

[(2)] .97619 .33612 0 1 Mshowa

.125 Mabswid

.07143 .34862 m

.07143 .35237 L

s

.11905 .34862 m

.11905 .35237 L

s

.16667 .34862 m

.16667 .35237 L

s

.21429 .34862 m

.21429 .35237 L

s

.30952 .34862 m

.30952 .35237 L

s

.35714 .34862 m

.35714 .35237 L

s

.40476 .34862 m

.40476 .35237 L

s

.45238 .34862 m

.45238 .35237 L

s

.54762 .34862 m

.54762 .35237 L

s

.59524 .34862 m

.59524 .35237 L

s

.64286 .34862 m

.64286 .35237 L

s

.69048 .34862 m

.69048 .35237 L

s

.78571 .34862 m

.78571 .35237 L

s

.83333 .34862 m

.83333 .35237 L

s

.88095 .34862 m

.88095 .35237 L

s

.92857 .34862 m

.92857 .35237 L

s

.25 Mabswid

0 .34862 m

1 .34862 L

s

gsave

1.025 .34862 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .11053 m

.50625 .11053 L

s

[(-1)] .4875 .11053 1 0 Mshowa

.5 .22957 m

.50625 .22957 L

s

[(-0.5)] .4875 .22957 1 0 Mshowa

.5 .46767 m

.50625 .46767 L

s

[(0.5)] .4875 .46767 1 0 Mshowa

.5 .58672 m

.50625 .58672 L

s

[(1)] .4875 .58672 1 0 Mshowa

.5 .70576 m

.50625 .70576 L

s

[(1.5)] .4875 .70576 1 0 Mshowa

.5 .82481 m

.50625 .82481 L

s

[(2)] .4875 .82481 1 0 Mshowa

.125 Mabswid

.5 .13434 m

.50375 .13434 L

s

.5 .15815 m

.50375 .15815 L

s

.5 .18196 m

.50375 .18196 L

s

.5 .20576 m

.50375 .20576 L

s

.5 .25338 m

.50375 .25338 L

s

.5 .27719 m

.50375 .27719 L

s

.5 .301 m

.50375 .301 L

s

.5 .32481 m

.50375 .32481 L

s

.5 .37243 m

.50375 .37243 L

s

.5 .39624 m

.50375 .39624 L

s

.5 .42005 m

.50375 .42005 L

s

.5 .44386 m

.50375 .44386 L

s

.5 .49148 m

.50375 .49148 L

s

.5 .51529 m

.50375 .51529 L

s

.5 .5391 m

.50375 .5391 L

s

.5 .56291 m

.50375 .56291 L

s

.5 .61053 m

.50375 .61053 L

s

.5 .63434 m

.50375 .63434 L

s

.5 .65815 m

.50375 .65815 L

s

.5 .68196 m

.50375 .68196 L

s

.5 .72957 m

.50375 .72957 L

s

.5 .75338 m

.50375 .75338 L

s

.5 .77719 m

.50375 .77719 L

s

.5 .801 m

.50375 .801 L

s

.5 .08672 m

.50375 .08672 L

s

.5 .06291 m

.50375 .06291 L

s

.5 .0391 m

.50375 .0391 L

s

.5 .01529 m

.50375 .01529 L

s

.5 .84862 m

.50375 .84862 L

s

.25 Mabswid

.5 0 m

.5 .86366 L

s

gsave

.5 .88866 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .87616 -198 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.425) show

298.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

303.000000 15.000000 moveto

(L) show

310.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

317.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

324.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

329.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

333.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .86366 L

0 .86366 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .18121 m

.02576 .18121 L

.03156 .1812 L

.04113 .1812 L

.0543 .18119 L

.07084 .18118 L

.09047 .18117 L

.11286 .18116 L

.13761 .18114 L

.16431 .18112 L

.1925 .18109 L

.2217 .18106 L

.25141 .18103 L

.28112 .18099 L

.31032 .18094 L

.33851 .18089 L

.36521 .18083 L

.38996 .18077 L

.41235 .1807 L

.43198 .18063 L

.44852 .18056 L

.46168 .1805 L

.47125 .18045 L

.47706 .18042 L

.47901 .18041 L

s

.47901 .18041 m

.48114 .18039 L

.48748 .18035 L

.49793 .18028 L

.51231 .18016 L

.53038 .17998 L

.55182 .17969 L

.57627 .17921 L

.6033 .17829 L

.63247 .17613 L

.66326 .16975 L

.69515 .15577 L

.7276 .13842 L

.76005 .12101 L

.79194 .10447 L

.82273 .08912 L

.85189 .07513 L

.87893 .06261 L

.90338 .05161 L

.92482 .04222 L

.94289 .03447 L

.95727 .02841 L

.96772 .02406 L

.97406 .02144 L

.97619 .02056 L

s

.47901 .43267 m

.48114 .40594 L

.48748 .37927 L

.49793 .35287 L

.51231 .32684 L

.53038 .30133 L

.55182 .27648 L

.57627 .25251 L

.6033 .22974 L

.63247 .2091 L

.66326 .19364 L

.69515 .18685 L

.7276 .1846 L

.76005 .18365 L

.79194 .18314 L

.82273 .18284 L

.85189 .18264 L

.87893 .18251 L

.90338 .18241 L

.92482 .18234 L

.94289 .18229 L

.95727 .18225 L

.96772 .18223 L

.97406 .18221 L

.97619 .18221 L

s

.47901 .43279 m

.48114 .45954 L

.48748 .48624 L

.49793 .51272 L

.51231 .53886 L

.53038 .56456 L

.55182 .58969 L

.57627 .61415 L

.6033 .63783 L

.63247 .66064 L

.66326 .68248 L

.69515 .70324 L

.7276 .72285 L

.76005 .74121 L

.79194 .75825 L

.82273 .7739 L

.85189 .78809 L

.87893 .80075 L

.90338 .81184 L

.92482 .8213 L

.94289 .8291 L

.95727 .8352 L

.96772 .83958 L

.97406 .84221 L

.97619 .84309 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<00`0C4`1`4`00oa=B4`0301<C070C001T4`D0j1<00`0C4`1`4`00IQ<00`0C4`3X4`80

LA<0040C00<=4a<07A<300<C00<04a<00Q<20>@C00<04a<0Fa<33A8C00114`033A<C028C00<04a<0

0Q<00`0C4`3S4`0301<C05PC0`dE4`00@A<00`dC4`0R4`0301<C008C00<04a<0ha<00`0C4`1F4`8=

61<0048C00<=4a<081<200@C00<04a<0ha<205DC0PdJ4`00@a<00`dC4`0U4`80i1<00`0C4`1B4`8=

71<004<C00<=4a<09A<00`0C4`3S4`0301<C050C0PdN4`00A1<00`dC4`0T4`0301<C0><C00<04a<0

CA<33B0C00154`033A<C02<C00<04a<0ha<00`0C4`1;4`8=8a<004DC00<=4a<08a<20>@C0P1:4`8=

9A<004HC00<=4a<08Q<00`0C4`3S4`0301<C04LC0PdW4`00Aa<00`dC4`0Q4`0301<C0><C00<04a<0

AA<23BTC00184`033A<C020C00<04a<0ha<00`0C4`134`8=:a<004PC00<=4a<081<20>@C00<04a<0

@1<33BdC00194`033A<C01lC00<04a<0ha<203lC0Pd`4`00BQ<00`dC4`0N4`0301<C0><C00<04a<0

?1<23C8C001:4`033A<C01hC00<04a<0ha<00`0C4`0k4`033A<C038C001;4`033A<C01dC0P3M4`D0

0Q<00`0C4`0i4`8==A<004`C00<=4a<071<00`0C4`3N4`0301<C008C00<04a<0=a<23CLC001<4`03

3A<C00dC00<04a<00Q<00`0C4`024`0301<C008C00<04a<0f1<300<C00<04a<00Q<203HC0Pdi4`00

CA<00`dC4`0;4`0301<000LC00<04`000a<00`0C4`3N4`0301<C008C00<04a<0<a<23C/C001>4`03

3A<C00DC0`024`0301<000TC00@04a<C0P3O4`0301<C008C00<04a<0<A<23CdC001?4`033A<C00TC

00<04`001a<200@C00<04a<0gA<200@C00<04a<0;a<23ClC001?4`033A<C00TC00<04`001a<00`0C

4`034`0301<C0><C0P0^4`8=@A<0050C00<=4a<02A<00`0C4`064`<00a<00`0C4`3S4`0301<C02/C

0Pe34`00DA<00`dC4`0G4`0301<C0><C00<04a<0:A<23DDC001B4`033A<C01HC0P3T4`0301<C02LC

0Pe74`00DQ<00`dC4`0F4`0301<C0><C00<04a<09A<23DTC001C4`033A<C01DC00<04a<0ha<202DC

00<=4a<0BA<005@C00<=4a<051<00`0C4`3S4`0301<C028C0Pe<4`00EA<00`dC4`0C4`80i1<00`0C

4`0P4`8=CQ<005DC00<=4a<04a<00`0C4`3S4`0301<C01`C10e@4`006Q<302DC1@0?4`033A<C018C

00<04a<091<502@C0`2C4`0301<C00XC4PeD4`006Q<00`0C4`0W4`0301<C010C00<=4a<04A<00`0C

4`0V4`0301<C02@C00<04a<0=1=/3BDC;`dB4`005A<300<C00<04a<081<300<C00<04a<04A<00`dC

4`0@4`809a<00`0C4`0U4`0301<C098C00<04a<08Q<=3D4C000K4`0301<C02HC00<04a<04A<00`dC

4`0@4`0301<C02HC00<04a<09A<00`0C4`2B4`0301<C01hC10e>4`006Q<00`0C000W4`0301<C018C

00<=4a<03a<00`0C4`0V4`0301<C02@C00<04`00Ta<00`0C4`0L4`8=DQ<001/C00<04a<09A<201DC

00<=4a<03Q<00`0C4`0U4`809a<00`0C4`2B4`0301<C01XC0PeD4`00FQ<00`dC4`0>4`80i1<201TC

0PeF4`00Fa<00`dC4`0=4`0301<C0><C00<04a<05a<00`dC4`1F4`00G1<00`dC4`0<4`0301<C05/C

0P264`0301<C01HC00<=4a<0Ea<005dC00<=4a<02a<00`0C4`1J4`0301<C07LC00<04a<00Q<00`0C

4`024`0301<C008C00<04a<051<23EXC000E4dP000<=0000HP064`0301<C07HC00<04`001a<00`0C

00034`0301<C01<C00<=4a<0FQ<001TC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C

4`054`0301<C00DC00<04a<01Q<00`0C4`054`0401<C3@@C00<04a<01A<00a0C4`054`0301<C00HC

00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C

4`054`0301<C00PC00<04a<0LA<3008C00<04`002A<0100C4a<201<C00<=4a<0Fa<005lC00<=4a<0

2A<00a0C4`1J4`0301<007HC00<04`001a<200@C00<04a<041<23EhC001O4`033A<C00TC0Q1K4`<0

MQ<00`0C00074`0301<C00<C00<04a<03a<00`dC4`1N4`00H1<00`dC4`084`8@eA<00`0C4`064`<0

0a<00`0C4`0=4`8=HA<0064C00<=4a<01Q<00a00403T4`803A<00`dC4`1Q4`00HA<00`dC4`064`03

400@0>@C00<04a<02a<00`dC4`1R4`00HQ<00`dC4`054`03400@0>@C00<04a<02Q<00`dC4`1S4`00

Ha<00`dC4`034`0541<00100ha<00`0C4`094`033A<C06@C001T4`033A<C008C00D@4`0C403S4`03

01<C00PC00<=4a<0IA<006@C00<=4a<00Q<01A0C01<@0><C0P084`033A<C06HC001U4`073A<C4a0C

00024`0341<C0>0C00<04a<01Q<00`dC4`1W4`00IQ<01@dC4a0C008000<C41<0hA<00`0C4`054`03

3A<C06PC001V4`063A<C41<00Q<00a0C4`3P4`0301<C00DC00<=4a<0J1<006LC00D=41<C00034`03

41<C084C0`0[4`D0:a<00`0C4`044`033A<C02<C1@0/4`<04Q<006PC00@=4a<00a<00a0C4`214`03

01<C02dC00<04a<0:a<200@C00<=4a<09Q<00`0C4`0/4`0301<C018C001X4`033A<C00800Q<00a0C

4`1l4`<00a<00`0C4`0V4`<00a<00`0C4`0[4`0301<C008C00<=4a<09a<00`0C4`0]4`0301<C014C

001W4`0541<=4`0011<00a0C4`214`0301<C02`C00<04a<0:a<00`0C4`024`033A<C02LC00<04a<0

;A<00`0C4`0A4`00G1<00`0C4`024`0301<C008C00H041<C3@044`0341<C080C00<04`00;A<00`0C

4`0[4`0501<C4`d0:Q<00`0C4`0/4`0301<0018C001K4`0301<000LC00<040000Q<00`d04`034`03

41<C084C00<04a<0:a<202dC00D04a<C3@0Y4`80;a<00`0C4`0A4`00Fa<00`0C00084`03400C008C

00<=01<00a<00a0C4`3M4`8000<C3A<0KQ<005/C00<04`001a<00`0@4`034`0300dC00<C00<@4a<0

gA<00`0C3@1`4`00Fa<00`0C00074`0341<C00<C00<03A<011<00a0C4`3L4`0301<=06XC0P044`00

G1<00`0C4`064`03400000<C00<04`d011<00a0C4`3L4`0300dC06TC00<04a<011<006@C00<@4a<0

11<200034`dC008C00<@4a<0N1=U00033@0006401a<00`0C4`044`00I1<00a0C4`044`0401<C3@@C

00<@4a<0O1<00`0C4`064`0301<C00LC00<04a<01Q<00`0C4`074`0301<C00HC00<04a<01a<00`0C

4`064`0301<C00LC00<04a<01a<00`0C4`064`033A<C00LC00<04a<01Q<00`0C4`074`0301<C00HC

00<04a<01a<00`0C4`064`0301<C00LC00<04a<01Q<00`0C4`074`0301<C00LC00<04a<02A<00`0C

4`044`00Ha<00a0C4`054`0501<C4`d00a<00a0C4`1l4`0301<C02`C00<04a<0;A<00`dC4`0]4`03

01<C02dC00<04a<02A<00`0C00044`00Ha<00a0C4`054`0301<C008C00D=4a<C403K4`033@0C06XC

0`044`00HQ<00a0C4`064`0301<C00<C00@=4a<@fa<00`d04`1a4`00HQ<00a0C4`064`8011<01@dC

4a<@0=XC00<=0000LA<0064C00<@4a<01a<00`0C4`044`043A<C4=TC00<=4`00LQ<0064C00<@4a<0

1a<00`0C4`054`033A<@0=TC00<=4`00LQ<0060C00<@4a<021<00`0C4`054`043A<C4=PC00<=4`00

LQ<0060C00<@4a<021<200LC00<=4a00ea<010dC4`1b4`00Ga<00a0C4`094`0301<C00LC00<=4a00

eQ<00`dC4`02074C001O4`0341<C00TC00<04a<01a<00`dC403E4`053A<C4`00LQ<005hC00<@4a<0

2Q<00`0C4`084`033A<@0=@C00D=4a<C001b4`00GQ<00a0C4`0:4`802Q<00`d@4`3C4`053A<C4`00

LQ<005dC00<@4a<02a<00`0C4`0:4`033A0C0=8C00D=4a<C001b4`00GA<00a0C4`044`D00Q<00`0C

4`0:4`033A0C0=8C00@=4a<C0P1a4`00G1<00a0C4`074`0301<C008C00<04a<02a<00`d@4`3A4`05

3A<C4`00LQ<005/C00<@4a<021<00`0C4`024`803A<00`d@4`3@4`053A<C4`00LQ<005/C00<@4a<0

21<00`0C4`024`0301<C00`C00<=41<0d1<01@dC4a<0078C001J4`0341<C00TC00<04a<00Q<00`0C

4`0=4`033A0C0<lC00D=4a<C001b4`00FQ<00a0C4`084`8011<00`0C4`0>4`033A0C0<hC00@=4a<C

0P1a4`00FA<00a0C4`0?4`803a<00`d@4`3>4`053A<C4`00LQ<005PC00<@4a<041<00`0C4`0?4`03

3A0C0<8C00<04a<00Q<00`0C4`024`0300dC008C00<04a<0L1<005PC00<@4a<041<00`0C4`0@4`03

3A0C0<0C00<04`001a<00`0C3@034`0301<C070C001G4`0341<C014C00<04a<04A<00`dC4`2o4`03

01<000TC00@=4a<C0P1a4`00EQ<00a0C4`0B4`804Q<00`d@4`2o4`0301<000LC0P001A<=4a<0078C

001F4`0341<C018C00<04a<04Q<00`d@4`2n4`0301<000LC00@04a<=0Q<00`0C4`1`4`00EA<00a0C

4`0C4`0301<C01<C00<=4a<0_Q<00`0C4`064`<000@C3A<0LQ<005@C00<@4a<051<00`0C4`0D4`03

3A<C0<XC00<=4`00LQ<005<C00<@4a<05A<201DC00<=4a<0bQ<010dC001a4`00Da<00a0C4`0E4`03

01<C01DC00<=4a<0bQ<00`d04`1a4`00DQ<00a0C4`0F4`0301<C01HC00<=4a<0bA<00`d04`1a4`00

DA<00a0C4`0G4`0301<C01HC00<@3A<0bQ<00`dC4`1`4`00DA<00a0C4`0G4`8061<00`dC4`394`03

3A<C070C001@4`0341<C01PC00<04a<05a<00a0=4`394`033@0C070C001?4`0341<C00PC1@024`03

01<C008C00<04a<00Q<00`0C4`0H4`0340dC0<PC00<03A<0L1<004lC00<@4a<02Q<00`0C4`064`03

01<000<C00<04a<06A<00a0=4`374`0300dC070C001>4`0341<C00/C00<04a<021<0100C4a<201/C

00<=4a<0aQ<00`0C3@1`4`00CA<00a0C4`0<4`0301<C00HC0P044`0301<C01XC00<@3A<0aQ<00`0C

3@1`4`00C1<00a0C4`0=4`0301<C00HC00<04a<00a<00`0C4`0K4`033A<C0<DC0P000a<=4`1^4`00

C1<00a0C4`0<4`8021<300<C00<04a<071<00`dC4`344`0501<C4`d0KQ<004/C00<@4a<07A<201hC

00<=4a<0`a<01@0C4a<=06hC001:4`0341<C01hC00<04a<07A<00`dC4`334`0301<C008C00<=4a<0

Ja<004XC00<@4a<07Q<00`0C4`0N4`033A<C0<8C0P034`033A<C06/C00194`0341<C01lC00<04a<0

7Q<00`d@4`324`0301<C00<C00<=4a<0JQ<004PC00<@4a<081<2020C00<=41<0`A<00`0C4`044`03

3A<C06TC00174`0341<C024C00<04a<081<00`d@4`2i4`D00Q<00`0C4`054`033A<C06PC00174`03

41<C024C00<04a<081<00`d@4`2k4`0301<C008C00<04a<01A<00`dC4`1X4`00AQ<00a0C4`0R4`03

01<C024C00<=41<0^Q<00`0C4`024`801a<00`dC4`1W4`00AA<00a0C4`0S4`808a<00`d@4`2i4`03

01<C008C00<04a<01a<00`dC4`1V4`00A1<00a0C4`0T4`0301<C028C00<=4a00^A<00`0C4`024`03

01<C00PC00<=4a<0IA<004@C00<@4a<091<00`0C4`0S4`033A0C0;LC0P044`0301<C00TC00<=4a<0

I1<004<C00<@4a<09A<00`0C4`0T4`033A0C0;`C00<04a<02Q<00`dC4`1S4`00@Q<00a0C4`0V4`03

01<C02DC00<=41<0^a<200`C00<=4a<0HQ<0044C00<@4a<09a<202HC00<=4a00^a<00`0C4`0<4`03

3A<C064C00104`0341<C02PC00<04a<09Q<00`dC402j4`0301<C00dC0PeQ4`00@1<00a0C4`0R4`<0

0a<00`0C4`0W4`033A<@0;TC00<04a<03a<00`dC4`1N4`00?a<00a0C4`0S4`0301<C00<C00<04a<0

:1<00`d@4`2h4`0301<C010C0PeN4`00?Q<00a0C4`0U4`0301<C008C0P0Y4`033A<@0;PC0P0C4`03

3A<C05/C000m4`0341<C02HC00<04a<00Q<00`0C4`0Y4`033A<@0;LC00<04a<04a<00`dC4`1J4`00

?A<00a0C4`0U4`0301<000<C00<04a<0:Q<00`dC402f4`0301<C01@C00<=4a<0FA<003`C00<@4a<0

9a<00`0C4`024`0301<C02/C00<=4a00]A<00`0C4`0E4`8=FA<003/C00<@4a<0;A<202`C00@=4a<@

]1<201PC00<=4a<0EQ<003XC00<@4a<0;Q<00`0C4`0/4`033A<@0;@C00<04a<061<00`dC4`1E4`00

>Q<00a0C4`0^4`0301<C02dC00<=4a00/a<00`0C4`0I4`8=EA<003TC00<@4a<0;a<00`0C4`0^4`03

3A<@0;8C00<04a<06a<00`dC4`1B4`00>1<00a0C4`0`4`80;a<010dC4a2a4`0301<C01`C0PeB4`00

=a<00a0C4`0a4`0301<C02lC00<=4a00/A<201lC00<=4a<0Ca<003LC00<@4a<0<A<00`0C4`0`4`03

3A<@0;0C00<04a<07a<00`dC4`1>4`00=Q<00a0C4`0b4`0301<C030C00@=4a<@[a<00`0C4`0P4`03

3A<C04dC000e4`0341<C03<C0P0b4`043A<C49dC1@024`0301<C008C00<04a<00Q<00`0C4`0Q4`8=

CA<003@C00<@4a<0=1<00`0C4`0b4`043A<C49hC00<04a<01Q<00`0C00034`0301<C02<C00<=4a<0

BQ<003<C00<@4a<0=A<00`0C4`0c4`043A<C49dC00<04a<021<0100C4a<202DC0Pe:4`00<Q<00a0C

4`0f4`0301<C03<C00@=4a<@WA<00`0C4`064`8011<00`0C4`0V4`8=B1<0034C00<@4a<0=a<203DC

00@=4a<@W1<00`0C4`064`0301<C00<C00<04a<0:1<23DHC000`4`0341<C03PC00<04a<0=A<010dC

4a2J4`8021<300<C00<04a<0:Q<23D@C000_4`0341<C02TC0`034`0301<C008C00<04a<00Q<00`0C

4`0e4`053A<C4a00ZA<00`0C4`0/4`8=@Q<002hC00<@4a<0:Q<00`0C4`074`0301<000<C00<04a<0

=Q<01@dC4a<@0:PC0P0_4`033A<C03lC000]4`0341<C02`C00<04a<021<0100C4a<203PC00D=4a<C

402W4`0301<C02lC0Pdo4`00;1<00a0C4`0]4`0301<C00HC0P044`0301<C03LC00<=4a<00Q<00a0C

4`2T4`0301<C034C00<=4a<0?1<002/C00<@4a<0;A<00`0C00074`0301<C00<C00<04a<0>1<00`dC

4`024`0341<C0:<C00<04a<0<Q<23C`C000Z4`0341<C02lC00<04a<01Q<300<C00<04a<0>A<00`dC

4`024`0341<C0:8C00<04a<0=1<23CXC000Y4`0341<C03lC0P0k4`033A<C008C00<@4a<0XA<203LC

0Pdh4`00:1<00a0C4`104`0301<C03XC00<=4a<00a<00a0C4`2P4`0301<C03PC00<=4a<0=A<002LC

00<@4a<0@A<00`0C4`0k4`033A<C00<C00<@4a<0Wa<00`0C4`0i4`8==A<002HC00<@4a<0@Q<00`0C

4`0l4`033A<C00<C00<@4a<0WQ<00`0C4`0k4`8=<a<002DC00<@4a<0@a<203dC00<=4a<011<00a0C

4`2M4`80?Q<23C4C000T4`0341<C04@C00<04a<0?A<00`dC4`044`0341<C09`C00<04a<0?a<23BlC

000S4`0341<C04DC00<04a<0?A<00`dC4`054`0341<C09/C00<04a<0@A<23BdC000S4`0341<C04DC

00<04a<0?Q<00`dC4`054`0341<C09XC00<04a<0@a<33BXC000R4`0341<C04HC0P104`033A<C00DC

00<@4a<0VA<00`0C4`164`8=:1<0024C00<@4a<0Aa<00`0C4`0o4`033A<C00HC00<@4a<0V1<204TC

0`dU4`0081<00a0C4`184`0301<C040C00<=4a<01Q<00a0C4`2G4`0301<C04/C0PdS4`007a<00a0C

4`194`0301<C040C00<=4a<01a<00a0C4`2F4`0301<C04dC0PdQ4`007Q<00a0C4`1:4`80@Q<00`dC

4`074`0341<C08lC0`034`0301<C04lC0PdO4`007A<00a0C4`1;4`0301<C048C00<=4a<01a<00a0C

4`2>4`0301<C00<C00<04a<0DA<23AdC000L4`0341<C04`C00<04a<0@a<00`dC4`074`0341<C08hC

00<04a<00Q<205@C0PdK4`006a<00a0C4`174`8011<00`0C4`134`033A<C00PC00<@4a<0SA<00`0C

4`024`0301<C05DC0`dH4`006Q<00a0C4`1:4`0501<C4`00AQ<00`dC4`084`0341<C08/C00<04`00

0a<00`0C4`1H4`8=5Q<001TC00<@4a<0BQ<00`0C4`024`80AQ<00`dC4`074`0341<C08`C00<04a<0

0Q<00`0C4`1J4`<=4a<006LC00<04a<0ia<00`0C4`1M4`033A<C010C001U4`0301<00>TC0P1a4`00

IQ<00`0C4`3X4`0301<C070C000Z4`<0oa<U4`0301<C070C000Z4`0301<C0?lC9A<00`0C4`1`4`00

:a<00`0C4`044`0301<C0?lCT1<002/C00@04a<C10034`<0oa><4`00:Q<00`0C00024`8000<C01<0

11<00`0C4`3o4hXC000[4`0301<C00<C00<04`000a<00`0C4`3o4h/C000a4`0301<000@C00<04a<0

1Q<00`0C4`0W4`<0:a<00`0C4`3o4bTC000K4`<000<C00000P0<4`<011<300PC00<04a<09Q<0100C

4`0?4`<000<C00000P024`0301<C008C00<04a<00Q<00`0C4`054`0401<C4`D00Q<00`0C4`024`<0

00@C00000a<00`0C4`044`80aA<00`0C4`0g4`0301<C00HC000J4`0401<C02@C00<04a<09A<0100C

4`0>4`0401<C00HC00<04`001a<00`0C00044`D00a<00`0C4`084`0401<C00@C00<04`0011<00`0C

4`2m4`0301<C00@C00<04a<04a<00`0C4`0S4`0301<C00DC000J4`0501<C01<010000a<0000H02dC

0`0>4`0501<C01<0100011<04`094`0301<C00@C00<04a<00a<00`0C4`064`@00Q<00`0C4`034`03

01<C008C00<04a<0Za<0100C4a<4008C0P064`0301<C00<C00<04a<00Q<00`0C4`024`0301<C008C

00<04a<01A<0100C4a<5008C00<04a<00Q<300044`0000<C00<04a<011<200@C00@04a<C0P014`00

6a<304lC00<04a<03A<300HC00<04`001a<200LC00<04a<00a<00`0C4`064`0301<000<C00@04a<C

0P054`0301<C0:XC00<04`001a<00`0C4`044`D00a<01`0C4a<04`001a<00`0C00044`D00a<00`0C

4`084`0401<C00@C00<04`0011<00`0C4`044`0301<C008C0@014`007A<00`0C4`1<4`804A<00`0C

4`044`0301<000LC00<04a<031<00`0C4`074`800Q<00`0C00024`0301<C00@C00<04`00ZQ<00`0C

00024`@000<C01<01a<00`0C4`034`0701<C4`0C00094`0301<C00@C00<04a<00a<00`0C4`064`@0

0Q<00`0C4`034`0301<C008C00<04a<011<00`0C4`034`40000L4`80H1<200LC00<04a<01Q<300/C

0P0:4`0501<C4`000a<300@C0`2C4`8000<C00004Q<00`0C00074`0301<C00HC00<04a<00a<01`0C

4a<04`001a<200LC00<04a<00a<00`0C4`064`0301<000<C00@04a<C0P054`0301<C00@C00<04a<0

0a<10000oa=A4`0301<001<C00<04`001a<00`0C000=4`0601<C01<01a<00`0C4`0<4`0301<C00LC

0P024`0301<0008C00<04a<011<00`0C00034`0301<C00<C0@014`009Q<200HC0P3o4b8C00<04a<0

4a<00`0C4`064`<03Q<0100C4`084`<02a<200XC00D04a<C00034`<011<3008C00<04a<00a<2004C

000X4`0301<C008C00<04a<0oa<R4`0301<C070C000W4`0301<C00<C00<04a<01Q<00`0C4`3o4aPC

00<04`00LA<002PC00<04a<00Q<00`0C4`024`<000@C01<C0`3o4a@C0P000a<0001`4`009Q<00`0C

00044`0301<0008C0P024`0301<C008C00<04a<0oa>74`009a<00`0C4`034`<011<0100C4`024`03

01<C0?lCR1<003@C00@04a<00a<00`0C4`3o4hLC000b4`<011<30?lCRA<00?lCaA<00?lCaA<00?lC

aA<00?lCaA<00?lCaA<00001\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.0739, -1.56638, 0.0209539, 0.0209539}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -82 0 ]

[.5 .96488 82 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -143 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.42) show

217.250000 19.500000 moveto

(C) show

222.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.24849 0 m

.26171 .01877 L

.30316 .07762 L

.34309 .13432 L

.3815 .18887 L

.42237 .2469 L

.46172 .30278 L

.49955 .35651 L

.53984 .41371 L

.57861 .46877 L

.61984 .52731 L

.65954 .5837 L

.69774 .63793 L

.73838 .69565 L

.77751 .75121 L

.81909 .81026 L

.85916 .86715 L

.89771 .92189 L

s

.89771 .92189 m

.91918 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.347166 0.238095 [

[.02381 .33467 -6 -9 ]

[.02381 .33467 6 0 ]

[.2619 .33467 -6 -9 ]

[.2619 .33467 6 0 ]

[.7381 .33467 -3 -9 ]

[.7381 .33467 3 0 ]

[.97619 .33467 -3 -9 ]

[.97619 .33467 3 0 ]

[1.025 .34717 0 -8 ]

[1.025 .34717 9 8 ]

[.4875 .10907 -12 -4.5 ]

[.4875 .10907 0 4.5 ]

[.4875 .22812 -24 -4.5 ]

[.4875 .22812 0 4.5 ]

[.4875 .46621 -18 -4.5 ]

[.4875 .46621 0 4.5 ]

[.4875 .58526 -6 -4.5 ]

[.4875 .58526 0 4.5 ]

[.4875 .70431 -18 -4.5 ]

[.4875 .70431 0 4.5 ]

[.4875 .82336 -6 -4.5 ]

[.4875 .82336 0 4.5 ]

[.5 .88664 -4.5 0 ]

[.5 .88664 4.5 16 ]

[.5 .87414 -134.5 0 ]

[.5 .87414 134.5 16 ]

[ 0 0 0 0 ]

[ 1 .86164 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .34717 m

.02381 .35342 L

s

[(-2)] .02381 .33467 0 1 Mshowa

.2619 .34717 m

.2619 .35342 L

s

[(-1)] .2619 .33467 0 1 Mshowa

.7381 .34717 m

.7381 .35342 L

s

[(1)] .7381 .33467 0 1 Mshowa

.97619 .34717 m

.97619 .35342 L

s

[(2)] .97619 .33467 0 1 Mshowa

.125 Mabswid

.07143 .34717 m

.07143 .35092 L

s

.11905 .34717 m

.11905 .35092 L

s

.16667 .34717 m

.16667 .35092 L

s

.21429 .34717 m

.21429 .35092 L

s

.30952 .34717 m

.30952 .35092 L

s

.35714 .34717 m

.35714 .35092 L

s

.40476 .34717 m

.40476 .35092 L

s

.45238 .34717 m

.45238 .35092 L

s

.54762 .34717 m

.54762 .35092 L

s

.59524 .34717 m

.59524 .35092 L

s

.64286 .34717 m

.64286 .35092 L

s

.69048 .34717 m

.69048 .35092 L

s

.78571 .34717 m

.78571 .35092 L

s

.83333 .34717 m

.83333 .35092 L

s

.88095 .34717 m

.88095 .35092 L

s

.92857 .34717 m

.92857 .35092 L

s

.25 Mabswid

0 .34717 m

1 .34717 L

s

gsave

1.025 .34717 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .10907 m

.50625 .10907 L

s

[(-1)] .4875 .10907 1 0 Mshowa

.5 .22812 m

.50625 .22812 L

s

[(-0.5)] .4875 .22812 1 0 Mshowa

.5 .46621 m

.50625 .46621 L

s

[(0.5)] .4875 .46621 1 0 Mshowa

.5 .58526 m

.50625 .58526 L

s

[(1)] .4875 .58526 1 0 Mshowa

.5 .70431 m

.50625 .70431 L

s

[(1.5)] .4875 .70431 1 0 Mshowa

.5 .82336 m

.50625 .82336 L

s

[(2)] .4875 .82336 1 0 Mshowa

.125 Mabswid

.5 .13288 m

.50375 .13288 L

s

.5 .15669 m

.50375 .15669 L

s

.5 .1805 m

.50375 .1805 L

s

.5 .20431 m

.50375 .20431 L

s

.5 .25193 m

.50375 .25193 L

s

.5 .27574 m

.50375 .27574 L

s

.5 .29955 m

.50375 .29955 L

s

.5 .32336 m

.50375 .32336 L

s

.5 .37098 m

.50375 .37098 L

s

.5 .39479 m

.50375 .39479 L

s

.5 .41859 m

.50375 .41859 L

s

.5 .4424 m

.50375 .4424 L

s

.5 .49002 m

.50375 .49002 L

s

.5 .51383 m

.50375 .51383 L

s

.5 .53764 m

.50375 .53764 L

s

.5 .56145 m

.50375 .56145 L

s

.5 .60907 m

.50375 .60907 L

s

.5 .63288 m

.50375 .63288 L

s

.5 .65669 m

.50375 .65669 L

s

.5 .6805 m

.50375 .6805 L

s

.5 .72812 m

.50375 .72812 L

s

.5 .75193 m

.50375 .75193 L

s

.5 .77574 m

.50375 .77574 L

s

.5 .79955 m

.50375 .79955 L

s

.5 .08526 m

.50375 .08526 L

s

.5 .06145 m

.50375 .06145 L

s

.5 .03764 m

.50375 .03764 L

s

.5 .01383 m

.50375 .01383 L

s

.5 .84717 m

.50375 .84717 L

s

.25 Mabswid

.5 0 m

.5 .86164 L

s

gsave

.5 .88664 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .87414 -195.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.42) show

293.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

298.000000 15.000000 moveto

(L) show

305.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

312.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

319.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

324.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

328.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .86164 L

0 .86164 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .17932 m

.02576 .17931 L

.03156 .17931 L

.04113 .17931 L

.0543 .17931 L

.07084 .1793 L

.09047 .17929 L

.11285 .17929 L

.1376 .17928 L

.1643 .17927 L

.19249 .17925 L

.22169 .17924 L

.2514 .17922 L

.2811 .1792 L

.3103 .17917 L

.33849 .17914 L

.36519 .17911 L

.38994 .17908 L

.41233 .17904 L

.43195 .17901 L

.44849 .17897 L

.46166 .17894 L

.47123 .17891 L

.47704 .17889 L

.47898 .17888 L

s

.47898 .17888 m

.48111 .17888 L

.48745 .17886 L

.49791 .17882 L

.51229 .17875 L

.53036 .17866 L

.5518 .1785 L

.57625 .17824 L

.60329 .17773 L

.63245 .17646 L

.66324 .17155 L

.69514 .1572 L

.72759 .13917 L

.76004 .12142 L

.79193 .1047 L

.82272 .08924 L

.85189 .07519 L

.87893 .06262 L

.90338 .05161 L

.92482 .0422 L

.94288 .03444 L

.95727 .02837 L

.96772 .02401 L

.97406 .02139 L

.97619 .02052 L

s

.47898 .43125 m

.48111 .40453 L

.48745 .37787 L

.49791 .35146 L

.51229 .32541 L

.53036 .29985 L

.5518 .2749 L

.57625 .25074 L

.60329 .22759 L

.63245 .20609 L

.66324 .1892 L

.69514 .18282 L

.72759 .18126 L

.76004 .18068 L

.79193 .18039 L

.82272 .18022 L

.85189 .1801 L

.87893 .18003 L

.90338 .17997 L

.92482 .17993 L

.94288 .17991 L

.95727 .17988 L

.96772 .17987 L

.97406 .17986 L

.97619 .17986 L

s

.47898 .43136 m

.48111 .45809 L

.48745 .48477 L

.49791 .51122 L

.51229 .53733 L

.53036 .56299 L

.5518 .58809 L

.57625 .61252 L

.60329 .63617 L

.63245 .65895 L

.66324 .68075 L

.69514 .70148 L

.72759 .72106 L

.76004 .7394 L

.79193 .75641 L

.82272 .77204 L

.85189 .7862 L

.87893 .79885 L

.90338 .80992 L

.92482 .81937 L

.94288 .82715 L

.95727 .83325 L

.96772 .83762 L

.97406 .84024 L

.97619 .84112 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<00`0C4`1`4`00oa=B4`0301<C070C001T4`D0j1<2074C001V4`0301<C0>PC00<04a<0

L1<0040C00<=4a<07A<300<C00<04a<00Q<20>@C00<04a<0Fa<33A8C00114`033A<C028C00<04a<0

0Q<00`0C4`3S4`0301<C05PC0`dE4`00@A<00`dC4`0R4`0301<C008C00<04a<0ha<00`0C4`1F4`8=

61<0048C00<=4a<081<200@C00<04a<0ha<205DC0PdJ4`00@a<00`dC4`0U4`80i1<00`0C4`1B4`8=

71<004<C00<=4a<09A<00`0C4`3S4`0301<C050C0PdN4`00A1<00`dC4`0T4`0301<C0><C00<04a<0

CA<33B0C00154`033A<C02<C00<04a<0ha<00`0C4`1;4`8=8a<004DC00<=4a<08a<20>@C0P1:4`8=

9A<004HC00<=4a<08Q<00`0C4`3S4`0301<C04LC0PdW4`00Aa<00`dC4`0Q4`0301<C0><C00<04a<0

AA<23BTC00184`033A<C020C00<04a<0ha<00`0C4`134`8=:a<004PC00<=4a<081<20>@C00<04a<0

@1<33BdC00194`033A<C01lC00<04a<0ha<203lC0Pd`4`00BQ<00`dC4`0N4`0301<C0><C00<04a<0

?1<23C8C001:4`033A<C01hC00<04a<0g1<5008C00<04a<0>a<00`dC4`0b4`00Ba<00`dC4`0M4`80

ga<00`0C4`024`0301<C03TC0Pde4`00C1<00`dC4`0L4`0301<C0=PC0`034`0301<C008C0P0h4`8=

=a<004`C00<=4a<03A<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`3N4`0301<C008C00<04a<0

=A<23CTC001=4`033A<C00/C00<04`001a<00`0C00034`0301<C0=hC00<04a<00Q<00`0C4`0c4`8=

>a<004hC00<=4a<01A<3008C00<04`002A<0100C4a<20=hC0P044`0301<C034C0Pdm4`00Ca<00`dC

4`094`0301<000LC0P044`0301<C0><C00<04a<0;a<23ClC001?4`033A<C00TC00<04`001a<00`0C

4`034`0301<C0><C0P0_4`033A<C03lC001@4`033A<C00TC00<04a<01Q<300<C00<04a<0ha<00`0C

4`0/4`8=@Q<0054C00<=4a<05a<00`0C4`3S4`0301<C02XC0Pe44`00DQ<00`dC4`0F4`80i1<00`0C

4`0X4`8=AQ<0058C00<=4a<05Q<00`0C4`3S4`0301<C02HC0Pe84`00Da<00`dC4`0E4`0301<C0><C

0P0U4`8=BQ<005@C00<=4a<051<00`0C4`3S4`0301<C028C0Pe<4`00EA<00`dC4`0C4`80i1<00`0C

4`0P4`8=CQ<005DC00<=4a<04a<00`0C4`3S4`0301<C01`C10e@4`006Q<302DC1@0?4`033A<C018C

00<04a<091<502@C0`2>4b@=E1<001XC00<04a<09a<00`0C4`0@4`033A<C014C00<04a<09Q<00`0C

4`0T4`0301<C03<CF`d54`8091<k3A8C000E4`<00a<00`0C4`0P4`<00a<00`0C4`0A4`033A<C010C

0P0W4`0301<C02DC00<04a<0TQ<00`0C4`0P4`<=CA<001/C00<04a<09Q<00`0C4`0A4`033A<C010C

00<04a<09Q<00`0C4`0U4`0301<C098C00<04a<07Q<23E0C000J4`0301<002LC00<04a<04Q<00`dC

4`0?4`0301<C02HC00<04a<091<00`0C002C4`0301<C01`C0PeB4`006a<00`0C4`0U4`805A<00`dC

4`0>4`0301<C02DC0P0W4`0301<C098C00<04a<06Q<23E@C001J4`033A<C00hC0P3T4`806A<23EHC

001K4`033A<C00dC00<04a<0ha<00`0C4`0F4`8=F1<005`C00<=4a<031<00`0C4`1K4`80Ma<00`0C

4`024`0301<C008C00<04a<00Q<00`0C4`0E4`033A<C05PC001M4`033A<C00/C00<04a<0FQ<00`0C

4`1f4`0301<000LC00<04`000a<00`0C4`0C4`8=Fa<001DCB0000`d0001R00HC00<04a<0LA<3008C

00<04`002A<0100C4a<201<C00<=4a<0Fa<001TC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<0

1A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0401<C3@@C00<04a<01A<00a0C4`054`03

01<C00HC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<0

1A<00`0C4`054`0301<C00PC00<04a<0MQ<00`0C00074`8011<00`0C4`0A4`033A<C05`C001O4`03

3A<C00TC00<@4a<0FQ<00`0C001f4`0301<000LC00<04a<00a<00`0C4`0@4`033A<C05dC001O4`03

3A<C00TC0Q1K4`<0Ma<00`0C4`064`<00a<00`0C4`0>4`8=H1<0060C00<=4a<021<24>@C00<04a<0

3A<00`dC4`1P4`00HA<00`dC4`064`03400@0>@C0P0=4`033A<C064C001Q4`033A<C00HC00<@0100

i1<00`0C4`0;4`033A<C068C001R4`033A<C00DC00<@0100i1<00`0C4`0:4`033A<C06<C001S4`03

3A<C00<C00D@4`00403S4`0301<C00XC00<=4a<0Ha<006@C00<=4a<00Q<01A0C01<@0><C00<04a<0

2A<00`dC4`1T4`00I1<00`dC4`024`0541<04a00ha<200TC00<=4a<0IA<006DC00L=4a<C41<0008C

00<@4a<0h1<00`0C4`074`033A<C06HC001V4`053A<C41<00P000a<@4`3Q4`0301<C00HC00<=4a<0

Ia<006HC00H=4a<@4`024`0341<C0>0C00<04a<01A<00`dC4`1X4`00Ia<01@d@4a<000<C00<@4a<0

P1<302`C1@0[4`0301<C00@C00<=4a<08a<502`C0`0B4`00J1<010dC4`034`0341<C080C00<04a<0

;Q<00`0C4`0[4`8011<00`dC4`0V4`0301<C02`C00<04a<04Q<006PC00<=4a<00P024`0341<C07/C

0`034`0301<C02LC0`034`0301<C02/C00<04a<00Q<00`dC4`0W4`0301<C02dC00<04a<04A<006LC

00D@4`dC00044`0341<C080C00<04a<0;A<00`0C4`0[4`0301<C008C00<=4a<09a<00`0C4`0]4`03

01<C014C001L4`0301<C008C00<04a<00Q<01P0@4a<=00@C00<@4a<0Oa<00`0C000^4`0301<C02/C

00D04a<C3@0Z4`0301<C02`C00<04`004Q<005/C00<04`001a<00`0@00024`033@0C00<C00<@4a<0

P1<00`0C4`0/4`80;A<01@0C4a<=02TC0P0_4`0301<C014C001K4`0301<000PC00<@01<00Q<00`d0

4`034`0341<C0=dC0P000a<=4`1^4`00Fa<00`0C00074`03010C00<C00<03A<00a<00a0C4`3M4`03

01<=070C001K4`0301<000LC00<@4a<00a<00`0=4`044`0341<C0=`C00<04`d0Ja<200<C001L4`03

01<C00HC00<@00000a<00`0C3@044`0341<C0=`C00<03A<0JQ<00`0C4`034`00I1<00a0C4`044`80

00<C3A<00Q<00a0C4`1h4fD000<=0000HP074`0301<C00<C001T4`0341<C00@C00@04a<=11<00a0C

4`1k4`0301<C00LC00<04a<01a<00`0C4`064`0301<C00LC00<04a<01Q<00`0C4`074`0301<C00HC

00<04a<01a<00`0C4`074`0301<C00HC00<=4a<01a<00`0C4`064`0301<C00LC00<04a<01Q<00`0C

4`074`0301<C00HC00<04a<01a<00`0C4`074`0301<C00HC00<04a<01a<00`0C4`0:4`0301<C00<C

001S4`0341<C00DC00D04a<C3@034`0341<C07/C00<04a<0;A<00`0C4`0]4`033A<C02dC00<04a<0

;A<00`0C4`0:4`0301<000<C001S4`0341<C00DC00<04a<00Q<01@dC4a<@0=/C00<=01<0Ja<300<C

001R4`0341<C00HC00<04a<00a<010dC4a3K4`033@0C074C001R4`0341<C00HC0P044`053A<C4a00

fA<010dC001a4`00HA<00a0C4`074`0301<C00@C00@=4a<@fA<00`dC001b4`00HA<00a0C4`074`03

01<C00DC00<=4a00fA<00`dC001b4`00H1<00a0C4`084`0301<C00DC00@=4a<@ea<010dC4`1b4`00

H1<00a0C4`084`801a<00`dC403G4`043A<C078C001O4`0341<C00TC00<04a<01a<00`dC403F4`03

3A<C0080LA<005lC00<@4a<02A<00`0C4`074`033A<@0=DC00D=4a<C001b4`00GQ<00a0C4`0:4`03

01<C00PC00<=4a00e1<01@dC4a<0078C001N4`0341<C00XC0P0:4`033A0C0=<C00D=4a<C001b4`00

GA<00a0C4`0;4`0301<C00XC00<=41<0dQ<01@dC4a<0078C001M4`0341<C00@C1@024`0301<C00XC

00<=41<0dQ<010dC4a<2074C001L4`0341<C00LC00<04a<00Q<00`0C4`0;4`033A0C0=4C00D=4a<C

001b4`00Fa<00a0C4`084`0301<C008C0P0=4`033A0C0=0C00D=4a<C001b4`00Fa<00a0C4`084`03

01<C008C00<04a<031<00`d@4`3@4`053A<C4`00LQ<005XC00<@4a<02A<00`0C4`024`0301<C00dC

00<=41<0ca<010dC4a<2074C001J4`0341<C00PC0P044`0301<C00hC00<=41<0cQ<01@dC4a<0078C

001I4`0341<C00lC0P0?4`033A0C0<hC00D=4a<C001b4`00F1<00a0C4`0@4`0301<C00lC00<=41<0

`Q<00`0C4`024`0301<C008C00<03A<00Q<00`0C4`1`4`00F1<00a0C4`0@4`0301<C010C00<=41<0

`1<00`0C00074`0301<=00<C00<04a<0L1<005LC00<@4a<04A<00`0C4`0A4`033A<C0;lC00<04`00

2A<010dC4a<2074C001F4`0341<C018C0P0B4`033A0C0;lC00<04`001a<200054`dC4`00LQ<005HC

00<@4a<04Q<00`0C4`0B4`033A0C0;hC00<04`001a<0100C4`d24`0301<C070C001E4`0341<C01<C

00<04a<04a<00`dC4`2n4`0301<C00HC0`0011<=4`1b4`00E1<00a0C4`0D4`0301<C01@C00<=4a<0

bQ<00`dC001b4`00Da<00a0C4`0E4`805A<00`dC4`3:4`043A<0074C001C4`0341<C01DC00<04a<0

5A<00`dC4`3:4`033@0C074C001B4`0341<C01HC00<04a<05Q<00`dC4`394`033@0C074C001A4`03

41<C01LC00<04a<05Q<00a0=4`3:4`033A<C070C001A4`0341<C01LC0P0H4`033A<C0<TC00<=4a<0

L1<0050C00<@4a<061<00`0C4`0G4`0340dC0<TC00<=01<0L1<004lC00<@4a<021<5008C00<04a<0

0Q<00`0C4`024`0301<C01PC00<@3A<0b1<00`0=4`1`4`00Ca<00a0C4`0:4`0301<C00HC00<04`00

0a<00`0C4`0I4`0340dC0<LC00<03A<0L1<004hC00<@4a<02a<00`0C4`084`0401<C4`806a<00`dC

4`364`0301<=070C001=4`0341<C00`C00<04a<01Q<200@C00<04a<06Q<00a0=4`364`0301<=070C

001<4`0341<C00dC00<04a<01Q<00`0C4`034`0301<C01/C00<=4a<0aA<200034`dC06hC001<4`03

41<C00`C0P084`<00a<00`0C4`0L4`033A<C0<@C00D04a<C3@1^4`00Ba<00a0C4`0M4`807Q<00`dC

4`334`0501<C4`d0KQ<004XC00<@4a<07Q<00`0C4`0M4`033A<C0<<C00<04a<00Q<00`dC4`1[4`00

BQ<00a0C4`0N4`0301<C01hC00<=4a<0`Q<200<C00<=4a<0Ja<004TC00<@4a<07a<00`0C4`0N4`03

3A0C0<8C00<04a<00a<00`dC4`1Z4`00B1<00a0C4`0P4`8081<00`d@4`314`0301<C00@C00<=4a<0

JA<004LC00<@4a<08A<00`0C4`0P4`033A0C0;TC1@024`0301<C00DC00<=4a<0J1<004LC00<@4a<0

8A<00`0C4`0Q4`033A<C0;XC00<04a<00Q<00`0C4`064`033A<C06LC00164`0341<C028C00<04a<0

8A<00`d@4`2j4`0301<C008C0P084`033A<C06HC00154`0341<C02<C0P0S4`033A0C0;TC00<04a<0

0Q<00`0C4`084`033A<C06DC00144`0341<C02@C00<04a<08a<00`d@4`2h4`0301<C008C00<04a<0

2A<00`dC4`1T4`00A1<00a0C4`0T4`0301<C02@C00<=4a<0]Q<200@C00<04a<02Q<00`dC4`1S4`00

@a<00a0C4`0U4`0301<C02@C00<=41<0_1<00`0C4`0:4`033A<C06<C00124`0341<C02HC00<04a<0

9A<00`d@4`2k4`8031<00`dC4`1R4`00@A<00a0C4`0W4`809a<00`d@4`2j4`0301<C00`C00<=4a<0

HA<0040C00<@4a<0:1<00`0C4`0W4`033A0C0;TC00<04a<03A<23F4C00104`0341<C028C0`034`03

01<C02LC00<=4a00^A<00`0C4`0?4`033A<C05hC000o4`0341<C02<C00<04a<00a<00`0C4`0X4`03

3A0C0;PC00<04a<041<23EhC000n4`0341<C02DC00<04a<00Q<202XC00<=41<0]a<201<C00<=4a<0

Fa<003dC00<@4a<09Q<00`0C4`024`0301<C02TC00<=4a00]a<00`0C4`0C4`033A<C05XC000m4`03

41<C02DC00<04`000a<00`0C4`0Z4`033A<@0;HC00<04a<051<00`dC4`1I4`00?1<00a0C4`0W4`03

01<C008C00<04a<0:a<00`dC402e4`0301<C01DC0PeI4`00>a<00a0C4`0]4`80;A<00`dC402d4`80

61<00`dC4`1F4`00>Q<00a0C4`0^4`0301<C02`C00<=4a00]1<00`0C4`0H4`033A<C05DC000j4`03

41<C02hC00<04a<0;A<00`dC402c4`0301<C01TC0PeE4`00>A<00a0C4`0_4`0301<C02hC00<=4a00

/Q<00`0C4`0K4`033A<C058C000h4`0341<C030C0P0_4`043A<C4;4C00<04a<071<23E8C000g4`03

41<C034C00<04a<0;a<00`dC402a4`807a<00`dC4`1?4`00=a<00a0C4`0a4`0301<C030C00<=4a00

/1<00`0C4`0O4`8=Ca<003HC00<@4a<0<Q<00`0C4`0`4`043A<C4:lC00<04a<08A<00`dC4`1<4`00

=A<00a0C4`0c4`80<Q<010dC4a2M4`D00Q<00`0C4`024`0301<C008C00<04a<08Q<23D`C000d4`03

41<C03@C00<04a<0<Q<010dC4a2N4`0301<C00HC00<04`000a<00`0C4`0T4`033A<C04TC000c4`03

41<C03DC00<04a<0<a<010dC4a2M4`0301<C00PC00@04a<C0P0V4`8=BA<0038C00<@4a<0=Q<00`0C

4`0c4`043A<C49dC00<04a<01Q<200@C00<04a<09a<23DLC000a4`0341<C03LC0P0e4`043A<C49`C

00<04a<01Q<00`0C4`034`0301<C02TC0Pe54`00<1<00a0C4`0h4`0301<C03DC00@=4a<@VQ<200PC

0`034`0301<C02/C00<=4a<0@Q<002lC00<@4a<0:A<300<C00<04a<00Q<00`0C4`024`0301<C03DC

00D=4a<C402Y4`0301<C02`C0Pe24`00;Q<00a0C4`0Z4`0301<C00LC00<04`000a<00`0C4`0f4`05

3A<C4a00Z1<202lC00<=4a<0?a<002dC00<@4a<0;1<00`0C4`084`0401<C4`80>1<01@dC4a<@0:LC

00<04a<0;a<23ClC000/4`0341<C02dC00<04a<01Q<200@C00<04a<0=a<00`dC4`024`0341<C0:@C

00<04a<0<A<00`dC4`0l4`00:a<00a0C4`0]4`0301<000LC00<04a<00a<00`0C4`0h4`033A<C008C

00<@4a<0Xa<00`0C4`0b4`8=?1<002XC00<@4a<0;a<00`0C4`064`<00a<00`0C4`0i4`033A<C008C

00<@4a<0XQ<00`0C4`0d4`8=>Q<002TC00<@4a<0?a<203/C00<=4a<00Q<00a0C4`2Q4`80=a<23CPC

000X4`0341<C040C00<04a<0>Q<00`dC4`034`0341<C0:0C00<04a<0>1<00`dC4`0e4`009a<00a0C

4`114`0301<C03/C00<=4a<00a<00a0C4`2O4`0301<C03TC0Pde4`009Q<00a0C4`124`0301<C03`C

00<=4a<00a<00a0C4`2N4`0301<C03/C0Pdc4`009A<00a0C4`134`80?A<00`dC4`044`0341<C09dC

0P0n4`8=<A<002@C00<@4a<0A1<00`0C4`0m4`033A<C00@C00<@4a<0W1<00`0C4`0o4`8=;a<002<C

00<@4a<0AA<00`0C4`0n4`033A<C00@C00<@4a<0Va<00`0C4`114`8=;A<002<C00<@4a<0AA<00`0C

4`0n4`033A<C00DC00<@4a<0VQ<00`0C4`134`<=:Q<0028C00<@4a<0AQ<2040C00<=4a<01A<00a0C

4`2I4`0301<C04HC0PdX4`008A<00a0C4`174`0301<C040C00<=4a<01A<00a0C4`2H4`80BA<33BDC

000P4`0341<C04PC00<04a<0@1<00`dC4`064`0341<C09LC00<04a<0Ba<23B<C000O4`0341<C04TC

00<04a<0@A<00`dC4`064`0341<C09HC00<04a<0CA<23B4C000N4`0341<C04XC0P134`033A<C00HC

00<@4a<0Sa<300<C00<04a<0Ca<23AlC000M4`0341<C04/C00<04a<0@Q<00`dC4`074`0341<C08hC

00<04a<00a<00`0C4`1A4`8=7A<001`C00<@4a<0C1<00`0C4`134`033A<C00LC00<@4a<0SQ<00`0C

4`024`80E1<23A/C000K4`0341<C04LC0P044`0301<C04@C00<=4a<01a<00a0C4`2=4`0301<C008C

00<04a<0EA<33APC000J4`0341<C04XC00D04a<C00164`033A<C00PC00<@4a<0Ra<00`0C00034`03

01<C05PC0PdF4`006A<00a0C4`1:4`0301<C008C0P164`033A<C00LC00<@4a<0S1<00`0C4`024`03

01<C05XC0`dC4`00Ia<00`0C4`3W4`0301<C05dC00<=4a<041<006DC00<04`00jA<2074C001V4`03

01<C0>PC00<04a<0L1<002`C0`3o4b<C00<04a<0L1<002`C00<04a<0oa<S4`0301<C070C000]4`03

01<C00DC00<04a<0oa>=4`00;A<0100C4a<300044`0C4`<0oa>:4`00;1<00`0C00024`800Q<00`0C

4`024`0301<C0?lCR1<002dC00<04a<00a<0100C4`024`0301<C0?lCRA<003<C00@04a<00a<00`0C

4`064`0301<C02DC0`0]4`0301<C0?lC9a<001dC0`000a<0000200`C0`044`<021<00`0C4`0T4`04

01<C014C0`000a<00002008C00<04a<00Q<00`0C4`024`0301<C00DC00@04a<C1@024`0301<C008C

0`0011<000054`80ba<00`0C4`0b4`0301<C00PC000L4`0401<C02@C00<04a<08a<0100C4`0@4`04

01<C00HC00<04`001a<00`0C00044`D00a<00`0C4`084`0401<C00HC00<04a<0`a<00`0C4`044`03

01<C01<C00<04a<07Q<00`0C4`074`0071<01@0C4`0C00@000<C0000600[4`<041<01@0C4`0C00@0

00@C01<02A<00`0C4`044`0301<C00<C00<04a<01Q<4008C00<04a<00a<00`0C4`2a4`0401<C4`@0

0Q<200HC00<04a<00a<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`054`0401<C4`D00Q<00`0C

4`024`<000@C00001A<200@C00@04a<C0P014`400@0001dC0`1=4`0301<C00lC0`064`0301<000LC

0P074`0301<C00<C00<04a<01Q<00`0C00034`0301<C00<C00<04a<0/1<00`0C00074`0301<C00@C

1@034`0701<C4`0C00074`0301<000@C1@034`0301<C00PC00@04a<01Q<00`0C4`044`0301<C008C

00<04`000A<001lC00<04a<0BQ<201<C00<04a<011<00`0C00074`0301<C00`C00<04a<01a<2008C

00<04`0011<00`0C002`4`0301<0008C10000a<04`074`0301<C00<C00L04a<C01<000TC00<04a<0

11<00`0C4`034`0301<C00HC10024`0301<C00<C00<04a<011<00`0C4`034`400A<14`007Q<2060C

0P074`0301<C00HC0`0;4`802Q<01@0C4a<000DC0`2F4`8000<C00005A<00`0C00074`0301<C00HC

00<04a<00a<01`0C4a<04`001a<200LC00<04a<00a<00`0C4`064`0301<000<C00<04a<00a<00`0C

4`044`0301<C00<C0@014`4C003o4e4C00<04`005Q<00`0C00074`0301<000dC00H04a<04`074`03

01<C00`C00<04a<01a<2008C00<04`0011<00`0C00034`0301<C00<C00<04`000A<002TC0P064`80

oa<O4`0301<C01HC00<04a<01Q<300hC00@04a<021<300/C0P0:4`0501<C4`001A<3008C00<04a<0

0a<2004C0@010000:a<00`0C4`024`0301<C0?lC7a<00`0C4`1`4`00:Q<00`0C4`034`0301<C00DC

00<04a<0oa<F4`0301<0074C000[4`0301<C008C00<04a<00Q<400<C0`3o4a4C0P000a<0001`4`00

:A<00`0C00044`0301<0008C0P000a<04`044`0301<C0?lCQ1<002XC00<04a<00a<300@C00<04`00

0a<00`0C4`3o4hDC000g4`0301<000@C00<04a<0oa>44`00=A<300@C0`3o4hHC003o4lDC003o4lDC

003o4lDC003o4lDC003o4lDC0000\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.05783, -1.56004, 0.0209063, 0.0209063}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -84.5 0 ]

[.5 .96488 84.5 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -145.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.415) show

222.250000 19.500000 moveto

(C) show

227.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.2476 0 m

.26171 .01996 L

.30316 .07861 L

.34309 .13511 L

.3815 .18946 L

.42237 .24729 L

.46172 .30297 L

.49955 .35651 L

.53984 .41352 L

.57861 .46838 L

.61984 .52671 L

.65954 .5829 L

.69774 .63694 L

.73838 .69445 L

.77751 .74982 L

.81909 .80866 L

.85916 .86536 L

.89771 .9199 L

s

.89771 .9199 m

.92066 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.345693 0.238095 [

[.02381 .33319 -6 -9 ]

[.02381 .33319 6 0 ]

[.2619 .33319 -6 -9 ]

[.2619 .33319 6 0 ]

[.7381 .33319 -3 -9 ]

[.7381 .33319 3 0 ]

[.97619 .33319 -3 -9 ]

[.97619 .33319 3 0 ]

[1.025 .34569 0 -8 ]

[1.025 .34569 9 8 ]

[.4875 .1076 -12 -4.5 ]

[.4875 .1076 0 4.5 ]

[.4875 .22664 -24 -4.5 ]

[.4875 .22664 0 4.5 ]

[.4875 .46474 -18 -4.5 ]

[.4875 .46474 0 4.5 ]

[.4875 .58379 -6 -4.5 ]

[.4875 .58379 0 4.5 ]

[.4875 .70284 -18 -4.5 ]

[.4875 .70284 0 4.5 ]

[.4875 .82188 -6 -4.5 ]

[.4875 .82188 0 4.5 ]

[.5 .8846 -4.5 0 ]

[.5 .8846 4.5 16 ]

[.5 .8721 -137 0 ]

[.5 .8721 137 16 ]

[ 0 0 0 0 ]

[ 1 .8596 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .34569 m

.02381 .35194 L

s

[(-2)] .02381 .33319 0 1 Mshowa

.2619 .34569 m

.2619 .35194 L

s

[(-1)] .2619 .33319 0 1 Mshowa

.7381 .34569 m

.7381 .35194 L

s

[(1)] .7381 .33319 0 1 Mshowa

.97619 .34569 m

.97619 .35194 L

s

[(2)] .97619 .33319 0 1 Mshowa

.125 Mabswid

.07143 .34569 m

.07143 .34944 L

s

.11905 .34569 m

.11905 .34944 L

s

.16667 .34569 m

.16667 .34944 L

s

.21429 .34569 m

.21429 .34944 L

s

.30952 .34569 m

.30952 .34944 L

s

.35714 .34569 m

.35714 .34944 L

s

.40476 .34569 m

.40476 .34944 L

s

.45238 .34569 m

.45238 .34944 L

s

.54762 .34569 m

.54762 .34944 L

s

.59524 .34569 m

.59524 .34944 L

s

.64286 .34569 m

.64286 .34944 L

s

.69048 .34569 m

.69048 .34944 L

s

.78571 .34569 m

.78571 .34944 L

s

.83333 .34569 m

.83333 .34944 L

s

.88095 .34569 m

.88095 .34944 L

s

.92857 .34569 m

.92857 .34944 L

s

.25 Mabswid

0 .34569 m

1 .34569 L

s

gsave

1.025 .34569 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .1076 m

.50625 .1076 L

s

[(-1)] .4875 .1076 1 0 Mshowa

.5 .22664 m

.50625 .22664 L

s

[(-0.5)] .4875 .22664 1 0 Mshowa

.5 .46474 m

.50625 .46474 L

s

[(0.5)] .4875 .46474 1 0 Mshowa

.5 .58379 m

.50625 .58379 L

s

[(1)] .4875 .58379 1 0 Mshowa

.5 .70284 m

.50625 .70284 L

s

[(1.5)] .4875 .70284 1 0 Mshowa

.5 .82188 m

.50625 .82188 L

s

[(2)] .4875 .82188 1 0 Mshowa

.125 Mabswid

.5 .13141 m

.50375 .13141 L

s

.5 .15522 m

.50375 .15522 L

s

.5 .17903 m

.50375 .17903 L

s

.5 .20284 m

.50375 .20284 L

s

.5 .25045 m

.50375 .25045 L

s

.5 .27426 m

.50375 .27426 L

s

.5 .29807 m

.50375 .29807 L

s

.5 .32188 m

.50375 .32188 L

s

.5 .3695 m

.50375 .3695 L

s

.5 .39331 m

.50375 .39331 L

s

.5 .41712 m

.50375 .41712 L

s

.5 .44093 m

.50375 .44093 L

s

.5 .48855 m

.50375 .48855 L

s

.5 .51236 m

.50375 .51236 L

s

.5 .53617 m

.50375 .53617 L

s

.5 .55998 m

.50375 .55998 L

s

.5 .6076 m

.50375 .6076 L

s

.5 .63141 m

.50375 .63141 L

s

.5 .65522 m

.50375 .65522 L

s

.5 .67903 m

.50375 .67903 L

s

.5 .72664 m

.50375 .72664 L

s

.5 .75045 m

.50375 .75045 L

s

.5 .77426 m

.50375 .77426 L

s

.5 .79807 m

.50375 .79807 L

s

.5 .08379 m

.50375 .08379 L

s

.5 .05998 m

.50375 .05998 L

s

.5 .03617 m

.50375 .03617 L

s

.5 .01236 m

.50375 .01236 L

s

.5 .84569 m

.50375 .84569 L

s

.25 Mabswid

.5 0 m

.5 .8596 L

s

gsave

.5 .8846 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .8721 -198 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.415) show

298.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

303.000000 15.000000 moveto

(L) show

310.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

317.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

324.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

329.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

333.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .8596 L

0 .8596 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .1774 m

.02576 .1774 L

.03156 .1774 L

.04113 .1774 L

.0543 .1774 L

.07084 .1774 L

.09046 .1774 L

.11285 .1774 L

.1376 .1774 L

.1643 .1774 L

.19248 .17739 L

.22168 .17739 L

.25138 .17739 L

.28109 .17739 L

.31028 .17738 L

.33847 .17738 L

.36517 .17738 L

.38992 .17737 L

.4123 .17737 L

.43193 .17736 L

.44847 .17736 L

.46164 .17735 L

.4712 .17735 L

.47701 .17735 L

.47896 .17734 L

s

.47896 .17734 m

.48109 .17734 L

.48743 .17734 L

.49788 .17733 L

.51227 .17733 L

.53033 .17731 L

.55178 .17729 L

.57623 .17726 L

.60327 .17719 L

.63243 .17699 L

.66323 .17541 L

.69512 .15938 L

.72757 .14013 L

.76003 .12191 L

.79192 .10497 L

.82272 .08939 L

.85188 .07527 L

.87892 .06265 L

.90337 .05161 L

.92481 .04218 L

.94288 .03441 L

.95727 .02833 L

.96772 .02397 L

.97406 .02134 L

.97619 .02047 L

s

.47896 .42981 m

.48109 .4031 L

.48743 .37645 L

.49788 .35004 L

.51227 .32396 L

.53033 .29835 L

.55178 .27331 L

.57623 .24895 L

.60327 .2254 L

.63243 .20285 L

.66323 .18266 L

.69512 .17799 L

.72757 .17769 L

.76003 .1776 L

.79192 .17755 L

.82272 .17753 L

.85188 .17751 L

.87892 .1775 L

.90337 .17749 L

.92481 .17749 L

.94288 .17748 L

.95727 .17748 L

.96772 .17748 L

.97406 .17748 L

.97619 .17748 L

s

.47896 .42992 m

.48109 .45663 L

.48743 .48328 L

.49788 .50971 L

.51227 .53579 L

.53033 .56142 L

.55178 .58648 L

.57623 .61087 L

.60327 .63449 L

.63243 .65724 L

.66323 .67901 L

.69512 .69971 L

.72757 .71926 L

.76003 .73757 L

.79192 .75456 L

.82272 .77016 L

.85188 .7843 L

.87892 .79692 L

.90337 .80798 L

.92481 .81741 L

.94288 .82519 L

.95727 .83127 L

.96772 .83563 L

.97406 .83826 L

.97619 .83913 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<00`0C4`1`4`00oa=B4`0301<C070C001T4`D0j1<2074C001V4`0301<C0>PC00<04a<0

L1<0040C00<=4a<07A<300<C00<04a<00Q<20>@C00<04a<0Fa<33A8C00114`033A<C028C00<04a<0

0Q<00`0C4`3S4`0301<C05PC0`dE4`00@A<00`dC4`0R4`0301<C008C00<04a<0ha<00`0C4`1F4`8=

61<0048C00<=4a<081<200@C00<04a<0ha<205DC0PdJ4`00@a<00`dC4`0U4`80i1<00`0C4`1B4`8=

71<004<C00<=4a<09A<00`0C4`3S4`0301<C050C0PdN4`00A1<00`dC4`0T4`0301<C0><C00<04a<0

CA<33B0C00154`033A<C02<C00<04a<0ha<00`0C4`1;4`8=8a<004DC00<=4a<08a<20>@C0P1:4`8=

9A<004HC00<=4a<08Q<00`0C4`3S4`0301<C04LC0PdW4`00AQ<00`dC4`0R4`0301<C0><C00<04a<0

AA<23BTC00174`033A<C024C00<04a<0ha<00`0C4`144`033A<C02TC00184`033A<C020C0P3T4`80

@a<23B`C00184`033A<C020C00<04a<0ha<00`0C4`104`8=;Q<004TC00<=4a<07a<00`0C4`3S4`03

01<C03hC0Pd`4`00BQ<00`dC4`0N4`0301<C0=`C1@024`0301<C03`C0Pdb4`00Ba<00`dC4`0M4`80

ga<00`0C4`024`0301<C03XC0Pdd4`00Ba<00`dC4`0M4`0301<C0=PC0`034`0301<C008C0P0h4`<=

=Q<004`C00<=4a<03A<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`3N4`0301<C008C00<04a<0

=A<23CTC001=4`033A<C00/C00<04`001a<00`0C00034`0301<C0=hC00<04a<00Q<00`0C4`0c4`8=

>a<004hC00<=4a<01A<3008C00<04`002A<0100C4a<20=hC0P044`0301<C034C0Pdm4`00CQ<00`dC

4`0:4`0301<000LC0P044`0301<C0><C00<04a<0;a<23ClC001?4`033A<C00TC00<04`001a<00`0C

4`034`0301<C0><C0P0_4`033A<C03lC001@4`033A<C00TC00<04a<01Q<300<C00<04a<0ha<00`0C

4`0/4`8=@Q<0054C00<=4a<05a<00`0C4`3S4`0301<C02/C00<=4a<0@Q<0054C00<=4a<05a<20>@C

00<04a<0:A<23DDC001B4`033A<C01HC00<04a<0ha<00`0C4`0W4`8=Aa<005<C00<=4a<05A<00`0C

4`3S4`809Q<23DTC001C4`033A<C01DC00<04a<0ha<00`0C4`0T4`033A<C04TC001D4`033A<C01@C

0P3T4`0301<C028C0Pe<4`00EA<00`dC4`0C4`0301<C0><C00<04a<081<23DhC000J4`<09A<500lC

00<=4a<04Q<00`0C4`0T4`D091<303<CP`d24c`=4Q<001XC00<04a<09a<00`0C4`0?4`033A<C018C

00<04a<09Q<00`0C4`0T4`0301<C09<C0P0O4`@=CQ<001DC0`034`0301<C020C0`034`0301<C010C

00<=4a<04A<202LC00<04a<09A<00`0C4`2B4`0301<C01`C0PeB4`006a<00`0C4`0V4`0301<C014C

00<=4a<041<00`0C4`0V4`0301<C02DC00<04a<0TQ<00`0C4`0K4`033A<C058C000J4`0301<002LC

00<04a<04A<00`dC4`0@4`0301<C02HC00<04a<091<00`0C002C4`0301<C01TC0PeE4`006a<00`0C

4`0U4`8051<00`dC4`0?4`0301<C02DC0P0W4`0301<C098C0P0I4`033A<C05DC001J4`033A<C00hC

0P3T4`0301<C01LC00<=4a<0EQ<005XC00<=4a<03Q<00`0C4`3S4`0301<C01HC00<=4a<0Ea<005/C

00<=4a<03A<00`0C4`1K4`80Ma<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`0D4`8=FQ<005`C

00<=4a<031<00`0C4`1J4`0301<C07HC00<04`001a<00`0C00034`0301<C01<C00<=4a<0FQ<001DC

B0000`d0001R00HC00<04a<0LA<3008C00<04`002A<0100C4a<201<C00<=4a<0Fa<001TC00<04a<0

1Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`03

01<=00DC00<04a<01A<00a0C4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC00<04a<0

1A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00PC00<04a<0MQ<00`0C00074`80

11<00`0C4`0A4`033A<C05`C001N4`033A<C00XC00<@4a<0FQ<00`0C001f4`0301<000LC00<04a<0

0a<00`0C4`0@4`033A<C05dC001O4`033A<C00TC0Q1K4`<0Ma<00`0C4`064`<00a<00`0C4`0>4`8=

H1<0060C00<=4a<021<24>@C00<04a<03A<00`dC4`1P4`00H1<00`dC4`074`03400@0>@C0P0=4`03

3A<C064C001Q4`033A<C00HC00<@0100i1<00`0C4`0;4`033A<C068C001R4`033A<C00DC00<@0100

i1<00`0C4`0:4`033A<C06<C001S4`033A<C00<C00D@4`00403S4`0301<C00XC00<=4a<0Ha<006<C

00<=4a<00a<01A0C01<@0><C00<04a<02A<00`dC4`1T4`00I1<00`dC4`024`0541<04a00ha<200TC

00<=4a<0IA<006DC00L=4a<C41<0008C00<@4a<0h1<00`0C4`074`033A<C06HC001V4`053A<C41<0

0P000a<@4`3Q4`0301<C00HC00<=4a<0Ia<006HC00H=4a<@4`024`0341<C0>0C00<04a<01A<00`dC

4`1X4`00Ia<01@d@4a<000<C00<@4a<0P1<302`C1@0[4`0301<C00@C00<=4a<091<502/C0`0B4`00

J1<010dC4`034`0341<C080C00<04a<0;Q<00`0C4`0[4`8011<00`dC4`0W4`0301<C02/C00<04a<0

4Q<006PC00<=4a<00P024`0341<C07/C0`034`0301<C02LC0`034`0301<C02/C00<04a<00Q<00`dC

4`0X4`0301<C02`C00<04a<04A<006LC00D@4`dC00044`0341<C080C00<04a<0;A<00`0C4`0[4`03

01<C008C00<=4a<0:1<00`0C4`0/4`0301<C014C001L4`0301<C008C00<04a<00Q<01P0@4a<=00@C

00<@4a<0Oa<00`0C000^4`0301<C02/C00D04a<C3@0[4`0301<C02/C00<04`004Q<005/C00<04`00

1a<00`0@00024`033@0C00<C00<@4a<0P1<00`0C4`0/4`80;A<2008C00<=4a<0:1<202hC00<04a<0

4A<005/C00<04`0021<00a004`024`033@0C00<C00<@4a<0gA<0100C4`e_4`00Fa<00`0C00074`03

010C00<C00<03A<00a<00a0C4`3M4`0301<=070C001K4`0301<000LC00<@4a<00a<00`0=4`044`03

41<C0=`C00<04`d0Ja<200<C001L4`0301<C00HC00<@00000a<00`0C3@044`0341<C0=`C00<03A<0

JQ<00`0C4`034`00I1<00a0C4`044`8000<C3A<00Q<00a0C4`1g4fH000<=0000HP074`0301<C00<C

001T4`0341<C00@C00@04a<=11<00a0C4`1k4`0301<C00LC00<04a<01Q<00`0C4`074`0301<C00LC

00<04a<01Q<00`0C4`074`0301<C00HC00<04a<01a<00`0C4`074`0301<C00HC00<=4a<01a<00`0C

4`064`0301<C00LC00<04a<01Q<00`0C4`074`0301<C00LC00<04a<01Q<00`0C4`074`0301<C00HC

00<04a<01a<00`0C4`0:4`0301<C00<C001S4`0341<C00DC00D04a<C3@034`0341<C0=/C00<=4a<0

JQ<00`0C00034`00Ha<00a0C4`054`0301<C008C00D=4a<C403K4`033@0C06/C0`034`00HQ<00a0C

4`064`0301<C00<C00@=4a<@fa<00`d04`1a4`00HQ<00a0C4`064`8011<01@dC4a<@0=TC00@=4`00

LA<0064C00<@4a<01a<00`0C4`044`043A<C4=TC00<=4`00LQ<0064C00<@4a<01a<00`0C4`054`03

3A<@0=TC00<=4`00LQ<0060C00<@4a<021<00`0C4`064`033A<@0=LC00@=4a<0LQ<0060C00<@4a<0

21<200LC00<=4a00ea<010dC4`1b4`00Ga<00a0C4`094`0301<C00LC00<=4a00eQ<00`dC4`02074C

001O4`0341<C00TC00<04a<021<00`d@4`3D4`053A<C4`00LQ<005hC00<@4a<02Q<00`0C4`094`03

3A0C0=<C00D=4a<C001b4`00GQ<00a0C4`0:4`802Q<00`d@4`3C4`053A<C4`00LQ<005dC00<@4a<0

2a<00`0C4`0:4`033A0C0=8C00D=4a<C001b4`00GA<00a0C4`044`D00Q<00`0C4`0;4`033A<C0=4C

00@=4a<C0P1a4`00G1<00a0C4`074`0301<C008C00<04a<031<00`dC4`3@4`053A<C4`00LQ<005/C

00<@4a<021<00`0C4`024`803A<00`d@4`3@4`053A<C4`00LQ<005/C00<@4a<021<00`0C4`024`03

01<C00dC00<=4a<0ca<01@dC4a<0078C001J4`0341<C00TC00<04a<00Q<00`0C4`0>4`033A<C0<hC

00@=4a<C0P1a4`00FQ<00a0C4`084`8011<00`0C4`0>4`033A0C0<hC00D=4a<C001b4`00FA<00a0C

4`0?4`8041<00`dC4`3=4`053A<C4`00LQ<005PC00<@4a<041<00`0C4`0@4`033A<C0<4C00<04a<0

0Q<00`0C4`024`0300dC008C00<04a<0L1<005PC00<@4a<041<00`0C4`0A4`033A<C0;lC00<04`00

1a<00`0C3@034`0301<C070C001G4`0341<C014C00<04a<04A<00`dC4`2o4`0301<000TC00@=4a<C

0P1a4`00EQ<00a0C4`0B4`804a<00`dC4`2n4`0301<000LC0P001A<=4a<0078C001F4`0341<C018C

00<04a<04a<00`dC4`2m4`0301<000LC00@04a<=0Q<00`0C4`1`4`00EA<00a0C4`0C4`0301<C01<C

00<=4a<0_Q<00`0C4`064`<000@C3A<0LQ<005@C00<@4a<051<00`0C4`0D4`033A<C0<XC00<=4`00

LQ<005<C00<@4a<05A<201DC00<@3A<0bQ<010dC001a4`00Da<00a0C4`0E4`0301<C01DC00<=4a<0

bQ<00`d04`1a4`00DQ<00a0C4`0F4`0301<C01HC00<=4a<0bA<00`d04`1a4`00DA<00a0C4`0G4`03

01<C01HC00<@3A<0bQ<00`dC4`1`4`00DA<00a0C4`0G4`8061<00a0=4`394`033A<C070C001@4`03

41<C01PC00<04a<05a<00a0=4`394`0300dC070C001?4`0341<C00PC1@024`0301<C008C00<04a<0

0Q<00`0C4`0H4`0340dC0<PC00<03A<0L1<004lC00<@4a<02Q<00`0C4`064`0301<000<C00<04a<0

6A<00a0=4`374`0301<=070C001>4`0341<C00/C00<04a<021<0100C4a<201/C00<=4a<0aQ<00`0C

3@1`4`00CA<00a0C4`0<4`0301<C00HC0P044`0301<C01XC00<@3A<0aQ<0100C4`e_4`00C1<00a0C

4`0=4`0301<C00HC00<04a<00a<00`0C4`0K4`0340dC0<DC0P000a<=4`1^4`00C1<00a0C4`0<4`80

21<300<C00<04a<071<00`dC4`344`0501<C4`d0KQ<004/C00<@4a<07A<201hC00<=4a<0`a<01@0C

4a<=06hC001:4`0341<C01hC00<04a<07A<00a0=4`334`0301<C008C00<=4a<0Ja<004XC00<@4a<0

7Q<00`0C4`0N4`033A<C0<8C0P034`033A<C06/C00194`0341<C01lC00<04a<07a<00`dC4`314`03

01<C00<C00<=4a<0JQ<004PC00<@4a<081<2024C00<=4a<0`1<00`0C4`044`033A<C06TC00174`03

41<C024C00<04a<081<00`d@4`2i4`D00Q<00`0C4`054`033A<C06PC00174`0341<C024C00<04a<0

8A<00`dC4`2j4`0301<C008C00<04a<01Q<00`dC4`1W4`00AQ<00a0C4`0R4`0301<C028C00<=4a<0

^A<00`0C4`024`8021<00`dC4`1V4`00AA<00a0C4`0S4`808a<00`d@4`2i4`0301<C008C00<04a<0

21<00`dC4`1U4`00A1<00a0C4`0T4`0301<C02<C00<=41<0^1<00`0C4`024`0301<C00TC00<=4a<0

I1<004@C00<@4a<091<00`0C4`0T4`033A<C0;HC0P044`0301<C00XC00<=4a<0Ha<004<C00<@4a<0

9A<00`0C4`0U4`033A<C0;/C00<04a<02Q<00`dC4`1S4`00@Q<00a0C4`0V4`0301<C02DC00<=41<0

^a<200`C00<=4a<0HQ<0044C00<@4a<09a<202LC00<=41<0^Q<00`0C4`0<4`033A<C064C00104`03

41<C02PC00<04a<09a<00`d@4`2i4`0301<C00dC0PeQ4`00@1<00a0C4`0R4`<00a<00`0C4`0W4`03

3A<@0;TC00<04a<03a<00`dC4`1N4`00?a<00a0C4`0S4`0301<C00<C00<04a<0:1<00`d@4`2h4`03

01<C010C0PeN4`00?Q<00a0C4`0U4`0301<C008C0P0Z4`033A0C0;LC0P0C4`033A<C05/C000m4`03

41<C02HC00<04a<00Q<00`0C4`0Y4`033A<@0;LC00<04a<04a<00`dC4`1J4`00?A<00a0C4`0U4`03

01<000<C00<04a<0:Q<00`dC402f4`0301<C01@C00<=4a<0FA<003`C00<@4a<09a<00`0C4`024`03

01<C02/C00<=4a00]A<00`0C4`0E4`8=FA<003/C00<@4a<0;A<202dC00<=4a00]1<201PC00<=4a<0

EQ<003XC00<@4a<0;Q<00`0C4`0/4`033A<@0;@C00<04a<061<00`dC4`1E4`00>Q<00a0C4`0^4`03

01<C02dC00<=4a00/a<00`0C4`0I4`8=EA<003TC00<@4a<0;a<00`0C4`0^4`033A<@0;8C00<04a<0

6a<00`dC4`1B4`00>1<00a0C4`0`4`80;a<010dC4a2a4`0301<C01`C0PeB4`00=a<00a0C4`0a4`03

01<C02lC00<=4a00/A<201lC00<=4a<0Ca<003LC00<@4a<0<A<00`0C4`0`4`033A<@0;0C00<04a<0

7a<23DlC000f4`0341<C038C00<04a<0<1<010dC4a2_4`0301<C024C00<=4a<0C1<003DC00<@4a<0

<a<2038C00@=4a<@WA<5008C00<04a<00Q<00`0C4`024`0301<C028C0Pe<4`00=1<00a0C4`0d4`03

01<C038C00@=4a<@WQ<00`0C4`064`0301<000<C00<04a<091<00`dC4`194`00<a<00a0C4`0e4`03

01<C03<C00@=4a<@WA<00`0C4`084`0401<C4`809Q<23DTC000b4`0341<C03HC00<04a<0<a<010dC

4a2M4`0301<C00HC0P044`0301<C02LC0Pe74`00<A<00a0C4`0g4`80=A<010dC4a2L4`0301<C00HC

00<04a<00a<00`0C4`0Y4`8=AA<0030C00<@4a<0>1<00`0C4`0e4`043A<C49XC0P084`<00a<00`0C

4`0[4`033A<C048C000_4`0341<C02TC0`034`0301<C008C00<04a<00Q<00`0C4`0e4`053A<C4a00

ZA<00`0C4`0/4`8=@Q<002hC00<@4a<0:Q<00`0C4`074`0301<000<C00<04a<0=Q<01@dC4a<@0:PC

0P0_4`033A<C03lC000]4`0341<C02`C00<04a<021<0100C4a<203PC00D=4a<C402W4`0301<C02lC

0Pdo4`00;1<00a0C4`0]4`0301<C00HC0P044`0301<C03LC00<=4a<00Q<00a0C4`2T4`0301<C034C

0Pdm4`00:a<00a0C4`0]4`0301<000LC00<04a<00a<00`0C4`0h4`033A<C008C00<@4a<0Xa<00`0C

4`0c4`8=>a<002XC00<@4a<0;a<00`0C4`064`<00a<00`0C4`0i4`033A<C008C00<@4a<0XQ<00`0C

4`0e4`8=>A<002TC00<@4a<0?a<203/C00<=4a<00Q<00a0C4`2Q4`80>1<23CLC000X4`0341<C040C

00<04a<0>Q<00`dC4`034`0341<C0:0C00<04a<0>A<23CDC000W4`0341<C044C00<04a<0>a<00`dC

4`034`0341<C09lC00<04a<0>a<00`dC4`0b4`009Q<00a0C4`124`0301<C03`C00<=4a<00a<00a0C

4`2N4`0301<C03`C0Pdb4`009A<00a0C4`134`80?A<00`dC4`044`0341<C09dC0P0o4`8=<1<002@C

00<@4a<0A1<00`0C4`0m4`033A<C00@C00<@4a<0W1<00`0C4`104`<=;A<002<C00<@4a<0AA<00`0C

4`0n4`033A<C00@C00<@4a<0Va<00`0C4`134`8=:a<002<C00<@4a<0AA<00`0C4`0n4`033A<C00DC

00<@4a<0VQ<00`0C4`154`8=:A<0028C00<@4a<0AQ<2040C00<=4a<01A<00a0C4`2I4`0301<C04LC

0PdW4`008A<00a0C4`174`0301<C040C00<=4a<01A<00a0C4`2H4`80BQ<23BDC000P4`0341<C04PC

00<04a<0@1<00`dC4`064`0341<C09LC00<04a<0Ba<23B<C000O4`0341<C04TC00<04a<0@A<00`dC

4`064`0341<C09HC00<04a<0CA<33B0C000N4`0341<C04XC0P134`033A<C00HC00<@4a<0Sa<300<C

00<04a<0D1<23AhC000M4`0341<C04/C00<04a<0@Q<00`dC4`074`0341<C08hC00<04a<00a<00`0C

4`1B4`8=71<001`C00<@4a<0C1<00`0C4`134`033A<C00LC00<@4a<0SQ<00`0C4`024`80EA<23AXC

000K4`0341<C04LC0P044`0301<C04@C00<=4a<01a<00a0C4`2=4`0301<C008C00<04a<0EQ<23APC

000J4`0341<C04XC00D04a<C00164`033A<C00PC00<@4a<0Ra<00`0C00034`0301<C05PC0PdF4`00

6A<00a0C4`1:4`0301<C008C0P164`033A<C00LC00<@4a<0S1<00`0C4`024`0301<C05XC10dB4`00

Ia<00`0C4`3W4`0301<C05dC00<=4a<041<006DC00<04`00jA<2074C001V4`0301<C0>PC00<04a<0

L1<002XC0`3o4bDC00<04a<0L1<002XC00<04a<0oa<U4`0301<C070C000[4`0301<C00@C00<04a<0

oa>@4`00:a<0100C4a<400<C0`3o4h`C000Z4`0301<0008C0P000a<04`044`0301<C0?lCRQ<002/C

00<04a<00a<00`0C00034`0301<C0?lCRa<0034C00<04`0011<00`0C4`064`0301<C02LC0`0[4`03

01<C0?lC:A<001/C0`000a<0000200`C0`044`<021<00`0C4`0V4`0401<C00lC0`000a<00002008C

00<04a<00Q<00`0C4`024`0301<C00DC00@04a<C1@024`0301<C008C20024`0301<C00@C0P354`03

01<C03LC00<04a<01Q<001XC00@04a<091<00`0C4`0U4`0401<C00hC00@04a<01Q<00`0C00074`03

01<000@C1@034`0301<C00PC00D04a<C00034`0301<000@C00<04a<0_A<00`0C4`044`0301<C01<C

00<04a<08a<00`0C4`054`006Q<01@0C4`0C00@000<C0000600]4`<03Q<01@0C4`0C00@000@C01<0

2A<00`0C4`044`0301<C00<C00<04a<01Q<4008C00<04a<00a<00`0C4`024`0301<C0:/C00@04a<C

10024`801Q<00`0C4`034`0301<C008C00<04a<00Q<00`0C4`024`0301<C00DC00@04a<C1@024`03

01<C008C20024`0301<C00@C0P044`0401<C4`800A<001/C0`1?4`0301<C00dC0`064`0301<000LC

0P074`0301<C00<C00<04a<01Q<00`0C00034`0401<C4`801A<00`0C4`2Z4`0301<000LC00<04a<0

11<500<C00L04a<C01<000LC00<04`0011<500<C00<04a<021<01@0C4a<000<C00<04`0011<00`0C

4`044`0301<C008C0@014`007A<00`0C4`1<4`804A<00`0C4`044`0301<000LC00<04a<031<00`0C

4`074`800a<01@0C4a<000HC00<04`00ZQ<00`0C00024`@000<C01<01a<00`0C4`034`0701<C4`0C

00094`0301<C00@C00<04a<00a<00`0C4`064`@00Q<00`0C4`034`0301<C008C00<04a<011<00`0C

4`034`40000L4`80H1<200LC00<04a<01Q<300/C0P0:4`0301<C00800a<300@C0`2C4`8000<C0000

4Q<00`0C00074`0301<C00HC00<04a<00a<01`0C4a<04`001a<200LC00<04a<00a<00`0C4`064`03

01<000<C00@04a<C0P054`0301<C00@C00<04a<00a<10000oa=A4`0301<001<C00<04`001a<00`0C

000=4`0601<C01<01a<00`0C4`0<4`0301<C00LC0P034`0501<C4`001Q<00`0C00034`0301<C00<C

0@014`009Q<200HC0P3o4b8C00<04a<04a<00`0C4`064`<03Q<0100C4`084`<02a<200XC00<04a<0

0P034`<011<3008C00<04a<00a<2004C000X4`0301<C008C00<04a<0oa<R4`0301<C070C000W4`03

01<C00<C00<04a<01Q<00`0C4`3o4aPC00<04`00LA<002PC00<04a<00Q<00`0C4`024`<000@C01<C

0`3o4a@C0P000a<0001`4`009Q<00`0C00044`0301<0008C0P024`0301<C008C00<04a<0oa>74`00

9a<00`0C4`034`<011<0100C4`024`0301<C0?lCR1<003@C00@04a<00a<00`0C4`3o4hLC000b4`<0

11<30?lCRA<00?lCaA<00?lCaA<00?lCaA<00?lCaA<00?lCaA<00001\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.04159, -1.55361, 0.0208582, 0.0208582}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -82 0 ]

[.5 .96488 82 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -143 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.41) show

217.250000 19.500000 moveto

(C) show

222.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.24671 0 m

.26171 .02115 L

.30316 .07959 L

.34309 .13589 L

.3815 .19006 L

.42237 .24768 L

.46172 .30316 L

.49955 .35651 L

.53984 .41332 L

.57861 .46798 L

.61984 .52611 L

.65954 .5821 L

.69774 .63595 L

.73838 .69326 L

.77751 .74843 L

.81909 .80707 L

.85916 .86356 L

.89771 .91792 L

s

.89771 .91792 m

.92215 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.3442 0.238095 [

[.02381 .3317 -6 -9 ]

[.02381 .3317 6 0 ]

[.2619 .3317 -6 -9 ]

[.2619 .3317 6 0 ]

[.7381 .3317 -3 -9 ]

[.7381 .3317 3 0 ]

[.97619 .3317 -3 -9 ]

[.97619 .3317 3 0 ]

[1.025 .3442 0 -8 ]

[1.025 .3442 9 8 ]

[.4875 .1061 -12 -4.5 ]

[.4875 .1061 0 4.5 ]

[.4875 .22515 -24 -4.5 ]

[.4875 .22515 0 4.5 ]

[.4875 .46325 -18 -4.5 ]

[.4875 .46325 0 4.5 ]

[.4875 .5823 -6 -4.5 ]

[.4875 .5823 0 4.5 ]

[.4875 .70134 -18 -4.5 ]

[.4875 .70134 0 4.5 ]

[.4875 .82039 -6 -4.5 ]

[.4875 .82039 0 4.5 ]

[.5 .88254 -4.5 0 ]

[.5 .88254 4.5 16 ]

[.5 .87004 -134.5 0 ]

[.5 .87004 134.5 16 ]

[ 0 0 0 0 ]

[ 1 .85754 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .3442 m

.02381 .35045 L

s

[(-2)] .02381 .3317 0 1 Mshowa

.2619 .3442 m

.2619 .35045 L

s

[(-1)] .2619 .3317 0 1 Mshowa

.7381 .3442 m

.7381 .35045 L

s

[(1)] .7381 .3317 0 1 Mshowa

.97619 .3442 m

.97619 .35045 L

s

[(2)] .97619 .3317 0 1 Mshowa

.125 Mabswid

.07143 .3442 m

.07143 .34795 L

s

.11905 .3442 m

.11905 .34795 L

s

.16667 .3442 m

.16667 .34795 L

s

.21429 .3442 m

.21429 .34795 L

s

.30952 .3442 m

.30952 .34795 L

s

.35714 .3442 m

.35714 .34795 L

s

.40476 .3442 m

.40476 .34795 L

s

.45238 .3442 m

.45238 .34795 L

s

.54762 .3442 m

.54762 .34795 L

s

.59524 .3442 m

.59524 .34795 L

s

.64286 .3442 m

.64286 .34795 L

s

.69048 .3442 m

.69048 .34795 L

s

.78571 .3442 m

.78571 .34795 L

s

.83333 .3442 m

.83333 .34795 L

s

.88095 .3442 m

.88095 .34795 L

s

.92857 .3442 m

.92857 .34795 L

s

.25 Mabswid

0 .3442 m

1 .3442 L

s

gsave

1.025 .3442 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .1061 m

.50625 .1061 L

s

[(-1)] .4875 .1061 1 0 Mshowa

.5 .22515 m

.50625 .22515 L

s

[(-0.5)] .4875 .22515 1 0 Mshowa

.5 .46325 m

.50625 .46325 L

s

[(0.5)] .4875 .46325 1 0 Mshowa

.5 .5823 m

.50625 .5823 L

s

[(1)] .4875 .5823 1 0 Mshowa

.5 .70134 m

.50625 .70134 L

s

[(1.5)] .4875 .70134 1 0 Mshowa

.5 .82039 m

.50625 .82039 L

s

[(2)] .4875 .82039 1 0 Mshowa

.125 Mabswid

.5 .12991 m

.50375 .12991 L

s

.5 .15372 m

.50375 .15372 L

s

.5 .17753 m

.50375 .17753 L

s

.5 .20134 m

.50375 .20134 L

s

.5 .24896 m

.50375 .24896 L

s

.5 .27277 m

.50375 .27277 L

s

.5 .29658 m

.50375 .29658 L

s

.5 .32039 m

.50375 .32039 L

s

.5 .36801 m

.50375 .36801 L

s

.5 .39182 m

.50375 .39182 L

s

.5 .41563 m

.50375 .41563 L

s

.5 .43944 m

.50375 .43944 L

s

.5 .48706 m

.50375 .48706 L

s

.5 .51087 m

.50375 .51087 L

s

.5 .53468 m

.50375 .53468 L

s

.5 .55849 m

.50375 .55849 L

s

.5 .6061 m

.50375 .6061 L

s

.5 .62991 m

.50375 .62991 L

s

.5 .65372 m

.50375 .65372 L

s

.5 .67753 m

.50375 .67753 L

s

.5 .72515 m

.50375 .72515 L

s

.5 .74896 m

.50375 .74896 L

s

.5 .77277 m

.50375 .77277 L

s

.5 .79658 m

.50375 .79658 L

s

.5 .0823 m

.50375 .0823 L

s

.5 .05849 m

.50375 .05849 L

s

.5 .03468 m

.50375 .03468 L

s

.5 .01087 m

.50375 .01087 L

s

.5 .8442 m

.50375 .8442 L

s

.25 Mabswid

.5 0 m

.5 .85754 L

s

gsave

.5 .88254 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .87004 -195.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.41) show

293.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

298.000000 15.000000 moveto

(L) show

305.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

312.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

319.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

324.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

328.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .85754 L

0 .85754 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .17547 m

.02576 .17547 L

.03156 .17547 L

.04113 .17547 L

.0543 .17548 L

.07083 .17548 L

.09046 .17549 L

.11284 .17549 L

.13759 .1755 L

.16429 .17551 L

.19247 .17552 L

.22167 .17553 L

.25137 .17554 L

.28107 .17556 L

.31027 .17558 L

.33846 .1756 L

.36515 .17562 L

.3899 .17564 L

.41228 .17567 L

.43191 .1757 L

.44845 .17572 L

.46161 .17575 L

.47118 .17577 L

.47699 .17578 L

.47893 .17579 L

s

.47893 .17579 m

.47966 .17579 L

.48181 .17579 L

.48536 .1758 L

.49025 .17581 L

.49639 .17583 L

.50367 .17585 L

.51198 .17588 L

.52116 .17591 L

.53107 .17595 L

.54153 .17601 L

.55237 .17607 L

.56339 .17614 L

.57442 .17624 L

.58525 .17636 L

.59572 .17651 L

.60562 .1767 L

.61481 .17694 L

.62312 .17726 L

.6304 .17768 L

.63654 .17823 L

.64142 .17897 L

.64498 .17995 L

.64713 .18125 L

.64785 .18297 L

s

.47893 .42835 m

.47966 .41282 L

.48181 .39729 L

.48536 .3819 L

.49025 .3667 L

.49639 .35176 L

.50367 .33715 L

.51198 .32292 L

.52116 .30914 L

.53107 .29586 L

.54153 .28314 L

.55237 .27103 L

.56339 .25957 L

.57442 .24882 L

.58525 .23881 L

.59572 .22958 L

.60562 .22116 L

.61481 .21357 L

.62312 .20682 L

.6304 .20091 L

.63654 .19583 L

.64142 .19156 L

.64498 .18804 L

.64713 .1852 L

.64785 .18298 L

s

.47893 .42846 m

.47966 .44399 L

.48181 .45951 L

.48536 .4749 L

.49025 .49008 L

.49639 .50501 L

.50367 .5196 L

.51198 .5338 L

.52116 .54755 L

.53107 .56078 L

.54153 .57346 L

.55237 .58551 L

.56339 .59688 L

.57442 .60754 L

.58525 .61743 L

.59572 .62651 L

.60562 .63474 L

.61481 .64209 L

.62312 .64852 L

.6304 .65401 L

.63654 .65853 L

.64142 .66207 L

.64498 .66461 L

.64713 .66614 L

.64785 .66665 L

s

.64785 .66665 m

.64805 .66679 L

.64863 .6672 L

.64958 .66787 L

.65089 .66879 L

.65254 .66993 L

.6545 .67129 L

.65673 .67283 L

.6592 .67452 L

.66186 .67633 L

.66467 .67823 L

.66758 .68018 L

.67055 .68215 L

.67351 .6841 L

.67642 .68601 L

.67923 .68783 L

.68189 .68955 L

.68436 .69113 L

.68659 .69256 L

.68855 .6938 L

.6902 .69484 L

.69151 .69567 L

.69247 .69626 L

.69305 .69663 L

.69324 .69675 L

s

.69324 .16792 m

.69445 .16513 L

.69806 .16144 L

.70401 .15678 L

.71219 .15112 L

.72248 .14452 L

.73468 .13709 L

.74859 .12897 L

.76398 .12031 L

.78057 .11129 L

.7981 .10207 L

.81625 .0928 L

.83472 .08365 L

.85318 .07474 L

.87133 .0662 L

.88886 .05815 L

.90545 .05068 L

.92084 .04389 L

.93475 .03786 L

.94696 .03264 L

.95724 .0283 L

.96542 .02488 L

.97137 .02241 L

.97498 .02092 L

.97619 .02042 L

s

.69324 .16793 m

.69445 .16996 L

.69806 .17141 L

.70401 .17241 L

.71219 .17312 L

.72248 .17361 L

.73468 .17397 L

.74859 .17422 L

.76398 .17441 L

.78057 .17456 L

.7981 .17466 L

.81625 .17475 L

.83472 .17482 L

.85318 .17487 L

.87133 .17491 L

.88886 .17495 L

.90545 .17497 L

.92084 .175 L

.93475 .17501 L

.94696 .17503 L

.95724 .17504 L

.96542 .17505 L

.97137 .17505 L

.97498 .17506 L

.97619 .17506 L

s

.69324 .69675 m

.69445 .69751 L

.69806 .69975 L

.70401 .70341 L

.71219 .70836 L

.72248 .71446 L

.73468 .72154 L

.74859 .72941 L

.76398 .73787 L

.78057 .74675 L

.7981 .75587 L

.81625 .76505 L

.83472 .77414 L

.85318 .783 L

.87133 .79149 L

.88886 .79951 L

.90545 .80694 L

.92084 .81371 L

.93475 .81973 L

.94696 .82493 L

.95724 .82926 L

.96542 .83267 L

.97137 .83514 L

.97498 .83663 L

.97619 .83712 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<00`0C4`1`4`00oa=B4`0301<C070C001T4`D0j1<2074C001V4`0301<C0>PC00<04a<0

L1<0040C00<=4a<07A<300<C00<04a<00Q<20>@C00<04a<0G1<23A8C00104`033A<C02<C00<04a<0

0Q<00`0C4`3S4`0301<C05TC0`dD4`00@A<00`dC4`0R4`0301<C008C00<04a<0ha<00`0C4`1G4`8=

5a<0044C00<=4a<08A<200@C00<04a<0ha<205DC0`dI4`00@Q<00`dC4`0V4`80i1<00`0C4`1B4`8=

71<004<C00<=4a<09A<00`0C4`3S4`0301<C050C0PdN4`00@a<00`dC4`0U4`0301<C0><C00<04a<0

CQ<23B0C00144`033A<C02@C00<04a<0ha<204dC0PdR4`00AA<00`dC4`0S4`80i1<00`0C4`1:4`8=

91<004DC00<=4a<08a<00`0C4`3S4`0301<C04PC0PdV4`00AQ<00`dC4`0R4`0301<C0><C00<04a<0

AQ<23BPC00174`033A<C024C00<04a<0ha<00`0C4`134`<=:Q<004PC00<=4a<081<20>@C0P124`8=

;A<004PC00<=4a<081<00`0C4`3S4`0301<C03lC0Pd_4`00BA<00`dC4`0O4`0301<C0><C00<04a<0

?A<23C4C001:4`033A<C01hC00<04a<0g1<5008C00<04a<0>a<23C<C001;4`033A<C01dC0P3O4`03

01<C008C00<04a<0>A<23CDC001;4`033A<C01dC00<04a<0f1<300<C00<04a<00Q<203PC0Pdg4`00

C1<00`dC4`0=4`0301<C008C00<04a<00Q<00`0C4`024`0301<C0=hC00<04a<00Q<00`0C4`0f4`03

3A<C03LC001=4`033A<C00/C00<04`001a<00`0C00034`0301<C0=hC00<04a<00Q<00`0C4`0d4`8=

>Q<004hC00<=4a<01A<3008C00<04`002A<0100C4a<20=hC0P044`0301<C038C0Pdl4`00CQ<00`dC

4`0:4`0301<000LC0P044`0301<C0><C00<04a<0<1<23ChC001?4`033A<C00TC00<04`001a<00`0C

4`034`0301<C0><C0P0_4`8=@1<0050C00<=4a<02A<00`0C4`064`<00a<00`0C4`3S4`0301<C02`C

0Pe24`00DA<00`dC4`0G4`0301<C0><C00<04a<0:a<00`dC4`124`00DA<00`dC4`0G4`80i1<00`0C

4`0Z4`033A<C04<C001B4`033A<C01HC00<04a<0ha<00`0C4`0X4`8=AQ<005<C00<=4a<05A<00`0C

4`3S4`809a<23DPC001C4`033A<C01DC00<04a<0ha<00`0C4`0U4`033A<C04PC001D4`033A<C01@C

0P3T4`0301<C02@C00<=4a<0BA<005DC00<=4a<04a<00`0C4`3S4`0301<C02@C0`e94`006Q<302DC

1@0?4`033A<C018C00<04a<091<502@C0`0c4g/=3a<g3A8C000J4`0301<C02LC00<04a<03a<00`dC

4`0B4`0301<C02HC00<04a<091<00`0C4`2C4`0301<C01PC10eD4`005A<300<C00<04a<081<300<C

00<04a<041<00`dC4`0A4`809a<00`0C4`0U4`0301<C098C00<04a<06a<00`dC4`1B4`006a<00`0C

4`0V4`0301<C014C00<=4a<041<00`0C4`0V4`0301<C02DC00<04a<0TQ<00`0C4`0J4`033A<C05<C

000J4`0301<002LC00<04a<04A<00`dC4`0@4`0301<C02HC00<04a<091<00`0C002C4`0301<C01TC

00<=4a<0E1<001/C00<04a<09A<201@C00<=4a<03a<00`0C4`0U4`809a<00`0C4`2B4`8061<23ELC

001J4`033A<C00hC0P3T4`0301<C01HC00<=4a<0Ea<005XC00<=4a<03Q<00`0C4`3S4`0301<C01DC

00<=4a<0F1<005/C00<=4a<03A<00`0C4`1K4`80Ma<00`0C4`024`0301<C008C00<04a<00Q<00`0C

4`0D4`033A<C05TC001L4`033A<C00`C00<04a<0FQ<00`0C4`1f4`0301<000LC00<04`000a<00`0C

4`0B4`8=G1<001DCB0000`d0001R00HC00<04a<0LA<3008C00<04`002A<0100C4a<2018C00<=4a<0

G1<001TC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<0

1Q<00`0C4`054`0301<=00DC00<04a<01A<00a0C4`054`0301<C00HC00<04a<01A<00`0C4`054`03

01<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00PC00<04a<0

MQ<00`0C00074`8011<00`0C4`0@4`033A<C05dC001N4`033A<C00XC00<@4a<0FQ<00`0C001f4`03

01<000LC00<04a<00a<00`0C4`0?4`033A<C05hC001O4`033A<C00TC0Q1K4`<0Ma<00`0C4`064`<0

0a<00`0C4`0>4`033A<C05lC001P4`033A<C00PC0Q3T4`0301<C00dC00<=4a<0H1<0060C00<=4a<0

1a<00a00403T4`803A<00`dC4`1Q4`00HA<00`dC4`064`03400@0>@C00<04a<02a<00`dC4`1R4`00

HQ<00`dC4`054`03400@0>@C00<04a<02Q<00`dC4`1S4`00Ha<00`dC4`034`0541<00100ha<00`0C

4`094`033A<C06@C001S4`033A<C00<C00D@4`0C403S4`0301<C00PC00<=4a<0IA<006@C00<=4a<0

0Q<01A0C01<@0><C0P084`033A<C06HC001U4`073A<C4a0C00024`0341<C0>0C00<04a<01Q<00`dC

4`1W4`00IQ<01@dC4a0C008000<C41<0hA<00`0C4`054`033A<C06PC001V4`063A<C41<00Q<00a0C

4`3P4`0301<C00@C00<=4a<0JA<006LC00D=41<C00034`0341<C080C0`0/4`D0:a<200@C00<=4a<0

9A<502`C0`0A4`00J1<010dC4`034`0341<C080C00<04a<0;Q<00`0C4`0[4`0301<C008C00<=4a<0

:1<00`0C4`0/4`0301<C014C001X4`033A<C00800Q<00a0C4`1k4`<00a<00`0C4`0W4`<00a<00`0C

4`0[4`0301<C008C00<=4a<0:1<00`0C4`0]4`0301<C010C001W4`0541<=4`0011<00a0C4`204`03

01<C02dC00<04a<0:a<01@0C4a<=02/C00<04a<0;A<00`0C4`0@4`00G1<00`0C4`024`0301<C008C

00H041<C3@044`0341<C07lC00<04`00;Q<00`0C4`0[4`0501<C4`d0:a<00`0C4`0/4`0301<0014C

001K4`0301<000LC00<040000Q<00`d04`034`0341<C080C00<04a<0;1<202dC0P000a<=4`0Z4`80

;a<00`0C4`0@4`00Fa<00`0C00084`03400C008C00<=01<00a<00a0C4`3M4`0401<C3FlC001K4`03

01<000LC00<041<00a<00`0=4`034`0341<C0=dC00<04`d0L1<005/C00<04`001a<00a0C4`034`03

00dC00@C00<@4a<0g1<00`0C3@1[4`800a<005`C00<04a<01Q<00a0000034`0301<=00@C00<@4a<0

g1<00`0=4`1Z4`0301<C00<C001T4`0341<C00@C0P000a<=4`024`0341<C07LCI@000`d0001S00LC

00<04a<00a<006@C00<@4a<011<0100C4`d44`0341<C07/C00<04a<01a<00`0C4`064`0301<C00LC

00<04a<01Q<00`0C4`074`0301<C00LC00<04a<01Q<00`0C4`074`0301<C00HC00<04a<01a<00`dC

4`074`0301<C00HC00<04a<01a<00`0C4`074`0301<C00HC00<04a<01a<00`0C4`064`0301<C00LC

00<04a<01a<00`0C4`064`0301<C00XC00<04a<00a<006<C00<@4a<01A<01@0C4a<=00<C00<@4a<0

fQ<00`d04`1[4`0301<000<C001S4`0341<C00DC00<04a<00Q<01@dC4a<@0=/C00<=01<0Ja<300<C

001R4`0341<C00HC00<04a<00a<010dC4a3J4`033A<0078C001R4`0341<C00HC0P044`053A<C4a00

fA<010dC001a4`00HA<00a0C4`074`0301<C00@C00@=4a<@fA<00`dC001b4`00HA<00a0C4`074`03

01<C00DC00<=4a00f1<010dC4`1b4`00H1<00a0C4`084`0301<C00HC00<=4a00ea<010dC4`1b4`00

H1<00a0C4`084`801a<00`dC403G4`043A<C078C001O4`0341<C00TC00<04a<01a<00`dC403E4`04

3A<C4`80LA<005lC00<@4a<02A<00`0C4`084`033A0C0=@C00D=4a<C001b4`00GQ<00a0C4`0:4`03

01<C00TC00<=41<0da<01@dC4a<0078C001N4`0341<C00XC0P0:4`033A0C0=<C00D=4a<C001b4`00

GA<00a0C4`0;4`0301<C00XC00<=41<0dQ<010dC4a<2074C001M4`0341<C00@C1@024`0301<C00/C

00<=4a<0dA<01@dC4a<0078C001L4`0341<C00LC00<04a<00Q<00`0C4`0<4`033A<C0=0C00D=4a<C

001b4`00Fa<00a0C4`084`0301<C008C0P0=4`033A0C0=0C00D=4a<C001b4`00Fa<00a0C4`084`03

01<C008C00<04a<03A<00`dC4`3?4`053A<C4`00LQ<005XC00<@4a<02A<00`0C4`024`0301<C00hC

00<=4a<0cQ<010dC4a<2074C001J4`0341<C00PC0P044`0301<C00hC00<=41<0cQ<01@dC4a<0078C

001I4`0341<C00lC0P0@4`033A<C0<dC00D=4a<C001b4`00F1<00a0C4`0@4`0301<C010C00<=4a<0

`A<00`0C4`024`0301<C008C00<03A<00Q<00`0C4`1`4`00F1<00a0C4`0@4`0301<C014C00<=4a<0

_a<00`0C00074`0301<=00<C00<04a<0L1<005LC00<@4a<04A<00`0C4`0A4`033A<C0;lC00<04`00

2A<010dC4a<2074C001F4`0341<C018C0P0C4`033A<C0;hC00<04`001a<200054`dC4`00LQ<005HC

00<@4a<04Q<00`0C4`0C4`033A<C0;dC00<04`001a<0100C4`d24`0301<C070C001E4`0341<C01<C

00<04a<04a<00`dC4`2n4`0301<C00HC0`0010dC4`1b4`00E1<00a0C4`0D4`0301<C01@C00<=4a<0

bQ<00`dC001b4`00Da<00a0C4`0E4`805A<00a0=4`3:4`043A<0074C001C4`0341<C01DC00<04a<0

5A<00`dC4`394`033A<0078C001B4`0341<C01HC00<04a<05Q<00`dC4`394`033@0C074C001A4`03

41<C01LC00<04a<05Q<00a0=4`394`033@0C074C001A4`0341<C01LC0P0H4`0340dC0<TC00<=4a<0

L1<0050C00<@4a<061<00`0C4`0G4`0340dC0<TC00<=01<0L1<004lC00<@4a<021<5008C00<04a<0

0Q<00`0C4`024`0301<C01PC00<@3A<0b1<00`0=4`1`4`00Ca<00a0C4`0:4`0301<C00HC00<04`00

0a<00`0C4`0I4`0340dC0<LC00<04`d0L1<004hC00<@4a<02a<00`0C4`084`0401<C4`806a<00`dC

4`364`0301<=070C001=4`0341<C00`C00<04a<01Q<200@C00<04a<06Q<00a0=4`364`8000<C3A<0

KQ<004`C00<@4a<03A<00`0C4`064`0301<C00<C00<04a<06a<00a0=4`354`0401<C3FlC001<4`03

41<C00`C0P084`<00a<00`0C4`0L4`033A<C0<@C00D04a<C3@1^4`00Ba<00a0C4`0M4`807Q<00`dC

4`334`0501<C4`d0KQ<004XC00<@4a<07Q<00`0C4`0M4`0340dC0<<C00<04a<00Q<00`dC4`1[4`00

BQ<00a0C4`0N4`0301<C01hC00<=4a<0`Q<200<C00<=4a<0Ja<004TC00<@4a<07a<00`0C4`0O4`03

3A<C0<4C00<04a<00a<00`dC4`1Z4`00B1<00a0C4`0P4`808A<00`dC4`304`0301<C00@C00<=4a<0

JA<004LC00<@4a<08A<00`0C4`0P4`033A0C0;TC1@024`0301<C00DC00<=4a<0J1<004LC00<@4a<0

8A<00`0C4`0Q4`033A<C0;XC00<04a<00Q<00`0C4`064`033A<C06LC00164`0341<C028C00<04a<0

8Q<00`dC4`2i4`0301<C008C0P084`033A<C06HC00154`0341<C02<C0P0S4`033A0C0;TC00<04a<0

0Q<00`0C4`084`033A<C06DC00144`0341<C02@C00<04a<08a<00`d@4`2h4`0301<C008C00<04a<0

2A<00`dC4`1T4`00A1<00a0C4`0T4`0301<C02@C00<=4a<0]Q<200@C00<04a<02Q<00`dC4`1S4`00

@a<00a0C4`0U4`0301<C02DC00<=4a<0^a<00`0C4`0;4`033A<C068C00124`0341<C02HC00<04a<0

9A<00`d@4`2k4`803A<00`dC4`1Q4`00@A<00a0C4`0W4`809a<00`d@4`2j4`0301<C00dC00<=4a<0

H1<0040C00<@4a<0:1<00`0C4`0W4`033A0C0;TC00<04a<03Q<00`dC4`1O4`00@1<00a0C4`0R4`<0

0a<00`0C4`0W4`033A<@0;TC00<04a<03a<00`dC4`1N4`00?a<00a0C4`0S4`0301<C00<C00<04a<0

:1<00`d@4`2h4`0301<C010C00<=4a<0GA<003hC00<@4a<09A<00`0C4`024`80:Q<00`d@4`2g4`80

4Q<00`dC4`1L4`00?A<00a0C4`0V4`0301<C008C00<04a<0:A<00`dC402g4`0301<C018C00<=4a<0

Fa<003dC00<@4a<09A<00`0C00034`0301<C02XC00<=4a00]Q<00`0C4`0C4`8=Fa<003`C00<@4a<0

9a<00`0C4`024`0301<C02/C00<=4a00]A<00`0C4`0E4`8=FA<003/C00<@4a<0;A<202dC00<=4a00

]1<00`0C4`0F4`033A<C05LC000j4`0341<C02hC00<04a<0;1<00`dC402d4`8061<33EHC000j4`03

41<C02hC00<04a<0;A<00`dC402c4`0301<C01XC00<=4a<0Da<003TC00<@4a<0;a<00`0C4`0^4`03

3A<@0;8C00<04a<06Q<23E@C000h4`0341<C030C0P0_4`043A<C4;4C00<04a<071<23E8C000g4`03

41<C034C00<04a<0;a<00`dC402a4`807Q<23E4C000g4`0341<C034C00<04a<0<1<00`dC402`4`03

01<C01lC0Pe?4`00=Q<00a0C4`0b4`0301<C030C00@=4a<@[a<00`0C4`0P4`8=CQ<003DC00<@4a<0

<a<2038C00@=4a<@WA<5008C00<04a<00Q<00`0C4`024`0301<C028C0Pe<4`00=1<00a0C4`0d4`03

01<C038C00@=4a<@WQ<00`0C4`064`0301<000<C00<04a<08a<23D/C000c4`0341<C03DC00<04a<0

<a<010dC4a2M4`0301<C00PC00@04a<C0P0V4`033A<C04PC000b4`0341<C03HC00<04a<0<a<010dC

4a2M4`0301<C00HC0P044`0301<C02HC00<=4a<0Aa<0034C00<@4a<0=a<203DC00@=4a<@W1<00`0C

4`064`0301<C00<C00<04a<09a<23DLC000`4`0341<C03PC00<04a<0=A<010dC4a2J4`8021<300<C

00<04a<0:A<23DDC000_4`0341<C02TC0`034`0301<C008C00<04a<00Q<00`0C4`0f4`043A<C4:TC

00<04a<0:a<23D<C000^4`0341<C02XC00<04a<01a<00`0C00034`0301<C03HC00D=4a<C402X4`80

;Q<23D4C000]4`0341<C02`C00<04a<021<0100C4a<203PC00D=4a<C402W4`0301<C02lC0Pdo4`00

;1<00a0C4`0]4`0301<C00HC0P044`0301<C03PC00D=4a<C402V4`0301<C034C0Pdm4`00:a<00a0C

4`0]4`0301<000LC00<04a<00a<00`0C4`0i4`053A<C4a00YA<00`0C4`0c4`8=>a<002XC00<@4a<0

;a<00`0C4`064`<00a<00`0C4`0i4`033A<C008C00<@4a<0XQ<00`0C4`0e4`8=>A<002TC00<@4a<0

?a<203/C00<=4a<00Q<00a0C4`2Q4`80>1<23CLC000X4`0341<C040C00<04a<0>a<00`dC4`024`03

41<C0:0C00<04a<0>A<00`dC4`0d4`009a<00a0C4`114`0301<C03`C00<=4a<00Q<00a0C4`2O4`03

01<C03XC0Pdd4`009Q<00a0C4`124`0301<C03`C00<=4a<00a<00a0C4`2N4`0301<C03`C0Pdb4`00

9A<00a0C4`134`80?Q<00`dC4`034`0341<C09dC00<04a<0?Q<23C0C000T4`0341<C04@C00<04a<0

?A<00`dC4`044`0341<C09`C0P114`8=;Q<002<C00<@4a<0AA<00`0C4`0n4`033A<C00@C00<@4a<0

Va<00`0C4`124`8=;1<002<C00<@4a<0AA<00`0C4`0o4`033A<C00@C00<@4a<0VQ<00`0C4`144`8=

:Q<0028C00<@4a<0AQ<2040C00<=4a<01A<00a0C4`2I4`0301<C04HC0`dW4`008A<00a0C4`174`03

01<C040C00<=4a<01A<00a0C4`2H4`80BQ<23BDC000P4`0341<C04PC00<04a<0@1<00`dC4`064`03

41<C09LC00<04a<0Ba<33B8C000O4`0341<C04TC00<04a<0@A<00`dC4`064`0341<C09HC00<04a<0

CQ<23B0C000N4`0341<C04XC0P134`033A<C00HC00<@4a<0Sa<300<C00<04a<0D1<23AhC000M4`03

41<C04/C00<04a<0@a<00`dC4`064`0341<C08hC00<04a<00a<00`0C4`1B4`8=71<001`C00<@4a<0

C1<00`0C4`134`033A<C00LC00<@4a<0SQ<00`0C4`024`80EA<23AXC000K4`0341<C04LC0P044`03

01<C04@C00<=4a<01a<00a0C4`2=4`0301<C008C00<04a<0EQ<23APC000J4`0341<C04XC00D04a<C

00174`033A<C00LC00<@4a<0Ra<00`0C00034`0301<C05PC0PdF4`006A<00a0C4`1:4`0301<C008C

0P174`033A<C00HC00<@4a<0S1<00`0C4`024`0301<C05XC10dB4`00Ia<00`0C4`3W4`0301<C05dC

00<=4a<041<006DC00<04`00jA<2074C001V4`0301<C0>PC00<04a<0L1<002`C0`3o4b<C00<04a<0

L1<002`C00<04a<0oa<S4`0301<C070C000]4`0301<C00DC00<04a<0oa>=4`00;A<0100C4a<30004

4`0C4`<0oa>:4`00;1<00`0C00024`800Q<00`0C4`024`0301<C0?lCR1<002dC00<04a<00a<0100C

4`024`0301<C0?lCRA<003<C00@04a<00a<00`0C4`064`0301<C02DC0`0]4`0301<C0?lC9a<001dC

0`000a<0000200`C0`044`<021<00`0C4`0T4`0401<C014C0`000a<00002008C00<04a<00Q<00`0C

4`024`0301<C00DC00@04a<C1@024`0301<C008C20044`80ba<00`0C4`0b4`0301<C00PC000L4`04

01<C02@C00<04a<08a<0100C4`0@4`0401<C00HC00<04`001a<00`0C00044`D00a<00`0C4`084`05

01<C4`001A<00`0C4`334`0301<C00@C00<04a<04a<00`0C4`0N4`0301<C00LC000L4`0501<C01<0

10000a<0000H02/C0`0@4`0501<C01<0100011<04`094`0301<C00@C00<04a<00a<00`0C4`064`@0

0Q<00`0C4`034`0301<C0;4C00@04a<C10024`801Q<00`0C4`034`0301<C008C00<04a<00Q<00`0C

4`024`0301<C00DC00@04a<C1@024`0301<C008C20044`8011<0100C4a<2004C0@0100007A<304dC

00<04a<03a<300HC00<04`001a<200LC00<04a<00a<00`0C4`064`0301<000<C00<04a<00a<00`0C

4`2`4`0301<000LC00<04a<011<500<C00L04a<C01<000LC00<04`0011<500<C00<04a<021<01@0C

4a<000DC00<04a<011<00`0C4`024`0301<0004C000O4`0301<C04XC0P0C4`0301<C00@C00<04`00

1a<00`0C4`0<4`0301<C00LC0P034`0301<C00<C00<04`00/1<00`0C00024`@000<C01<01a<00`0C

4`034`0701<C4`0C00094`0301<C00@C00<04a<00a<00`0C4`064`@00Q<00`0C4`034`0301<C00@C

00<04a<00a<1004C0A<001hC0P1P4`801a<00`0C4`064`<02a<200XC00<04a<00P054`<0UQ<20003

4`0001DC00<04`001a<00`0C4`064`0301<C00<C00L04a<C01<000LC0P074`0301<C00<C00<04a<0

1Q<00`0C00034`0301<C00<C00<04a<011<00`0C4`034`400A<14`00oa=A4`0301<001HC00<04`00

1a<00`0C000=4`0601<C01<01a<00`0C4`0<4`0301<C00LC0P034`0301<C00<C00<04`000a<00`0C

4`034`0301<0004C000Y4`801Q<20?lC7a<00`0C4`0F4`0301<C00HC0`0>4`0401<C00PC0`0;4`80

2Q<00`0C4`0200DC0`024`0301<C00<C0P014`400@0002/C00<04a<00Q<00`0C4`3o4alC00<04a<0

L1<002XC00<04a<00a<00`0C4`054`0301<C0?lC5Q<00`0C001a4`00:a<00`0C4`024`0301<C008C

10034`<0oa<A4`8000<C0000L1<002TC00<04`0011<00`0C00024`8000<C01<011<00`0C4`3o4h@C

000Z4`0301<C00<C0`044`0301<000<C00<04a<0oa>54`00=a<00`0C00044`0301<C0?lCQ1<003DC

0`044`<0oa>64`00oa?54`00oa?54`00oa?54`00oa?54`00oa?54`00\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.02519, -1.54711, 0.0208096, 0.0208096}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -84.5 0 ]

[.5 .96488 84.5 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -145.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.405) show

222.250000 19.500000 moveto

(C) show

227.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.24581 0 m

.26171 .02235 L

.30316 .08058 L

.34309 .13668 L

.3815 .19065 L

.42237 .24807 L

.46172 .30335 L

.49955 .35651 L

.53984 .41312 L

.57861 .46759 L

.61984 .52551 L

.65954 .5813 L

.69774 .63496 L

.73838 .69207 L

.77751 .74705 L

.81909 .80547 L

.85916 .86176 L

.89771 .91593 L

s

.89771 .91593 m

.92366 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.342687 0.238095 [

[.02381 .33019 -6 -9 ]

[.02381 .33019 6 0 ]

[.2619 .33019 -6 -9 ]

[.2619 .33019 6 0 ]

[.7381 .33019 -3 -9 ]

[.7381 .33019 3 0 ]

[.97619 .33019 -3 -9 ]

[.97619 .33019 3 0 ]

[1.025 .34269 0 -8 ]

[1.025 .34269 9 8 ]

[.4875 .10459 -12 -4.5 ]

[.4875 .10459 0 4.5 ]

[.4875 .22364 -24 -4.5 ]

[.4875 .22364 0 4.5 ]

[.4875 .46173 -18 -4.5 ]

[.4875 .46173 0 4.5 ]

[.4875 .58078 -6 -4.5 ]

[.4875 .58078 0 4.5 ]

[.4875 .69983 -18 -4.5 ]

[.4875 .69983 0 4.5 ]

[.4875 .81888 -6 -4.5 ]

[.4875 .81888 0 4.5 ]

[.5 .88046 -4.5 0 ]

[.5 .88046 4.5 16 ]

[.5 .86796 -137 0 ]

[.5 .86796 137 16 ]

[ 0 0 0 0 ]

[ 1 .85546 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .34269 m

.02381 .34894 L

s

[(-2)] .02381 .33019 0 1 Mshowa

.2619 .34269 m

.2619 .34894 L

s

[(-1)] .2619 .33019 0 1 Mshowa

.7381 .34269 m

.7381 .34894 L

s

[(1)] .7381 .33019 0 1 Mshowa

.97619 .34269 m

.97619 .34894 L

s

[(2)] .97619 .33019 0 1 Mshowa

.125 Mabswid

.07143 .34269 m

.07143 .34644 L

s

.11905 .34269 m

.11905 .34644 L

s

.16667 .34269 m

.16667 .34644 L

s

.21429 .34269 m

.21429 .34644 L

s

.30952 .34269 m

.30952 .34644 L

s

.35714 .34269 m

.35714 .34644 L

s

.40476 .34269 m

.40476 .34644 L

s

.45238 .34269 m

.45238 .34644 L

s

.54762 .34269 m

.54762 .34644 L

s

.59524 .34269 m

.59524 .34644 L

s

.64286 .34269 m

.64286 .34644 L

s

.69048 .34269 m

.69048 .34644 L

s

.78571 .34269 m

.78571 .34644 L

s

.83333 .34269 m

.83333 .34644 L

s

.88095 .34269 m

.88095 .34644 L

s

.92857 .34269 m

.92857 .34644 L

s

.25 Mabswid

0 .34269 m

1 .34269 L

s

gsave

1.025 .34269 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .10459 m

.50625 .10459 L

s

[(-1)] .4875 .10459 1 0 Mshowa

.5 .22364 m

.50625 .22364 L

s

[(-0.5)] .4875 .22364 1 0 Mshowa

.5 .46173 m

.50625 .46173 L

s

[(0.5)] .4875 .46173 1 0 Mshowa

.5 .58078 m

.50625 .58078 L

s

[(1)] .4875 .58078 1 0 Mshowa

.5 .69983 m

.50625 .69983 L

s

[(1.5)] .4875 .69983 1 0 Mshowa

.5 .81888 m

.50625 .81888 L

s

[(2)] .4875 .81888 1 0 Mshowa

.125 Mabswid

.5 .1284 m

.50375 .1284 L

s

.5 .15221 m

.50375 .15221 L

s

.5 .17602 m

.50375 .17602 L

s

.5 .19983 m

.50375 .19983 L

s

.5 .24745 m

.50375 .24745 L

s

.5 .27126 m

.50375 .27126 L

s

.5 .29507 m

.50375 .29507 L

s

.5 .31888 m

.50375 .31888 L

s

.5 .3665 m

.50375 .3665 L

s

.5 .39031 m

.50375 .39031 L

s

.5 .41412 m

.50375 .41412 L

s

.5 .43793 m

.50375 .43793 L

s

.5 .48554 m

.50375 .48554 L

s

.5 .50935 m

.50375 .50935 L

s

.5 .53316 m

.50375 .53316 L

s

.5 .55697 m

.50375 .55697 L

s

.5 .60459 m

.50375 .60459 L

s

.5 .6284 m

.50375 .6284 L

s

.5 .65221 m

.50375 .65221 L

s

.5 .67602 m

.50375 .67602 L

s

.5 .72364 m

.50375 .72364 L

s

.5 .74745 m

.50375 .74745 L

s

.5 .77126 m

.50375 .77126 L

s

.5 .79507 m

.50375 .79507 L

s

.5 .08078 m

.50375 .08078 L

s

.5 .05697 m

.50375 .05697 L

s

.5 .03316 m

.50375 .03316 L

s

.5 .00935 m

.50375 .00935 L

s

.5 .84269 m

.50375 .84269 L

s

.25 Mabswid

.5 0 m

.5 .85546 L

s

gsave

.5 .88046 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .86796 -198 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.405) show

298.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

303.000000 15.000000 moveto

(L) show

310.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

317.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

324.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

329.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

333.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .85546 L

0 .85546 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .17352 m

.02576 .17352 L

.03156 .17352 L

.04113 .17352 L

.0543 .17353 L

.07083 .17354 L

.09046 .17355 L

.11284 .17356 L

.13758 .17358 L

.16428 .1736 L

.19247 .17362 L

.22166 .17364 L

.25136 .17367 L

.28106 .17371 L

.31025 .17375 L

.33844 .17379 L

.36513 .17384 L

.38988 .17389 L

.41226 .17395 L

.43189 .17401 L

.44842 .17407 L

.46159 .17412 L

.47116 .17417 L

.47696 .1742 L

.47891 .17421 L

s

.47891 .17421 m

.4796 .17421 L

.48164 .17422 L

.48501 .17424 L

.48965 .17426 L

.49548 .1743 L

.5024 .17434 L

.51028 .1744 L

.51901 .17447 L

.52841 .17455 L

.53835 .17465 L

.54864 .17478 L

.5591 .17492 L

.56957 .17511 L

.57986 .17533 L

.58979 .1756 L

.5992 .17594 L

.60792 .17637 L

.61581 .1769 L

.62273 .17756 L

.62855 .17841 L

.63319 .17947 L

.63656 .18082 L

.63861 .18252 L

.6393 .18462 L

s

.47891 .42687 m

.4796 .41175 L

.48164 .39663 L

.48501 .38163 L

.48965 .36682 L

.49548 .35227 L

.5024 .33802 L

.51028 .32414 L

.51901 .3107 L

.52841 .29773 L

.53835 .2853 L

.54864 .27345 L

.5591 .26223 L

.56957 .25168 L

.57986 .24183 L

.58979 .23272 L

.5992 .22437 L

.60792 .2168 L

.61581 .21001 L

.62273 .204 L

.62855 .19876 L

.63319 .19425 L

.63656 .19043 L

.63861 .18725 L

.6393 .18464 L

s

.47891 .42698 m

.4796 .4421 L

.48164 .45721 L

.48501 .47219 L

.48965 .48697 L

.49548 .5015 L

.5024 .5157 L

.51028 .52952 L

.51901 .5429 L

.52841 .55578 L

.53835 .56811 L

.54864 .57984 L

.5591 .59091 L

.56957 .60128 L

.57986 .6109 L

.58979 .61974 L

.5992 .62774 L

.60792 .63489 L

.61581 .64115 L

.62273 .6465 L

.62855 .6509 L

.63319 .65434 L

.63656 .65681 L

.63861 .6583 L

.6393 .65879 L

s

.6393 .65879 m

.63959 .659 L

.64045 .65963 L

.64188 .66065 L

.64384 .66205 L

.6463 .6638 L

.64922 .66586 L

.65255 .66818 L

.65624 .67073 L

.66021 .67344 L

.66441 .67628 L

.66876 .67918 L

.67318 .6821 L

.6776 .68499 L

.68195 .68779 L

.68615 .69048 L

.69012 .69299 L

.69381 .6953 L

.69714 .69737 L

.70006 .69917 L

.70252 .70069 L

.70448 .70188 L

.70591 .70275 L

.70677 .70327 L

.70706 .70345 L

s

.70706 .1623 m

.70821 .15915 L

.71165 .15521 L

.7173 .15042 L

.72509 .14478 L

.73487 .13834 L

.74647 .13118 L

.75971 .12342 L

.77434 .11518 L

.79013 .10662 L

.8068 .09787 L

.82406 .0891 L

.84163 .08042 L

.85919 .07198 L

.87645 .06388 L

.89312 .05624 L

.90891 .04915 L

.92354 .0427 L

.93678 .03696 L

.94838 .032 L

.95816 .02787 L

.96595 .02461 L

.97161 .02226 L

.97504 .02084 L

.97619 .02037 L

s

.70706 .16231 m

.70821 .16477 L

.71165 .16664 L

.7173 .16806 L

.72509 .16912 L

.73487 .16991 L

.74647 .17051 L

.75971 .17096 L

.77434 .17131 L

.79013 .17158 L

.8068 .17179 L

.82406 .17196 L

.84163 .17209 L

.85919 .1722 L

.87645 .17229 L

.89312 .17236 L

.90891 .17242 L

.92354 .17247 L

.93678 .17251 L

.94838 .17254 L

.95816 .17256 L

.96595 .17258 L

.97161 .17259 L

.97504 .1726 L

.97619 .1726 L

s

.70706 .70345 m

.70821 .70415 L

.71165 .70621 L

.7173 .70958 L

.72509 .71416 L

.73487 .71981 L

.74647 .72637 L

.75971 .73368 L

.77434 .74157 L

.79013 .74986 L

.8068 .7584 L

.82406 .76701 L

.84163 .77555 L

.85919 .78388 L

.87645 .79189 L

.89312 .79946 L

.90891 .80649 L

.92354 .81289 L

.93678 .81859 L

.94838 .82352 L

.95816 .82763 L

.96595 .83087 L

.97161 .83321 L

.97504 .83462 L

.97619 .83509 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<00`0C4`1`4`00oa=B4`80LA<006@C1@3X4`0301<C070C001V4`0301<C0>PC00<04a<0

L1<0040C00<=4a<07A<300<C00<04a<00Q<20>@C00<04a<0GA<00`dC4`0@4`00@1<00`dC4`0S4`03

01<C008C00<04a<0ha<00`0C4`1J4`<=4a<0044C00<=4a<08Q<00`0C4`024`0301<C0><C0P1H4`<=

5Q<0044C00<=4a<08A<200@C00<04a<0ha<00`0C4`1E4`8=6A<0048C00<=4a<09Q<20>@C00<04a<0

Da<23A/C00134`033A<C02DC00<04a<0ha<00`0C4`1A4`8=7A<004<C00<=4a<09A<00`0C4`3S4`03

01<C04lC0PdO4`00A1<00`dC4`0T4`0301<C0><C0P1=4`<=8A<004DC00<=4a<08a<20>@C00<04a<0

BA<33B@C00154`033A<C02<C00<04a<0ha<00`0C4`174`8=9a<004HC00<=4a<08Q<00`0C4`3S4`03

01<C04HC00<=4a<09a<004LC00<=4a<08A<00`0C4`3S4`0301<C04@C0PdZ4`00B1<00`dC4`0P4`80

i1<204<C0Pd/4`00B1<00`dC4`0P4`0301<C0><C00<04a<0@1<23BhC00194`033A<C01lC00<04a<0

ha<00`0C4`0n4`8=<1<004XC00<=4a<07Q<00`0C4`3L4`D00Q<00`0C4`0k4`<=<Q<004XC00<=4a<0

7Q<20=lC00<04a<00Q<00`0C4`0i4`8==A<004/C00<=4a<07A<00`0C4`3H4`<00a<00`0C4`024`80

>A<00`dC4`0e4`00C1<00`dC4`0=4`0301<C008C00<04a<00Q<00`0C4`024`0301<C0=hC00<04a<0

0Q<00`0C4`0f4`8=>1<004`C00<=4a<031<00`0C00074`0301<000<C00<04a<0gQ<00`0C4`024`03

01<C03DC00<=4a<0>1<004dC00<=4a<01Q<3008C00<04`002A<0100C4a<20=hC0P044`0301<C03<C

0Pdk4`00CQ<00`dC4`0:4`0301<000LC0P044`0301<C0><C00<04a<0<A<23CdC001?4`033A<C00TC

00<04`001a<00`0C4`034`0301<C0><C0P0`4`8=?a<004lC00<=4a<02Q<00`0C4`064`<00a<00`0C

4`3S4`0301<C02hC00<=4a<0?a<0050C00<=4a<061<00`0C4`3S4`0301<C02dC00<=4a<0@1<0054C

00<=4a<05a<20>@C00<04a<0:a<23D<C001B4`033A<C01HC00<04a<0ha<202XC0Pe54`00DQ<00`dC

4`0F4`0301<C0><C00<04a<0:1<00`dC4`154`00Da<00`dC4`0E4`0301<C0><C00<04a<09a<00`dC

4`164`00E1<00`dC4`0D4`80i1<00`0C4`0W4`8=Aa<005DC00<=4a<04a<00`0C4`3S4`0301<C02TC

=@dB4`006Q<302DC1@0>4`033A<C01<C00<04a<091<502@C0`0c4gX=FA<001XC00<04a<09a<00`0C

4`0?4`033A<C018C00<04a<09Q<00`0C4`0T4`0301<C09<C00<04a<05a<33EHC000E4`<00a<00`0C

4`0P4`<00a<00`0C4`0@4`033A<C014C0P0W4`0301<C02DC00<04a<0TQ<00`0C4`0I4`033A<C05@C

000K4`0301<C02HC00<04a<04A<00`dC4`0@4`0301<C02HC00<04a<09A<00`0C4`2B4`0301<C01TC

00<=4a<0E1<001XC00<04`009a<00`0C4`0A4`033A<C010C00<04a<09Q<00`0C4`0T4`0301<009<C

00<04a<061<00`dC4`1E4`006a<00`0C4`0U4`8051<00`dC4`0?4`0301<C02DC0P0W4`0301<C098C

0P0H4`033A<C05HC001J4`033A<C00hC0P3T4`0301<C01HC00<=4a<0Ea<005XC00<=4a<03Q<00`0C

4`3S4`0301<C01DC00<=4a<0F1<005/C00<=4a<03A<00`0C4`1K4`80Ma<00`0C4`024`0301<C008C

00<04a<00Q<00`0C4`0C4`8=Fa<005`C00<=4a<031<00`0C4`1J4`0301<C07HC00<04`001a<00`0C

00034`0301<C018C00<=4a<0Fa<001DCB0000`d0001R00HC00<04a<0LA<3008C00<04`002A<0100C

4a<2018C00<=4a<0G1<001TC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`03

01<C00DC00<04a<01Q<00`0C4`054`0301<=00DC00<04a<01A<00a0C4`054`0301<C00HC00<04a<0

1A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`054`03

01<C00PC00<04a<0MQ<00`0C00074`8011<00`0C4`0@4`033A<C05dC001N4`033A<C00XC00<@4a<0

FQ<00`0C001f4`0301<000LC00<04a<00a<00`0C4`0?4`033A<C05hC001O4`033A<C00TC0Q1K4`<0

Ma<00`0C4`064`<00a<00`0C4`0=4`8=HA<0060C00<=4a<021<24>@C00<04a<031<00`dC4`1Q4`00

H1<00`dC4`074`03400@0>@C0P0<4`033A<C068C001Q4`033A<C00HC00<@0100i1<00`0C4`0:4`03

3A<C06<C001R4`033A<C00DC00<@0100i1<00`0C4`0:4`033A<C06<C001S4`033A<C00<C00D@4`00

403S4`0301<C00TC00<=4a<0I1<006<C00<=4a<00a<01A0C01<@0><C0P094`033A<C06DC001T4`03

3A<C008C00D@4`0C403S4`0301<C00LC00<=4a<0IQ<006DC00L=4a<C41<0008C00<@4a<0h1<00`0C

4`064`033A<C06LC001V4`053A<C41<00P000a<@4`3Q4`0301<C00DC00<=4a<0J1<006HC00H=4a<@

4`024`0341<C084C0`0/4`D0:a<00`0C4`044`033A<C02@C1@0/4`<04A<006LC00D=41<C00034`03

41<C080C00<04a<0;Q<00`0C4`0[4`801A<00`dC4`0V4`0301<C02`C00<04a<04A<006PC00@=4a<0

0a<00a0C4`1k4`<00a<00`0C4`0W4`<00a<00`0C4`0[4`0301<C00<C00<=4a<09a<00`0C4`0]4`03

01<C010C001X4`033A<C00800Q<00a0C4`214`0301<C02dC00<04a<0:a<00`0C4`024`033A<C02PC

00<04a<0;A<00`0C4`0@4`00Ia<01A0C3A<000@C00<@4a<0Oa<00`0C000^4`0301<C02/C00D04a<C

3@0[4`0301<C02`C00<04`004A<005`C00<04a<00Q<00`0C4`024`06010C4`d011<00a0C4`204`03

01<C02`C0P0]4`0401<C3B/C0P0_4`0301<C010C001K4`0301<000LC00<040000Q<00`d04`034`03

41<C0=hC0P000a<=4`1^4`00Fa<00`0C00084`03400C008C00<=01<00a<00a0C4`3M4`0301<=070C

001K4`0301<000LC00<041<00a<00`0=4`034`0341<C0=dC00<04`d0L1<005/C00<04`001a<00a0C

4`034`0300dC00@C00<@4a<0g1<00`0=4`1[4`800a<005`C00<04a<01Q<00a0000034`0301<=00@C

00<@4a<0g1<00`0=4`1Z4`0301<C00<C001T4`0341<C00@C0P000a<=4`024`0341<C07LCI@000`d0

001S00LC00<04a<00a<006@C00<@4a<011<0100C4`d44`0341<C07/C00<04a<01Q<00`0C4`074`03

01<C00LC00<04a<01Q<00`0C4`074`0301<C00LC00<04a<01Q<00`0C4`074`0301<C00HC00<04a<0

1a<00`dC4`074`0301<C00HC00<04a<01a<00`0C4`074`0301<C00HC00<04a<01a<00`0C4`074`03

01<C00HC00<04a<01a<00`0C4`064`0301<C00XC00<04a<00a<006<C00<@4a<01A<01@0C4a<=00<C

00<@4a<0fQ<00`d04`1[4`0301<000<C001S4`0341<C00DC00<04a<00Q<01@dC4a<@0=/C00<=01<0

Ja<300<C001R4`0341<C00HC00<04a<00a<010dC4a3J4`033A<0078C001R4`0341<C00HC0P044`05

3A<C4a00fA<010dC001a4`00HA<00a0C4`074`0301<C00@C00@=4a<@fA<00`dC001b4`00HA<00a0C

4`074`0301<C00DC00<=4a00f1<010dC4`1b4`00H1<00a0C4`084`0301<C00HC00<=4a00ea<010dC

4`1b4`00H1<00a0C4`084`801a<00`dC403G4`043A<C078C001O4`0341<C00TC00<04a<01a<00`dC

403E4`043A<C4`80LA<005lC00<@4a<02A<00`0C4`084`033A0C0=@C00D=4a<C001b4`00GQ<00a0C

4`0:4`0301<C00TC00<=41<0da<01@dC4a<0078C001N4`0341<C00XC0P0:4`033A0C0=<C00D=4a<C

001b4`00GA<00a0C4`0;4`0301<C00XC00<=41<0dQ<010dC4a<2074C001M4`0341<C00@C1@024`03

01<C00/C00<=4a<0dA<01@dC4a<0078C001L4`0341<C00LC00<04a<00Q<00`0C4`0<4`033A<C0=0C

00D=4a<C001b4`00Fa<00a0C4`084`0301<C008C0P0=4`033A0C0=0C00D=4a<C001b4`00Fa<00a0C

4`084`0301<C008C00<04a<03A<00`dC4`3?4`053A<C4`00LQ<005XC00<@4a<02A<00`0C4`024`03

01<C00hC00<=4a<0cQ<010dC4a<2074C001J4`0341<C00PC0P044`0301<C00hC00<=41<0cQ<01@dC

4a<0078C001I4`0341<C00lC0P0@4`033A<C0<dC00D=4a<C001b4`00F1<00a0C4`0@4`0301<C010C

00<=4a<0`A<00`0C4`024`0301<C008C00<03A<00Q<00`0C4`1`4`00F1<00a0C4`0@4`0301<C014C

00<=4a<0_a<00`0C00074`0301<=00<C00<04a<0L1<005LC00<@4a<04A<00`0C4`0A4`033A<C0;lC

00<04`002A<010dC4a<2074C001F4`0341<C018C0P0C4`033A<C0;hC00<04`001a<200054`dC4`00

LQ<005HC00<@4a<04Q<00`0C4`0C4`033A<C0;dC00<04`001a<0100C4`d24`0301<C070C001E4`03

41<C01<C00<04a<04a<00`dC4`2n4`0301<C00HC0`0010dC4`1b4`00E1<00a0C4`0D4`0301<C01@C

00<=4a<0bQ<00`dC001b4`00Da<00a0C4`0E4`805A<00a0=4`3:4`043A<0074C001C4`0341<C01DC

00<04a<05A<00`dC4`394`033A<0078C001B4`0341<C01HC00<04a<05Q<00`dC4`394`033@0C074C

001A4`0341<C01LC00<04a<05Q<00a0=4`394`033@0C074C001A4`0341<C01LC0P0H4`0340dC0<TC

00<=4a<0L1<0050C00<@4a<061<00`0C4`0G4`0340dC0<TC00<=01<0L1<004lC00<@4a<021<5008C

00<04a<00Q<00`0C4`024`0301<C01PC00<@3A<0b1<00`0=4`1`4`00Ca<00a0C4`0:4`0301<C00HC

00<04`000a<00`0C4`0I4`0340dC0<LC00<03A<0L1<004hC00<@4a<02a<00`0C4`084`0401<C4`80

6a<00`dC4`364`0301<=070C001=4`0341<C00`C00<04a<01Q<200@C00<04a<06Q<00a0=4`364`80

00<=4a<0KQ<004`C00<@4a<03A<00`0C4`064`0301<C00<C00<04a<06a<00a0=4`354`0401<C3FlC

001<4`0341<C00`C0P084`<00a<00`0C4`0L4`033A<C0<@C00D04a<C3@1^4`00Ba<00a0C4`0M4`80

7Q<00`dC4`334`0301<C008C00<=4a<0Ja<004XC00<@4a<07Q<00`0C4`0M4`0340dC0<<C00<04a<0

0Q<00`dC4`1[4`00BQ<00a0C4`0N4`0301<C01hC00<=4a<0`Q<200@C00<=4a<0JQ<004TC00<@4a<0

7a<00`0C4`0O4`033A<C0<4C00<04a<011<00`dC4`1Y4`00B1<00a0C4`0P4`808A<00`dC4`304`03

01<C00DC00<=4a<0J1<004LC00<@4a<08A<00`0C4`0P4`033A0C0;TC1@024`0301<C00HC00<=4a<0

Ia<004LC00<@4a<08A<00`0C4`0Q4`033A<C0;XC00<04a<00Q<00`0C4`064`033A<C06LC00164`03

41<C028C00<04a<08Q<00`dC4`2i4`0301<C008C0P084`033A<C06HC00154`0341<C02<C0P0S4`03

3A0C0;TC00<04a<00Q<00`0C4`084`033A<C06DC00144`0341<C02@C00<04a<08a<00`d@4`2h4`03

01<C008C00<04a<02A<00`dC4`1T4`00A1<00a0C4`0T4`0301<C02@C00<=4a<0]Q<200@C00<04a<0

2Q<00`dC4`1S4`00@a<00a0C4`0U4`0301<C02DC00<=4a<0^a<00`0C4`0;4`033A<C068C00124`03

41<C02HC00<04a<09A<00`d@4`2k4`803A<00`dC4`1Q4`00@A<00a0C4`0W4`809a<00`d@4`2j4`03

01<C00dC00<=4a<0H1<0040C00<@4a<0:1<00`0C4`0W4`033A0C0;TC00<04a<03Q<00`dC4`1O4`00

@1<00a0C4`0R4`<00a<00`0C4`0X4`033A0C0;PC00<04a<03a<00`dC4`1N4`00?a<00a0C4`0S4`03

01<C00<C00<04a<0:1<00`d@4`2h4`0301<C010C00<=4a<0GA<003hC00<@4a<09A<00`0C4`024`80

:Q<00`d@4`2g4`804Q<00`dC4`1L4`00?A<00a0C4`0V4`0301<C008C00<04a<0:Q<00`d@4`2f4`03

01<C018C0PeL4`00?A<00a0C4`0U4`0301<000<C00<04a<0:a<00`d@4`2e4`0301<C01@C0PeJ4`00

?1<00a0C4`0W4`0301<C008C00<04a<0:a<00`dC402e4`0301<C01HC00<=4a<0Ea<003/C00<@4a<0

;A<202dC00<=4a00]1<00`0C4`0G4`033A<C05HC000j4`0341<C02hC00<04a<0;A<00`d@4`2c4`80

6A<23EHC000j4`0341<C02hC00<04a<0;Q<00`d@4`2b4`0301<C01TC0PeE4`00>A<00a0C4`0_4`03

01<C02hC00<=4a00/Q<00`0C4`0K4`033A<C058C000h4`0341<C030C0P0`4`033A<@0;4C00<04a<0

71<23E8C000g4`0341<C034C00<04a<0<1<00`d@4`2`4`807a<00`dC4`1?4`00=a<00a0C4`0a4`03

01<C030C00<=4a00/1<00`0C4`0O4`033A<C04hC000f4`0341<C038C00<04a<0<A<00`dC402_4`03

01<C020C0Pe>4`00=A<00a0C4`0c4`80<a<00`dC402M4`D00Q<00`0C4`024`0301<C008C00<04a<0

8Q<23D`C000d4`0341<C03@C00<04a<0<a<00`dC402N4`0301<C00HC00<04`000a<00`0C4`0T4`03

3A<C04TC000c4`0341<C03DC00<04a<0<a<010dC4a2M4`0301<C00PC00@04a<C0P0V4`8=BA<0038C

00<@4a<0=Q<00`0C4`0d4`033A<@09dC00<04a<01Q<200@C00<04a<09Q<33DLC000a4`0341<C03LC

0P0f4`033A<@09`C00<04a<01Q<00`0C4`034`0301<C02TC00<=4a<0A1<0030C00<@4a<0>1<00`0C

4`0e4`043A<C49XC0P084`<00a<00`0C4`0Z4`8=A1<002lC00<@4a<0:A<300<C00<04a<00Q<00`0C

4`024`0301<C03HC00@=4a<@ZA<00`0C4`0/4`8=@Q<002hC00<@4a<0:Q<00`0C4`074`0301<000<C

00<04a<0=a<010dC4a2X4`80;a<00`dC4`0o4`00;A<00a0C4`0/4`0301<C00PC00@04a<C0P0h4`05

3A<C4a00Ya<00`0C4`0_4`8=?a<002`C00<@4a<0;A<00`0C4`064`8011<00`0C4`0h4`053A<C4a00

YQ<00`0C4`0a4`8=?A<002/C00<@4a<0;A<00`0C00074`0301<C00<C00<04a<0>A<01@dC4a<@0:DC

00<04a<0<a<23C/C000Z4`0341<C02lC00<04a<01Q<300<C00<04a<0>Q<01@dC4a<@0:@C00<04a<0

=A<23CTC000Y4`0341<C03lC0P0k4`033A<C008C00<@4a<0XA<203PC0Pdg4`00:1<00a0C4`104`03

01<C03/C00<=4a<00Q<00a0C4`2P4`0301<C03TC0Pde4`009a<00a0C4`114`0301<C03`C00<=4a<0

0Q<00a0C4`2O4`0301<C03/C00<=4a<0<Q<002HC00<@4a<0@Q<00`0C4`0l4`033A<C00<C00<@4a<0

WQ<00`0C4`0l4`8=<Q<002DC00<@4a<0@a<203hC00<=4a<00a<00a0C4`2M4`0301<C03hC0`d_4`00

91<00a0C4`144`0301<C03hC00<=4a<00a<00a0C4`2L4`80@Q<23BdC000S4`0341<C04DC00<04a<0

?Q<00`dC4`044`0341<C09/C00<04a<0@a<23B/C000S4`0341<C04DC00<04a<0?a<00`dC4`044`03

41<C09XC00<04a<0AA<23BTC000R4`0341<C04HC0P114`033A<C00@C00<@4a<0VA<00`0C4`174`8=

9a<0024C00<@4a<0Aa<00`0C4`104`033A<C00DC00<@4a<0V1<204XC0PdU4`0081<00a0C4`184`03

01<C044C00<=4a<01A<00a0C4`2G4`0301<C04/C0`dR4`007a<00a0C4`194`0301<C048C00<=4a<0

1A<00a0C4`2F4`0301<C04hC0PdP4`007Q<00a0C4`1:4`80@a<00`dC4`064`0341<C08lC0`034`03

01<C050C0PdN4`007A<00a0C4`1;4`0301<C04<C00<=4a<01Q<00a0C4`2>4`0301<C00<C00<04a<0

DQ<23A`C000L4`0341<C04`C00<04a<0A1<00`dC4`064`0341<C08hC00<04a<00Q<205DC0`dI4`00

6a<00a0C4`174`8011<00`0C4`154`033A<C00HC00<@4a<0SA<00`0C4`024`0301<C05LC0PdG4`00

6Q<00a0C4`1:4`0501<C4`00Aa<00`dC4`074`0341<C08/C00<04`000a<00`0C4`1I4`8=5A<001TC

00<@4a<0BQ<00`0C4`024`80Aa<00`dC4`064`0341<C08`C00<04a<00Q<00`0C4`1K4`<=4Q<006LC

00<04a<0ia<00`0C4`1M4`033A<C010C001U4`0301<00>TC0P1a4`00IQ<00`0C4`3X4`0301<C070C

000Z4`<0oa<U4`0301<C070C000Z4`0301<C0?lC9A<00`0C4`1`4`00:a<00`0C4`044`0301<C0?lC

T1<002/C00@04a<C10034`<0oa><4`00:Q<00`0C00024`8000<C01<011<00`0C4`3o4hXC000[4`03

01<C00<C00<04`000a<00`0C4`3o4h/C000a4`0301<000@C00<04a<01Q<00`0C4`0W4`<0:a<00`0C

4`3o4bTC000K4`<000<C00000P0<4`<011<300PC00<04a<09Q<0100C4`0?4`<000<C00000P024`03

01<C008C00<04a<00Q<00`0C4`054`0401<C4`D00Q<00`0C4`024`<00Q<00`0C4`024`0301<C00@C

0P354`0301<C03LC00<04a<01Q<001XC00@04a<091<00`0C4`0U4`0401<C00hC00@04a<01Q<00`0C

00074`0301<000@C1@034`0301<C00PC00H04a<04`024`0301<000@C00<04a<0_A<00`0C4`044`03

01<C01<C00<04a<08a<00`0C4`054`006Q<01@0C4`0C00@000<C0000600]4`<03Q<01@0C4`0C00@0

00@C01<02A<00`0C4`044`0301<C00<C00<04a<01Q<400044`0C00@C00<04a<00Q<00`0C4`2[4`04

01<C4`@00Q<200HC00<04a<00a<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`054`0401<C4`D0

0Q<00`0C4`024`<00Q<00`0C4`024`0301<C00@C0P044`0401<C4`800A<001/C0`1?4`0301<C00dC

0`064`0301<000LC0P074`0301<C00<C00<04a<01Q<00`0C00024`0301<0008C0P054`0301<C0:XC

00<04`001a<00`0C4`044`D00a<01`0C4a<04`001a<00`0C00044`D00a<00`0C4`084`0601<C01<0

0Q<00`0C00044`0301<C00@C00<04a<00Q<1004C000M4`0301<C04`C0P0A4`0301<C00@C00<04`00

1a<00`0C4`0<4`0301<C00LC0P024`0301<0008C00<04a<011<00`0C002Z4`0301<0008C10000a<0

4`074`0301<C00<C00L04a<C01<000TC00<04a<011<00`0C4`034`0301<C00HC100011<04`044`03

01<C008C00<04a<011<00`0C4`034`40000L4`80H1<200LC00<04a<01Q<300/C0P0:4`0501<C4`00

0a<300@C0`2C4`8000<C00004Q<00`0C00074`0301<C00HC00<04a<00a<01`0C4a<04`001a<200LC

00<04a<00a<00`0C4`064`0301<0008C00<04`000Q<200DC00<04a<011<00`0C4`034`40003o4e4C

00<04`004a<00`0C00074`0301<000dC00H04a<04`074`0301<C00`C00<04a<01a<2008C00<04`00

0Q<00`0C4`044`0301<000<C00<04a<00a<1004C000V4`801Q<20?lC8Q<00`0C4`0C4`0301<C00HC

0`0>4`0401<C00PC0`0;4`802Q<01@0C4a<000<C0`044`<00Q<00`0C4`034`800A<002PC00<04a<0

0Q<00`0C4`3o4b8C00<04a<0L1<002LC00<04a<00a<00`0C4`064`0301<C0?lC61<00`0C001a4`00

:1<00`0C4`024`0301<C008C0`0011<04a<30?lC51<200034`00070C000V4`0301<000@C00<04`00

0Q<2008C00<04a<00Q<00`0C4`3o4hLC000W4`0301<C00<C0`044`0401<C008C00<04a<0oa>84`00

=1<0100C4`034`0301<C0?lCQa<0038C0`044`<0oa>94`00oa?54`00oa?54`00oa?54`00oa?54`00

oa?54`00\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-7.00863, -1.54051, 0.0207605, 0.0207605}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -79.5 0 ]

[.5 .96488 79.5 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -140.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.4) show

212.250000 19.500000 moveto

(C) show

217.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.2449 0 m

.26171 .02354 L

.30316 .08156 L

.34309 .13746 L

.3815 .19124 L

.42237 .24845 L

.46172 .30355 L

.49955 .35652 L

.53984 .41292 L

.57861 .4672 L

.61984 .52491 L

.65954 .5805 L

.69774 .63397 L

.73838 .69088 L

.77751 .74566 L

.81909 .80387 L

.85916 .85997 L

.89771 .91394 L

s

.89771 .91394 m

.92517 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.341153 0.238095 [

[.02381 .32865 -6 -9 ]

[.02381 .32865 6 0 ]

[.2619 .32865 -6 -9 ]

[.2619 .32865 6 0 ]

[.7381 .32865 -3 -9 ]

[.7381 .32865 3 0 ]

[.97619 .32865 -3 -9 ]

[.97619 .32865 3 0 ]

[1.025 .34115 0 -8 ]

[1.025 .34115 9 8 ]

[.4875 .10306 -12 -4.5 ]

[.4875 .10306 0 4.5 ]

[.4875 .22211 -24 -4.5 ]

[.4875 .22211 0 4.5 ]

[.4875 .4602 -18 -4.5 ]

[.4875 .4602 0 4.5 ]

[.4875 .57925 -6 -4.5 ]

[.4875 .57925 0 4.5 ]

[.4875 .6983 -18 -4.5 ]

[.4875 .6983 0 4.5 ]

[.4875 .81734 -6 -4.5 ]

[.4875 .81734 0 4.5 ]

[.5 .87836 -4.5 0 ]

[.5 .87836 4.5 16 ]

[.5 .86586 -132 0 ]

[.5 .86586 132 16 ]

[ 0 0 0 0 ]

[ 1 .85336 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .34115 m

.02381 .3474 L

s

[(-2)] .02381 .32865 0 1 Mshowa

.2619 .34115 m

.2619 .3474 L

s

[(-1)] .2619 .32865 0 1 Mshowa

.7381 .34115 m

.7381 .3474 L

s

[(1)] .7381 .32865 0 1 Mshowa

.97619 .34115 m

.97619 .3474 L

s

[(2)] .97619 .32865 0 1 Mshowa

.125 Mabswid

.07143 .34115 m

.07143 .3449 L

s

.11905 .34115 m

.11905 .3449 L

s

.16667 .34115 m

.16667 .3449 L

s

.21429 .34115 m

.21429 .3449 L

s

.30952 .34115 m

.30952 .3449 L

s

.35714 .34115 m

.35714 .3449 L

s

.40476 .34115 m

.40476 .3449 L

s

.45238 .34115 m

.45238 .3449 L

s

.54762 .34115 m

.54762 .3449 L

s

.59524 .34115 m

.59524 .3449 L

s

.64286 .34115 m

.64286 .3449 L

s

.69048 .34115 m

.69048 .3449 L

s

.78571 .34115 m

.78571 .3449 L

s

.83333 .34115 m

.83333 .3449 L

s

.88095 .34115 m

.88095 .3449 L

s

.92857 .34115 m

.92857 .3449 L

s

.25 Mabswid

0 .34115 m

1 .34115 L

s

gsave

1.025 .34115 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .10306 m

.50625 .10306 L

s

[(-1)] .4875 .10306 1 0 Mshowa

.5 .22211 m

.50625 .22211 L

s

[(-0.5)] .4875 .22211 1 0 Mshowa

.5 .4602 m

.50625 .4602 L

s

[(0.5)] .4875 .4602 1 0 Mshowa

.5 .57925 m

.50625 .57925 L

s

[(1)] .4875 .57925 1 0 Mshowa

.5 .6983 m

.50625 .6983 L

s

[(1.5)] .4875 .6983 1 0 Mshowa

.5 .81734 m

.50625 .81734 L

s

[(2)] .4875 .81734 1 0 Mshowa

.125 Mabswid

.5 .12687 m

.50375 .12687 L

s

.5 .15068 m

.50375 .15068 L

s

.5 .17449 m

.50375 .17449 L

s

.5 .1983 m

.50375 .1983 L

s

.5 .24592 m

.50375 .24592 L

s

.5 .26972 m

.50375 .26972 L

s

.5 .29353 m

.50375 .29353 L

s

.5 .31734 m

.50375 .31734 L

s

.5 .36496 m

.50375 .36496 L

s

.5 .38877 m

.50375 .38877 L

s

.5 .41258 m

.50375 .41258 L

s

.5 .43639 m

.50375 .43639 L

s

.5 .48401 m

.50375 .48401 L

s

.5 .50782 m

.50375 .50782 L

s

.5 .53163 m

.50375 .53163 L

s

.5 .55544 m

.50375 .55544 L

s

.5 .60306 m

.50375 .60306 L

s

.5 .62687 m

.50375 .62687 L

s

.5 .65068 m

.50375 .65068 L

s

.5 .67449 m

.50375 .67449 L

s

.5 .72211 m

.50375 .72211 L

s

.5 .74592 m

.50375 .74592 L

s

.5 .76972 m

.50375 .76972 L

s

.5 .79353 m

.50375 .79353 L

s

.5 .07925 m

.50375 .07925 L

s

.5 .05544 m

.50375 .05544 L

s

.5 .03163 m

.50375 .03163 L

s

.5 .00782 m

.50375 .00782 L

s

.5 .84115 m

.50375 .84115 L

s

.25 Mabswid

.5 0 m

.5 .85336 L

s

gsave

.5 .87836 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .86586 -193 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.4) show

288.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

293.000000 15.000000 moveto

(L) show

300.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

307.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

314.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

319.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

323.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .85336 L

0 .85336 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .17154 m

.02576 .17154 L

.03156 .17154 L

.04113 .17155 L

.05429 .17156 L

.07083 .17157 L

.09045 .17159 L

.11283 .17161 L

.13758 .17164 L

.16427 .17166 L

.19246 .1717 L

.22165 .17174 L

.25135 .17178 L

.28105 .17184 L

.31024 .1719 L

.33842 .17197 L

.36512 .17204 L

.38986 .17213 L

.41224 .17221 L

.43186 .17231 L

.4484 .1724 L

.46156 .17248 L

.47113 .17255 L

.47694 .17259 L

.47888 .17261 L

s

.47888 .17261 m

.47955 .17261 L

.48152 .17263 L

.48476 .17265 L

.48923 .17269 L

.49485 .17274 L

.50151 .17281 L

.5091 .17289 L

.5175 .17299 L

.52656 .17311 L

.53613 .17326 L

.54604 .17343 L

.55612 .17365 L

.5662 .1739 L

.57611 .17421 L

.58568 .17459 L

.59474 .17505 L

.60314 .17561 L

.61074 .1763 L

.6174 .17714 L

.62301 .17819 L

.62748 .17948 L

.63073 .18107 L

.6327 .18301 L

.63336 .18537 L

s

.47888 .42537 m

.47955 .41054 L

.48152 .39571 L

.48476 .381 L

.48923 .36647 L

.49485 .35218 L

.50151 .33819 L

.5091 .32456 L

.5175 .31135 L

.52656 .2986 L

.53613 .28637 L

.54604 .2747 L

.55612 .26364 L

.5662 .25322 L

.57611 .24348 L

.58568 .23444 L

.59474 .22614 L

.60314 .21857 L

.61074 .21175 L

.6174 .20566 L

.62301 .2003 L

.62748 .19564 L

.63073 .19163 L

.6327 .18823 L

.63336 .18539 L

s

.47888 .42548 m

.47955 .44031 L

.48152 .45513 L

.48476 .46981 L

.48923 .4843 L

.49485 .49854 L

.50151 .51246 L

.5091 .52601 L

.5175 .53912 L

.52656 .55175 L

.53613 .56383 L

.54604 .57533 L

.55612 .58618 L

.5662 .59634 L

.57611 .60577 L

.58568 .61443 L

.59474 .62228 L

.60314 .62928 L

.61074 .63542 L

.6174 .64065 L

.62301 .64497 L

.62748 .64834 L

.63073 .65076 L

.6327 .65222 L

.63336 .65271 L

s

.63336 .65271 m

.63372 .65297 L

.63481 .65377 L

.6366 .65507 L

.63905 .65685 L

.64214 .65907 L

.64581 .66168 L

.64999 .66461 L

.65461 .66782 L

.65959 .67123 L

.66486 .67478 L

.67031 .67841 L

.67585 .68204 L

.6814 .68563 L

.68685 .68911 L

.69211 .69242 L

.6971 .69552 L

.70172 .69836 L

.7059 .70091 L

.70956 .70312 L

.71265 .70497 L

.71511 .70644 L

.7169 .7075 L

.71798 .70814 L

.71835 .70835 L

s

.71835 .15754 m

.71945 .15421 L

.72274 .15014 L

.72816 .14532 L

.73562 .13974 L

.74499 .13344 L

.75611 .1265 L

.76879 .11901 L

.78281 .1111 L

.79793 .10289 L

.8139 .09452 L

.83044 .08613 L

.84727 .07783 L

.8641 .06975 L

.88064 .062 L

.8966 .05469 L

.91173 .04791 L

.92575 .04173 L

.93843 .03623 L

.94955 .03148 L

.95892 .02751 L

.96638 .02439 L

.9718 .02214 L

.97509 .02077 L

.97619 .02032 L

s

.71835 .15756 m

.71945 .16025 L

.72274 .16238 L

.72816 .16405 L

.73562 .16535 L

.74499 .16636 L

.75611 .16714 L

.76879 .16775 L

.78281 .16822 L

.79793 .1686 L

.8139 .1689 L

.83044 .16915 L

.84727 .16934 L

.8641 .1695 L

.88064 .16963 L

.8966 .16974 L

.91173 .16983 L

.92575 .1699 L

.93843 .16996 L

.94955 .17 L

.95892 .17004 L

.96638 .17007 L

.9718 .17008 L

.97509 .1701 L

.97619 .1701 L

s

.71835 .70835 m

.71945 .709 L

.72274 .71093 L

.72816 .71409 L

.73562 .71837 L

.74499 .72366 L

.75611 .72983 L

.76879 .73671 L

.78281 .74414 L

.79793 .75197 L

.8139 .76003 L

.83044 .76819 L

.84727 .77629 L

.8641 .78421 L

.88064 .79182 L

.8966 .79903 L

.91173 .80573 L

.92575 .81183 L

.93843 .81727 L

.94955 .82198 L

.95892 .82591 L

.96638 .829 L

.9718 .83124 L

.97509 .83259 L

.97619 .83304 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<00`0C4`1`4`00oa=B4`80LA<006@C1@3X4`0301<C070C001V4`0301<C0>PC00<04a<0

L1<003lC00<=4a<07Q<300<C00<04a<00Q<20>@C00<04a<0GA<23A4C00104`033A<C02<C00<04a<0

0Q<00`0C4`3S4`0301<C05XC0`dC4`00@1<00`dC4`0S4`0301<C008C00<04a<0ha<205TC0PdF4`00

@A<00`dC4`0Q4`8011<00`0C4`3S4`0301<C05DC0`dH4`00@Q<00`dC4`0V4`80i1<00`0C4`1C4`8=

6a<004<C00<=4a<09A<00`0C4`3S4`0301<C054C0PdM4`00@a<00`dC4`0U4`0301<C0><C00<04a<0

Ca<23AlC00144`033A<C02@C00<04a<0ha<204hC0PdQ4`00AA<00`dC4`0S4`80i1<00`0C4`1:4`<=

8a<004DC00<=4a<08a<00`0C4`3S4`0301<C04PC0PdV4`00AQ<00`dC4`0R4`0301<C0><C00<04a<0

AQ<23BPC00174`033A<C024C00<04a<0ha<00`0C4`144`8=:Q<004PC00<=4a<081<20>@C0P134`8=

;1<004PC00<=4a<081<00`0C4`3S4`0301<C040C0Pd^4`00BA<00`dC4`0O4`0301<C0=`C1@024`03

01<C03hC0Pd`4`00BQ<00`dC4`0N4`0301<C0=hC00<04a<00Q<00`0C4`0l4`8=<Q<004XC00<=4a<0

7Q<20=TC0`034`0301<C008C0P0k4`8==1<004/C00<=4a<07A<00`0C4`3N4`0301<C008C00<04a<0

>1<23CHC001<4`033A<C00dC00<04a<00Q<00`0C4`024`0301<C008C00<04a<0gQ<00`0C4`024`03

01<C03HC0Pdh4`00C1<00`dC4`0<4`0301<000LC00<04`000a<00`0C4`3M4`8011<00`0C4`0e4`03

3A<C03PC001=4`033A<C00HC0`024`0301<000TC00@04a<C0P3T4`0301<C03<C0Pdk4`00CQ<00`dC

4`0:4`0301<000LC0P044`0301<C0><C0P0b4`8=?A<004lC00<=4a<02A<00`0C00074`0301<C00<C

00<04a<0ha<00`0C4`0`4`033A<C03dC001?4`033A<C00XC00<04a<01Q<300<C00<04a<0ha<00`0C

4`0_4`033A<C03hC001@4`033A<C01PC00<04a<0ha<00`0C4`0]4`8=@A<0054C00<=4a<05a<20>@C

00<04a<0:a<23D<C001B4`033A<C01HC00<04a<0ha<202/C00<=4a<0@a<0058C00<=4a<05Q<00`0C

4`3S4`0301<C02XC00<=4a<0@a<005<C00<=4a<05A<00`0C4`3S4`0301<C02TC0Pe54`00E1<00`dC

4`0D4`80i1<00`0C4`0[4`P=?A<005DC00<=4a<04a<00`0C4`234e0=41<00`0C4`0c4b`=4A<001XC

0`0U4`D03Q<00`dC4`0C4`0301<C02@C1@0T4`<0Pa<Y3EXC000J4`0301<C02LC00<04a<03a<00`dC

4`0B4`0301<C02HC00<04a<091<00`0C4`2C4`0301<C01HC0`eG4`005A<300<C00<04a<081<300<C

00<04a<041<00`dC4`0A4`809a<00`0C4`0U4`0301<C098C00<04a<061<00`dC4`1E4`006a<00`0C

4`0V4`0301<C014C00<=4a<041<00`0C4`0V4`0301<C02DC00<04a<0TQ<00`0C4`0H4`033A<C05DC

000J4`0301<002LC00<04a<04A<00`dC4`0@4`0301<C02HC00<04a<091<00`0C002C4`0301<C01LC

00<=4a<0EQ<001/C00<04a<09A<201@C00<=4a<03a<00`0C4`0U4`809a<00`0C4`2B4`805a<00`dC

4`1G4`00FQ<00`dC4`0>4`80i1<00`0C4`0E4`033A<C05PC001J4`033A<C00hC00<04a<0ha<00`0C

4`0D4`033A<C05TC001K4`033A<C00dC00<04a<0Fa<207LC00<04a<00Q<00`0C4`024`0301<C008C

00<04a<051<00`dC4`1I4`00G1<00`dC4`0<4`0301<C05XC00<04a<0MQ<00`0C00074`0301<000<C

00<04a<04Q<23E`C000E4dP000<=0000HP064`0301<C074C0`024`0301<000TC00@04a<C0P0A4`8=

GQ<001TC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<0

1Q<00`0C4`054`0301<=00DC00<04a<01A<00a0C4`054`0301<C00HC00<04a<01A<00`0C4`054`03

01<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00PC00<04a<0

MQ<00`0C00074`8011<00`0C4`0?4`033A<C05hC001N4`033A<C00XC00<@4a<0FQ<00`0C001f4`03

01<000LC00<04a<00a<00`0C4`0>4`033A<C05lC001O4`033A<C00TC0Q1K4`<0Ma<00`0C4`064`<0

0a<00`0C4`0=4`033A<C060C001P4`033A<C00PC0Q3T4`803Q<00`dC4`1P4`00H1<00`dC4`074`03

400@0>@C00<04a<031<00`dC4`1Q4`00HA<00`dC4`064`03400@0>@C00<04a<02a<00`dC4`1R4`00

HQ<00`dC4`054`03400@0>@C00<04a<02A<23FDC001S4`033A<C00<C00D@4`00403S4`0301<C00PC

00<=4a<0IA<006<C00<=4a<00a<01A0C01<@0><C0P084`033A<C06HC001T4`033A<C008C00D@4`0C

403S4`0301<C00HC00<=4a<0Ia<006DC00L=4a<C41<0008C00<@4a<0h1<00`0C4`054`033A<C06PC

001V4`053A<C41<00P000a<@4`3Q4`0301<C00DC00<=4a<0J1<006HC00H=4a<@4`024`0341<C084C

0`0/4`D0:a<00`0C4`044`033A<C02@C1@0/4`<04A<006LC00D=41<C00034`0341<C080C00<04a<0

;Q<00`0C4`0[4`8011<00`dC4`0W4`0301<C02`C00<04a<04A<006PC00@=4a<00a<00a0C4`1k4`<0

0a<00`0C4`0W4`<00a<00`0C4`0[4`0301<C008C00<=4a<0:1<00`0C4`0]4`0301<C010C001X4`03

3A<C00800Q<00a0C4`214`0301<C02dC00<04a<0:a<00`0C4`024`033A<C02PC00<04a<0;A<00`0C

4`0@4`00Ia<01A0C3A<000@C00<@4a<0Oa<00`0C000^4`0301<C02/C00D04a<C3@0[4`0301<C02`C

00<04`004A<005`C00<04a<00Q<00`0C4`024`06010C4`d011<00a0C4`204`0301<C02`C0P0]4`05

01<C4`d0:Q<202lC00<04a<041<005/C00<04`001a<00`0@00024`033@0C00<C00<@4a<0gQ<20003

4`dC06hC001K4`0301<000PC00<@01<00Q<00`d04`034`0341<C0=dC00<04`d0L1<005/C00<04`00

1a<00`0@4`034`0300dC00<C00<@4a<0gA<00`0=4`1`4`00Fa<00`0C00074`0341<C00<C00<03A<0

11<00a0C4`3L4`0300dC06`C0P024`00G1<00`0C4`064`03400000<C00<04`d011<00a0C4`3L4`03

3A<C06/C00<04a<00Q<006@C00<@4a<011<200034`dC008C00<@4a<0Ma=U00033@0006<021<00`0C

4`024`00I1<00a0C4`044`0401<C3@@C00<@4a<0Na<00`0C4`064`0301<C00LC00<04a<01Q<00`0C

4`074`0301<C00LC00<04a<01Q<00`0C4`074`0301<C00LC00<04a<01Q<00`0C4`064`033@0C00PC

00<04a<01Q<00`0C4`074`0301<C00LC00<04a<01Q<00`0C4`074`0301<C00LC00<04a<01Q<00`0C

4`074`0301<C00LC00<04a<02Q<00`0C4`024`00Ha<00a0C4`054`0501<C4`d00a<00a0C4`3J4`03

3@0C06`C00<04`000Q<006<C00<@4a<01A<00`0C4`024`053A<C4a00fa<00`d04`1/4`<00Q<0068C

00<@4a<01Q<00`0C4`034`043A<C4=XC00<=4`00LQ<0068C00<@4a<01Q<200@C00D=4a<C403I4`04

3A<0074C001Q4`0341<C00LC00<04a<011<010dC4a3I4`033A<0078C001Q4`0341<C00LC00<04a<0

1A<00`dC403H4`043A<C078C001P4`0341<C00PC00<04a<01Q<00`dC403G4`043A<C078C001P4`03

41<C00PC0P074`033A<@0=LC00<=4a<00P1a4`00Ga<00a0C4`094`0301<C00LC00<=4a00eA<01@dC

4a<0078C001O4`0341<C00TC00<04a<021<00`d@4`3D4`053A<C4`00LQ<005hC00<@4a<02Q<00`0C

4`094`033A0C0=<C00D=4a<C001b4`00GQ<00a0C4`0:4`802Q<00`d@4`3C4`053A<C4`00LQ<005dC

00<@4a<02a<00`0C4`0:4`033A0C0=8C00@=4a<C0P1a4`00GA<00a0C4`044`D00Q<00`0C4`0;4`03

3A<C0=4C00D=4a<C001b4`00G1<00a0C4`074`0301<C008C00<04a<031<00`dC4`3@4`053A<C4`00

LQ<005/C00<@4a<021<00`0C4`024`803A<00`d@4`3@4`053A<C4`00LQ<005/C00<@4a<021<00`0C

4`024`0301<C00dC00<=4a<0ca<01@dC4a<0078C001J4`0341<C00TC00<04a<00Q<00`0C4`0>4`03

3A<C0<hC00@=4a<C0P1a4`00FQ<00a0C4`084`8011<00`0C4`0>4`033A0C0<hC00D=4a<C001b4`00

FA<00a0C4`0?4`8041<00`dC4`3=4`053A<C4`00LQ<005PC00<@4a<041<00`0C4`0@4`033A<C0<4C

00<04a<00Q<00`0C4`024`0300dC008C00<04a<0L1<005PC00<@4a<041<00`0C4`0A4`033A<C0;lC

00<04`001a<00`0C3@034`0301<C070C001G4`0341<C014C00<04a<04A<00`dC4`2o4`0301<000TC

00@=4a<C0P1a4`00EQ<00a0C4`0B4`804a<00`dC4`2n4`0301<000LC0P001A<=4a<0078C001F4`03

41<C018C00<04a<04a<00`dC4`2m4`0301<000LC00@04a<=0Q<00`0C4`1`4`00EA<00a0C4`0C4`03

01<C01<C00<=4a<0_Q<00`0C4`064`<000@=4a<0LQ<005@C00<@4a<051<00`0C4`0D4`033A<C0<XC

00<=4`00LQ<005<C00<@4a<05A<201DC00<@3A<0bQ<010dC001a4`00Da<00a0C4`0E4`0301<C01DC

00<=4a<0bA<00`dC001b4`00DQ<00a0C4`0F4`0301<C01HC00<=4a<0bA<00`d04`1a4`00DA<00a0C

4`0G4`0301<C01HC00<@3A<0bA<00`d04`1a4`00DA<00a0C4`0G4`8061<00a0=4`384`033@0C074C

001@4`0341<C01PC00<04a<05a<00a0=4`394`033@0C070C001?4`0341<C00PC1@024`0301<C008C

00<04a<00Q<00`0C4`0H4`0340dC0<PC00<03A<0L1<004lC00<@4a<02Q<00`0C4`064`0301<000<C

00<04a<06A<00a0=4`374`0300dC070C001>4`0341<C00/C00<04a<021<0100C4a<201/C00<=4a<0

aQ<00`0C3@1`4`00CA<00a0C4`0<4`0301<C00HC0P044`0301<C01XC00<@3A<0aQ<200034`dC06hC

001<4`0341<C00dC00<04a<01Q<00`0C4`034`0301<C01/C00<@3A<0aA<0100C4`e_4`00C1<00a0C

4`0<4`8021<300<C00<04a<071<00`dC4`344`0501<C4`d0KQ<004/C00<@4a<07A<201hC00<=4a<0

`a<01@0C4a<=06hC001:4`0341<C01hC00<04a<07A<00a0=4`334`0301<C008C00<=4a<0Ja<004XC

00<@4a<07Q<00`0C4`0N4`033A<C0<8C0P044`033A<C06XC00194`0341<C01lC00<04a<07a<00`dC

4`314`0301<C00<C00<=4a<0JQ<004PC00<@4a<081<2024C00<=4a<0`1<00`0C4`044`033A<C06TC

00174`0341<C024C00<04a<081<00`d@4`2i4`D00Q<00`0C4`054`033A<C06PC00174`0341<C024C

00<04a<08A<00`dC4`2j4`0301<C008C00<04a<01Q<00`dC4`1W4`00AQ<00a0C4`0R4`0301<C028C

00<=4a<0^A<00`0C4`024`8021<00`dC4`1V4`00AA<00a0C4`0S4`808a<00`d@4`2i4`0301<C008C

00<04a<021<00`dC4`1U4`00A1<00a0C4`0T4`0301<C02<C00<=41<0^1<00`0C4`024`0301<C00TC

0PeU4`00A1<00a0C4`0T4`0301<C02@C00<=4a<0]Q<200@C00<04a<02a<00`dC4`1R4`00@a<00a0C

4`0U4`0301<C02DC00<=4a<0^a<00`0C4`0<4`033A<C064C00124`0341<C02HC00<04a<09A<00`d@

4`2k4`803Q<00`dC4`1P4`00@A<00a0C4`0W4`809a<00`d@4`2j4`0301<C00dC00<=4a<0H1<0040C

00<@4a<0:1<00`0C4`0W4`033A0C0;TC00<04a<03Q<00`dC4`1O4`00@1<00a0C4`0R4`<00a<00`0C

4`0X4`033A0C0;PC00<04a<03a<00`dC4`1N4`00?a<00a0C4`0S4`0301<C00<C00<04a<0:1<00`d@

4`2h4`0301<C010C00<=4a<0GA<003hC00<@4a<09A<00`0C4`024`80:Q<00`d@4`2g4`804Q<23EdC

000m4`0341<C02HC00<04a<00Q<00`0C4`0Z4`033A0C0;HC00<04a<04a<23E/C000m4`0341<C02DC

00<04`000a<00`0C4`0[4`033A0C0;DC00<04a<05A<00`dC4`1H4`00?1<00a0C4`0W4`0301<C008C

00<04a<0:a<00`dC402e4`0301<C01HC00<=4a<0Ea<003/C00<@4a<0;A<202dC00<=4a00]1<00`0C

4`0G4`033A<C05HC000j4`0341<C02hC00<04a<0;A<00`d@4`2c4`806A<23EHC000j4`0341<C02hC

00<04a<0;Q<00`d@4`2b4`0301<C01TC0PeE4`00>A<00a0C4`0_4`0301<C02hC00<=4a00/Q<00`0C

4`0K4`8=Da<003PC00<@4a<0<1<2030C00<=4a00/A<00`0C4`0L4`033A<C054C000g4`0341<C034C

00<04a<0<1<00`d@4`2`4`807Q<33E0C000g4`0341<C034C00<04a<0<1<00`dC402`4`0301<C020C

00<=4a<0CA<003HC00<@4a<0<Q<00`0C4`0a4`033A<@0:lC00<04a<08A<00`dC4`1<4`00=A<00a0C

4`0c4`80<a<00`dC402M4`D00Q<00`0C4`024`0301<C008C00<04a<08Q<23D`C000d4`0341<C03@C

00<04a<0<a<00`dC402N4`0301<C00HC00<04`000a<00`0C4`0T4`033A<C04TC000c4`0341<C03DC

00<04a<0<a<010dC4a2M4`0301<C00PC00@04a<C0P0V4`8=BA<0038C00<@4a<0=Q<00`0C4`0d4`03

3A<@09dC00<04a<01Q<200@C00<04a<09a<23DLC000a4`0341<C03LC0P0f4`033A<@09`C00<04a<0

1Q<00`0C4`034`0301<C02PC0`e54`00<1<00a0C4`0h4`0301<C03DC00@=4a<@VQ<200PC0`034`03

01<C02XC0Pe44`00;a<00a0C4`0Y4`<00a<00`0C4`024`0301<C008C00<04a<0=Q<010dC4a2Y4`03

01<C02`C0Pe24`00;Q<00a0C4`0Z4`0301<C00LC00<04`000a<00`0C4`0g4`043A<C4:PC0P0_4`8=

@1<002dC00<@4a<0;1<00`0C4`084`0401<C4`80>1<01@dC4a<@0:LC00<04a<0<1<00`dC4`0m4`00

;1<00a0C4`0]4`0301<C00HC0P044`0301<C03PC00D=4a<C402V4`0301<C034C0Pdm4`00:a<00a0C

4`0]4`0301<000LC00<04a<00a<00`0C4`0i4`053A<C4a00YA<00`0C4`0c4`8=>a<002XC00<@4a<0

;a<00`0C4`064`<00a<00`0C4`0j4`053A<C4a00Y1<00`0C4`0e4`8=>A<002TC00<@4a<0?a<203/C

00<=4a<00Q<00a0C4`2Q4`80>1<23CLC000X4`0341<C040C00<04a<0>a<00`dC4`024`0341<C0:0C

00<04a<0>A<23CDC000W4`0341<C044C00<04a<0?1<00`dC4`024`0341<C09lC00<04a<0>a<23C<C

000V4`0341<C048C00<04a<0?1<00`dC4`034`0341<C09hC00<04a<0?A<23C4C000U4`0341<C04<C

0P0n4`033A<C00<C00<@4a<0WA<00`0C4`0o4`8=;a<002@C00<@4a<0A1<00`0C4`0n4`033A<C00<C

00<@4a<0W1<2048C0Pd]4`008a<00a0C4`154`0301<C03hC00<=4a<011<00a0C4`2K4`0301<C04<C

0Pd[4`008a<00a0C4`154`0301<C03lC00<=4a<011<00a0C4`2J4`0301<C04DC0PdY4`008Q<00a0C

4`164`80@A<00`dC4`044`0341<C09TC00<04a<0Aa<23BLC000Q4`0341<C04LC00<04a<0@1<00`dC

4`054`0341<C09PC0P1:4`8=9A<0020C00<@4a<0B1<00`0C4`114`033A<C00DC00<@4a<0Ua<00`0C

4`1;4`8=8a<001lC00<@4a<0BA<00`0C4`124`033A<C00DC00<@4a<0UQ<00`0C4`1=4`<=81<001hC

00<@4a<0BQ<204<C00<=4a<01Q<00a0C4`2?4`<00a<00`0C4`1@4`8=7Q<001dC00<@4a<0Ba<00`0C

4`134`033A<C00HC00<@4a<0SQ<00`0C4`034`0301<C058C0`dK4`0071<00a0C4`1<4`0301<C04@C

00<=4a<01Q<00a0C4`2>4`0301<C008C0P1F4`8=6A<001/C00<@4a<0Aa<200@C00<04a<0AA<00`dC

4`064`0341<C08dC00<04a<00Q<00`0C4`1G4`8=5a<001XC00<@4a<0BQ<01@0C4a<004LC00<=4a<0

1a<00a0C4`2;4`0301<000<C00<04a<0FA<23ADC000I4`0341<C04XC00<04a<00Q<204LC00<=4a<0

1Q<00a0C4`2<4`0301<C008C00<04a<0Fa<43A4C001W4`0301<C0>LC00<04a<0L1<006DC00<04`00

jA<2074C001V4`0301<C0>PC00<04a<0L1<002lC0`3o4b0C00<04a<0L1<002lC00<04a<0oa<P4`03

01<C070C000`4`0301<C00@C00<04a<0oa>;4`00<1<0100C4a<400<C0`3o4hLC000_4`0301<0008C

0P000a<04`044`0301<C0?lCQA<0030C00<04a<00a<00`0C00034`0301<C0?lCQQ<003HC00<04`00

11<00`0C4`064`0301<C028C0`0`4`0301<C0?lC91<0020C0`000a<0000200`C0`044`<021<00`0C

4`0Q4`0401<C01@C0`000a<00002008C00<04a<00Q<00`0C4`024`0301<C00DC00@04a<C1@024`03

01<C008C0`044`80ca<00`0C4`0]4`0301<C00/C000O4`0401<C02@C00<04a<081<0100C4`0C4`04

01<C00HC00<04`001a<00`0C00044`D00a<00`0C4`084`0301<C008C00<04a<0aa<00`0C4`044`03

01<C01<C00<04a<06A<00`0C4`0:4`007a<01@0C4`0C00@000<C0000600X4`<04a<01@0C4`0C00@0

00@C01<02A<00`0C4`044`0301<C00<C00<04a<01Q<400<C00<04a<0]A<0100C4a<4008C0P064`03

01<C00<C00<04a<00Q<00`0C4`024`0301<C008C00<04a<01A<0100C4a<5008C00<04a<00Q<300@C

0P044`0401<C4`8000<C00000a<0020C0`1:4`0301<C018C0`064`0301<000LC0P074`0301<C00<C

00<04a<01Q<00`0C00044`0301<C0;@C00<04`001a<00`0C4`044`D00a<01`0C4a<04`001a<00`0C

00044`D00a<00`0C4`084`0301<C008C00<04a<011<00`0C4`024`0301<000@C000R4`0301<C04LC

0P0F4`0301<C00@C00<04`001a<00`0C4`0<4`0301<C00LC0P044`0301<00;@C00<04`000Q<40003

4`0C00LC00<04a<00a<01`0C4a<04`002A<00`0C4`044`0301<C00<C00<04a<01Q<400<C00<04a<0

11<00`0C4`034`0301<C00<C000Q4`80H1<200LC00<04a<01Q<300/C0P0:4`0301<C008C0`2H4`80

00<C00005a<00`0C00074`0301<C00HC00<04a<00a<01`0C4a<04`001a<200LC00<04a<00a<00`0C

4`064`0301<000@C00<04a<011<00`0C4`034`0301<C00<C003o4e4C00<04`0061<00`0C00074`03

01<000dC00H04a<04`074`0301<C00`C00<04a<01a<200@C00<04`000a<00`0C4`034`0301<000@C

000[4`801Q<20?lC7A<00`0C4`0H4`0301<C00HC0`0>4`0401<C00PC0`0;4`802Q<00`0C4`024`<0

0Q<00`0C4`034`8000<C00000a<002dC00<04a<00Q<00`0C4`3o4adC00<04a<0L1<002`C00<04a<0

0a<00`0C4`064`0301<C0?lC4a<00`0C001a4`00;A<00`0C4`024`0301<C008C0`0011<04a<30?lC

3a<200034`00070C000[4`0301<000@C00<04`000Q<2008C00<04a<00Q<00`0C4`3o4h8C000/4`03

01<C00<C0`044`0401<C008C00<04a<0oa>34`00>A<0100C4`034`0301<C0?lCPQ<003LC0`044`<0

oa>44`00oa?54`00oa?54`00oa?54`00oa?54`00oa?54`00\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-6.99191, -1.53383, 0.020711, 0.020711}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -84.5 0 ]

[.5 .96488 84.5 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -145.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.395) show

222.250000 19.500000 moveto

(C) show

227.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.24398 0 m

.26171 .02473 L

.30316 .08254 L

.34309 .13825 L

.3815 .19183 L

.42237 .24884 L

.46172 .30374 L

.49955 .35652 L

.53984 .41272 L

.57861 .46681 L

.61984 .52431 L

.65954 .57971 L

.69774 .63299 L

.73838 .68969 L

.77751 .74427 L

.81909 .80228 L

.85916 .85817 L

.89771 .91195 L

s

.89771 .91195 m

.92669 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.339598 0.238095 [

[.02381 .3271 -6 -9 ]

[.02381 .3271 6 0 ]

[.2619 .3271 -6 -9 ]

[.2619 .3271 6 0 ]

[.7381 .3271 -3 -9 ]

[.7381 .3271 3 0 ]

[.97619 .3271 -3 -9 ]

[.97619 .3271 3 0 ]

[1.025 .3396 0 -8 ]

[1.025 .3396 9 8 ]

[.4875 .1015 -12 -4.5 ]

[.4875 .1015 0 4.5 ]

[.4875 .22055 -24 -4.5 ]

[.4875 .22055 0 4.5 ]

[.4875 .45865 -18 -4.5 ]

[.4875 .45865 0 4.5 ]

[.4875 .57769 -6 -4.5 ]

[.4875 .57769 0 4.5 ]

[.4875 .69674 -18 -4.5 ]

[.4875 .69674 0 4.5 ]

[.4875 .81579 -6 -4.5 ]

[.4875 .81579 0 4.5 ]

[.5 .87624 -4.5 0 ]

[.5 .87624 4.5 16 ]

[.5 .86374 -137 0 ]

[.5 .86374 137 16 ]

[ 0 0 0 0 ]

[ 1 .85124 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .3396 m

.02381 .34585 L

s

[(-2)] .02381 .3271 0 1 Mshowa

.2619 .3396 m

.2619 .34585 L

s

[(-1)] .2619 .3271 0 1 Mshowa

.7381 .3396 m

.7381 .34585 L

s

[(1)] .7381 .3271 0 1 Mshowa

.97619 .3396 m

.97619 .34585 L

s

[(2)] .97619 .3271 0 1 Mshowa

.125 Mabswid

.07143 .3396 m

.07143 .34335 L

s

.11905 .3396 m

.11905 .34335 L

s

.16667 .3396 m

.16667 .34335 L

s

.21429 .3396 m

.21429 .34335 L

s

.30952 .3396 m

.30952 .34335 L

s

.35714 .3396 m

.35714 .34335 L

s

.40476 .3396 m

.40476 .34335 L

s

.45238 .3396 m

.45238 .34335 L

s

.54762 .3396 m

.54762 .34335 L

s

.59524 .3396 m

.59524 .34335 L

s

.64286 .3396 m

.64286 .34335 L

s

.69048 .3396 m

.69048 .34335 L

s

.78571 .3396 m

.78571 .34335 L

s

.83333 .3396 m

.83333 .34335 L

s

.88095 .3396 m

.88095 .34335 L

s

.92857 .3396 m

.92857 .34335 L

s

.25 Mabswid

0 .3396 m

1 .3396 L

s

gsave

1.025 .3396 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .1015 m

.50625 .1015 L

s

[(-1)] .4875 .1015 1 0 Mshowa

.5 .22055 m

.50625 .22055 L

s

[(-0.5)] .4875 .22055 1 0 Mshowa

.5 .45865 m

.50625 .45865 L

s

[(0.5)] .4875 .45865 1 0 Mshowa

.5 .57769 m

.50625 .57769 L

s

[(1)] .4875 .57769 1 0 Mshowa

.5 .69674 m

.50625 .69674 L

s

[(1.5)] .4875 .69674 1 0 Mshowa

.5 .81579 m

.50625 .81579 L

s

[(2)] .4875 .81579 1 0 Mshowa

.125 Mabswid

.5 .12531 m

.50375 .12531 L

s

.5 .14912 m

.50375 .14912 L

s

.5 .17293 m

.50375 .17293 L

s

.5 .19674 m

.50375 .19674 L

s

.5 .24436 m

.50375 .24436 L

s

.5 .26817 m

.50375 .26817 L

s

.5 .29198 m

.50375 .29198 L

s

.5 .31579 m

.50375 .31579 L

s

.5 .36341 m

.50375 .36341 L

s

.5 .38722 m

.50375 .38722 L

s

.5 .41103 m

.50375 .41103 L

s

.5 .43484 m

.50375 .43484 L

s

.5 .48246 m

.50375 .48246 L

s

.5 .50626 m

.50375 .50626 L

s

.5 .53007 m

.50375 .53007 L

s

.5 .55388 m

.50375 .55388 L

s

.5 .6015 m

.50375 .6015 L

s

.5 .62531 m

.50375 .62531 L

s

.5 .64912 m

.50375 .64912 L

s

.5 .67293 m

.50375 .67293 L

s

.5 .72055 m

.50375 .72055 L

s

.5 .74436 m

.50375 .74436 L

s

.5 .76817 m

.50375 .76817 L

s

.5 .79198 m

.50375 .79198 L

s

.5 .07769 m

.50375 .07769 L

s

.5 .05388 m

.50375 .05388 L

s

.5 .03007 m

.50375 .03007 L

s

.5 .00626 m

.50375 .00626 L

s

.5 .8396 m

.50375 .8396 L

s

.25 Mabswid

.5 0 m

.5 .85124 L

s

gsave

.5 .87624 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .86374 -198 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.395) show

298.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

303.000000 15.000000 moveto

(L) show

310.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

317.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

324.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

329.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

333.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .85124 L

0 .85124 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .16954 m

.02576 .16954 L

.03156 .16955 L

.04113 .16956 L

.05429 .16957 L

.07083 .16959 L

.09045 .16961 L

.11283 .16964 L

.13757 .16967 L

.16426 .16971 L

.19245 .16975 L

.22164 .16981 L

.25133 .16987 L

.28103 .16994 L

.31022 .17002 L

.3384 .17012 L

.3651 .17022 L

.38984 .17033 L

.41222 .17046 L

.43184 .17058 L

.44838 .1707 L

.46154 .17081 L

.47111 .1709 L

.47691 .17096 L

.47886 .17098 L

s

.47886 .17098 m

.4795 .17099 L

.48141 .17101 L

.48456 .17105 L

.4889 .1711 L

.49434 .17116 L

.5008 .17125 L

.50817 .17136 L

.51632 .17148 L

.5251 .17164 L

.53438 .17183 L

.54399 .17205 L

.55377 .17232 L

.56355 .17264 L

.57316 .17303 L

.58244 .17349 L

.59123 .17405 L

.59937 .17473 L

.60674 .17555 L

.6132 .17654 L

.61865 .17775 L

.62298 .17921 L

.62613 .18098 L

.62804 .18311 L

.62868 .18565 L

s

.47886 .42385 m

.4795 .40925 L

.48141 .39465 L

.48456 .38017 L

.4889 .36586 L

.49434 .35179 L

.5008 .33801 L

.50817 .32458 L

.51632 .31155 L

.5251 .29898 L

.53438 .2869 L

.54399 .27537 L

.55377 .26443 L

.56355 .25412 L

.57316 .24446 L

.58244 .23548 L

.59123 .2272 L

.59937 .21963 L

.60674 .21278 L

.6132 .20664 L

.61865 .20119 L

.62298 .19641 L

.62613 .19226 L

.62804 .18869 L

.62868 .18568 L

s

.47886 .42396 m

.4795 .43855 L

.48141 .45313 L

.48456 .46758 L

.4889 .48183 L

.49434 .49584 L

.5008 .50953 L

.50817 .52286 L

.51632 .53576 L

.5251 .54818 L

.53438 .56006 L

.54399 .57137 L

.55377 .58204 L

.56355 .59203 L

.57316 .60131 L

.58244 .60982 L

.59123 .61754 L

.59937 .62443 L

.60674 .63046 L

.6132 .63561 L

.61865 .63985 L

.62298 .64317 L

.62613 .64555 L

.62804 .64698 L

.62868 .64746 L

s

.62868 .64746 m

.62911 .64778 L

.63038 .64873 L

.63248 .65028 L

.63537 .65239 L

.63899 .65502 L

.64329 .6581 L

.6482 .66156 L

.65363 .66534 L

.65948 .66934 L

.66566 .6735 L

.67206 .67774 L

.67857 .68197 L

.68508 .68614 L

.69148 .69018 L

.69766 .69402 L

.70351 .6976 L

.70894 .70088 L

.71384 .70382 L

.71815 .70637 L

.72177 .70849 L

.72466 .71018 L

.72676 .7114 L

.72803 .71213 L

.72846 .71238 L

s

.72846 .1532 m

.72952 .14974 L

.73268 .14561 L

.73788 .14079 L

.74505 .13528 L

.75405 .12912 L

.76474 .12237 L

.77692 .11513 L

.79039 .10751 L

.80492 .09961 L

.82026 .09157 L

.83615 .0835 L

.85232 .07554 L

.86849 .06778 L

.88438 .06034 L

.89972 .05332 L

.91426 .0468 L

.92773 .04086 L

.93991 .03557 L

.95059 .031 L

.9596 .02719 L

.96676 .02419 L

.97197 .02202 L

.97513 .02071 L

.97619 .02027 L

s

.72846 .15322 m

.72952 .15606 L

.73268 .15837 L

.73788 .16023 L

.74505 .16171 L

.75405 .16288 L

.76474 .16381 L

.77692 .16455 L

.79039 .16514 L

.80492 .16561 L

.82026 .16599 L

.83615 .1663 L

.85232 .16656 L

.86849 .16676 L

.88438 .16694 L

.89972 .16708 L

.91426 .16719 L

.92773 .16729 L

.93991 .16736 L

.95059 .16743 L

.9596 .16748 L

.96676 .16751 L

.97197 .16754 L

.97513 .16755 L

.97619 .16756 L

s

.72846 .71238 m

.72952 .71299 L

.73268 .71481 L

.73788 .71777 L

.74505 .72181 L

.75405 .7268 L

.76474 .73261 L

.77692 .73911 L

.79039 .74615 L

.80492 .75358 L

.82026 .76123 L

.83615 .76899 L

.85232 .7767 L

.86849 .78425 L

.88438 .79152 L

.89972 .7984 L

.91426 .80481 L

.92773 .81065 L

.93991 .81586 L

.95059 .82037 L

.9596 .82413 L

.96676 .8271 L

.97197 .82924 L

.97513 .83054 L

.97619 .83097 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<00`0C4`1`4`00oa=B4`80LA<006@C1@3X4`0301<C070C001V4`0301<C0>PC00<04a<0

L1<003lC00<=4a<07Q<300<C00<04a<00Q<20>@C00<04a<0G1<33A4C00104`033A<C02<C00<04a<0

0Q<00`0C4`3S4`0301<C05/C00<=4a<04Q<0040C00<=4a<08a<00`0C4`024`0301<C0><C0P1J4`8=

5A<0044C00<=4a<08A<200@C00<04a<0ha<00`0C4`1F4`<=5a<0048C00<=4a<09Q<20>@C00<04a<0

Da<33AXC00134`033A<C02DC00<04a<0ha<00`0C4`1@4`<=7A<004<C00<=4a<09A<00`0C4`3S4`03

01<C04hC0PdP4`00A1<00`dC4`0T4`0301<C0><C0P1=4`8=8Q<004DC00<=4a<08a<20>@C00<04a<0

BQ<23B@C00154`033A<C02<C00<04a<0ha<00`0C4`184`8=9Q<004HC00<=4a<08Q<00`0C4`3S4`03

01<C04HC0PdX4`00Aa<00`dC4`0Q4`0301<C0><C0P164`033A<C02PC00184`033A<C020C0P3T4`03

01<C04<C0Pd[4`00B1<00`dC4`0P4`0301<C0><C00<04a<0@1<33BdC00194`033A<C01lC00<04a<0

g1<5008C00<04a<0?Q<23C0C001:4`033A<C01hC00<04a<0gQ<00`0C4`024`0301<C03`C0Pdb4`00

BQ<00`dC4`0N4`80fA<300<C00<04a<00Q<203/C0Pdd4`00Ba<00`dC4`0M4`0301<C0=hC00<04a<0

0Q<00`0C4`0h4`8==Q<004`C00<=4a<03A<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`3N4`03

01<C008C00<04a<0=Q<23CPC001<4`033A<C00`C00<04`001a<00`0C00034`0301<C0=dC0P044`03

01<C03DC00<=4a<0>1<004dC00<=4a<01Q<3008C00<04`002A<0100C4a<20>@C00<04a<0<a<23C/C

001>4`033A<C00XC00<04`001a<200@C00<04a<0ha<203<C00<=4a<0>a<004lC00<=4a<02A<00`0C

00074`0301<C00<C00<04a<0ha<00`0C4`0a4`033A<C03`C001?4`033A<C00XC00<04a<01Q<300<C

00<04a<0ha<00`0C4`0_4`8=?a<0050C00<=4a<061<00`0C4`3S4`0301<C02dC0Pe14`00DA<00`dC

4`0G4`80i1<00`0C4`0/4`033A<C044C001B4`033A<C01HC00<04a<0ha<202dC00<=4a<0@A<0058C

00<=4a<05Q<00`0C4`3S4`0301<C02`C00<=4a<0@A<005<C00<=4a<05A<00`0C4`3S4`0301<C02`C

10e04`00E1<00`dC4`0D4`80i1<00`0C4`0`4ad=8a<005DC00<=4a<04a<00`0C4`224fT=B1<B3A4C

000J4`<09A<500hC00<=4a<04a<00`0C4`0T4`D091<309<C0P064a0=Fa<001XC00<04a<09a<00`0C

4`0?4`033A<C018C00<04a<09Q<00`0C4`0T4`0301<C09<C00<04a<05A<33EPC000E4`<00a<00`0C

4`0P4`<00a<00`0C4`0@4`033A<C014C0P0W4`0301<C02DC00<04a<0TQ<00`0C4`0G4`033A<C05HC

000K4`0301<C02HC00<04a<04A<00`dC4`0@4`0301<C02HC00<04a<09A<00`0C4`2B4`0301<C01LC

00<=4a<0EQ<001XC00<04`009a<00`0C4`0A4`033A<C010C00<04a<09Q<00`0C4`0T4`0301<009<C

00<04a<05Q<23EPC000K4`0301<C02DC0P0D4`033A<C00lC00<04a<09A<202LC00<04a<0TQ<201HC

00<=4a<0F1<005XC00<=4a<03Q<20>@C00<04a<051<00`dC4`1I4`00FQ<00`dC4`0>4`0301<C0=@C

00<04a<00Q<00`0C4`024`0301<C008C00<04a<051<00`dC4`1I4`00Fa<00`dC4`0=4`0301<C05/C

0P1f4`0301<000LC00<04`000a<00`0C4`0C4`033A<C05XC001L4`033A<C00`C00<04a<0FQ<00`0C

4`1a4`<00Q<00`0C00094`0401<C4`804Q<23EdC000E4dP000<=0000HP064`0301<C07HC00<04`00

1a<200@C00<04a<041<00`dC4`1M4`006A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`03

01<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04`d01A<00`0C4`054`0341<C00DC00<04a<0

1Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`03

01<C00DC00<04a<021<00`0C4`1f4`0301<000LC00<04a<00a<00`0C4`0@4`033A<C05dC001N4`03

3A<C00XC00<@4a<0FQ<00`0C001g4`0301<C00HC0`034`0301<C00hC0PeP4`00Ga<00`dC4`094`8@

Fa<308HC00<04a<03A<00`dC4`1P4`00H1<00`dC4`084`8@i1<200dC00<=4a<0HA<0060C00<=4a<0

1a<00a00403T4`0301<C00/C00<=4a<0HQ<0064C00<=4a<01Q<00a00403T4`0301<C00XC00<=4a<0

Ha<0068C00<=4a<01A<00a00403T4`0301<C00TC00<=4a<0I1<006<C00<=4a<00a<01A0C000@0><C

00<04a<021<00`dC4`1U4`00Ha<00`dC4`034`0541<04a00ha<200PC00<=4a<0IQ<006@C00<=4a<0

0Q<01A0C01<@0><C00<04a<01a<00`dC4`1V4`00IA<01`dC4a<@4`000Q<00a0C4`3P4`0301<C00HC

00<=4a<0Ia<006HC00D=4a<@4`0200034a0C0>4C00<04a<01A<00`dC4`1X4`00IQ<01PdC4a0C008C

00<@4a<0P1<302dC1@0[4`0301<C00@C00<=4a<091<502`C0`0A4`00Ia<01@d@4a<000<C00<@4a<0

Oa<00`0C4`0_4`0301<C02/C0P044`033A<C02LC00<04a<0;1<00`0C4`0A4`00J1<010dC4`034`03

41<C07XC0`034`0301<C02PC0`034`0301<C02/C00<04a<00Q<00`dC4`0X4`0301<C02dC00<04a<0

41<006PC00<=4a<00P024`0341<C080C00<04a<0;Q<00`0C4`0[4`0501<C4`d0:a<00`0C4`0]4`03

01<C010C001W4`0541<=4`0011<00a0C4`1n4`0301<002lC00<04a<0:a<01@0C4a<=02/C00<04a<0

;1<00`0C000A4`00G1<00`0C4`024`0301<C008C00H041<C3@044`0341<C07lC00<04a<0;A<202dC

00@04a<=:a<202lC00<04a<041<005/C00<04`001a<00`0@00024`033@0C00<C00<@4a<0gQ<20003

4`dC06hC001K4`0301<000PC00<@01<00Q<00`d04`034`0341<C0=dC00<04`d0L1<005/C00<04`00

1a<00`0@4`034`0300dC00<C00<@4a<0gA<00`0C3@1`4`00Fa<00`0C00074`0341<C00<C00<03A<0

11<00a0C4`3L4`0300dC06`C0P024`00G1<00`0C4`064`03400000<C00<04`d011<00a0C4`3L4`03

3A<C06/C00<04a<00Q<006@C00<@4a<011<200034`dC008C00<@4a<0MQ=V00033@0006@01a<00`0C

4`024`00I1<00a0C4`044`0401<C3@@C00<@4a<0NQ<00`0C4`0^4`0301<C02`C00<=01<0;Q<00`0C

4`0^4`0301<C00XC00<04a<00Q<006<C00<@4a<01A<01@0C4a<=00<C00<@4a<0fQ<00`d04`1/4`03

01<0008C001S4`0341<C00DC00<04a<00Q<01@dC4a<@0=/C00<=01<0K1<3008C001R4`0341<C00HC

00<04a<00a<010dC4a3J4`043A<0074C001R4`0341<C00HC0P044`053A<C4a00fA<00`dC001b4`00

HA<00a0C4`074`0301<C00@C00@=4a<@fA<00`dC001b4`00HA<00a0C4`074`0301<C00DC00<=4a00

f1<010dC4`1b4`00H1<00a0C4`084`0301<C00HC00<=4a00ea<010dC4`1b4`00H1<00a0C4`084`80

1a<00`dC403G4`033A<C0080LA<005lC00<@4a<02A<00`0C4`074`033A<@0=DC00D=4a<C001b4`00

Ga<00a0C4`094`0301<C00PC00<=41<0e1<01@dC4a<0078C001N4`0341<C00XC00<04a<02A<00`d@

4`3C4`053A<C4`00LQ<005hC00<@4a<02Q<200XC00<=41<0da<01@dC4a<0078C001M4`0341<C00/C

00<04a<02Q<00`d@4`3B4`043A<C4`80LA<005dC00<@4a<011<5008C00<04a<02a<00`dC4`3A4`05

3A<C4`00LQ<005`C00<@4a<01a<00`0C4`024`0301<C00`C00<=4a<0d1<01@dC4a<0078C001K4`03

41<C00PC00<04a<00Q<200dC00<=41<0d1<01@dC4a<0078C001K4`0341<C00PC00<04a<00Q<00`0C

4`0=4`033A<C0<lC00D=4a<C001b4`00FQ<00a0C4`094`0301<C008C00<04a<03Q<00`dC4`3>4`04

3A<C4`80LA<005XC00<@4a<021<200@C00<04a<03Q<00`d@4`3>4`053A<C4`00LQ<005TC00<@4a<0

3a<2010C00<=4a<0cA<01@dC4a<0078C001H4`0341<C010C00<04a<041<00`dC4`314`0301<C008C

00<04a<00Q<00`0=4`024`0301<C070C001H4`0341<C010C00<04a<04A<00`dC4`2o4`0301<000LC

00<04`d00a<00`0C4`1`4`00Ea<00a0C4`0A4`0301<C014C00<=4a<0_a<00`0C00094`043A<C4`80

LA<005HC00<@4a<04Q<201<C00<=4a<0_Q<00`0C00074`8000DC3A<C001b4`00EQ<00a0C4`0B4`03

01<C01<C00<=4a<0_A<00`0C00074`0401<C3@8C00<04a<0L1<005DC00<@4a<04a<00`0C4`0C4`03

3A<C0;hC00<04a<01Q<300043A<C078C001D4`0341<C01@C00<04a<051<00`dC4`3:4`033A<0078C

001C4`0341<C01DC0P0E4`0340dC0<XC00@=4`00LA<005<C00<@4a<05A<00`0C4`0E4`033A<C0<TC

00<=4`00LQ<0058C00<@4a<05Q<00`0C4`0F4`033A<C0<TC00<=01<0LA<0054C00<@4a<05a<00`0C

4`0F4`0340dC0<TC00<=01<0LA<0054C00<@4a<05a<201PC00<@3A<0bA<00`d04`1`4`00D1<00a0C

4`0H4`0301<C01LC00<@3A<0bA<00`dC4`1`4`00Ca<00a0C4`084`D00Q<00`0C4`024`0301<C008C

00<04a<061<00a0=4`384`0300dC070C001?4`0341<C00XC00<04a<01Q<00`0C00034`0301<C01TC

00<@3A<0aa<00`0=4`1`4`00CQ<00a0C4`0;4`0301<C00PC00@04a<C0P0K4`033A<C0<HC00<04`d0

L1<004dC00<@4a<031<00`0C4`064`8011<00`0C4`0J4`0340dC0<HC0P000`dC4`1^4`00C1<00a0C

4`0=4`0301<C00HC00<04a<00a<00`0C4`0K4`0340dC0<DC00@04a<=Ka<004`C00<@4a<031<200PC

0`034`0301<C01`C00<=4a<0a1<01@0C4a<=06hC001;4`0341<C01dC0P0N4`033A<C0<<C00D04a<C

3@1^4`00BQ<00a0C4`0N4`0301<C01dC00<@3A<0`a<00`0C4`024`033A<C06/C001:4`0341<C01hC

00<04a<07Q<00`dC4`324`8011<00`dC4`1Z4`00BA<00a0C4`0O4`0301<C01lC00<=4a<0`A<00`0C

4`044`033A<C06TC00184`0341<C020C0P0Q4`033A<C0<0C00<04a<01A<00`dC4`1X4`00Aa<00a0C

4`0Q4`0301<C024C00<=4a<0^1<5008C00<04a<01A<00`dC4`1X4`00Aa<00a0C4`0Q4`0301<C024C

00<=4a<0^Q<00`0C4`024`0301<C00HC00<=4a<0Ia<004HC00<@4a<08Q<00`0C4`0R4`033A<C0;TC

00<04a<00Q<200PC00<=4a<0IQ<004DC00<@4a<08a<202@C00<=4a<0^1<00`0C4`024`0301<C00PC

00<=4a<0IA<004@C00<@4a<091<00`0C4`0T4`033A<C0;LC00<04a<00Q<00`0C4`094`033A<C06@C

00144`0341<C02@C00<04a<091<00`dC4`2f4`8011<00`0C4`0:4`033A<C06<C00134`0341<C02DC

00<04a<09A<00`dC4`2k4`0301<C00/C00<=4a<0HQ<0048C00<@4a<09Q<00`0C4`0V4`033A<C0;XC

0P0=4`033A<C064C00114`0341<C02LC0P0X4`033A<C0;TC00<04a<03A<00`dC4`1P4`00@1<00a0C

4`0X4`0301<C02LC00<=41<0^A<00`0C4`0>4`033A<C05lC00104`0341<C028C0`034`0301<C02PC

00<=41<0^1<00`0C4`0?4`8=Ga<003lC00<@4a<08a<00`0C4`034`0301<C02TC00<=4a<0]a<00`0C

4`0A4`033A<C05`C000n4`0341<C02DC00<04a<00Q<202XC00<=41<0]a<201<C00<=4a<0Fa<003dC

00<@4a<09Q<00`0C4`024`0301<C02XC00<=41<0]Q<00`0C4`0C4`033A<C05XC000m4`0341<C02DC

00<04`000a<00`0C4`0[4`033A0C0;DC00<04a<051<00`dC4`1I4`00?1<00a0C4`0W4`0301<C008C

00<04a<0;1<00`d@4`2d4`0301<C01DC0PeI4`00>a<00a0C4`0]4`80;A<00`dC402d4`0301<C01LC

0PeG4`00>Q<00a0C4`0^4`0301<C02dC00<=41<0/a<201TC0PeF4`00>Q<00a0C4`0^4`0301<C02hC

00<=41<0/Q<00`0C4`0I4`8=EA<003TC00<@4a<0;a<00`0C4`0^4`033A<@0;8C00<04a<06a<00`dC

4`1B4`00>1<00a0C4`0`4`80<1<00`dC402a4`0301<C01`C00<=4a<0DA<003LC00<@4a<0<A<00`0C

4`0`4`033A0C0;0C0P0N4`<=D1<003LC00<@4a<0<A<00`0C4`0`4`033A<@0;0C00<04a<081<00`dC

4`1=4`00=Q<00a0C4`0b4`0301<C034C00<=4a00[a<00`0C4`0Q4`033A<C04`C000e4`0341<C03<C

0P0c4`033A<@09dC1@024`0301<C008C00<04a<00Q<00`0C4`0R4`8=C1<003@C00<@4a<0=1<00`0C

4`0c4`033A<@09hC00<04a<01Q<00`0C00034`0301<C02@C00<=4a<0BA<003<C00<@4a<0=A<00`0C

4`0c4`043A<C49dC00<04a<021<0100C4a<202HC0Pe94`00<Q<00a0C4`0f4`0301<C03@C00<=4a00

WA<00`0C4`064`8011<00`0C4`0W4`8=Aa<0034C00<@4a<0=a<203HC00<=4a00W1<00`0C4`064`03

01<C00<C00<04a<0:A<00`dC4`144`00<1<00a0C4`0h4`0301<C03HC00<=4a00VQ<200PC0`034`03

01<C02XC0`e34`00;a<00a0C4`0Y4`<00a<00`0C4`024`0301<C008C00<04a<0=Q<010dC4a2Y4`03

01<C02`C0Pe24`00;Q<00a0C4`0Z4`0301<C00LC00<04`000a<00`0C4`0g4`043A<C4:PC0P0_4`8=

@1<002dC00<@4a<0;1<00`0C4`084`0401<C4`80>A<010dC4a2W4`0301<C030C0Pdn4`00;1<00a0C

4`0]4`0301<C00HC0P044`0301<C03TC00@=4a<@YQ<00`0C4`0b4`8=?1<002/C00<@4a<0;A<00`0C

00074`0301<C00<C00<04a<0>A<01@dC4a<@0:DC00<04a<0=1<00`dC4`0i4`00:Q<00a0C4`0_4`03

01<C00HC0`034`0301<C03XC00D=4a<C402T4`0301<C03DC0Pdi4`00:A<00a0C4`0o4`80?1<01@dC

4a<@0:<C0P0h4`8==a<002PC00<@4a<0@1<00`0C4`0l4`053A<C4a00XQ<00`0C4`0i4`8==A<002LC

00<@4a<0@A<00`0C4`0l4`033A<C008C00<@4a<0Wa<00`0C4`0k4`8=<a<002HC00<@4a<0@Q<00`0C

4`0m4`033A<C008C00<@4a<0WQ<00`0C4`0m4`8=<A<002DC00<@4a<0@a<203hC00<=4a<00a<00a0C

4`2M4`0301<C03lC0Pd_4`0091<00a0C4`144`0301<C03hC00<=4a<00a<00a0C4`2L4`80@Q<23BdC

000S4`0341<C04DC00<04a<0?a<00`dC4`034`0341<C09/C00<04a<0@a<33BXC000S4`0341<C04DC

00<04a<0?a<00`dC4`044`0341<C09XC00<04a<0AQ<23BPC000R4`0341<C04HC0P114`033A<C00@C

00<@4a<0VA<00`0C4`184`8=9Q<0024C00<@4a<0Aa<00`0C4`104`033A<C00DC00<@4a<0V1<00`0C

4`1:4`8=91<0020C00<@4a<0B1<00`0C4`114`033A<C00DC00<@4a<0Ua<204dC0PdR4`007a<00a0C

4`194`0301<C048C00<=4a<01A<00a0C4`2F4`0301<C04hC0PdP4`007Q<00a0C4`1:4`80@a<00`dC

4`064`0341<C08lC0`034`0301<C050C0`dM4`007A<00a0C4`1;4`0301<C04<C00<=4a<01Q<00a0C

4`2>4`0301<C00<C00<04a<0Da<33AXC000L4`0341<C04`C00<04a<0A1<00`dC4`064`0341<C08hC

00<04a<00Q<205LC0PdH4`006a<00a0C4`174`8011<00`0C4`154`033A<C00HC00<@4a<0SA<00`0C

4`024`0301<C05PC0PdF4`006Q<00a0C4`1:4`0501<C4`00Aa<00`dC4`074`0341<C08/C00<04`00

0a<00`0C4`1J4`8=51<001TC00<@4a<0BQ<00`0C4`024`80Aa<00`dC4`064`0341<C08`C00<04a<0

0Q<00`0C4`1L4`<=4A<006LC00<04a<0ia<00`0C4`1`4`00IA<00`0C003Y4`80LA<006HC00<04a<0

j1<00`0C4`1`4`00:Q<30?lC9A<00`0C4`1`4`00:Q<00`0C4`3o4bDC00<04a<0L1<002/C00<04a<0

11<00`0C4`3o4i0C000[4`0401<C4`@00a<30?lCS1<002XC00<04`000Q<200034`0C00@C00<04a<0

oa>:4`00:a<00`0C4`034`0301<000<C00<04a<0oa>;4`00<A<00`0C00044`0301<C00HC00<04a<0

9a<302/C00<04a<0oa<Y4`006a<300034`00008031<300@C0`084`0301<C02HC00@04a<03a<30003

4`0000800Q<00`0C4`024`0301<C008C00<04a<01A<0100C4a<5008C00@04a<C0P034`8011<00`0C

4`044`80aA<00`0C4`0g4`0301<C00HC000J4`0401<C02@C00<04a<09A<0100C4`0>4`0401<C00HC

00<04`001a<00`0C00044`D00a<00`0C4`084`0301<C008C00H04a<04`044`0301<C0;dC00<04a<0

11<00`0C4`0C4`0301<C02<C00<04a<01A<001XC00D04a<04`0400034`0001P0;A<300hC00D04a<0

4`0400044`0C00TC00<04a<011<00`0C4`034`0301<C00LC00<04a<00Q<200@C00<04a<00Q<00`0C

4`2[4`0401<C4`@00Q<200HC00<04a<00a<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`054`04

01<C4`D00Q<0100C4a<200<C0P044`0301<C00@C0P044`0401<C4`800A<001/C0`1?4`0301<C00dC

0`064`0301<000LC0P074`0301<C00<C00<04a<021<01P0C4`0C008C0P054`0301<C0:XC00<04`00

1a<00`0C4`044`D00a<01`0C4a<04`001a<00`0C00044`D00a<00`0C4`084`0301<C008C00H04a<0

4`044`0301<C00@C00<04a<00Q<1004C000M4`0301<C04`C0P0A4`0301<C00@C00<04`001a<00`0C

4`0<4`0301<C00HC00<04`000Q<00`0C00024`0301<C00@C00<04`00ZQ<00`0C00024`@000<C01<0

1a<00`0C4`034`0701<C4`0C00094`0301<C00@C00<04a<00a<00`0C4`074`0301<C008C0P044`03

01<C008C00<04a<011<00`0C4`034`40000L4`80H1<200LC00<04a<01Q<300/C0P094`0301<C008C

0P024`<011<309<C0P000a<0000B4`0301<000LC00<04a<01Q<00`0C4`034`0701<C4`0C00074`80

1a<00`0C4`034`0301<C00PC00H04a<04`024`801A<00`0C4`044`0301<C00<C0@000?lCDA<00`0C

000C4`0301<000LC00<04`003A<01P0C4`0C00LC00<04a<031<00`0C4`064`0301<0008C00<04`00

0Q<00`0C4`044`0301<000<C00<04a<00a<1004C000V4`801Q<20?lC8Q<00`0C4`0C4`0301<C00HC

0`0>4`0401<C00PC0`0;4`802A<00`0C4`024`800Q<300@C0`024`0301<C00<C0P014`00:1<00`0C

4`024`0301<C0?lC8Q<00`0C4`1`4`009a<00`0C4`034`0301<C00HC00<04a<0oa<H4`0301<0074C

000X4`0301<C008C00<04a<00Q<300044`0C4`<0oa<D4`8000<C0000L1<002HC00<04`0011<00`0C

00024`800Q<00`0C4`024`0301<C0?lCQa<002LC00<04a<00a<300@C00@04a<00Q<00`0C4`3o4hPC

000d4`0401<C00<C00<04a<0oa>74`00<Q<300@C0`3o4hTC003o4lDC003o4lDC003o4lDC003o4lDC

003o4lDC0000\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-6.97504, -1.52705, 0.020661, 0.020661}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -82 0 ]

[.5 .96488 82 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -143 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.39) show

217.250000 19.500000 moveto

(C) show

222.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.24306 0 m

.26171 .02592 L

.30316 .08353 L

.34309 .13903 L

.3815 .19243 L

.42237 .24923 L

.46172 .30393 L

.49955 .35652 L

.53984 .41252 L

.57861 .46641 L

.61984 .52371 L

.65954 .57891 L

.69774 .632 L

.73838 .68849 L

.77751 .74288 L

.81909 .80068 L

.85916 .85638 L

.89771 .90996 L

s

.89771 .90996 m

.92823 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.338019 0.238095 [

[.02381 .32552 -6 -9 ]

[.02381 .32552 6 0 ]

[.2619 .32552 -6 -9 ]

[.2619 .32552 6 0 ]

[.7381 .32552 -3 -9 ]

[.7381 .32552 3 0 ]

[.97619 .32552 -3 -9 ]

[.97619 .32552 3 0 ]

[1.025 .33802 0 -8 ]

[1.025 .33802 9 8 ]

[.4875 .09992 -12 -4.5 ]

[.4875 .09992 0 4.5 ]

[.4875 .21897 -24 -4.5 ]

[.4875 .21897 0 4.5 ]

[.4875 .45707 -18 -4.5 ]

[.4875 .45707 0 4.5 ]

[.4875 .57611 -6 -4.5 ]

[.4875 .57611 0 4.5 ]

[.4875 .69516 -18 -4.5 ]

[.4875 .69516 0 4.5 ]

[.4875 .81421 -6 -4.5 ]

[.4875 .81421 0 4.5 ]

[.5 .87409 -4.5 0 ]

[.5 .87409 4.5 16 ]

[.5 .86159 -134.5 0 ]

[.5 .86159 134.5 16 ]

[ 0 0 0 0 ]

[ 1 .84909 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .33802 m

.02381 .34427 L

s

[(-2)] .02381 .32552 0 1 Mshowa

.2619 .33802 m

.2619 .34427 L

s

[(-1)] .2619 .32552 0 1 Mshowa

.7381 .33802 m

.7381 .34427 L

s

[(1)] .7381 .32552 0 1 Mshowa

.97619 .33802 m

.97619 .34427 L

s

[(2)] .97619 .32552 0 1 Mshowa

.125 Mabswid

.07143 .33802 m

.07143 .34177 L

s

.11905 .33802 m

.11905 .34177 L

s

.16667 .33802 m

.16667 .34177 L

s

.21429 .33802 m

.21429 .34177 L

s

.30952 .33802 m

.30952 .34177 L

s

.35714 .33802 m

.35714 .34177 L

s

.40476 .33802 m

.40476 .34177 L

s

.45238 .33802 m

.45238 .34177 L

s

.54762 .33802 m

.54762 .34177 L

s

.59524 .33802 m

.59524 .34177 L

s

.64286 .33802 m

.64286 .34177 L

s

.69048 .33802 m

.69048 .34177 L

s

.78571 .33802 m

.78571 .34177 L

s

.83333 .33802 m

.83333 .34177 L

s

.88095 .33802 m

.88095 .34177 L

s

.92857 .33802 m

.92857 .34177 L

s

.25 Mabswid

0 .33802 m

1 .33802 L

s

gsave

1.025 .33802 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .09992 m

.50625 .09992 L

s

[(-1)] .4875 .09992 1 0 Mshowa

.5 .21897 m

.50625 .21897 L

s

[(-0.5)] .4875 .21897 1 0 Mshowa

.5 .45707 m

.50625 .45707 L

s

[(0.5)] .4875 .45707 1 0 Mshowa

.5 .57611 m

.50625 .57611 L

s

[(1)] .4875 .57611 1 0 Mshowa

.5 .69516 m

.50625 .69516 L

s

[(1.5)] .4875 .69516 1 0 Mshowa

.5 .81421 m

.50625 .81421 L

s

[(2)] .4875 .81421 1 0 Mshowa

.125 Mabswid

.5 .12373 m

.50375 .12373 L

s

.5 .14754 m

.50375 .14754 L

s

.5 .17135 m

.50375 .17135 L

s

.5 .19516 m

.50375 .19516 L

s

.5 .24278 m

.50375 .24278 L

s

.5 .26659 m

.50375 .26659 L

s

.5 .2904 m

.50375 .2904 L

s

.5 .31421 m

.50375 .31421 L

s

.5 .36183 m

.50375 .36183 L

s

.5 .38564 m

.50375 .38564 L

s

.5 .40945 m

.50375 .40945 L

s

.5 .43326 m

.50375 .43326 L

s

.5 .48088 m

.50375 .48088 L

s

.5 .50469 m

.50375 .50469 L

s

.5 .5285 m

.50375 .5285 L

s

.5 .55231 m

.50375 .55231 L

s

.5 .59992 m

.50375 .59992 L

s

.5 .62373 m

.50375 .62373 L

s

.5 .64754 m

.50375 .64754 L

s

.5 .67135 m

.50375 .67135 L

s

.5 .71897 m

.50375 .71897 L

s

.5 .74278 m

.50375 .74278 L

s

.5 .76659 m

.50375 .76659 L

s

.5 .7904 m

.50375 .7904 L

s

.5 .07611 m

.50375 .07611 L

s

.5 .05231 m

.50375 .05231 L

s

.5 .0285 m

.50375 .0285 L

s

.5 .00469 m

.50375 .00469 L

s

.5 .83802 m

.50375 .83802 L

s

.25 Mabswid

.5 0 m

.5 .84909 L

s

gsave

.5 .87409 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .86159 -195.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.39) show

293.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

298.000000 15.000000 moveto

(L) show

305.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

312.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

319.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

324.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

328.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .84909 L

0 .84909 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .16751 m

.02576 .16752 L

.03156 .16752 L

.04113 .16754 L

.05429 .16755 L

.07082 .16758 L

.09045 .1676 L

.11282 .16764 L

.13757 .16768 L

.16426 .16773 L

.19244 .16779 L

.22163 .16786 L

.25132 .16793 L

.28102 .16803 L

.31021 .16813 L

.33839 .16825 L

.36508 .16838 L

.38982 .16852 L

.4122 .16867 L

.43182 .16883 L

.44835 .16898 L

.46152 .16912 L

.47108 .16924 L

.47689 .16931 L

.47883 .16934 L

s

.47883 .16934 m

.47946 .16935 L

.48132 .16937 L

.48439 .16942 L

.48861 .16948 L

.49391 .16956 L

.50021 .16966 L

.50738 .16979 L

.51532 .16995 L

.52388 .17014 L

.53292 .17036 L

.54228 .17063 L

.55181 .17095 L

.56133 .17134 L

.57069 .17179 L

.57973 .17233 L

.58829 .17298 L

.59623 .17376 L

.6034 .17469 L

.6097 .17581 L

.615 .17715 L

.61922 .17876 L

.62229 .18068 L

.62415 .18296 L

.62478 .18565 L

s

.47883 .4223 m

.47946 .40791 L

.48132 .39351 L

.48439 .37922 L

.48861 .3651 L

.49391 .35121 L

.50021 .33761 L

.50738 .32434 L

.51532 .31147 L

.52388 .29904 L

.53292 .2871 L

.54228 .27569 L

.55181 .26485 L

.56133 .25462 L

.57069 .24502 L

.57973 .23609 L

.58829 .22783 L

.59623 .22026 L

.6034 .21339 L

.6097 .20719 L

.615 .20167 L

.61922 .19679 L

.62229 .19253 L

.62415 .18883 L

.62478 .18567 L

s

.47883 .42242 m

.47946 .4368 L

.48132 .45118 L

.48439 .46542 L

.48861 .47948 L

.49391 .49329 L

.50021 .50679 L

.50738 .51992 L

.51532 .53264 L

.52388 .54488 L

.53292 .5566 L

.54228 .56774 L

.55181 .57826 L

.56133 .58811 L

.57069 .59725 L

.57973 .60564 L

.58829 .61325 L

.59623 .62004 L

.6034 .62598 L

.6097 .63106 L

.615 .63524 L

.61922 .63851 L

.62229 .64085 L

.62415 .64227 L

.62478 .64274 L

s

.62478 .64274 m

.62526 .6431 L

.6267 .64418 L

.62908 .64596 L

.63235 .64838 L

.63646 .65138 L

.64134 .65489 L

.6469 .65883 L

.65305 .66311 L

.65969 .66765 L

.66669 .67235 L

.67395 .67712 L

.68133 .68189 L

.68871 .68657 L

.69596 .6911 L

.70297 .69539 L

.7096 .6994 L

.71575 .70306 L

.72131 .70633 L

.72619 .70917 L

.7303 .71154 L

.73357 .71341 L

.73595 .71476 L

.73739 .71558 L

.73788 .71586 L

s

.73788 .14909 m

.7389 .14556 L

.74194 .1414 L

.74695 .13661 L

.75384 .13118 L

.7625 .12515 L

.77278 .11859 L

.7845 .11158 L

.79746 .10421 L

.81144 .09659 L

.82619 .08885 L

.84148 .08109 L

.85703 .07342 L

.87259 .06596 L

.88787 .0588 L

.90263 .05204 L

.91661 .04577 L

.92957 .04005 L

.94129 .03496 L

.95157 .03056 L

.96023 .02689 L

.96712 .02399 L

.97213 .0219 L

.97517 .02064 L

.97619 .02022 L

s

.73788 .14911 m

.7389 .15206 L

.74194 .15451 L

.74695 .15651 L

.75384 .15813 L

.7625 .15944 L

.77278 .16049 L

.7845 .16134 L

.79746 .16203 L

.81144 .16259 L

.82619 .16305 L

.84148 .16342 L

.85703 .16373 L

.87259 .16399 L

.88787 .1642 L

.90263 .16437 L

.91661 .16451 L

.92957 .16463 L

.94129 .16473 L

.95157 .16481 L

.96023 .16487 L

.96712 .16491 L

.97213 .16494 L

.97517 .16496 L

.97619 .16497 L

s

.73788 .71586 m

.7389 .71643 L

.74194 .71815 L

.74695 .72094 L

.75384 .72475 L

.7625 .72947 L

.77278 .73498 L

.7845 .74114 L

.79746 .74782 L

.81144 .75487 L

.82619 .76216 L

.84148 .76955 L

.85703 .77691 L

.87259 .78411 L

.88787 .79106 L

.90263 .79765 L

.91661 .80378 L

.92957 .80938 L

.94129 .81437 L

.95157 .81869 L

.96023 .8223 L

.96712 .82515 L

.97213 .82721 L

.97517 .82846 L

.97619 .82887 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<00`0C4`1`4`00oa=B4`80LA<006@C1@3X4`0301<C070C001V4`0301<C0>PC00<04a<0

L1<003lC00<=4a<07Q<300<C00<04a<00Q<20>@C00<04a<0G1<33A4C00104`033A<C02<C00<04a<0

0Q<00`0C4`3S4`80G1<00`dC4`0B4`00@1<00`dC4`0S4`0301<C008C00<04a<0ha<00`0C4`1I4`8=

5A<0044C00<=4a<08A<200@C00<04a<0ha<00`0C4`1G4`8=5a<0044C00<=4a<09a<20>@C00<04a<0

E1<33ATC00124`033A<C02HC00<04a<0ha<00`0C4`1A4`<=71<004<C00<=4a<09A<00`0C4`3S4`80

D1<23AlC00144`033A<C02@C00<04a<0ha<00`0C4`1=4`8=8A<004@C00<=4a<091<20>@C00<04a<0

Ba<23B<C00154`033A<C02<C00<04a<0ha<00`0C4`194`8=9A<004HC00<=4a<08Q<00`0C4`3S4`03

01<C04LC0PdW4`00Aa<00`dC4`0Q4`0301<C0><C0P164`8=:A<004LC00<=4a<08A<20>@C00<04a<0

@a<23B/C00184`033A<C020C00<04a<0ha<00`0C4`114`8=;A<004TC00<=4a<07a<00`0C4`3L4`D0

0Q<00`0C4`0o4`8=;a<004XC00<=4a<07Q<00`0C4`3N4`0301<C008C00<04a<0?A<23C4C001:4`03

3A<C01hC0P3I4`<00a<00`0C4`024`80?1<23C<C001;4`033A<C01dC00<04a<0gQ<00`0C4`024`03

01<C03TC0Pde4`00C1<00`dC4`0=4`0301<C008C00<04a<00Q<00`0C4`024`0301<C0=hC00<04a<0

0Q<00`0C4`0g4`8==a<004`C00<=4a<031<00`0C00074`0301<000<C00<04a<0gA<200@C00<04a<0

=Q<00`dC4`0g4`00CA<00`dC4`064`<00Q<00`0C00094`0401<C4`80i1<00`0C4`0e4`033A<C03PC

001>4`033A<C00XC00<04`001a<200@C00<04a<0ha<203@C0Pdk4`00Ca<00`dC4`094`0301<000LC

00<04a<00a<00`0C4`3S4`0301<C034C0Pdm4`00Ca<00`dC4`0:4`0301<C00HC0`034`0301<C0><C

00<04a<0;a<23ClC001@4`033A<C01PC00<04a<0ha<00`0C4`0^4`033A<C03lC001A4`033A<C01LC

0P3T4`0301<C02hC00<=4a<0?a<0058C00<=4a<05Q<00`0C4`3S4`80;a<00`dC4`0o4`00DQ<00`dC

4`0F4`0301<C0><C00<04a<0;Q<23D0C001C4`033A<C01DC00<04a<0ha<00`0C4`0`4`T==a<005@C

00<=4a<051<20>@C00<04a<0>A<V3A4C001E4`033A<C01<C00<04a<0PQ=_3FDC000J4`<09A<500hC

00<=4a<04a<00`0C4`0T4`D091<309<C00<04a<02a<93E`C000J4`0301<C02LC00<04a<03a<00`dC

4`0B4`0301<C02HC00<04a<091<00`0C4`2C4`0301<C01@C0`eI4`005A<300<C00<04a<081<300<C

00<04a<041<00`dC4`0A4`809a<00`0C4`0U4`0301<C098C00<04a<05Q<23EPC000K4`0301<C02HC

00<04a<04A<00`dC4`0@4`0301<C02HC00<04a<09A<00`0C4`2B4`0301<C01HC00<=4a<0Ea<001XC

00<04`009a<00`0C4`0A4`033A<C010C00<04a<09Q<00`0C4`0T4`0301<009<C0P0G4`033A<C05LC

000K4`0301<C02DC0P0D4`033A<C00lC00<04a<09A<202LC00<04a<0TQ<00`0C4`0E4`033A<C05PC

001J4`033A<C00hC0P3T4`0301<C01DC00<=4a<0F1<005XC00<=4a<03Q<00`0C4`3D4`0301<C008C

00<04a<00Q<00`0C4`024`0301<C01<C0PeK4`00Fa<00`dC4`0=4`0301<C05/C0P1f4`0301<000LC

00<04`000a<00`0C4`0B4`033A<C05/C001L4`033A<C00`C00<04a<0FQ<00`0C4`1a4`<00Q<00`0C

00094`0401<C4`804Q<00`dC4`1L4`005A=800033@0006801Q<00`0C4`1f4`0301<000LC0P044`03

01<C010C00<=4a<0GA<001TC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`03

01<C00DC00<04a<01Q<00`0C4`054`0301<=00DC00<04a<01A<00a0C4`054`0301<C00HC00<04a<0

1A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`054`03

01<C00PC00<04a<0MQ<00`0C00074`0301<C00<C00<04a<03a<00`dC4`1N4`00GQ<00`dC4`0:4`03

41<C05XC00<04`00Ma<00`0C4`064`<00a<00`0C4`0>4`033A<C05lC001O4`033A<C00TC0Q1K4`<0

QQ<00`0C4`0=4`033A<C060C001P4`033A<C00PC0Q3T4`803A<00`dC4`1Q4`00H1<00`dC4`074`03

400@0>@C00<04a<02a<00`dC4`1R4`00HA<00`dC4`064`03400@0>@C00<04a<02Q<00`dC4`1S4`00

HQ<00`dC4`054`03400@0>@C00<04a<02A<00`dC4`1T4`00Ha<00`dC4`034`0541<00100ha<00`0C

4`094`033A<C06@C001S4`033A<C00<C00D@4`0C403S4`802A<00`dC4`1U4`00I1<00`dC4`024`05

41<04a00ha<00`0C4`074`033A<C06HC001U4`073A<C4a0C00024`0341<C0>0C00<04a<01Q<00`dC

4`1W4`00IQ<01@dC4a0C008000<C41<0hA<00`0C4`054`033A<C06PC001V4`063A<C41<00Q<00a0C

4`204`<0;A<502/C00<04a<011<00`dC4`0T4`D0;A<3010C001W4`053A0C4`000a<00a0C4`1o4`03

01<C02lC00<04a<0:a<200@C00<=4a<09a<00`0C4`0]4`0301<C010C001X4`043A<C00<C00<@4a<0

NQ<300<C00<04a<0:1<300<C00<04a<0:a<00`0C4`034`033A<C02LC00<04a<0;Q<00`0C4`0?4`00

J1<00`dC4`02008C00<@4a<0P1<00`0C4`0^4`0301<C02/C00<04a<00Q<00`dC4`0X4`0301<C02hC

00<04a<03a<006LC00D@4`dC00044`0341<C07hC00<04`00;a<00`0C4`0[4`0501<C4`d0:a<00`0C

4`0]4`0301<0010C001L4`0301<C008C00<04a<00Q<01P0@4a<=00@C00<@4a<0Oa<00`0C4`0]4`80

;A<0100C4`d[4`80<1<00`0C4`0?4`00Fa<00`0C00074`030100008C00<=01<00a<00a0C4`3N4`80

00<C3A<0KQ<005/C00<04`0021<00a004`024`033@0C00<C00<@4a<0gA<00`0C3@1`4`00Fa<00`0C

00074`03010C00<C00<03A<00a<00a0C4`3M4`0301<=06`C0P024`00Fa<00`0C00074`0341<C00<C

00<03A<011<00a0C4`3L4`0300dC06/C00<04a<00Q<005`C00<04a<01Q<00a0000034`0301<=00@C

00<@4a<0MQ=V00033@0006@01a<00`0C4`024`00I1<00a0C4`044`8000<C3A<00Q<00a0C4`1k4`03

01<C00LC00<04a<01Q<00`0C4`074`0301<C00LC00<04a<01a<00`0C4`064`0301<C00LC00<04a<0

1a<00`0C4`064`0301<C00LC00<=4a<01a<00`0C4`074`0301<C00HC00<04a<01a<00`0C4`074`03

01<C00HC00<04a<01a<00`0C4`074`0301<C00HC00<04a<01a<00`0C4`0:4`0301<C008C001T4`03

41<C00@C00@04a<=11<00a0C4`1j4`0301<C02hC00<04a<0;1<00`d04`0_4`0301<C02dC00<04a<0

2Q<00`0C00024`00Ha<00a0C4`054`0501<C4`d00a<00a0C4`3J4`033@0C06`C0`024`00Ha<00a0C

4`054`0301<C008C00D=4a<C403K4`033@0C074C001R4`0341<C00HC00<04a<00a<010dC4a3J4`04

3A<0074C001R4`0341<C00HC0P044`053A<C4a00fA<00`dC001b4`00HA<00a0C4`074`0301<C00@C

00@=4a<@fA<00`dC001b4`00HA<00a0C4`074`0301<C00DC00<=4a00f1<010dC4`1b4`00H1<00a0C

4`084`0301<C00HC00<=4a00ea<010dC4`1b4`00H1<00a0C4`084`801a<00`dC403G4`033A<C0080

LA<005lC00<@4a<02A<00`0C4`074`033A<@0=DC00D=4a<C001b4`00Ga<00a0C4`094`0301<C00PC

00<=41<0e1<01@dC4a<0078C001N4`0341<C00XC00<04a<02A<00`d@4`3C4`053A<C4`00LQ<005hC

00<@4a<02Q<200XC00<=41<0da<01@dC4a<0078C001M4`0341<C00/C00<04a<02Q<00`d@4`3B4`04

3A<C4`80LA<005dC00<@4a<011<5008C00<04a<02a<00`dC4`3A4`053A<C4`00LQ<005`C00<@4a<0

1a<00`0C4`024`0301<C00`C00<=4a<0d1<01@dC4a<0078C001K4`0341<C00PC00<04a<00Q<200dC

00<=41<0d1<01@dC4a<0078C001K4`0341<C00PC00<04a<00Q<00`0C4`0=4`033A<C0<lC00D=4a<C

001b4`00FQ<00a0C4`094`0301<C008C00<04a<03Q<00`dC4`3>4`043A<C4`80LA<005XC00<@4a<0

21<200@C00<04a<03Q<00`d@4`3>4`053A<C4`00LQ<005TC00<@4a<03a<2010C00<=4a<0cA<01@dC

4a<0078C001H4`0341<C010C00<04a<041<00`dC4`314`0301<C008C00<04a<00Q<00`0=4`024`03

01<C070C001H4`0341<C010C00<04a<04A<00`dC4`2o4`0301<000LC00<04`d00a<00`0C4`1`4`00

Ea<00a0C4`0A4`0301<C014C00<=4a<0_a<00`0C00094`043A<C4`80LA<005HC00<@4a<04Q<201<C

00<=4a<0_Q<00`0C00074`8000DC3A<C001b4`00EQ<00a0C4`0B4`0301<C01<C00<=4a<0_A<00`0C

00074`0401<C3@8C00<04a<0L1<005DC00<@4a<04a<00`0C4`0C4`0340dC0;hC00<04a<01Q<30004

4`dC078C001D4`0341<C01@C00<04a<051<00`dC4`3:4`033A<0078C001C4`0341<C01DC0P0E4`03

40dC0<XC00@=4`00LA<005<C00<@4a<05A<00`0C4`0E4`0340dC0<XC00<=01<0LA<0058C00<@4a<0

5Q<00`0C4`0F4`0340dC0<TC00<=01<0LA<0054C00<@4a<05a<00`0C4`0F4`0340dC0<TC00<=01<0

LA<0054C00<@4a<05a<201PC00<@3A<0bA<00`d04`1`4`00D1<00a0C4`0H4`0301<C01LC00<@4`d0

bA<00`dC4`1`4`00Ca<00a0C4`084`D00Q<00`0C4`024`0301<C008C00<04a<061<00a0C3@384`03

00dC070C001?4`0341<C00XC00<04a<01Q<00`0C00034`0301<C01TC00<@3A<0aa<00`0=4`1`4`00

CQ<00a0C4`0;4`0301<C00PC00@04a<C0P0K4`0340dC0<HC00<04`d0L1<004dC00<@4a<031<00`0C

4`064`8011<00`0C4`0J4`0340dC0<HC0P000`dC4`1^4`00C1<00a0C4`0=4`0301<C00HC00<04a<0

0a<00`0C4`0K4`0340dC0<DC00@04a<=Ka<004`C00<@4a<031<200PC0`034`0301<C01`C00<@3A<0

a1<01@0C4a<=06hC001;4`0341<C01dC0P0N4`033A<C0<<C00D04a<C3@1^4`00BQ<00a0C4`0N4`03

01<C01dC00<@3A<0`a<00`0C4`024`033A<C06/C001:4`0341<C01hC00<04a<07Q<00`dC4`324`80

11<00`dC4`1Z4`00BA<00a0C4`0O4`0301<C01lC00<=4a<0`A<00`0C4`044`033A<C06TC00184`03

41<C020C0P0Q4`033A<C0<0C00<04a<01A<00`dC4`1X4`00Aa<00a0C4`0Q4`0301<C024C00<=4a<0

^1<5008C00<04a<01Q<00`dC4`1W4`00Aa<00a0C4`0Q4`0301<C024C00<=4a<0^Q<00`0C4`024`03

01<C00LC00<=4a<0IQ<004HC00<@4a<08Q<00`0C4`0R4`033A<C0;TC00<04a<00Q<200TC00<=4a<0

IA<004DC00<@4a<08a<202@C00<=4a<0^1<00`0C4`024`0301<C00TC00<=4a<0I1<004@C00<@4a<0

91<00`0C4`0T4`033A<C0;LC00<04a<00Q<00`0C4`0:4`033A<C06<C00144`0341<C02@C00<04a<0

91<00`dC4`2f4`8011<00`0C4`0;4`033A<C068C00134`0341<C02DC00<04a<09A<00`dC4`2k4`03

01<C00`C00<=4a<0HA<0048C00<@4a<09Q<00`0C4`0V4`033A<C0;XC0P0=4`033A<C064C00114`03

41<C02LC0P0X4`033A<C0;TC00<04a<03A<00`dC4`1P4`00@1<00a0C4`0X4`0301<C02LC00<=41<0

^A<00`0C4`0>4`033A<C05lC00104`0341<C028C0`034`0301<C02PC00<=41<0^1<00`0C4`0?4`03

3A<C05hC000o4`0341<C02<C00<04a<00a<00`0C4`0Y4`033A<C0;LC00<04a<041<23EhC000n4`03

41<C02DC00<04a<00Q<202XC00<=41<0]a<201<C00<=4a<0Fa<003dC00<@4a<09Q<00`0C4`024`03

01<C02XC00<=41<0]Q<00`0C4`0C4`033A<C05XC000m4`0341<C02DC00<04`000a<00`0C4`0[4`03

3A0C0;DC00<04a<051<23EXC000l4`0341<C02LC00<04a<00Q<00`0C4`0/4`033A0C0;@C00<04a<0

5A<23ETC000k4`0341<C02dC0P0]4`033A<@0;@C00<04a<05a<00`dC4`1F4`00>Q<00a0C4`0^4`03

01<C02dC00<=41<0/a<201TC0PeF4`00>Q<00a0C4`0^4`0301<C02hC00<=41<0/Q<00`0C4`0J4`03

3A<C05<C000i4`0341<C02lC00<04a<0;a<00`d@4`2a4`0301<C01/C00<=4a<0DQ<003PC00<@4a<0

<1<2030C00<=4a00/A<00`0C4`0L4`033A<C054C000g4`0341<C034C00<04a<0<1<00`d@4`2`4`80

7Q<23E4C000g4`0341<C034C00<04a<0<A<00`d@4`2_4`0301<C01lC00<=4a<0CQ<003HC00<@4a<0

<Q<00`0C4`0b4`033A0C0:hC00<04a<081<23DhC000e4`0341<C03<C0P0c4`033A<@09dC1@024`03

01<C008C00<04a<00Q<00`0C4`0R4`<=Ba<003@C00<@4a<0=1<00`0C4`0c4`033A<@09hC00<04a<0

1Q<00`0C00034`0301<C02DC00<=4a<0B1<003<C00<@4a<0=A<00`0C4`0d4`033A<@09dC00<04a<0

21<0100C4a<202LC00<=4a<0Aa<0038C00<@4a<0=Q<00`0C4`0e4`033A0C09`C00<04a<01Q<200@C

00<04a<09a<23DLC000a4`0341<C03LC0P0f4`033A<@09`C00<04a<01Q<00`0C4`034`0301<C02TC

0Pe54`00<1<00a0C4`0h4`0301<C03HC00<=4a00VQ<200PC0`034`0301<C02/C00<=4a<0@Q<002lC

00<@4a<0:A<300<C00<04a<00Q<00`0C4`024`0301<C03LC00<=4a00ZA<00`0C4`0/4`<=@A<002hC

00<@4a<0:Q<00`0C4`074`0301<000<C00<04a<0=a<010dC4a2X4`80;a<23D0C000]4`0341<C02`C

00<04a<021<0100C4a<203TC00@=4a<@Ya<00`0C4`0`4`8=?Q<002`C00<@4a<0;A<00`0C4`064`80

11<00`0C4`0i4`043A<C4:HC00<04a<0<Q<23C`C000[4`0341<C02dC00<04`001a<00`0C4`034`03

01<C03XC00@=4a<@YA<00`0C4`0d4`8=>Q<002XC00<@4a<0;a<00`0C4`064`<00a<00`0C4`0j4`05

3A<C4a00Y1<00`0C4`0f4`033A<C03LC000Y4`0341<C03lC0P0l4`053A<C4a00Xa<203PC0Pdg4`00

:1<00a0C4`104`0301<C03`C00D=4a<C402R4`0301<C03TC0`dd4`009a<00a0C4`114`0301<C03`C

00<=4a<00Q<00a0C4`2O4`0301<C03`C0Pdb4`009Q<00a0C4`124`0301<C03dC00<=4a<00Q<00a0C

4`2N4`0301<C03hC0Pd`4`009A<00a0C4`134`80?a<00`dC4`024`0341<C09dC00<04a<0@1<23BhC

000T4`0341<C04@C00<04a<0?Q<00`dC4`034`0341<C09`C0P134`8=;1<002<C00<@4a<0AA<00`0C

4`0o4`033A<C00<C00<@4a<0Va<00`0C4`144`8=:Q<002<C00<@4a<0AA<00`0C4`104`033A<C00<C

00<@4a<0VQ<00`0C4`164`8=:1<0028C00<@4a<0AQ<2044C00<=4a<011<00a0C4`2I4`0301<C04PC

0PdV4`008A<00a0C4`174`0301<C044C00<=4a<011<00a0C4`2H4`0301<C04XC0PdT4`0081<00a0C

4`184`0301<C048C00<=4a<011<00a0C4`2G4`80CA<23B8C000O4`0341<C04TC00<04a<0@Q<00`dC

4`054`0341<C09HC00<04a<0CQ<33AlC000N4`0341<C04XC0P144`033A<C00DC00<@4a<0Sa<300<C

00<04a<0DA<33A`C000M4`0341<C04/C00<04a<0A1<00`dC4`054`0341<C08hC00<04a<00a<00`0C

4`1D4`8=6Q<001`C00<@4a<0C1<00`0C4`154`033A<C00DC00<@4a<0SQ<00`0C4`024`80Ea<00`dC

4`0G4`006a<00a0C4`174`8011<00`0C4`154`033A<C00HC00<@4a<0SA<00`0C4`024`0301<C05LC

0`dF4`006Q<00a0C4`1:4`0501<C4`00B1<00`dC4`064`0341<C08/C00<04`000a<00`0C4`1J4`8=

51<001TC00<@4a<0BQ<00`0C4`024`80B1<00`dC4`054`0341<C08`C00<04a<00Q<00`0C4`1L4`<=

4A<006LC00<04a<0ia<00`0C4`1`4`00IA<00`0C003Y4`80LA<006HC00<04a<0j1<00`0C4`1`4`00

;1<30?lC8a<00`0C4`1`4`00;1<00`0C4`3o4b<C00<04a<0L1<002dC00<04a<01A<00`0C4`3o4hdC

000]4`0401<C4`<000@C01<C0`3o4hXC000/4`0301<0008C0P024`0301<C008C00<04a<0oa>84`00

;A<00`0C4`034`0401<C008C00<04a<0oa>94`00<a<0100C4`034`0301<C00HC00<04a<09A<302dC

00<04a<0oa<W4`007A<300034`00008031<300@C0`084`0301<C02@C00@04a<04A<300034`000080

0Q<00`0C4`024`0301<C008C00<04a<01A<0100C4a<5008C00@04a<C0P034`801Q<20</C00<04a<0

<Q<00`0C4`084`0071<0100C4`0T4`0301<C02<C00@04a<041<0100C4`064`0301<000LC00<04`00

11<500<C00<04a<021<00`0C4`024`0301<C008C00<04a<0`a<00`0C4`044`0301<C01<C00<04a<0

7Q<00`0C4`074`0071<01@0C4`0C00@000<C0000600[4`<041<01@0C4`0C00@000@C01<02A<00`0C

4`044`0301<C00<C00<04a<01a<00`0C4`024`8011<00`0C4`2a4`0401<C4`@00Q<200HC00<04a<0

0a<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`054`0401<C4`D00Q<0100C4a<200<C0P064`80

11<0100C4a<2004C0@0100007A<304dC00<04a<03a<300HC00<04`001a<200LC00<04a<00a<00`0C

4`084`0601<C01<011<00`0C4`2`4`0301<000LC00<04a<011<500<C00L04a<C01<000LC00<04`00

11<500<C00<04a<021<00`0C4`024`0301<C008C00<04a<011<00`0C4`024`0301<0004C000O4`03

01<C04XC0P0C4`0301<C00@C00<04`001a<00`0C4`0<4`0301<C00HC00<04`000Q<00`0C00044`03

01<00;0C00<04`000Q<400034`0C00LC00<04a<00a<01`0C4a<04`002A<00`0C4`044`0301<C00<C

00<04a<01a<00`0C4`024`8011<00`0C4`044`0301<C00<C0@014`4C000N4`80H1<200LC00<04a<0

1Q<300/C0P094`0301<C008C0P044`<0UQ<200034`0001DC00<04`001a<00`0C4`064`0301<C00<C

00L04a<C01<000LC0P074`0301<C00<C00<04a<021<01P0C4`0C00@C00<04a<011<00`0C4`034`40

0A<14`00oa=A4`0301<001HC00<04`001a<00`0C000=4`0601<C01<01a<00`0C4`0<4`0301<C00HC

00<04`000Q<00`0C00044`0301<000<C00<04a<00a<00`0C00014`00:A<200HC0P3o4alC00<04a<0

5Q<00`0C4`064`<03Q<0100C4`084`<02a<200TC00<04a<00Q<200@C0`024`0301<C00<C0P014`40

0@0002/C00<04a<00Q<00`0C4`3o4alC00<04a<0L1<002XC00<04a<00a<00`0C4`054`0301<C0?lC

5Q<00`0C001a4`00:a<00`0C4`024`0301<C008C10034`<0oa<A4`8000<C0000L1<002TC00<04`00

11<00`0C00024`8000<C01<011<00`0C4`3o4h@C000Z4`0301<C00<C0`044`0301<000<C00<04a<0

oa>54`00=a<00`0C00044`0301<C0?lCQ1<003DC0`044`<0oa>64`00oa?54`00oa?54`00oa?54`00

oa?54`00oa?54`00\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-6.95792, -1.52018, 0.0206103, 0.0206103}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -84.5 0 ]

[.5 .96488 84.5 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -145.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.385) show

222.250000 19.500000 moveto

(C) show

227.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.24214 0 m

.26171 .02711 L

.30316 .08451 L

.34309 .13982 L

.3815 .19302 L

.42237 .24962 L

.46172 .30412 L

.49955 .35652 L

.53984 .41232 L

.57861 .46602 L

.61984 .52311 L

.65954 .57811 L

.69774 .63101 L

.73838 .6873 L

.77751 .7415 L

.81909 .79909 L

.85916 .85458 L

.89771 .90797 L

s

.89771 .90797 m

.92977 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.336416 0.238095 [

[.02381 .32392 -6 -9 ]

[.02381 .32392 6 0 ]

[.2619 .32392 -6 -9 ]

[.2619 .32392 6 0 ]

[.7381 .32392 -3 -9 ]

[.7381 .32392 3 0 ]

[.97619 .32392 -3 -9 ]

[.97619 .32392 3 0 ]

[1.025 .33642 0 -8 ]

[1.025 .33642 9 8 ]

[.4875 .09832 -12 -4.5 ]

[.4875 .09832 0 4.5 ]

[.4875 .21737 -24 -4.5 ]

[.4875 .21737 0 4.5 ]

[.4875 .45546 -18 -4.5 ]

[.4875 .45546 0 4.5 ]

[.4875 .57451 -6 -4.5 ]

[.4875 .57451 0 4.5 ]

[.4875 .69356 -18 -4.5 ]

[.4875 .69356 0 4.5 ]

[.4875 .81261 -6 -4.5 ]

[.4875 .81261 0 4.5 ]

[.5 .87192 -4.5 0 ]

[.5 .87192 4.5 16 ]

[.5 .85942 -137 0 ]

[.5 .85942 137 16 ]

[ 0 0 0 0 ]

[ 1 .84692 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .33642 m

.02381 .34267 L

s

[(-2)] .02381 .32392 0 1 Mshowa

.2619 .33642 m

.2619 .34267 L

s

[(-1)] .2619 .32392 0 1 Mshowa

.7381 .33642 m

.7381 .34267 L

s

[(1)] .7381 .32392 0 1 Mshowa

.97619 .33642 m

.97619 .34267 L

s

[(2)] .97619 .32392 0 1 Mshowa

.125 Mabswid

.07143 .33642 m

.07143 .34017 L

s

.11905 .33642 m

.11905 .34017 L

s

.16667 .33642 m

.16667 .34017 L

s

.21429 .33642 m

.21429 .34017 L

s

.30952 .33642 m

.30952 .34017 L

s

.35714 .33642 m

.35714 .34017 L

s

.40476 .33642 m

.40476 .34017 L

s

.45238 .33642 m

.45238 .34017 L

s

.54762 .33642 m

.54762 .34017 L

s

.59524 .33642 m

.59524 .34017 L

s

.64286 .33642 m

.64286 .34017 L

s

.69048 .33642 m

.69048 .34017 L

s

.78571 .33642 m

.78571 .34017 L

s

.83333 .33642 m

.83333 .34017 L

s

.88095 .33642 m

.88095 .34017 L

s

.92857 .33642 m

.92857 .34017 L

s

.25 Mabswid

0 .33642 m

1 .33642 L

s

gsave

1.025 .33642 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .09832 m

.50625 .09832 L

s

[(-1)] .4875 .09832 1 0 Mshowa

.5 .21737 m

.50625 .21737 L

s

[(-0.5)] .4875 .21737 1 0 Mshowa

.5 .45546 m

.50625 .45546 L

s

[(0.5)] .4875 .45546 1 0 Mshowa

.5 .57451 m

.50625 .57451 L

s

[(1)] .4875 .57451 1 0 Mshowa

.5 .69356 m

.50625 .69356 L

s

[(1.5)] .4875 .69356 1 0 Mshowa

.5 .81261 m

.50625 .81261 L

s

[(2)] .4875 .81261 1 0 Mshowa

.125 Mabswid

.5 .12213 m

.50375 .12213 L

s

.5 .14594 m

.50375 .14594 L

s

.5 .16975 m

.50375 .16975 L

s

.5 .19356 m

.50375 .19356 L

s

.5 .24118 m

.50375 .24118 L

s

.5 .26499 m

.50375 .26499 L

s

.5 .2888 m

.50375 .2888 L

s

.5 .31261 m

.50375 .31261 L

s

.5 .36023 m

.50375 .36023 L

s

.5 .38404 m

.50375 .38404 L

s

.5 .40785 m

.50375 .40785 L

s

.5 .43165 m

.50375 .43165 L

s

.5 .47927 m

.50375 .47927 L

s

.5 .50308 m

.50375 .50308 L

s

.5 .52689 m

.50375 .52689 L

s

.5 .5507 m

.50375 .5507 L

s

.5 .59832 m

.50375 .59832 L

s

.5 .62213 m

.50375 .62213 L

s

.5 .64594 m

.50375 .64594 L

s

.5 .66975 m

.50375 .66975 L

s

.5 .71737 m

.50375 .71737 L

s

.5 .74118 m

.50375 .74118 L

s

.5 .76499 m

.50375 .76499 L

s

.5 .7888 m

.50375 .7888 L

s

.5 .07451 m

.50375 .07451 L

s

.5 .0507 m

.50375 .0507 L

s

.5 .02689 m

.50375 .02689 L

s

.5 .00308 m

.50375 .00308 L

s

.5 .83642 m

.50375 .83642 L

s

.25 Mabswid

.5 0 m

.5 .84692 L

s

gsave

.5 .87192 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .85942 -198 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.385) show

298.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

303.000000 15.000000 moveto

(L) show

310.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

317.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

324.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

329.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

333.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .84692 L

0 .84692 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .16546 m

.02576 .16547 L

.03156 .16548 L

.04113 .16549 L

.05429 .16551 L

.07082 .16554 L

.09044 .16557 L

.11282 .16561 L

.13756 .16567 L

.16425 .16573 L

.19243 .1658 L

.22161 .16588 L

.25131 .16597 L

.281 .16608 L

.31019 .16621 L

.33837 .16635 L

.36506 .16651 L

.3898 .16668 L

.41218 .16687 L

.4318 .16706 L

.44833 .16724 L

.46149 .16741 L

.47106 .16755 L

.47686 .16764 L

.47881 .16767 L

s

.47881 .16767 m

.47942 .16768 L

.48124 .16771 L

.48424 .16776 L

.48836 .16783 L

.49354 .16793 L

.49969 .16805 L

.5067 .1682 L

.51446 .16838 L

.52282 .1686 L

.53165 .16887 L

.5408 .16918 L

.5501 .16955 L

.55941 .16998 L

.56856 .1705 L

.57739 .17112 L

.58575 .17185 L

.59351 .17271 L

.60052 .17374 L

.60667 .17497 L

.61185 .17643 L

.61597 .17816 L

.61897 .1802 L

.62079 .18262 L

.6214 .18543 L

s

.47881 .42073 m

.47942 .40651 L

.48124 .39229 L

.48424 .37817 L

.48836 .36422 L

.49354 .35049 L

.49969 .33704 L

.5067 .32392 L

.51446 .31118 L

.52282 .29887 L

.53165 .28705 L

.5408 .27574 L

.5501 .26499 L

.55941 .25483 L

.56856 .24529 L

.57739 .23639 L

.58575 .22815 L

.59351 .22058 L

.60052 .21368 L

.60667 .20745 L

.61185 .20186 L

.61597 .1969 L

.61897 .19254 L

.62079 .18874 L

.6214 .18546 L

s

.47881 .42085 m

.47942 .43506 L

.48124 .44925 L

.48424 .46332 L

.48836 .4772 L

.49354 .49083 L

.49969 .50416 L

.5067 .51713 L

.51446 .52968 L

.52282 .54177 L

.53165 .55334 L

.5408 .56433 L

.5501 .57472 L

.55941 .58444 L

.56856 .59346 L

.57739 .60174 L

.58575 .60925 L

.59351 .61596 L

.60052 .62182 L

.60667 .62683 L

.61185 .63096 L

.61597 .63419 L

.61897 .6365 L

.62079 .6379 L

.6214 .63836 L

s

.6214 .63836 m

.62194 .63877 L

.62354 .63998 L

.62618 .64197 L

.6298 .64467 L

.63436 .64802 L

.63977 .65193 L

.64594 .65631 L

.65276 .66106 L

.66012 .66609 L

.66789 .67128 L

.67594 .67654 L

.68413 .68179 L

.69232 .68694 L

.70036 .6919 L

.70813 .69661 L

.71549 .70099 L

.72231 .70499 L

.72848 .70856 L

.73389 .71166 L

.73845 .71424 L

.74208 .71629 L

.74472 .71776 L

.74632 .71865 L

.74686 .71895 L

s

.74686 .14514 m

.74784 .14157 L

.75076 .1374 L

.75558 .13264 L

.76222 .1273 L

.77055 .12141 L

.78044 .11503 L

.79172 .10823 L

.80419 .1011 L

.81764 .09375 L

.83184 .08629 L

.84656 .07881 L

.86152 .07142 L

.87649 .06424 L

.8912 .05734 L

.9054 .05083 L

.91886 .04479 L

.93133 .03928 L

.94261 .03438 L

.95249 .03013 L

.96083 .0266 L

.96746 .02381 L

.97228 .02179 L

.97521 .02057 L

.97619 .02016 L

s

.74686 .14516 m

.74784 .14819 L

.75076 .15074 L

.75558 .15285 L

.76222 .15459 L

.77055 .15601 L

.78044 .15717 L

.79172 .15812 L

.80419 .1589 L

.81764 .15954 L

.83184 .16007 L

.84656 .1605 L

.86152 .16086 L

.87649 .16116 L

.8912 .16141 L

.9054 .16162 L

.91886 .16179 L

.93133 .16193 L

.94261 .16204 L

.95249 .16214 L

.96083 .16221 L

.96746 .16227 L

.97228 .1623 L

.97521 .16233 L

.97619 .16233 L

s

.74686 .71895 m

.74784 .71949 L

.75076 .72111 L

.75558 .72376 L

.76222 .72736 L

.77055 .73183 L

.78044 .73705 L

.79172 .7429 L

.80419 .74924 L

.81764 .75595 L

.83184 .7629 L

.84656 .76994 L

.86152 .77696 L

.87649 .78385 L

.8912 .79049 L

.9054 .7968 L

.91886 .80267 L

.93133 .80804 L

.94261 .81283 L

.95249 .81698 L

.96083 .82044 L

.96746 .82318 L

.97228 .82516 L

.97521 .82635 L

.97619 .82675 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<2074C003o4e8C00<04a<0L1<006@C1@3X4`0301<C070C001V4`0301<C0>PC00<04a<0

L1<003lC00<=4a<07Q<300<C00<04a<00Q<20>@C00<04a<0GA<23A4C00104`033A<C02<C00<04a<0

0Q<00`0C4`3S4`80G1<23A<C00104`033A<C02<C00<04a<00Q<00`0C4`3S4`0301<C05TC0PdE4`00

@A<00`dC4`0Q4`8011<00`0C4`3S4`0301<C05LC0PdG4`00@A<00`dC4`0W4`80i1<00`0C4`1D4`<=

6A<0048C00<=4a<09Q<00`0C4`3S4`0301<C058C0PdL4`00@a<00`dC4`0U4`0301<C0><C0P1@4`<=

7Q<004<C00<=4a<09A<00`0C4`3S4`0301<C04dC0PdQ4`00A1<00`dC4`0T4`80i1<00`0C4`1;4`8=

8a<004DC00<=4a<08a<00`0C4`3S4`0301<C04TC0PdU4`00AA<00`dC4`0S4`0301<C0><C00<04a<0

Aa<23BLC00164`033A<C028C00<04a<0ha<204HC0PdY4`00Aa<00`dC4`0Q4`80i1<00`0C4`134`8=

:a<004PC00<=4a<081<00`0C4`3S4`0301<C044C0Pd]4`00B1<00`dC4`0P4`0301<C0=`C1@024`03

01<C03lC0Pd_4`00BA<00`dC4`0O4`0301<C0=hC00<04a<00Q<00`0C4`0m4`8=<A<004XC00<=4a<0

7Q<20=TC0`034`0301<C008C0P0l4`8=<a<004/C00<=4a<07A<00`0C4`3N4`0301<C008C00<04a<0

>Q<00`dC4`0c4`00Ba<00`dC4`0>4`0301<C008C00<04a<00Q<00`0C4`024`0301<C0=hC00<04a<0

0Q<00`0C4`0h4`8==Q<004`C00<=4a<031<00`0C00074`0301<000<C00<04a<0gA<200@C00<04a<0

=Q<23CPC001=4`033A<C00HC0`024`0301<000TC00@04a<C0P3T4`0301<C03DC00<=4a<0>1<004hC

00<=4a<02Q<00`0C00074`8011<00`0C4`3S4`80=A<00`dC4`0i4`00CQ<00`dC4`0:4`0301<000LC

00<04a<00a<00`0C4`3S4`0301<C03<C00<=4a<0>Q<004lC00<=4a<02Q<00`0C4`064`<00a<00`0C

4`3S4`0301<C034C0Pdm4`00D1<00`dC4`0H4`0301<C0><C00<04a<0<1<00`dC4`0m4`00DA<00`dC

4`0G4`80i1<00`0C4`0_4`8=?a<0058C00<=4a<05Q<00`0C4`3S4`80<A<00`dC4`0m4`00DQ<00`dC

4`0F4`0301<C0><C00<04a<0<A<33C`C001C4`033A<C01DC00<04a<0ha<00`0C4`0d4a8=:Q<005@C

00<=4a<051<208<C1@eL4`0301<C04HC6@dA4`00EA<00`dC4`0C4`0301<C08LCJ@eV4`006Q<302DC

1@0>4`033A<C01<C00<04a<091<502@C0`2C4`0301<C00XC2PeL4`006Q<00`0C4`0W4`0301<C00lC

00<=4a<04Q<00`0C4`0V4`0301<C02@C00<04a<0Ta<00`0C4`0D4`8=FQ<001DC0`034`0301<C020C

0`034`0301<C010C00<=4a<04A<202LC00<04a<09A<00`0C4`2B4`0301<C01HC00<=4a<0Ea<001/C

00<04a<09Q<00`0C4`0A4`033A<C010C00<04a<09Q<00`0C4`0U4`0301<C098C00<04a<05Q<00`dC

4`1G4`006Q<00`0C000W4`0301<C014C00<=4a<041<00`0C4`0V4`0301<C02@C00<04`00Ta<201HC

00<=4a<0F1<001/C00<04a<09A<201@C00<=4a<03a<00`0C4`0U4`809a<00`0C4`2B4`0301<C01DC

00<=4a<0F1<005XC00<=4a<03Q<20>@C00<04a<051<00`dC4`1I4`00FQ<00`dC4`0>4`0301<C0=@C

00<04a<00Q<00`0C4`024`0301<C008C00<04a<04a<00`dC4`1J4`00Fa<00`dC4`0=4`0301<C05/C

0P1f4`0301<000LC00<04`000a<00`0C4`0B4`033A<C05/C001L4`033A<C00`C00<04a<0FQ<00`0C

4`1a4`<00Q<00`0C00094`0401<C4`804Q<00`dC4`1L4`005A=800033@0006801Q<00`0C4`1f4`03

01<000LC0P044`0301<C010C00<=4a<0GA<001TC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<0

1A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<=00DC00<04a<01A<00a0C4`054`03

01<C00HC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<0

1A<00`0C4`054`0301<C00PC00<04a<0MQ<00`0C00074`0301<C00<C00<04a<03a<00`dC4`1N4`00

GQ<00`dC4`0:4`0341<C05XC00<04`00Ma<00`0C4`064`<00a<00`0C4`0>4`033A<C05lC001O4`03

3A<C00TC0Q1K4`<0QQ<00`0C4`0=4`033A<C060C001P4`033A<C00PC0Q3T4`803A<00`dC4`1Q4`00

H1<00`dC4`074`03400@0>@C00<04a<02a<00`dC4`1R4`00HA<00`dC4`064`03400@0>@C00<04a<0

2Q<00`dC4`1S4`00HQ<00`dC4`054`03400@0>@C00<04a<02A<00`dC4`1T4`00Ha<00`dC4`034`05

41<00100ha<00`0C4`084`033A<C06DC001S4`033A<C00<C00D@4`0C403S4`8021<00`dC4`1V4`00

I1<00`dC4`024`0541<04a00ha<00`0C4`064`033A<C06LC001U4`073A<C4a0C00024`0341<C0>0C

00<04a<01A<00`dC4`1X4`00IQ<01@dC4a0C008000<C41<0hA<00`0C4`044`033A<C06TC001V4`06

3A<C41<00Q<00a0C4`204`<0;A<502/C00<04a<011<00`dC4`0T4`D0;A<3010C001W4`053A0C4`00

0a<00a0C4`1o4`0301<C02lC00<04a<0:a<200@C00<=4a<09a<00`0C4`0]4`0301<C010C001X4`04

3A<C00<C00<@4a<0NQ<300<C00<04a<0:1<300<C00<04a<0:a<00`0C4`034`033A<C02LC00<04a<0

;Q<00`0C4`0?4`00J1<00`dC4`02008C00<@4a<0P1<00`0C4`0^4`0301<C02/C00<04a<00Q<00`dC

4`0X4`0301<C02hC00<04a<03a<006LC00D@4`dC00044`0341<C07hC00<04`00;a<00`0C4`0[4`05

01<C4`d0:a<00`0C4`0]4`0301<0010C001L4`0301<C008C00<04a<00Q<01P0@4a<=00@C00<@4a<0

Oa<00`0C4`0]4`80;A<200034`dC02XC0P0`4`0301<C00lC001K4`0301<000LC00<040000Q<00`d0

4`034`0341<C0=hC00<04`d0L1<005/C00<04`0021<00a004`024`033@0C00<C00<@4a<0gA<00`0C

3@1`4`00Fa<00`0C00074`03010C00<C00<03A<00a<00a0C4`3M4`0300dC06`C0P024`00Fa<00`0C

00074`0341<C00<C00<03A<011<00a0C4`3L4`033A<C06/C00<04a<00Q<005`C00<04a<01Q<00a00

00034`0301<=00@C00<@4a<0MQ=V00033@0006@01a<00`0C4`024`00I1<00a0C4`044`8000<C3A<0

0Q<00a0C4`1k4`0301<C00LC00<04a<01Q<00`0C4`074`0301<C00LC00<04a<01a<00`0C4`064`03

01<C00LC00<04a<01a<00`0C4`064`0301<C00LC00<=4a<01a<00`0C4`074`0301<C00HC00<04a<0

1a<00`0C4`074`0301<C00HC00<04a<01a<00`0C4`074`0301<C00HC00<04a<01a<00`0C4`0:4`03

01<C008C001T4`0341<C00@C00@04a<=11<00a0C4`1j4`0301<C02hC00<04a<0;1<00`d04`0_4`03

01<C02dC00<04a<02Q<00`0C00024`00Ha<00a0C4`054`0501<C4`d00a<00a0C4`3J4`033@0C06`C

0`024`00Ha<00a0C4`054`0301<C008C00D=4a<C403K4`033@0C074C001R4`0341<C00HC00<04a<0

0a<010dC4a3J4`043A<0074C001R4`0341<C00HC0P044`053A<C4a00fA<00`dC001b4`00HA<00a0C

4`074`0301<C00@C00@=4a<@fA<00`dC001b4`00HA<00a0C4`074`0301<C00DC00<=4a00f1<010dC

4`1b4`00H1<00a0C4`084`0301<C00HC00<=4a00ea<010dC4`1b4`00H1<00a0C4`084`801a<00`dC

403G4`033A<C0080LA<005lC00<@4a<02A<00`0C4`074`033A<@0=DC00D=4a<C001b4`00Ga<00a0C

4`094`0301<C00PC00<=41<0e1<01@dC4a<0078C001N4`0341<C00XC00<04a<02A<00`d@4`3C4`05

3A<C4`00LQ<005hC00<@4a<02Q<200XC00<=41<0da<01@dC4a<0078C001M4`0341<C00/C00<04a<0

2Q<00`d@4`3B4`043A<C4`80LA<005dC00<@4a<011<5008C00<04a<02a<00`dC4`3A4`053A<C4`00

LQ<005`C00<@4a<01a<00`0C4`024`0301<C00`C00<=4a<0d1<01@dC4a<0078C001K4`0341<C00PC

00<04a<00Q<200dC00<=41<0d1<01@dC4a<0078C001K4`0341<C00PC00<04a<00Q<00`0C4`0=4`03

3A<C0<lC00D=4a<C001b4`00FQ<00a0C4`094`0301<C008C00<04a<03Q<00`dC4`3>4`043A<C4`80

LA<005XC00<@4a<021<200@C00<04a<03Q<00`d@4`3>4`053A<C4`00LQ<005TC00<@4a<03a<2010C

00<=4a<0cA<01@dC4a<0078C001H4`0341<C010C00<04a<041<00`dC4`314`0301<C008C00<04a<0

0Q<00`0=4`024`0301<C070C001H4`0341<C010C00<04a<04A<00`dC4`2o4`0301<000LC00<04`d0

0a<00`0C4`1`4`00Ea<00a0C4`0A4`0301<C014C00<=4a<0_a<00`0C00094`0400dC4`80LA<005HC

00<@4a<04Q<201<C00<=4a<0_Q<00`0C00074`8000DC3A<C001b4`00EQ<00a0C4`0B4`0301<C01<C

00<=4a<0_A<00`0C00074`0401<C3@8C00<04a<0L1<005DC00<@4a<04a<00`0C4`0C4`0340dC0;hC

00<04a<01Q<300044`dC078C001D4`0341<C01@C00<04a<051<00`dC4`3:4`043A<0074C001C4`03

41<C01DC0P0E4`0340dC0<XC00<=4`00LQ<005<C00<@4a<05A<00`0C4`0E4`0340dC0<XC00<=01<0

LA<0058C00<@4a<05Q<00`0C4`0F4`0340dC0<TC00<=01<0LA<0054C00<@4a<05a<00`0C4`0F4`03

40dC0<TC00<=01<0LA<0054C00<@4a<05a<201PC00<@3A<0bA<00`d04`1`4`00D1<00a0C4`0H4`03

01<C01LC00<@4`d0bA<00`dC4`1`4`00Ca<00a0C4`084`D00Q<00`0C4`024`0301<C008C00<04a<0

61<00a0C3@384`033A<C070C001?4`0341<C00XC00<04a<01Q<00`0C00034`0301<C01TC00<@3A<0

aa<00`0=4`1`4`00CQ<00a0C4`0;4`0301<C00PC00@04a<C0P0K4`0340dC0<HC00<04`d0L1<004dC

00<@4a<031<00`0C4`064`8011<00`0C4`0J4`0341<=0<HC0P000`dC4`1^4`00C1<00a0C4`0=4`03

01<C00HC00<04a<00a<00`0C4`0K4`0340dC0<DC00@04a<=Ka<004`C00<@4a<031<200PC0`034`03

01<C01`C00<@3A<0a1<01@0C4a<=06hC001;4`0341<C01dC0P0N4`0340dC0<<C00<04a<00Q<00`dC

4`1[4`00BQ<00a0C4`0N4`0301<C01dC00<@3A<0`a<00`0C4`034`033A<C06XC001:4`0341<C01hC

00<04a<07Q<00a0=4`324`8011<00`dC4`1Z4`00BA<00a0C4`0O4`0301<C01lC00<@3A<0`A<00`0C

4`044`033A<C06TC00184`0341<C020C0P0Q4`033A<C0<0C00<04a<011<00`dC4`1Y4`00Aa<00a0C

4`0Q4`0301<C024C00<=4a<0^1<5008C00<04a<01A<00`dC4`1X4`00Aa<00a0C4`0Q4`0301<C024C

00<@3A<0^Q<00`0C4`024`0301<C00HC00<=4a<0Ia<004HC00<@4a<08Q<00`0C4`0R4`033A<C0;TC

00<04a<00Q<200PC00<=4a<0IQ<004DC00<@4a<08a<202@C00<=4a<0^1<00`0C4`024`0301<C00PC

00<=4a<0IA<004@C00<@4a<091<00`0C4`0T4`033A<C0;LC00<04a<00Q<00`0C4`094`033A<C06@C

00144`0341<C02@C00<04a<091<00a0=4`2f4`8011<00`0C4`0:4`033A<C06<C00134`0341<C02DC

00<04a<09A<00`dC4`2k4`0301<C00/C00<=4a<0HQ<0048C00<@4a<09Q<00`0C4`0V4`033A<C0;XC

0P0=4`8=HQ<0044C00<@4a<09a<202PC00<=4a<0^A<00`0C4`0>4`033A<C05lC00104`0341<C02PC

00<04a<0:1<00`dC4`2h4`0301<C00lC00<=4a<0GQ<0040C00<@4a<08Q<300<C00<04a<0:1<00`d@

4`2h4`0301<C010C00<=4a<0GA<003lC00<@4a<08a<00`0C4`034`0301<C02TC00<=4a<0]a<00`0C

4`0A4`033A<C05`C000n4`0341<C02DC00<04a<00Q<202/C00<=4a<0]Q<201<C00<=4a<0Fa<003dC

00<@4a<09Q<00`0C4`024`0301<C02/C00<=4a<0]A<00`0C4`0C4`8=Fa<003dC00<@4a<09A<00`0C

00034`0301<C02/C00<=41<0]A<00`0C4`0E4`033A<C05PC000l4`0341<C02LC00<04a<00Q<00`0C

4`0/4`033A0C0;@C00<04a<05Q<00`dC4`1G4`00>a<00a0C4`0]4`80;Q<00`d@4`2c4`8061<23ELC

000j4`0341<C02hC00<04a<0;Q<00`dC4`2b4`0301<C01PC00<=4a<0EA<003XC00<@4a<0;Q<00`0C

4`0^4`033A0C0;8C00<04a<06A<23EDC000i4`0341<C02lC00<04a<0;a<00`d@4`2a4`0301<C01/C

00<=4a<0DQ<003PC00<@4a<0<1<2034C00<=41<0/1<00`0C4`0L4`033A<C054C000g4`0341<C034C

00<04a<0<1<00`d@4`2`4`807Q<23E4C000g4`0341<C034C00<04a<0<A<00`d@4`2_4`0301<C01lC

00<=4a<0CQ<003HC00<@4a<0<Q<00`0C4`0b4`033A0C0:hC00<04a<081<23DhC000e4`0341<C03<C

0P0d4`033A0C09`C1@024`0301<C008C00<04a<00Q<00`0C4`0R4`8=C1<003@C00<@4a<0=1<00`0C

4`0c4`033A<@09hC00<04a<01Q<00`0C00034`0301<C02@C00<=4a<0BA<003<C00<@4a<0=A<00`0C

4`0d4`033A<@09dC00<04a<021<0100C4a<202HC0Pe94`00<Q<00a0C4`0f4`0301<C03DC00<=41<0

W1<00`0C4`064`8011<00`0C4`0W4`8=Aa<0034C00<@4a<0=a<203HC00<=4a00W1<00`0C4`064`03

01<C00<C00<04a<0:A<23DDC000`4`0341<C03PC00<04a<0=Q<00`dC402J4`8021<300<C00<04a<0

:a<23D<C000_4`0341<C02TC0`034`0301<C008C00<04a<00Q<00`0C4`0g4`033A<@0:TC00<04a<0

;A<23D4C000^4`0341<C02XC00<04a<01a<00`0C00034`0301<C03LC00@=4a<@Z1<202lC0`do4`00

;A<00a0C4`0/4`0301<C00PC00@04a<C0P0i4`043A<C4:LC00<04a<0<1<23ChC000/4`0341<C02dC

00<04a<01Q<200@C00<04a<0>A<010dC4a2V4`0301<C038C0Pdl4`00:a<00a0C4`0]4`0301<000LC

00<04a<00a<00`0C4`0j4`043A<C4:DC00<04a<0=1<00`dC4`0i4`00:Q<00a0C4`0_4`0301<C00HC

0`034`0301<C03XC00D=4a<C402T4`0301<C03DC0`dh4`00:A<00a0C4`0o4`80?1<01@dC4a<@0:<C

0P0i4`8==Q<002PC00<@4a<0@1<00`0C4`0l4`053A<C4a00XQ<00`0C4`0j4`8==1<002LC00<@4a<0

@A<00`0C4`0l4`033A<C008C00<@4a<0Wa<00`0C4`0l4`8=<Q<002HC00<@4a<0@Q<00`0C4`0m4`03

3A<C008C00<@4a<0WQ<00`0C4`0n4`8=<1<002DC00<@4a<0@a<203lC00<=4a<00Q<00a0C4`2M4`03

01<C040C0Pd^4`0091<00a0C4`144`0301<C03hC00<=4a<00a<00a0C4`2L4`80@a<23B`C000S4`03

41<C04DC00<04a<0?a<00`dC4`034`0341<C09/C00<04a<0A1<23BXC000S4`0341<C04DC00<04a<0

@1<00`dC4`034`0341<C09XC00<04a<0AQ<23BPC000R4`0341<C04HC0P114`033A<C00@C00<@4a<0

VA<00`0C4`184`8=9Q<0024C00<@4a<0Aa<00`0C4`114`033A<C00@C00<@4a<0V1<00`0C4`1:4`8=

91<0020C00<@4a<0B1<00`0C4`124`033A<C00@C00<@4a<0Ua<204dC0`dQ4`007a<00a0C4`194`03

01<C048C00<=4a<01A<00a0C4`2F4`0301<C04lC0PdO4`007Q<00a0C4`1:4`80A1<00`dC4`054`03

41<C08lC0`034`0301<C054C0`dL4`007A<00a0C4`1;4`0301<C04@C00<=4a<01A<00a0C4`2>4`03

01<C00<C00<04a<0E1<23AXC000L4`0341<C04`C00<04a<0AA<00`dC4`054`0341<C08hC00<04a<0

0Q<205LC0PdH4`006a<00a0C4`174`8011<00`0C4`154`033A<C00HC00<@4a<0SA<00`0C4`024`03

01<C05PC0PdF4`006Q<00a0C4`1:4`0501<C4`00B1<00`dC4`064`0341<C08/C00<04`000a<00`0C

4`1J4`8=51<001TC00<@4a<0BQ<00`0C4`024`80B1<00`dC4`054`0341<C08`C00<04a<00Q<00`0C

4`1L4`<=4A<006LC00<04a<0ia<00`0C4`1`4`00IA<00`0C003Y4`80LA<006HC00<04a<0j1<00`0C

4`1`4`00:Q<30?lC9A<00`0C4`1`4`00:Q<00`0C4`3o4iPC000[4`0301<C00@C00<04a<0oa>@4`00

:a<0100C4a<400<C0`3o4h`C000Z4`0301<0008C0P000a<04`044`0301<C0?lCRQ<002/C00<04a<0

0a<00`0C00034`0301<C0?lCRa<0034C00<04`0011<00`0C4`064`0301<C02LC0`0[4`0301<C0?lC

:A<001/C0`000a<0000200`C0`044`<021<00`0C4`0V4`0401<C00lC0`000a<00002008C00<04a<0

0Q<00`0C4`024`0301<C00DC00@04a<C1@024`0401<C4`8011<00`0C4`024`0301<C00@C0P354`03

01<C03LC00<04a<01Q<001XC00@04a<091<00`0C4`0U4`0401<C00hC00@04a<01Q<00`0C00074`03

01<000@C1@034`0301<C00PC00H04a<04`024`0301<000@C00<04a<0_A<00`0C4`044`0301<C01<C

00<04a<08a<00`0C4`054`006Q<01@0C4`0C00@000<C0000600]4`<03Q<01@0C4`0C00@000@C01<0

2A<00`0C4`044`0301<C00<C00<04a<01a<01`0C4a<04`0011<00`0C4`024`0301<C0:/C00@04a<C

10024`801Q<00`0C4`034`0301<C008C00<04a<00Q<00`0C4`024`0301<C00DC00@04a<C1@024`04

01<C4`8011<00`0C4`024`0301<C00@C0P044`0401<C4`800A<001/C0`1?4`0301<C00dC0`064`03

01<000LC0P074`0301<C00<C00<04a<021<01@0C4a<000<C0P054`0301<C0:XC00<04`001a<00`0C

4`044`D00a<01`0C4a<04`001a<00`0C00044`D00a<00`0C4`084`0601<C01<00Q<00`0C00044`03

01<C00@C00<04a<00Q<1004C000M4`0301<C04`C0P0A4`0301<C00@C00<04`001a<00`0C4`0<4`03

01<C00HC00<04`000Q<00`0C00024`0301<C00@C00<04`00Ta<200034`00018C00<04`000Q<40003

4`0C00LC00<04a<00a<01`0C4a<04`002A<00`0C4`044`0301<C00<C00<04a<01a<01`0C4a<04`00

11<00`0C4`024`0301<C00@C00<04a<00a<1000071<2060C0P074`0301<C00HC0`0;4`802A<00`0C

4`024`0401<C4`<011<309@C00<04`004a<00`0C00074`0301<C00HC00<04a<00a<01`0C4a<04`00

1a<200LC00<04a<00a<00`0C4`084`0501<C4`000a<200DC00<04a<011<00`0C4`034`40003o4e8C

00<04a<04Q<00`0C00074`0301<000dC00H04a<04`074`0301<C00`C00<04a<01Q<00`0C00024`03

01<0008C00<04a<011<00`0C00034`0301<C00<C0@014`009Q<200HC0P3o4b8C00<04a<04a<00`0C

4`064`<03Q<0100C4`084`<02a<200TC00<04a<00Q<0100C4a<300@C0`024`0301<C00<C0P014`00

:1<00`0C4`024`0301<C0?lC8A<00`0C001a4`009a<00`0C4`034`0301<C00HC00<04a<0oa<G4`80

00<C0000L1<002PC00<04a<00Q<00`0C4`024`<000@C01<C0`3o4hTC000V4`0301<000@C00<04`00

0Q<2008C00<04a<00Q<00`0C4`3o4hLC000W4`0301<C00<C0`044`0401<C008C00<04a<0oa>84`00

=1<0100C4`034`0301<C0?lCQa<0038C0`044`<0oa>94`00oa?54`00oa?54`00oa?54`00oa?54`00

oa?54`00\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-6.95686, -1.5177, 0.0206072, 0.0206072}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -82 0 ]

[.5 .96488 82 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -143 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.38) show

217.250000 19.500000 moveto

(C) show

222.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.2412 0 m

.26171 .0283 L

.30316 .0855 L

.34309 .1406 L

.3815 .19361 L

.42237 .25001 L

.46172 .30431 L

.49955 .35652 L

.53984 .41212 L

.57861 .46563 L

.61984 .52252 L

.65954 .57731 L

.69774 .63002 L

.73838 .68611 L

.77751 .74011 L

.81909 .79749 L

.85916 .85278 L

.89771 .90598 L

s

.89771 .90598 m

.93133 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.334788 0.238095 [

[.02381 .32229 -6 -9 ]

[.02381 .32229 6 0 ]

[.2619 .32229 -6 -9 ]

[.2619 .32229 6 0 ]

[.7381 .32229 -3 -9 ]

[.7381 .32229 3 0 ]

[.97619 .32229 -3 -9 ]

[.97619 .32229 3 0 ]

[1.025 .33479 0 -8 ]

[1.025 .33479 9 8 ]

[.4875 .09669 -12 -4.5 ]

[.4875 .09669 0 4.5 ]

[.4875 .21574 -24 -4.5 ]

[.4875 .21574 0 4.5 ]

[.4875 .45384 -18 -4.5 ]

[.4875 .45384 0 4.5 ]

[.4875 .57288 -6 -4.5 ]

[.4875 .57288 0 4.5 ]

[.4875 .69193 -18 -4.5 ]

[.4875 .69193 0 4.5 ]

[.4875 .81098 -6 -4.5 ]

[.4875 .81098 0 4.5 ]

[.5 .86972 -4.5 0 ]

[.5 .86972 4.5 16 ]

[.5 .85722 -134.5 0 ]

[.5 .85722 134.5 16 ]

[ 0 0 0 0 ]

[ 1 .84472 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .33479 m

.02381 .34104 L

s

[(-2)] .02381 .32229 0 1 Mshowa

.2619 .33479 m

.2619 .34104 L

s

[(-1)] .2619 .32229 0 1 Mshowa

.7381 .33479 m

.7381 .34104 L

s

[(1)] .7381 .32229 0 1 Mshowa

.97619 .33479 m

.97619 .34104 L

s

[(2)] .97619 .32229 0 1 Mshowa

.125 Mabswid

.07143 .33479 m

.07143 .33854 L

s

.11905 .33479 m

.11905 .33854 L

s

.16667 .33479 m

.16667 .33854 L

s

.21429 .33479 m

.21429 .33854 L

s

.30952 .33479 m

.30952 .33854 L

s

.35714 .33479 m

.35714 .33854 L

s

.40476 .33479 m

.40476 .33854 L

s

.45238 .33479 m

.45238 .33854 L

s

.54762 .33479 m

.54762 .33854 L

s

.59524 .33479 m

.59524 .33854 L

s

.64286 .33479 m

.64286 .33854 L

s

.69048 .33479 m

.69048 .33854 L

s

.78571 .33479 m

.78571 .33854 L

s

.83333 .33479 m

.83333 .33854 L

s

.88095 .33479 m

.88095 .33854 L

s

.92857 .33479 m

.92857 .33854 L

s

.25 Mabswid

0 .33479 m

1 .33479 L

s

gsave

1.025 .33479 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .09669 m

.50625 .09669 L

s

[(-1)] .4875 .09669 1 0 Mshowa

.5 .21574 m

.50625 .21574 L

s

[(-0.5)] .4875 .21574 1 0 Mshowa

.5 .45384 m

.50625 .45384 L

s

[(0.5)] .4875 .45384 1 0 Mshowa

.5 .57288 m

.50625 .57288 L

s

[(1)] .4875 .57288 1 0 Mshowa

.5 .69193 m

.50625 .69193 L

s

[(1.5)] .4875 .69193 1 0 Mshowa

.5 .81098 m

.50625 .81098 L

s

[(2)] .4875 .81098 1 0 Mshowa

.125 Mabswid

.5 .1205 m

.50375 .1205 L

s

.5 .14431 m

.50375 .14431 L

s

.5 .16812 m

.50375 .16812 L

s

.5 .19193 m

.50375 .19193 L

s

.5 .23955 m

.50375 .23955 L

s

.5 .26336 m

.50375 .26336 L

s

.5 .28717 m

.50375 .28717 L

s

.5 .31098 m

.50375 .31098 L

s

.5 .3586 m

.50375 .3586 L

s

.5 .38241 m

.50375 .38241 L

s

.5 .40622 m

.50375 .40622 L

s

.5 .43003 m

.50375 .43003 L

s

.5 .47765 m

.50375 .47765 L

s

.5 .50145 m

.50375 .50145 L

s

.5 .52526 m

.50375 .52526 L

s

.5 .54907 m

.50375 .54907 L

s

.5 .59669 m

.50375 .59669 L

s

.5 .6205 m

.50375 .6205 L

s

.5 .64431 m

.50375 .64431 L

s

.5 .66812 m

.50375 .66812 L

s

.5 .71574 m

.50375 .71574 L

s

.5 .73955 m

.50375 .73955 L

s

.5 .76336 m

.50375 .76336 L

s

.5 .78717 m

.50375 .78717 L

s

.5 .07288 m

.50375 .07288 L

s

.5 .04907 m

.50375 .04907 L

s

.5 .02526 m

.50375 .02526 L

s

.5 .00145 m

.50375 .00145 L

s

.5 .83479 m

.50375 .83479 L

s

.25 Mabswid

.5 0 m

.5 .84472 L

s

gsave

.5 .86972 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .85722 -195.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.38) show

293.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

298.000000 15.000000 moveto

(L) show

305.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

312.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

319.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

324.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

328.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .84472 L

0 .84472 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .16339 m

.02576 .16339 L

.03156 .1634 L

.04113 .16342 L

.05429 .16344 L

.07082 .16347 L

.09044 .16351 L

.11281 .16356 L

.13755 .16362 L

.16424 .16369 L

.19242 .16378 L

.2216 .16387 L

.2513 .16399 L

.28099 .16412 L

.31017 .16426 L

.33835 .16443 L

.36504 .16461 L

.38978 .16482 L

.41215 .16503 L

.43177 .16526 L

.44831 .16547 L

.46147 .16567 L

.47103 .16583 L

.47684 .16594 L

.47878 .16597 L

s

.47878 .16597 m

.47938 .16599 L

.48116 .16602 L

.4841 .16608 L

.48814 .16616 L

.49321 .16627 L

.49923 .16641 L

.5061 .16658 L

.51369 .16679 L

.52188 .16704 L

.53053 .16734 L

.53949 .16769 L

.5486 .1681 L

.55771 .16859 L

.56667 .16917 L

.57532 .16985 L

.58351 .17065 L

.5911 .1716 L

.59797 .17272 L

.60399 .17404 L

.60907 .1756 L

.6131 .17744 L

.61604 .1796 L

.61782 .18212 L

.61842 .18505 L

s

.47878 .41914 m

.47938 .40508 L

.48116 .39101 L

.4841 .37704 L

.48814 .36324 L

.49321 .34965 L

.49923 .33634 L

.5061 .32335 L

.51369 .31073 L

.52188 .29854 L

.53053 .28681 L

.53949 .27559 L

.5486 .26491 L

.55771 .25482 L

.56667 .24533 L

.57532 .23646 L

.58351 .22824 L

.5911 .22066 L

.59797 .21375 L

.60399 .20747 L

.60907 .20183 L

.6131 .19681 L

.61604 .19236 L

.61782 .18846 L

.61842 .18507 L

s

.47878 .41925 m

.47938 .4333 L

.48116 .44734 L

.4841 .46125 L

.48814 .47497 L

.49321 .48844 L

.49923 .50162 L

.5061 .51444 L

.51369 .52684 L

.52188 .53879 L

.53053 .55022 L

.53949 .56109 L

.5486 .57135 L

.55771 .58096 L

.56667 .58987 L

.57532 .59806 L

.58351 .60548 L

.5911 .6121 L

.59797 .6179 L

.60399 .62285 L

.60907 .62693 L

.6131 .63012 L

.61604 .6324 L

.61782 .63378 L

.61842 .63424 L

s

.61842 .63424 m

.61901 .63469 L

.62076 .63603 L

.62364 .63821 L

.6276 .64119 L

.63259 .64487 L

.6385 .64915 L

.64524 .65395 L

.6527 .65914 L

.66074 .66462 L

.66923 .67027 L

.67803 .67599 L

.68697 .68168 L

.69592 .68725 L

.70472 .69262 L

.71321 .6977 L

.72125 .70243 L

.72871 .70674 L

.73545 .71059 L

.74136 .71392 L

.74634 .71669 L

.75031 .71889 L

.75319 .72047 L

.75494 .72143 L

.75553 .72175 L

s

.75553 .1413 m

.75647 .1377 L

.75929 .13354 L

.76393 .12884 L

.77031 .12359 L

.77833 .11783 L

.78784 .11162 L

.79869 .10503 L

.81069 .09814 L

.82364 .09104 L

.8373 .08384 L

.85146 .07663 L

.86586 .06951 L

.88026 .06259 L

.89441 .05595 L

.90808 .04968 L

.92102 .04385 L

.93302 .03854 L

.94388 .03382 L

.95339 .02973 L

.96141 .02632 L

.96779 .02362 L

.97243 .02168 L

.97525 .02051 L

.97619 .02011 L

s

.75553 .14132 m

.75647 .1444 L

.75929 .14703 L

.76393 .14923 L

.77031 .15107 L

.77833 .15259 L

.78784 .15385 L

.79869 .15489 L

.81069 .15575 L

.82364 .15646 L

.8373 .15705 L

.85146 .15754 L

.86586 .15795 L

.88026 .15829 L

.89441 .15858 L

.90808 .15881 L

.92102 .15901 L

.93302 .15918 L

.94388 .15931 L

.95339 .15942 L

.96141 .1595 L

.96779 .15957 L

.97243 .15961 L

.97525 .15964 L

.97619 .15965 L

s

.75553 .72175 m

.75647 .72226 L

.75929 .72379 L

.76393 .7263 L

.77031 .72971 L

.77833 .73394 L

.78784 .73889 L

.79869 .74445 L

.81069 .75048 L

.82364 .75687 L

.8373 .76348 L

.85146 .7702 L

.86586 .7769 L

.88026 .78349 L

.89441 .78984 L

.90808 .79587 L

.92102 .8015 L

.93302 .80664 L

.94388 .81124 L

.95339 .81522 L

.96141 .81854 L

.96779 .82117 L

.97243 .82307 L

.97525 .82422 L

.97619 .8246 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<2074C003o4e8C00<04a<0L1<006@C1@3X4`0301<C070C001V4`0301<C0>PC00<04a<0

L1<003lC00<=4a<07Q<300<C00<04a<00Q<20>@C00<04a<0GA<23A4C00104`033A<C02<C00<04a<0

0Q<00`0C4`3S4`80G1<23A<C00104`033A<C02<C00<04a<00Q<00`0C4`3S4`0301<C05XC00<=4a<0

4a<0044C00<=4a<08A<200@C00<04a<0ha<00`0C4`1G4`<=5Q<0044C00<=4a<09a<20>@C00<04a<0

EA<23ATC00124`033A<C02HC00<04a<0ha<00`0C4`1B4`<=6a<004<C00<=4a<09A<00`0C4`3S4`80

D1<33AhC00134`033A<C02DC00<04a<0ha<00`0C4`1=4`8=8A<004@C00<=4a<091<20>@C00<04a<0

C1<00`dC4`0Q4`00AA<00`dC4`0S4`0301<C0><C00<04a<0BQ<23B@C00154`033A<C02<C00<04a<0

ha<00`0C4`184`8=9Q<004HC00<=4a<08Q<00`0C4`3S4`80Aa<23BPC00174`033A<C024C0P3T4`03

01<C04@C0PdZ4`00B1<00`dC4`0P4`0301<C0><C00<04a<0@Q<23B`C00184`033A<C020C00<04a<0

g1<5008C00<04a<0@1<23BhC00194`033A<C01lC00<04a<0gQ<00`0C4`024`0301<C03hC0Pd`4`00

BQ<00`dC4`0N4`80fA<300<C00<04a<00Q<203dC0Pdb4`00Ba<00`dC4`0M4`0301<C0=hC00<04a<0

0Q<00`0C4`0j4`8==1<004/C00<=4a<03Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`3N4`03

01<C008C00<04a<0>A<00`dC4`0d4`00C1<00`dC4`0<4`0301<000LC00<04`000a<00`0C4`3M4`80

11<00`0C4`0h4`033A<C03DC001=4`033A<C00HC0`024`0301<000TC00@04a<C0P3T4`0301<C03HC

0Pdh4`00CQ<00`dC4`0:4`0301<000LC0P044`0301<C0><C0P0e4`8=>Q<004hC00<=4a<02Q<00`0C

00074`0301<C00<C00<04a<0ha<00`0C4`0c4`033A<C03XC001?4`033A<C00XC00<04a<01Q<300<C

00<04a<0ha<00`0C4`0b4`033A<C03/C001@4`033A<C01PC00<04a<0ha<00`0C4`0a4`033A<C03`C

001A4`033A<C01LC0P3T4`80<Q<00`dC4`0l4`00DQ<00`dC4`0F4`0301<C0><C00<04a<0<Q<23C`C

001B4`033A<C01HC00<04a<0ha<00`0C4`0d4`D==a<005<C00<=4a<05A<00`0C4`3S4`0301<C03TC

8PdE4`00E1<00`dC4`0D4`80Pa<m3B@C00<04a<0Fa<43A4C001E4`033A<C01<C00<04a<0_a<c3F@C

000J4`<09A<500hC00<=4a<04a<00`0C4`0T4`D091<309<C00<04a<031<73EdC000J4`0301<C02LC

00<04a<03a<00`dC4`0B4`0301<C02HC00<04a<091<00`0C4`2C4`0301<C01<C0PeK4`005A<300<C

00<04a<081<300<C00<04a<041<00`dC4`0A4`809a<00`0C4`0U4`0301<C098C00<04a<05A<00`dC

4`1H4`006a<00`0C4`0V4`0301<C014C00<=4a<041<00`0C4`0V4`0301<C02DC00<04a<0TQ<00`0C

4`0E4`033A<C05PC000J4`0301<002LC00<04a<04A<00`dC4`0@4`0301<C02HC00<04a<091<00`0C

002C4`805Q<00`dC4`1H4`006a<00`0C4`0U4`8051<00`dC4`0?4`0301<C02DC0P0W4`0301<C098C

00<04a<051<00`dC4`1I4`00FQ<00`dC4`0>4`80i1<00`0C4`0C4`033A<C05XC001J4`033A<C00hC

00<04a<0e1<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`0B4`033A<C05/C001K4`033A<C00dC

00<04a<0Fa<207HC00<04`001a<00`0C00034`0301<C014C00<=4a<0G1<005`C00<=4a<031<00`0C

4`1J4`0301<C074C0`024`0301<000TC00@04a<C0P0B4`033A<C05`C000E4dP000<=0000HP064`03

01<C07HC00<04`001a<200@C00<04a<041<00`dC4`1M4`006A<00`0C4`064`0301<C00DC00<04a<0

1A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04`d01A<00`0C4`054`03

41<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<0

1Q<00`0C4`054`0301<C00DC00<04a<021<00`0C4`1f4`0301<000LC00<04a<00a<00`0C4`0?4`03

3A<C05hC001N4`033A<C00XC00<@4a<0FQ<00`0C001g4`0301<C00HC0`034`0301<C00hC00<=4a<0

Ga<005lC00<=4a<02A<245/C0`264`0301<C00`C0PeR4`00H1<00`dC4`084`8@i1<200`C00<=4a<0

HQ<0060C00<=4a<01a<00a00403T4`0301<C00/C00<=4a<0HQ<0064C00<=4a<01Q<00a00403T4`03

01<C00XC00<=4a<0Ha<0068C00<=4a<01A<00a00403T4`0301<C00TC00<=4a<0I1<006<C00<=4a<0

0a<01A0C000@0><C00<04a<021<00`dC4`1U4`00Ha<00`dC4`034`0541<04a00ha<200PC00<=4a<0

IQ<006@C00<=4a<00Q<01A0C01<@0><C00<04a<01Q<00`dC4`1W4`00IA<01`dC4a<@4`000Q<00a0C

4`3P4`0301<C00DC00<=4a<0J1<006HC00D=4a<@4`0200034a0C0>4C00<04a<011<00`dC4`1Y4`00

IQ<01PdC4a0C008C00<@4a<0P1<302dC1@0[4`0301<C00<C00<=4a<09A<502dC0`0@4`00Ia<01@d@

4a<000<C00<@4a<0Oa<00`0C4`0_4`0301<C02/C0P044`033A<C02LC00<04a<0;A<00`0C4`0@4`00

J1<010dC4`034`0341<C07XC0`034`0301<C02PC0`034`0301<C02/C00<04a<00Q<00`dC4`0X4`03

01<C02hC00<04a<03a<006PC00<=4a<00P024`0341<C080C00<04a<0;Q<00`0C4`0[4`0301<C008C

00<=4a<0:1<00`0C4`0^4`0301<C00lC001W4`0541<=4`0011<00a0C4`1n4`0301<002lC00<04a<0

:a<01@0C4a<=02/C00<04a<0;A<00`0C000@4`00G1<00`0C4`024`0301<C008C00H041<C3@044`03

41<C07lC00<04a<0;A<202dC0P000a<=4`0Z4`80<1<00`0C4`0?4`00Fa<00`0C00074`030100008C

00<=01<00a<00a0C4`3N4`0301<=070C001K4`0301<000PC00<@01<00Q<00`d04`034`0341<C0=dC

00<04`d0L1<005/C00<04`001a<00`0@4`034`0300dC00<C00<@4a<0gA<00`0=4`1/4`800Q<005/C

00<04`001a<00a0C4`034`0300dC00@C00<@4a<0g1<00`0=4`1[4`0301<C008C001L4`0301<C00HC

00<@00000a<00`0C3@044`0341<C07HCIP000`d0001T00LC00<04a<00Q<006@C00<@4a<011<20003

4`dC008C00<@4a<0Na<00`0C4`074`0301<C00HC00<04a<01a<00`0C4`074`0301<C00LC00<04a<0

1Q<00`0C4`074`0301<C00LC00<04a<01Q<00`0C4`074`033A<C00LC00<04a<01a<00`0C4`064`03

01<C00LC00<04a<01a<00`0C4`064`0301<C00LC00<04a<01a<00`0C4`064`0301<C00LC00<04a<0

2Q<00`0C4`024`00I1<00a0C4`044`0401<C3@@C00<@4a<0NQ<00`0C4`0^4`0301<C02`C00<=01<0

;a<00`0C4`0]4`0301<C00XC00<04`000Q<006<C00<@4a<01A<01@0C4a<=00<C00<@4a<0fQ<00`d0

4`1/4`<00Q<006<C00<@4a<01A<00`0C4`024`053A<C4a00fa<00`d04`1a4`00HQ<00a0C4`064`03

01<C00<C00@=4a<@fQ<010dC001a4`00HQ<00a0C4`064`8011<01@dC4a<@0=TC00<=4`00LQ<0064C

00<@4a<01a<00`0C4`044`043A<C4=TC00<=4`00LQ<0064C00<@4a<01a<00`0C4`054`033A<@0=PC

00@=4a<0LQ<0060C00<@4a<021<00`0C4`064`033A<@0=LC00@=4a<0LQ<0060C00<@4a<021<200LC

00<=4a00ea<00`dC4`02074C001O4`0341<C00TC00<04a<01a<00`dC403E4`053A<C4`00LQ<005lC

00<@4a<02A<00`0C4`084`033A0C0=@C00D=4a<C001b4`00GQ<00a0C4`0:4`0301<C00TC00<=41<0

da<01@dC4a<0078C001N4`0341<C00XC0P0:4`033A0C0=<C00D=4a<C001b4`00GA<00a0C4`0;4`03

01<C00XC00<=41<0dQ<010dC4a<2074C001M4`0341<C00@C1@024`0301<C00/C00<=4a<0dA<01@dC

4a<0078C001L4`0341<C00LC00<04a<00Q<00`0C4`0<4`033A<C0=0C00D=4a<C001b4`00Fa<00a0C

4`084`0301<C008C0P0=4`033A0C0=0C00D=4a<C001b4`00Fa<00a0C4`084`0301<C008C00<04a<0

3A<00`dC4`3?4`053A<C4`00LQ<005XC00<@4a<02A<00`0C4`024`0301<C00hC00<=4a<0cQ<010dC

4a<2074C001J4`0341<C00PC0P044`0301<C00hC00<=41<0cQ<01@dC4a<0078C001I4`0341<C00lC

0P0@4`033A<C0<8C00<04a<00Q<00`0C4`024`0300dC008C00<04a<0L1<005PC00<@4a<041<00`0C

4`0@4`033A<C0<0C00<04`001a<00`0C3@034`0301<C070C001H4`0341<C010C00<04a<04A<00`dC

4`2o4`0301<000TC00@=4a<C0P1a4`00Ea<00a0C4`0A4`0301<C014C00<=4a<0_a<00`0C00074`80

00DC3A<C001b4`00EQ<00a0C4`0B4`804a<00`dC4`2n4`0301<000LC00@04a<=0Q<00`0C4`1`4`00

EQ<00a0C4`0B4`0301<C01<C00<=4a<0_Q<00`0C4`064`<000@=4a<0LQ<005DC00<@4a<04a<00`0C

4`0C4`0340dC0</C00<=4`00LQ<005@C00<@4a<051<00`0C4`0D4`033A<C0<XC00@=4`00LA<005<C

00<@4a<05A<201DC00<@3A<0bQ<00`dC001b4`00Da<00a0C4`0E4`0301<C01DC00<@3A<0bQ<00`d0

4`1a4`00DQ<00a0C4`0F4`0301<C01HC00<@3A<0bA<00`d04`1a4`00DA<00a0C4`0G4`0301<C01HC

00<@3A<0bA<00`d04`1a4`00DA<00a0C4`0G4`8061<00a0=4`394`033@0C070C001@4`0341<C01PC

00<04a<05a<00a0C3@394`033A<C070C001?4`0341<C00PC1@024`0301<C008C00<04a<00Q<00`0C

4`0H4`0341<=0<PC00<03A<0L1<004lC00<@4a<02Q<00`0C4`064`0301<000<C00<04a<06A<00a0=

4`374`0300dC070C001>4`0341<C00/C00<04a<021<0100C4a<201/C00<@3A<0aQ<00`0C3@1`4`00

CA<00a0C4`0<4`0301<C00HC0P044`0301<C01XC00<@4`d0aQ<200034`dC06hC001<4`0341<C00dC

00<04a<01Q<00`0C4`034`0301<C01/C00<@3A<0aA<01@0C4a<=06hC001<4`0341<C00`C0P084`<0

0a<00`0C4`0L4`0340dC0<@C00D04a<C3@1^4`00Ba<00a0C4`0M4`807Q<00a0=4`334`0301<C008C

00<=4a<0Ja<004XC00<@4a<07Q<00`0C4`0M4`0340dC0<<C00<04a<00Q<00`dC4`1[4`00BQ<00a0C

4`0N4`0301<C01hC00<@3A<0`Q<200@C00<=4a<0JQ<004TC00<@4a<07a<00`0C4`0O4`0340dC0<4C

00<04a<011<00`dC4`1Y4`00B1<00a0C4`0P4`808A<00`dC4`304`0301<C00DC00<=4a<0J1<004LC

00<@4a<08A<00`0C4`0Q4`033A<C0;PC1@024`0301<C00HC00<=4a<0Ia<004LC00<@4a<08A<00`0C

4`0Q4`0340dC0;XC00<04a<00Q<00`0C4`074`033A<C06HC00164`0341<C028C00<04a<08Q<00`dC

4`2i4`0301<C008C0P094`033A<C06DC00154`0341<C02<C0P0T4`033A<C0;PC00<04a<00Q<00`0C

4`094`033A<C06@C00144`0341<C02@C00<04a<091<00`dC4`2g4`0301<C008C00<04a<02Q<00`dC

4`1S4`00A1<00a0C4`0T4`0301<C02@C00<@3A<0]Q<200@C00<04a<02a<00`dC4`1R4`00@a<00a0C

4`0U4`0301<C02DC00<=4a<0^a<00`0C4`0;4`033A<C068C00124`0341<C02HC00<04a<09Q<00`dC

4`2j4`803A<00`dC4`1Q4`00@A<00a0C4`0W4`80:1<00`dC4`2i4`0301<C00dC0PeQ4`00@1<00a0C

4`0X4`0301<C02PC00<=4a<0^1<00`0C4`0?4`033A<C05hC00104`0341<C028C0`034`0301<C02PC

00<=41<0^1<00`0C4`0@4`033A<C05dC000o4`0341<C02<C00<04a<00a<00`0C4`0Y4`033A<C0;LC

0P0B4`033A<C05`C000n4`0341<C02DC00<04a<00Q<202/C00<=4a<0]Q<00`0C4`0B4`033A<C05/C

000m4`0341<C02HC00<04a<00Q<00`0C4`0[4`033A<C0;DC00<04a<04a<23E/C000m4`0341<C02DC

00<04`000a<00`0C4`0[4`033A0C0;DC00<04a<05A<00`dC4`1H4`00?1<00a0C4`0W4`0301<C008C

00<04a<0;1<00`d@4`2d4`0301<C01HC00<=4a<0Ea<003/C00<@4a<0;A<202hC00<=41<0/a<201PC

0PeG4`00>Q<00a0C4`0^4`0301<C02hC00<=4a<0/Q<00`0C4`0I4`033A<C05@C000j4`0341<C02hC

00<04a<0;Q<00`d@4`2b4`0301<C01XC0PeD4`00>A<00a0C4`0_4`0301<C02lC00<=41<0/A<00`0C

4`0L4`033A<C054C000h4`0341<C030C0P0a4`033A0C0;0C00<04a<07A<23E4C000g4`0341<C034C

00<04a<0<1<00`d@4`2`4`8081<00`dC4`1>4`00=a<00a0C4`0a4`0301<C034C00<=41<0[a<00`0C

4`0P4`033A<C04dC000f4`0341<C038C00<04a<0<Q<00`d@4`2^4`0301<C024C00<=4a<0C1<003DC

00<@4a<0<a<203@C00<=41<0W1<5008C00<04a<00Q<00`0C4`024`0301<C028C0Pe<4`00=1<00a0C

4`0d4`0301<C03<C00<=4a00WQ<00`0C4`064`0301<000<C00<04a<091<23DXC000c4`0341<C03DC

00<04a<0=1<00`dC402M4`0301<C00PC00@04a<C0P0W4`8=B1<0038C00<@4a<0=Q<00`0C4`0e4`03

3A0C09`C00<04a<01Q<200@C00<04a<0:1<23DHC000a4`0341<C03LC0P0g4`033A0C09/C00<04a<0

1Q<00`0C4`034`0301<C02XC00<=4a<0@a<0030C00<@4a<0>1<00`0C4`0f4`033A<@09XC0P084`<0

0a<00`0C4`0[4`8=@a<002lC00<@4a<0:A<300<C00<04a<00Q<00`0C4`024`0301<C03LC00<=4a00

ZA<00`0C4`0]4`8=@A<002hC00<@4a<0:Q<00`0C4`074`0301<000<C00<04a<0>1<00`dC402X4`80

<1<00`dC4`0n4`00;A<00a0C4`0/4`0301<C00PC00@04a<C0P0j4`033A<@0:LC00<04a<0<1<23ChC

000/4`0341<C02dC00<04a<01Q<200@C00<04a<0>A<010dC4a2V4`0301<C038C0Pdl4`00:a<00a0C

4`0]4`0301<000LC00<04a<00a<00`0C4`0j4`043A<C4:DC00<04a<0=1<00`dC4`0i4`00:Q<00a0C

4`0_4`0301<C00HC0`034`0301<C03/C00@=4a<@Y1<00`0C4`0e4`8=>A<002TC00<@4a<0?a<203dC

00@=4a<@Xa<203PC0Pdg4`00:1<00a0C4`104`0301<C03`C00D=4a<C402R4`0301<C03TC0Pde4`00

9a<00a0C4`114`0301<C03dC00D=4a<C402Q4`0301<C03/C0`db4`009Q<00a0C4`124`0301<C03dC

00<=4a<00Q<00a0C4`2N4`0301<C03hC0Pd`4`009A<00a0C4`134`80?a<00`dC4`024`0341<C09dC

00<04a<0@1<23BhC000T4`0341<C04@C00<04a<0?a<00`dC4`024`0341<C09`C0P134`8=;1<002<C

00<@4a<0AA<00`0C4`0o4`033A<C00<C00<@4a<0Va<00`0C4`144`<=:A<002<C00<@4a<0AA<00`0C

4`104`033A<C00<C00<@4a<0VQ<00`0C4`174`8=9a<0028C00<@4a<0AQ<2044C00<=4a<011<00a0C

4`2I4`0301<C04TC0PdU4`008A<00a0C4`174`0301<C044C00<=4a<011<00a0C4`2H4`80C1<00`dC

4`0R4`0081<00a0C4`184`0301<C048C00<=4a<011<00a0C4`2G4`0301<C04`C0`dQ4`007a<00a0C

4`194`0301<C048C00<=4a<01A<00a0C4`2F4`0301<C04lC0`dN4`007Q<00a0C4`1:4`80A1<00`dC

4`054`0341<C08lC0`034`0301<C058C0PdL4`007A<00a0C4`1;4`0301<C04@C00<=4a<01A<00a0C

4`2>4`0301<C00<C00<04a<0E1<33ATC000L4`0341<C04`C00<04a<0AA<00`dC4`054`0341<C08hC

00<04a<00Q<205PC0PdG4`006a<00a0C4`174`8011<00`0C4`154`033A<C00HC00<@4a<0SA<00`0C

4`024`0301<C05TC0PdE4`006Q<00a0C4`1:4`0501<C4`00B1<00`dC4`064`0341<C08/C00<04`00

0a<00`0C4`1K4`8=4a<001TC00<@4a<0BQ<00`0C4`024`80B1<00`dC4`054`0341<C08`C00<04a<0

0Q<00`0C4`1M4`8=4A<006LC00<04a<0ia<00`0C4`1`4`00IA<00`0C003Y4`80LA<006HC00<04a<0

j1<00`0C4`1`4`00;1<30?lC8a<00`0C4`1`4`00;1<00`0C4`3o4iHC000]4`0301<C00DC00<04a<0

oa>=4`00;A<0100C4a<300044`0C4`<0oa>:4`00;1<00`0C00024`800Q<00`0C4`024`0301<C0?lC

R1<002dC00<04a<00a<0100C4`024`0301<C0?lCRA<003<C00@04a<00a<00`0C4`064`0301<C02DC

0`0]4`0301<C0?lC9a<001dC0`000a<0000200`C0`044`<021<00`0C4`0T4`0401<C014C0`000a<0

0002008C00<04a<00Q<00`0C4`024`0301<C00DC00@04a<C1@024`0401<C4`8011<00`0C4`044`80

ba<00`0C4`0b4`0301<C00PC000L4`0401<C02@C00<04a<08a<0100C4`0@4`0401<C00HC00<04`00

1a<00`0C00044`D00a<00`0C4`084`0601<C01<011<00`0C4`334`0301<C00@C00<04a<04a<00`0C

4`0N4`0301<C00LC000L4`0501<C01<010000a<0000H02/C0`0@4`0501<C01<0100011<04`094`03

01<C00@C00<04a<00a<00`0C4`074`0701<C4`0C00044`0301<C0;4C00@04a<C10024`801Q<00`0C

4`034`0301<C008C00<04a<00Q<00`0C4`024`0301<C00DC00@04a<C1@024`0401<C4`8011<00`0C

4`044`8011<0100C4a<2004C0@0100007A<304dC00<04a<03a<300HC00<04`001a<200LC00<04a<0

0a<00`0C4`084`0501<C4`001A<00`0C4`2`4`0301<000LC00<04a<011<500<C00L04a<C01<000LC

00<04`0011<500<C00<04a<021<01P0C4`0C00@C00<04a<011<00`0C4`024`0301<0004C000O4`03

01<C04XC0P0C4`0301<C00@C00<04`001a<00`0C4`0<4`0301<C00HC00<04`000Q<00`0C00044`03

01<009HC0P000a<0000E4`0301<0008C10000a<04`074`0301<C00<C00L04a<C01<000TC00<04a<0

11<00`0C4`034`0301<C00LC00L04a<C01<000@C00<04a<011<00`0C4`034`400A<14`007Q<2060C

0P074`0301<C00HC0`0;4`802A<00`0C4`024`0301<C00<C0`2G4`0301<001HC00<04`001a<00`0C

4`064`0301<C00<C00L04a<C01<000LC0P074`0301<C00<C00<04a<021<01@0C4a<000DC00<04a<0

11<00`0C4`034`400A<14`00oa=B4`0301<C01DC00<04`001a<00`0C000=4`0601<C01<01a<00`0C

4`0<4`0301<C00HC00<04`000Q<00`0C00044`0301<000<C00<04a<00a<00`0C00014`00:A<200HC

0P3o4alC00<04a<05Q<00`0C4`064`<03Q<0100C4`084`<02a<200TC00<04a<00Q<00`0C4`034`<0

0Q<00`0C4`034`800A<10040000[4`0301<C008C00<04a<0oa<N4`0301<0074C000Z4`0301<C00<C

00<04a<01A<00`0C4`3o4aDC0P000a<0001`4`00:a<00`0C4`024`0301<C008C10034`<0oa>64`00

:A<00`0C00044`0301<0008C0P000a<04`044`0301<C0?lCQ1<002XC00<04a<00a<300@C00<04`00

0a<00`0C4`3o4hDC000g4`0301<000@C00<04a<0oa>44`00=A<300@C0`3o4hHC003o4lDC003o4lDC

003o4lDC003o4lDC003o4lDC0000\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-6.95686, -1.51549, 0.0206072, 0.0206072}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -84.5 0 ]

[.5 .96488 84.5 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -145.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.375) show

222.250000 19.500000 moveto

(C) show

227.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.24026 0 m

.26171 .02949 L

.30316 .08648 L

.34309 .14138 L

.3815 .1942 L

.42237 .2504 L

.46172 .3045 L

.49955 .35653 L

.53984 .41192 L

.57861 .46523 L

.61984 .52192 L

.65954 .57652 L

.69774 .62903 L

.73838 .68492 L

.77751 .73872 L

.81909 .7959 L

.85916 .85099 L

.89771 .904 L

s

.89771 .904 m

.9329 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.333132 0.238095 [

[.02381 .32063 -6 -9 ]

[.02381 .32063 6 0 ]

[.2619 .32063 -6 -9 ]

[.2619 .32063 6 0 ]

[.7381 .32063 -3 -9 ]

[.7381 .32063 3 0 ]

[.97619 .32063 -3 -9 ]

[.97619 .32063 3 0 ]

[1.025 .33313 0 -8 ]

[1.025 .33313 9 8 ]

[.4875 .09504 -12 -4.5 ]

[.4875 .09504 0 4.5 ]

[.4875 .21408 -24 -4.5 ]

[.4875 .21408 0 4.5 ]

[.4875 .45218 -18 -4.5 ]

[.4875 .45218 0 4.5 ]

[.4875 .57123 -6 -4.5 ]

[.4875 .57123 0 4.5 ]

[.4875 .69028 -18 -4.5 ]

[.4875 .69028 0 4.5 ]

[.4875 .80932 -6 -4.5 ]

[.4875 .80932 0 4.5 ]

[.5 .86749 -4.5 0 ]

[.5 .86749 4.5 16 ]

[.5 .85499 -137 0 ]

[.5 .85499 137 16 ]

[ 0 0 0 0 ]

[ 1 .84249 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .33313 m

.02381 .33938 L

s

[(-2)] .02381 .32063 0 1 Mshowa

.2619 .33313 m

.2619 .33938 L

s

[(-1)] .2619 .32063 0 1 Mshowa

.7381 .33313 m

.7381 .33938 L

s

[(1)] .7381 .32063 0 1 Mshowa

.97619 .33313 m

.97619 .33938 L

s

[(2)] .97619 .32063 0 1 Mshowa

.125 Mabswid

.07143 .33313 m

.07143 .33688 L

s

.11905 .33313 m

.11905 .33688 L

s

.16667 .33313 m

.16667 .33688 L

s

.21429 .33313 m

.21429 .33688 L

s

.30952 .33313 m

.30952 .33688 L

s

.35714 .33313 m

.35714 .33688 L

s

.40476 .33313 m

.40476 .33688 L

s

.45238 .33313 m

.45238 .33688 L

s

.54762 .33313 m

.54762 .33688 L

s

.59524 .33313 m

.59524 .33688 L

s

.64286 .33313 m

.64286 .33688 L

s

.69048 .33313 m

.69048 .33688 L

s

.78571 .33313 m

.78571 .33688 L

s

.83333 .33313 m

.83333 .33688 L

s

.88095 .33313 m

.88095 .33688 L

s

.92857 .33313 m

.92857 .33688 L

s

.25 Mabswid

0 .33313 m

1 .33313 L

s

gsave

1.025 .33313 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .09504 m

.50625 .09504 L

s

[(-1)] .4875 .09504 1 0 Mshowa

.5 .21408 m

.50625 .21408 L

s

[(-0.5)] .4875 .21408 1 0 Mshowa

.5 .45218 m

.50625 .45218 L

s

[(0.5)] .4875 .45218 1 0 Mshowa

.5 .57123 m

.50625 .57123 L

s

[(1)] .4875 .57123 1 0 Mshowa

.5 .69028 m

.50625 .69028 L

s

[(1.5)] .4875 .69028 1 0 Mshowa

.5 .80932 m

.50625 .80932 L

s

[(2)] .4875 .80932 1 0 Mshowa

.125 Mabswid

.5 .11885 m

.50375 .11885 L

s

.5 .14266 m

.50375 .14266 L

s

.5 .16647 m

.50375 .16647 L

s

.5 .19028 m

.50375 .19028 L

s

.5 .23789 m

.50375 .23789 L

s

.5 .2617 m

.50375 .2617 L

s

.5 .28551 m

.50375 .28551 L

s

.5 .30932 m

.50375 .30932 L

s

.5 .35694 m

.50375 .35694 L

s

.5 .38075 m

.50375 .38075 L

s

.5 .40456 m

.50375 .40456 L

s

.5 .42837 m

.50375 .42837 L

s

.5 .47599 m

.50375 .47599 L

s

.5 .4998 m

.50375 .4998 L

s

.5 .52361 m

.50375 .52361 L

s

.5 .54742 m

.50375 .54742 L

s

.5 .59504 m

.50375 .59504 L

s

.5 .61885 m

.50375 .61885 L

s

.5 .64266 m

.50375 .64266 L

s

.5 .66647 m

.50375 .66647 L

s

.5 .71408 m

.50375 .71408 L

s

.5 .73789 m

.50375 .73789 L

s

.5 .7617 m

.50375 .7617 L

s

.5 .78551 m

.50375 .78551 L

s

.5 .07123 m

.50375 .07123 L

s

.5 .04742 m

.50375 .04742 L

s

.5 .02361 m

.50375 .02361 L

s

.5 .83313 m

.50375 .83313 L

s

.25 Mabswid

.5 0 m

.5 .84249 L

s

gsave

.5 .86749 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .85499 -198 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.375) show

298.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

303.000000 15.000000 moveto

(L) show

310.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

317.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

324.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

329.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

333.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .84249 L

0 .84249 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .16128 m

.02576 .16129 L

.03156 .1613 L

.04112 .16132 L

.05429 .16135 L

.07082 .16138 L

.09044 .16143 L

.11281 .16149 L

.13755 .16155 L

.16423 .16164 L

.19241 .16173 L

.22159 .16184 L

.25128 .16197 L

.28098 .16212 L

.31016 .16229 L

.33833 .16248 L

.36502 .16269 L

.38976 .16292 L

.41213 .16317 L

.43175 .16343 L

.44828 .16368 L

.46144 .1639 L

.47101 .16409 L

.47681 .16421 L

.47876 .16425 L

s

.47876 .16425 m

.47934 .16426 L

.48109 .1643 L

.48397 .16437 L

.48793 .16446 L

.49291 .16458 L

.49882 .16474 L

.50556 .16493 L

.513 .16516 L

.52104 .16544 L

.52952 .16577 L

.53831 .16616 L

.54725 .16662 L

.55619 .16715 L

.56498 .16779 L

.57346 .16853 L

.5815 .1694 L

.58895 .17042 L

.59568 .17163 L

.60159 .17304 L

.60657 .17469 L

.61053 .17663 L

.61341 .17888 L

.61516 .18151 L

.61574 .18453 L

s

.47876 .41752 m

.47934 .4036 L

.48109 .38967 L

.48397 .37584 L

.48793 .36217 L

.49291 .34872 L

.49882 .33553 L

.50556 .32265 L

.513 .31015 L

.52104 .29805 L

.52952 .28642 L

.53831 .27528 L

.54725 .26467 L

.55619 .25463 L

.56498 .24518 L

.57346 .23634 L

.5815 .22813 L

.58895 .22056 L

.59568 .21362 L

.60159 .20732 L

.60657 .20163 L

.61053 .19654 L

.61341 .19202 L

.61516 .18803 L

.61574 .18456 L

s

.47876 .41763 m

.47934 .43153 L

.48109 .44542 L

.48397 .45919 L

.48793 .47276 L

.49291 .48609 L

.49882 .49913 L

.50556 .51181 L

.513 .52409 L

.52104 .5359 L

.52952 .54721 L

.53831 .55796 L

.54725 .56811 L

.55619 .57761 L

.56498 .58643 L

.57346 .59453 L

.5815 .60186 L

.58895 .60842 L

.59568 .61415 L

.60159 .61904 L

.60657 .62308 L

.61053 .62623 L

.61341 .6285 L

.61516 .62986 L

.61574 .63031 L

s

.61574 .63031 m

.61638 .6308 L

.61827 .63226 L

.62139 .63464 L

.62567 .63787 L

.63106 .64187 L

.63745 .64651 L

.64474 .6517 L

.6528 .65731 L

.6615 .66321 L

.67068 .66929 L

.68019 .67544 L

.68986 .68155 L

.69954 .68752 L

.70905 .69326 L

.71823 .69869 L

.72692 .70373 L

.73498 .70834 L

.74227 .71243 L

.74867 .71598 L

.75405 .71894 L

.75834 .72127 L

.76146 .72296 L

.76335 .72397 L

.76398 .72431 L

s

.76398 .13753 m

.76489 .13392 L

.7676 .12979 L

.77206 .12514 L

.7782 .12 L

.78591 .11438 L

.79506 .10834 L

.80549 .10194 L

.81703 .09528 L

.82948 .08842 L

.84262 .08147 L

.85624 .07452 L

.87009 .06766 L

.88394 .06099 L

.89755 .05459 L

.91069 .04855 L

.92314 .04294 L

.93468 .03783 L

.94511 .03327 L

.95426 .02933 L

.96198 .02604 L

.96811 .02344 L

.97258 .02157 L

.97528 .02044 L

.97619 .02006 L

s

.76398 .13755 m

.76489 .14068 L

.7676 .14336 L

.77206 .14564 L

.7782 .14755 L

.78591 .14916 L

.79506 .1505 L

.80549 .15162 L

.81703 .15255 L

.82948 .15333 L

.84262 .15398 L

.85624 .15453 L

.87009 .15498 L

.88394 .15537 L

.89755 .15569 L

.91069 .15596 L

.92314 .15618 L

.93468 .15637 L

.94511 .15652 L

.95426 .15665 L

.96198 .15674 L

.96811 .15682 L

.97258 .15687 L

.97528 .1569 L

.97619 .15691 L

s

.76398 .72431 m

.76489 .7248 L

.7676 .72625 L

.77206 .72862 L

.7782 .73185 L

.78591 .73586 L

.79506 .74056 L

.80549 .74583 L

.81703 .75157 L

.82948 .75764 L

.84262 .76394 L

.85624 .77035 L

.87009 .77675 L

.88394 .78304 L

.89755 .78911 L

.91069 .79489 L

.92314 .80027 L

.93468 .8052 L

.94511 .8096 L

.95426 .81342 L

.96198 .81661 L

.96811 .81914 L

.97258 .82096 L

.97528 .82206 L

.97619 .82243 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<00`0C4`1`4`00oa=B4`0301<C070C001T4`D0j1<00`0C4`1`4`00IQ<00`0C4`3X4`03

01<C070C000o4`033A<C01hC0`034`0301<C008C0P3T4`0301<C05hC00<=4a<03a<0040C00<=4a<0

8a<00`0C4`024`0301<C0><C0P1N4`033A<C010C00104`033A<C02<C00<04a<00Q<00`0C4`3S4`03

01<C05XC0`dC4`00@A<00`dC4`0Q4`8011<00`0C4`3S4`0301<C05PC0PdF4`00@A<00`dC4`0W4`80

i1<00`0C4`1E4`<=61<0048C00<=4a<09Q<00`0C4`3S4`0301<C05<C0PdK4`00@a<00`dC4`0U4`03

01<C0><C0P1A4`<=7A<004<C00<=4a<09A<00`0C4`3S4`0301<C04hC0PdP4`00A1<00`dC4`0T4`80

i1<00`0C4`1<4`8=8Q<004DC00<=4a<08a<00`0C4`3S4`0301<C04/C00<=4a<08Q<004DC00<=4a<0

8a<00`0C4`3S4`0301<C04PC0`dU4`00AQ<00`dC4`0R4`0301<C0><C0P174`8=:1<004LC00<=4a<0

8A<20>@C00<04a<0A1<23BXC00184`033A<C020C00<04a<0ha<00`0C4`124`8=;1<004PC00<=4a<0

81<00`0C4`3L4`D00Q<00`0C4`104`8=;Q<004TC00<=4a<07a<00`0C4`3N4`0301<C008C00<04a<0

?a<00`dC4`0^4`00BQ<00`dC4`0N4`80fA<300<C00<04a<00Q<203hC0Pda4`00Ba<00`dC4`0M4`03

01<C0=hC00<04a<00Q<00`0C4`0k4`8=<a<004/C00<=4a<03Q<00`0C4`024`0301<C008C00<04a<0

0Q<00`0C4`3N4`0301<C008C00<04a<0>A<23CDC001<4`033A<C00`C00<04`001a<00`0C00034`03

01<C0=dC0P044`0301<C03PC00<=4a<0=A<004dC00<=4a<01Q<3008C00<04`002A<0100C4a<20>@C

0P0h4`033A<C03HC001>4`033A<C00XC00<04`001a<200@C00<04a<0ha<00`0C4`0f4`033A<C03LC

001>4`033A<C00XC00<04`001a<00`0C4`034`0301<C0><C00<04a<0=A<00`dC4`0h4`00Ca<00`dC

4`0:4`0301<C00HC0`034`0301<C0><C00<04a<0=1<00`dC4`0i4`00D1<00`dC4`0H4`0301<C0><C

00<04a<0<a<00`dC4`0j4`00DA<00`dC4`0G4`80i1<203@C0Pdk4`00DQ<00`dC4`0F4`0301<C0><C

00<04a<0=A<23CTC001B4`033A<C01HC00<04a<0ha<00`0C4`0g4`/=;Q<005<C00<=4a<05A<00`0C

4`3S4`0301<C048C7@dA4`00E1<00`dC4`0D4`80Pa=A3A0C00<04a<0L1<005DC00<=4a<04a<00`0C

4`3C4ah=IA<001XC0`0U4`D03Q<00`dC4`0C4`0301<C02@C1@0T4`<0Ta<00`0C4`0;4`P=GA<001XC

00<04a<09a<00`0C4`0?4`033A<C018C00<04a<09Q<00`0C4`0T4`0301<C09<C00<04a<04a<23E/C

000E4`<00a<00`0C4`0P4`<00a<00`0C4`0@4`033A<C014C0P0W4`0301<C02DC00<04a<0TQ<00`0C

4`0D4`8=FQ<001/C00<04a<09Q<00`0C4`0A4`033A<C010C00<04a<09Q<00`0C4`0U4`0301<C098C

00<04a<05A<00`dC4`1H4`006Q<00`0C000W4`0301<C014C00<=4a<041<00`0C4`0V4`0301<C02@C

00<04`00Ta<201DC0PeJ4`006a<00`0C4`0U4`8051<00`dC4`0?4`0301<C02DC0P0W4`0301<C098C

00<04a<051<00`dC4`1I4`00FQ<00`dC4`0>4`80i1<00`0C4`0C4`033A<C05XC001J4`033A<C00hC

00<04a<0e1<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`0B4`033A<C05/C001K4`033A<C00dC

00<04a<0Fa<207HC00<04`001a<00`0C00034`0301<C014C00<=4a<0G1<005`C00<=4a<031<00`0C

4`1J4`0301<C074C0`024`0301<000TC00@04a<C0P0B4`033A<C05`C000E4dP000<=0000HP064`03

01<C07HC00<04`001a<200@C00<04a<03a<23ElC000I4`0301<C00HC00<04a<01A<00`0C4`054`03

01<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C3@054`0301<C00DC00<@4a<0

1A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`03

01<C00DC00<04a<01A<00`0C4`084`0301<C07HC00<04`001a<00`0C4`034`0301<C00hC00<=4a<0

Ga<005hC00<=4a<02Q<00a0C4`1J4`0301<007LC00<04a<01Q<300<C00<04a<03Q<00`dC4`1O4`00

Ga<00`dC4`094`8@Fa<308HC00<04a<031<23F8C001P4`033A<C00PC0Q3T4`8031<00`dC4`1R4`00

H1<00`dC4`074`03400@0>@C00<04a<02Q<00`dC4`1S4`00HA<00`dC4`064`03400@0>@C00<04a<0

2A<00`dC4`1T4`00HQ<00`dC4`054`03400@0>@C00<04a<02A<00`dC4`1T4`00Ha<00`dC4`034`05

41<00100ha<00`0C4`084`033A<C06DC001S4`033A<C00<C00D@4`0C403S4`8021<00`dC4`1V4`00

I1<00`dC4`024`0541<04a00ha<00`0C4`064`033A<C06LC001U4`073A<C4a0C00024`0341<C0>0C

00<04a<01A<00`dC4`1X4`00IQ<01@dC4a0C008000<C41<0hA<00`0C4`044`033A<C06TC001V4`06

3A<C41<00Q<00a0C4`204`<0;A<502/C0P054`033A<C02@C1@0]4`<041<006LC00D=41<C00034`03

41<C07lC00<04a<0;a<00`0C4`0[4`0301<C00<C00<=4a<09a<00`0C4`0]4`0301<C010C001X4`04

3A<C00<C00<@4a<0NQ<300<C00<04a<0:1<300<C00<04a<0:a<00`0C4`024`033A<C02PC00<04a<0

;Q<00`0C4`0?4`00J1<00`dC4`02008C00<@4a<0P1<00`0C4`0^4`0301<C02/C00D04a<C3@0[4`03

01<C02hC00<04a<03a<006LC00D@4`dC00044`0341<C07hC00<04`00;a<00`0C4`0[4`0401<C3B`C

00<04a<0;A<00`0C000@4`00G1<00`0C4`024`0301<C008C00H041<C3@044`0341<C07lC00<04a<0

;A<202dC0P000a<=4`0Z4`80<1<00`0C4`0?4`00Fa<00`0C00074`030100008C00<=01<00a<00a0C

4`3N4`0301<=070C001K4`0301<000PC00<@01<00Q<00`d04`034`0341<C0=dC00<04`d0L1<005/C

00<04`001a<00`0@4`034`0300dC00<C00<@4a<0gA<00`0=4`1/4`800Q<005/C00<04`001a<00a0C

4`034`0300dC00@C00<@4a<0g1<00`0=4`1[4`0301<C008C001L4`0301<C00HC00<@00000a<00`0C

3@044`0341<C07HCIP000`d0001T00LC00<04a<00Q<006@C00<@4a<011<200034`dC008C00<@4a<0

Na<00`0C4`074`0301<C00HC00<04a<01a<00`0C4`074`0301<C00LC00<04a<01Q<00`0C4`074`03

01<C00LC00<04a<01Q<00`0C4`074`033A<C00LC00<04a<01a<00`0C4`064`0301<C00LC00<04a<0

1a<00`0C4`064`0301<C00LC00<04a<01a<00`0C4`064`0301<C00LC00<04a<02Q<00`0C4`024`00

I1<00a0C4`044`0401<C3@@C00<@4a<0fQ<00`d04`1/4`0301<0008C001S4`0341<C00DC00D04a<C

3@034`0341<C0=XC00<=01<0K1<3008C001S4`0341<C00DC00<04a<00Q<01@dC4a<@0=/C00<=01<0

LA<0068C00<@4a<01Q<00`0C4`034`043A<C4=XC00@=4`00LA<0068C00<@4a<01Q<200@C00D=4a<C

403I4`033A<0078C001Q4`0341<C00LC00<04a<011<010dC4a3I4`033A<0078C001Q4`0341<C00LC

00<04a<01A<00`dC403H4`043A<C078C001P4`0341<C00PC00<04a<01Q<00`dC403G4`043A<C078C

001P4`0341<C00PC0P074`033A<@0=LC00<=4a<00P1a4`00Ga<00a0C4`094`0301<C00LC00<=4a00

eA<01@dC4a<0078C001O4`0341<C00TC00<04a<021<00`d@4`3D4`053A<C4`00LQ<005hC00<@4a<0

2Q<00`0C4`094`033A0C0=<C00D=4a<C001b4`00GQ<00a0C4`0:4`802Q<00`d@4`3C4`053A<C4`00

LQ<005dC00<@4a<02a<00`0C4`0:4`033A0C0=8C00@=4a<C0P1a4`00GA<00a0C4`044`D00Q<00`0C

4`0;4`033A<C0=4C00D=4a<C001b4`00G1<00a0C4`074`0301<C008C00<04a<031<00`dC4`3@4`05

3A<C4`00LQ<005/C00<@4a<021<00`0C4`024`803A<00`d@4`3@4`053A<C4`00LQ<005/C00<@4a<0

21<00`0C4`024`0301<C00dC00<=4a<0ca<01@dC4a<0078C001J4`0341<C00TC00<04a<00Q<00`0C

4`0>4`033A<C0<hC00@=4a<C0P1a4`00FQ<00a0C4`084`8011<00`0C4`0>4`033A0C0<hC00D=4a<C

001b4`00FA<00a0C4`0?4`8041<00`dC4`324`0301<C008C00<04a<00Q<00`0=4`024`0301<C070C

001H4`0341<C010C00<04a<041<00`dC4`304`0301<000LC00<04`d00a<00`0C4`1`4`00F1<00a0C

4`0@4`0301<C014C00<=4a<0_a<00`0C00094`043A<C4`80LA<005LC00<@4a<04A<00`0C4`0A4`03

3A<C0;lC00<04`001a<200054`dC4`00LQ<005HC00<@4a<04Q<201<C00<=4a<0_Q<00`0C00074`04

01<C3@8C00<04a<0L1<005HC00<@4a<04Q<00`0C4`0C4`033A<C0;hC00<04a<01Q<300043A<C078C

001E4`0341<C01<C00<04a<04a<00a0=4`3;4`033A<0078C001D4`0341<C01@C00<04a<051<00`dC

4`3:4`043A<0074C001C4`0341<C01DC0P0E4`0340dC0<XC00<=4`00LQ<005<C00<@4a<05A<00`0C

4`0E4`0340dC0<XC00<=01<0LA<0058C00<@4a<05Q<00`0C4`0F4`0340dC0<TC00<=01<0LA<0054C

00<@4a<05a<00`0C4`0F4`0340dC0<XC00<=4a<0L1<0054C00<@4a<05a<201PC00<@3A<0bA<00`d0

4`1`4`00D1<00a0C4`0H4`0301<C01LC00<@4`d0bA<00`dC4`1`4`00Ca<00a0C4`084`D00Q<00`0C

4`024`0301<C008C00<04a<061<00a0C3@384`0300dC070C001?4`0341<C00XC00<04a<01Q<00`0C

00034`0301<C01TC00<@3A<0aa<00`0=4`1`4`00CQ<00a0C4`0;4`0301<C00PC00@04a<C0P0K4`03

40dC0<HC00<04`d0L1<004dC00<@4a<031<00`0C4`064`8011<00`0C4`0J4`0341<=0<HC0P000a<=

4`1^4`00C1<00a0C4`0=4`0301<C00HC00<04a<00a<00`0C4`0K4`0340dC0<DC00@04a<=Ka<004`C

00<@4a<031<200PC0`034`0301<C01`C00<@3A<0a1<01@0C4a<=06hC001;4`0341<C01dC0P0N4`03

40dC0<<C00<04a<00Q<00`dC4`1[4`00BQ<00a0C4`0N4`0301<C01dC00<@3A<0`a<00`0C4`024`03

3A<C06/C001:4`0341<C01hC00<04a<07Q<00a0=4`324`8011<00`dC4`1Z4`00BA<00a0C4`0O4`03

01<C01lC00<@3A<0`A<00`0C4`044`033A<C06TC00184`0341<C020C0P0Q4`033A<C0<0C00<04a<0

1A<00`dC4`1X4`00Aa<00a0C4`0Q4`0301<C024C00<=4a<0^1<5008C00<04a<01Q<00`dC4`1W4`00

Aa<00a0C4`0Q4`0301<C024C00<@3A<0^Q<00`0C4`024`0301<C00LC00<=4a<0IQ<004HC00<@4a<0

8Q<00`0C4`0R4`033A<C0;TC00<04a<00Q<200TC00<=4a<0IA<004DC00<@4a<08a<202@C00<=4a<0

^1<00`0C4`024`0301<C00TC00<=4a<0I1<004@C00<@4a<091<00`0C4`0T4`033A<C0;LC00<04a<0

0Q<00`0C4`094`033A<C06@C00144`0341<C02@C00<04a<091<00a0=4`2f4`8011<00`0C4`0:4`03

3A<C06<C00134`0341<C02DC00<04a<09A<00`dC4`2k4`8031<23F<C00124`0341<C02HC00<04a<0

9Q<00`dC4`2j4`0301<C00dC00<=4a<0H1<0044C00<@4a<09a<202PC00<=4a<0^A<00`0C4`0>4`03

3A<C05lC00104`0341<C02PC00<04a<0:1<00`dC4`2h4`0301<C00lC00<=4a<0GQ<0040C00<@4a<0

8Q<300<C00<04a<0:1<00`d@4`2h4`0301<C010C0PeN4`00?a<00a0C4`0S4`0301<C00<C00<04a<0

:A<00`dC4`2g4`804a<00`dC4`1K4`00?Q<00a0C4`0U4`0301<C008C0P0[4`033A<C0;HC00<04a<0

4a<00`dC4`1J4`00?A<00a0C4`0V4`0301<C008C00<04a<0:a<00`dC4`2e4`0301<C01@C00<=4a<0

FA<003dC00<@4a<09A<00`0C00034`0301<C02/C00<=41<0]A<00`0C4`0E4`033A<C05PC000l4`03

41<C02LC00<04a<00Q<00`0C4`0/4`033A0C0;@C00<04a<05Q<23EPC000k4`0341<C02dC0P0^4`03

3A0C0;<C0P0I4`033A<C05DC000j4`0341<C02hC00<04a<0;Q<00`dC4`2b4`0301<C01TC00<=4a<0

E1<003XC00<@4a<0;Q<00`0C4`0^4`033A0C0;8C00<04a<06Q<23E@C000i4`0341<C02lC00<04a<0

;a<00`d@4`2a4`0301<C01`C00<=4a<0DA<003PC00<@4a<0<1<2034C00<=41<0/1<00`0C4`0M4`8=

DA<003LC00<@4a<0<A<00`0C4`0`4`033A0C0;0C0P0P4`033A<C04hC000g4`0341<C034C00<04a<0

<A<00`d@4`2_4`0301<C020C00<=4a<0CA<003HC00<@4a<0<Q<00`0C4`0b4`033A0C0:hC00<04a<0

8A<23DdC000e4`0341<C03<C0P0d4`033A0C09`C1@024`0301<C008C00<04a<00Q<00`0C4`0S4`8=

Ba<003@C00<@4a<0=1<00`0C4`0c4`033A<@09hC00<04a<01Q<00`0C00034`0301<C02DC0Pe94`00

<a<00a0C4`0e4`0301<C03@C00<=4a00WA<00`0C4`084`0401<C4`80:1<00`dC4`164`00<Q<00a0C

4`0f4`0301<C03DC00<=41<0W1<00`0C4`064`8011<00`0C4`0X4`033A<C04DC000a4`0341<C03LC

0P0g4`033A0C09/C00<04a<01Q<00`0C4`034`0301<C02TC0Pe54`00<1<00a0C4`0h4`0301<C03HC

00<=4a00VQ<200PC0`034`0301<C02/C00<=4a<0@Q<002lC00<@4a<0:A<300<C00<04a<00Q<00`0C

4`024`0301<C03LC00<=4a00ZA<00`0C4`0/4`<=@A<002hC00<@4a<0:Q<00`0C4`074`0301<000<C

00<04a<0>1<00`dC402X4`80<1<23ClC000]4`0341<C02`C00<04a<021<0100C4a<203XC00<=4a00

Ya<00`0C4`0a4`8=?A<002`C00<@4a<0;A<00`0C4`064`8011<00`0C4`0i4`043A<C4:HC00<04a<0

<Q<33C/C000[4`0341<C02dC00<04`001a<00`0C4`034`0301<C03XC00@=4a<@YA<00`0C4`0e4`8=

>A<002XC00<@4a<0;a<00`0C4`064`<00a<00`0C4`0k4`043A<C4:@C00<04a<0=a<00`dC4`0f4`00

:A<00a0C4`0o4`80?A<010dC4a2S4`80>A<23CHC000X4`0341<C040C00<04a<0?1<01@dC4a<@0:8C

00<04a<0>Q<33C<C000W4`0341<C044C00<04a<0?A<01@dC4a<@0:4C00<04a<0?A<23C4C000V4`03

41<C048C00<04a<0?Q<01@dC4a<@0:0C00<04a<0?a<00`dC4`0^4`009A<00a0C4`134`80?a<00`dC

4`024`0341<C09dC0P114`8=;Q<002@C00<@4a<0A1<00`0C4`0o4`033A<C008C00<@4a<0W1<00`0C

4`124`<=:a<002<C00<@4a<0AA<00`0C4`104`033A<C008C00<@4a<0Va<00`0C4`154`8=:A<002<C

00<@4a<0AA<00`0C4`104`033A<C00<C00<@4a<0VQ<00`0C4`174`8=9a<0028C00<@4a<0AQ<2048C

00<=4a<00a<00a0C4`2I4`0301<C04TC00<=4a<091<0024C00<@4a<0Aa<00`0C4`124`033A<C00<C

00<@4a<0V1<204/C0`dS4`0081<00a0C4`184`0301<C048C00<=4a<011<00a0C4`2G4`0301<C04dC

0`dP4`007a<00a0C4`194`0301<C04<C00<=4a<011<00a0C4`2F4`0301<C050C0PdN4`007Q<00a0C

4`1:4`80AA<00`dC4`044`0341<C08lC0`034`0301<C058C0`dK4`007A<00a0C4`1;4`0301<C04@C

00<=4a<01A<00a0C4`2>4`0301<C00<C00<04a<0EA<23ATC000L4`0341<C04`C00<04a<0AA<00`dC

4`054`0341<C08hC00<04a<00Q<205PC0PdG4`006a<00a0C4`174`8011<00`0C4`164`033A<C00DC

00<@4a<0SA<00`0C4`024`0301<C05TC0PdE4`006Q<00a0C4`1:4`0501<C4`00B1<00`dC4`064`03

41<C08/C00<04`000a<00`0C4`1K4`<=4Q<001TC00<@4a<0BQ<00`0C4`024`80B1<00`dC4`054`03

41<C08`C00<04a<00Q<00`0C4`1M4`8=4A<006LC00<04a<0ia<00`0C4`1`4`00IA<00`0C003Y4`80

LA<006HC00<04a<0j1<00`0C4`1`4`00:Q<30?lC9A<00`0C4`1`4`00:Q<00`0C4`3o4iPC000[4`03

01<C00@C00<04a<0oa>@4`00:a<0100C4a<400<C0`3o4h`C000Z4`0301<0008C0P000a<04`044`03

01<C0?lCRQ<002/C00<04a<00a<00`0C00034`0301<C0?lCRa<0034C00<04`0011<00`0C4`064`03

01<C02LC0`0[4`0301<C0>DC00<04a<0=a<00`0C4`064`006a<300034`00008031<300@C0`084`03

01<C02HC00@04a<03a<300034`0000800Q<00`0C4`024`0301<C008C00<04a<01A<0100C4a<5008C

00@04a<C0P044`0301<C008C00<04a<011<20;dC00<04a<011<00`0C4`0C4`0301<C02<C00<04a<0

1A<001XC00@04a<091<00`0C4`0U4`0401<C00hC00@04a<01Q<00`0C00074`0301<000@C1@034`03

01<C00PC00D04a<C00034`0301<000@C00<04a<0Za<0100C4a<4008C0P064`0301<C00<C00<04a<0

0Q<00`0C4`024`0301<C008C00<04a<01A<0100C4a<5008C00@04a<C0P044`0301<C008C00<04a<0

11<200@C00@04a<C0P014`006Q<01@0C4`0C00@000<C0000600]4`<03Q<01@0C4`0C00@000@C01<0

2A<00`0C4`044`0301<C00<C00<04a<01a<00`0C4`024`0301<C00<C00<04a<00Q<00`0C4`2Z4`03

01<000LC00<04a<011<500<C00L04a<C01<000LC00<04`0011<500<C00<04a<021<01@0C4a<000<C

00<04`0011<00`0C4`044`0301<C008C0@014`006a<304lC00<04a<03A<300HC00<04`001a<200LC

00<04a<00a<00`0C4`084`0301<C008C00<04a<00P054`0301<C0:XC00<04`000Q<400034`0C00LC

00<04a<00a<01`0C4a<04`002A<00`0C4`044`0301<C00<C00<04a<01a<00`0C4`024`0301<C00<C

00<04a<00Q<00`0C4`044`0301<C00<C0@0001dC00<04a<0C1<2014C00<04a<011<00`0C00074`03

01<C00`C00<04a<01Q<00`0C00024`0301<0008C00<04a<011<00`0C002C4`8000<C00004Q<00`0C

00074`0301<C00HC00<04a<00a<01`0C4a<04`001a<200LC00<04a<00a<00`0C4`084`0301<C008C

00<04a<00P054`0301<C00@C00<04a<00a<1000071<2060C0P074`0301<C00HC0`0;4`802A<0100C

4a<3008C0`044`<0U1<00`0C000C4`0301<000LC00<04`003A<01P0C4`0C00LC00<04a<031<00`0C

4`064`0301<0008C00<04`000Q<00`0C4`044`0301<000<C00<04a<00a<1004C003o4e8C00<04a<0

4a<00`0C4`064`<03Q<0100C4`084`<02a<200TC00@04a<C0`024`<011<3008C00<04a<00a<2004C

000V4`801Q<20?lC8Q<00`0C4`1`4`00:1<00`0C4`024`0301<C0?lC8A<00`0C001a4`009a<00`0C

4`034`0301<C00HC00<04a<0oa<G4`8000<C0000L1<002PC00<04a<00Q<00`0C4`024`<000@C01<C

0`3o4hTC000V4`0301<000@C00<04`000Q<2008C00<04a<00Q<00`0C4`3o4hLC000W4`0301<C00<C

0`044`0401<C008C00<04a<0oa>84`00=1<0100C4`034`0301<C0?lCQa<0038C0`044`<0oa>94`00

oa?54`00oa?54`00oa?54`00oa?54`00oa?54`00\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-6.95686, -1.51321, 0.0206072, 0.0206072}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -82 0 ]

[.5 .96488 82 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -143 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.37) show

217.250000 19.500000 moveto

(C) show

222.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.23931 0 m

.26171 .03069 L

.30316 .08747 L

.34309 .14217 L

.3815 .1948 L

.42237 .25078 L

.46172 .30469 L

.49955 .35653 L

.53984 .41172 L

.57861 .46484 L

.61984 .52132 L

.65954 .57572 L

.69774 .62804 L

.73838 .68373 L

.77751 .73733 L

.81909 .7943 L

.85916 .84919 L

.89771 .90201 L

s

.89771 .90201 m

.93448 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.331448 0.238095 [

[.02381 .31895 -6 -9 ]

[.02381 .31895 6 0 ]

[.2619 .31895 -6 -9 ]

[.2619 .31895 6 0 ]

[.7381 .31895 -3 -9 ]

[.7381 .31895 3 0 ]

[.97619 .31895 -3 -9 ]

[.97619 .31895 3 0 ]

[1.025 .33145 0 -8 ]

[1.025 .33145 9 8 ]

[.4875 .09335 -12 -4.5 ]

[.4875 .09335 0 4.5 ]

[.4875 .2124 -24 -4.5 ]

[.4875 .2124 0 4.5 ]

[.4875 .4505 -18 -4.5 ]

[.4875 .4505 0 4.5 ]

[.4875 .56954 -6 -4.5 ]

[.4875 .56954 0 4.5 ]

[.4875 .68859 -18 -4.5 ]

[.4875 .68859 0 4.5 ]

[.4875 .80764 -6 -4.5 ]

[.4875 .80764 0 4.5 ]

[.5 .86523 -4.5 0 ]

[.5 .86523 4.5 16 ]

[.5 .85273 -134.5 0 ]

[.5 .85273 134.5 16 ]

[ 0 0 0 0 ]

[ 1 .84023 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .33145 m

.02381 .3377 L

s

[(-2)] .02381 .31895 0 1 Mshowa

.2619 .33145 m

.2619 .3377 L

s

[(-1)] .2619 .31895 0 1 Mshowa

.7381 .33145 m

.7381 .3377 L

s

[(1)] .7381 .31895 0 1 Mshowa

.97619 .33145 m

.97619 .3377 L

s

[(2)] .97619 .31895 0 1 Mshowa

.125 Mabswid

.07143 .33145 m

.07143 .3352 L

s

.11905 .33145 m

.11905 .3352 L

s

.16667 .33145 m

.16667 .3352 L

s

.21429 .33145 m

.21429 .3352 L

s

.30952 .33145 m

.30952 .3352 L

s

.35714 .33145 m

.35714 .3352 L

s

.40476 .33145 m

.40476 .3352 L

s

.45238 .33145 m

.45238 .3352 L

s

.54762 .33145 m

.54762 .3352 L

s

.59524 .33145 m

.59524 .3352 L

s

.64286 .33145 m

.64286 .3352 L

s

.69048 .33145 m

.69048 .3352 L

s

.78571 .33145 m

.78571 .3352 L

s

.83333 .33145 m

.83333 .3352 L

s

.88095 .33145 m

.88095 .3352 L

s

.92857 .33145 m

.92857 .3352 L

s

.25 Mabswid

0 .33145 m

1 .33145 L

s

gsave

1.025 .33145 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .09335 m

.50625 .09335 L

s

[(-1)] .4875 .09335 1 0 Mshowa

.5 .2124 m

.50625 .2124 L

s

[(-0.5)] .4875 .2124 1 0 Mshowa

.5 .4505 m

.50625 .4505 L

s

[(0.5)] .4875 .4505 1 0 Mshowa

.5 .56954 m

.50625 .56954 L

s

[(1)] .4875 .56954 1 0 Mshowa

.5 .68859 m

.50625 .68859 L

s

[(1.5)] .4875 .68859 1 0 Mshowa

.5 .80764 m

.50625 .80764 L

s

[(2)] .4875 .80764 1 0 Mshowa

.125 Mabswid

.5 .11716 m

.50375 .11716 L

s

.5 .14097 m

.50375 .14097 L

s

.5 .16478 m

.50375 .16478 L

s

.5 .18859 m

.50375 .18859 L

s

.5 .23621 m

.50375 .23621 L

s

.5 .26002 m

.50375 .26002 L

s

.5 .28383 m

.50375 .28383 L

s

.5 .30764 m

.50375 .30764 L

s

.5 .35526 m

.50375 .35526 L

s

.5 .37907 m

.50375 .37907 L

s

.5 .40288 m

.50375 .40288 L

s

.5 .42669 m

.50375 .42669 L

s

.5 .47431 m

.50375 .47431 L

s

.5 .49811 m

.50375 .49811 L

s

.5 .52192 m

.50375 .52192 L

s

.5 .54573 m

.50375 .54573 L

s

.5 .59335 m

.50375 .59335 L

s

.5 .61716 m

.50375 .61716 L

s

.5 .64097 m

.50375 .64097 L

s

.5 .66478 m

.50375 .66478 L

s

.5 .7124 m

.50375 .7124 L

s

.5 .73621 m

.50375 .73621 L

s

.5 .76002 m

.50375 .76002 L

s

.5 .78383 m

.50375 .78383 L

s

.5 .06954 m

.50375 .06954 L

s

.5 .04573 m

.50375 .04573 L

s

.5 .02192 m

.50375 .02192 L

s

.5 .83145 m

.50375 .83145 L

s

.25 Mabswid

.5 0 m

.5 .84023 L

s

gsave

.5 .86523 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .85273 -195.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.37) show

293.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

298.000000 15.000000 moveto

(L) show

305.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

312.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

319.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

324.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

328.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .84023 L

0 .84023 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .15915 m

.02576 .15915 L

.03156 .15916 L

.04112 .15919 L

.05428 .15922 L

.07081 .15926 L

.09043 .15931 L

.1128 .15938 L

.13754 .15946 L

.16423 .15955 L

.1924 .15966 L

.22158 .15978 L

.25127 .15993 L

.28096 .1601 L

.31014 .16029 L

.33832 .1605 L

.365 .16074 L

.38974 .161 L

.41211 .16128 L

.43173 .16157 L

.44826 .16185 L

.46142 .16211 L

.47098 .16232 L

.47679 .16245 L

.47873 .1625 L

s

.47873 .1625 m

.47931 .16251 L

.48103 .16256 L

.48386 .16263 L

.48775 .16273 L

.49264 .16287 L

.49844 .16304 L

.50506 .16325 L

.51238 .16351 L

.52027 .16381 L

.52861 .16417 L

.53724 .1646 L

.54602 .16509 L

.55481 .16568 L

.56344 .16636 L

.57177 .16716 L

.57967 .1681 L

.58699 .16919 L

.5936 .17047 L

.59941 .17196 L

.6043 .1737 L

.60819 .17572 L

.61102 .17807 L

.61274 .18078 L

.61331 .18389 L

s

.47873 .41587 m

.47931 .40208 L

.48103 .38828 L

.48386 .37458 L

.48775 .36104 L

.49264 .3477 L

.49844 .33462 L

.50506 .32186 L

.51238 .30945 L

.52027 .29745 L

.52861 .2859 L

.53724 .27483 L

.54602 .26429 L

.55481 .25429 L

.56344 .24488 L

.57177 .23607 L

.57967 .22787 L

.58699 .22029 L

.5936 .21334 L

.59941 .207 L

.6043 .20127 L

.60819 .19613 L

.61102 .19154 L

.61274 .18748 L

.61331 .18392 L

s

.47873 .41598 m

.47931 .42975 L

.48103 .4435 L

.48386 .45713 L

.48775 .47057 L

.49264 .48378 L

.49844 .49668 L

.50506 .50924 L

.51238 .52139 L

.52027 .53308 L

.52861 .54428 L

.53724 .55492 L

.54602 .56496 L

.55481 .57437 L

.56344 .5831 L

.57177 .59111 L

.57967 .59838 L

.58699 .60486 L

.5936 .61054 L

.59941 .61538 L

.6043 .61937 L

.60819 .62249 L

.61102 .62473 L

.61274 .62608 L

.61331 .62653 L

s

.61331 .62653 m

.61399 .62706 L

.61602 .62864 L

.61936 .6312 L

.62396 .63469 L

.62974 .63898 L

.63659 .64398 L

.64441 .64955 L

.65306 .65555 L

.66238 .66186 L

.67223 .66835 L

.68242 .6749 L

.6928 .6814 L

.70317 .68774 L

.71337 .69383 L

.72322 .69959 L

.73254 .70494 L

.74119 .70981 L

.749 .71414 L

.75586 .71789 L

.76164 .72101 L

.76623 .72348 L

.76958 .72525 L

.7716 .72633 L

.77228 .72669 L

s

.77228 .13382 m

.77316 .13021 L

.77576 .12611 L

.78005 .12154 L

.78594 .11649 L

.79335 .11101 L

.80215 .10514 L

.81217 .09894 L

.82326 .09249 L

.83522 .08587 L

.84785 .07917 L

.86093 .07247 L

.87424 .06586 L

.88755 .05943 L

.90062 .05327 L

.91325 .04745 L

.92521 .04205 L

.9363 .03712 L

.94633 .03274 L

.95512 .02894 L

.96253 .02577 L

.96843 .02327 L

.97272 .02146 L

.97532 .02037 L

.97619 .02001 L

s

.77228 .13384 m

.77316 .13699 L

.77576 .13971 L

.78005 .14205 L

.78594 .14403 L

.79335 .14571 L

.80215 .14713 L

.81217 .14832 L

.82326 .14932 L

.83522 .15016 L

.84785 .15087 L

.86093 .15147 L

.87424 .15197 L

.88755 .15239 L

.90062 .15275 L

.91325 .15305 L

.92521 .1533 L

.9363 .15351 L

.94633 .15368 L

.95512 .15382 L

.96253 .15393 L

.96843 .15401 L

.97272 .15407 L

.97532 .1541 L

.97619 .15411 L

s

.77228 .72669 m

.77316 .72715 L

.77576 .72852 L

.78005 .73076 L

.78594 .73382 L

.79335 .73762 L

.80215 .74208 L

.81217 .74708 L

.82326 .75253 L

.83522 .75831 L

.84785 .76431 L

.86093 .77041 L

.87424 .77652 L

.88755 .78252 L

.90062 .78832 L

.91325 .79384 L

.92521 .799 L

.9363 .80371 L

.94633 .80793 L

.95512 .81159 L

.96253 .81465 L

.96843 .81707 L

.97272 .81881 L

.97532 .81987 L

.97619 .82022 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCDQ<00`0C4`1`4`00oa=B4`0301<C070C001T4`D0j1<00`0C4`1`4`00IQ<00`0C4`3X4`03

01<C070C000n4`033A<C01lC0`034`0301<C008C0P3T4`0301<C070C000o4`033A<C02@C00<04a<0

0Q<00`0C4`3S4`80GQ<23A4C00104`033A<C02<C00<04a<00Q<00`0C4`3S4`0301<C05XC0`dC4`00

@1<00`dC4`0R4`8011<00`0C4`3S4`0301<C05PC0PdF4`00@A<00`dC4`0W4`80i1<00`0C4`1F4`8=

61<0048C00<=4a<09Q<00`0C4`3S4`0301<C05<C0`dJ4`00@a<00`dC4`0U4`0301<C0><C0P1B4`8=

7A<004<C00<=4a<09A<00`0C4`3S4`0301<C04lC0PdO4`00A1<00`dC4`0T4`80i1<00`0C4`1=4`8=

8A<004DC00<=4a<08a<00`0C4`3S4`0301<C04/C0PdS4`00AA<00`dC4`0S4`0301<C0><C00<04a<0

BA<23BDC00164`033A<C028C00<04a<0ha<204PC0PdW4`00Aa<00`dC4`0Q4`80i1<00`0C4`154`8=

:A<004PC00<=4a<081<00`0C4`3L4`D00Q<00`0C4`134`8=:a<004PC00<=4a<081<00`0C4`3N4`03

01<C008C00<04a<0@A<23BdC00194`033A<C01lC00<04a<0f1<300<C00<04a<00Q<2040C0Pd_4`00

BQ<00`dC4`0N4`80ga<00`0C4`024`0301<C03hC00<=4a<0;a<004/C00<=4a<07A<00`0C4`3N4`03

01<C008C00<04a<0?A<00`dC4`0`4`00Ba<00`dC4`0>4`0301<C008C00<04a<00Q<00`0C4`024`03

01<C0=dC0P044`0301<C03/C0Pdc4`00C1<00`dC4`0<4`0301<000LC00<04`000a<00`0C4`3S4`03

01<C03TC0Pde4`00CA<00`dC4`064`<00Q<00`0C00094`0401<C4`80i1<203PC0Pdg4`00CQ<00`dC

4`0:4`0301<000LC0P044`0301<C0><C00<04a<0=Q<00`dC4`0g4`00CQ<00`dC4`0:4`0301<000LC

00<04a<00a<00`0C4`3S4`0301<C03DC00<=4a<0>1<004lC00<=4a<02Q<00`0C4`064`<00a<00`0C

4`3S4`0301<C03DC00<=4a<0>1<0050C00<=4a<061<00`0C4`3S4`0301<C03DC00<=4a<0>1<0054C

00<=4a<05a<20>@C0P0f4`8=>A<0058C00<=4a<05Q<00`0C4`3S4`0301<C03LC1@dd4`00DQ<00`dC

4`0F4`0301<C0><C00<04a<0?1<?3BDC001C4`033A<C01DC00<04a<0ha<00`0C4`1;4a@=4A<005@C

00<=4a<051<208<CFPd74`0301<C070C001E4`033A<C01<C00<04a<0g1<E3FDC000J4`<09A<500hC

00<=4a<04a<00`0C4`0T4`D091<309<C00<04a<02a<73EhC000J4`0301<C02LC00<04a<03a<00`dC

4`0B4`0301<C02HC00<04a<091<00`0C4`2C4`0301<C018C0PeL4`005A<300<C00<04a<081<300<C

00<04a<041<00`dC4`0A4`809a<00`0C4`0U4`0301<C098C00<04a<051<00`dC4`1I4`006a<00`0C

4`0V4`0301<C014C00<=4a<041<00`0C4`0V4`0301<C02DC00<04a<0TQ<00`0C4`0D4`033A<C05TC

000J4`0301<002LC00<04a<04A<00`dC4`0@4`0301<C02HC00<04a<091<00`0C002C4`805A<00`dC

4`1I4`006a<00`0C4`0U4`8051<00`dC4`0?4`0301<C02DC0P0W4`0301<C098C00<04a<04a<00`dC

4`1J4`00FQ<00`dC4`0>4`80i1<00`0C4`0B4`033A<C05/C001J4`033A<C00hC00<04a<0e1<00`0C

4`024`0301<C008C00<04a<00Q<00`0C4`0A4`033A<C05`C001K4`033A<C00dC00<04a<0Fa<207HC

00<04`001a<00`0C00034`0301<C014C00<=4a<0G1<005`C00<=4a<031<00`0C4`1J4`0301<C074C

0`024`0301<000TC00@04a<C0P0A4`033A<C05dC000E4dP000<=0000HP064`0301<C07HC00<04`00

1a<200@C00<04a<03a<00`dC4`1N4`006A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`03

01<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04`d01A<00`0C4`054`0341<C00DC00<04a<0

1Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`03

01<C00DC00<04a<021<00`0C4`1f4`0301<000LC00<04a<00a<00`0C4`0>4`033A<C05lC001N4`03

3A<C00XC00<@4a<0FQ<00`0C001g4`0301<C00HC0`034`0301<C00dC00<=4a<0H1<005lC00<=4a<0

2A<245/C0`264`0301<C00`C00<=4a<0HA<0060C00<=4a<021<24>@C0P0=4`033A<C064C001P4`03

3A<C00LC00<@0100i1<00`0C4`0:4`8=I1<0064C00<=4a<01Q<00a00403T4`0301<C00TC00<=4a<0

I1<0068C00<=4a<01A<00a00403T4`0301<C00PC00<=4a<0IA<006<C00<=4a<00a<01A0C000@0><C

0P084`033A<C06HC001S4`033A<C00<C00D@4`0C403S4`0301<C00HC00<=4a<0Ia<006@C00<=4a<0

0Q<01A0C01<@0><C00<04a<01A<00`dC4`1X4`00IA<01`dC4a<@4`000Q<00a0C4`3P4`0301<C00DC

00<=4a<0J1<006HC00D=4a<@4`0200034a0C084C0`0]4`D0:a<00`0C4`044`033A<C02@C1@0]4`<0

41<006HC00H=4a<@4`024`0341<C080C00<04a<0;a<00`0C4`0[4`801A<00`dC4`0V4`0301<C02dC

00<04a<041<006LC00D=41<C00034`0341<C07XC0`034`0301<C02PC0`034`0301<C02/C00<04a<0

0a<00`dC4`0W4`0301<C02hC00<04a<03a<006PC00@=4a<00a<00a0C4`204`0301<C02hC00<04a<0

:a<00`0C4`024`033A<C02PC00<04a<0;Q<00`0C4`0?4`00J1<00`dC4`02008C00<@4a<0Oa<00`0C

000_4`0301<C02/C00D04a<C3@0[4`0301<C02dC00<04`0041<006LC00D@4`dC00044`0341<C07lC

00<04a<0;A<202dC00D04a<C3@0Z4`80<1<00`0C4`0?4`00G1<00`0C4`024`0301<C008C00H041<C

3@044`0341<C0=hC0P000a<=4`1^4`00Fa<00`0C00074`030100008C00<=01<00a<00a0C4`3N4`04

01<C3FlC001K4`0301<000PC00<@01<00Q<00`d04`034`0341<C0=dC00<04`d0L1<005/C00<04`00

1a<00`0@4`034`0300dC00<C00<@4a<0gA<00`0=4`1/4`800Q<005/C00<04`001a<00a0C4`034`03

00dC00@C00<@4a<0g1<00`0=4`1[4`0301<C008C001L4`0301<C00HC00<@00000a<00`0C3@044`03

41<C07HCIP000`d0001T00LC00<04a<00Q<006@C00<@4a<011<200034`dC008C00<@4a<0Na<00`0C

4`074`0301<C00HC00<04a<01a<00`0C4`074`0301<C00LC00<04a<01Q<00`0C4`074`0301<C00LC

00<04a<01Q<00`0C4`074`033A<C00LC00<04a<01a<00`0C4`064`0301<C00LC00<04a<01a<00`0C

4`064`0301<C00LC00<04a<01a<00`0C4`064`0301<C00LC00<04a<02Q<00`0C4`024`00I1<00a0C

4`044`0401<C3@@C00<@4a<0fQ<00`d04`1/4`0301<0008C001S4`0341<C00DC00D04a<C3@034`03

41<C0=XC00<=01<0K1<3008C001S4`0341<C00DC00<04a<00Q<01@dC4a<@0=/C00<=01<0LA<0068C

00<@4a<01Q<00`0C4`034`043A<C4=XC00@=4`00LA<0068C00<@4a<01Q<200@C00D=4a<C403I4`03

3A<0078C001Q4`0341<C00LC00<04a<011<010dC4a3I4`033A<0078C001Q4`0341<C00LC00<04a<0

1A<00`dC403H4`043A<C078C001P4`0341<C00PC00<04a<01Q<00`dC403G4`043A<C078C001P4`03

41<C00PC0P074`033A<@0=LC00<=4a<00P1a4`00Ga<00a0C4`094`0301<C00LC00<=4a00eA<01@dC

4a<0078C001O4`0341<C00TC00<04a<021<00`d@4`3D4`053A<C4`00LQ<005hC00<@4a<02Q<00`0C

4`094`033A0C0=<C00D=4a<C001b4`00GQ<00a0C4`0:4`802Q<00`d@4`3C4`053A<C4`00LQ<005dC

00<@4a<02a<00`0C4`0:4`033A0C0=8C00@=4a<C0P1a4`00GA<00a0C4`044`D00Q<00`0C4`0;4`03

3A<C0=4C00D=4a<C001b4`00G1<00a0C4`074`0301<C008C00<04a<031<00`dC4`3@4`053A<C4`00

LQ<005/C00<@4a<021<00`0C4`024`803A<00`d@4`3@4`053A<C4`00LQ<005/C00<@4a<021<00`0C

4`024`0301<C00dC00<=4a<0ca<010dC4a<2074C001J4`0341<C00TC00<04a<00Q<00`0C4`0>4`03

3A<C0<hC00D=4a<C001b4`00FQ<00a0C4`084`8011<00`0C4`0>4`033A0C0<hC00D=4a<C001b4`00

FA<00a0C4`0?4`8041<00`dC4`324`0301<C008C00<04a<00Q<00`0=4`024`0301<C070C001H4`03

41<C010C00<04a<041<00`dC4`304`0301<000LC00<04`d00a<00`0C4`1`4`00F1<00a0C4`0@4`03

01<C014C00<=4a<0_a<00`0C00094`043A<C4`80LA<005LC00<@4a<04A<00`0C4`0A4`033A<C0;lC

00<04`001a<200054`dC4`00LQ<005HC00<@4a<04Q<201<C00<=4a<0_Q<00`0C00074`0401<C3@8C

00<04a<0L1<005HC00<@4a<04Q<00`0C4`0C4`033A<C0;hC00<04a<01Q<300043A<C078C001E4`03

41<C01<C00<04a<04a<00a0=4`3;4`033A<0078C001D4`0341<C01@C00<04a<051<00`dC4`3:4`04

3A<0074C001C4`0341<C01DC0P0E4`0340dC0</C00<=01<0LA<005<C00<@4a<05A<00`0C4`0E4`03

40dC0<XC00<=01<0LA<0058C00<@4a<05Q<00`0C4`0F4`0340dC0<TC00<=01<0LA<0054C00<@4a<0

5a<00`0C4`0F4`0340dC0<XC00<=4a<0L1<0054C00<@4a<05a<201PC00<@3A<0bA<00`d04`1`4`00

D1<00a0C4`0H4`0301<C01LC00<@4`d0bA<00`dC4`1`4`00Ca<00a0C4`084`D00Q<00`0C4`024`03

01<C008C00<04a<061<00a0C3@384`0300dC070C001?4`0341<C00XC00<04a<01Q<00`0C00034`03

01<C01TC00<@3A<0aa<00`0C3@1`4`00CQ<00a0C4`0;4`0301<C00PC00@04a<C0P0K4`0340dC0<HC

00<04`d0L1<004dC00<@4a<031<00`0C4`064`8011<00`0C4`0J4`0341<=0<HC0P000a<=4`1^4`00

C1<00a0C4`0=4`0301<C00HC00<04a<00a<00`0C4`0K4`0340dC0<DC00@04a<=Ka<004`C00<@4a<0

31<200PC0`034`0301<C01`C00<@3A<0a1<01@0C4a<=06hC001;4`0341<C01dC0P0N4`0340dC0<<C

00<04a<00Q<00`dC4`1[4`00BQ<00a0C4`0N4`0301<C01dC00<@3A<0`a<00`0C4`034`033A<C06XC

001:4`0341<C01hC00<04a<07Q<00a0=4`324`801A<00`dC4`1Y4`00BA<00a0C4`0O4`0301<C01lC

00<@3A<0`A<00`0C4`044`033A<C06TC00184`0341<C020C0P0Q4`0340dC0<0C00<04a<01A<00`dC

4`1X4`00Aa<00a0C4`0Q4`0301<C024C00<=4a<0^1<5008C00<04a<01A<00`dC4`1X4`00Aa<00a0C

4`0Q4`0301<C024C00<@3A<0^Q<00`0C4`024`0301<C00HC00<=4a<0Ia<004HC00<@4a<08Q<00`0C

4`0R4`0340dC0;TC00<04a<00Q<200PC00<=4a<0IQ<004DC00<@4a<08a<202@C00<@3A<0^1<00`0C

4`024`0301<C00PC00<=4a<0IA<004@C00<@4a<091<00`0C4`0T4`033A<C0;LC00<04a<00Q<00`0C

4`094`8=IA<004@C00<@4a<091<00`0C4`0T4`0340dC0;HC0P044`0301<C00/C00<=4a<0HQ<004<C

00<@4a<09A<00`0C4`0U4`0340dC0;/C0P0=4`033A<C064C00124`0341<C02HC00<04a<09Q<00a0=

4`2j4`0301<C00dC00<=4a<0H1<0044C00<@4a<09a<202PC00<=4a<0^A<00`0C4`0>4`033A<C05lC

00104`0341<C02PC00<04a<0:1<00`dC4`2h4`0301<C00lC00<=4a<0GQ<0040C00<@4a<08Q<300<C

00<04a<0:A<00`dC4`2g4`0301<C010C00<=4a<0GA<003lC00<@4a<08a<00`0C4`034`0301<C02TC

00<=4a<0]a<2018C00<=4a<0G1<003hC00<@4a<09A<00`0C4`024`80:a<00`dC4`2f4`0301<C018C

0PeL4`00?A<00a0C4`0V4`0301<C008C00<04a<0:a<00`dC4`2e4`0301<C01@C00<=4a<0FA<003dC

00<@4a<09A<00`0C00034`0301<C02`C00<=4a<0]1<00`0C4`0E4`033A<C05PC000l4`0341<C02LC

00<04a<00Q<00`0C4`0/4`033A0C0;@C00<04a<05Q<00`dC4`1G4`00>a<00a0C4`0]4`80;Q<00`d@

4`2c4`8061<23ELC000j4`0341<C02hC00<04a<0;Q<00`dC4`2b4`0301<C01TC00<=4a<0E1<003XC

00<@4a<0;Q<00`0C4`0_4`033A<C0;4C00<04a<06Q<23E@C000i4`0341<C02lC00<04a<0;a<00`d@

4`2a4`0301<C01`C00<=4a<0DA<003PC00<@4a<0<1<2034C00<=41<0/1<00`0C4`0M4`8=DA<003LC

00<@4a<0<A<00`0C4`0a4`033A<C0:lC0P0P4`033A<C04hC000g4`0341<C034C00<04a<0<Q<00`dC

4`2^4`0301<C020C00<=4a<0CA<003HC00<@4a<0<Q<00`0C4`0b4`033A0C0:hC00<04a<08A<23DdC

000e4`0341<C03<C0P0d4`033A0C09`C1@024`0301<C008C00<04a<00Q<00`0C4`0S4`8=Ba<003@C

00<@4a<0=1<00`0C4`0d4`033A0C09dC00<04a<01Q<00`0C00034`0301<C02DC0Pe94`00<a<00a0C

4`0e4`0301<C03DC00<=41<0W1<00`0C4`084`0401<C4`80:1<00`dC4`164`00<Q<00a0C4`0f4`03

01<C03DC00<=41<0W1<00`0C4`064`8011<00`0C4`0X4`8=AQ<0034C00<@4a<0=a<203LC00<=41<0

Va<00`0C4`064`0301<C00<C00<04a<0:Q<23D@C000`4`0341<C03PC00<04a<0=a<00`d@4`2I4`80

21<300<C00<04a<0;1<00`dC4`114`00;a<00a0C4`0Y4`<00a<00`0C4`024`0301<C008C00<04a<0

=a<00`dC402Y4`0301<C02dC0Pe14`00;Q<00a0C4`0Z4`0301<C00LC00<04`000a<00`0C4`0h4`03

3A<@0:PC0P0`4`8=?a<002dC00<@4a<0;1<00`0C4`084`0401<C4`80>Q<00`dC402W4`0301<C034C

0Pdm4`00;1<00a0C4`0]4`0301<C00HC0P044`0301<C03XC00<=4a00YQ<00`0C4`0c4`8=>a<002/C

00<@4a<0;A<00`0C00074`0301<C00<C00<04a<0>Q<010dC4a2U4`0301<C03DC0Pdi4`00:Q<00a0C

4`0_4`0301<C00HC0`034`0301<C03/C00@=4a<@Y1<203PC00<=4a<0=Q<002TC00<@4a<0?a<203dC

00@=4a<@Xa<00`0C4`0h4`8==Q<002PC00<@4a<0@1<00`0C4`0l4`053A<C4a00XQ<00`0C4`0j4`8=

=1<002LC00<@4a<0@A<00`0C4`0m4`053A<C4a00XA<00`0C4`0l4`8=<Q<002HC00<@4a<0@Q<00`0C

4`0n4`053A<C4a00X1<00`0C4`0n4`8=<1<002DC00<@4a<0@a<203lC00<=4a<00Q<00a0C4`2M4`80

@A<33BdC000T4`0341<C04@C00<04a<0?a<00`dC4`024`0341<C09`C00<04a<0@a<33BXC000S4`03

41<C04DC00<04a<0@1<00`dC4`024`0341<C09/C00<04a<0AQ<23BPC000S4`0341<C04DC00<04a<0

@1<00`dC4`034`0341<C09XC00<04a<0B1<00`dC4`0U4`008Q<00a0C4`164`80@Q<00`dC4`034`03

41<C09TC00<04a<0BA<23BDC000Q4`0341<C04LC00<04a<0@Q<00`dC4`034`0341<C09PC0P1<4`<=

8Q<0020C00<@4a<0B1<00`0C4`134`033A<C00<C00<@4a<0Ua<00`0C4`1>4`8=81<001lC00<@4a<0

BA<00`0C4`134`033A<C00@C00<@4a<0UQ<00`0C4`1@4`<=7A<001hC00<@4a<0BQ<204DC00<=4a<0

11<00a0C4`2?4`<00a<00`0C4`1C4`8=6a<001dC00<@4a<0Ba<00`0C4`154`033A<C00@C00<@4a<0

SQ<00`0C4`034`0301<C05DC0PdI4`0071<00a0C4`1<4`0301<C04HC00<=4a<011<00a0C4`2>4`03

01<C008C0P1H4`8=5a<001/C00<@4a<0Aa<200@C00<04a<0AQ<00`dC4`054`0341<C08dC00<04a<0

0Q<00`0C4`1I4`<=51<001XC00<@4a<0BQ<01@0C4a<004TC00<=4a<01A<00a0C4`2;4`0301<000<C

00<04a<0G1<23A8C000I4`0341<C04XC00<04a<00Q<204TC00<=4a<011<00a0C4`2<4`0301<C008C

00<04a<0GQ<00`dC4`0?4`00Ia<00`0C4`3W4`0301<C070C001U4`0301<00>TC0P1a4`00IQ<00`0C

4`3X4`0301<C070C000/4`<0oa<S4`0301<C070C000/4`0301<C0?lCUQ<002dC00<04a<01A<00`0C

4`3o4hdC000]4`0401<C4`<000@C01<C0`3o4hXC000/4`0301<0008C0P024`0301<C008C00<04a<0

oa>84`00;A<00`0C4`034`0401<C008C00<04a<0oa>94`00<a<0100C4`034`0301<C00HC00<04a<0

9A<302dC00<04a<0iQ<00`0C4`0b4`0301<C00PC000M4`<000<C00000P0<4`<011<300PC00<04a<0

91<0100C4`0A4`<000<C00000P024`0301<C008C00<04a<00Q<00`0C4`054`0401<C4`D00Q<0100C

4a<200@C00<04a<011<20<<C00<04a<011<00`0C4`0C4`0301<C01hC00<04a<01a<001`C00@04a<0

91<00`0C4`0S4`0401<C010C00@04a<01Q<00`0C00074`0301<000@C1@034`0301<C00PC00D04a<C

00054`0301<C0;4C00@04a<C10024`801Q<00`0C4`034`0301<C008C00<04a<00Q<00`0C4`024`03

01<C00DC00@04a<C1@024`0401<C4`8011<00`0C4`044`8011<0100C4a<2004C0@01000071<01@0C

4`0C00@000<C0000600[4`<041<01@0C4`0C00@000@C01<02A<00`0C4`044`0301<C00<C00<04a<0

1a<00`0C4`024`0301<C00<C00<04a<0/1<00`0C00074`0301<C00@C1@034`0701<C4`0C00074`03

01<000@C1@034`0301<C00PC00D04a<C00054`0301<C00@C00<04a<00Q<00`0C00014`007A<304dC

00<04a<03a<300HC00<04`001a<200LC00<04a<00a<00`0C4`084`0301<C008C00<04a<00Q<00`0C

4`2`4`0301<0008C10000a<04`074`0301<C00<C00L04a<C01<000TC00<04a<011<00`0C4`034`03

01<C00LC00<04a<00Q<00`0C4`034`0301<C00@C00<04a<00a<1004C0A<001lC00<04a<0BQ<201<C

00<04a<011<00`0C00074`0301<C00`C00<04a<01Q<00`0C00024`0301<000@C00<04`00UQ<20003

4`0001DC00<04`001a<00`0C4`064`0301<C00<C00L04a<C01<000LC0P074`0301<C00<C00<04a<0

21<00`0C4`024`0301<C008C00<04a<011<00`0C4`034`400A<14`007Q<2060C0P074`0301<C00HC

0`0;4`802A<0100C4a<300@C0`2G4`0301<001HC00<04`001a<00`0C000=4`0601<C01<01a<00`0C

4`0<4`0301<C00HC00<04`000Q<00`0C00044`0301<000<C00<04a<00a<00`0C00014`00oa=B4`03

01<C01HC00<04a<01Q<300hC00@04a<021<300/C0P094`0401<C4`<011<3008C00<04a<00a<2004C

0@010000:A<200HC0P3o4alC00<04a<0L1<002/C00<04a<00Q<00`0C4`3o4ahC00<04`00LA<002XC

00<04a<00a<00`0C4`054`0301<C0?lC5A<200034`00070C000[4`0301<C008C00<04a<00Q<400<C

0`3o4hHC000Y4`0301<000@C00<04`000Q<200034`0C00@C00<04a<0oa>44`00:Q<00`0C4`034`<0

11<00`0C00034`0301<C0?lCQA<003LC00<04`0011<00`0C4`3o4h@C000e4`<011<30?lCQQ<00?lC

aA<00?lCaA<00?lCaA<00?lCaA<00?lCaA<00001\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-6.95686, -1.51089, 0.0206072, 0.0206072}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -84.5 0 ]

[.5 .96488 84.5 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -145.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.365) show

222.250000 19.500000 moveto

(C) show

227.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.23836 0 m

.26171 .03188 L

.30316 .08845 L

.34309 .14295 L

.3815 .19539 L

.42237 .25117 L

.46172 .30489 L

.49955 .35653 L

.53984 .41152 L

.57861 .46445 L

.61984 .52072 L

.65954 .57492 L

.69774 .62705 L

.73838 .68253 L

.77751 .73595 L

.81909 .79271 L

.85916 .8474 L

.89771 .90002 L

s

.89771 .90002 m

.93607 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.329733 0.238095 [

[.02381 .31723 -6 -9 ]

[.02381 .31723 6 0 ]

[.2619 .31723 -6 -9 ]

[.2619 .31723 6 0 ]

[.7381 .31723 -3 -9 ]

[.7381 .31723 3 0 ]

[.97619 .31723 -3 -9 ]

[.97619 .31723 3 0 ]

[1.025 .32973 0 -8 ]

[1.025 .32973 9 8 ]

[.4875 .09164 -12 -4.5 ]

[.4875 .09164 0 4.5 ]

[.4875 .21069 -24 -4.5 ]

[.4875 .21069 0 4.5 ]

[.4875 .44878 -18 -4.5 ]

[.4875 .44878 0 4.5 ]

[.4875 .56783 -6 -4.5 ]

[.4875 .56783 0 4.5 ]

[.4875 .68688 -18 -4.5 ]

[.4875 .68688 0 4.5 ]

[.4875 .80592 -6 -4.5 ]

[.4875 .80592 0 4.5 ]

[.5 .86294 -4.5 0 ]

[.5 .86294 4.5 16 ]

[.5 .85044 -137 0 ]

[.5 .85044 137 16 ]

[ 0 0 0 0 ]

[ 1 .83794 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .32973 m

.02381 .33598 L

s

[(-2)] .02381 .31723 0 1 Mshowa

.2619 .32973 m

.2619 .33598 L

s

[(-1)] .2619 .31723 0 1 Mshowa

.7381 .32973 m

.7381 .33598 L

s

[(1)] .7381 .31723 0 1 Mshowa

.97619 .32973 m

.97619 .33598 L

s

[(2)] .97619 .31723 0 1 Mshowa

.125 Mabswid

.07143 .32973 m

.07143 .33348 L

s

.11905 .32973 m

.11905 .33348 L

s

.16667 .32973 m

.16667 .33348 L

s

.21429 .32973 m

.21429 .33348 L

s

.30952 .32973 m

.30952 .33348 L

s

.35714 .32973 m

.35714 .33348 L

s

.40476 .32973 m

.40476 .33348 L

s

.45238 .32973 m

.45238 .33348 L

s

.54762 .32973 m

.54762 .33348 L

s

.59524 .32973 m

.59524 .33348 L

s

.64286 .32973 m

.64286 .33348 L

s

.69048 .32973 m

.69048 .33348 L

s

.78571 .32973 m

.78571 .33348 L

s

.83333 .32973 m

.83333 .33348 L

s

.88095 .32973 m

.88095 .33348 L

s

.92857 .32973 m

.92857 .33348 L

s

.25 Mabswid

0 .32973 m

1 .32973 L

s

gsave

1.025 .32973 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .09164 m

.50625 .09164 L

s

[(-1)] .4875 .09164 1 0 Mshowa

.5 .21069 m

.50625 .21069 L

s

[(-0.5)] .4875 .21069 1 0 Mshowa

.5 .44878 m

.50625 .44878 L

s

[(0.5)] .4875 .44878 1 0 Mshowa

.5 .56783 m

.50625 .56783 L

s

[(1)] .4875 .56783 1 0 Mshowa

.5 .68688 m

.50625 .68688 L

s

[(1.5)] .4875 .68688 1 0 Mshowa

.5 .80592 m

.50625 .80592 L

s

[(2)] .4875 .80592 1 0 Mshowa

.125 Mabswid

.5 .11545 m

.50375 .11545 L

s

.5 .13926 m

.50375 .13926 L

s

.5 .16307 m

.50375 .16307 L

s

.5 .18688 m

.50375 .18688 L

s

.5 .23449 m

.50375 .23449 L

s

.5 .2583 m

.50375 .2583 L

s

.5 .28211 m

.50375 .28211 L

s

.5 .30592 m

.50375 .30592 L

s

.5 .35354 m

.50375 .35354 L

s

.5 .37735 m

.50375 .37735 L

s

.5 .40116 m

.50375 .40116 L

s

.5 .42497 m

.50375 .42497 L

s

.5 .47259 m

.50375 .47259 L

s

.5 .4964 m

.50375 .4964 L

s

.5 .52021 m

.50375 .52021 L

s

.5 .54402 m

.50375 .54402 L

s

.5 .59164 m

.50375 .59164 L

s

.5 .61545 m

.50375 .61545 L

s

.5 .63926 m

.50375 .63926 L

s

.5 .66307 m

.50375 .66307 L

s

.5 .71069 m

.50375 .71069 L

s

.5 .73449 m

.50375 .73449 L

s

.5 .7583 m

.50375 .7583 L

s

.5 .78211 m

.50375 .78211 L

s

.5 .06783 m

.50375 .06783 L

s

.5 .04402 m

.50375 .04402 L

s

.5 .02021 m

.50375 .02021 L

s

.5 .82973 m

.50375 .82973 L

s

.25 Mabswid

.5 0 m

.5 .83794 L

s

gsave

.5 .86294 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .85044 -198 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.365) show

298.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

303.000000 15.000000 moveto

(L) show

310.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

317.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

324.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

329.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

333.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .83794 L

0 .83794 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .15698 m

.02576 .15698 L

.03156 .157 L

.04112 .15702 L

.05428 .15706 L

.07081 .15711 L

.09043 .15716 L

.1128 .15724 L

.13753 .15732 L

.16422 .15743 L

.19239 .15755 L

.22157 .15769 L

.25126 .15785 L

.28095 .15804 L

.31013 .15825 L

.3383 .15849 L

.36498 .15876 L

.38972 .15905 L

.41209 .15936 L

.43171 .15968 L

.44824 .16 L

.46139 .16028 L

.47096 .16051 L

.47676 .16066 L

.47871 .16072 L

s

.47871 .16072 m

.47927 .16073 L

.48096 .16078 L

.48375 .16086 L

.48758 .16097 L

.49239 .16112 L

.49809 .16131 L

.5046 .16154 L

.5118 .16182 L

.51957 .16215 L

.52776 .16254 L

.53626 .163 L

.5449 .16353 L

.55353 .16416 L

.56203 .16489 L

.57022 .16575 L

.57799 .16674 L

.58519 .1679 L

.5917 .16925 L

.5974 .17082 L

.60221 .17263 L

.60604 .17474 L

.60883 .17717 L

.61052 .17996 L

.61108 .18315 L

s

.47871 .41418 m

.47927 .40052 L

.48096 .38685 L

.48375 .37326 L

.48758 .35983 L

.49239 .34661 L

.49809 .33363 L

.5046 .32097 L

.5118 .30865 L

.51957 .29674 L

.52776 .28526 L

.53626 .27426 L

.5449 .26377 L

.55353 .25383 L

.56203 .24445 L

.57022 .23566 L

.57799 .22747 L

.58519 .21989 L

.5917 .21292 L

.5974 .20656 L

.60221 .20079 L

.60604 .19559 L

.60883 .19094 L

.61052 .18681 L

.61108 .18318 L

s

.47871 .4143 m

.47927 .42794 L

.48096 .44157 L

.48375 .45508 L

.48758 .46839 L

.49239 .48147 L

.49809 .49426 L

.5046 .50669 L

.5118 .51873 L

.51957 .53032 L

.52776 .5414 L

.53626 .55194 L

.5449 .56189 L

.55353 .57121 L

.56203 .57985 L

.57022 .58779 L

.57799 .59499 L

.58519 .60141 L

.5917 .60703 L

.5974 .61182 L

.60221 .61578 L

.60604 .61887 L

.60883 .62109 L

.61052 .62242 L

.61108 .62287 L

s

.61108 .62287 m

.61181 .62344 L

.61397 .62512 L

.61753 .62788 L

.62243 .6316 L

.62858 .6362 L

.63589 .64153 L

.64422 .64746 L

.65343 .65384 L

.66337 .66054 L

.67386 .66742 L

.68473 .67436 L

.69578 .68123 L

.70684 .68792 L

.7177 .69435 L

.72819 .70042 L

.73813 .70604 L

.74734 .71117 L

.75567 .71572 L

.76298 .71966 L

.76913 .72294 L

.77403 .72553 L

.77759 .72739 L

.77975 .72852 L

.78048 .7289 L

s

.78048 .13014 m

.78132 .12655 L

.78381 .12249 L

.78793 .11799 L

.79359 .11305 L

.8007 .10771 L

.80914 .10201 L

.81876 .09601 L

.82941 .08977 L

.84089 .08338 L

.85301 .07691 L

.86556 .07046 L

.87833 .06409 L

.89111 .05791 L

.90366 .05198 L

.91578 .04638 L

.92726 .04117 L

.93791 .03643 L

.94753 .03221 L

.95597 .02855 L

.96308 .0255 L

.96874 .02309 L

.97286 .02135 L

.97535 .0203 L

.97619 .01995 L

s

.78048 .13016 m

.78132 .13332 L

.78381 .13608 L

.78793 .13846 L

.79359 .1405 L

.8007 .14225 L

.80914 .14373 L

.81876 .14498 L

.82941 .14604 L

.84089 .14694 L

.85301 .14771 L

.86556 .14835 L

.87833 .1489 L

.89111 .14936 L

.90366 .14975 L

.91578 .15008 L

.92726 .15035 L

.93791 .15058 L

.94753 .15077 L

.95597 .15093 L

.96308 .15105 L

.96874 .15114 L

.97286 .15121 L

.97535 .15125 L

.97619 .15126 L

s

.78048 .7289 m

.78132 .72933 L

.78381 .73063 L

.78793 .73275 L

.79359 .73564 L

.8007 .73924 L

.80914 .74346 L

.81876 .74821 L

.82941 .75338 L

.84089 .75888 L

.85301 .76458 L

.86556 .77039 L

.87833 .77621 L

.89111 .78193 L

.90366 .78747 L

.91578 .79275 L

.92726 .79767 L

.93791 .80218 L

.94753 .80622 L

.95597 .80972 L

.96308 .81265 L

.96874 .81496 L

.97286 .81664 L

.97535 .81765 L

.97619 .81799 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCaA<00?lCDQ<00`0C4`1`4`00I1<50>PC00<04a<0L1<006HC00<04a<0j1<00`0C4`1`4`00

?Q<00`dC4`0O4`<00a<00`0C4`024`80i1<00`0C4`1`4`00?a<00`dC4`0T4`0301<C008C00<04a<0

ha<205hC0PdA4`00?a<00`dC4`0T4`0301<C008C00<04a<0ha<00`0C4`1K4`8=4a<0040C00<=4a<0

8Q<200@C00<04a<0ha<00`0C4`1H4`<=5A<0044C00<=4a<09a<20>@C00<04a<0EQ<23APC00114`03

3A<C02LC00<04a<0ha<00`0C4`1D4`8=6Q<0048C00<=4a<09Q<00`0C4`3S4`80DQ<33A`C00134`03

3A<C02DC00<04a<0ha<00`0C4`1?4`8=7a<004@C00<=4a<091<20>@C00<04a<0CA<23B4C00144`03

3A<C02@C00<04a<0ha<00`0C4`1;4`8=8a<004DC00<=4a<08a<00`0C4`3S4`0301<C04XC00<=4a<0

8a<004HC00<=4a<08Q<00`0C4`3S4`80B1<33BHC00174`033A<C024C0P3T4`0301<C04DC0PdY4`00

Aa<00`dC4`0Q4`0301<C0=`C1@024`0301<C04@C00<=4a<0:A<004PC00<=4a<081<00`0C4`3N4`03

01<C008C00<04a<0@Q<23B`C00194`033A<C01lC00<04a<0f1<300<C00<04a<00Q<2044C0Pd^4`00

BQ<00`dC4`0N4`80ga<00`0C4`024`0301<C03hC0Pd`4`00BQ<00`dC4`0N4`0301<C0=hC00<04a<0

0Q<00`0C4`0l4`8=<Q<004/C00<=4a<03Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`3M4`80

11<00`0C4`0k4`033A<C038C001<4`033A<C00`C00<04`001a<00`0C00034`0301<C0><C00<04a<0

>Q<00`dC4`0c4`00C1<00`dC4`074`<00Q<00`0C00094`0401<C4`80i1<203XC00<=4a<0=1<004dC

00<=4a<02a<00`0C00074`8011<00`0C4`3S4`0301<C03PC00<=4a<0=A<004hC00<=4a<02Q<00`0C

00074`0301<C00<C00<04a<0ha<00`0C4`0f4`8=>1<004lC00<=4a<02Q<00`0C4`064`<00a<00`0C

4`3S4`0301<C03HC00<=4a<0=a<004lC00<=4a<06A<00`0C4`3S4`0301<C03HC0Pdh4`00D1<00`dC

4`0H4`80i1<203TC0Pdf4`00DA<00`dC4`0G4`0301<C0><C00<04a<0>Q<83BhC001B4`033A<C01HC

00<04a<0ha<00`0C4`124a`=4Q<0058C00<=4a<05Q<00`0C4`3S4`0301<C05dC0PdA4`00Da<00`dC

4`0E4`80Pa=P3@034`0C074C001D4`033A<C01@C00<04a<0hQ<@3F@C000J4`<09A<500hC00<=4a<0

4a<00`0C4`0T4`D091<309<C00<04a<031<63EhC000J4`0301<C02LC00<04a<03Q<00`dC4`0C4`03

01<C02HC00<04a<091<00`0C4`2C4`0301<C018C0PeL4`005A<300<C00<04a<081<300<C00<04a<0

3a<00`dC4`0B4`809a<00`0C4`0U4`0301<C098C00<04a<04a<23E/C000K4`0301<C02HC00<04a<0

41<00`dC4`0A4`0301<C02HC00<04a<09A<00`0C4`2B4`0301<C01@C00<=4a<0FA<001XC00<04`00

9a<00`0C4`0A4`033A<C010C00<04a<09Q<00`0C4`0T4`0301<009<C0P0E4`033A<C05TC000K4`03

01<C02DC0P0D4`033A<C00lC00<04a<09A<202LC00<04a<0TQ<00`0C4`0C4`033A<C05XC001I4`03

3A<C00lC0P3T4`0301<C01<C00<=4a<0FQ<005XC00<=4a<03Q<00`0C4`3D4`0301<C008C00<04a<0

0Q<00`0C4`024`0301<C018C00<=4a<0Fa<005/C00<=4a<03A<00`0C4`1K4`80MQ<00`0C00074`03

01<000<C00<04a<04A<00`dC4`1L4`00G1<00`dC4`0<4`0301<C05XC00<04a<0LA<3008C00<04`00

2A<0100C4a<2014C00<=4a<0GA<001DCA`000`d0001S00HC00<04a<0MQ<00`0C00074`8011<00`0C

4`0?4`033A<C05hC000I4`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C

4`054`0301<C00HC00<04a<01A<00`0C3@054`0301<C00DC00<@4a<01A<00`0C4`064`0301<C00DC

00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C

4`084`0301<C07HC00<04`001a<00`0C4`034`0301<C00hC00<=4a<0Ga<005hC00<=4a<02Q<00a0C

4`1J4`0301<007LC00<04a<01Q<300<C00<04a<03A<00`dC4`1P4`00Ga<00`dC4`094`8@Fa<308HC

0P0=4`033A<C064C001P4`033A<C00PC0Q3T4`0301<C00/C00<=4a<0HQ<0060C00<=4a<01a<00a00

403T4`0301<C00XC00<=4a<0Ha<0064C00<=4a<01Q<00a00403T4`0301<C00XC00<=4a<0Ha<0068C

00<=4a<01A<00a00403T4`0301<C00PC0PeV4`00Ha<00`dC4`034`0541<00100ha<200PC00<=4a<0

IQ<006<C00<=4a<00a<01A0C01<@0><C00<04a<01Q<00`dC4`1W4`00I1<00`dC4`024`0541<04a00

ha<00`0C4`054`033A<C06PC001U4`073A<C4a0C00024`0341<C0>0C00<04a<01A<00`dC4`1X4`00

IQ<01@dC4a0C008000<C41<0PA<302dC1@0[4`0301<C00@C00<=4a<091<502dC0`0@4`00IQ<01PdC

4a0C008C00<@4a<0P1<00`0C4`0_4`0301<C02/C0P044`033A<C02LC00<04a<0;A<00`0C4`0@4`00

Ia<01@d@4a<000<C00<@4a<0NQ<300<C00<04a<0:1<300<C00<04a<0:a<00`0C4`034`033A<C02LC

00<04a<0;Q<00`0C4`0?4`00J1<010dC4`034`0341<C080C00<04a<0;Q<00`0C4`0[4`0301<C008C

00<=4a<0:1<00`0C4`0^4`0301<C00lC001X4`033A<C00800Q<00a0C4`1o4`0301<002lC00<04a<0

:a<01@0C4a<=02/C00<04a<0;A<00`0C000@4`00Ia<01A0C3A<000@C00<@4a<0Oa<00`0C4`0]4`80

;A<01@0C4a<=02XC0P0`4`0301<C00lC001L4`0301<C008C00<04a<00Q<01P0@4a<=00@C00<@4a<0

gQ<200034`dC06hC001K4`0301<000LC00<040000Q<00`d04`034`0341<C0=hC00@04a<=Ka<005/C

00<04`0021<00a004`024`033@0C00<C00<@4a<0gA<00`0C3@1`4`00Fa<00`0C00074`03010C00<C

00<03A<00a<00a0C4`3M4`0300dC06`C0P024`00Fa<00`0C00074`0341<C00<C00<03A<011<00a0C

4`3L4`0300dC06/C00<04a<00Q<005`C00<04a<01Q<00a0000034`0301<=00@C00<@4a<0MQ=V0003

3@0006@01a<00`0C4`024`00I1<00a0C4`044`8000<C3A<00Q<00a0C4`1k4`0301<C00LC00<04a<0

1Q<00`0C4`074`0301<C00LC00<04a<01a<00`0C4`064`0301<C00LC00<04a<01a<00`0C4`064`03

01<C00LC00<=4a<01a<00`0C4`074`0301<C00HC00<04a<01a<00`0C4`074`0301<C00HC00<04a<0

1a<00`0C4`074`0301<C00HC00<04a<01a<00`0C4`0:4`0301<C008C001T4`0341<C00@C00@04a<=

11<00a0C4`3J4`033@0C06`C00<04`000Q<006<C00<@4a<01A<01@0C4a<=00<C00<@4a<0fQ<00`d0

4`1/4`<00Q<006<C00<@4a<01A<00`0C4`024`053A<C4a00fa<00`d04`1a4`00HQ<00a0C4`064`03

01<C00<C00@=4a<@fQ<010dC001a4`00HQ<00a0C4`064`8011<01@dC4a<@0=TC00<=4`00LQ<0064C

00<@4a<01a<00`0C4`044`043A<C4=TC00<=4`00LQ<0064C00<@4a<01a<00`0C4`054`033A<@0=PC

00@=4a<0LQ<0060C00<@4a<021<00`0C4`064`033A<@0=LC00@=4a<0LQ<0060C00<@4a<021<200LC

00<=4a00ea<00`dC4`02074C001O4`0341<C00TC00<04a<01a<00`dC403E4`053A<C4`00LQ<005lC

00<@4a<02A<00`0C4`084`033A0C0=@C00D=4a<C001b4`00GQ<00a0C4`0:4`0301<C00TC00<=41<0

da<01@dC4a<0078C001N4`0341<C00XC0P0:4`033A0C0=<C00@=4a<C0P1a4`00GA<00a0C4`0;4`03

01<C00XC00<=41<0dQ<01@dC4a<0078C001M4`0341<C00@C1@024`0301<C00/C00<=4a<0dA<01@dC

4a<0078C001L4`0341<C00LC00<04a<00Q<00`0C4`0<4`033A<C0=0C00D=4a<C001b4`00Fa<00a0C

4`084`0301<C008C0P0>4`033A<C0<lC00D=4a<C001b4`00Fa<00a0C4`084`0301<C008C00<04a<0

3A<00`dC4`3?4`043A<C4`80LA<005XC00<@4a<02A<00`0C4`024`0301<C00hC00<=4a<0cQ<01@dC

4a<0078C001J4`0341<C00PC0P044`0301<C00lC00<=4a<0cA<01@dC4a<0078C001I4`0341<C00lC

0P0@4`0340dC0<8C00<04a<00Q<00`0C4`024`0300dC008C00<04a<0L1<005PC00<@4a<041<00`0C

4`0@4`033A<C0<0C00<04`001a<00`0C3@034`0301<C070C001H4`0341<C010C00<04a<04A<00`dC

4`2o4`0301<000TC00@=4a<C0P1a4`00Ea<00a0C4`0A4`0301<C014C00<@3A<0_a<00`0C00074`80

00DC3A<C001b4`00EQ<00a0C4`0B4`804a<00a0=4`2n4`0301<000LC00@04a<=0Q<00`0C4`1`4`00

EQ<00a0C4`0B4`0301<C01<C00<=4a<0_Q<00`0C4`064`<000@C3A<0LQ<005DC00<@4a<04a<00`0C

4`0C4`0340dC0</C00<=4`00LQ<005@C00<@4a<051<00`0C4`0D4`0340dC0<XC00@=4`00LA<005<C

00<@4a<05A<201DC00<@3A<0ba<00`d04`1a4`00Da<00a0C4`0E4`0301<C01DC00<@3A<0bQ<00`d0

4`1a4`00DQ<00a0C4`0F4`0301<C01HC00<@3A<0bA<00`d04`1a4`00DA<00a0C4`0G4`0301<C01HC

00<@4`d0bQ<00`dC4`1`4`00DA<00a0C4`0G4`8061<00a0=4`394`033@0C070C001@4`0341<C01PC

00<04a<05a<00a0C3@394`0300dC070C001?4`0341<C00PC1@024`0301<C008C00<04a<00Q<00`0C

4`0H4`0341<=0<PC00<03A<0L1<004lC00<@4a<02Q<00`0C4`064`0301<000<C00<04a<06A<00a0=

4`374`0301<=070C001>4`0341<C00/C00<04a<021<0100C4a<201/C00<@3A<0aQ<0100C4`e_4`00

CA<00a0C4`0<4`0301<C00HC0P044`0301<C01XC00<@4`d0aQ<200034`dC06hC001<4`0341<C00dC

00<04a<01Q<00`0C4`034`0301<C01/C00<@3A<0aA<01@0C4a<=06hC001<4`0341<C00`C0P084`<0

0a<00`0C4`0L4`0340dC0<@C00D04a<C3@1^4`00Ba<00a0C4`0M4`807Q<00a0=4`334`0301<C008C

00<=4a<0Ja<004XC00<@4a<07Q<00`0C4`0M4`0340dC0<<C00<04a<00a<00`dC4`1Z4`00BQ<00a0C

4`0N4`0301<C01hC00<@3A<0`Q<200@C00<=4a<0JQ<004TC00<@4a<07a<00`0C4`0O4`0340dC0<4C

00<04a<011<00`dC4`1Y4`00B1<00a0C4`0P4`808A<00a0=4`2i4`D00Q<00`0C4`054`033A<C06PC

00174`0341<C024C00<04a<08A<00`dC4`2j4`0301<C008C00<04a<01Q<00`dC4`1W4`00Aa<00a0C

4`0Q4`0301<C024C00<@3A<0^Q<00`0C4`024`8021<00`dC4`1V4`00AQ<00a0C4`0R4`0301<C028C

00<@3A<0^A<00`0C4`024`0301<C00PC00<=4a<0IA<004DC00<@4a<08a<202@C00<@3A<0^1<00`0C

4`024`0301<C00TC00<=4a<0I1<004@C00<@4a<091<00`0C4`0T4`033A<C0;HC0P044`0301<C00XC

00<=4a<0Ha<004@C00<@4a<091<00`0C4`0T4`0340dC0;`C00<04a<02a<00`dC4`1R4`00@a<00a0C

4`0U4`0301<C02DC00<@3A<0^a<200dC00<=4a<0HA<0048C00<@4a<09Q<00`0C4`0V4`0340dC0;XC

00<04a<03A<00`dC4`1P4`00@A<00a0C4`0W4`80:1<00a0=4`2i4`0301<C00hC00<=4a<0Ga<0040C

00<@4a<0:1<00`0C4`0X4`033A<C0;PC00<04a<03a<23ElC00104`0341<C028C0`034`0301<C02TC

00<=4a<0]a<00`0C4`0A4`033A<C05`C000o4`0341<C02<C00<04a<00a<00`0C4`0Y4`0340dC0;LC

0P0C4`033A<C05/C000n4`0341<C02DC00<04a<00Q<202/C00<@3A<0]Q<00`0C4`0C4`033A<C05XC

000m4`0341<C02HC00<04a<00Q<00`0C4`0[4`033A<C0;DC00<04a<051<00`dC4`1I4`00?A<00a0C

4`0U4`0301<000<C00<04a<0;1<00`dC4`2d4`0301<C01DC0PeI4`00?1<00a0C4`0W4`0301<C008C

00<04a<0;A<00`dC4`2c4`0301<C01LC00<=4a<0EQ<003/C00<@4a<0;A<202lC00<=4a<0/Q<201TC

0PeF4`00>Q<00a0C4`0^4`0301<C02hC00<=4a<0/Q<00`0C4`0I4`033A<C05@C000j4`0341<C02hC

00<04a<0;a<00`dC4`2a4`0301<C01XC00<=4a<0Da<003TC00<@4a<0;a<00`0C4`0`4`033A<C0;0C

00<04a<06a<23E<C000h4`0341<C030C0P0a4`033A0C0;0C00<04a<07A<23E4C000g4`0341<C034C

00<04a<0<A<00`dC4`2_4`8081<23DlC000g4`0341<C034C00<04a<0<Q<00`dC4`2^4`0301<C024C

00<=4a<0C1<003HC00<@4a<0<Q<00`0C4`0c4`033A<C0:dC00<04a<08Q<23D`C000e4`0341<C03<C

0P0d4`033A0C09`C1@024`0301<C008C00<04a<00Q<00`0C4`0T4`033A<C04TC000d4`0341<C03@C

00<04a<0=1<00`d@4`2M4`0301<C00HC00<04`000a<00`0C4`0U4`033A<C04PC000c4`0341<C03DC

00<04a<0=A<00`d@4`2L4`0301<C00PC00@04a<C0P0W4`8=B1<0038C00<@4a<0=Q<00`0C4`0e4`03

3A0C09`C00<04a<01Q<200@C00<04a<0:1<33DDC000a4`0341<C03LC0P0g4`033A0C09/C00<04a<0

1Q<00`0C4`034`0301<C02/C0Pe34`00<1<00a0C4`0h4`0301<C03LC00<=41<0VA<200PC0`034`03

01<C02dC00<=4a<0@1<002lC00<@4a<0:A<300<C00<04a<00Q<00`0C4`024`0301<C03LC00<=4a00

ZA<00`0C4`0^4`033A<C03lC000^4`0341<C02XC00<04a<01a<00`0C00034`0301<C03PC00<=4a00

Z1<2030C0Pdo4`00;A<00a0C4`0/4`0301<C00PC00@04a<C0P0j4`033A<@0:LC00<04a<0<A<33C`C

000/4`0341<C02dC00<04a<01Q<200@C00<04a<0>Q<00`dC402V4`0301<C03@C00<=4a<0>A<002/C

00<@4a<0;A<00`0C00074`0301<C00<C00<04a<0>Q<010dC4a2U4`0301<C03DC0Pdi4`00:Q<00a0C

4`0_4`0301<C00HC0`034`0301<C03/C00@=4a<@Y1<203PC0Pdg4`00:A<00a0C4`0o4`80?A<010dC

4a2S4`0301<C03TC0Pde4`00:1<00a0C4`104`0301<C03`C00D=4a<C402R4`0301<C03/C0Pdc4`00

9a<00a0C4`114`0301<C03dC00D=4a<C402Q4`0301<C03dC0Pda4`009Q<00a0C4`124`0301<C03hC

00D=4a<C402P4`0301<C03lC0`d^4`009A<00a0C4`134`80?a<00`dC4`024`0341<C09dC0P134`8=

;1<002@C00<@4a<0A1<00`0C4`0o4`033A<C008C00<@4a<0W1<00`0C4`144`033A<C02TC000S4`03

41<C04DC00<04a<0@1<00`dC4`024`0341<C09/C00<04a<0AA<23BTC000S4`0341<C04DC00<04a<0

@1<00`dC4`034`0341<C09XC00<04a<0Aa<23BLC000R4`0341<C04HC0P124`033A<C00<C00<@4a<0

VA<00`0C4`194`<=91<0024C00<@4a<0Aa<00`0C4`124`033A<C00<C00<@4a<0V1<204dC0PdR4`00

81<00a0C4`184`0301<C04<C00<=4a<00a<00a0C4`2G4`0301<C04hC0`dO4`007a<00a0C4`194`03

01<C04<C00<=4a<011<00a0C4`2F4`0301<C054C0PdM4`007Q<00a0C4`1:4`80AA<00`dC4`044`03

41<C08lC0`034`0301<C05<C0PdK4`007A<00a0C4`1;4`0301<C04DC00<=4a<011<00a0C4`2>4`03

01<C00<C00<04a<0EA<23ATC000L4`0341<C04`C00<04a<0AQ<00`dC4`044`0341<C08hC00<04a<0

0Q<205PC0PdG4`006a<00a0C4`174`8011<00`0C4`164`033A<C00DC00<@4a<0SA<00`0C4`024`03

01<C05TC0`dD4`006Q<00a0C4`1:4`0501<C4`00BA<00`dC4`054`0341<C08/C00<04`000a<00`0C

4`1L4`<=4A<001TC00<@4a<0BQ<00`0C4`024`80BA<00`dC4`044`0341<C08`C00<04a<00Q<00`0C

4`1`4`00Ia<00`0C4`3W4`0301<C070C001U4`0301<00>TC0P1a4`00IQ<00`0C4`3X4`0301<C070C

000Z4`<0oa>H4`00:Q<00`0C4`3o4iPC000[4`0301<C00@C00<04a<0oa>@4`00:a<0100C4a<400<C

0`3o4h`C000Z4`0301<0008C0P000a<04`044`0301<C0?lCRQ<002/C00<04a<00a<00`0C00034`03

01<C0?lCRa<0034C00<04`0011<00`0C4`064`0301<C02LC0`0[4`0301<C0>DC00<04a<0=a<00`0C

4`064`006a<300034`00008031<300@C0`084`0301<C02HC00@04a<03a<300034`0000800Q<00`0C

4`024`0301<C008C00<04a<01A<0100C4a<5008C00@04a<C0P034`8011<00`0C4`044`80_A<00`0C

4`044`0301<C01<C00<04a<08a<00`0C4`054`006Q<0100C4`0T4`0301<C02DC00@04a<03Q<0100C

4`064`0301<000LC00<04`0011<500<C00<04a<021<01P0C4`0C008C00<04`0011<00`0C4`2[4`04

01<C4`@00Q<200HC00<04a<00a<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`054`0401<C4`D0

0Q<0100C4a<200<C0P044`0301<C00@C0P044`0401<C4`800A<001XC00D04a<04`0400034`0001P0

;A<300hC00D04a<04`0400044`0C00TC00<04a<011<00`0C4`034`0301<C00LC00L04a<C01<000@C

00<04a<00Q<00`0C4`2Z4`0301<000LC00<04a<011<500<C00L04a<C01<000LC00<04`0011<500<C

00<04a<021<01P0C4`0C008C00<04`0011<00`0C4`044`0301<C008C0@014`006a<304lC00<04a<0

3A<300HC00<04`001a<200LC00<04a<00a<00`0C4`084`0301<C00800a<200DC00<04a<0ZQ<00`0C

00024`@000<C01<01a<00`0C4`034`0701<C4`0C00094`0301<C00@C00<04a<00a<00`0C4`074`07

01<C4`0C00044`0301<C008C00<04a<011<00`0C4`034`40000M4`0301<C04`C0P0A4`0301<C00@C

00<04`001a<00`0C4`0<4`0301<C00HC00<04`000Q<00`0C4`024`0301<C00@C00<04`00Ta<20003

4`00018C00<04`001a<00`0C4`064`0301<C00<C00L04a<C01<000LC0P074`0301<C00<C00<04a<0

21<00`0C4`0200<C0P054`0301<C00@C00<04a<00a<1000071<2060C0P074`0301<C00HC0`0;4`80

2A<00`0C4`024`800Q<300@C0`2D4`0301<001<C00<04`001a<00`0C000=4`0601<C01<01a<00`0C

4`0<4`0301<C00HC00<04`000Q<00`0C4`024`0301<C00@C00<04`000a<00`0C4`034`400A<00?lC

DQ<00`0C4`0C4`0301<C00HC0`0>4`0401<C00PC0`0;4`802A<00`0C4`024`800Q<300@C0`024`03

01<C00<C0P014`009Q<200HC0P3o4b8C00<04a<0L1<002PC00<04a<00Q<00`0C4`3o4b4C00<04`00

LA<002LC00<04a<00a<00`0C4`064`0301<C0?lC5a<200034`00070C000X4`0301<C008C00<04a<0

0Q<300044`0C4`<0oa>94`009Q<00`0C00044`0301<0008C0P024`0301<C008C00<04a<0oa>74`00

9a<00`0C4`034`<011<0100C4`024`0301<C0?lCR1<003@C00@04a<00a<00`0C4`3o4hLC000b4`<0

11<30?lCRA<00?lCaA<00?lCaA<00?lCaA<00?lCaA<00?lCaA<00001\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-6.95686, -1.50849, 0.0206072, 0.0206072}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -82 0 ]

[.5 .96488 82 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -143 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.36) show

217.250000 19.500000 moveto

(C) show

222.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.23739 0 m

.26171 .03307 L

.30316 .08943 L

.34309 .14374 L

.3815 .19598 L

.42237 .25156 L

.46172 .30508 L

.49955 .35653 L

.53984 .41132 L

.57861 .46405 L

.61984 .52012 L

.65954 .57412 L

.69774 .62607 L

.73838 .68134 L

.77751 .73456 L

.81909 .79111 L

.85916 .8456 L

.89771 .89803 L

s

.89771 .89803 m

.93768 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.327986 0.238095 [

[.02381 .31549 -6 -9 ]

[.02381 .31549 6 0 ]

[.2619 .31549 -6 -9 ]

[.2619 .31549 6 0 ]

[.7381 .31549 -3 -9 ]

[.7381 .31549 3 0 ]

[.97619 .31549 -3 -9 ]

[.97619 .31549 3 0 ]

[1.025 .32799 0 -8 ]

[1.025 .32799 9 8 ]

[.4875 .08989 -12 -4.5 ]

[.4875 .08989 0 4.5 ]

[.4875 .20894 -24 -4.5 ]

[.4875 .20894 0 4.5 ]

[.4875 .44703 -18 -4.5 ]

[.4875 .44703 0 4.5 ]

[.4875 .56608 -6 -4.5 ]

[.4875 .56608 0 4.5 ]

[.4875 .68513 -18 -4.5 ]

[.4875 .68513 0 4.5 ]

[.4875 .80418 -6 -4.5 ]

[.4875 .80418 0 4.5 ]

[.5 .86062 -4.5 0 ]

[.5 .86062 4.5 16 ]

[.5 .84812 -134.5 0 ]

[.5 .84812 134.5 16 ]

[ 0 0 0 0 ]

[ 1 .83562 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .32799 m

.02381 .33424 L

s

[(-2)] .02381 .31549 0 1 Mshowa

.2619 .32799 m

.2619 .33424 L

s

[(-1)] .2619 .31549 0 1 Mshowa

.7381 .32799 m

.7381 .33424 L

s

[(1)] .7381 .31549 0 1 Mshowa

.97619 .32799 m

.97619 .33424 L

s

[(2)] .97619 .31549 0 1 Mshowa

.125 Mabswid

.07143 .32799 m

.07143 .33174 L

s

.11905 .32799 m

.11905 .33174 L

s

.16667 .32799 m

.16667 .33174 L

s

.21429 .32799 m

.21429 .33174 L

s

.30952 .32799 m

.30952 .33174 L

s

.35714 .32799 m

.35714 .33174 L

s

.40476 .32799 m

.40476 .33174 L

s

.45238 .32799 m

.45238 .33174 L

s

.54762 .32799 m

.54762 .33174 L

s

.59524 .32799 m

.59524 .33174 L

s

.64286 .32799 m

.64286 .33174 L

s

.69048 .32799 m

.69048 .33174 L

s

.78571 .32799 m

.78571 .33174 L

s

.83333 .32799 m

.83333 .33174 L

s

.88095 .32799 m

.88095 .33174 L

s

.92857 .32799 m

.92857 .33174 L

s

.25 Mabswid

0 .32799 m

1 .32799 L

s

gsave

1.025 .32799 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .08989 m

.50625 .08989 L

s

[(-1)] .4875 .08989 1 0 Mshowa

.5 .20894 m

.50625 .20894 L

s

[(-0.5)] .4875 .20894 1 0 Mshowa

.5 .44703 m

.50625 .44703 L

s

[(0.5)] .4875 .44703 1 0 Mshowa

.5 .56608 m

.50625 .56608 L

s

[(1)] .4875 .56608 1 0 Mshowa

.5 .68513 m

.50625 .68513 L

s

[(1.5)] .4875 .68513 1 0 Mshowa

.5 .80418 m

.50625 .80418 L

s

[(2)] .4875 .80418 1 0 Mshowa

.125 Mabswid

.5 .1137 m

.50375 .1137 L

s

.5 .13751 m

.50375 .13751 L

s

.5 .16132 m

.50375 .16132 L

s

.5 .18513 m

.50375 .18513 L

s

.5 .23275 m

.50375 .23275 L

s

.5 .25656 m

.50375 .25656 L

s

.5 .28037 m

.50375 .28037 L

s

.5 .30418 m

.50375 .30418 L

s

.5 .3518 m

.50375 .3518 L

s

.5 .3756 m

.50375 .3756 L

s

.5 .39941 m

.50375 .39941 L

s

.5 .42322 m

.50375 .42322 L

s

.5 .47084 m

.50375 .47084 L

s

.5 .49465 m

.50375 .49465 L

s

.5 .51846 m

.50375 .51846 L

s

.5 .54227 m

.50375 .54227 L

s

.5 .58989 m

.50375 .58989 L

s

.5 .6137 m

.50375 .6137 L

s

.5 .63751 m

.50375 .63751 L

s

.5 .66132 m

.50375 .66132 L

s

.5 .70894 m

.50375 .70894 L

s

.5 .73275 m

.50375 .73275 L

s

.5 .75656 m

.50375 .75656 L

s

.5 .78037 m

.50375 .78037 L

s

.5 .06608 m

.50375 .06608 L

s

.5 .04227 m

.50375 .04227 L

s

.5 .01846 m

.50375 .01846 L

s

.5 .82799 m

.50375 .82799 L

s

.25 Mabswid

.5 0 m

.5 .83562 L

s

gsave

.5 .86062 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .84812 -195.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.36) show

293.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

298.000000 15.000000 moveto

(L) show

305.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

312.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

319.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

324.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

328.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .83562 L

0 .83562 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .15478 m

.02576 .15478 L

.03156 .1548 L

.04112 .15483 L

.05428 .15487 L

.07081 .15492 L

.09042 .15498 L

.11279 .15506 L

.13753 .15516 L

.16421 .15527 L

.19238 .15541 L

.22156 .15556 L

.25125 .15574 L

.28093 .15595 L

.31011 .15619 L

.33828 .15645 L

.36496 .15675 L

.3897 .15707 L

.41207 .15741 L

.43168 .15777 L

.44821 .15811 L

.46137 .15842 L

.47093 .15868 L

.47674 .15884 L

.47868 .1589 L

s

.47868 .1589 m

.47924 .15892 L

.4809 .15897 L

.48364 .15906 L

.48741 .15918 L

.49215 .15934 L

.49777 .15954 L

.50418 .15979 L

.51127 .16009 L

.51891 .16045 L

.52698 .16087 L

.53535 .16136 L

.54385 .16193 L

.55236 .1626 L

.56072 .16338 L

.56879 .16429 L

.57644 .16534 L

.58352 .16656 L

.58993 .16797 L

.59555 .16961 L

.60029 .1715 L

.60406 .17368 L

.6068 .17618 L

.60846 .17906 L

.60902 .18232 L

s

.47868 .41247 m

.47924 .39892 L

.4809 .38536 L

.48364 .37189 L

.48741 .35856 L

.49215 .34544 L

.49777 .33257 L

.50418 .31999 L

.51127 .30776 L

.51891 .29592 L

.52698 .28452 L

.53535 .27358 L

.54385 .26315 L

.55236 .25324 L

.56072 .2439 L

.56879 .23513 L

.57644 .22695 L

.58352 .21937 L

.58993 .21238 L

.59555 .20599 L

.60029 .20019 L

.60406 .19494 L

.6068 .19024 L

.60846 .18605 L

.60902 .18234 L

s

.47868 .41258 m

.47924 .42611 L

.4809 .43963 L

.48364 .45301 L

.48741 .46621 L

.49215 .47918 L

.49777 .49185 L

.50418 .50417 L

.51127 .5161 L

.51891 .52759 L

.52698 .53857 L

.53535 .54902 L

.54385 .55888 L

.55236 .56811 L

.56072 .57668 L

.56879 .58454 L

.57644 .59167 L

.58352 .59803 L

.58993 .6036 L

.59555 .60835 L

.60029 .61227 L

.60406 .61534 L

.6068 .61753 L

.60846 .61886 L

.60902 .6193 L

s

.60902 .6193 m

.60979 .6199 L

.61208 .6217 L

.61586 .62463 L

.62105 .6286 L

.62758 .63348 L

.63532 .63914 L

.64415 .64542 L

.65392 .65217 L

.66445 .65925 L

.67557 .66651 L

.68709 .67381 L

.69881 .68104 L

.71053 .68807 L

.72205 .69481 L

.73317 .70117 L

.7437 .70707 L

.75347 .71243 L

.7623 .7172 L

.77004 .72131 L

.77657 .72474 L

.78176 .72745 L

.78554 .7294 L

.78783 .73057 L

.7886 .73097 L

s

.7886 .12648 m

.7894 .12291 L

.79179 .11891 L

.79574 .11449 L

.80116 .10966 L

.80798 .10446 L

.81607 .09893 L

.82529 .09312 L

.8355 .08709 L

.8465 .08093 L

.85812 .0747 L

.87015 .06848 L

.88239 .06236 L

.89464 .05641 L

.90667 .0507 L

.91829 .04531 L

.92929 .04031 L

.93949 .03575 L

.94872 .03169 L

.95681 .02817 L

.96362 .02523 L

.96905 .02292 L

.97299 .02125 L

.97539 .02023 L

.97619 .0199 L

s

.7886 .12651 m

.7894 .12966 L

.79179 .13244 L

.79574 .13486 L

.80116 .13695 L

.80798 .13875 L

.81607 .14029 L

.82529 .1416 L

.8355 .14272 L

.8465 .14367 L

.85812 .14448 L

.87015 .14518 L

.88239 .14576 L

.89464 .14626 L

.90667 .14669 L

.91829 .14704 L

.92929 .14735 L

.93949 .1476 L

.94872 .14781 L

.95681 .14798 L

.96362 .14811 L

.96905 .14821 L

.97299 .14828 L

.97539 .14832 L

.97619 .14834 L

s

.7886 .73097 m

.7894 .73138 L

.79179 .7326 L

.79574 .7346 L

.80116 .73734 L

.80798 .74075 L

.81607 .74474 L

.82529 .74924 L

.8355 .75414 L

.8465 .75936 L

.85812 .76478 L

.87015 .7703 L

.88239 .77584 L

.89464 .78129 L

.90667 .78657 L

.91829 .7916 L

.92929 .7963 L

.93949 .80061 L

.94872 .80446 L

.95681 .80781 L

.96362 .81061 L

.96905 .81283 L

.97299 .81443 L

.97539 .8154 L

.97619 .81572 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCaA<00?lCDQ<00`0C4`1`4`00I1<50>PC00<04a<0L1<006HC00<04a<0j1<00`0C4`1`4`00

?Q<00`dC4`0O4`<00a<00`0C4`024`80i1<00`0C4`1`4`00?a<00`dC4`0T4`0301<C008C00<04a<0

ha<205hC0PdA4`00?a<00`dC4`0T4`0301<C008C00<04a<0ha<00`0C4`1L4`8=4Q<0040C00<=4a<0

8Q<200@C00<04a<0ha<00`0C4`1I4`<=51<0044C00<=4a<09a<20>@C00<04a<0Ea<23ALC00114`03

3A<C02LC00<04a<0ha<00`0C4`1D4`<=6A<0048C00<=4a<09Q<00`0C4`3S4`80Da<23A`C00134`03

3A<C02DC00<04a<0ha<00`0C4`1@4`8=7Q<004@C00<=4a<091<20>@C00<04a<0CQ<23B0C00144`03

3A<C02@C00<04a<0ha<00`0C4`1<4`8=8Q<004DC00<=4a<08a<00`0C4`3S4`80C1<00`dC4`0R4`00

AQ<00`dC4`0R4`0301<C0><C00<04a<0B1<33BDC00174`033A<C024C0P3T4`0301<C04HC0PdX4`00

Aa<00`dC4`0Q4`0301<C0=`C1@024`0301<C04@C0PdZ4`00B1<00`dC4`0P4`0301<C0=hC00<04a<0

0Q<00`0C4`124`8=;1<004TC00<=4a<07a<00`0C4`3H4`<00a<00`0C4`024`80@Q<00`dC4`0/4`00

BQ<00`dC4`0N4`80ga<00`0C4`024`0301<C03lC0Pd_4`00BQ<00`dC4`0N4`0301<C0=hC00<04a<0

0Q<00`0C4`0n4`033A<C02lC001;4`033A<C00hC00<04a<00Q<00`0C4`024`0301<C008C00<04a<0

gA<200@C00<04a<0?1<23C8C001<4`033A<C00`C00<04`001a<00`0C00034`0301<C0><C00<04a<0

>Q<23C@C001<4`033A<C00LC0`024`0301<000TC00@04a<C0P3T4`80>Q<00`dC4`0d4`00CA<00`dC

4`0;4`0301<000LC0P044`0301<C0><C00<04a<0>A<00`dC4`0d4`00CQ<00`dC4`0:4`0301<000LC

00<04a<00a<00`0C4`3S4`0301<C03PC00<=4a<0=A<004lC00<=4a<02Q<00`0C4`064`<00a<00`0C

4`3S4`0301<C03PC00<=4a<0=A<004lC00<=4a<06A<00`0C4`3S4`0301<C03TC00<=4a<0=1<0050C

00<=4a<061<20>@C0P0k4`<=<a<0054C00<=4a<05a<00`0C4`3S4`0301<C03dC2`dX4`00DQ<00`dC

4`0F4`0301<C0><C00<04a<0B1<G3A4C001B4`033A<C01HC00<04a<0PQ<<3EDC00<04a<0L1<005<C

00<=4a<05A<208lCE`ea4`00E1<00`dC4`0D4`0301<C0><C0P0=3F@C000J4`<09A<500hC00<=4a<0

4a<00`0C4`0T4`D091<309<C00<04a<031<63EhC000J4`0301<C02LC00<04a<03Q<00`dC4`0C4`03

01<C02HC00<04a<091<00`0C4`2C4`0301<C018C00<=4a<0Fa<001DC0`034`0301<C020C0`034`03

01<C00lC00<=4a<04Q<202LC00<04a<09A<00`0C4`2B4`0301<C01<C00<=4a<0FQ<001/C00<04a<0

9Q<00`0C4`0@4`033A<C014C00<04a<09Q<00`0C4`0U4`0301<C098C00<04a<04a<00`dC4`1J4`00

6Q<00`0C000W4`0301<C014C00<=4a<041<00`0C4`0V4`0301<C02@C00<04`00Ta<201@C00<=4a<0

FQ<001/C00<04a<09A<201@C00<=4a<03a<00`0C4`0U4`809a<00`0C4`2B4`0301<C01<C00<=4a<0

FQ<005TC00<=4a<03a<20>@C00<04a<04Q<00`dC4`1K4`00FQ<00`dC4`0>4`0301<C0=@C00<04a<0

0Q<00`0C4`024`0301<C008C00<04a<04Q<00`dC4`1K4`00Fa<00`dC4`0=4`0301<C05/C0P1f4`03

01<000LC00<04`000a<00`0C4`0A4`033A<C05`C001L4`033A<C00`C00<04a<0FQ<00`0C4`1a4`<0

0Q<00`0C00094`0401<C4`8041<23ElC000E4dL000<=0000H`064`0301<C07HC00<04`001a<200@C

00<04a<03Q<00`dC4`1O4`006A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00DC

00<04a<01A<00`0C4`064`0301<C00DC00<04`d01A<00`0C4`054`0341<C00DC00<04a<01Q<00`0C

4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<C00DC

00<04a<021<00`0C4`1f4`0301<000LC00<04a<00a<00`0C4`0>4`033A<C05lC001N4`033A<C00XC

00<@4a<0FQ<00`0C001g4`0301<C00HC0`034`0301<C00dC00<=4a<0H1<005lC00<=4a<02A<245/C

0`264`803A<00`dC4`1Q4`00H1<00`dC4`084`8@i1<00`0C4`0;4`033A<C068C001P4`033A<C00LC

00<@0100i1<00`0C4`0:4`033A<C06<C001Q4`033A<C00HC00<@0100i1<00`0C4`094`033A<C06@C

001R4`033A<C00DC00<@0100i1<00`0C4`084`033A<C06DC001S4`033A<C00<C00D@4`00403S4`80

2A<00`dC4`1U4`00Ha<00`dC4`034`0541<04a00ha<00`0C4`074`033A<C06HC001T4`033A<C008C

00D@4`0C403S4`0301<C00HC00<=4a<0Ia<006DC00L=4a<C41<0008C00<@4a<0h1<00`0C4`054`03

3A<C06PC001V4`053A<C41<00P000a<@4`214`<0;A<502/C00<04a<011<00`dC4`0T4`D0;A<3010C

001V4`063A<C41<00Q<00a0C4`204`0301<C02lC00<04a<0:a<200@C00<=4a<09a<00`0C4`0]4`03

01<C010C001W4`053A0C4`000a<00a0C4`1j4`<00a<00`0C4`0X4`<00a<00`0C4`0[4`0301<C00<C

00<=4a<09a<00`0C4`0^4`0301<C00lC001X4`043A<C00<C00<@4a<0P1<00`0C4`0^4`0301<C02/C

00<04a<00Q<00`dC4`0X4`0301<C02hC00<04a<03a<006PC00<=4a<00P024`0341<C07lC00<04`00

;a<00`0C4`0[4`0501<C4`d0:a<00`0C4`0]4`0301<0010C001W4`0541<=4`0011<00a0C4`1o4`03

01<C02dC0P0]4`0401<C3B/C0P0`4`0301<C00lC001L4`0301<C008C00<04a<00Q<01P0@4a<=00@C

00<@4a<0gQ<200034`dC06hC001K4`0301<000LC00<040000Q<00`d04`034`0341<C0=hC00<04`d0

L1<005/C00<04`0021<00a004`024`033@0C00<C00<@4a<0gA<00`0=4`1`4`00Fa<00`0C00074`03

010C00<C00<03A<00a<00a0C4`3M4`0300dC06`C0P024`00Fa<00`0C00074`0341<C00<C00<03A<0

11<00a0C4`3L4`0300dC06/C00<04a<00Q<005`C00<04a<01Q<00a0000034`0301<=00@C00<@4a<0

MQ=V00033@0006@01a<00`0C4`024`00I1<00a0C4`044`8000<C3A<00Q<00a0C4`1k4`0301<C00LC

00<04a<01Q<00`0C4`074`0301<C00LC00<04a<01a<00`0C4`064`0301<C00LC00<04a<01a<00`0C

4`064`0301<C00LC00<=4a<01a<00`0C4`074`0301<C00HC00<04a<01a<00`0C4`074`0301<C00HC

00<04a<01a<00`0C4`074`0301<C00HC00<04a<01a<00`0C4`0:4`0301<C008C001T4`0341<C00@C

00@04a<=11<00a0C4`3J4`033@0C06`C00<04`000Q<006<C00<@4a<01A<01@0C4a<=00<C00<@4a<0

fA<00`dC001]4`<00Q<006<C00<@4a<01A<00`0C4`024`053A<C4a00fQ<00`dC001b4`00HQ<00a0C

4`064`0301<C00<C00@=4a<@fQ<010dC001a4`00HQ<00a0C4`064`8011<01@dC4a<@0=TC00<=4`00

LQ<0064C00<@4a<01a<00`0C4`044`043A<C4=TC00<=4`00LQ<0064C00<@4a<01a<00`0C4`054`03

3A<@0=PC00@=4a<0LQ<0060C00<@4a<021<00`0C4`064`033A<@0=LC00<=4a<00P1a4`00H1<00a0C

4`084`801a<00`dC403F4`053A<C4`00LQ<005lC00<@4a<02A<00`0C4`074`033A<@0=DC00D=4a<C

001b4`00Ga<00a0C4`094`0301<C00PC00<=41<0e1<01@dC4a<0078C001N4`0341<C00XC00<04a<0

2A<00`d@4`3C4`053A<C4`00LQ<005hC00<@4a<02Q<200XC00<=41<0da<010dC4a<2074C001M4`03

41<C00/C00<04a<02Q<00`d@4`3B4`053A<C4`00LQ<005dC00<@4a<011<5008C00<04a<02a<00`dC

4`3A4`053A<C4`00LQ<005`C00<@4a<01a<00`0C4`024`0301<C00`C00<=4a<0d1<01@dC4a<0078C

001K4`0341<C00PC00<04a<00Q<200hC00<=4a<0ca<01@dC4a<0078C001K4`0341<C00PC00<04a<0

0Q<00`0C4`0=4`033A<C0<lC00@=4a<C0P1a4`00FQ<00a0C4`094`0301<C008C00<04a<03Q<00`dC

4`3>4`053A<C4`00LQ<005XC00<@4a<021<200@C00<04a<03a<00`dC4`3=4`053A<C4`00LQ<005TC

00<@4a<03a<2010C00<@3A<0`Q<00`0C4`024`0301<C008C00<03A<00Q<00`0C4`1`4`00F1<00a0C

4`0@4`0301<C010C00<=4a<0`1<00`0C00074`0301<=00<C00<04a<0L1<005PC00<@4a<041<00`0C

4`0A4`033A<C0;lC00<04`002A<010dC4a<2074C001G4`0341<C014C00<04a<04A<00a0=4`2o4`03

01<000LC0P001A<=4a<0078C001F4`0341<C018C0P0C4`0340dC0;hC00<04`001a<0100C4`d24`03

01<C070C001F4`0341<C018C00<04a<04a<00`dC4`2n4`0301<C00HC0`0011<=4`1b4`00EA<00a0C

4`0C4`0301<C01<C00<@3A<0ba<00`dC001b4`00E1<00a0C4`0D4`0301<C01@C00<@3A<0bQ<010dC

001a4`00Da<00a0C4`0E4`805A<00a0=4`3:4`033A<0078C001C4`0341<C01DC00<04a<05A<00a0=

4`394`033A<0078C001B4`0341<C01HC00<04a<05Q<00a0=4`394`033@0C074C001A4`0341<C01LC

00<04a<05Q<00a0C3@3:4`033A<C070C001A4`0341<C01LC0P0H4`0340dC0<TC00<=01<0L1<0050C

00<@4a<061<00`0C4`0G4`0341<=0<TC00<03A<0L1<004lC00<@4a<021<5008C00<04a<00Q<00`0C

4`024`0301<C01PC00<@4`d0b1<00`0=4`1`4`00Ca<00a0C4`0:4`0301<C00HC00<04`000a<00`0C

4`0I4`0340dC0<LC00<03A<0L1<004hC00<@4a<02a<00`0C4`084`0401<C4`806a<00a0=4`364`03

01<=070C001=4`0341<C00`C00<04a<01Q<200@C00<04a<06Q<00a0C3@364`8000<C3A<0KQ<004`C

00<@4a<03A<00`0C4`064`0301<C00<C00<04a<06a<00a0=4`354`0501<C4`d0KQ<004`C00<@4a<0

31<200PC0`034`0301<C01`C00<@3A<0a1<00`0C4`024`033A<C06/C001;4`0341<C01dC0P0N4`03

40dC0<<C00<04a<00Q<00`dC4`1[4`00BQ<00a0C4`0N4`0301<C01dC00<@3A<0`a<200@C00<=4a<0

JQ<004XC00<@4a<07Q<00`0C4`0N4`0340dC0<8C00<04a<00a<00`dC4`1Z4`00BA<00a0C4`0O4`03

01<C01lC00<@3A<0`A<00`0C4`044`033A<C06TC00184`0341<C020C0P0Q4`0340dC0;TC1@024`03

01<C00DC00<=4a<0J1<004LC00<@4a<08A<00`0C4`0Q4`033A<C0;XC00<04a<00Q<00`0C4`064`03

3A<C06LC00174`0341<C024C00<04a<08A<00a0=4`2j4`0301<C008C0P084`033A<C06HC00164`03

41<C028C00<04a<08Q<00a0=4`2i4`0301<C008C00<04a<021<00`dC4`1U4`00AA<00a0C4`0S4`80

91<00a0=4`2h4`0301<C008C00<04a<02A<00`dC4`1T4`00A1<00a0C4`0T4`0301<C02@C00<=4a<0

]Q<200@C00<04a<02Q<00`dC4`1S4`00A1<00a0C4`0T4`0301<C02@C00<@3A<0_1<00`0C4`0;4`03

3A<C068C00134`0341<C02DC00<04a<09A<00a0=4`2k4`803A<00`dC4`1Q4`00@Q<00a0C4`0V4`03

01<C02HC00<@3A<0^Q<00`0C4`0=4`033A<C060C00114`0341<C02LC0P0X4`0340dC0;TC00<04a<0

3Q<00`dC4`1O4`00@1<00a0C4`0X4`0301<C02PC00<=4a<0^1<00`0C4`0?4`033A<C05hC00104`03

41<C028C0`034`0301<C02TC00<=4a<0]a<00`0C4`0@4`8=GQ<003lC00<@4a<08a<00`0C4`034`03

01<C02TC00<@3A<0]a<201<C00<=4a<0Fa<003hC00<@4a<09A<00`0C4`024`80:a<00a0=4`2f4`03

01<C01<C00<=4a<0FQ<003dC00<@4a<09Q<00`0C4`024`0301<C02/C00<=4a<0]A<00`0C4`0D4`8=

FQ<003dC00<@4a<09A<00`0C00034`0301<C02`C00<=4a<0]1<00`0C4`0F4`033A<C05LC000l4`03

41<C02LC00<04a<00Q<00`0C4`0]4`033A<C0;<C00<04a<05a<00`dC4`1F4`00>a<00a0C4`0]4`80

;a<00`dC4`2b4`806A<23EHC000j4`0341<C02hC00<04a<0;Q<00`dC4`2b4`0301<C01XC00<=4a<0

Da<003XC00<@4a<0;Q<00`0C4`0_4`033A<C0;4C00<04a<06a<00`dC4`1B4`00>A<00a0C4`0_4`03

01<C030C00<=4a<0/1<00`0C4`0L4`8=DQ<003PC00<@4a<0<1<2034C00<=41<0/1<00`0C4`0N4`8=

D1<003LC00<@4a<0<A<00`0C4`0a4`033A<C0:lC0P0Q4`033A<C04dC000g4`0341<C034C00<04a<0

<Q<00`dC4`2^4`0301<C024C00<=4a<0C1<003HC00<@4a<0<Q<00`0C4`0c4`033A<C0:dC00<04a<0

8Q<23D`C000e4`0341<C03<C0P0d4`033A0C09`C1@024`0301<C008C00<04a<00Q<00`0C4`0T4`8=

BQ<003@C00<@4a<0=1<00`0C4`0d4`033A0C09dC00<04a<01Q<00`0C00034`0301<C02HC00<=4a<0

Aa<003<C00<@4a<0=A<00`0C4`0e4`033A0C09`C00<04a<021<0100C4a<202PC0Pe74`00<Q<00a0C

4`0f4`0301<C03HC00<=4a<0Va<00`0C4`064`8011<00`0C4`0Y4`033A<C04@C000a4`0341<C03LC

0P0g4`033A0C09/C00<04a<01Q<00`0C4`034`0301<C02XC0Pe44`00<1<00a0C4`0h4`0301<C03LC

00<=41<0VA<200PC0`034`0301<C02`C0Pe24`00;a<00a0C4`0Y4`<00a<00`0C4`024`0301<C008C

00<04a<0>1<00`d@4`2X4`80;a<23D0C000^4`0341<C02XC00<04a<01a<00`0C00034`0301<C03TC

00<=41<0Ya<00`0C4`0`4`8=?Q<002dC00<@4a<0;1<00`0C4`084`0401<C4`80>Q<00`dC402W4`03

01<C038C0Pdl4`00;1<00a0C4`0]4`0301<C00HC0P044`0301<C03XC00<=4a00YQ<00`0C4`0d4`03

3A<C03TC000[4`0341<C02dC00<04`001a<00`0C4`034`0301<C03/C00<=4a00YA<00`0C4`0e4`<=

>1<002XC00<@4a<0;a<00`0C4`064`<00a<00`0C4`0l4`033A<@0:@C0P0h4`<==Q<002TC00<@4a<0

?a<203dC00@=4a<@Xa<00`0C4`0i4`8==A<002PC00<@4a<0@1<00`0C4`0m4`043A<C4:8C00<04a<0

>a<23C<C000W4`0341<C044C00<04a<0?Q<010dC4a2Q4`0301<C03dC0Pda4`009Q<00a0C4`124`03

01<C03hC00D=4a<C402P4`0301<C03lC00<=4a<0;Q<002DC00<@4a<0@a<2040C00D=4a<C402O4`80

@A<33BdC000T4`0341<C04@C00<04a<0@1<01@dC4a<@09hC00<04a<0@a<23B/C000S4`0341<C04DC

00<04a<0@1<00`dC4`024`0341<C09/C00<04a<0AA<33BPC000S4`0341<C04DC00<04a<0@A<00`dC

4`024`0341<C09XC00<04a<0B1<23BHC000R4`0341<C04HC0P134`033A<C008C00<@4a<0VA<00`0C

4`1:4`<=8a<0024C00<@4a<0Aa<00`0C4`124`033A<C00<C00<@4a<0V1<204hC0PdQ4`0081<00a0C

4`184`0301<C04<C00<=4a<00a<00a0C4`2G4`0301<C04lC0PdO4`007a<00a0C4`194`0301<C04@C

00<=4a<00a<00a0C4`2F4`0301<C054C0`dL4`007Q<00a0C4`1:4`80AA<00`dC4`044`0341<C08lC

0`034`0301<C05@C0PdJ4`007A<00a0C4`1;4`0301<C04DC00<=4a<011<00a0C4`2>4`0301<C00<C

00<04a<0EQ<23APC000L4`0341<C04`C00<04a<0AQ<00`dC4`044`0341<C08hC00<04a<00Q<205TC

0PdF4`006a<00a0C4`174`8011<00`0C4`174`033A<C00@C00<@4a<0SA<00`0C4`024`0301<C05XC

0`dC4`006Q<00a0C4`1:4`0501<C4`00BA<00`dC4`054`0341<C08/C00<04`000a<00`0C4`1M4`8=

4A<001TC00<@4a<0BQ<00`0C4`024`80BA<00`dC4`044`0341<C08`C00<04a<00Q<00`0C4`1`4`00

Ia<00`0C4`3W4`0301<C070C001U4`0301<00>TC0P1a4`00IQ<00`0C4`3X4`0301<C070C000/4`<0

oa>F4`00;1<00`0C4`3o4iHC000]4`0301<C00DC00<04a<0oa>=4`00;A<0100C4a<300044`0C4`<0

oa>:4`00;1<00`0C00024`800Q<00`0C4`024`0301<C0?lCR1<002dC00<04a<00a<0100C4`024`03

01<C0?lCRA<003<C00@04a<00a<00`0C4`064`0301<C02DC0`0]4`0301<C0>HC00<04a<0<Q<00`0C

4`084`007A<300034`00008031<300@C0`084`0301<C02@C00@04a<04A<300034`0000800Q<00`0C

4`024`0301<C008C00<04a<01A<0100C4a<5008C00@04a<C0P034`801Q<20<<C00<04a<011<00`0C

4`0C4`0301<C01hC00<04a<01a<001`C00@04a<091<00`0C4`0S4`0401<C010C00@04a<01Q<00`0C

00074`0301<000@C1@034`0301<C00PC00H04a<04`044`0301<C0;4C00@04a<C10024`801Q<00`0C

4`034`0301<C008C00<04a<00Q<00`0C4`024`0301<C00DC00@04a<C1@024`0401<C4`800a<200HC

0P044`0401<C4`800A<10040000L4`0501<C01<010000a<0000H02/C0`0@4`0501<C01<0100011<0

4`094`0301<C00@C00<04a<00a<00`0C4`074`0701<C4`0C00044`0301<C0;0C00<04`001a<00`0C

4`044`D00a<01`0C4a<04`001a<00`0C00044`D00a<00`0C4`084`0601<C01<011<00`0C4`044`03

01<C008C00<04`000A<001dC0`1=4`0301<C00lC0`064`0301<000LC0P074`0301<C00<C00<04a<0

21<00`0C4`0200DC00<04a<0UQ<200034`0001DC00<04`000Q<400034`0C00LC00<04a<00a<01`0C

4a<04`002A<00`0C4`044`0301<C00<C00<04a<01a<01`0C4a<04`0011<00`0C4`044`0301<C00<C

0@014`4C000O4`0301<C04XC0P0C4`0301<C00@C00<04`001a<00`0C4`0<4`0301<C00HC00<04`00

0Q<00`0C4`044`0301<009LC00<04`005Q<00`0C00074`0301<C00HC00<04a<00a<01`0C4a<04`00

1a<200LC00<04a<00a<00`0C4`084`0301<C00801A<00`0C4`044`0301<C00<C0@014`4C000N4`80

H1<200LC00<04a<01Q<300/C0P094`0301<C008C0P044`<0V1<00`0C4`0E4`0301<000LC00<04`00

3A<01P0C4`0C00LC00<04a<031<00`0C4`064`0301<0008C00<04a<011<00`0C00034`0301<C00<C

00<04`000A<00?lCDQ<00`0C4`0F4`0301<C00HC0`0>4`0401<C00PC0`0;4`802A<00`0C4`024`80

11<3008C00<04a<00a<2004C0@010000:A<200HC0P3o4ahC00<04`00LA<002/C00<04a<00Q<00`0C

4`3o4adC0P000a<0001`4`00:Q<00`0C4`034`0301<C00DC00<04a<0oa>:4`00:a<00`0C4`024`03

01<C008C10034`<0oa>64`00:A<00`0C00044`0301<0008C0P000a<04`044`0301<C0?lCQ1<002XC

00<04a<00a<300@C00<04`000a<00`0C4`3o4hDC000g4`0301<000@C00<04a<0oa>44`00=A<300@C

0`3o4hHC003o4lDC003o4lDC003o4lDC003o4lDC003o4lDC0000\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-6.95686, -1.50603, 0.0206072, 0.0206072}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -84.5 0 ]

[.5 .96488 84.5 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -145.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.355) show

222.250000 19.500000 moveto

(C) show

227.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.23643 0 m

.26171 .03426 L

.30316 .09042 L

.34309 .14452 L

.3815 .19657 L

.42237 .25195 L

.46172 .30527 L

.49955 .35654 L

.53984 .41112 L

.57861 .46366 L

.61984 .51952 L

.65954 .57333 L

.69774 .62508 L

.73838 .68015 L

.77751 .73317 L

.81909 .78952 L

.85916 .84381 L

.89771 .89604 L

.93871 .9516 L

s

.93871 .9516 m

.93929 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.326203 0.238095 [

[.02381 .3137 -6 -9 ]

[.02381 .3137 6 0 ]

[.2619 .3137 -6 -9 ]

[.2619 .3137 6 0 ]

[.7381 .3137 -3 -9 ]

[.7381 .3137 3 0 ]

[.97619 .3137 -3 -9 ]

[.97619 .3137 3 0 ]

[1.025 .3262 0 -8 ]

[1.025 .3262 9 8 ]

[.4875 .08811 -12 -4.5 ]

[.4875 .08811 0 4.5 ]

[.4875 .20716 -24 -4.5 ]

[.4875 .20716 0 4.5 ]

[.4875 .44525 -18 -4.5 ]

[.4875 .44525 0 4.5 ]

[.4875 .5643 -6 -4.5 ]

[.4875 .5643 0 4.5 ]

[.4875 .68335 -18 -4.5 ]

[.4875 .68335 0 4.5 ]

[.4875 .80239 -6 -4.5 ]

[.4875 .80239 0 4.5 ]

[.5 .85826 -4.5 0 ]

[.5 .85826 4.5 16 ]

[.5 .84576 -137 0 ]

[.5 .84576 137 16 ]

[ 0 0 0 0 ]

[ 1 .83326 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .3262 m

.02381 .33245 L

s

[(-2)] .02381 .3137 0 1 Mshowa

.2619 .3262 m

.2619 .33245 L

s

[(-1)] .2619 .3137 0 1 Mshowa

.7381 .3262 m

.7381 .33245 L

s

[(1)] .7381 .3137 0 1 Mshowa

.97619 .3262 m

.97619 .33245 L

s

[(2)] .97619 .3137 0 1 Mshowa

.125 Mabswid

.07143 .3262 m

.07143 .32995 L

s

.11905 .3262 m

.11905 .32995 L

s

.16667 .3262 m

.16667 .32995 L

s

.21429 .3262 m

.21429 .32995 L

s

.30952 .3262 m

.30952 .32995 L

s

.35714 .3262 m

.35714 .32995 L

s

.40476 .3262 m

.40476 .32995 L

s

.45238 .3262 m

.45238 .32995 L

s

.54762 .3262 m

.54762 .32995 L

s

.59524 .3262 m

.59524 .32995 L

s

.64286 .3262 m

.64286 .32995 L

s

.69048 .3262 m

.69048 .32995 L

s

.78571 .3262 m

.78571 .32995 L

s

.83333 .3262 m

.83333 .32995 L

s

.88095 .3262 m

.88095 .32995 L

s

.92857 .3262 m

.92857 .32995 L

s

.25 Mabswid

0 .3262 m

1 .3262 L

s

gsave

1.025 .3262 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .08811 m

.50625 .08811 L

s

[(-1)] .4875 .08811 1 0 Mshowa

.5 .20716 m

.50625 .20716 L

s

[(-0.5)] .4875 .20716 1 0 Mshowa

.5 .44525 m

.50625 .44525 L

s

[(0.5)] .4875 .44525 1 0 Mshowa

.5 .5643 m

.50625 .5643 L

s

[(1)] .4875 .5643 1 0 Mshowa

.5 .68335 m

.50625 .68335 L

s

[(1.5)] .4875 .68335 1 0 Mshowa

.5 .80239 m

.50625 .80239 L

s

[(2)] .4875 .80239 1 0 Mshowa

.125 Mabswid

.5 .11192 m

.50375 .11192 L

s

.5 .13573 m

.50375 .13573 L

s

.5 .15954 m

.50375 .15954 L

s

.5 .18335 m

.50375 .18335 L

s

.5 .23097 m

.50375 .23097 L

s

.5 .25477 m

.50375 .25477 L

s

.5 .27858 m

.50375 .27858 L

s

.5 .30239 m

.50375 .30239 L

s

.5 .35001 m

.50375 .35001 L

s

.5 .37382 m

.50375 .37382 L

s

.5 .39763 m

.50375 .39763 L

s

.5 .42144 m

.50375 .42144 L

s

.5 .46906 m

.50375 .46906 L

s

.5 .49287 m

.50375 .49287 L

s

.5 .51668 m

.50375 .51668 L

s

.5 .54049 m

.50375 .54049 L

s

.5 .58811 m

.50375 .58811 L

s

.5 .61192 m

.50375 .61192 L

s

.5 .63573 m

.50375 .63573 L

s

.5 .65954 m

.50375 .65954 L

s

.5 .70716 m

.50375 .70716 L

s

.5 .73097 m

.50375 .73097 L

s

.5 .75477 m

.50375 .75477 L

s

.5 .77858 m

.50375 .77858 L

s

.5 .0643 m

.50375 .0643 L

s

.5 .04049 m

.50375 .04049 L

s

.5 .01668 m

.50375 .01668 L

s

.5 .8262 m

.50375 .8262 L

s

.25 Mabswid

.5 0 m

.5 .83326 L

s

gsave

.5 .85826 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .84576 -198 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.355) show

298.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

303.000000 15.000000 moveto

(L) show

310.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

317.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

324.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

329.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

333.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .83326 L

0 .83326 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .15254 m

.02576 .15254 L

.03156 .15256 L

.04112 .15259 L

.05428 .15264 L

.07081 .15269 L

.09042 .15277 L

.11279 .15285 L

.13752 .15296 L

.1642 .15308 L

.19237 .15323 L

.22155 .1534 L

.25123 .1536 L

.28092 .15383 L

.31009 .15408 L

.33826 .15437 L

.36494 .1547 L

.38968 .15505 L

.41205 .15543 L

.43166 .15581 L

.44819 .15619 L

.46135 .15653 L

.47091 .15681 L

.47671 .15699 L

.47866 .15705 L

s

.47866 .15705 m

.47921 .15707 L

.48085 .15713 L

.48355 .15722 L

.48726 .15735 L

.49193 .15752 L

.49747 .15774 L

.50378 .15801 L

.51077 .15833 L

.5183 .15871 L

.52626 .15916 L

.5345 .15968 L

.54288 .16029 L

.55126 .161 L

.5595 .16182 L

.56746 .16278 L

.57499 .16388 L

.58198 .16516 L

.58829 .16664 L

.59383 .16834 L

.5985 .1703 L

.60222 .17255 L

.60492 .17512 L

.60656 .17806 L

.60711 .18139 L

s

.47866 .41072 m

.47921 .39728 L

.48085 .38383 L

.48355 .37046 L

.48726 .35723 L

.49193 .34421 L

.49747 .33142 L

.50378 .31894 L

.51077 .30679 L

.5183 .29502 L

.52626 .28368 L

.5345 .2728 L

.54288 .26242 L

.55126 .25255 L

.5595 .24324 L

.56746 .23449 L

.57499 .22632 L

.58198 .21873 L

.58829 .21174 L

.59383 .20532 L

.5985 .19948 L

.60222 .19419 L

.60492 .18944 L

.60656 .18519 L

.60711 .18142 L

s

.47866 .41083 m

.47921 .42426 L

.48085 .43766 L

.48355 .45093 L

.48726 .46403 L

.49193 .47688 L

.49747 .48945 L

.50378 .50167 L

.51077 .5135 L

.5183 .52488 L

.52626 .53577 L

.5345 .54613 L

.54288 .5559 L

.55126 .56506 L

.5595 .57355 L

.56746 .58134 L

.57499 .58841 L

.58198 .59472 L

.58829 .60024 L

.59383 .60495 L

.5985 .60883 L

.60222 .61187 L

.60492 .61405 L

.60656 .61536 L

.60711 .6158 L

s

.60711 .6158 m

.60792 .61644 L

.61034 .61835 L

.61432 .62146 L

.6198 .62566 L

.62669 .63083 L

.63487 .6368 L

.64419 .64343 L

.6545 .65054 L

.66562 .65798 L

.67736 .6656 L

.68952 .67325 L

.70189 .68082 L

.71426 .68818 L

.72642 .69522 L

.73816 .70186 L

.74928 .70801 L

.75959 .7136 L

.76891 .71857 L

.77708 .72286 L

.78397 .72643 L

.78945 .72924 L

.79344 .73127 L

.79586 .7325 L

.79667 .73291 L

s

.79667 .12284 m

.79744 .1193 L

.79973 .11536 L

.8035 .11102 L

.8087 .10631 L

.81522 .10125 L

.82296 .09589 L

.83179 .09027 L

.84155 .08445 L

.85208 .07851 L

.8632 .07251 L

.87471 .06653 L

.88643 .06064 L

.89815 .05492 L

.90966 .04944 L

.92078 .04426 L

.93131 .03945 L

.94107 .03507 L

.9499 .03117 L

.95764 .02779 L

.96416 .02497 L

.96936 .02274 L

.97313 .02114 L

.97542 .02016 L

.97619 .01984 L

s

.79667 .12286 m

.79744 .12601 L

.79973 .1288 L

.8035 .13125 L

.8087 .13337 L

.81522 .13522 L

.82296 .1368 L

.83179 .13817 L

.84155 .13934 L

.85208 .14034 L

.8632 .1412 L

.87471 .14194 L

.88643 .14257 L

.89815 .1431 L

.90966 .14356 L

.92078 .14394 L

.93131 .14427 L

.94107 .14454 L

.9499 .14477 L

.95764 .14496 L

.96416 .1451 L

.96936 .14521 L

.97313 .14529 L

.97542 .14534 L

.97619 .14535 L

s

.79667 .73291 m

.79744 .73329 L

.79973 .73445 L

.8035 .73634 L

.8087 .73892 L

.81522 .74214 L

.82296 .74592 L

.83179 .75017 L

.84155 .75482 L

.85208 .75976 L

.8632 .7649 L

.87471 .77014 L

.88643 .7754 L

.89815 .78059 L

.90966 .78562 L

.92078 .7904 L

.93131 .79489 L

.94107 .79899 L

.9499 .80267 L

.95764 .80587 L

.96416 .80854 L

.96936 .81065 L

.97313 .81218 L

.97542 .81311 L

.97619 .81342 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCaA<00?lCDQ<00`0C4`1`4`00I1<50>PC00<04a<0L1<006HC00<04a<0j1<00`0C4`1`4`00

?Q<00`dC4`0O4`<00a<00`0C4`024`80i1<00`0C4`1`4`00?a<00`dC4`0T4`0301<C008C00<04a<0

ha<205lC00<=4a<03a<003lC00<=4a<091<00`0C4`024`0301<C0><C00<04a<0G1<23A8C00104`03

3A<C028C0P044`0301<C0><C00<04a<0FQ<23A@C00114`033A<C02LC0P3T4`0301<C05LC0`dF4`00

@A<00`dC4`0W4`0301<C0><C0P1F4`8=6A<0048C00<=4a<09Q<00`0C4`3S4`0301<C05<C0PdK4`00

@a<00`dC4`0U4`0301<C0><C00<04a<0D1<33AdC00134`033A<C02DC0P3T4`0301<C04hC0PdP4`00

A1<00`dC4`0T4`0301<C0><C00<04a<0CA<00`dC4`0P4`00AA<00`dC4`0S4`0301<C0><C0P1<4`8=

8a<004DC00<=4a<08a<00`0C4`3S4`0301<C04TC0PdU4`00AQ<00`dC4`0R4`80i1<00`0C4`174`8=

9a<004LC00<=4a<08A<00`0C4`3L4`D00Q<00`0C4`154`8=:A<004PC00<=4a<081<00`0C4`3N4`03

01<C008C00<04a<0@a<23B/C00184`033A<C020C00<04a<0f1<300<C00<04a<00Q<204<C00<=4a<0

:a<004TC00<=4a<07a<20=lC00<04a<00Q<00`0C4`114`033A<C02`C001:4`033A<C01hC00<04a<0

gQ<00`0C4`024`0301<C03lC0Pd_4`00Ba<00`dC4`0>4`0301<C008C00<04a<00Q<00`0C4`024`03

01<C0=dC0P044`0301<C03dC0Pda4`00Ba<00`dC4`0=4`0301<000LC00<04`000a<00`0C4`3S4`03

01<C03`C00<=4a<0<A<004`C00<=4a<01a<3008C00<04`002A<0100C4a<20>@C0P0l4`033A<C038C

001=4`033A<C00/C00<04`001a<200@C00<04a<0ha<00`0C4`0j4`033A<C03<C001>4`033A<C00XC

00<04`001a<00`0C4`034`0301<C0><C00<04a<0>Q<00`dC4`0c4`00CQ<00`dC4`0;4`0301<C00HC

0`034`0301<C0><C00<04a<0>Q<00`dC4`0c4`00Ca<00`dC4`0I4`0301<C0><C00<04a<0>a<23C<C

001@4`033A<C01PC0P3T4`80?Q<53BhC001A4`033A<C01LC00<04a<0ha<00`0C4`124a8=71<0058C

00<=4a<05Q<00`0C4`3S4`0301<C05@C2`dA4`00DQ<00`dC4`0F4`0301<C088C<@d`4`0301<C070C

001C4`033A<C01DC0P2d4c<=L1<005@C00<=4a<051<00`0C4`3S4`8000<C3@d02PeT4`006Q<302DC

1@0>4`033A<C01<C00<04a<091<502@C0`2C4`0301<C00`C1@eO4`006Q<00`0C4`0W4`0301<C00hC

00<=4a<04a<00`0C4`0V4`0301<C02@C00<04a<0Ta<00`0C4`0A4`8=GA<001DC0`034`0301<C020C

0`034`0301<C00lC00<=4a<04Q<202LC00<04a<09A<00`0C4`2B4`0301<C018C0PeL4`006a<00`0C

4`0V4`0301<C010C00<=4a<04A<00`0C4`0V4`0301<C02DC00<04a<0TQ<00`0C4`0C4`033A<C05XC

000J4`0301<002LC00<04a<04A<00`dC4`0@4`0301<C02HC00<04a<091<00`0C002C4`8051<00`dC

4`1J4`006a<00`0C4`0U4`8051<00`dC4`0?4`0301<C02DC0P0W4`0301<C098C00<04a<04Q<00`dC

4`1K4`00FA<00`dC4`0?4`80eA<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`0B4`033A<C05/C

001J4`033A<C00hC00<04a<0da<00`0C00074`0301<000<C00<04a<04A<00`dC4`1L4`00Fa<00`dC

4`0=4`0301<C05/C0P1a4`<00Q<00`0C00094`0401<C4`804A<00`dC4`1M4`00G1<00`dC4`0<4`03

01<C05XC00<04a<0MQ<00`0C00074`8011<00`0C4`0?4`033A<C05hC000E4dL000<=0000H`064`03

01<C07HC00<04`001a<00`0C4`034`0301<C00hC00<=4a<0Ga<001TC00<04a<01Q<00`0C4`054`03

01<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`0301<=00DC00<04a<0

1A<00a0C4`054`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`03

01<C00HC00<04a<01A<00`0C4`054`0301<C00PC00<04a<0Ma<00`0C4`064`<00a<00`0C4`0>4`03

3A<C05lC001N4`033A<C00XC00<@4a<0FQ<00`0C00264`0301<C00`C0PeR4`00Ga<00`dC4`094`8@

Fa<308HC0P0<4`033A<C068C001P4`033A<C00PC0Q3T4`0301<C00/C00<=4a<0HQ<0060C00<=4a<0

1a<00a00403T4`0301<C00XC00<=4a<0Ha<0064C00<=4a<01Q<00a00403T4`0301<C00TC00<=4a<0

I1<0068C00<=4a<01A<00a00403T4`0301<C00PC00<=4a<0IA<006<C00<=4a<00a<01A0C000@0><C

0P094`033A<C06DC001S4`033A<C00<C00D@4`0C403S4`0301<C00LC00<=4a<0IQ<006@C00<=4a<0

0Q<01A0C01<@0><C00<04a<01Q<00`dC4`1W4`00IA<01`dC4a<@4`000Q<00a0C4`3P4`0301<C00DC

00<=4a<0J1<006HC00D=4a<@4`0200034a0C084C0`0]4`D0:a<00`0C4`044`033A<C02@C1@0]4`<0

41<006HC00H=4a<@4`024`0341<C080C00<04a<0;a<00`0C4`0[4`8011<00`dC4`0W4`0301<C02dC

00<04a<041<006LC00D=41<C00034`0341<C07XC0`034`0301<C02PC0`034`0301<C02/C00<04a<0

0Q<00`dC4`0X4`0301<C02hC00<04a<03a<006PC00@=4a<00a<00a0C4`204`0301<C02hC00<04a<0

:a<01@0C4a<=02/C00<04a<0;Q<00`0C4`0?4`00J1<00`dC4`02008C00<@4a<0Oa<00`0C000_4`03

01<C02/C00D04a<C3@0[4`0301<C02dC00<04`0041<006LC00D@4`dC00044`0341<C07lC00<04a<0

;A<202dC00@04a<=:a<2030C00<04a<03a<005`C00<04a<00Q<00`0C4`024`06010C4`d011<00a0C

4`3N4`8000<C3A<0KQ<005/C00<04`001a<00`0@00024`033@0C00<C00<@4a<0gQ<00`0C3@1`4`00

Fa<00`0C00084`03400C008C00<=01<00a<00a0C4`3M4`0300dC070C001K4`0301<000LC00<041<0

0a<00`0=4`034`0341<C0=dC00<03A<0K1<2008C001K4`0301<000LC00<@4a<00a<00`0=4`044`03

41<C0=`C00<03A<0Ja<00`0C4`024`00G1<00`0C4`064`03400000<C00<04`d011<00a0C4`1f4fH0

00<=0000I0074`0301<C008C001T4`0341<C00@C0P000a<=4`024`0341<C07/C00<04a<0;Q<00`0C

4`0]4`033A<C02hC00<04a<0;A<00`0C4`0:4`0301<C008C001T4`0341<C00@C00@04a<=11<00a0C

4`3J4`033@0C06`C00<04`000Q<006<C00<@4a<01A<01@0C4a<=00<C00<@4a<0fA<00`dC001]4`<0

0Q<006<C00<@4a<01A<00`0C4`024`053A<C4a00fQ<010dC001a4`00HQ<00a0C4`064`0301<C00<C

00@=4a<@fA<010dC4`1b4`00HQ<00a0C4`064`8011<01@dC4a<@0=PC00@=4a<0LQ<0064C00<@4a<0

1a<00`0C4`044`043A<C4=PC00@=4a<0LQ<0064C00<@4a<01a<00`0C4`054`033A<@0=PC00@=4a<0

LQ<0060C00<@4a<021<00`0C4`064`033A<@0=LC00<=4a<00P1a4`00H1<00a0C4`084`801a<00`dC

403F4`053A<C4`00LQ<005lC00<@4a<02A<00`0C4`074`033A<@0=DC00D=4a<C001b4`00Ga<00a0C

4`094`0301<C00PC00<=41<0e1<01@dC4a<0078C001N4`0341<C00XC00<04a<02A<00`d@4`3C4`05

3A<C4`00LQ<005hC00<@4a<02Q<200XC00<=41<0da<010dC4a<2074C001M4`0341<C00/C00<04a<0

2Q<00`d@4`3B4`053A<C4`00LQ<005dC00<@4a<011<5008C00<04a<02a<00`dC4`3A4`053A<C4`00

LQ<005`C00<@4a<01a<00`0C4`024`0301<C00`C00<=4a<0d1<01@dC4a<0078C001K4`0341<C00PC

00<04a<00Q<200hC00<=4a<0ca<01@dC4a<0078C001K4`0341<C00PC00<04a<00Q<00`0C4`0=4`03

3A<C0<lC00@=4a<C0P1a4`00FQ<00a0C4`094`0301<C008C00<04a<03Q<00`dC4`3>4`053A<C4`00

LQ<005XC00<@4a<021<200@C00<04a<03a<00`dC4`3=4`053A<C4`00LQ<005TC00<@4a<03a<2010C

00<@3A<0`Q<00`0C4`024`0301<C008C00<03A<00Q<00`0C4`1`4`00F1<00a0C4`0@4`0301<C010C

00<=4a<0`1<00`0C00074`0301<=00<C00<04a<0L1<005PC00<@4a<041<00`0C4`0A4`033A<C0;lC

00<04`002A<0100=4a<2074C001G4`0341<C014C00<04a<04A<00a0=4`2o4`0301<000LC0P001A<=

4a<0078C001F4`0341<C018C0P0C4`0340dC0;hC00<04`001a<0100C4`d24`0301<C070C001F4`03

41<C018C00<04a<04a<00a0=4`2n4`0301<C00HC0`0010dC4`1b4`00EA<00a0C4`0C4`0301<C01<C

00<@3A<0bQ<010dC4`1b4`00E1<00a0C4`0D4`0301<C01@C00<@3A<0bA<00`dC4`02074C001C4`03

41<C01DC0P0E4`0341<=0<XC00<=4`00LQ<005<C00<@4a<05A<00`0C4`0E4`0341<=0<XC00<=01<0

LA<0058C00<@4a<05Q<00`0C4`0F4`0340dC0<TC00<=01<0LA<0054C00<@4a<05a<00`0C4`0F4`03

41<=0<XC00<=4a<0L1<0054C00<@4a<05a<201PC00<@4`d0bA<00`d04`1`4`00D1<00a0C4`0H4`03

01<C01LC00@@4a<=b1<00`0=4`1`4`00Ca<00a0C4`084`D00Q<00`0C4`024`0301<C008C00<04a<0

61<00a0C3@384`0300dC070C001?4`0341<C00XC00<04a<01Q<00`0C00034`0301<C01TC00<@4`d0

aa<00`0C3@1`4`00CQ<00a0C4`0;4`0301<C00PC00@04a<C0P0K4`0341<=0<HC0P000`dC4`1^4`00

CA<00a0C4`0<4`0301<C00HC0P044`0301<C01XC00<@4`d0aQ<0100C4`e_4`00C1<00a0C4`0=4`03

01<C00HC00<04a<00a<00`0C4`0K4`0341<=0<DC00D04a<C3@1^4`00C1<00a0C4`0<4`8021<300<C

00<04a<071<00a0C3@344`0501<C4`d0KQ<004/C00<@4a<07A<201hC00<@3A<0`a<00`0C4`024`03

3A<C06/C001:4`0341<C01hC00<04a<07A<00a0C3@334`8011<00`dC4`1Z4`00BQ<00a0C4`0N4`03

01<C01hC00<@4`d0`Q<00`0C4`044`033A<C06TC00194`0341<C01lC00<04a<07a<00a0=4`314`03

01<C00DC00<=4a<0J1<004PC00<@4a<081<2024C00<@3A<0^A<5008C00<04a<01Q<00`dC4`1W4`00

Aa<00a0C4`0Q4`0301<C024C00<@3A<0^Q<00`0C4`024`0301<C00LC00<=4a<0IQ<004LC00<@4a<0

8A<00`0C4`0Q4`0340dC0;XC00<04a<00Q<200TC00<=4a<0IA<004HC00<@4a<08Q<00`0C4`0R4`03

40dC0;TC00<04a<00Q<00`0C4`084`033A<C06DC00154`0341<C02<C0P0T4`0340dC0;PC00<04a<0

0Q<00`0C4`094`033A<C06@C00144`0341<C02@C00<04a<091<00a0=4`2f4`8011<00`0C4`0:4`03

3A<C06<C00144`0341<C02@C00<04a<091<00a0=4`2l4`0301<C00/C00<=4a<0HQ<004<C00<@4a<0

9A<00`0C4`0U4`0340dC0;/C0P0=4`033A<C064C00124`0341<C02HC00<04a<09Q<00a0=4`2j4`03

01<C00dC0PeQ4`00@A<00a0C4`0W4`80:1<00a0=4`2i4`0301<C00lC00<=4a<0GQ<0040C00<@4a<0

:1<00`0C4`0X4`033A<C0;PC00<04a<041<00`dC4`1M4`00@1<00a0C4`0R4`<00a<00`0C4`0Y4`03

3A<C0;LC00<04a<04A<00`dC4`1L4`00?a<00a0C4`0S4`0301<C00<C00<04a<0:A<00a0=4`2g4`80

4a<00`dC4`1K4`00?Q<00a0C4`0U4`0301<C008C0P0[4`0340dC0;HC00<04a<04a<23E/C000m4`03

41<C02HC00<04a<00Q<00`0C4`0[4`033A<C0;DC00<04a<051<00`dC4`1I4`00?A<00a0C4`0U4`03

01<000<C00<04a<0;1<00`dC4`2d4`0301<C01DC0PeI4`00?1<00a0C4`0W4`0301<C008C00<04a<0

;A<00`dC4`2c4`0301<C01LC00<=4a<0EQ<003/C00<@4a<0;A<202lC00<=4a<0/Q<201TC0PeF4`00

>Q<00a0C4`0^4`0301<C02hC00<=4a<0/Q<00`0C4`0J4`033A<C05<C000j4`0341<C02hC00<04a<0

;a<00`dC4`2a4`0301<C01/C0PeC4`00>A<00a0C4`0_4`0301<C030C00<=4a<0/1<00`0C4`0M4`03

3A<C050C000h4`0341<C030C0P0a4`033A0C0;0C00<04a<07Q<23E0C000g4`0341<C034C00<04a<0

<A<00`dC4`2_4`808A<00`dC4`1=4`00=a<00a0C4`0a4`0301<C038C00<=4a<0[Q<00`0C4`0Q4`8=

CA<003HC00<@4a<0<Q<00`0C4`0c4`033A<C09`C1@024`0301<C008C00<04a<00Q<00`0C4`0S4`8=

Ba<003DC00<@4a<0<a<203@C00<=41<0WQ<00`0C4`064`0301<000<C00<04a<09A<00`dC4`184`00

=1<00a0C4`0d4`0301<C03@C00<=41<0WA<00`0C4`084`0401<C4`809a<23DPC000c4`0341<C03DC

00<04a<0=A<00`d@4`2L4`0301<C00HC0P044`0301<C02PC0Pe64`00<Q<00a0C4`0f4`0301<C03HC

00<=4a<0Va<00`0C4`064`0301<C00<C00<04a<0:Q<00`dC4`134`00<A<00a0C4`0g4`80=a<00`d@

4`2J4`8021<300<C00<04a<0:a<23D<C000`4`0341<C03PC00<04a<0=a<00`d@4`2Y4`0301<C02dC

0Pe14`00;a<00a0C4`0Y4`<00a<00`0C4`024`0301<C008C00<04a<0>1<00`d@4`2X4`80<1<23ClC

000^4`0341<C02XC00<04a<01a<00`0C00034`0301<C03TC00<=41<0Ya<00`0C4`0a4`033A<C03`C

000]4`0341<C02`C00<04a<021<0100C4a<203XC00<=4a00Ya<00`0C4`0b4`033A<C03/C000/4`03

41<C02dC00<04a<01Q<200@C00<04a<0>Q<00`dC402V4`0301<C03<C10di4`00:a<00a0C4`0]4`03

01<000LC00<04a<00a<00`0C4`0k4`033A<@0:DC00<04a<0=a<00`dC4`0f4`00:Q<00a0C4`0_4`03

01<C00HC0`034`0301<C03`C00<=4a00Y1<203TC0Pdf4`00:A<00a0C4`0o4`80?A<010dC4a2S4`03

01<C03XC0Pdd4`00:1<00a0C4`104`0301<C03dC00@=4a<@XQ<00`0C4`0l4`8=<Q<002LC00<@4a<0

@A<00`0C4`0n4`043A<C4:4C00<04a<0?Q<23C0C000V4`0341<C048C00<04a<0?Q<01@dC4a<@0:0C

00<04a<0@1<23BhC000U4`0341<C04<C0P104`053A<C4a00Wa<204<C0Pd/4`0091<00a0C4`144`03

01<C040C00D=4a<C402N4`0301<C04@C0PdZ4`008a<00a0C4`154`0301<C040C00<=4a<00Q<00a0C

4`2K4`0301<C04HC0PdX4`008a<00a0C4`154`0301<C044C00<=4a<00Q<00a0C4`2J4`0301<C04PC

0`dU4`008Q<00a0C4`164`80@a<00`dC4`024`0341<C09TC00<04a<0Ba<23B<C000Q4`0341<C04LC

00<04a<0@a<00`dC4`024`0341<C09PC0P1>4`<=81<0020C00<@4a<0B1<00`0C4`134`033A<C00<C

00<@4a<0Ua<00`0C4`1@4`8=7Q<001lC00<@4a<0BA<00`0C4`144`033A<C00<C00<@4a<0UQ<00`0C

4`1B4`8=71<001hC00<@4a<0BQ<204HC00<=4a<00a<00a0C4`2?4`<00a<00`0C4`1D4`8=6Q<001dC

00<@4a<0Ba<00`0C4`164`033A<C00<C00<@4a<0SQ<00`0C4`034`0301<C05HC0PdH4`0071<00a0C

4`1<4`0301<C04HC00<=4a<011<00a0C4`2>4`0301<C008C0P1I4`<=5A<001/C00<@4a<0Aa<200@C

00<04a<0Aa<00`dC4`044`0341<C08dC00<04a<00Q<00`0C4`1K4`<=4Q<001XC00<@4a<0BQ<01@0C

4a<004XC00<=4a<011<00a0C4`2;4`0301<000<C00<04a<0GQ<00`dC4`0?4`006A<00a0C4`1:4`03

01<C008C0P1:4`033A<C00<C00<@4a<0S1<00`0C4`024`0301<C070C001W4`0301<C0>LC00<04a<0

L1<006DC00<04`00jA<2074C001V4`0301<C0>PC00<04a<0L1<002XC0`3o4iPC000Z4`0301<C0?lC

V1<002/C00<04a<011<00`0C4`3o4i0C000[4`0401<C4`@00a<30?lCS1<002XC00<04`000Q<20003

4`0C00@C00<04a<0oa>:4`00:a<00`0C4`034`0301<000<C00<04a<0oa>;4`00<A<00`0C00044`03

01<C00HC00<04a<09a<302/C00<04a<0iA<00`0C4`0g4`0301<C00HC000K4`<000<C00000P0<4`<0

11<300PC00<04a<09Q<0100C4`0?4`<000<C00000P024`0301<C008C00<04a<00Q<00`0C4`054`04

01<C4`D00Q<0100C4a<200@C00<04a<00Q<00`0C4`044`80_A<00`0C4`044`0301<C01<C00<04a<0

8a<00`0C4`054`006Q<0100C4`0T4`0301<C02DC00@04a<03Q<0100C4`064`0301<000LC00<04`00

11<500<C00<04a<021<01P0C4`0C008C00<04`0011<00`0C4`2[4`0401<C4`@00Q<200HC00<04a<0

0a<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`054`0401<C4`D00Q<0100C4a<200@C00<04a<0

0Q<00`0C4`044`8011<0100C4a<2004C000J4`0501<C01<010000a<0000H02dC0`0>4`0501<C01<0

100011<04`094`0301<C00@C00<04a<00a<00`0C4`074`0301<C00<C00<04a<00Q<00`0C4`024`03

01<C0:XC00<04`001a<00`0C4`044`D00a<01`0C4a<04`001a<00`0C00044`D00a<00`0C4`084`06

01<C01<00Q<00`0C00044`0301<C00@C00<04a<00Q<1004C000K4`<0Ca<00`0C4`0=4`<01Q<00`0C

00074`801a<00`0C4`034`0301<C00PC00<04a<00P034`801A<00`0C4`2C4`8000<C00004Q<00`0C

00024`@000<C01<01a<00`0C4`034`0701<C4`0C00094`0301<C00@C00<04a<00a<00`0C4`074`03

01<C00<C00<04a<00Q<00`0C4`024`0301<C00@C00<04a<00a<100007A<00`0C4`1<4`804A<00`0C

4`044`0301<000LC00<04a<031<00`0C4`064`0301<0008C00<04a<00Q<00`0C4`044`0301<009@C

00<04`004a<00`0C00074`0301<C00HC00<04a<00a<01`0C4a<04`001a<200LC00<04a<00a<00`0C

4`084`0301<C00800a<200DC00<04a<011<00`0C4`034`40000L4`80H1<200LC00<04a<01Q<300/C

0P094`0401<C4`<00Q<300@C0`2E4`0301<C018C00<04`001a<00`0C000=4`0601<C01<01a<00`0C

4`0<4`0301<C00HC00<04`000Q<00`0C4`024`0301<C00@C00<04`000a<00`0C4`034`400A<00?lC

DQ<00`0C4`0C4`0301<C00HC0`0>4`0401<C00PC0`0;4`802A<0100C4a<3008C0`044`<00Q<00`0C

4`034`800A<002HC0P064`80oa<Q4`0301<0074C000X4`0301<C008C00<04a<0oa<P4`8000<C0000

L1<002LC00<04a<00a<00`0C4`064`0301<C0?lCS1<002PC00<04a<00Q<00`0C4`024`<000@C01<C

0`3o4hTC000V4`0301<000@C00<04`000Q<2008C00<04a<00Q<00`0C4`3o4hLC000W4`0301<C00<C

0`044`0401<C008C00<04a<0oa>84`00=1<0100C4`034`0301<C0?lCQa<0038C0`044`<0oa>94`00

oa?54`00oa?54`00oa?54`00oa?54`00oa?54`00\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-6.95686, -1.50349, 0.0206072, 0.0206072}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -82 0 ]

[.5 .96488 82 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -143 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.35) show

217.250000 19.500000 moveto

(C) show

222.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.23545 0 m

.26171 .03545 L

.30316 .0914 L

.34309 .14531 L

.3815 .19717 L

.42237 .25234 L

.46172 .30546 L

.49955 .35654 L

.53984 .41093 L

.57861 .46327 L

.61984 .51892 L

.65954 .57253 L

.69774 .62409 L

.73838 .67896 L

.77751 .73178 L

.81909 .78792 L

.85916 .84201 L

.89771 .89405 L

.93871 .94941 L

s

.93871 .94941 m

.94092 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.324384 0.238095 [

[.02381 .31188 -6 -9 ]

[.02381 .31188 6 0 ]

[.2619 .31188 -6 -9 ]

[.2619 .31188 6 0 ]

[.7381 .31188 -3 -9 ]

[.7381 .31188 3 0 ]

[.97619 .31188 -3 -9 ]

[.97619 .31188 3 0 ]

[1.025 .32438 0 -8 ]

[1.025 .32438 9 8 ]

[.4875 .08629 -12 -4.5 ]

[.4875 .08629 0 4.5 ]

[.4875 .20534 -24 -4.5 ]

[.4875 .20534 0 4.5 ]

[.4875 .44343 -18 -4.5 ]

[.4875 .44343 0 4.5 ]

[.4875 .56248 -6 -4.5 ]

[.4875 .56248 0 4.5 ]

[.4875 .68153 -18 -4.5 ]

[.4875 .68153 0 4.5 ]

[.4875 .80057 -6 -4.5 ]

[.4875 .80057 0 4.5 ]

[.5 .85586 -4.5 0 ]

[.5 .85586 4.5 16 ]

[.5 .84336 -134.5 0 ]

[.5 .84336 134.5 16 ]

[ 0 0 0 0 ]

[ 1 .83086 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .32438 m

.02381 .33063 L

s

[(-2)] .02381 .31188 0 1 Mshowa

.2619 .32438 m

.2619 .33063 L

s

[(-1)] .2619 .31188 0 1 Mshowa

.7381 .32438 m

.7381 .33063 L

s

[(1)] .7381 .31188 0 1 Mshowa

.97619 .32438 m

.97619 .33063 L

s

[(2)] .97619 .31188 0 1 Mshowa

.125 Mabswid

.07143 .32438 m

.07143 .32813 L

s

.11905 .32438 m

.11905 .32813 L

s

.16667 .32438 m

.16667 .32813 L

s

.21429 .32438 m

.21429 .32813 L

s

.30952 .32438 m

.30952 .32813 L

s

.35714 .32438 m

.35714 .32813 L

s

.40476 .32438 m

.40476 .32813 L

s

.45238 .32438 m

.45238 .32813 L

s

.54762 .32438 m

.54762 .32813 L

s

.59524 .32438 m

.59524 .32813 L

s

.64286 .32438 m

.64286 .32813 L

s

.69048 .32438 m

.69048 .32813 L

s

.78571 .32438 m

.78571 .32813 L

s

.83333 .32438 m

.83333 .32813 L

s

.88095 .32438 m

.88095 .32813 L

s

.92857 .32438 m

.92857 .32813 L

s

.25 Mabswid

0 .32438 m

1 .32438 L

s

gsave

1.025 .32438 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .08629 m

.50625 .08629 L

s

[(-1)] .4875 .08629 1 0 Mshowa

.5 .20534 m

.50625 .20534 L

s

[(-0.5)] .4875 .20534 1 0 Mshowa

.5 .44343 m

.50625 .44343 L

s

[(0.5)] .4875 .44343 1 0 Mshowa

.5 .56248 m

.50625 .56248 L

s

[(1)] .4875 .56248 1 0 Mshowa

.5 .68153 m

.50625 .68153 L

s

[(1.5)] .4875 .68153 1 0 Mshowa

.5 .80057 m

.50625 .80057 L

s

[(2)] .4875 .80057 1 0 Mshowa

.125 Mabswid

.5 .1101 m

.50375 .1101 L

s

.5 .13391 m

.50375 .13391 L

s

.5 .15772 m

.50375 .15772 L

s

.5 .18153 m

.50375 .18153 L

s

.5 .22915 m

.50375 .22915 L

s

.5 .25296 m

.50375 .25296 L

s

.5 .27677 m

.50375 .27677 L

s

.5 .30057 m

.50375 .30057 L

s

.5 .34819 m

.50375 .34819 L

s

.5 .372 m

.50375 .372 L

s

.5 .39581 m

.50375 .39581 L

s

.5 .41962 m

.50375 .41962 L

s

.5 .46724 m

.50375 .46724 L

s

.5 .49105 m

.50375 .49105 L

s

.5 .51486 m

.50375 .51486 L

s

.5 .53867 m

.50375 .53867 L

s

.5 .58629 m

.50375 .58629 L

s

.5 .6101 m

.50375 .6101 L

s

.5 .63391 m

.50375 .63391 L

s

.5 .65772 m

.50375 .65772 L

s

.5 .70534 m

.50375 .70534 L

s

.5 .72915 m

.50375 .72915 L

s

.5 .75296 m

.50375 .75296 L

s

.5 .77677 m

.50375 .77677 L

s

.5 .06248 m

.50375 .06248 L

s

.5 .03867 m

.50375 .03867 L

s

.5 .01486 m

.50375 .01486 L

s

.5 .82438 m

.50375 .82438 L

s

.25 Mabswid

.5 0 m

.5 .83086 L

s

gsave

.5 .85586 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .84336 -195.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.35) show

293.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

298.000000 15.000000 moveto

(L) show

305.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

312.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

319.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

324.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

328.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .83086 L

0 .83086 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .15026 m

.02576 .15027 L

.03156 .15029 L

.04112 .15032 L

.05428 .15037 L

.0708 .15043 L

.09042 .15051 L

.11278 .15061 L

.13751 .15072 L

.16419 .15086 L

.19236 .15102 L

.22154 .1512 L

.25122 .15142 L

.2809 .15166 L

.31008 .15195 L

.33825 .15226 L

.36493 .15261 L

.38966 .15299 L

.41202 .1534 L

.43164 .15382 L

.44816 .15423 L

.46132 .1546 L

.47088 .1549 L

.47669 .1551 L

.47863 .15517 L

s

.47863 .15517 m

.47917 .15519 L

.48079 .15524 L

.48345 .15534 L

.48712 .15548 L

.49172 .15567 L

.49718 .1559 L

.50341 .15618 L

.5103 .15652 L

.51773 .15693 L

.52558 .1574 L

.5337 .15796 L

.54197 .1586 L

.55024 .15935 L

.55837 .16022 L

.56621 .16122 L

.57364 .16238 L

.58053 .16371 L

.58676 .16524 L

.59222 .16701 L

.59683 .16903 L

.60049 .17134 L

.60316 .17399 L

.60477 .17699 L

.60531 .18038 L

s

.47863 .40894 m

.47917 .3956 L

.48079 .38224 L

.48345 .36897 L

.48712 .35584 L

.49172 .34291 L

.49718 .33021 L

.50341 .3178 L

.5103 .30573 L

.51773 .29404 L

.52558 .28276 L

.5337 .27193 L

.54197 .26159 L

.55024 .25177 L

.55837 .24248 L

.56621 .23374 L

.57364 .22558 L

.58053 .21799 L

.58676 .21098 L

.59222 .20455 L

.59683 .19867 L

.60049 .19335 L

.60316 .18854 L

.60477 .18424 L

.60531 .18041 L

s

.47863 .40905 m

.47917 .42237 L

.48079 .43567 L

.48345 .44884 L

.48712 .46183 L

.49172 .47458 L

.49718 .48704 L

.50341 .49917 L

.5103 .5109 L

.51773 .52219 L

.52558 .53299 L

.5337 .54326 L

.54197 .55296 L

.55024 .56203 L

.55837 .57046 L

.56621 .57819 L

.57364 .5852 L

.58053 .59145 L

.58676 .59693 L

.59222 .6016 L

.59683 .60545 L

.60049 .60846 L

.60316 .61062 L

.60477 .61192 L

.60531 .61236 L

s

.60531 .61236 m

.60617 .61304 L

.60871 .61505 L

.6129 .61834 L

.61867 .62277 L

.62592 .62821 L

.63452 .6345 L

.64432 .64146 L

.65516 .64892 L

.66686 .65671 L

.67921 .66468 L

.692 .67268 L

.70501 .68057 L

.71803 .68824 L

.73082 .69558 L

.74317 .70249 L

.75486 .70889 L

.76571 .7147 L

.77551 .71985 L

.78411 .72431 L

.79136 .72801 L

.79713 .73093 L

.80132 .73304 L

.80386 .73431 L

.80471 .73473 L

s

.80471 .1192 m

.80545 .1157 L

.80764 .11182 L

.81124 .10758 L

.8162 .10299 L

.82243 .09807 L

.82983 .09288 L

.83826 .08745 L

.84758 .08184 L

.85764 .07611 L

.86826 .07034 L

.87926 .06459 L

.89045 .05894 L

.90164 .05345 L

.91264 .04819 L

.92326 .04322 L

.93332 .03861 L

.94265 .0344 L

.95108 .03066 L

.95847 .02741 L

.9647 .02471 L

.96966 .02257 L

.97327 .02103 L

.97546 .02009 L

.97619 .01978 L

s

.80471 .11922 m

.80545 .12235 L

.80764 .12515 L

.81124 .12761 L

.8162 .12976 L

.82243 .13164 L

.82983 .13328 L

.83826 .13469 L

.84758 .13591 L

.85764 .13695 L

.86826 .13786 L

.87926 .13863 L

.89045 .1393 L

.90164 .13987 L

.91264 .14036 L

.92326 .14077 L

.93332 .14112 L

.94265 .14142 L

.95108 .14166 L

.95847 .14186 L

.9647 .14202 L

.96966 .14214 L

.97327 .14222 L

.97546 .14227 L

.97619 .14229 L

s

.80471 .73473 m

.80545 .7351 L

.80764 .73618 L

.81124 .73796 L

.8162 .7404 L

.82243 .74343 L

.82983 .747 L

.83826 .75102 L

.84758 .75541 L

.85764 .76008 L

.86826 .76495 L

.87926 .76992 L

.89045 .77491 L

.90164 .77984 L

.91264 .78461 L

.92326 .78916 L

.93332 .79342 L

.94265 .79733 L

.95108 .80083 L

.95847 .80388 L

.9647 .80643 L

.96966 .80844 L

.97327 .8099 L

.97546 .81078 L

.97619 .81108 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCaA<00?lCDQ<00`0C4`1`4`00I1<50>PC00<04a<0L1<006HC00<04a<0j1<00`0C4`1`4`00

?Q<00`dC4`0O4`<00a<00`0C4`024`80i1<2074C000o4`033A<C02@C00<04a<00Q<00`0C4`3S4`03

01<C05hC00<=4a<03a<003lC00<=4a<091<00`0C4`024`0301<C0><C00<04a<0G1<33A4C00104`03

3A<C028C0P044`0301<C0><C00<04a<0Fa<00`dC4`0B4`00@A<00`dC4`0W4`80i1<00`0C4`1G4`@=

5A<0044C00<=4a<09a<00`0C4`3S4`80EQ<23ATC00124`033A<C02HC00<04a<0ha<00`0C4`1C4`8=

6a<004<C00<=4a<09A<00`0C4`3S4`0301<C054C0PdM4`00@a<00`dC4`0U4`80i1<00`0C4`1?4`8=

7a<004@C00<=4a<091<00`0C4`3S4`0301<C04dC0PdQ4`00AA<00`dC4`0S4`0301<C0><C0P1<4`8=

8a<004DC00<=4a<08a<00`0C4`3S4`0301<C04XC00<=4a<08a<004HC00<=4a<08Q<20>@C00<04a<0

B1<23BHC00174`033A<C024C00<04a<0g1<5008C00<04a<0AQ<23BPC00184`033A<C020C00<04a<0

gQ<00`0C4`024`0301<C04@C0PdZ4`00B1<00`dC4`0P4`0301<C0=PC0`034`0301<C008C0P134`8=

;1<004TC00<=4a<07a<20=lC00<04a<00Q<00`0C4`104`8=;Q<004XC00<=4a<07Q<00`0C4`3N4`03

01<C008C00<04a<0?a<00`dC4`0^4`00Ba<00`dC4`0>4`0301<C008C00<04a<00Q<00`0C4`024`03

01<C0=dC0P044`0301<C03hC00<=4a<0;a<004/C00<=4a<03A<00`0C00074`0301<000<C00<04a<0

ha<00`0C4`0m4`033A<C030C001<4`033A<C00LC0`024`0301<000TC00@04a<C0P3T4`80?A<00`dC

4`0a4`00CA<00`dC4`0;4`0301<000LC0P044`0301<C0><C00<04a<0>a<00`dC4`0b4`00CQ<00`dC

4`0:4`0301<000LC00<04a<00a<00`0C4`3S4`0301<C03/C00<=4a<0<Q<004hC00<=4a<02a<00`0C

4`064`<00a<00`0C4`3S4`0301<C03`C0Pdb4`00Ca<00`dC4`0I4`0301<C0><C00<04a<0?Q<23C0C

001@4`033A<C01PC0P3T4`80@A<73BTC001A4`033A<C01LC00<04a<0ha<00`0C4`174aP=4A<0058C

00<=4a<05Q<00`0C4`3S4`0301<C070C001B4`033A<C01HC00<04a<0PQ=33AhC00<04a<0L1<005<C

00<=4a<05A<20<HC90e]4`00E1<00`dC4`0D4`0301<C0><C0P044`T=I1<001XC0`0U4`D03Q<00`dC

4`0C4`0301<C02@C1@0T4`<0Ta<00`0C4`0<4`D=Ga<001XC00<04a<09a<00`0C4`0>4`033A<C01<C

00<04a<09Q<00`0C4`0T4`0301<C09<C00<04a<04A<23EdC000E4`<00a<00`0C4`0P4`<00a<00`0C

4`0?4`033A<C018C0P0W4`0301<C02DC00<04a<0TQ<00`0C4`0B4`033A<C05/C000K4`0301<C02HC

00<04a<041<00`dC4`0A4`0301<C02HC00<04a<09A<00`0C4`2B4`8051<00`dC4`1J4`006Q<00`0C

000W4`0301<C014C00<=4a<041<00`0C4`0V4`0301<C02@C00<04`00Ta<00`0C4`0B4`033A<C05/C

000K4`0301<C02DC0P0D4`033A<C00lC00<04a<09A<202LC00<04a<0TQ<00`0C4`0B4`033A<C05/C

001I4`033A<C00lC0P3E4`0301<C008C00<04a<00Q<00`0C4`024`0301<C018C00<=4a<0Fa<005XC

00<=4a<03Q<00`0C4`3C4`0301<000LC00<04`000a<00`0C4`0A4`033A<C05`C001K4`033A<C00dC

00<04a<0Fa<2074C0`024`0301<000TC00@04a<C0P0A4`033A<C05dC001L4`033A<C00`C00<04a<0

FQ<00`0C4`1f4`0301<000LC0P044`0301<C00lC00<=4a<0GQ<001DCA`000`d0001S00HC00<04a<0

MQ<00`0C00074`0301<C00<C00<04a<03Q<00`dC4`1O4`006A<00`0C4`064`0301<C00DC00<04a<0

1A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04`d01A<00`0C4`054`03

41<C00DC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<0

1Q<00`0C4`054`0301<C00DC00<04a<021<00`0C4`1g4`0301<C00HC0`034`0301<C00hC00<=4a<0

Ga<005hC00<=4a<02Q<00a0C4`1J4`0301<008HC00<04a<031<23F8C001O4`033A<C00TC0Q1K4`<0

QQ<200`C00<=4a<0HQ<0060C00<=4a<021<24>@C00<04a<02a<00`dC4`1R4`00H1<00`dC4`074`03

400@0>@C00<04a<02Q<00`dC4`1S4`00HA<00`dC4`064`03400@0>@C00<04a<02A<00`dC4`1T4`00

HQ<00`dC4`054`03400@0>@C00<04a<021<00`dC4`1U4`00Ha<00`dC4`034`0541<00100ha<200PC

00<=4a<0IQ<006<C00<=4a<00a<01A0C01<@0><C00<04a<01Q<00`dC4`1W4`00I1<00`dC4`024`05

41<04a00ha<00`0C4`064`033A<C06LC001U4`073A<C4a0C00024`0341<C0>0C00<04a<01A<00`dC

4`1X4`00IQ<01@dC4a0C008000<C41<0PA<302dC1@0[4`0301<C00@C00<=4a<091<502dC0`0@4`00

IQ<01PdC4a0C008C00<@4a<0P1<00`0C4`0_4`0301<C02/C0P044`033A<C02LC00<04a<0;A<00`0C

4`0@4`00Ia<01@d@4a<000<C00<@4a<0NQ<300<C00<04a<0:1<300<C00<04a<0:a<00`0C4`024`03

3A<C02PC00<04a<0;Q<00`0C4`0?4`00J1<010dC4`034`0341<C080C00<04a<0;Q<00`0C4`0[4`05

01<C4`d0:a<00`0C4`0^4`0301<C00lC001X4`033A<C00800Q<00a0C4`1o4`0301<002lC00<04a<0

:a<01@0C4a<=02/C00<04a<0;A<00`0C000@4`00Ia<01A0C3A<000@C00<@4a<0Oa<00`0C4`0]4`80

;A<0100C4`d[4`80<1<00`0C4`0?4`00G1<00`0C4`024`0301<C008C00H041<C3@044`0341<C0=hC

0P000a<=4`1^4`00Fa<00`0C00074`030100008C00<=01<00a<00a0C4`3N4`0301<=070C001K4`03

01<000PC00<@01<00Q<00`d04`034`0341<C0=dC00<03A<0L1<005/C00<04`001a<00`0@4`034`03

00dC00<C00<@4a<0gA<00`0=4`1/4`800Q<005/C00<04`001a<00a0C4`034`0300dC00@C00<@4a<0

g1<00`0=4`1[4`0301<C008C001L4`0301<C00HC00<@00000a<00`0C3@044`0341<C07HCIP000`d0

001T00LC00<04a<00Q<006@C00<@4a<011<200034`dC008C00<@4a<0Na<00`0C4`0^4`0301<C02dC

00<=4a<0;Q<00`0C4`0]4`0301<C00XC00<04a<00Q<006@C00<@4a<011<0100C4`d44`0341<C0=XC

00<=01<0K1<00`0C00024`00Ha<00a0C4`054`0501<C4`d00a<00a0C4`3I4`033A<006dC0`024`00

Ha<00a0C4`054`0301<C008C00D=4a<C403J4`043A<0074C001R4`0341<C00HC00<04a<00a<010dC

4a3I4`043A<C078C001R4`0341<C00HC0P044`053A<C4a00f1<010dC4`1b4`00HA<00a0C4`074`03

01<C00@C00@=4a<@f1<010dC4`1b4`00HA<00a0C4`074`0301<C00DC00<=4a00f1<010dC4`1b4`00

H1<00a0C4`084`0301<C00HC00<=4a00ea<00`dC4`02074C001P4`0341<C00PC0P074`033A<@0=HC

00D=4a<C001b4`00Ga<00a0C4`094`0301<C00LC00<=4a00eA<01@dC4a<0078C001O4`0341<C00TC

00<04a<021<00`d@4`3D4`053A<C4`00LQ<005hC00<@4a<02Q<00`0C4`094`033A0C0=<C00D=4a<C

001b4`00GQ<00a0C4`0:4`802Q<00`d@4`3C4`043A<C4`80LA<005dC00<@4a<02a<00`0C4`0:4`03

3A0C0=8C00D=4a<C001b4`00GA<00a0C4`044`D00Q<00`0C4`0;4`033A<C0=4C00D=4a<C001b4`00

G1<00a0C4`074`0301<C008C00<04a<031<00`dC4`3@4`053A<C4`00LQ<005/C00<@4a<021<00`0C

4`024`803Q<00`dC4`3?4`053A<C4`00LQ<005/C00<@4a<021<00`0C4`024`0301<C00dC00<=4a<0

ca<010dC4a<2074C001J4`0341<C00TC00<04a<00Q<00`0C4`0>4`033A<C0<hC00D=4a<C001b4`00

FQ<00a0C4`084`8011<00`0C4`0?4`033A<C0<dC00D=4a<C001b4`00FA<00a0C4`0?4`8041<00a0=

4`324`0301<C008C00<04a<00Q<00`0=4`024`0301<C070C001H4`0341<C010C00<04a<041<00`dC

4`304`0301<000LC00<04`d00a<00`0C4`1`4`00F1<00a0C4`0@4`0301<C014C00<=4a<0_a<00`0C

00094`0400dC4`80LA<005LC00<@4a<04A<00`0C4`0A4`0340dC0;lC00<04`001a<200054`dC4`00

LQ<005HC00<@4a<04Q<201<C00<@3A<0_Q<00`0C00074`0401<C3@8C00<04a<0L1<005HC00<@4a<0

4Q<00`0C4`0C4`0340dC0;hC00<04a<01Q<300043A<C078C001E4`0341<C01<C00<04a<04a<00a0=

4`3:4`043A<C078C001D4`0341<C01@C00<04a<051<00a0=4`394`033A<C0080LA<005<C00<@4a<0

5A<201DC00<@4`d0bQ<00`dC001b4`00Da<00a0C4`0E4`0301<C01DC00<@4`d0bQ<00`d04`1a4`00

DQ<00a0C4`0F4`0301<C01HC00<@3A<0bA<00`d04`1a4`00DA<00a0C4`0G4`0301<C01HC00<@4`d0

bQ<00`d04`1`4`00DA<00a0C4`0G4`8061<00a0C3@394`033A<C070C001@4`0341<C01PC00<04a<0

5a<0110C4`g84`0300dC070C001?4`0341<C00PC1@024`0301<C008C00<04a<00Q<00`0C4`0H4`03

41<=0<PC00<03A<0L1<004lC00<@4a<02Q<00`0C4`064`0301<000<C00<04a<06A<00a0C3@374`03

01<=070C001>4`0341<C00/C00<04a<021<0100C4a<201/C00<@4`d0aQ<200033A<C06hC001=4`03

41<C00`C00<04a<01Q<200@C00<04a<06Q<00a0C3@364`0401<C3FlC001<4`0341<C00dC00<04a<0

1Q<00`0C4`034`0301<C01/C00<@4`d0aA<01@0C4a<=06hC001<4`0341<C00`C0P084`<00a<00`0C

4`0L4`0341<=0<@C00D04a<C3@1^4`00Ba<00a0C4`0M4`807Q<00a0=4`334`0301<C008C00<=4a<0

Ja<004XC00<@4a<07Q<00`0C4`0M4`0341<=0<<C0P044`033A<C06XC001:4`0341<C01hC00<04a<0

7Q<00a0C3@324`0301<C00@C00<=4a<0JA<004TC00<@4a<07a<00`0C4`0O4`0340dC0<4C00<04a<0

1A<00`dC4`1X4`00B1<00a0C4`0P4`808A<00a0=4`2i4`D00Q<00`0C4`064`033A<C06LC00174`03

41<C024C00<04a<08A<00a0=4`2j4`0301<C008C00<04a<01Q<00`dC4`1W4`00Aa<00a0C4`0Q4`03

01<C024C00<@3A<0^Q<00`0C4`024`8021<00`dC4`1V4`00AQ<00a0C4`0R4`0301<C028C00<@3A<0

^A<00`0C4`024`0301<C00PC00<=4a<0IA<004DC00<@4a<08a<202@C00<@3A<0^1<00`0C4`024`03

01<C00TC00<=4a<0I1<004@C00<@4a<091<00`0C4`0T4`0340dC0;HC0P044`0301<C00XC0PeT4`00

A1<00a0C4`0T4`0301<C02@C00<@3A<0_1<00`0C4`0;4`033A<C068C00134`0341<C02DC00<04a<0

9A<00a0=4`2k4`803A<00`dC4`1Q4`00@Q<00a0C4`0V4`0301<C02HC00<@3A<0^Q<00`0C4`0=4`8=

HA<0044C00<@4a<09a<202PC00<@3A<0^A<00`0C4`0?4`033A<C05hC00104`0341<C02PC00<04a<0

:1<00`dC4`2h4`0301<C010C00<=4a<0GA<0040C00<@4a<08Q<300<C00<04a<0:A<00`dC4`2g4`03

01<C014C0PeM4`00?a<00a0C4`0S4`0301<C00<C00<04a<0:A<00a0=4`2g4`804a<23E`C000n4`03

41<C02DC00<04a<00Q<202/C00<@3A<0]Q<00`0C4`0C4`8=Fa<003dC00<@4a<09Q<00`0C4`024`03

01<C02/C00<=4a<0]A<00`0C4`0E4`033A<C05PC000m4`0341<C02DC00<04`000a<00`0C4`0/4`03

3A<C0;@C00<04a<05Q<23EPC000l4`0341<C02LC00<04a<00Q<00`0C4`0]4`033A<C0;<C00<04a<0

61<00`dC4`1E4`00>a<00a0C4`0]4`80;a<00`dC4`2b4`806Q<00`dC4`1D4`00>Q<00a0C4`0^4`03

01<C02hC00<@3A<0/Q<00`0C4`0J4`8=E1<003XC00<@4a<0;Q<00`0C4`0_4`033A<C0;4C00<04a<0

71<00`dC4`1A4`00>A<00a0C4`0_4`0301<C030C00<=4a<0/1<00`0C4`0M4`033A<C050C000h4`03

41<C030C0P0b4`033A<C0:lC0P0O4`8=D1<003LC00<@4a<0<A<00`0C4`0a4`0340dC0:lC00<04a<0

81<23DhC000g4`0341<C034C00<04a<0<Q<00`dC4`2^4`0301<C028C00<=4a<0Ba<003HC00<@4a<0

<Q<00`0C4`0c4`033A<C09`C1@024`0301<C008C00<04a<00Q<00`0C4`0S4`033A<C04XC000e4`03

41<C03<C0P0e4`033A<C09dC00<04a<01Q<00`0C00034`0301<C02@C0Pe:4`00=1<00a0C4`0d4`03

01<C03DC00<=4a<0W1<00`0C4`084`0401<C4`809a<23DPC000c4`0341<C03DC00<04a<0=A<00`d@

4`2L4`0301<C00HC0P044`0301<C02PC0Pe64`00<Q<00a0C4`0f4`0301<C03HC00<=4a<0Va<00`0C

4`064`0301<C00<C00<04a<0:Q<00`dC4`134`00<A<00a0C4`0g4`80>1<00`dC4`2I4`8021<300<C

00<04a<0:a<23D<C000`4`0341<C03PC00<04a<0=a<00`d@4`2Y4`0301<C02dC0Pe14`00;a<00a0C

4`0Y4`<00a<00`0C4`024`0301<C008C00<04a<0>1<00`d@4`2X4`80<1<00`dC4`0n4`00;Q<00a0C

4`0Z4`0301<C00LC00<04`000a<00`0C4`0i4`033A0C0:LC00<04a<0<1<23ChC000]4`0341<C02`C

00<04a<021<0100C4a<203/C00<=41<0YQ<00`0C4`0b4`8=?1<002`C00<@4a<0;A<00`0C4`064`80

11<00`0C4`0j4`033A<@0:HC00<04a<0=1<23CXC000[4`0341<C02dC00<04`001a<00`0C4`034`03

01<C03/C00<=4a00YA<00`0C4`0f4`8=>1<002XC00<@4a<0;a<00`0C4`064`<00a<00`0C4`0l4`03

3A<@0:@C0P0i4`<==A<002TC00<@4a<0?a<203dC00@=4a<@Xa<00`0C4`0k4`8=<a<002PC00<@4a<0

@1<00`0C4`0m4`043A<C4:8C00<04a<0?A<23C4C000W4`0341<C044C00<04a<0?Q<010dC4a2Q4`03

01<C03lC00<=4a<0;Q<002HC00<@4a<0@Q<00`0C4`0n4`053A<C4a00X1<00`0C4`104`<=;A<002DC

00<@4a<0@a<2040C00D=4a<C402O4`80A1<23B/C000T4`0341<C04@C00<04a<0@1<01@dC4a<@09hC

00<04a<0AA<23BTC000S4`0341<C04DC00<04a<0@1<00`dC4`024`0341<C09/C00<04a<0Aa<23BLC

000S4`0341<C04DC00<04a<0@A<00`dC4`024`0341<C09XC00<04a<0BA<33B@C000R4`0341<C04HC

0P134`033A<C008C00<@4a<0VA<00`0C4`1<4`8=8Q<0024C00<@4a<0Aa<00`0C4`134`033A<C008C

00<@4a<0V1<204lC0PdP4`0081<00a0C4`184`0301<C04<C00<=4a<00a<00a0C4`2G4`0301<C050C

0PdN4`007a<00a0C4`194`0301<C04@C00<=4a<00a<00a0C4`2F4`0301<C058C0PdL4`007Q<00a0C

4`1:4`80AQ<00`dC4`034`0341<C08lC0`034`0301<C05@C0PdJ4`007A<00a0C4`1;4`0301<C04HC

00<=4a<00a<00a0C4`2>4`0301<C00<C00<04a<0EQ<23APC000L4`0341<C04`C00<04a<0AQ<00`dC

4`044`0341<C08hC00<04a<00Q<205TC10dD4`006a<00a0C4`174`8011<00`0C4`174`033A<C00@C

00<@4a<0SA<00`0C4`024`0301<C05`C0`dA4`006Q<00a0C4`1:4`0501<C4`00BQ<00`dC4`044`03

41<C08/C00<04`000a<00`0C4`1N4`033A<C00lC000I4`0341<C04XC00<04a<00Q<204XC00<=4a<0

0a<00a0C4`2<4`0301<C008C00<04a<0L1<006LC00<04a<0ia<2074C001U4`0301<00>TC00<04a<0

L1<006HC00<04a<0j1<00`0C4`1`4`00;1<30?lCUQ<002`C00<04a<0oa>F4`00;A<00`0C4`054`03

01<C0?lCSA<002dC00@04a<C0`0011<04a<30?lCRQ<002`C00<04`000Q<2008C00<04a<00Q<00`0C

4`3o4hPC000]4`0301<C00<C00@04a<00Q<00`0C4`3o4dTC00<04a<0<Q<00`0C4`084`00<a<0100C

4`034`0301<C00HC00<04a<09A<302dC00<04a<0gQ<00`0C4`044`0301<C01<C00<04a<07Q<00`0C

4`074`007A<300034`00008031<300@C0`084`0301<C02@C00@04a<04A<300034`0000800Q<00`0C

4`024`0301<C008C00<04a<01A<0100C4a<5008C00@04a<C0P044`0301<C00@C0P2a4`0401<C4`@0

0Q<200HC00<04a<00a<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`054`0401<C4`D00Q<0100C

4a<200@C00<04a<011<200@C00@04a<C0P014`400@0001`C00@04a<091<00`0C4`0S4`0401<C010C

00@04a<01Q<00`0C00074`0301<000@C1@034`0301<C00PC00H04a<04`044`0301<C0;0C00<04`00

1a<00`0C4`044`D00a<01`0C4a<04`001a<00`0C00044`D00a<00`0C4`084`0601<C01<011<00`0C

4`044`0301<C008C00<04`000A<001`C00D04a<04`0400034`0001P0:a<3010C00D04a<04`040004

4`0C00TC00<04a<011<00`0C4`034`0301<C00LC00<04a<00a<00`0C4`024`0301<C0;0C00<04`00

0Q<400034`0C00LC00<04a<00a<01`0C4a<04`002A<00`0C4`044`0301<C00<C00<04a<01a<00`0C

4`034`0301<C008C00<04a<011<00`0C4`034`400A<14`007A<304dC00<04a<03a<300HC00<04`00

1a<200LC00<04a<00a<00`0C4`084`0301<C00801A<00`0C4`2F4`8000<C00005A<00`0C00074`03

01<C00HC00<04a<00a<01`0C4a<04`001a<200LC00<04a<00a<00`0C4`084`0301<C00801A<00`0C

4`044`0301<C00<C0@014`4C000O4`0301<C04XC0P0C4`0301<C00@C00<04`001a<00`0C4`0<4`03

01<C00HC00<04`000Q<00`0C4`044`0301<009LC00<04`005Q<00`0C00074`0301<000dC00H04a<0

4`074`0301<C00`C00<04a<01Q<00`0C00024`0301<C00@C00<04`000a<00`0C4`034`0301<0004C

000N4`80H1<200LC00<04a<01Q<300/C0P094`0401<C4`<011<309PC00<04a<05Q<00`0C4`064`<0

3Q<0100C4`084`<02a<200TC00@04a<C0`044`<00Q<00`0C4`034`800A<10040003o4e8C00<04a<0

L1<002TC0P064`80oa<N4`0301<0074C000[4`0301<C008C00<04a<0oa<M4`8000<C0000L1<002XC

00<04a<00a<00`0C4`054`0301<C0?lCRQ<002/C00<04a<00Q<00`0C4`024`@00a<30?lCQQ<002TC

00<04`0011<00`0C00024`8000<C01<011<00`0C4`3o4h@C000Z4`0301<C00<C0`044`0301<000<C

00<04a<0oa>54`00=a<00`0C00044`0301<C0?lCQ1<003DC0`044`<0oa>64`00oa?54`00oa?54`00

oa?54`00oa?54`00oa?54`00\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-6.95686, -1.50089, 0.0206072, 0.0206072}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -84.5 0 ]

[.5 .96488 84.5 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -145.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.345) show

222.250000 19.500000 moveto

(C) show

227.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.23447 0 m

.26171 .03664 L

.30316 .09239 L

.34309 .14609 L

.3815 .19776 L

.42237 .25272 L

.46172 .30565 L

.49955 .35654 L

.53984 .41073 L

.57861 .46287 L

.61984 .51832 L

.65954 .57173 L

.69774 .6231 L

.73838 .67777 L

.77751 .7304 L

.81909 .78632 L

.85916 .84021 L

.89771 .89206 L

.93871 .94721 L

s

.93871 .94721 m

.94256 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.322525 0.238095 [

[.02381 .31002 -6 -9 ]

[.02381 .31002 6 0 ]

[.2619 .31002 -6 -9 ]

[.2619 .31002 6 0 ]

[.7381 .31002 -3 -9 ]

[.7381 .31002 3 0 ]

[.97619 .31002 -3 -9 ]

[.97619 .31002 3 0 ]

[1.025 .32252 0 -8 ]

[1.025 .32252 9 8 ]

[.4875 .08443 -12 -4.5 ]

[.4875 .08443 0 4.5 ]

[.4875 .20348 -24 -4.5 ]

[.4875 .20348 0 4.5 ]

[.4875 .44157 -18 -4.5 ]

[.4875 .44157 0 4.5 ]

[.4875 .56062 -6 -4.5 ]

[.4875 .56062 0 4.5 ]

[.4875 .67967 -18 -4.5 ]

[.4875 .67967 0 4.5 ]

[.4875 .79872 -6 -4.5 ]

[.4875 .79872 0 4.5 ]

[.5 .85342 -4.5 0 ]

[.5 .85342 4.5 16 ]

[.5 .84092 -137 0 ]

[.5 .84092 137 16 ]

[ 0 0 0 0 ]

[ 1 .82842 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .32252 m

.02381 .32877 L

s

[(-2)] .02381 .31002 0 1 Mshowa

.2619 .32252 m

.2619 .32877 L

s

[(-1)] .2619 .31002 0 1 Mshowa

.7381 .32252 m

.7381 .32877 L

s

[(1)] .7381 .31002 0 1 Mshowa

.97619 .32252 m

.97619 .32877 L

s

[(2)] .97619 .31002 0 1 Mshowa

.125 Mabswid

.07143 .32252 m

.07143 .32627 L

s

.11905 .32252 m

.11905 .32627 L

s

.16667 .32252 m

.16667 .32627 L

s

.21429 .32252 m

.21429 .32627 L

s

.30952 .32252 m

.30952 .32627 L

s

.35714 .32252 m

.35714 .32627 L

s

.40476 .32252 m

.40476 .32627 L

s

.45238 .32252 m

.45238 .32627 L

s

.54762 .32252 m

.54762 .32627 L

s

.59524 .32252 m

.59524 .32627 L

s

.64286 .32252 m

.64286 .32627 L

s

.69048 .32252 m

.69048 .32627 L

s

.78571 .32252 m

.78571 .32627 L

s

.83333 .32252 m

.83333 .32627 L

s

.88095 .32252 m

.88095 .32627 L

s

.92857 .32252 m

.92857 .32627 L

s

.25 Mabswid

0 .32252 m

1 .32252 L

s

gsave

1.025 .32252 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .08443 m

.50625 .08443 L

s

[(-1)] .4875 .08443 1 0 Mshowa

.5 .20348 m

.50625 .20348 L

s

[(-0.5)] .4875 .20348 1 0 Mshowa

.5 .44157 m

.50625 .44157 L

s

[(0.5)] .4875 .44157 1 0 Mshowa

.5 .56062 m

.50625 .56062 L

s

[(1)] .4875 .56062 1 0 Mshowa

.5 .67967 m

.50625 .67967 L

s

[(1.5)] .4875 .67967 1 0 Mshowa

.5 .79872 m

.50625 .79872 L

s

[(2)] .4875 .79872 1 0 Mshowa

.125 Mabswid

.5 .10824 m

.50375 .10824 L

s

.5 .13205 m

.50375 .13205 L

s

.5 .15586 m

.50375 .15586 L

s

.5 .17967 m

.50375 .17967 L

s

.5 .22729 m

.50375 .22729 L

s

.5 .2511 m

.50375 .2511 L

s

.5 .27491 m

.50375 .27491 L

s

.5 .29872 m

.50375 .29872 L

s

.5 .34633 m

.50375 .34633 L

s

.5 .37014 m

.50375 .37014 L

s

.5 .39395 m

.50375 .39395 L

s

.5 .41776 m

.50375 .41776 L

s

.5 .46538 m

.50375 .46538 L

s

.5 .48919 m

.50375 .48919 L

s

.5 .513 m

.50375 .513 L

s

.5 .53681 m

.50375 .53681 L

s

.5 .58443 m

.50375 .58443 L

s

.5 .60824 m

.50375 .60824 L

s

.5 .63205 m

.50375 .63205 L

s

.5 .65586 m

.50375 .65586 L

s

.5 .70348 m

.50375 .70348 L

s

.5 .72729 m

.50375 .72729 L

s

.5 .7511 m

.50375 .7511 L

s

.5 .77491 m

.50375 .77491 L

s

.5 .06062 m

.50375 .06062 L

s

.5 .03681 m

.50375 .03681 L

s

.5 .013 m

.50375 .013 L

s

.5 .82252 m

.50375 .82252 L

s

.25 Mabswid

.5 0 m

.5 .82842 L

s

gsave

.5 .85342 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .84092 -198 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.345) show

298.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

303.000000 15.000000 moveto

(L) show

310.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

317.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

324.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

329.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

333.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .82842 L

0 .82842 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .14794 m

.02575 .14795 L

.03156 .14797 L

.04112 .14801 L

.05428 .14806 L

.0708 .14813 L

.09041 .14821 L

.11278 .14832 L

.13751 .14844 L

.16419 .14859 L

.19235 .14876 L

.22153 .14896 L

.25121 .1492 L

.28089 .14946 L

.31006 .14977 L

.33823 .15011 L

.36491 .15049 L

.38964 .1509 L

.412 .15134 L

.43161 .15179 L

.44814 .15223 L

.4613 .15263 L

.47086 .15295 L

.47666 .15316 L

.47861 .15324 L

s

.47861 .15324 m

.47914 .15326 L

.48074 .15332 L

.48336 .15343 L

.48698 .15358 L

.49152 .15377 L

.49692 .15402 L

.50306 .15432 L

.50986 .15468 L

.5172 .15511 L

.52494 .15561 L

.53296 .15619 L

.54112 .15687 L

.54928 .15766 L

.5573 .15857 L

.56504 .15961 L

.57238 .16082 L

.57917 .1622 L

.58532 .16379 L

.59071 .16561 L

.59526 .1677 L

.59887 .17007 L

.6015 .17278 L

.6031 .17585 L

.60363 .17929 L

s

.47861 .40711 m

.47914 .39387 L

.48074 .38061 L

.48336 .36743 L

.48698 .35439 L

.49152 .34154 L

.49692 .32893 L

.50306 .3166 L

.50986 .3046 L

.5172 .29296 L

.52494 .28174 L

.53296 .27097 L

.54112 .26067 L

.54928 .25088 L

.5573 .24162 L

.56504 .2329 L

.57238 .22475 L

.57917 .21716 L

.58532 .21014 L

.59071 .20368 L

.59526 .19778 L

.59887 .19241 L

.6015 .18756 L

.6031 .1832 L

.60363 .17933 L

s

.47861 .40722 m

.47914 .42044 L

.48074 .43364 L

.48336 .44672 L

.48698 .45961 L

.49152 .47226 L

.49692 .48463 L

.50306 .49666 L

.50986 .5083 L

.5172 .5195 L

.52494 .53022 L

.53296 .54041 L

.54112 .55003 L

.54928 .55903 L

.5573 .56739 L

.56504 .57506 L

.57238 .58201 L

.57917 .58822 L

.58532 .59365 L

.59071 .59828 L

.59526 .6021 L

.59887 .60509 L

.6015 .60723 L

.6031 .60852 L

.60363 .60895 L

s

.60363 .60895 m

.60453 .60967 L

.60719 .6118 L

.61159 .61525 L

.61764 .61992 L

.62524 .62563 L

.63426 .63222 L

.64454 .63951 L

.65591 .64731 L

.66818 .65545 L

.68113 .66376 L

.69454 .67209 L

.70819 .6803 L

.72184 .68827 L

.73525 .69589 L

.7482 .70306 L

.76047 .70969 L

.77184 .71571 L

.78213 .72105 L

.79114 .72566 L

.79874 .7295 L

.80479 .73252 L

.80919 .73469 L

.81186 .73601 L

.81275 .73645 L

s

.81275 .11555 m

.81345 .1121 L

.81554 .1083 L

.81897 .10415 L

.8237 .09968 L

.82964 .09491 L

.83669 .08989 L

.84472 .08464 L

.85361 .07924 L

.8632 .07374 L

.87332 .06819 L

.8838 .06267 L

.89447 .05725 L

.90514 .05198 L

.91562 .04694 L

.92574 .04218 L

.93533 .03776 L

.94422 .03373 L

.95226 .03014 L

.9593 .02703 L

.96524 .02444 L

.96997 .0224 L

.97341 .02092 L

.97549 .02002 L

.97619 .01972 L

s

.81275 .11558 m

.81345 .11868 L

.81554 .12147 L

.81897 .12394 L

.8237 .12612 L

.82964 .12803 L

.83669 .12969 L

.84472 .13115 L

.85361 .13241 L

.8632 .1335 L

.87332 .13444 L

.8838 .13526 L

.89447 .13596 L

.90514 .13656 L

.91562 .13708 L

.92574 .13752 L

.93533 .1379 L

.94422 .13821 L

.95226 .13848 L

.9593 .13869 L

.96524 .13886 L

.96997 .13899 L

.97341 .13908 L

.97549 .13913 L

.97619 .13915 L

s

.81275 .73645 m

.81345 .73679 L

.81554 .73781 L

.81897 .73949 L

.8237 .74178 L

.82964 .74464 L

.83669 .74799 L

.84472 .75178 L

.85361 .75593 L

.8632 .76034 L

.87332 .76494 L

.8838 .76964 L

.89447 .77437 L

.90514 .77903 L

.91562 .78355 L

.92574 .78787 L

.93533 .79192 L

.94422 .79563 L

.95226 .79896 L

.9593 .80185 L

.96524 .80427 L

.96997 .80619 L

.97341 .80758 L

.97549 .80842 L

.97619 .8087 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCaA<00?lCaA<006@C1@3X4`0301<C070C001V4`0301<C0>PC00<04a<0L1<003hC00<=4a<0

7a<300<C00<04a<00Q<20>@C0P1a4`00?a<00`dC4`0T4`0301<C008C00<04a<0ha<00`0C4`1`4`00

?a<00`dC4`0T4`0301<C008C00<04a<0ha<00`0C4`1M4`8=4A<0040C00<=4a<08Q<200@C00<04a<0

ha<00`0C4`1K4`8=4a<0044C00<=4a<09a<20>@C00<04a<0FA<23ADC00114`033A<C02LC00<04a<0

ha<205LC0`dG4`00@Q<00`dC4`0V4`0301<C0><C00<04a<0E1<23AXC00134`033A<C02DC00<04a<0

ha<00`0C4`1B4`8=71<004<C00<=4a<09A<20>@C00<04a<0Ca<33AhC00144`033A<C02@C00<04a<0

ha<00`0C4`1=4`8=8A<004DC00<=4a<08a<00`0C4`3S4`80C1<23B<C00154`033A<C02<C00<04a<0

ha<00`0C4`1:4`033A<C02<C00164`033A<C028C0P3T4`0301<C04TC00<=4a<091<004LC00<=4a<0

8A<00`0C4`3L4`D00Q<00`0C4`174`8=9a<004PC00<=4a<081<00`0C4`3N4`0301<C008C00<04a<0

AA<23BTC00184`033A<C020C00<04a<0f1<300<C00<04a<00Q<204@C0Pd[4`00BA<00`dC4`0O4`80

ga<00`0C4`024`0301<C048C00<=4a<0:a<004XC00<=4a<07Q<00`0C4`3N4`0301<C008C00<04a<0

@1<23BhC001;4`033A<C00hC00<04a<00Q<00`0C4`024`0301<C008C00<04a<0gA<200@C00<04a<0

?a<00`dC4`0^4`00Ba<00`dC4`0=4`0301<000LC00<04`000a<00`0C4`3S4`0301<C03hC00<=4a<0

;a<004`C00<=4a<01a<3008C00<04`002A<0100C4a<20>@C0P0n4`033A<C030C001=4`033A<C00/C

00<04`001a<200@C00<04a<0ha<00`0C4`0m4`033A<C030C001>4`033A<C00XC00<04`001a<00`0C

4`034`0301<C0><C00<04a<0?A<00`dC4`0`4`00CQ<00`dC4`0;4`0301<C00HC0`034`0301<C0><C

00<04a<0?Q<23C0C001?4`033A<C01TC00<04a<0ha<00`0C4`104`@=;1<0050C00<=4a<061<20>@C

0P154`d=7a<0054C00<=4a<05a<00`0C4`3S4`0301<C054C3PdA4`00DQ<00`dC4`0F4`0301<C0><C

00<04a<0L1<0058C00<=4a<05Q<00`0C4`224e4=41<00`0C4`1`4`00Da<00`dC4`0E4`80e1<H3F/C

001D4`033A<C01@C00<04a<0ha<00`0C4`054`P=Ha<001XC0`0U4`D03Q<00`dC4`0C4`0301<C02@C

1@0T4`<0Ta<00`0C4`0=4`@=Ga<001XC00<04a<09a<00`0C4`0>4`033A<C01<C00<04a<09Q<00`0C

4`0T4`0301<C09<C00<04a<04A<00`dC4`1L4`005A<300<C00<04a<081<300<C00<04a<03a<00`dC

4`0B4`809a<00`0C4`0U4`0301<C098C00<04a<04Q<00`dC4`1K4`006a<00`0C4`0V4`0301<C010C

00<=4a<04A<00`0C4`0V4`0301<C02DC00<04a<0TQ<201<C00<=4a<0Fa<001XC00<04`009a<00`0C

4`0A4`033A<C010C00<04a<09Q<00`0C4`0T4`0301<009<C00<04a<04Q<00`dC4`1K4`006a<00`0C

4`0U4`8051<00`dC4`0?4`0301<C02DC0P0W4`0301<C098C00<04a<04Q<00`dC4`1K4`00FA<00`dC

4`0?4`80eA<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`0A4`033A<C05`C001J4`033A<C00hC

00<04a<0da<00`0C00074`0301<000<C00<04a<04A<00`dC4`1L4`00Fa<00`dC4`0=4`0301<C05/C

0P1a4`<00Q<00`0C00094`0401<C4`804A<00`dC4`1M4`00G1<00`dC4`0<4`0301<C05XC00<04a<0

MQ<00`0C00074`8011<00`0C4`0>4`8=H1<001DCA`000`d0001S00HC00<04a<0MQ<00`0C00074`03

01<C00<C00<04a<03A<00`dC4`1P4`006A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`03

01<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04`d01A<00`0C4`054`0341<C00DC00<04a<0

1Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C4`054`03

01<C00DC00<04a<021<00`0C4`1g4`0301<C00HC0`034`0301<C00dC00<=4a<0H1<005hC00<=4a<0

2Q<00a0C4`1J4`0301<008HC00<04a<031<00`dC4`1Q4`00Ga<00`dC4`094`8@Fa<308HC0P0<4`03

3A<C068C001O4`033A<C00TC0Q3T4`0301<C00XC00<=4a<0Ha<0060C00<=4a<01a<00a00403T4`03

01<C00TC00<=4a<0I1<0064C00<=4a<01Q<00a00403T4`0301<C00TC00<=4a<0I1<0064C00<=4a<0

1Q<00a00403T4`0301<C00PC00<=4a<0IA<0068C00<=4a<011<01A0C000@0><C0P084`033A<C06HC

001S4`033A<C00<C00D@4`0C403S4`0301<C00HC00<=4a<0Ia<006@C00<=4a<00Q<01A0C01<@0><C

00<04a<01A<00`dC4`1X4`00I1<00`dC4`024`0341<0008C00<@4a<0h1<00`0C4`044`033A<C06TC

001U4`063A<C4a0C0P000a<@4`214`<0;A<502/C00<04a<011<00`dC4`0T4`D0;A<3010C001V4`06

3A<C41<00Q<00a0C4`204`0301<C02lC00<04a<0:a<200@C00<=4a<09a<00`0C4`0]4`0301<C010C

001V4`033A<@008C00D04a<C401l4`<00a<00`0C4`0X4`<00a<00`0C4`0[4`0301<C008C00<=4a<0

:1<00`0C4`0^4`0301<C00lC001W4`053A0C4`000a<00a0C4`204`0301<C02hC00<04a<0:a<01@0C

4a<=02/C00<04a<0;Q<00`0C4`0?4`00J1<00`dC4`02008C00<@4a<0Oa<00`0C000_4`0301<C02/C

00D04a<C3@0[4`0301<C02dC00<04`0041<006LC00D@4`dC00044`0341<C07lC00<04a<0;A<202dC

00@04a<=:a<2030C00<04a<03a<005`C00<04a<00Q<00`0C4`024`06010C3A<011<00a0C4`3N4`80

00<C3A<0KQ<005/C00<04`001a<00`0@00024`033@0C00<C00<@4a<0gQ<00`0C3@1`4`00Fa<00`0C

00084`03400C008C00<=01<00a<00a0C4`3M4`0300dC06`C0P024`00Fa<00`0C00074`03010C00<C

00<03A<00a<00a0C4`3M4`0300dC06/C00<04a<00Q<005/C00<04`001a<00a0C4`034`0300dC00@C

00<@4a<0MQ=V00033@0006@01a<00`0C4`024`00G1<00`0C4`064`03400000<C00<04`d011<00a0C

4`1k4`0301<C00LC00<04a<01Q<00`0C4`074`0301<C00LC00<04a<01a<00`0C4`064`0301<C00LC

00<04a<01a<00`0C4`064`0301<C00LC00<=4a<01a<00`0C4`074`0301<C00HC00<04a<01a<00`0C

4`074`0301<C00HC00<04a<01a<00`0C4`074`0301<C00HC00<04a<01a<00`0C4`0:4`0301<C008C

001T4`0341<C00@C0P000a<=4`024`0341<C07/C00<04a<0;Q<00`0C4`0/4`033@0C02lC00<04a<0

;A<00`0C4`0:4`0301<0008C001T4`0341<C00@C00@04a<=11<00a0C4`3I4`033A<006dC0`024`00

Ha<00a0C4`054`0501<C4`d00a<00a0C4`3I4`033A<0078C001S4`0341<C00DC00<04a<00Q<01@dC

4a<@0=XC00@=4`00LA<0068C00<@4a<01Q<00`0C4`034`043A<C4=TC00@=4a<0LQ<0068C00<@4a<0

1Q<200@C00D=4a<C403H4`043A<C078C001Q4`0341<C00LC00<04a<011<010dC4a3H4`043A<C078C

001Q4`0341<C00LC00<04a<01A<00`dC403H4`043A<C078C001P4`0341<C00PC00<04a<01Q<00`dC

403G4`033A<C0080LA<0060C00<@4a<021<200LC00<=4a00eQ<01@dC4a<0078C001O4`0341<C00TC

00<04a<01a<00`dC403E4`053A<C4`00LQ<005lC00<@4a<02A<00`0C4`084`033A0C0=@C00D=4a<C

001b4`00GQ<00a0C4`0:4`0301<C00TC00<=41<0da<01@dC4a<0078C001N4`0341<C00XC0P0:4`03

3A0C0=<C00@=4a<C0P1a4`00GA<00a0C4`0;4`0301<C00XC00<=41<0dQ<01@dC4a<0078C001M4`03

41<C00@C1@024`0301<C00/C00<=4a<0dA<01@dC4a<0078C001L4`0341<C00LC00<04a<00Q<00`0C

4`0<4`033A<C0=0C00D=4a<C001b4`00Fa<00a0C4`084`0301<C008C0P0>4`033A<C0<lC00D=4a<C

001b4`00Fa<00a0C4`084`0301<C008C00<04a<03A<00`dC4`3?4`043A<C4`80LA<005XC00<@4a<0

2A<00`0C4`024`0301<C00hC00<=4a<0cQ<01@dC4a<0078C001J4`0341<C00PC0P044`0301<C00lC

00<=4a<0cA<01@dC4a<0078C001I4`0341<C00lC0P0@4`0340dC0<8C00<04a<00Q<00`0C4`024`03

00dC008C00<04a<0L1<005PC00<@4a<041<00`0C4`0@4`033A<C0<0C00<04`001a<00`0C3@034`03

01<C070C001H4`0341<C010C00<04a<04A<00`dC4`2o4`0301<000TC00@03A<C0P1a4`00Ea<00a0C

4`0A4`0301<C014C00<@3A<0_a<00`0C00074`8000DC3A<C001b4`00EQ<00a0C4`0B4`804a<00a0=

4`2n4`0301<000LC00@04a<=0Q<00`0C4`1`4`00EQ<00a0C4`0B4`0301<C01<C00<@3A<0_Q<00`0C

4`064`<000@=4a<0LQ<005DC00<@4a<04a<00`0C4`0C4`0340dC0<XC00@=4a<0LQ<005@C00<@4a<0

51<00`0C4`0D4`0340dC0<XC00@=4`00LA<005<C00<@4a<05A<201DC00<@4`d0bQ<00`dC001b4`00

Da<00a0C4`0E4`0301<C01DC00<@4`d0bA<00`dC001b4`00DQ<00a0C4`0F4`0301<C01HC00<@3A<0

bA<00`d04`1a4`00DA<00a0C4`0G4`0301<C01HC00<@4`d0bQ<00`d04`1`4`00DA<00a0C4`0G4`80

61<00a0C3@394`033A<C070C001@4`0341<C01PC00<04a<05a<0110C4`g84`0300dC070C001?4`03

41<C00PC1@024`0301<C008C00<04a<00Q<00`0C4`0H4`0341<=0<PC00<03A<0L1<004lC00<@4a<0

2Q<00`0C4`064`0301<000<C00<04a<06A<00a0C3@374`0301<=070C001>4`0341<C00/C00<04a<0

21<0100C4a<201/C00<@4`d0aQ<200034`dC06hC001=4`0341<C00`C00<04a<01Q<200@C00<04a<0

6Q<00a0C3@364`0401<C3FlC001<4`0341<C00dC00<04a<01Q<00`0C4`034`0301<C01/C00<@4`d0

aA<01@0C4a<=06hC001<4`0341<C00`C0P084`<00a<00`0C4`0L4`0341<=0<@C00D04a<C3@1^4`00

Ba<00a0C4`0M4`807Q<00a0=4`334`0301<C008C00<=4a<0Ja<004XC00<@4a<07Q<00`0C4`0M4`03

41<=0<<C0P044`033A<C06XC001:4`0341<C01hC00<04a<07Q<00a0C3@324`0301<C00@C00<=4a<0

JA<004TC00<@4a<07a<00`0C4`0O4`0341<=0<4C00<04a<011<00`dC4`1Y4`00B1<00a0C4`0P4`80

8A<00a0=4`2i4`D00Q<00`0C4`054`033A<C06PC00174`0341<C024C00<04a<08A<00a0=4`2j4`03

01<C008C00<04a<01Q<00`dC4`1W4`00Aa<00a0C4`0Q4`0301<C024C00<@4`d0^Q<00`0C4`024`80

21<00`dC4`1V4`00AQ<00a0C4`0R4`0301<C028C00<@4`d0^A<00`0C4`024`0301<C00PC0PeV4`00

AA<00a0C4`0S4`8091<00a0=4`2h4`0301<C008C00<04a<02A<00`dC4`1T4`00A1<00a0C4`0T4`03

01<C02@C00<@3A<0]Q<200@C00<04a<02Q<00`dC4`1S4`00A1<00a0C4`0T4`0301<C02@C00<@4`d0

_1<00`0C4`0;4`8=Ha<004<C00<@4a<09A<00`0C4`0U4`0341<=0;/C0P0=4`033A<C064C00124`03

41<C02HC00<04a<09Q<00a0C3@2j4`0301<C00dC00<=4a<0H1<0044C00<@4a<09a<202PC00<@3A<0

^A<00`0C4`0>4`033A<C05lC00104`0341<C02PC00<04a<0:1<00a0=4`2h4`0301<C00lC0`eN4`00

@1<00a0C4`0R4`<00a<00`0C4`0Y4`0340dC0;LC00<04a<04A<23EdC000o4`0341<C02<C00<04a<0

0a<00`0C4`0Y4`0341<=0;LC0P0C4`8=G1<003hC00<@4a<09A<00`0C4`024`80:a<00a0=4`2f4`03

01<C01@C00<=4a<0FA<003dC00<@4a<09Q<00`0C4`024`0301<C02/C00<@3A<0]A<00`0C4`0E4`03

3A<C05PC000m4`0341<C02DC00<04`000a<00`0C4`0/4`0340dC0;@C00<04a<05Q<23EPC000l4`03

41<C02LC00<04a<00Q<00`0C4`0]4`0340dC0;<C0P0H4`033A<C05HC000k4`0341<C02dC0P0_4`03

3A<C0;8C00<04a<061<23EHC000j4`0341<C02hC00<04a<0;Q<00a0=4`2b4`0301<C01XC0PeD4`00

>Q<00a0C4`0^4`0301<C02lC00<@3A<0/A<00`0C4`0L4`033A<C054C000i4`0341<C02lC00<04a<0

<1<00`dC4`2`4`0301<C01dC00<=4a<0D1<003PC00<@4a<0<1<2038C00<=4a<0[a<201lC0Pe@4`00

=a<00a0C4`0a4`0301<C034C00<@3A<0[a<00`0C4`0P4`8=CQ<003LC00<@4a<0<A<00`0C4`0b4`03

40dC0:hC00<04a<08Q<00`dC4`1;4`00=Q<00a0C4`0b4`0301<C03<C00<=4a<0W1<5008C00<04a<0

0Q<00`0C4`024`0301<C02<C0Pe;4`00=A<00a0C4`0c4`80=A<00`dC4`2M4`0301<C00HC00<04`00

0a<00`0C4`0U4`8=BA<003@C00<@4a<0=1<00`0C4`0e4`033A<C09`C00<04a<021<0100C4a<202PC

0Pe74`00<a<00a0C4`0e4`0301<C03HC00<=4a<0Va<00`0C4`064`8011<00`0C4`0Y4`033A<C04@C

000b4`0341<C03HC00<04a<0=Q<00`dC4`2K4`0301<C00HC00<04a<00a<00`0C4`0Z4`8=A1<0034C

00<@4a<0=a<203PC00<=4a<0VA<200PC0`034`0301<C02`C0Pe24`00<1<00a0C4`0h4`0301<C03PC

00<=4a<0Z1<00`0C4`0^4`8=@1<002lC00<@4a<0:A<300<C00<04a<00Q<00`0C4`024`0301<C03TC

00<=4a<0Ya<2034C00<=4a<0?A<002hC00<@4a<0:Q<00`0C4`074`0301<000<C00<04a<0>A<00`d@

4`2W4`0301<C034C0Pdm4`00;A<00a0C4`0/4`0301<C00PC00@04a<C0P0k4`033A0C0:HC00<04a<0

<a<23C/C000/4`0341<C02dC00<04a<01Q<200@C00<04a<0>a<00`d@4`2U4`0301<C03DC00<=4a<0

>1<002/C00<@4a<0;A<00`0C00074`0301<C00<C00<04a<0?1<00`d@4`2T4`0301<C03HC0Pdh4`00

:Q<00a0C4`0_4`0301<C00HC0`034`0301<C03`C00<=4a00Y1<203TC0`de4`00:A<00a0C4`0o4`80

?Q<00`dC402S4`0301<C03/C0Pdc4`00:1<00a0C4`104`0301<C03hC00<=4a00XQ<00`0C4`0m4`8=

<A<002LC00<@4a<0@A<00`0C4`0n4`043A<C4:4C00<04a<0?a<23BlC000V4`0341<C048C00<04a<0

?a<010dC4a2P4`0301<C044C0Pd]4`009A<00a0C4`134`80@A<010dC4a2O4`80A1<00`dC4`0Z4`00

91<00a0C4`144`0301<C040C00D=4a<C402N4`0301<C04@C0PdZ4`008a<00a0C4`154`0301<C044C

00D=4a<C402M4`0301<C04HC0PdX4`008a<00a0C4`154`0301<C048C00D=4a<C402L4`0301<C04PC

0PdV4`008Q<00a0C4`164`80@a<00`dC4`024`0341<C09TC00<04a<0BQ<53B4C000Q4`0341<C04LC

00<04a<0@a<00`dC4`024`0341<C09PC0P1@4`8=7a<0020C00<@4a<0B1<00`0C4`144`033A<C008C

00<@4a<0Ua<00`0C4`1A4`8=7A<001lC00<@4a<0BA<00`0C4`144`033A<C00<C00<@4a<0T1<300<C

00<04a<0Da<23A/C000N4`0341<C04XC0P164`033A<C00<C00<@4a<0Sa<00`0C4`034`0301<C05DC

0PdI4`007A<00a0C4`1;4`0301<C04HC00<=4a<00a<00a0C4`2?4`0301<C008C0P1H4`<=5Q<001`C

00<@4a<0C1<00`0C4`174`033A<C00<C00<@4a<0SQ<00`0C4`024`0301<C05XC0PdD4`006a<00a0C

4`174`8011<00`0C4`174`033A<C00@C00<@4a<0S1<00`0C00034`0301<C05`C0`dA4`006Q<00a0C

4`1:4`0501<C4`00BQ<00`dC4`044`0341<C08`C00<04a<00Q<00`0C4`1`4`006A<00a0C4`1:4`03

01<C008C0P1:4`033A<C00<C00<@4a<0TA<00`0C4`1`4`00Ia<00`0C4`3W4`80LA<006DC00<04`00

jA<00`0C4`1`4`00IQ<00`0C4`3o4e`C000Z4`<0oa>H4`00:Q<00`0C4`3o4iPC000[4`0301<C00@C

00<04a<0oa>@4`00:a<0100C4a<400<C0`3o4h`C000Z4`0301<0008C0P000a<04`044`0301<C0?lC

RQ<002/C00<04a<00a<00`0C00034`0301<C0?lCB1<00`0C4`0g4`0301<C00HC000a4`0301<000@C

00<04a<01Q<00`0C4`0W4`<0:a<00`0C4`3M4`0301<C00@C00<04a<04a<00`0C4`0S4`0301<C00DC

000K4`<000<C00000P0<4`<011<300PC00<04a<09Q<0100C4`0?4`<000<C00000P024`0301<C008C

00<04a<00Q<00`0C4`054`0401<C4`D00Q<0100C4a<200@C0`024`0301<C00@C0P2[4`0401<C4`@0

0Q<200HC00<04a<00a<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`054`0401<C4`D00Q<0100C

4a<200@C0`024`0301<C00@C0P044`0401<C4`800A<001XC00@04a<091<00`0C4`0U4`0401<C00hC

00@04a<01Q<00`0C00074`0301<000@C1@034`0301<C00PC00<04a<00Q<01P0C4`0C00@C00<04a<0

ZQ<00`0C00074`0301<C00@C1@034`0701<C4`0C00074`0301<000@C1@034`0301<C00PC00<04a<0

0Q<01P0C4`0C00@C00<04a<011<00`0C4`024`400A<001XC00D04a<04`0400034`0001P0;A<300hC

00D04a<04`0400044`0C00TC00<04a<011<00`0C4`034`0301<C00LC00@04a<C10034`0301<C008C

00<04a<0ZQ<00`0C00024`@000<C01<01a<00`0C4`034`0701<C4`0C00094`0301<C00@C00<04a<0

0a<00`0C4`074`0401<C4`@00a<00`0C4`024`0301<C00@C00<04a<00a<100006a<304lC00<04a<0

3A<300HC00<04`001a<200LC00<04a<00a<00`0C4`084`0601<C01<00Q<200DC00<04a<0Ta<20003

4`00018C00<04`001a<00`0C4`064`0301<C00<C00L04a<C01<000LC0P074`0301<C00<C00<04a<0

21<01P0C4`0C008C0P054`0301<C00@C00<04a<00a<100007A<00`0C4`1<4`804A<00`0C4`044`03

01<000LC00<04a<031<00`0C4`064`0301<000<C0P024`0301<C00@C00<04`00U1<00`0C000C4`03

01<000LC00<04`003A<01P0C4`0C00LC00<04a<031<00`0C4`064`0301<000<C0P024`0301<C00@C

00<04`000a<00`0C4`034`400A<001`C0P1P4`801a<00`0C4`064`<02a<200TC00<04a<00a<00`0C

4`0300@C0`2E4`0301<C01<C00<04a<01Q<300hC00@04a<021<300/C0P094`0301<C00<C00<04a<0

0`044`<00Q<00`0C4`034`800A<00?lCDQ<00`0C4`1`4`009Q<200HC0P3o4b4C00<04`00LA<002PC

00<04a<00Q<00`0C4`3o4b0C0P000a<0001`4`009a<00`0C4`034`0301<C00HC00<04a<0oa><4`00

:1<00`0C4`024`0301<C008C0`0011<04a<30?lCRA<002HC00<04`0011<00`0C00024`800Q<00`0C

4`024`0301<C0?lCQa<002LC00<04a<00a<300@C00@04a<00Q<00`0C4`3o4hPC000d4`0401<C00<C

00<04a<0oa>74`00<Q<300@C0`3o4hTC003o4lDC003o4lDC003o4lDC003o4lDC003o4lDC0000\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-6.95686, -1.49821, 0.0206072, 0.0206072}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -82 0 ]

[.5 .96488 82 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -143 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.34) show

217.250000 19.500000 moveto

(C) show

222.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.23348 0 m

.26171 .03783 L

.30316 .09337 L

.34309 .14688 L

.3815 .19835 L

.42237 .25311 L

.46172 .30584 L

.49955 .35654 L

.53984 .41053 L

.57861 .46248 L

.61984 .51772 L

.65954 .57093 L

.69774 .62211 L

.73838 .67658 L

.77751 .72901 L

.81909 .78473 L

.85916 .83842 L

.89771 .89008 L

.93871 .94502 L

s

.93871 .94502 m

.94421 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.320622 0.238095 [

[.02381 .30812 -6 -9 ]

[.02381 .30812 6 0 ]

[.2619 .30812 -6 -9 ]

[.2619 .30812 6 0 ]

[.7381 .30812 -3 -9 ]

[.7381 .30812 3 0 ]

[.97619 .30812 -3 -9 ]

[.97619 .30812 3 0 ]

[1.025 .32062 0 -8 ]

[1.025 .32062 9 8 ]

[.4875 .08253 -12 -4.5 ]

[.4875 .08253 0 4.5 ]

[.4875 .20157 -24 -4.5 ]

[.4875 .20157 0 4.5 ]

[.4875 .43967 -18 -4.5 ]

[.4875 .43967 0 4.5 ]

[.4875 .55872 -6 -4.5 ]

[.4875 .55872 0 4.5 ]

[.4875 .67777 -18 -4.5 ]

[.4875 .67777 0 4.5 ]

[.4875 .79681 -6 -4.5 ]

[.4875 .79681 0 4.5 ]

[.5 .85094 -4.5 0 ]

[.5 .85094 4.5 16 ]

[.5 .83844 -134.5 0 ]

[.5 .83844 134.5 16 ]

[ 0 0 0 0 ]

[ 1 .82594 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .32062 m

.02381 .32687 L

s

[(-2)] .02381 .30812 0 1 Mshowa

.2619 .32062 m

.2619 .32687 L

s

[(-1)] .2619 .30812 0 1 Mshowa

.7381 .32062 m

.7381 .32687 L

s

[(1)] .7381 .30812 0 1 Mshowa

.97619 .32062 m

.97619 .32687 L

s

[(2)] .97619 .30812 0 1 Mshowa

.125 Mabswid

.07143 .32062 m

.07143 .32437 L

s

.11905 .32062 m

.11905 .32437 L

s

.16667 .32062 m

.16667 .32437 L

s

.21429 .32062 m

.21429 .32437 L

s

.30952 .32062 m

.30952 .32437 L

s

.35714 .32062 m

.35714 .32437 L

s

.40476 .32062 m

.40476 .32437 L

s

.45238 .32062 m

.45238 .32437 L

s

.54762 .32062 m

.54762 .32437 L

s

.59524 .32062 m

.59524 .32437 L

s

.64286 .32062 m

.64286 .32437 L

s

.69048 .32062 m

.69048 .32437 L

s

.78571 .32062 m

.78571 .32437 L

s

.83333 .32062 m

.83333 .32437 L

s

.88095 .32062 m

.88095 .32437 L

s

.92857 .32062 m

.92857 .32437 L

s

.25 Mabswid

0 .32062 m

1 .32062 L

s

gsave

1.025 .32062 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .08253 m

.50625 .08253 L

s

[(-1)] .4875 .08253 1 0 Mshowa

.5 .20157 m

.50625 .20157 L

s

[(-0.5)] .4875 .20157 1 0 Mshowa

.5 .43967 m

.50625 .43967 L

s

[(0.5)] .4875 .43967 1 0 Mshowa

.5 .55872 m

.50625 .55872 L

s

[(1)] .4875 .55872 1 0 Mshowa

.5 .67777 m

.50625 .67777 L

s

[(1.5)] .4875 .67777 1 0 Mshowa

.5 .79681 m

.50625 .79681 L

s

[(2)] .4875 .79681 1 0 Mshowa

.125 Mabswid

.5 .10634 m

.50375 .10634 L

s

.5 .13015 m

.50375 .13015 L

s

.5 .15396 m

.50375 .15396 L

s

.5 .17777 m

.50375 .17777 L

s

.5 .22538 m

.50375 .22538 L

s

.5 .24919 m

.50375 .24919 L

s

.5 .273 m

.50375 .273 L

s

.5 .29681 m

.50375 .29681 L

s

.5 .34443 m

.50375 .34443 L

s

.5 .36824 m

.50375 .36824 L

s

.5 .39205 m

.50375 .39205 L

s

.5 .41586 m

.50375 .41586 L

s

.5 .46348 m

.50375 .46348 L

s

.5 .48729 m

.50375 .48729 L

s

.5 .5111 m

.50375 .5111 L

s

.5 .53491 m

.50375 .53491 L

s

.5 .58253 m

.50375 .58253 L

s

.5 .60634 m

.50375 .60634 L

s

.5 .63015 m

.50375 .63015 L

s

.5 .65396 m

.50375 .65396 L

s

.5 .70157 m

.50375 .70157 L

s

.5 .72538 m

.50375 .72538 L

s

.5 .74919 m

.50375 .74919 L

s

.5 .773 m

.50375 .773 L

s

.5 .05872 m

.50375 .05872 L

s

.5 .03491 m

.50375 .03491 L

s

.5 .0111 m

.50375 .0111 L

s

.5 .82062 m

.50375 .82062 L

s

.25 Mabswid

.5 0 m

.5 .82594 L

s

gsave

.5 .85094 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .83844 -195.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.34) show

293.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

298.000000 15.000000 moveto

(L) show

305.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

312.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

319.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

324.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

328.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .82594 L

0 .82594 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .14558 m

.02575 .14559 L

.03156 .14561 L

.04112 .14565 L

.05427 .14571 L

.0708 .14578 L

.09041 .14587 L

.11277 .14598 L

.1375 .14612 L

.16418 .14628 L

.19234 .14646 L

.22151 .14668 L

.25119 .14693 L

.28087 .14722 L

.31005 .14754 L

.33821 .14791 L

.36489 .14832 L

.38962 .14876 L

.41198 .14923 L

.43159 .14971 L

.44812 .15019 L

.46127 .15061 L

.47083 .15096 L

.47663 .15119 L

.47858 .15127 L

s

.47858 .15127 m

.47911 .15129 L

.48068 .15136 L

.48328 .15147 L

.48685 .15162 L

.49134 .15183 L

.49666 .15209 L

.50273 .15241 L

.50945 .15279 L

.51669 .15324 L

.52434 .15377 L

.53226 .15438 L

.54031 .15509 L

.54837 .15591 L

.55629 .15686 L

.56394 .15795 L

.57118 .1592 L

.57789 .16064 L

.58397 .16228 L

.58929 .16416 L

.59378 .1663 L

.59735 .16873 L

.59994 .1715 L

.60152 .17462 L

.60205 .17813 L

s

.47858 .40524 m

.47911 .3921 L

.48068 .37892 L

.48328 .36583 L

.48685 .35288 L

.49134 .34011 L

.49666 .32757 L

.50273 .31532 L

.50945 .30338 L

.51669 .29181 L

.52434 .28065 L

.53226 .26992 L

.54031 .25967 L

.54837 .24991 L

.55629 .24067 L

.56394 .23197 L

.57118 .22382 L

.57789 .21623 L

.58397 .20919 L

.58929 .20272 L

.59378 .19678 L

.59735 .19138 L

.59994 .18649 L

.60152 .18209 L

.60205 .17816 L

s

.47858 .40536 m

.47911 .41848 L

.48068 .43159 L

.48328 .44457 L

.48685 .45736 L

.49134 .46992 L

.49666 .4822 L

.50273 .49414 L

.50945 .5057 L

.51669 .51681 L

.52434 .52745 L

.53226 .53757 L

.54031 .54711 L

.54837 .55605 L

.55629 .56434 L

.56394 .57195 L

.57118 .57885 L

.57789 .58501 L

.58397 .5904 L

.58929 .595 L

.59378 .59879 L

.59735 .60175 L

.59994 .60388 L

.60152 .60516 L

.60205 .60558 L

s

.60205 .60558 m

.60298 .60634 L

.60577 .60857 L

.61037 .6122 L

.6167 .61709 L

.62465 .62307 L

.63408 .62997 L

.64484 .63758 L

.65673 .64571 L

.66956 .65418 L

.68311 .66282 L

.69714 .67147 L

.71142 .67999 L

.7257 .68826 L

.73973 .69615 L

.75328 .70357 L

.76611 .71042 L

.778 .71665 L

.78876 .72217 L

.79819 .72693 L

.80614 .73089 L

.81247 .73401 L

.81707 .73625 L

.81986 .73761 L

.82079 .73806 L

s

.82079 .11189 m

.82146 .1085 L

.82344 .10477 L

.82671 .10072 L

.8312 .09638 L

.83685 .09176 L

.84355 .08691 L

.85119 .08185 L

.85964 .07666 L

.86876 .07137 L

.87838 .06605 L

.88835 .06076 L

.89849 .05557 L

.90863 .05053 L

.9186 .0457 L

.92823 .04115 L

.93734 .03692 L

.94579 .03306 L

.95343 .02963 L

.96013 .02666 L

.96578 .02418 L

.97028 .02222 L

.97354 .02081 L

.97553 .01995 L

.97619 .01967 L

s

.82079 .11191 m

.82146 .11499 L

.82344 .11776 L

.82671 .12023 L

.8312 .12242 L

.83685 .12436 L

.84355 .12605 L

.85119 .12754 L

.85964 .12884 L

.86876 .12997 L

.87838 .13095 L

.88835 .1318 L

.89849 .13254 L

.90863 .13317 L

.9186 .13372 L

.92823 .13419 L

.93734 .13459 L

.94579 .13492 L

.95343 .1352 L

.96013 .13543 L

.96578 .13562 L

.97028 .13575 L

.97354 .13585 L

.97553 .13591 L

.97619 .13593 L

s

.82079 .73806 m

.82146 .73839 L

.82344 .73934 L

.82671 .74092 L

.8312 .74307 L

.83685 .74575 L

.84355 .74891 L

.85119 .75247 L

.85964 .75637 L

.86876 .76053 L

.87838 .76487 L

.88835 .7693 L

.89849 .77376 L

.90863 .77817 L

.9186 .78245 L

.92823 .78653 L

.93734 .79036 L

.94579 .79388 L

.95343 .79703 L

.96013 .79978 L

.96578 .80207 L

.97028 .80389 L

.97354 .80521 L

.97553 .80601 L

.97619 .80627 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCaA<00?lCaA<006@C1@3X4`0301<C070C001V4`0301<C0>PC00<04a<0L1<003dC00<=4a<0

81<300<C00<04a<00Q<20>@C0P1a4`00?Q<00`dC4`0U4`0301<C008C00<04a<0ha<00`0C4`1`4`00

?Q<00`dC4`0U4`0301<C008C00<04a<0ha<00`0C4`1M4`8=4A<003lC00<=4a<08a<200@C00<04a<0

ha<00`0C4`1K4`8=4a<0040C00<=4a<0:1<20>@C00<04a<0FQ<00`dC4`0C4`00@A<00`dC4`0W4`03

01<C0><C0P1G4`@=5Q<0044C00<=4a<09a<00`0C4`3S4`0301<C05@C0PdJ4`00@Q<00`dC4`0V4`03

01<C0><C00<04a<0DQ<23A`C00134`033A<C02DC0P3T4`0301<C050C0PdN4`00A1<00`dC4`0T4`03

01<C0><C00<04a<0CQ<23B0C00144`033A<C02@C00<04a<0ha<204dC0PdR4`00AA<00`dC4`0S4`03

01<C0><C00<04a<0BQ<23B@C00164`033A<C028C0P3T4`0301<C04PC0PdV4`00Aa<00`dC4`0Q4`03

01<C0=`C1@024`0301<C04LC00<=4a<09Q<004LC00<=4a<08A<00`0C4`3N4`0301<C008C00<04a<0

AQ<00`dC4`0W4`00B1<00`dC4`0P4`0301<C0=PC0`034`0301<C008C0P164`033A<C02PC00194`03

3A<C01lC0P3O4`0301<C008C00<04a<0@a<23B/C001:4`033A<C01hC00<04a<0gQ<00`0C4`024`03

01<C048C00<=4a<0:a<004/C00<=4a<03Q<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`3M4`80

11<00`0C4`104`8=;Q<004/C00<=4a<03A<00`0C00074`0301<000<C00<04a<0ha<00`0C4`0o4`03

3A<C02hC001<4`033A<C00LC0`024`0301<000TC00@04a<C0P3T4`80@1<00`dC4`0^4`00CA<00`dC

4`0;4`0301<000LC0P044`0301<C0><C00<04a<0?Q<23C0C001>4`033A<C00XC00<04`001a<00`0C

4`034`0301<C0><C00<04a<0?a<23BlC001>4`033A<C00/C00<04a<01Q<300<C00<04a<0ha<00`0C

4`114`8=;A<004lC00<=4a<06A<00`0C4`3S4`80A1<63BLC001@4`033A<C01PC0P3T4`0301<C04TC

4PdE4`00DA<00`dC4`0G4`0301<C0><C00<04a<0Fa<43A4C001B4`033A<C01HC00<04a<0ha<00`0C

4`1`4`00DQ<00`dC4`0F4`0301<C088CE@d<4`0301<C070C001C4`033A<C01DC0P3H4a@=Ja<005@C

00<=4a<051<00`0C4`3S4`0301<C00DC20eS4`006Q<302DC1@0>4`033A<C01<C00<04a<091<502@C

0`2C4`0301<C00dC0`eP4`006Q<00`0C4`0W4`0301<C00hC00<=4a<04a<00`0C4`0V4`0301<C02@C

00<04a<0Ta<00`0C4`0@4`8=GQ<001DC0`034`0301<C020C0`034`0301<C00lC00<=4a<04Q<202LC

00<04a<09A<00`0C4`2B4`0301<C014C0PeM4`006a<00`0C4`0V4`0301<C010C00<=4a<04A<00`0C

4`0V4`0301<C02DC00<04a<0TQ<201<C00<=4a<0Fa<001XC00<04`009a<00`0C4`0A4`033A<C010C

00<04a<09Q<00`0C4`0T4`0301<009<C00<04a<04Q<00`dC4`1K4`006a<00`0C4`0U4`804a<00`dC

4`0@4`0301<C02DC0P0W4`0301<C098C00<04a<04A<00`dC4`1L4`00FA<00`dC4`0?4`80eA<00`0C

4`024`0301<C008C00<04a<00Q<00`0C4`0A4`033A<C05`C001J4`033A<C00hC00<04a<0da<00`0C

00074`0301<000<C00<04a<041<00`dC4`1M4`00FQ<00`dC4`0>4`0301<C05/C0P1a4`<00Q<00`0C

00094`0401<C4`8041<00`dC4`1N4`00Fa<00`dC4`0=4`0301<C05XC00<04a<0MQ<00`0C00074`80

11<00`0C4`0>4`033A<C05lC000E4dL000<=0000H`064`0301<C07HC00<04`001a<00`0C4`034`03

01<C00hC00<=4a<0Ga<001TC00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`03

01<C00DC00<04a<01Q<00`0C4`054`0301<=00DC00<04a<01A<00a0C4`054`0301<C00HC00<04a<0

1A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C4`054`03

01<C00PC00<04a<0Ma<00`0C4`064`<00a<00`0C4`0=4`033A<C060C001M4`033A<C00/C00<@4a<0

FQ<00`0C00264`0301<C00`C00<=4a<0HA<005hC00<=4a<02Q<245/C0`264`803A<00`dC4`1Q4`00

Ga<00`dC4`094`8@i1<00`0C4`0:4`8=I1<0060C00<=4a<01a<00a00403T4`0301<C00TC00<=4a<0

I1<0060C00<=4a<01a<00a00403T4`0301<C00TC00<=4a<0I1<0064C00<=4a<01Q<00a00403T4`03

01<C00PC00<=4a<0IA<0068C00<=4a<011<01A0C000@0><C0P084`033A<C06HC001S4`033A<C00<C

00D@4`0C403S4`0301<C00HC00<=4a<0Ia<006<C00<=4a<00a<01A0C01<@0><C00<04a<01A<00`dC

4`1X4`00I1<00`dC4`024`0341<0008C00<@4a<0h1<00`0C4`044`033A<C06TC001U4`063A<C4a0C

0P000a<@4`214`<0;A<502/C00<04a<011<00`dC4`0T4`D0;A<3010C001V4`063A<C41<00Q<00a0C

4`204`0301<C02lC00<04a<0:a<200@C00<=4a<09a<00`0C4`0]4`0301<C010C001V4`033A<@008C

00D04a<C401l4`<00a<00`0C4`0X4`<00a<00`0C4`0[4`0301<C008C00<=4a<0:1<00`0C4`0^4`03

01<C00lC001W4`053A0C4`000a<00a0C4`204`0301<C02hC00<04a<0:a<01@0C4a<=02/C00<04a<0

;Q<00`0C4`0?4`00J1<00`dC4`02008C00<@4a<0Oa<00`0C000_4`0301<C02/C00@04a<=;1<00`0C

4`0]4`0301<0010C001W4`0541<=4`0011<00a0C4`1o4`0301<C02dC0P0]4`8000<C3A<0:Q<2030C

00<04a<03a<005`C00<04a<00Q<00`0C4`024`06010C3A<011<00a0C4`3N4`0301<=070C001K4`03

01<000LC00<040000Q<00`d04`034`0341<C0=hC00<04`d0L1<005/C00<04`0021<00a004`024`03

3@0C00<C00<@4a<0gA<00`0=4`1/4`800Q<005/C00<04`001a<00`0@4`034`0300dC00<C00<@4a<0

gA<00`0=4`1[4`0301<C008C001K4`0301<000LC00<@4a<00a<00`0=4`044`0341<C07HCIP000`d0

001T00LC00<04a<00Q<005`C00<04a<01Q<00a0000034`0301<=00@C00<@4a<0Na<00`0C4`074`03

01<C00HC00<04a<01a<00`0C4`074`0301<C00LC00<04a<01Q<00`0C4`074`0301<C00LC00<04a<0

1Q<00`0C4`074`033A<C00LC00<04a<01a<00`0C4`064`0301<C00LC00<04a<01a<00`0C4`064`03

01<C00LC00<04a<01a<00`0C4`064`0301<C00LC00<04a<02Q<00`0C4`024`00I1<00a0C4`044`80

00<C3A<00Q<00a0C4`1k4`0301<C02hC00<04a<0;1<00`d04`0_4`0301<C02dC00<04a<02Q<00`0C

00024`00I1<00a0C4`044`0401<C3@@C00<@4a<0fA<00`dC001]4`<00Q<006<C00<@4a<01A<01@0C

4a<=00<C00<@4a<0fA<00`dC001b4`00Ha<00a0C4`054`0301<C008C00D=4a<C403J4`043A<0074C

001R4`0341<C00HC00<04a<00a<010dC4a3I4`043A<C078C001R4`0341<C00HC0P044`053A<C4a00

f1<010dC4`1b4`00HA<00a0C4`074`0301<C00@C00@=4a<@f1<010dC4`1b4`00HA<00a0C4`074`03

01<C00DC00<=4a00f1<010dC4`1b4`00H1<00a0C4`084`0301<C00HC00<=4a00ea<00`dC4`02074C

001P4`0341<C00PC0P084`033A0C0=DC00D=4a<C001b4`00Ga<00a0C4`094`0301<C00LC00<=4a00

eA<01@dC4a<0078C001O4`0341<C00TC00<04a<021<00`d@4`3D4`053A<C4`00LQ<005hC00<@4a<0

2Q<00`0C4`094`033A0C0=<C00D=4a<C001b4`00GQ<00a0C4`0:4`802a<00`dC4`3B4`043A<C4`80

LA<005dC00<@4a<02a<00`0C4`0;4`033A<C0=4C00D=4a<C001b4`00GA<00a0C4`044`D00Q<00`0C

4`0;4`0340dC0=4C00D=4a<C001b4`00G1<00a0C4`074`0301<C008C00<04a<031<00`dC4`3@4`05

3A<C4`00LQ<005/C00<@4a<021<00`0C4`024`803Q<00`dC4`3?4`053A<C4`00LQ<005/C00<@4a<0

21<00`0C4`024`0301<C00dC00<@3A<0ca<010dC4a<2074C001J4`0341<C00TC00<04a<00Q<00`0C

4`0>4`033A<C0<hC00D=4a<C001b4`00FQ<00a0C4`084`8011<00`0C4`0?4`033A<C0<dC00D=4a<C

001b4`00FA<00a0C4`0?4`8041<00a0=4`324`0301<C008C00<04a<00Q<00`0=4`024`0301<C070C

001H4`0341<C010C00<04a<041<00a0=4`304`0301<000LC00<04`d00a<00`0C4`1`4`00F1<00a0C

4`0@4`0301<C014C00<=4a<0_a<00`0C00094`0400dC4`80LA<005LC00<@4a<04A<00`0C4`0A4`03

40dC0;lC00<04`001a<200054`dC4`00LQ<005HC00<@4a<04Q<201<C00<@3A<0_Q<00`0C00074`04

01<C3@8C00<04a<0L1<005HC00<@4a<04Q<00`0C4`0C4`0340dC0;hC00<04a<01Q<300043A<C078C

001E4`0341<C01<C00<04a<04a<00a0=4`3:4`033A<C0080LA<005@C00<@4a<051<00`0C4`0D4`03

40dC0<XC00<=4`00LQ<005<C00<@4a<05A<201DC00<@4`d0bQ<00`dC001b4`00Da<00a0C4`0E4`03

01<C01DC00<@4`d0bA<00`dC001b4`00DQ<00a0C4`0F4`0301<C01HC00<@3A<0bA<00`d04`1a4`00

DA<00a0C4`0G4`0301<C01HC00<@4`d0bQ<00`d04`1`4`00DA<00a0C4`0G4`8061<00a0C3@394`03

3A<C070C001@4`0341<C01PC00<04a<05a<0110C4`g84`0300dC070C001?4`0341<C00PC1@024`03

01<C008C00<04a<00Q<00`0C4`0H4`0341<=0<PC00<03A<0L1<004lC00<@4a<02Q<00`0C4`064`03

01<000<C00<04a<06A<00a0C3@374`0301<=070C001>4`0341<C00/C00<04a<021<0100C4a<201/C

00<@4`d0aQ<200033A<C06hC001=4`0341<C00`C00<04a<01Q<200@C00<04a<06Q<00a0C3@364`04

01<C3FlC001<4`0341<C00dC00<04a<01Q<00`0C4`034`0301<C01/C00<@4`d0aA<01@0C4a<=06hC

001<4`0341<C00`C0P084`<00a<00`0C4`0L4`0341<=0<@C00<04a<00Q<00`dC4`1[4`00Ba<00a0C

4`0M4`807Q<00a0=4`334`0301<C00<C00<=4a<0JQ<004XC00<@4a<07Q<00`0C4`0M4`0341<=0<<C

0P054`033A<C06TC001:4`0341<C01hC00<04a<07Q<00a0C3@324`0301<C00@C00<=4a<0JA<004TC

00<@4a<07a<00`0C4`0O4`0341<=0<4C00<04a<01A<00`dC4`1X4`00B1<00a0C4`0P4`808A<00a0=

4`2i4`D00Q<00`0C4`064`033A<C06LC00174`0341<C024C00<04a<08A<00a0=4`2j4`0301<C008C

00<04a<01a<00`dC4`1V4`00Aa<00a0C4`0Q4`0301<C024C00<@4`d0^Q<00`0C4`024`802A<00`dC

4`1U4`00AQ<00a0C4`0R4`0301<C028C00<@4`d0^A<00`0C4`024`0301<C00TC00<=4a<0I1<004DC

00<@4a<08a<202@C00<@3A<0^1<00`0C4`024`0301<C00XC00<=4a<0Ha<004@C00<@4a<091<00`0C

4`0T4`0340dC0;HC0P044`0301<C00/C00<=4a<0HQ<004@C00<@4a<091<00`0C4`0T4`0341<=0;`C

00<04a<031<00`dC4`1Q4`00@a<00a0C4`0U4`0301<C02DC00<@4`d0^a<200hC00<=4a<0H1<0048C

00<@4a<09Q<00`0C4`0V4`0341<=0;XC00<04a<03Q<00`dC4`1O4`00@A<00a0C4`0W4`80:1<00a0=

4`2i4`0301<C00lC00<=4a<0GQ<0040C00<@4a<0:1<00`0C4`0X4`0340dC0;PC00<04a<041<00`dC

4`1M4`00@1<00a0C4`0R4`<00a<00`0C4`0Y4`0340dC0;LC0P0B4`8=GA<003lC00<@4a<08a<00`0C

4`034`0301<C02TC00<@4`d0]a<00`0C4`0C4`033A<C05XC000n4`0341<C02DC00<04a<00Q<202/C

00<@3A<0]Q<00`0C4`0D4`033A<C05TC000m4`0341<C02HC00<04a<00Q<00`0C4`0[4`0340dC0;DC

00<04a<05A<00`dC4`1H4`00?A<00a0C4`0U4`0301<000<C00<04a<0;1<00a0=4`2d4`0301<C01HC

0PeH4`00?1<00a0C4`0W4`0301<C008C00<04a<0;A<00a0=4`2c4`806A<00`dC4`1E4`00>a<00a0C

4`0]4`80;a<00`dC4`2b4`0301<C01TC0PeE4`00>Q<00a0C4`0^4`0301<C02hC00<@3A<0/Q<00`0C

4`0K4`033A<C058C000j4`0341<C02hC00<04a<0;a<00a0=4`2a4`0301<C01`C00<=4a<0DA<003TC

00<@4a<0;a<00`0C4`0`4`033A<C0;0C00<04a<07A<23E4C000h4`0341<C030C0P0b4`033A<C0:lC

0P0P4`8=Ca<003LC00<@4a<0<A<00`0C4`0a4`0340dC0:lC00<04a<08A<00`dC4`1<4`00=a<00a0C

4`0a4`0301<C038C00<@3A<0[Q<00`0C4`0R4`033A<C04/C000f4`0341<C038C00<04a<0<a<00`dC

4`2L4`D00Q<00`0C4`024`0301<C008C00<04a<08a<23D/C000e4`0341<C03<C0P0e4`033A<C09dC

00<04a<01Q<00`0C00034`0301<C02DC0Pe94`00=1<00a0C4`0d4`0301<C03DC00<=4a<0W1<00`0C

4`084`0401<C4`80:1<23DLC000c4`0341<C03DC00<04a<0=Q<00`dC4`2K4`0301<C00HC0P044`03

01<C02TC0Pe54`00<Q<00a0C4`0f4`0301<C03HC00<=4a<0Va<00`0C4`064`0301<C00<C00<04a<0

:a<00`dC4`124`00<A<00a0C4`0g4`80>1<00`dC4`2I4`8021<300<C00<04a<0;1<23D8C000`4`03

41<C03PC00<04a<0>1<00`dC4`2X4`0301<C02hC0Pe04`00;a<00a0C4`0Y4`<00a<00`0C4`024`03

01<C008C00<04a<0>A<00`dC4`2W4`80<A<23ChC000^4`0341<C02XC00<04a<01a<00`0C00034`03

01<C03TC00<=41<0Ya<00`0C4`0b4`033A<C03/C000]4`0341<C02`C00<04a<021<0100C4a<203/C

00<=41<0YQ<00`0C4`0c4`8=>a<002`C00<@4a<0;A<00`0C4`064`8011<00`0C4`0k4`033A0C0:DC

00<04a<0=A<23CTC000[4`0341<C02dC00<04`001a<00`0C4`034`0301<C03`C00<=41<0Y1<00`0C

4`0g4`8==a<002XC00<@4a<0;a<00`0C4`064`<00a<00`0C4`0l4`033A<@0:@C0P0j4`8==A<002TC

00<@4a<0?a<203hC00<=4a00Xa<00`0C4`0k4`033A<C038C000X4`0341<C040C00<04a<0?Q<00`dC

402R4`0301<C03`C10d`4`009a<00a0C4`114`0301<C03hC00@=4a<@XA<00`0C4`0o4`<=;Q<002HC

00<@4a<0@Q<00`0C4`0o4`043A<C4:0C00<04a<0@Q<00`dC4`0[4`009A<00a0C4`134`80@A<010dC

4a2O4`80A1<33BXC000T4`0341<C04@C00<04a<0@1<01@dC4a<@09hC00<04a<0AQ<00`dC4`0W4`00

8a<00a0C4`154`0301<C044C00D=4a<C402M4`0301<C04LC0PdW4`008a<00a0C4`154`0301<C048C

00D=4a<C402L4`0301<C04TC0PdU4`008Q<00a0C4`164`80A1<01@dC4a<@09/C0P1<4`8=8a<0024C

00<@4a<0Aa<00`0C4`134`033A<C008C00<@4a<0V1<00`0C4`1=4`8=8A<0020C00<@4a<0B1<00`0C

4`144`033A<C008C00<@4a<0Ua<00`0C4`1?4`@=7A<001lC00<@4a<0BA<00`0C4`154`033A<C008C

00<@4a<0T1<300<C00<04a<0Da<23A/C000N4`0341<C04XC0P174`033A<C008C00<@4a<0Sa<00`0C

4`034`0301<C05DC0PdI4`007A<00a0C4`1;4`0301<C04HC00<=4a<00a<00a0C4`2?4`0301<C008C

0P1H4`@=5A<001`C00<@4a<0C1<00`0C4`174`033A<C00<C00<@4a<0SQ<00`0C4`024`0301<C05/C

0PdC4`006a<00a0C4`174`8011<00`0C4`184`033A<C00<C00<@4a<0S1<00`0C00034`0301<C05dC

0PdA4`006Q<00a0C4`1:4`0501<C4`00BQ<00`dC4`044`0341<C08`C00<04a<00Q<00`0C4`1`4`00

6A<00a0C4`1:4`0301<C008C0P1:4`033A<C00<C00<@4a<0TA<00`0C4`1`4`00Ia<00`0C4`3W4`80

LA<006DC00<04`00jA<00`0C4`1`4`00IQ<00`0C4`3o4e`C000/4`<0oa>F4`00;1<00`0C4`3o4iHC

000]4`0301<C00DC00<04a<0oa>=4`00;A<0100C4a<300044`0C4`<0oa>:4`00;1<00`0C00024`80

0Q<00`0C4`024`0301<C0?lCR1<002dC00<04a<00a<0100C4`024`0301<C0?lCBA<00`0C4`0b4`03

01<C00PC000c4`0401<C00<C00<04a<01Q<00`0C4`0U4`<0;A<00`0C4`3N4`0301<C00@C00<04a<0

4a<00`0C4`0N4`0301<C00LC000M4`<000<C00000P0<4`<011<300PC00<04a<091<0100C4`0A4`<0

00<C00000P024`0301<C008C00<04a<00Q<00`0C4`054`0401<C4`D00Q<0100C4a<200@C0`044`80

/A<0100C4a<4008C0P064`0301<C00<C00<04a<00Q<00`0C4`024`0301<C008C00<04a<01A<0100C

4a<5008C00@04a<C0P044`<011<200@C00@04a<C0P014`400@0001`C00@04a<091<00`0C4`0S4`04

01<C010C00@04a<01Q<00`0C00074`0301<000@C1@034`0301<C00PC00<04a<00Q<00`0C4`024`03

01<C0;0C00<04`001a<00`0C4`044`D00a<01`0C4a<04`001a<00`0C00044`D00a<00`0C4`084`03

01<C008C00<04a<00Q<00`0C4`044`0301<C008C00<04`000A<001`C00D04a<04`0400034`0001P0

:a<3010C00D04a<04`0400044`0C00TC00<04a<011<00`0C4`034`0301<C00LC00@04a<C10034`03

01<C09HC0P000a<0000E4`0301<0008C10000a<04`074`0301<C00<C00L04a<C01<000TC00<04a<0

11<00`0C4`034`0301<C00LC00@04a<C10034`0301<C00@C00<04a<00a<1004C0A<001dC0`1=4`03

01<C00lC0`064`0301<000LC0P074`0301<C00<C00<04a<021<01P0C4`0C00@C00<04a<0Ua<00`0C

000F4`0301<000LC00<04a<01Q<00`0C4`034`0701<C4`0C00074`801a<00`0C4`034`0301<C00PC

00H04a<04`044`0301<C00@C00<04a<00a<1004C0A<001lC00<04a<0BQ<201<C00<04a<011<00`0C

00074`0301<C00`C00<04a<01Q<00`0C00034`8011<00`0C002H4`0301<C01DC00<04`001a<00`0C

000=4`0601<C01<01a<00`0C4`0<4`0301<C00HC00<04`000a<200@C00<04`000a<00`0C4`034`03

01<0004C000N4`80H1<200LC00<04a<01Q<300/C0P094`0301<C00<C00<04a<00Q<309PC00<04a<0

5Q<00`0C4`064`<03Q<0100C4`084`<02a<200TC00<04a<00a<00`0C4`024`<00Q<00`0C4`034`80

0A<10040003o4e4C00<04`00LA<002TC0P064`80oa<M4`8000<C0000L1<002/C00<04a<00Q<00`0C

4`3o4i8C000Z4`0301<C00<C00<04a<01A<00`0C4`3o4hXC000[4`0301<C008C00<04a<00Q<400<C

0`3o4hHC000Y4`0301<000@C00<04`000Q<200034`0C00@C00<04a<0oa>44`00:Q<00`0C4`034`<0

11<00`0C00034`0301<C0?lCQA<003LC00<04`0011<00`0C4`3o4h@C000e4`<011<30?lCQQ<00?lC

aA<00?lCaA<00?lCaA<00?lCaA<00?lCaA<00001\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-6.95686, -1.49543, 0.0206072, 0.0206072}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -84.5 0 ]

[.5 .96488 84.5 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -145.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.335) show

222.250000 19.500000 moveto

(C) show

227.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.23248 0 m

.26171 .03903 L

.30316 .09436 L

.34309 .14766 L

.3815 .19894 L

.42237 .2535 L

.46172 .30603 L

.49955 .35654 L

.53984 .41033 L

.57861 .46209 L

.61984 .51712 L

.65954 .57013 L

.69774 .62112 L

.73838 .67538 L

.77751 .72762 L

.81909 .78313 L

.85916 .83662 L

.89771 .88809 L

.93871 .94283 L

s

.93871 .94283 m

.94587 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.318673 0.238095 [

[.02381 .30617 -6 -9 ]

[.02381 .30617 6 0 ]

[.2619 .30617 -6 -9 ]

[.2619 .30617 6 0 ]

[.7381 .30617 -3 -9 ]

[.7381 .30617 3 0 ]

[.97619 .30617 -3 -9 ]

[.97619 .30617 3 0 ]

[1.025 .31867 0 -8 ]

[1.025 .31867 9 8 ]

[.4875 .08058 -12 -4.5 ]

[.4875 .08058 0 4.5 ]

[.4875 .19963 -24 -4.5 ]

[.4875 .19963 0 4.5 ]

[.4875 .43772 -18 -4.5 ]

[.4875 .43772 0 4.5 ]

[.4875 .55677 -6 -4.5 ]

[.4875 .55677 0 4.5 ]

[.4875 .67582 -18 -4.5 ]

[.4875 .67582 0 4.5 ]

[.4875 .79486 -6 -4.5 ]

[.4875 .79486 0 4.5 ]

[.5 .84841 -4.5 0 ]

[.5 .84841 4.5 16 ]

[.5 .83591 -137 0 ]

[.5 .83591 137 16 ]

[ 0 0 0 0 ]

[ 1 .82341 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .31867 m

.02381 .32492 L

s

[(-2)] .02381 .30617 0 1 Mshowa

.2619 .31867 m

.2619 .32492 L

s

[(-1)] .2619 .30617 0 1 Mshowa

.7381 .31867 m

.7381 .32492 L

s

[(1)] .7381 .30617 0 1 Mshowa

.97619 .31867 m

.97619 .32492 L

s

[(2)] .97619 .30617 0 1 Mshowa

.125 Mabswid

.07143 .31867 m

.07143 .32242 L

s

.11905 .31867 m

.11905 .32242 L

s

.16667 .31867 m

.16667 .32242 L

s

.21429 .31867 m

.21429 .32242 L

s

.30952 .31867 m

.30952 .32242 L

s

.35714 .31867 m

.35714 .32242 L

s

.40476 .31867 m

.40476 .32242 L

s

.45238 .31867 m

.45238 .32242 L

s

.54762 .31867 m

.54762 .32242 L

s

.59524 .31867 m

.59524 .32242 L

s

.64286 .31867 m

.64286 .32242 L

s

.69048 .31867 m

.69048 .32242 L

s

.78571 .31867 m

.78571 .32242 L

s

.83333 .31867 m

.83333 .32242 L

s

.88095 .31867 m

.88095 .32242 L

s

.92857 .31867 m

.92857 .32242 L

s

.25 Mabswid

0 .31867 m

1 .31867 L

s

gsave

1.025 .31867 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .08058 m

.50625 .08058 L

s

[(-1)] .4875 .08058 1 0 Mshowa

.5 .19963 m

.50625 .19963 L

s

[(-0.5)] .4875 .19963 1 0 Mshowa

.5 .43772 m

.50625 .43772 L

s

[(0.5)] .4875 .43772 1 0 Mshowa

.5 .55677 m

.50625 .55677 L

s

[(1)] .4875 .55677 1 0 Mshowa

.5 .67582 m

.50625 .67582 L

s

[(1.5)] .4875 .67582 1 0 Mshowa

.5 .79486 m

.50625 .79486 L

s

[(2)] .4875 .79486 1 0 Mshowa

.125 Mabswid

.5 .10439 m

.50375 .10439 L

s

.5 .1282 m

.50375 .1282 L

s

.5 .15201 m

.50375 .15201 L

s

.5 .17582 m

.50375 .17582 L

s

.5 .22343 m

.50375 .22343 L

s

.5 .24724 m

.50375 .24724 L

s

.5 .27105 m

.50375 .27105 L

s

.5 .29486 m

.50375 .29486 L

s

.5 .34248 m

.50375 .34248 L

s

.5 .36629 m

.50375 .36629 L

s

.5 .3901 m

.50375 .3901 L

s

.5 .41391 m

.50375 .41391 L

s

.5 .46153 m

.50375 .46153 L

s

.5 .48534 m

.50375 .48534 L

s

.5 .50915 m

.50375 .50915 L

s

.5 .53296 m

.50375 .53296 L

s

.5 .58058 m

.50375 .58058 L

s

.5 .60439 m

.50375 .60439 L

s

.5 .6282 m

.50375 .6282 L

s

.5 .65201 m

.50375 .65201 L

s

.5 .69963 m

.50375 .69963 L

s

.5 .72343 m

.50375 .72343 L

s

.5 .74724 m

.50375 .74724 L

s

.5 .77105 m

.50375 .77105 L

s

.5 .05677 m

.50375 .05677 L

s

.5 .03296 m

.50375 .03296 L

s

.5 .00915 m

.50375 .00915 L

s

.5 .81867 m

.50375 .81867 L

s

.25 Mabswid

.5 0 m

.5 .82341 L

s

gsave

.5 .84841 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .83591 -198 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.335) show

298.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

303.000000 15.000000 moveto

(L) show

310.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

317.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

324.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

329.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

333.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .82341 L

0 .82341 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .14317 m

.02575 .14318 L

.03156 .14321 L

.04112 .14325 L

.05427 .14331 L

.0708 .14338 L

.09041 .14348 L

.11277 .1436 L

.1375 .14375 L

.16417 .14392 L

.19233 .14412 L

.2215 .14435 L

.25118 .14462 L

.28086 .14492 L

.31003 .14527 L

.33819 .14566 L

.36487 .1461 L

.3896 .14657 L

.41196 .14708 L

.43157 .14759 L

.44809 .1481 L

.46125 .14855 L

.47081 .14892 L

.47661 .14917 L

.47855 .14925 L

s

.47855 .14925 m

.47908 .14927 L

.48063 .14934 L

.4832 .14946 L

.48673 .14963 L

.49116 .14984 L

.49642 .15012 L

.50242 .15045 L

.50905 .15085 L

.51621 .15132 L

.52376 .15187 L

.53159 .15252 L

.53955 .15326 L

.54751 .15412 L

.55534 .1551 L

.56289 .15623 L

.57005 .15753 L

.57668 .15901 L

.58268 .1607 L

.58794 .16263 L

.59237 .16483 L

.5959 .16732 L

.59847 .17014 L

.60002 .17332 L

.60055 .17688 L

s

.47855 .40333 m

.47908 .39027 L

.48063 .37718 L

.4832 .36418 L

.48673 .3513 L

.49116 .33861 L

.49642 .32615 L

.50242 .31396 L

.50905 .30209 L

.51621 .29058 L

.52376 .27947 L

.53159 .26879 L

.53955 .25857 L

.54751 .24884 L

.55534 .23963 L

.56289 .23094 L

.57005 .2228 L

.57668 .2152 L

.58268 .20816 L

.58794 .20166 L

.59237 .1957 L

.5959 .19027 L

.59847 .18534 L

.60002 .18089 L

.60055 .17691 L

s

.47855 .40344 m

.47908 .41648 L

.48063 .42949 L

.4832 .44238 L

.48673 .45509 L

.49116 .46756 L

.49642 .47975 L

.50242 .49161 L

.50905 .50308 L

.51621 .51412 L

.52376 .52468 L

.53159 .53472 L

.53955 .54419 L

.54751 .55306 L

.55534 .56129 L

.56289 .56885 L

.57005 .57569 L

.57668 .58181 L

.58268 .58716 L

.58794 .59172 L

.59237 .59548 L

.5959 .59843 L

.59847 .60054 L

.60002 .60181 L

.60055 .60223 L

s

.60055 .60223 m

.60152 .60302 L

.60444 .60536 L

.60924 .60916 L

.61584 .61428 L

.62414 .62053 L

.63398 .62772 L

.64521 .63564 L

.65762 .6441 L

.67102 .6529 L

.68516 .66187 L

.6998 .67083 L

.7147 .67965 L

.7296 .6882 L

.74425 .69635 L

.75839 .70401 L

.77178 .71109 L

.78419 .71751 L

.79542 .7232 L

.80526 .72811 L

.81356 .73219 L

.82016 .7354 L

.82496 .73772 L

.82788 .73912 L

.82885 .73958 L

s

.82885 .10821 m

.82948 .10487 L

.83136 .10123 L

.83446 .09729 L

.83872 .09308 L

.84408 .08861 L

.85043 .08393 L

.85768 .07907 L

.86569 .07408 L

.87433 .06901 L

.88346 .06392 L

.89291 .05886 L

.90252 .05389 L

.91214 .04907 L

.92159 .04446 L

.93071 .04011 L

.93936 .03607 L

.94737 .03239 L

.95461 .02912 L

.96097 .02628 L

.96632 .02391 L

.97058 .02204 L

.97368 .02069 L

.97556 .01988 L

.97619 .0196 L

s

.82885 .10823 m

.82948 .11126 L

.83136 .11401 L

.83446 .11648 L

.83872 .11868 L

.84408 .12063 L

.85043 .12235 L

.85768 .12387 L

.86569 .1252 L

.87433 .12636 L

.88346 .12738 L

.89291 .12826 L

.90252 .12903 L

.91214 .1297 L

.92159 .13027 L

.93071 .13077 L

.93936 .13119 L

.94737 .13154 L

.95461 .13184 L

.96097 .13208 L

.96632 .13228 L

.97058 .13243 L

.97368 .13253 L

.97556 .13259 L

.97619 .13261 L

s

.82885 .73958 m

.82948 .73988 L

.83136 .74078 L

.83446 .74225 L

.83872 .74427 L

.84408 .74678 L

.85043 .74974 L

.85768 .75308 L

.86569 .75674 L

.87433 .76065 L

.88346 .76473 L

.89291 .7689 L

.90252 .7731 L

.91214 .77725 L

.92159 .78129 L

.93071 .78514 L

.93936 .78876 L

.94737 .79208 L

.95461 .79506 L

.96097 .79765 L

.96632 .79983 L

.97058 .80155 L

.97368 .80279 L

.97556 .80355 L

.97619 .8038 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCaA<00?lCaA<006@C1@3X4`0301<C070C001V4`0301<C0>PC00<04a<0L1<003dC00<=4a<0

81<300<C00<04a<00Q<20>@C0P1a4`00?Q<00`dC4`0U4`0301<C008C00<04a<0ha<00`0C4`1`4`00

?Q<00`dC4`0U4`0301<C008C00<04a<0ha<00`0C4`1N4`033A<C00lC000o4`033A<C02<C0P044`03

01<C0><C00<04a<0G1<23A8C00104`033A<C02PC0P3T4`0301<C05XC0PdD4`00@A<00`dC4`0W4`03

01<C0><C0P1I4`8=5Q<0044C00<=4a<09a<00`0C4`3S4`0301<C05DC0`dH4`00@Q<00`dC4`0V4`03

01<C0><C00<04a<0Da<23A/C00134`033A<C02DC0P3T4`0301<C054C0PdM4`00A1<00`dC4`0T4`03

01<C0><C00<04a<0Ca<23AlC00144`033A<C02@C00<04a<0ha<204hC0PdQ4`00AA<00`dC4`0S4`03

01<C0><C00<04a<0Ba<23B<C00164`033A<C028C0P3T4`0301<C04TC0PdU4`00Aa<00`dC4`0Q4`03

01<C0=`C1@024`0301<C04PC00<=4a<09A<004LC00<=4a<08A<00`0C4`3N4`0301<C008C00<04a<0

AQ<23BPC00184`033A<C020C00<04a<0f1<300<C00<04a<00Q<204HC00<=4a<0:1<004TC00<=4a<0

7a<20=lC00<04a<00Q<00`0C4`134`8=:a<004XC00<=4a<07Q<00`0C4`3N4`0301<C008C00<04a<0

@Q<00`dC4`0[4`00Ba<00`dC4`0>4`0301<C008C00<04a<00Q<00`0C4`024`0301<C0=dC0P044`03

01<C044C00<=4a<0;1<004/C00<=4a<03A<00`0C00074`0301<000<C00<04a<0ha<2048C00<=4a<0

;1<004`C00<=4a<01a<3008C00<04`002A<0100C4a<20>@C00<04a<0@1<00`dC4`0]4`00CA<00`dC

4`0;4`0301<000LC0P044`0301<C0><C00<04a<0@1<23BhC001>4`033A<C00XC00<04`001a<00`0C

4`034`0301<C0><C00<04a<0@A<23BdC001>4`033A<C00/C00<04a<01Q<300<C00<04a<0ha<00`0C

4`134`@=:A<004lC00<=4a<06A<00`0C4`3S4`80B1<93B0C001@4`033A<C01PC0P3T4`0301<C050C

3`dA4`00DA<00`dC4`0G4`0301<C0><C00<04a<0L1<0058C00<=4a<05Q<00`0C4`224b0=@A<00`0C

4`1`4`00DQ<00`dC4`0F4`0301<C0:8C>Pd74`0301<C070C001C4`033A<C01DC0P3M4a0=JQ<005@C

00<=4a<051<00`0C4`3S4`0301<C00HC1PeT4`006Q<302DC1@0>4`033A<C01<C00<04a<091<502@C

0`2C4`0301<C00`C10eP4`006Q<00`0C4`0W4`0301<C00hC00<=4a<04a<00`0C4`0V4`0301<C02@C

00<04a<0Ta<00`0C4`0@4`8=GQ<001DC0`034`0301<C020C0`034`0301<C00lC00<=4a<04Q<202LC

00<04a<09A<00`0C4`2B4`0301<C014C00<=4a<0G1<001/C00<04a<09Q<00`0C4`0@4`033A<C014C

00<04a<09Q<00`0C4`0U4`0301<C098C0P0C4`033A<C05/C000J4`0301<002LC00<04a<04A<00`dC

4`0@4`0301<C02HC00<04a<091<00`0C002C4`0301<C014C00<=4a<0G1<001/C00<04a<09A<201<C

00<=4a<041<00`0C4`0U4`809a<00`0C4`2B4`0301<C014C00<=4a<0G1<005TC00<=4a<03a<20=DC

00<04a<00Q<00`0C4`024`0301<C008C00<04a<04A<00`dC4`1L4`00FQ<00`dC4`0>4`0301<C0=<C

00<04`001a<00`0C00034`0301<C010C00<=4a<0GA<005XC00<=4a<03Q<00`0C4`1K4`80LA<3008C

00<04`002A<0100C4a<2010C00<=4a<0GQ<005/C00<=4a<03A<00`0C4`1J4`0301<C07HC00<04`00

1a<200@C00<04a<03Q<00`dC4`1O4`005A=700033@0006<01Q<00`0C4`1f4`0301<000LC00<04a<0

0a<00`0C4`0>4`033A<C05lC000I4`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC00<04a<0

1A<00`0C4`054`0301<C00HC00<04a<01A<00`0C3@054`0301<C00DC00<@4a<01A<00`0C4`064`03

01<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<0

1A<00`0C4`084`0301<C07LC00<04a<01Q<300<C00<04a<03A<00`dC4`1P4`00GA<00`dC4`0;4`03

41<C05XC00<04`00QQ<00`0C4`0<4`033A<C064C001N4`033A<C00XC0Q1K4`<0QQ<200`C00<=4a<0

HQ<005lC00<=4a<02A<24>@C00<04a<02Q<00`dC4`1S4`00H1<00`dC4`074`03400@0>@C00<04a<0

2A<00`dC4`1T4`00H1<00`dC4`074`03400@0>@C00<04a<021<00`dC4`1U4`00HA<00`dC4`064`03

400@0>@C00<04a<01a<00`dC4`1V4`00HQ<00`dC4`044`0541<00100ha<200PC00<=4a<0IQ<006<C

00<=4a<00a<01A0C01<@0><C00<04a<01Q<00`dC4`1W4`00Ha<00`dC4`034`0541<04a00ha<00`0C

4`054`033A<C06PC001T4`033A<C008C00<@4`000Q<00a0C4`3P4`0301<C00@C00<=4a<0JA<006DC

00H=4a<C41<200034a0C084C0`0]4`D0:a<200DC00<=4a<091<502dC0`0@4`00IQ<01PdC4a0C008C

00<@4a<0P1<00`0C4`0_4`0301<C02/C00<04a<00a<00`dC4`0W4`0301<C02dC00<04a<041<006HC

00<=4a000Q<01@0C4a<@07`C0`034`0301<C02PC0`034`0301<C02/C00<04a<00Q<00`dC4`0X4`03

01<C02hC00<04a<03a<006LC00D=41<C00034`0341<C080C00<04a<0;Q<00`0C4`0[4`0501<C4`d0

:a<00`0C4`0^4`0301<C00lC001X4`033A<C00800Q<00a0C4`1o4`0301<002lC00<04a<0:a<0100C

4`d/4`0301<C02dC00<04`0041<006LC00D@4`dC00044`0341<C07lC00<04a<0;A<202dC0P000a<=

4`0Z4`80<1<00`0C4`0?4`00G1<00`0C4`024`0301<C008C00H041<=4`044`0341<C0=hC00<04`d0

L1<005/C00<04`001a<00`0@00024`033@0C00<C00<@4a<0gQ<00`0C3@1`4`00Fa<00`0C00084`03

400C008C00<=01<00a<00a0C4`3M4`0300dC06`C0P024`00Fa<00`0C00074`03010C00<C00<03A<0

0a<00a0C4`3M4`0300dC06/C00<04a<00Q<005/C00<04`001a<00a0C4`034`0301<=00@C00<@4a<0

MQ=V00033@0006@01a<00`0C4`024`00G1<00`0C4`064`03400000<C00<04`d011<00a0C4`1k4`03

01<C00LC00<04a<01Q<00`0C4`074`0301<C00LC00<04a<01a<00`0C4`064`0301<C00LC00<04a<0

1a<00`0C4`064`0301<C00LC00<=4a<01a<00`0C4`074`0301<C00HC00<04a<01a<00`0C4`074`03

01<C00HC00<04a<01a<00`0C4`074`0301<C00HC00<04a<01a<00`0C4`0:4`0301<C008C001T4`03

41<C00@C0P000a<=4`024`0341<C0=/C00<=01<0K1<00`0C00024`00I1<00a0C4`044`0501<C4`d0

0a<00a0C4`3I4`033A<006dC0`024`00Ha<00a0C4`054`0301<C008C00@=4a<@fa<00`dC001b4`00

Ha<00a0C4`054`0301<C008C00D=4a<C403J4`043A<0074C001R4`0341<C00HC00<04a<00a<010dC

4a3I4`043A<C078C001R4`0341<C00HC0P054`043A<C4=PC00@=4a<0LQ<0064C00<@4a<01a<00`0C

4`054`033A<@0=PC00@=4a<0LQ<0064C00<@4a<01a<00`0C4`064`033A0C0=LC00@=4a<0LQ<0060C

00<@4a<021<00`0C4`064`033A<@0=LC00<=4a<00P1a4`00H1<00a0C4`084`8021<00`d@4`3E4`05

3A<C4`00LQ<005lC00<@4a<02A<00`0C4`084`033A0C0=@C00D=4a<C001b4`00Ga<00a0C4`094`03

01<C00TC00<=4a<0da<01@dC4a<0078C001N4`0341<C00XC00<04a<02A<00`d@4`3C4`053A<C4`00

LQ<005hC00<@4a<02Q<200/C00<=4a<0dQ<010dC4a<2074C001M4`0341<C00/C00<04a<02a<00`dC

4`3A4`053A<C4`00LQ<005dC00<@4a<011<5008C00<04a<02a<00a0=4`3A4`053A<C4`00LQ<005`C

00<@4a<01a<00`0C4`024`0301<C00`C00<=4a<0d1<01@dC4a<0078C001K4`0341<C00PC00<04a<0

0Q<200hC00<=4a<0ca<01@dC4a<0078C001K4`0341<C00PC00<04a<00Q<00`0C4`0=4`0340dC0<lC

00@=4a<C0P1a4`00FQ<00a0C4`094`0301<C008C00<04a<03Q<00`dC4`3>4`053A<C4`00LQ<005XC

00<@4a<021<200@C00<04a<03a<00`dC4`324`0301<C008C00<04a<00Q<00`0=4`024`0301<C070C

001I4`0341<C00lC0P0@4`0340dC0<4C00<04`001a<00`0C3@034`0301<C070C001H4`0341<C010C

00<04a<041<00a0=4`304`0301<000TC00@=4a<C0P1a4`00F1<00a0C4`0@4`0301<C014C00<=4a<0

_a<00`0C00074`8000DC3A<C001b4`00Ea<00a0C4`0A4`0301<C014C00<@3A<0_a<00`0C00074`04

01<C3@8C00<04a<0L1<005HC00<@4a<04Q<201<C00<@3A<0_a<00`0C4`064`<000@=4a<0LQ<005HC

00<@4a<04Q<00`0C4`0C4`0340dC0<XC00@=4a<0LQ<005DC00<@4a<04a<00`0C4`0C4`0340dC0<XC

00<=4a<00P1a4`00E1<00a0C4`0D4`0301<C01@C00<@3A<0bQ<00`dC001b4`00Da<00a0C4`0E4`80

5A<00a0C3@3:4`033A<0078C001C4`0341<C01DC00<04a<05A<00a0C3@3:4`033@0C074C001B4`03

41<C01HC00<04a<05Q<00a0=4`394`033@0C074C001A4`0341<C01LC00<04a<05Q<00a0C3@3:4`03

3@0C070C001A4`0341<C01LC0P0H4`0341<=0<TC00<03A<0L1<0050C00<@4a<061<00`0C4`0G4`04

41<C3LPC00<03A<0L1<004lC00<@4a<021<5008C00<04a<00Q<00`0C4`024`0301<C01PC00<@4`d0

b1<00`0C3@1`4`00Ca<00a0C4`0:4`0301<C00HC00<04`000a<00`0C4`0I4`0341<=0<LC00<04`d0

L1<004hC00<@4a<02a<00`0C4`084`0401<C4`806a<00a0C3@364`8000<=4a<0KQ<004dC00<@4a<0

31<00`0C4`064`8011<00`0C4`0J4`0341<=0<HC00@04a<=Ka<004`C00<@4a<03A<00`0C4`064`03

01<C00<C00<04a<06a<00a0C3@354`0501<C4`d0KQ<004`C00<@4a<031<200PC0`034`0301<C01`C

00<@4`d0a1<00`0C4`024`033A<C06/C001;4`0341<C01dC0P0N4`0340dC0<<C00<04a<00a<00`dC

4`1Z4`00BQ<00a0C4`0N4`0301<C01dC00<@4`d0`a<200DC00<=4a<0JA<004XC00<@4a<07Q<00`0C

4`0N4`0341<=0<8C00<04a<011<00`dC4`1Y4`00BA<00a0C4`0O4`0301<C01lC00<@4`d0`A<00`0C

4`054`033A<C06PC00184`0341<C020C0P0Q4`0340dC0;TC1@024`0301<C00HC00<=4a<0Ia<004LC

00<@4a<08A<00`0C4`0Q4`0340dC0;XC00<04a<00Q<00`0C4`074`033A<C06HC00174`0341<C024C

00<04a<08A<00a0C3@2j4`0301<C008C0P084`033A<C06HC00164`0341<C028C00<04a<08Q<00a0C

3@2i4`0301<C008C00<04a<021<00`dC4`1U4`00AA<00a0C4`0S4`8091<00a0=4`2h4`0301<C008C

00<04a<02A<23FDC00144`0341<C02@C00<04a<091<00a0=4`2f4`8011<00`0C4`0;4`033A<C068C

00144`0341<C02@C00<04a<091<00a0C3@2l4`803A<00`dC4`1Q4`00@a<00a0C4`0U4`0301<C02DC

00<@4`d0^a<00`0C4`0=4`033A<C060C00124`0341<C02HC00<04a<09Q<00a0C3@2j4`0301<C00hC

00<=4a<0Ga<0044C00<@4a<09a<202PC00<@3A<0^A<00`0C4`0?4`033A<C05hC00104`0341<C02PC

00<04a<0:1<00a0=4`2h4`0301<C010C0PeN4`00@1<00a0C4`0R4`<00a<00`0C4`0Y4`0340dC0;LC

0P0B4`8=GA<003lC00<@4a<08a<00`0C4`034`0301<C02TC00<@4`d0]a<00`0C4`0B4`8=G1<003hC

00<@4a<09A<00`0C4`024`80:a<00a0=4`2f4`0301<C01@C0PeJ4`00?A<00a0C4`0V4`0301<C008C

00<04a<0:a<00a0=4`2e4`0301<C01DC00<=4a<0F1<003dC00<@4a<09A<00`0C00034`0301<C02`C

00<@3A<0]1<00`0C4`0F4`033A<C05LC000l4`0341<C02LC00<04a<00Q<00`0C4`0]4`0340dC0;<C

0P0H4`8=Ea<003/C00<@4a<0;A<202lC00<@3A<0/Q<00`0C4`0I4`8=EA<003XC00<@4a<0;Q<00`0C

4`0^4`0340dC0;8C00<04a<06a<00`dC4`1B4`00>Q<00a0C4`0^4`0301<C02lC00<@3A<0/A<00`0C

4`0L4`8=DQ<003TC00<@4a<0;a<00`0C4`0`4`0340dC0;0C00<04a<07Q<23E0C000h4`0341<C030C

0P0b4`0340dC0:lC0P0Q4`033A<C04dC000g4`0341<C034C00<04a<0<A<00a0=4`2_4`0301<C024C

0Pe=4`00=a<00a0C4`0a4`0301<C038C00<@3A<0[Q<00`0C4`0S4`033A<C04XC000f4`0341<C038C

00<04a<0<a<00a0=4`2L4`D00Q<00`0C4`024`0301<C008C00<04a<091<23DXC000e4`0341<C03<C

0P0e4`0340dC09dC00<04a<01Q<00`0C00034`0301<C02HC00<=4a<0Aa<003@C00<@4a<0=1<00`0C

4`0e4`033A<C09`C00<04a<021<0100C4a<202PC0Pe74`00<a<00a0C4`0e4`0301<C03HC00<=4a<0

Va<00`0C4`064`8011<00`0C4`0Y4`8=AA<0038C00<@4a<0=Q<00`0C4`0f4`0340dC09/C00<04a<0

1Q<00`0C4`034`0301<C02/C0Pe34`00<A<00a0C4`0g4`80>1<00`dC4`2I4`8021<300<C00<04a<0

;A<23D4C000`4`0341<C03PC00<04a<0>1<00`dC4`2X4`0301<C02lC00<=4a<0?Q<002lC00<@4a<0

:A<300<C00<04a<00Q<00`0C4`024`0301<C03TC00<=4a<0Ya<2034C0Pdn4`00;Q<00a0C4`0Z4`03

01<C00LC00<04`000a<00`0C4`0j4`033A<C0:HC00<04a<0<Q<00`dC4`0k4`00;A<00a0C4`0/4`03

01<C00PC00@04a<C0P0k4`033A0C0:HC00<04a<0<a<33CXC000/4`0341<C02dC00<04a<01Q<200@C

00<04a<0>a<00`d@4`2U4`0301<C03HC0Pdh4`00:a<00a0C4`0]4`0301<000LC00<04a<00a<00`0C

4`0l4`033A0C0:@C00<04a<0>1<00`dC4`0e4`00:Q<00a0C4`0_4`0301<C00HC0`034`0301<C03`C

00<=4a00Y1<203XC00<=4a<0=1<002TC00<@4a<0?a<203hC00<=4a00Xa<00`0C4`0j4`@=<Q<002PC

00<@4a<0@1<00`0C4`0n4`033A<@0:8C00<04a<0?Q<00`dC4`0_4`009a<00a0C4`114`0301<C03hC

00@=4a<@XA<00`0C4`0o4`<=;Q<002HC00<@4a<0@Q<00`0C4`0o4`043A<C4:0C0P134`8=;1<002DC

00<@4a<0@a<2044C00@=4a<@Wa<00`0C4`144`8=:Q<002@C00<@4a<0A1<00`0C4`104`053A<C4a00

WQ<00`0C4`164`<=9a<002<C00<@4a<0AA<00`0C4`114`053A<C4a00WA<00`0C4`194`033A<C02@C

000S4`0341<C04DC00<04a<0@Q<01@dC4a<@09`C00<04a<0BQ<23B@C000R4`0341<C04HC0P144`05

3A<C4a00Va<204dC0PdR4`008A<00a0C4`174`0301<C04<C00<=4a<00Q<00a0C4`2H4`0301<C04hC

0PdP4`0081<00a0C4`184`0301<C04@C00<=4a<00Q<00a0C4`2G4`0301<C050C10dL4`007a<00a0C

4`194`0301<C04DC00<=4a<00Q<00a0C4`2@4`<00a<00`0C4`1D4`8=6Q<001hC00<@4a<0BQ<204LC

00<=4a<00Q<00a0C4`2?4`0301<C00<C00<04a<0EQ<23APC000M4`0341<C04/C00<04a<0AQ<00`dC

4`034`0341<C08lC00<04a<00Q<205TC0`dE4`0071<00a0C4`1<4`0301<C04LC00<=4a<00a<00a0C

4`2>4`0301<C008C00<04a<0Fa<23A<C000K4`0341<C04LC0P044`0301<C04PC00<=4a<00a<00a0C

4`2<4`0301<000<C00<04a<0GA<23A4C000J4`0341<C04XC00D04a<C001;4`033A<C00<C00<@4a<0

S1<00`0C4`024`0301<C070C000I4`0341<C04XC00<04a<00Q<204/C00<=4a<00Q<00a0C4`2A4`03

01<C070C001W4`0301<C0>LC0P1a4`00IA<00`0C003Y4`0301<C070C001V4`0301<C0?lCG1<002XC

0`3o4iPC000Z4`0301<C0?lCV1<002/C00<04a<011<00`0C4`3o4i0C000[4`0401<C4`@00a<30?lC

S1<002XC00<04`000Q<200034`0C00@C00<04a<0oa>:4`00:a<00`0C4`034`0301<000<C00<04a<0

oa=84`0301<C03LC00<04a<01Q<0034C00<04`0011<00`0C4`064`0301<C02LC0`0[4`0301<C0=dC

00<04a<011<00`0C4`0C4`0301<C02<C00<04a<01A<001/C0`000a<0000200`C0`044`<021<00`0C

4`0V4`0401<C00lC0`000a<00002008C00<04a<00Q<00`0C4`024`0301<C00DC00@04a<C1@024`04

01<C4`800a<200@C00<04a<011<20:/C00@04a<C10024`801Q<00`0C4`034`0301<C008C00<04a<0

0Q<00`0C4`024`0301<C00DC00@04a<C1@024`0401<C4`800a<200@C00<04a<011<200@C00@04a<C

0P014`006Q<0100C4`0T4`0301<C02DC00@04a<03Q<0100C4`064`0301<000LC00<04`0011<500<C

00<04a<021<00`0C4`024`0601<C01<011<00`0C4`2Z4`0301<000LC00<04a<011<500<C00L04a<C

01<000LC00<04`0011<500<C00<04a<021<00`0C4`024`0601<C01<011<00`0C4`044`0301<C008C

0@014`006Q<01@0C4`0C00@000<C0000600]4`<03Q<01@0C4`0C00@000@C01<02A<00`0C4`044`03

01<C00<C00<04a<01a<00`0C4`024`0301<C00<C00<04a<00Q<00`0C4`2C4`8000<C00004Q<00`0C

00024`@000<C01<01a<00`0C4`034`0701<C4`0C00094`0301<C00@C00<04a<00a<00`0C4`074`03

01<C008C00<04a<00a<00`0C4`024`0301<C00@C00<04a<00a<100006a<304lC00<04a<03A<300HC

00<04`001a<200LC00<04a<00a<00`0C4`084`0301<C008C00<04a<00P054`0301<C09@C00<04`00

4a<00`0C00074`0301<C00HC00<04a<00a<01`0C4a<04`001a<200LC00<04a<00a<00`0C4`084`03

01<C008C00<04a<00P054`0301<C00@C00<04a<00a<100007A<00`0C4`1<4`804A<00`0C4`044`03

01<000LC00<04a<031<00`0C4`064`0301<0008C00<04`000Q<00`0C4`044`0301<009DC00<04a<0

4Q<00`0C00074`0301<000dC00H04a<04`074`0301<C00`C00<04a<01Q<00`0C00024`0301<0008C

00<04a<011<00`0C00034`0301<C00<C0@014`0071<2060C0P074`0301<C00HC0`0;4`802A<00`0C

4`024`0401<C4`<011<309DC00<04a<04a<00`0C4`064`<03Q<0100C4`084`<02a<200TC00<04a<0

0Q<0100C4a<300@C0`024`0301<C00<C0P014`00oa=A4`0301<0074C000V4`801Q<20?lC81<20003

4`00070C000X4`0301<C008C00<04a<0oa>E4`009a<00`0C4`034`0301<C00HC00<04a<0oa><4`00

:1<00`0C4`024`0301<C008C0`0011<04a<30?lCRA<002HC00<04`0011<00`0C00024`800Q<00`0C

4`024`0301<C0?lCQa<002LC00<04a<00a<300@C00@04a<00Q<00`0C4`3o4hPC000d4`0401<C00<C

00<04a<0oa>74`00<Q<300@C0`3o4hTC003o4lDC003o4lDC003o4lDC003o4lDC003o4lDC0000\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-6.95686, -1.49255, 0.0206072, 0.0206072}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -82 0 ]

[.5 .96488 82 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -143 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.33) show

217.250000 19.500000 moveto

(C) show

222.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.23147 0 m

.26171 .04022 L

.30316 .09534 L

.34309 .14845 L

.3815 .19954 L

.42237 .25389 L

.46172 .30623 L

.49955 .35655 L

.53984 .41013 L

.57861 .4617 L

.61984 .51652 L

.65954 .56934 L

.69774 .62013 L

.73838 .67419 L

.77751 .72623 L

.81909 .78154 L

.85916 .83483 L

.89771 .8861 L

.93871 .94063 L

s

.93871 .94063 m

.94755 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.316673 0.238095 [

[.02381 .30417 -6 -9 ]

[.02381 .30417 6 0 ]

[.2619 .30417 -6 -9 ]

[.2619 .30417 6 0 ]

[.7381 .30417 -3 -9 ]

[.7381 .30417 3 0 ]

[.97619 .30417 -3 -9 ]

[.97619 .30417 3 0 ]

[1.025 .31667 0 -8 ]

[1.025 .31667 9 8 ]

[.4875 .07858 -12 -4.5 ]

[.4875 .07858 0 4.5 ]

[.4875 .19763 -24 -4.5 ]

[.4875 .19763 0 4.5 ]

[.4875 .43572 -18 -4.5 ]

[.4875 .43572 0 4.5 ]

[.4875 .55477 -6 -4.5 ]

[.4875 .55477 0 4.5 ]

[.4875 .67382 -18 -4.5 ]

[.4875 .67382 0 4.5 ]

[.4875 .79286 -6 -4.5 ]

[.4875 .79286 0 4.5 ]

[.5 .84582 -4.5 0 ]

[.5 .84582 4.5 16 ]

[.5 .83332 -134.5 0 ]

[.5 .83332 134.5 16 ]

[ 0 0 0 0 ]

[ 1 .82082 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .31667 m

.02381 .32292 L

s

[(-2)] .02381 .30417 0 1 Mshowa

.2619 .31667 m

.2619 .32292 L

s

[(-1)] .2619 .30417 0 1 Mshowa

.7381 .31667 m

.7381 .32292 L

s

[(1)] .7381 .30417 0 1 Mshowa

.97619 .31667 m

.97619 .32292 L

s

[(2)] .97619 .30417 0 1 Mshowa

.125 Mabswid

.07143 .31667 m

.07143 .32042 L

s

.11905 .31667 m

.11905 .32042 L

s

.16667 .31667 m

.16667 .32042 L

s

.21429 .31667 m

.21429 .32042 L

s

.30952 .31667 m

.30952 .32042 L

s

.35714 .31667 m

.35714 .32042 L

s

.40476 .31667 m

.40476 .32042 L

s

.45238 .31667 m

.45238 .32042 L

s

.54762 .31667 m

.54762 .32042 L

s

.59524 .31667 m

.59524 .32042 L

s

.64286 .31667 m

.64286 .32042 L

s

.69048 .31667 m

.69048 .32042 L

s

.78571 .31667 m

.78571 .32042 L

s

.83333 .31667 m

.83333 .32042 L

s

.88095 .31667 m

.88095 .32042 L

s

.92857 .31667 m

.92857 .32042 L

s

.25 Mabswid

0 .31667 m

1 .31667 L

s

gsave

1.025 .31667 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .07858 m

.50625 .07858 L

s

[(-1)] .4875 .07858 1 0 Mshowa

.5 .19763 m

.50625 .19763 L

s

[(-0.5)] .4875 .19763 1 0 Mshowa

.5 .43572 m

.50625 .43572 L

s

[(0.5)] .4875 .43572 1 0 Mshowa

.5 .55477 m

.50625 .55477 L

s

[(1)] .4875 .55477 1 0 Mshowa

.5 .67382 m

.50625 .67382 L

s

[(1.5)] .4875 .67382 1 0 Mshowa

.5 .79286 m

.50625 .79286 L

s

[(2)] .4875 .79286 1 0 Mshowa

.125 Mabswid

.5 .10239 m

.50375 .10239 L

s

.5 .1262 m

.50375 .1262 L

s

.5 .15001 m

.50375 .15001 L

s

.5 .17382 m

.50375 .17382 L

s

.5 .22143 m

.50375 .22143 L

s

.5 .24524 m

.50375 .24524 L

s

.5 .26905 m

.50375 .26905 L

s

.5 .29286 m

.50375 .29286 L

s

.5 .34048 m

.50375 .34048 L

s

.5 .36429 m

.50375 .36429 L

s

.5 .3881 m

.50375 .3881 L

s

.5 .41191 m

.50375 .41191 L

s

.5 .45953 m

.50375 .45953 L

s

.5 .48334 m

.50375 .48334 L

s

.5 .50715 m

.50375 .50715 L

s

.5 .53096 m

.50375 .53096 L

s

.5 .57858 m

.50375 .57858 L

s

.5 .60239 m

.50375 .60239 L

s

.5 .6262 m

.50375 .6262 L

s

.5 .65001 m

.50375 .65001 L

s

.5 .69763 m

.50375 .69763 L

s

.5 .72143 m

.50375 .72143 L

s

.5 .74524 m

.50375 .74524 L

s

.5 .76905 m

.50375 .76905 L

s

.5 .05477 m

.50375 .05477 L

s

.5 .03096 m

.50375 .03096 L

s

.5 .00715 m

.50375 .00715 L

s

.5 .81667 m

.50375 .81667 L

s

.25 Mabswid

.5 0 m

.5 .82082 L

s

gsave

.5 .84582 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .83332 -195.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.33) show

293.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

298.000000 15.000000 moveto

(L) show

305.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

312.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

319.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

324.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

328.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .82082 L

0 .82082 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .14071 m

.02575 .14072 L

.03156 .14074 L

.04112 .14079 L

.05427 .14085 L

.07079 .14094 L

.0904 .14104 L

.11276 .14117 L

.13749 .14132 L

.16416 .14151 L

.19232 .14172 L

.22149 .14197 L

.25117 .14225 L

.28085 .14258 L

.31001 .14295 L

.33818 .14337 L

.36485 .14383 L

.38958 .14434 L

.41194 .14487 L

.43154 .14542 L

.44807 .14596 L

.46122 .14644 L

.47078 .14684 L

.47658 .14709 L

.47853 .14718 L

s

.47853 .14718 m

.47904 .14721 L

.48058 .14728 L

.48312 .1474 L

.48661 .14758 L

.49099 .14781 L

.49619 .14809 L

.50212 .14844 L

.50868 .14886 L

.51575 .14935 L

.52322 .14993 L

.53096 .1506 L

.53883 .15137 L

.5467 .15226 L

.55443 .15328 L

.5619 .15446 L

.56897 .15579 L

.57553 .15732 L

.58146 .15907 L

.58666 .16105 L

.59105 .16329 L

.59453 .16584 L

.59707 .16871 L

.59861 .17194 L

.59912 .17555 L

s

.47853 .40136 m

.47904 .38839 L

.48058 .37538 L

.48312 .36246 L

.48661 .34966 L

.49099 .33705 L

.49619 .32465 L

.50212 .31253 L

.50868 .30072 L

.51575 .28927 L

.52322 .2782 L

.53096 .26757 L

.53883 .25739 L

.5467 .24769 L

.55443 .23849 L

.5619 .22982 L

.56897 .22168 L

.57553 .21409 L

.58146 .20703 L

.58666 .20052 L

.59105 .19454 L

.59453 .18907 L

.59707 .1841 L

.59861 .17961 L

.59912 .17558 L

s

.47853 .40147 m

.47904 .41442 L

.48058 .42736 L

.48312 .44016 L

.48661 .45278 L

.49099 .46517 L

.49619 .47727 L

.50212 .48905 L

.50868 .50044 L

.51575 .5114 L

.52322 .52188 L

.53096 .53185 L

.53883 .54126 L

.5467 .55007 L

.55443 .55824 L

.5619 .56574 L

.56897 .57254 L

.57553 .57861 L

.58146 .58392 L

.58666 .58845 L

.59105 .59219 L

.59453 .59511 L

.59707 .59721 L

.59861 .59847 L

.59912 .59889 L

s

.59912 .59889 m

.60014 .59971 L

.60318 .60216 L

.60818 .60613 L

.61505 .61147 L

.6237 .61798 L

.63395 .62547 L

.64565 .6337 L

.65858 .64248 L

.67253 .65161 L

.68726 .66089 L

.70251 .67016 L

.71803 .67927 L

.73355 .68809 L

.74881 .6965 L

.76354 .7044 L

.77749 .71169 L

.79042 .7183 L

.80212 .72416 L

.81237 .72921 L

.82101 .73341 L

.82789 .73671 L

.83289 .73909 L

.83593 .74053 L

.83694 .74101 L

s

.83694 .10449 m

.83754 .10123 L

.83932 .09767 L

.84224 .09385 L

.84627 .08977 L

.85133 .08546 L

.85734 .08095 L

.86418 .07629 L

.87176 .0715 L

.87992 .06665 L

.88855 .06178 L

.89748 .05695 L

.90657 .05221 L

.91565 .04762 L

.92459 .04322 L

.93321 .03908 L

.94138 .03523 L

.94895 .03172 L

.9558 .0286 L

.9618 .0259 L

.96686 .02365 L

.97089 .02187 L

.97382 .02058 L

.97559 .0198 L

.97619 .01954 L

s

.83694 .10452 m

.83754 .1075 L

.83932 .11022 L

.84224 .11267 L

.84627 .11487 L

.85133 .11683 L

.85734 .11858 L

.86418 .12012 L

.87176 .12147 L

.87992 .12267 L

.88855 .12372 L

.89748 .12463 L

.90657 .12543 L

.91565 .12612 L

.92459 .12673 L

.93321 .12724 L

.94138 .12769 L

.94895 .12806 L

.9558 .12838 L

.9618 .12864 L

.96686 .12884 L

.97089 .129 L

.97382 .12911 L

.97559 .12917 L

.97619 .1292 L

s

.83694 .74101 m

.83754 .74129 L

.83932 .74212 L

.84224 .7435 L

.84627 .74538 L

.85133 .74772 L

.85734 .75049 L

.86418 .75362 L

.87176 .75704 L

.87992 .7607 L

.88855 .76452 L

.89748 .76844 L

.90657 .77238 L

.91565 .77628 L

.92459 .78007 L

.93321 .7837 L

.94138 .7871 L

.94895 .79023 L

.9558 .79304 L

.9618 .79548 L

.96686 .79753 L

.97089 .79915 L

.97382 .80033 L

.97559 .80104 L

.97619 .80128 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCaA<00?lCaA<006@C1@3X4`0301<C070C001V4`0301<C0>PC00<04a<0L1<003dC00<=4a<0

81<300<C00<04a<00Q<20>@C0P1a4`00?Q<00`dC4`0U4`0301<C008C00<04a<0ha<00`0C4`1`4`00

?Q<00`dC4`0U4`0301<C008C00<04a<0ha<00`0C4`1N4`033A<C00lC000o4`033A<C02<C0P044`03

01<C0><C00<04a<0G1<33A4C00104`033A<C02PC0P3T4`0301<C05XC0PdD4`00@A<00`dC4`0W4`03

01<C0><C0P1J4`033A<C01@C00114`033A<C02LC00<04a<0ha<00`0C4`1E4`@=5a<0048C00<=4a<0

9Q<00`0C4`3S4`0301<C05@C00<=4a<06A<004<C00<=4a<09A<20>@C00<04a<0DQ<23A`C00144`03

3A<C02@C00<04a<0ha<00`0C4`1@4`8=7Q<004@C00<=4a<091<00`0C4`3S4`80Ca<23B0C00154`03

3A<C02<C00<04a<0ha<00`0C4`1<4`8=8Q<004HC00<=4a<08Q<20=dC1@024`0301<C04/C00<=4a<0

8Q<004LC00<=4a<08A<00`0C4`3N4`0301<C008C00<04a<0BA<23BDC00174`033A<C024C00<04a<0

f1<300<C00<04a<00Q<204PC0PdW4`00B1<00`dC4`0P4`0301<C0=hC00<04a<00Q<00`0C4`164`03

3A<C02LC00194`033A<C01lC0P3O4`0301<C008C00<04a<0AA<00`dC4`0X4`00BQ<00`dC4`0N4`03

01<C0=dC0P044`0301<C04@C00<=4a<0:A<004XC00<=4a<03a<00`0C4`024`0301<C008C00<04a<0

0Q<00`0C4`3S4`0301<C048C0Pd/4`00Ba<00`dC4`0=4`0301<000LC00<04`000a<00`0C4`3S4`80

@a<00`dC4`0[4`00C1<00`dC4`074`<00Q<00`0C00094`0401<C4`80i1<00`0C4`124`033A<C02/C

001<4`033A<C00`C00<04`001a<200@C00<04a<0ha<00`0C4`124`8=;1<004dC00<=4a<02a<00`0C

00074`0301<C00<C00<04a<0ha<00`0C4`144`8=:Q<004hC00<=4a<02a<00`0C4`064`<00a<00`0C

4`3S4`0301<C04HC1PdT4`00Ca<00`dC4`0I4`0301<C0><C0P1=4``=61<004lC00<=4a<06A<20>@C

00<04a<0F1<73A4C001@4`033A<C01PC00<04a<0ha<00`0C4`1`4`00DA<00`dC4`0G4`0301<C088C

=`dZ4`0301<C070C001B4`033A<C01HC00<04a<0^A<X3@8C00<04a<0L1<005<C00<=4a<05A<20>4C

3PeX4`00Da<00`dC4`0E4`0301<C0><C00<04a<021<53F<C000J4`<09A<500dC00<=4a<051<00`0C

4`0T4`D091<309<C00<04a<03A<33F0C000J4`0301<C02LC00<04a<03Q<00`dC4`0C4`0301<C02HC

00<04a<091<00`0C4`2C4`0301<C010C00<=4a<0GA<001DC0`034`0301<C020C0`034`0301<C00lC

00<=4a<04Q<202LC00<04a<09A<00`0C4`2B4`0301<C014C00<=4a<0G1<001/C00<04a<09Q<00`0C

4`0@4`033A<C014C00<04a<09Q<00`0C4`0U4`0301<C098C0P0B4`033A<C05`C000J4`0301<002LC

00<04a<04A<00`dC4`0@4`0301<C02HC00<04a<091<00`0C002C4`0301<C014C00<=4a<0G1<001/C

00<04a<09A<201<C00<=4a<041<00`0C4`0U4`809a<00`0C4`2B4`0301<C014C00<=4a<0G1<005TC

00<=4a<03a<20=DC00<04a<00Q<00`0C4`024`0301<C008C00<04a<041<00`dC4`1M4`00FQ<00`dC

4`0>4`0301<C0=<C00<04`001a<00`0C00034`0301<C010C00<=4a<0GA<005XC00<=4a<03Q<00`0C

4`1K4`80LA<3008C00<04`002A<0100C4a<2010C00<=4a<0GQ<005/C00<=4a<03A<00`0C4`1J4`03

01<C07HC00<04`001a<200@C00<04a<03Q<00`dC4`1O4`005A=700033@0006<01Q<00`0C4`1f4`03

01<000LC00<04a<00a<00`0C4`0>4`033A<C05lC000I4`0301<C00HC00<04a<01A<00`0C4`054`03

01<C00DC00<04a<01A<00`0C4`054`0301<C00HC00<04a<01A<00`0C3@054`0301<C00DC00<@4a<0

1A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`03

01<C00DC00<04a<01A<00`0C4`084`0301<C07LC00<04a<01Q<300<C00<04a<031<23F8C001M4`03

3A<C00/C00<@4a<0FQ<00`0C00264`0301<C00/C00<=4a<0HQ<005hC00<=4a<02Q<245/C0`264`80

31<00`dC4`1R4`00Ga<00`dC4`094`8@i1<00`0C4`0:4`033A<C06<C001P4`033A<C00LC00<@0100

i1<00`0C4`094`033A<C06@C001P4`033A<C00LC00<@0100i1<00`0C4`084`033A<C06DC001Q4`03

3A<C00HC00<@0100i1<200PC00<=4a<0IQ<0068C00<=4a<011<01A0C000@0><C00<04a<01a<00`dC

4`1V4`00Ha<00`dC4`034`0541<04a00ha<00`0C4`064`033A<C06LC001S4`033A<C00<C00D@4`0C

403S4`0301<C00DC00<=4a<0J1<006@C00<=4a<00Q<00a0C00024`0341<C080C0`0]4`D0:a<00`0C

4`044`033A<C02@C1@0]4`<041<006DC00H=4a<C41<200034a0C084C00<04a<0;a<00`0C4`0[4`80

11<00`dC4`0W4`0301<C02dC00<04a<041<006HC00H=4a<@4`024`0341<C07/C0`034`0301<C02PC

0`034`0301<C02/C00<04a<00Q<00`dC4`0X4`0301<C02hC00<04a<03a<006HC00<=4a000Q<01@0C

4a<@088C00<04a<0;Q<00`0C4`0[4`0301<C008C00<=4a<0:1<00`0C4`0^4`0301<C00lC001W4`05

3A0C4`000a<00a0C4`1o4`0301<002lC00<04a<0:a<01@0C4a<=02/C00<04a<0;A<00`0C000@4`00

J1<00`dC4`02008C00<@4a<0P1<00`0C4`0]4`80;A<0100C4`d[4`80<1<00`0C4`0?4`00Ia<01A0C

3A<000@C00<@4a<0gQ<200034`dC06hC001L4`0301<C008C00<04a<00Q<01P0@4`dC00@C00<@4a<0

gQ<00`0C3@1`4`00Fa<00`0C00074`030100008C00<=01<00a<00a0C4`3N4`0301<=070C001K4`03

01<000PC00<@01<00Q<00`d04`034`0341<C0=dC00<03A<0K1<2008C001K4`0301<000LC00<041<0

0a<00`0=4`034`0341<C0=dC00<03A<0Ja<00`0C4`024`00Fa<00`0C00074`0341<C00<C00<04`d0

11<00a0C4`1f4fH000<=0000I0074`0301<C008C001L4`0301<C00HC00<@00000a<00`0C3@044`03

41<C07/C00<04a<01a<00`0C4`064`0301<C00LC00<04a<01a<00`0C4`074`0301<C00HC00<04a<0

1a<00`0C4`074`0301<C00HC00<04a<01a<00`dC4`074`0301<C00LC00<04a<01Q<00`0C4`074`03

01<C00LC00<04a<01Q<00`0C4`074`0301<C00LC00<04a<01Q<00`0C4`074`0301<C00XC00<04a<0

0Q<006@C00<@4a<011<200034`dC008C00<@4a<0fa<00`d04`1/4`0301<0008C001T4`0341<C00@C

00D04a<C3@034`0341<C0=TC00<=4`00KA<3008C001S4`0341<C00DC00<04a<00Q<010dC4a3K4`03

3A<0078C001S4`0341<C00DC00<04a<00Q<01@dC4a<@0=XC00@=4`00LA<0068C00<@4a<01Q<00`0C

4`034`043A<C4=TC00@=4a<0LQ<0068C00<@4a<01Q<200DC00@=4a<@f1<010dC4`1b4`00HA<00a0C

4`074`0301<C00DC00<=4a00f1<010dC4`1b4`00HA<00a0C4`074`0301<C00HC00<=41<0ea<010dC

4`1b4`00H1<00a0C4`084`0301<C00HC00<=4a00ea<00`dC4`02074C001P4`0341<C00PC0P084`03

3A0C0=DC00D=4a<C001b4`00Ga<00a0C4`094`0301<C00PC00<=41<0e1<01@dC4a<0078C001O4`03

41<C00TC00<04a<02A<00`dC4`3C4`053A<C4`00LQ<005hC00<@4a<02Q<00`0C4`094`033A0C0=<C

00D=4a<C001b4`00GQ<00a0C4`0:4`802a<00`dC4`3B4`043A<C4`80LA<005dC00<@4a<02a<00`0C

4`0;4`033A<C0=4C00D=4a<C001b4`00GA<00a0C4`044`D00Q<00`0C4`0;4`0340dC0=4C00D=4a<C

001b4`00G1<00a0C4`074`0301<C008C00<04a<031<00`dC4`3@4`053A<C4`00LQ<005/C00<@4a<0

21<00`0C4`024`803Q<00`dC4`3?4`043A<C4`80LA<005/C00<@4a<021<00`0C4`024`0301<C00dC

00<@3A<0ca<01@dC4a<0078C001J4`0341<C00TC00<04a<00Q<00`0C4`0>4`033A<C0<hC00D=4a<C

001b4`00FQ<00a0C4`084`8011<00`0C4`0?4`033A<C0<8C00<04a<00Q<00`0C4`024`0300dC008C

00<04a<0L1<005TC00<@4a<03a<2010C00<@3A<0`A<00`0C00074`0301<=00<C00<04a<0L1<005PC

00<@4a<041<00`0C4`0@4`0340dC0<0C00<04`002A<010dC4a<2074C001H4`0341<C010C00<04a<0

4A<00`dC4`2o4`0301<000LC0P001A<=4a<0078C001G4`0341<C014C00<04a<04A<00a0=4`2o4`03

01<000LC00@04a<=0Q<00`0C4`1`4`00EQ<00a0C4`0B4`804a<00a0=4`2o4`0301<C00HC0`0010dC

4`1b4`00EQ<00a0C4`0B4`0301<C01<C00<@3A<0bQ<010dC4`1b4`00EA<00a0C4`0C4`0301<C01<C

00<@3A<0bQ<00`dC4`02074C001D4`0341<C01@C00<04a<051<00a0=4`3:4`033A<0078C001C4`03

41<C01DC0P0E4`0341<=0<XC00<=4`00LQ<005<C00<@4a<05A<00`0C4`0E4`0341<=0<XC00<=01<0

LA<0058C00<@4a<05Q<00`0C4`0F4`0340dC0<TC00<=01<0LA<0054C00<@4a<05a<00`0C4`0F4`03

41<=0<XC00<=01<0L1<0054C00<@4a<05a<201PC00<@4`d0bA<00`0=4`1`4`00D1<00a0C4`0H4`03

01<C01LC00@@4a<=b1<00`0=4`1`4`00Ca<00a0C4`084`D00Q<00`0C4`024`0301<C008C00<04a<0

61<00a0C3@384`0301<=070C001?4`0341<C00XC00<04a<01Q<00`0C00034`0301<C01TC00<@4`d0

aa<00`0C3@1`4`00CQ<00a0C4`0;4`0301<C00PC00@04a<C0P0K4`0341<=0<HC0P000a<=4`1^4`00

CA<00a0C4`0<4`0301<C00HC0P044`0301<C01XC00<@4`d0aQ<0100C4`e_4`00C1<00a0C4`0=4`03

01<C00HC00<04a<00a<00`0C4`0K4`0341<=0<DC00D04a<C3@1^4`00C1<00a0C4`0<4`8021<300<C

00<04a<071<00a0C3@344`0301<C008C00<=4a<0Ja<004/C00<@4a<07A<201hC00<@3A<0`a<00`0C

4`024`033A<C06/C001:4`0341<C01hC00<04a<07A<00a0C3@334`8011<00`dC4`1Z4`00BQ<00a0C

4`0N4`0301<C01hC00<@4`d0`Q<00`0C4`044`033A<C06TC00194`0341<C01lC00<04a<07a<00a0C

3@2j4`D00Q<00`0C4`054`033A<C06PC00184`0341<C020C0P0Q4`0340dC0;/C00<04a<00Q<00`0C

4`064`033A<C06LC00174`0341<C024C00<04a<08A<00a0=4`2j4`0301<C008C0P084`033A<C06HC

00174`0341<C024C00<04a<08A<00a0C3@2j4`0301<C008C00<04a<021<00`dC4`1U4`00AQ<00a0C

4`0R4`0301<C028C00<@4`d0^A<00`0C4`024`0301<C00TC00<=4a<0I1<004DC00<@4a<08a<202@C

00<@3A<0]a<200@C00<04a<02Q<00`dC4`1S4`00A1<00a0C4`0T4`0301<C02@C00<@3A<0_1<00`0C

4`0;4`033A<C068C00144`0341<C02@C00<04a<091<00a0C3@2l4`803A<00`dC4`1Q4`00@a<00a0C

4`0U4`0301<C02DC00<@4`d0^a<00`0C4`0=4`8=HA<0048C00<@4a<09Q<00`0C4`0V4`0341<=0;XC

00<04a<03a<00`dC4`1N4`00@A<00a0C4`0W4`80:1<00a0=4`2i4`0301<C010C00<=4a<0GA<0040C

00<@4a<0:1<00`0C4`0X4`0340dC0;PC00<04a<041<23EhC00104`0341<C028C0`034`0301<C02TC

00<@3A<0]a<201<C00<=4a<0Fa<003lC00<@4a<08a<00`0C4`034`0301<C02TC00<@4`d0]a<00`0C

4`0C4`033A<C05XC000n4`0341<C02DC00<04a<00Q<202/C00<@3A<0]Q<00`0C4`0D4`8=FQ<003dC

00<@4a<09Q<00`0C4`024`0301<C02/C00<@3A<0]A<00`0C4`0F4`033A<C05LC000m4`0341<C02DC

00<04`000a<00`0C4`0/4`0340dC0;@C00<04a<05a<00`dC4`1F4`00?1<00a0C4`0W4`0301<C008C

00<04a<0;A<00a0=4`2c4`806A<00`dC4`1E4`00>a<00a0C4`0]4`80;a<00a0=4`2b4`0301<C01TC

0PeE4`00>Q<00a0C4`0^4`0301<C02hC00<@3A<0/Q<00`0C4`0K4`033A<C058C000j4`0341<C02hC

00<04a<0;a<00a0=4`2a4`0301<C01`C0PeB4`00>A<00a0C4`0_4`0301<C030C00<@3A<0/1<00`0C

4`0N4`8=D1<003PC00<@4a<0<1<2038C00<@3A<0[a<2024C00<=4a<0CA<003LC00<@4a<0<A<00`0C

4`0a4`0340dC0:lC00<04a<08A<23DdC000g4`0341<C034C00<04a<0<Q<00a0=4`2^4`0301<C02<C

00<=4a<0BQ<003HC00<@4a<0<Q<00`0C4`0c4`0340dC09`C1@024`0301<C008C00<04a<00Q<00`0C

4`0T4`8=BQ<003DC00<@4a<0<a<203DC00<@3A<0WA<00`0C4`064`0301<000<C00<04a<09Q<00`dC

4`174`00=1<00a0C4`0d4`0301<C03DC00<@3A<0W1<00`0C4`084`0401<C4`80:1<23DLC000c4`03

41<C03DC00<04a<0=Q<00`dC4`2K4`0301<C00HC0P044`0301<C02TC0Pe54`00<Q<00a0C4`0f4`03

01<C03HC00<@3A<0Va<00`0C4`064`0301<C00<C00<04a<0:a<23D<C000a4`0341<C03LC0P0h4`03

40dC09TC0P084`<00a<00`0C4`0]4`8=@A<0030C00<@4a<0>1<00`0C4`0h4`0340dC0:PC00<04a<0

;a<23ClC000_4`0341<C02TC0`034`0301<C008C00<04a<00Q<00`0C4`0i4`033A<C0:LC0P0b4`8=

?A<002hC00<@4a<0:Q<00`0C4`074`0301<000<C00<04a<0>Q<00`dC4`2V4`0301<C03<C0Pdk4`00

;A<00a0C4`0/4`0301<C00PC00@04a<C0P0l4`033A<C0:DC00<04a<0=A<23CTC000/4`0341<C02dC

00<04a<01Q<200@C00<04a<0?1<00`dC4`2T4`0301<C03LC00<=4a<0=Q<002/C00<@4a<0;A<00`0C

00074`0301<C00<C00<04a<0?1<00`d@4`2T4`80>A<23CHC000Z4`0341<C02lC00<04a<01Q<300<C

00<04a<0?A<00`d@4`2S4`0301<C03XC0Pdd4`00:A<00a0C4`0o4`80?a<00`d@4`2R4`0301<C03`C

0Pdb4`00:1<00a0C4`104`0301<C03hC00<=4a00XQ<00`0C4`0n4`8=<1<002LC00<@4a<0@A<00`0C

4`0o4`033A<@0:4C00<04a<0@1<33BdC000V4`0341<C048C00<04a<0@1<00`dC402P4`80@a<33B/C

000U4`0341<C04<C0P114`043A<C49lC00<04a<0AA<23BTC000T4`0341<C04@C00<04a<0@A<010dC

4a2N4`0301<C04LC00<=4a<09Q<002<C00<@4a<0AA<00`0C4`124`043A<C49dC00<04a<0B1<43B@C

000S4`0341<C04DC00<04a<0@Q<01@dC4a<@09`C00<04a<0C1<00`dC4`0Q4`008Q<00a0C4`164`80

A1<01@dC4a<@09/C0P1>4`8=8A<0024C00<@4a<0Aa<00`0C4`144`053A<C4a00VQ<00`0C4`1?4`8=

7a<0020C00<@4a<0B1<00`0C4`144`033A<C008C00<@4a<0Ua<00`0C4`1A4`@=6a<001lC00<@4a<0

BA<00`0C4`154`033A<C008C00<@4a<0T1<300<C00<04a<0EA<00`dC4`0H4`007Q<00a0C4`1:4`80

Aa<00`dC4`024`0341<C08lC00<04a<00a<00`0C4`1F4`@=5Q<001dC00<@4a<0Ba<00`0C4`174`03

3A<C008C00<@4a<0Sa<00`0C4`024`80Fa<00`dC4`0C4`0071<00a0C4`1<4`0301<C04LC00<=4a<0

0a<00a0C4`2>4`0301<C008C00<04a<0Fa<33A8C000K4`0341<C04LC0P044`0301<C04PC00<=4a<0

0a<00a0C4`2<4`0301<000<C00<04a<0GQ<00`dC4`0?4`006Q<00a0C4`1:4`0501<C4`00Ba<00`dC

4`034`0341<C08`C00<04a<00Q<00`0C4`1`4`006A<00a0C4`1:4`0301<C008C0P1;4`033A<C008C

00<@4a<0TA<00`0C4`1`4`00Ia<00`0C4`3W4`80LA<006DC00<04`00jA<00`0C4`1`4`00IQ<00`0C

4`3o4e`C000/4`<0oa>F4`00;1<00`0C4`3o4iHC000]4`0301<C00DC00<04a<0oa>=4`00;A<0100C

4a<300044`0C4`<0oa>:4`00;1<00`0C00024`800Q<00`0C4`024`0301<C0?lCB1<00`0C4`0b4`03

01<C00PC000]4`0301<C00<C00@04a<00Q<00`0C4`3o4d4C00<04a<011<00`0C4`0C4`0301<C01hC

00<04a<01a<003<C00@04a<00a<00`0C4`064`0301<C02DC0`0]4`0301<C0<`C00@04a<C10024`80

1Q<00`0C4`034`0301<C008C00<04a<00Q<00`0C4`024`0301<C00DC00@04a<C1@024`0401<C4`80

0a<200HC0P044`0401<C4`800A<10040000M4`<000<C00000P0<4`<011<300PC00<04a<091<0100C

4`0A4`<000<C00000P024`0301<C008C00<04a<00Q<00`0C4`054`0401<C4`D00Q<0100C4a<200<C

0P064`80/1<00`0C00074`0301<C00@C1@034`0701<C4`0C00074`0301<000@C1@034`0301<C00PC

00<04a<00Q<00`0C4`024`0301<C00@C00<04a<00Q<00`0C00014`0071<0100C4`0T4`0301<C02<C

00@04a<041<0100C4`064`0301<000LC00<04`0011<500<C00<04a<021<00`0C4`024`0301<C008C

00<04a<0/1<00`0C00024`@000<C01<01a<00`0C4`034`0701<C4`0C00094`0301<C00@C00<04a<0

0a<00`0C4`074`0301<C008C00<04a<00a<00`0C4`044`0301<C00<C0@014`4C000L4`0501<C01<0

10000a<0000H02/C0`0@4`0501<C01<0100011<04`094`0301<C00@C00<04a<00a<00`0C4`074`03

01<C008C00<04a<00a<00`0C4`2F4`8000<C00005A<00`0C00074`0301<C00HC00<04a<00a<01`0C

4a<04`001a<200LC00<04a<00a<00`0C4`084`0301<C008C00<04a<00Q<00`0C4`044`0301<C00<C

0@014`4C000M4`<0CA<00`0C4`0?4`<01Q<00`0C00074`801a<00`0C4`034`0301<C00PC00<04a<0

0Q<00`0C4`024`0301<C09LC00<04`005Q<00`0C00074`0301<000dC00H04a<04`074`0301<C00`C

00<04a<01Q<00`0C00024`0301<000@C00<04`000a<00`0C4`034`0301<0004C000O4`0301<C04XC

0P0C4`0301<C00@C00<04`001a<00`0C4`0<4`0301<C00HC00<04`000Q<00`0C00044`0301<009PC

00<04a<05Q<00`0C4`064`<03Q<0100C4`084`<02a<200TC00<04a<00Q<00`0C4`034`<00Q<00`0C

4`034`800A<10040000N4`80H1<200LC00<04a<01Q<300/C0P094`0301<C008C00<04a<00a<309PC

00<04a<0L1<00?lCDA<00`0C001a4`00:A<200HC0P3o4adC0P000a<0001`4`00:a<00`0C4`024`03

01<C0?lCTQ<002XC00<04a<00a<00`0C4`054`0301<C0?lCRQ<002/C00<04a<00Q<00`0C4`024`@0

0a<30?lCQQ<002TC00<04`0011<00`0C00024`8000<C01<011<00`0C4`3o4h@C000Z4`0301<C00<C

0`044`0301<000<C00<04a<0oa>54`00=a<00`0C00044`0301<C0?lCQ1<003DC0`044`<0oa>64`00

oa?54`00oa?54`00oa?54`00oa?54`00oa?54`00\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-6.95686, -1.48959, 0.0206072, 0.0206072}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -84.5 0 ]

[.5 .96488 84.5 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -145.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.325) show

222.250000 19.500000 moveto

(C) show

227.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.23046 0 m

.26171 .04141 L

.30316 .09632 L

.34309 .14923 L

.3815 .20013 L

.42237 .25428 L

.46172 .30642 L

.49955 .35655 L

.53984 .40993 L

.57861 .4613 L

.61984 .51592 L

.65954 .56854 L

.69774 .61914 L

.73838 .673 L

.77751 .72485 L

.81909 .77994 L

.85916 .83303 L

.89771 .88411 L

.93871 .93844 L

s

.93871 .93844 m

.94924 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.314617 0.238095 [

[.02381 .30212 -6 -9 ]

[.02381 .30212 6 0 ]

[.2619 .30212 -6 -9 ]

[.2619 .30212 6 0 ]

[.7381 .30212 -3 -9 ]

[.7381 .30212 3 0 ]

[.97619 .30212 -3 -9 ]

[.97619 .30212 3 0 ]

[1.025 .31462 0 -8 ]

[1.025 .31462 9 8 ]

[.4875 .07652 -12 -4.5 ]

[.4875 .07652 0 4.5 ]

[.4875 .19557 -24 -4.5 ]

[.4875 .19557 0 4.5 ]

[.4875 .43366 -18 -4.5 ]

[.4875 .43366 0 4.5 ]

[.4875 .55271 -6 -4.5 ]

[.4875 .55271 0 4.5 ]

[.4875 .67176 -18 -4.5 ]

[.4875 .67176 0 4.5 ]

[.4875 .79081 -6 -4.5 ]

[.4875 .79081 0 4.5 ]

[.5 .84318 -4.5 0 ]

[.5 .84318 4.5 16 ]

[.5 .83068 -137 0 ]

[.5 .83068 137 16 ]

[ 0 0 0 0 ]

[ 1 .81818 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .31462 m

.02381 .32087 L

s

[(-2)] .02381 .30212 0 1 Mshowa

.2619 .31462 m

.2619 .32087 L

s

[(-1)] .2619 .30212 0 1 Mshowa

.7381 .31462 m

.7381 .32087 L

s

[(1)] .7381 .30212 0 1 Mshowa

.97619 .31462 m

.97619 .32087 L

s

[(2)] .97619 .30212 0 1 Mshowa

.125 Mabswid

.07143 .31462 m

.07143 .31837 L

s

.11905 .31462 m

.11905 .31837 L

s

.16667 .31462 m

.16667 .31837 L

s

.21429 .31462 m

.21429 .31837 L

s

.30952 .31462 m

.30952 .31837 L

s

.35714 .31462 m

.35714 .31837 L

s

.40476 .31462 m

.40476 .31837 L

s

.45238 .31462 m

.45238 .31837 L

s

.54762 .31462 m

.54762 .31837 L

s

.59524 .31462 m

.59524 .31837 L

s

.64286 .31462 m

.64286 .31837 L

s

.69048 .31462 m

.69048 .31837 L

s

.78571 .31462 m

.78571 .31837 L

s

.83333 .31462 m

.83333 .31837 L

s

.88095 .31462 m

.88095 .31837 L

s

.92857 .31462 m

.92857 .31837 L

s

.25 Mabswid

0 .31462 m

1 .31462 L

s

gsave

1.025 .31462 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .07652 m

.50625 .07652 L

s

[(-1)] .4875 .07652 1 0 Mshowa

.5 .19557 m

.50625 .19557 L

s

[(-0.5)] .4875 .19557 1 0 Mshowa

.5 .43366 m

.50625 .43366 L

s

[(0.5)] .4875 .43366 1 0 Mshowa

.5 .55271 m

.50625 .55271 L

s

[(1)] .4875 .55271 1 0 Mshowa

.5 .67176 m

.50625 .67176 L

s

[(1.5)] .4875 .67176 1 0 Mshowa

.5 .79081 m

.50625 .79081 L

s

[(2)] .4875 .79081 1 0 Mshowa

.125 Mabswid

.5 .10033 m

.50375 .10033 L

s

.5 .12414 m

.50375 .12414 L

s

.5 .14795 m

.50375 .14795 L

s

.5 .17176 m

.50375 .17176 L

s

.5 .21938 m

.50375 .21938 L

s

.5 .24319 m

.50375 .24319 L

s

.5 .267 m

.50375 .267 L

s

.5 .29081 m

.50375 .29081 L

s

.5 .33843 m

.50375 .33843 L

s

.5 .36224 m

.50375 .36224 L

s

.5 .38605 m

.50375 .38605 L

s

.5 .40986 m

.50375 .40986 L

s

.5 .45747 m

.50375 .45747 L

s

.5 .48128 m

.50375 .48128 L

s

.5 .50509 m

.50375 .50509 L

s

.5 .5289 m

.50375 .5289 L

s

.5 .57652 m

.50375 .57652 L

s

.5 .60033 m

.50375 .60033 L

s

.5 .62414 m

.50375 .62414 L

s

.5 .64795 m

.50375 .64795 L

s

.5 .69557 m

.50375 .69557 L

s

.5 .71938 m

.50375 .71938 L

s

.5 .74319 m

.50375 .74319 L

s

.5 .767 m

.50375 .767 L

s

.5 .05271 m

.50375 .05271 L

s

.5 .0289 m

.50375 .0289 L

s

.5 .00509 m

.50375 .00509 L

s

.5 .81462 m

.50375 .81462 L

s

.25 Mabswid

.5 0 m

.5 .81818 L

s

gsave

.5 .84318 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .83068 -198 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.325) show

298.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

303.000000 15.000000 moveto

(L) show

310.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

317.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

324.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

329.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

333.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .81818 L

0 .81818 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .13819 m

.02575 .1382 L

.03156 .13823 L

.04112 .13827 L

.05427 .13834 L

.07079 .13843 L

.0904 .13854 L

.11276 .13868 L

.13748 .13884 L

.16415 .13904 L

.19231 .13926 L

.22148 .13953 L

.25116 .13983 L

.28083 .14018 L

.31 .14057 L

.33816 .14102 L

.36483 .14151 L

.38956 .14204 L

.41191 .14261 L

.43152 .14319 L

.44804 .14376 L

.4612 .14427 L

.47076 .14469 L

.47656 .14496 L

.4785 .14506 L

s

.4785 .14506 m

.47901 .14508 L

.48053 .14516 L

.48304 .14529 L

.48649 .14547 L

.49083 .14571 L

.49597 .14601 L

.50183 .14638 L

.50832 .14681 L

.51532 .14733 L

.5227 .14793 L

.53035 .14862 L

.53814 .14942 L

.54592 .15035 L

.55357 .15141 L

.56096 .15262 L

.56795 .154 L

.57444 .15557 L

.5803 .15736 L

.58545 .15939 L

.58978 .16169 L

.59323 .16428 L

.59574 .1672 L

.59726 .17049 L

.59777 .17414 L

s

.4785 .39934 m

.47901 .38645 L

.48053 .37352 L

.48304 .36067 L

.48649 .34795 L

.49083 .33541 L

.49597 .32308 L

.50183 .31102 L

.50832 .29927 L

.51532 .28787 L

.5227 .27686 L

.53035 .26626 L

.53814 .25611 L

.54592 .24644 L

.55357 .23727 L

.56096 .22861 L

.56795 .22048 L

.57444 .21288 L

.5803 .20581 L

.58545 .19928 L

.58978 .19328 L

.59323 .18778 L

.59574 .18278 L

.59726 .17824 L

.59777 .17417 L

s

.4785 .39945 m

.47901 .41232 L

.48053 .42517 L

.48304 .43789 L

.48649 .45043 L

.49083 .46273 L

.49597 .47476 L

.50183 .48645 L

.50832 .49777 L

.51532 .50865 L

.5227 .51907 L

.53035 .52897 L

.53814 .53831 L

.54592 .54706 L

.55357 .55518 L

.56096 .56263 L

.56795 .56938 L

.57444 .5754 L

.5803 .58068 L

.58545 .58518 L

.58978 .58889 L

.59323 .59179 L

.59574 .59387 L

.59726 .59512 L

.59777 .59554 L

s

.59777 .59554 m

.59883 .5964 L

.60198 .59896 L

.60718 .6031 L

.61434 .60866 L

.62332 .61543 L

.63399 .62321 L

.64615 .63175 L

.6596 .64085 L

.6741 .65028 L

.68942 .65987 L

.70528 .66945 L

.72142 .67884 L

.73756 .68793 L

.75342 .69659 L

.76874 .70472 L

.78325 .71222 L

.7967 .71901 L

.80886 .72503 L

.81952 .73022 L

.82851 .73453 L

.83566 .73792 L

.84086 .74037 L

.84401 .74184 L

.84507 .74233 L

s

.84507 .10075 m

.84563 .09756 L

.84731 .0941 L

.85006 .09039 L

.85386 .08645 L

.85862 .0823 L

.86427 .07797 L

.87072 .0735 L

.87785 .06892 L

.88554 .06429 L

.89366 .05964 L

.90207 .05504 L

.91063 .05053 L

.91919 .04616 L

.9276 .04198 L

.93572 .03804 L

.94341 .03438 L

.95054 .03105 L

.95699 .02809 L

.96264 .02552 L

.96741 .02338 L

.9712 .02169 L

.97396 .02047 L

.97563 .01973 L

.97619 .01948 L

s

.84507 .10077 m

.84563 .1037 L

.84731 .10638 L

.85006 .10881 L

.85386 .111 L

.85862 .11297 L

.86427 .11472 L

.87072 .11628 L

.87785 .11766 L

.88554 .11888 L

.89366 .11996 L

.90207 .1209 L

.91063 .12173 L

.91919 .12245 L

.9276 .12308 L

.93572 .12362 L

.94341 .12408 L

.95054 .12448 L

.95699 .12481 L

.96264 .12508 L

.96741 .1253 L

.9712 .12546 L

.97396 .12558 L

.97563 .12565 L

.97619 .12567 L

s

.84507 .74233 m

.84563 .7426 L

.84731 .74337 L

.85006 .74465 L

.85386 .7464 L

.85862 .74858 L

.86427 .75116 L

.87072 .75407 L

.87785 .75727 L

.88554 .76068 L

.89366 .76425 L

.90207 .76791 L

.91063 .7716 L

.91919 .77524 L

.9276 .7788 L

.93572 .7822 L

.94341 .78539 L

.95054 .78832 L

.95699 .79096 L

.96264 .79325 L

.96741 .79518 L

.9712 .7967 L

.97396 .79781 L

.97563 .79848 L

.97619 .7987 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->0,

  AnimationCycleRepetitions->0,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCaA<00?lCaA<006@C1@3o4e`C001V4`0301<C0>PC00<04a<0L1<003dC00<=4a<081<300<C

00<04a<00Q<20>@C0P1a4`00?Q<00`dC4`0U4`0301<C008C00<04a<0ha<00`0C4`1`4`00?Q<00`dC

4`0U4`0301<C008C00<04a<0ha<00`0C4`1`4`00?a<00`dC4`0S4`8011<00`0C4`3S4`0301<C05`C

0`dA4`00@1<00`dC4`0X4`80i1<00`0C4`1J4`8=51<0044C00<=4a<09a<00`0C4`3S4`80FQ<00`dC

4`0D4`00@A<00`dC4`0W4`0301<C0><C00<04a<0EQ<33ALC00124`033A<C02HC00<04a<0ha<00`0C

4`1D4`8=6Q<004<C00<=4a<09A<20>@C00<04a<0Da<00`dC4`0J4`00@a<00`dC4`0U4`0301<C0><C

0P1B4`8=7A<004@C00<=4a<091<00`0C4`3S4`0301<C04lC0PdO4`00AA<00`dC4`0S4`0301<C0><C

00<04a<0CA<23B4C00154`033A<C02<C0P3M4`D00Q<00`0C4`1<4`033A<C024C00164`033A<C028C

00<04a<0gQ<00`0C4`024`0301<C04XC0PdT4`00Aa<00`dC4`0Q4`0301<C0=PC0`034`0301<C008C

0P1:4`033A<C02@C00184`033A<C020C00<04a<0gQ<00`0C4`024`0301<C04HC0`dW4`00B1<00`dC

4`0P4`80ga<00`0C4`024`0301<C04DC00<=4a<0:1<004TC00<=4a<07a<00`0C4`3M4`8011<00`0C

4`144`033A<C02TC001:4`033A<C00lC00<04a<00Q<00`0C4`024`0301<C008C00<04a<0ha<00`0C

4`144`033A<C02TC001;4`033A<C00dC00<04`001a<00`0C00034`0301<C0><C0P144`8=:a<004/C

00<=4a<021<3008C00<04`002A<0100C4a<20>@C00<04a<0A1<00`dC4`0Y4`00C1<00`dC4`0<4`03

01<000LC0P044`0301<C0><C00<04a<0A1<23BXC001=4`033A<C00/C00<04`001a<00`0C4`034`03

01<C0><C00<04a<0AQ<43BHC001>4`033A<C00/C00<04a<01Q<300<C00<04a<0ha<00`0C4`1:4`H=

81<004hC00<=4a<06Q<00`0C4`3S4`80DA<?3A4C001?4`033A<C01TC0P3T4`0301<C070C001@4`03

3A<C01PC00<04a<0ha<00`0C4`1`4`00DA<00`dC4`0G4`0301<C088C@`dN4`0301<C070C001B4`03

3A<C01HC00<04a<0aA<N3@0301<C070C001C4`033A<C01DC0P3T4`X=JA<005<C00<=4a<05A<00`0C

4`3S4`0301<C00LC1PeS4`006Q<302DC1@0=4`033A<C01@C00<04a<091<502@C0`2C4`0301<C00dC

0`eP4`006Q<00`0C4`0W4`0301<C00hC00<=4a<04a<00`0C4`0V4`0301<C02@C00<04a<0Ta<00`0C

4`0?4`8=Ga<001DC0`034`0301<C020C0`034`0301<C00lC00<=4a<04Q<202LC00<04a<09A<00`0C

4`2B4`0301<C014C00<=4a<0G1<001/C00<04a<09Q<00`0C4`0@4`033A<C014C00<04a<09Q<00`0C

4`0U4`0301<C098C0P0B4`033A<C05`C000J4`0301<002LC00<04a<04A<00`dC4`0@4`0301<C02HC

00<04a<091<00`0C002C4`0301<C014C00<=4a<0G1<001/C00<04a<09A<201<C00<=4a<041<00`0C

4`0U4`809a<00`0C4`2B4`0301<C014C00<=4a<0G1<005TC00<=4a<03a<20=DC00<04a<00Q<00`0C

4`024`0301<C008C00<04a<041<00`dC4`1M4`00FQ<00`dC4`0>4`0301<C0=<C00<04`001a<00`0C

00034`0301<C00lC00<=4a<0GQ<005XC00<=4a<03Q<00`0C4`1K4`80LA<3008C00<04`002A<0100C

4a<2010C00<=4a<0GQ<005/C00<=4a<03A<00`0C4`1J4`0301<C07HC00<04`001a<200@C00<04a<0

3Q<00`dC4`1O4`005A=700033@0006<01Q<00`0C4`1f4`0301<000LC00<04a<00a<00`0C4`0=4`03

3A<C060C000I4`0301<C00HC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`03

01<C00HC00<04a<01A<00`0C3@054`0301<C00DC00<@4a<01A<00`0C4`064`0301<C00DC00<04a<0

1A<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<04a<01A<00`0C4`084`03

01<C07LC00<04a<01Q<300<C00<04a<031<00`dC4`1Q4`00GA<00`dC4`0;4`0341<C05XC00<04`00

QQ<200`C00<=4a<0HQ<005hC00<=4a<02Q<245/C0`264`0301<C00/C00<=4a<0HQ<005lC00<=4a<0

2A<24>@C00<04a<02Q<00`dC4`1S4`00H1<00`dC4`074`03400@0>@C00<04a<02A<00`dC4`1T4`00

H1<00`dC4`074`03400@0>@C00<04a<021<00`dC4`1U4`00HA<00`dC4`064`03400@0>@C0P084`03

3A<C06HC001R4`033A<C00@C00D@4`00403S4`0301<C00HC00<=4a<0Ia<006<C00<=4a<00a<01A0C

01<@0><C00<04a<01A<00`dC4`1X4`00Ha<00`dC4`034`0541<04a00ha<00`0C4`054`033A<C06PC

001T4`033A<C008C00<@4`000Q<00a0C4`204`<0;A<502/C00<04a<011<00`dC4`0T4`D0;A<3010C

001U4`063A<C4a0C0P000a<@4`214`0301<C02lC00<04a<0:a<200@C00<=4a<09a<00`0C4`0]4`03

01<C010C001V4`063A<C41<00Q<00a0C4`1k4`<00a<00`0C4`0X4`<00a<00`0C4`0[4`0301<C008C

00<=4a<0:1<00`0C4`0^4`0301<C00lC001V4`033A<@008C00D04a<C40224`0301<C02hC00<04a<0

:a<00`0C4`024`033A<C02PC00<04a<0;Q<00`0C4`0?4`00Ia<01@d@4a<000<C00<@4a<0Oa<00`0C

000_4`0301<C02/C00D04a<C3@0[4`0301<C02dC00<04`0041<006PC00<=4a<00P024`0341<C080C

00<04a<0;A<202dC00@04a<=:a<2030C00<04a<03a<006LC00D@4`dC00044`0341<C0=hC0P000a<=

4`1^4`00G1<00`0C4`024`0301<C008C00H041<=4`044`0341<C0=hC00<04`d0L1<005/C00<04`00

1a<00`0@00024`033@0C00<C00<@4a<0gQ<00`0C3@1`4`00Fa<00`0C00084`03400C008C00<=01<0

0a<00a0C4`3M4`0300dC06`C0P024`00Fa<00`0C00074`03010C00<C00<03A<00a<00a0C4`3M4`03

3A<C06/C00<04a<00Q<005/C00<04`001a<00a0C4`034`0301<=00@C00<@4a<0MQ=V00033@0006@0

1a<00`0C4`024`00G1<00`0C4`064`03400000<C00<04`d011<00a0C4`1k4`0301<C00LC00<04a<0

1Q<00`0C4`074`0301<C00LC00<04a<01a<00`0C4`064`0301<C00LC00<04a<01a<00`0C4`064`03

01<C00HC00<=01<021<00`0C4`074`0301<C00HC00<04a<01a<00`0C4`074`0301<C00HC00<04a<0

1a<00`0C4`074`0301<C00HC00<04a<01a<00`0C4`0:4`0301<C008C001T4`0341<C00@C0P000a<=

4`024`0341<C0=/C00<=01<0K1<00`0C00024`00I1<00a0C4`044`0501<C4`d00a<00a0C4`3I4`03

3A<006dC0`024`00Ha<00a0C4`054`0301<C008C00@=4a<@fa<00`dC001b4`00Ha<00a0C4`054`03

01<C008C00D=4a<C403J4`043A<0074C001R4`0341<C00HC00<04a<00a<010dC4a3I4`043A<C078C

001R4`0341<C00HC0P054`043A<C4=PC00@=4a<0LQ<0064C00<@4a<01a<00`0C4`054`033A<@0=PC

00@=4a<0LQ<0064C00<@4a<01a<00`0C4`064`033A0C0=LC00@=4a<0LQ<0060C00<@4a<021<00`0C

4`064`033A<@0=LC00<=4a<00P1a4`00H1<00a0C4`084`8021<00`d@4`3E4`053A<C4`00LQ<005lC

00<@4a<02A<00`0C4`084`033A0C0=@C00D=4a<C001b4`00Ga<00a0C4`094`0301<C00TC00<=4a<0

da<01@dC4a<0078C001N4`0341<C00XC00<04a<02A<00`d@4`3C4`043A<C4`80LA<005hC00<@4a<0

2Q<200/C00<=4a<0dQ<01@dC4a<0078C001M4`0341<C00/C00<04a<02a<00`dC4`3A4`053A<C4`00

LQ<005dC00<@4a<011<5008C00<04a<02a<00a0=4`3A4`053A<C4`00LQ<005`C00<@4a<01a<00`0C

4`024`0301<C00`C00<=4a<0d1<01@dC4a<0078C001K4`0341<C00PC00<04a<00Q<200hC00<=4a<0

ca<010dC4a<2074C001K4`0341<C00PC00<04a<00Q<00`0C4`0=4`0340dC0<lC00D=4a<C001b4`00

FQ<00a0C4`094`0301<C008C00<04a<03Q<00`dC4`3>4`053A<C4`00LQ<005XC00<@4a<021<200@C

00<04a<03a<00`dC4`324`0301<C008C00<04a<00Q<00`0=4`024`0301<C070C001I4`0341<C00lC

0P0@4`0340dC0<4C00<04`001a<00`0C3@034`0301<C070C001H4`0341<C010C00<04a<041<00a0=

4`304`0301<000TC00@03A<C0P1a4`00F1<00a0C4`0@4`0301<C014C00<=4a<0_a<00`0C00074`80

00DC3A<C001b4`00Ea<00a0C4`0A4`0301<C014C00<@3A<0_a<00`0C00074`0401<C3@8C00<04a<0

L1<005HC00<@4a<04Q<201<C00<@3A<0_a<00`0C4`064`<000@=4a<0LQ<005HC00<@4a<04Q<00`0C

4`0C4`0340dC0<XC00@=4a<0LQ<005DC00<@4a<04a<00`0C4`0C4`0340dC0<XC00<=4a<00P1a4`00

E1<00a0C4`0D4`0301<C01@C00<@3A<0bQ<00`dC001b4`00Da<00a0C4`0E4`805A<00a0C3@3:4`03

3A<0078C001C4`0341<C01DC00<04a<05A<00a0C3@3:4`033@0C074C001B4`0341<C01HC00<04a<0

5Q<00a0=4`394`033@0C074C001A4`0341<C01LC00<04a<05Q<00a0C3@3:4`033@0C070C001A4`03

41<C01LC0P0H4`0341<=0<TC00<=4a<0L1<0050C00<@4a<061<00`0C4`0G4`0441<C3LPC00<03A<0

L1<004lC00<@4a<021<5008C00<04a<00Q<00`0C4`024`0301<C01PC00<@4`d0b1<00`0C3@1`4`00

Ca<00a0C4`0:4`0301<C00HC00<04`000a<00`0C4`0I4`0341<=0<LC00<04`d0L1<004hC00<@4a<0

2a<00`0C4`084`0401<C4`806a<00a0C3@364`8000<C3A<0KQ<004dC00<@4a<031<00`0C4`064`80

11<00`0C4`0J4`0441<C3LDC00D04a<C3@1^4`00C1<00a0C4`0=4`0301<C00HC00<04a<00a<00`0C

4`0K4`0341<=0<DC00<04a<00Q<00`dC4`1[4`00C1<00a0C4`0<4`8021<300<C00<04a<071<00a0C

3@344`0301<C008C00<=4a<0Ja<004/C00<@4a<07A<201hC00<@4`d0`a<200@C00<=4a<0JQ<004XC

00<@4a<07Q<00`0C4`0M4`0441<C3L8C00<04a<00a<00`dC4`1Z4`00BQ<00a0C4`0N4`0301<C01hC

00<@4`d0`Q<00`0C4`044`8=JQ<004TC00<@4a<07a<00`0C4`0O4`0341<=0;XC1@024`0301<C00DC

00<=4a<0J1<004PC00<@4a<081<2024C00<@4`d0^a<00`0C4`024`0301<C00HC00<=4a<0Ia<004LC

00<@4a<08A<00`0C4`0Q4`0340dC0;XC00<04a<00Q<200PC00<=4a<0IQ<004LC00<@4a<08A<00`0C

4`0Q4`0341<=0;XC00<04a<00Q<00`0C4`084`033A<C06DC00164`0341<C028C00<04a<08Q<00a0C

3@2i4`0301<C008C00<04a<02A<23FDC00154`0341<C02<C0P0T4`0341<=0;LC0P044`0301<C00XC

00<=4a<0Ha<004@C00<@4a<091<00`0C4`0T4`0340dC0;`C00<04a<02a<00`dC4`1R4`00A1<00a0C

4`0T4`0301<C02@C00<@4`d0_1<200dC00<=4a<0HA<004<C00<@4a<09A<00`0C4`0U4`0341<=0;/C

00<04a<03A<00`dC4`1P4`00@Q<00a0C4`0V4`0301<C02HC00<@4`d0^Q<00`0C4`0>4`8=H1<0044C

00<@4a<09a<202PC00<@4`d0^A<00`0C4`0?4`8=Ga<0040C00<@4a<0:1<00`0C4`0X4`0340dC0;PC

00<04a<04A<00`dC4`1L4`00@1<00a0C4`0R4`<00a<00`0C4`0Y4`0340dC0;LC0P0C4`033A<C05/C

000o4`0341<C02<C00<04a<00a<00`0C4`0Y4`0341<=0;LC00<04a<04a<00`dC4`1J4`00?Q<00a0C

4`0U4`0301<C008C0P0[4`0341<=0;HC00<04a<051<00`dC4`1I4`00?A<00a0C4`0V4`0301<C008C

00<04a<0:a<00a0C3@2e4`0301<C01DC0PeI4`00?A<00a0C4`0U4`0301<000<C00<04a<0;1<00a0C

3@2d4`0301<C01LC00<=4a<0EQ<003`C00<@4a<09a<00`0C4`024`0301<C02dC00<@3A<0/a<201TC

0PeF4`00>a<00a0C4`0]4`80;a<00a0=4`2b4`0301<C01XC0PeD4`00>Q<00a0C4`0^4`0301<C02hC

00<@4`d0/Q<00`0C4`0L4`8=DQ<003XC00<@4a<0;Q<00`0C4`0_4`0340dC0;4C00<04a<07Q<00`dC

4`1?4`00>A<00a0C4`0_4`0301<C030C00<@3A<0/1<00`0C4`0O4`8=Ca<003PC00<@4a<0<1<2038C

00<@3A<0[a<2028C00<=4a<0C1<003LC00<@4a<0<A<00`0C4`0a4`0341<=0:lC00<04a<08Q<23D`C

000g4`0341<C034C00<04a<0<Q<00a0=4`2^4`0301<C02@C00<=4a<0BA<003HC00<@4a<0<Q<00`0C

4`0c4`0340dC09`C1@024`0301<C008C00<04a<00Q<00`0C4`0U4`8=BA<003DC00<@4a<0<a<203DC

00<@3A<0WA<00`0C4`064`0301<000<C00<04a<09a<00`dC4`164`00=1<00a0C4`0d4`0301<C03DC

00<@3A<0W1<00`0C4`084`0401<C4`80:A<23DHC000c4`0341<C03DC00<04a<0=Q<00`dC4`2K4`03

01<C00HC0P044`0301<C02XC00<=4a<0@a<0038C00<@4a<0=Q<00`0C4`0f4`0340dC09/C00<04a<0

1Q<00`0C4`034`0301<C02/C0Pe34`00<A<00a0C4`0g4`80>1<00a0=4`2I4`8021<300<C00<04a<0

;A<23D4C000`4`0341<C03PC00<04a<0>1<00a0=4`2X4`80<1<23ClC000_4`0341<C02TC0`034`03

01<C008C00<04a<00Q<00`0C4`0i4`033A<C0:LC00<04a<0<A<23CdC000^4`0341<C02XC00<04a<0

1a<00`0C00034`0301<C03XC00<=4a<0YQ<00`0C4`0c4`8=>a<002dC00<@4a<0;1<00`0C4`084`04

01<C4`80?1<00`dC4`2U4`0301<C03DC0Pdi4`00;1<00a0C4`0]4`0301<C00HC0P044`0301<C03`C

00<=4a<0Y1<00`0C4`0g4`8==a<002/C00<@4a<0;A<00`0C00074`0301<C00<C00<04a<0?1<00`d@

4`2T4`80>Q<23CDC000Z4`0341<C02lC00<04a<01Q<300<C00<04a<0?A<00`d@4`2S4`0301<C03/C

0Pdc4`00:A<00a0C4`0o4`80?a<00`d@4`2R4`0301<C03dC00<=4a<0<1<002PC00<@4a<0@1<00`0C

4`0n4`033A<@0:8C00<04a<0?Q<33BlC000W4`0341<C044C00<04a<0?a<00`dC402Q4`0301<C044C

0Pd]4`009Q<00a0C4`124`0301<C040C00<=4a00X1<204@C0Pd[4`009A<00a0C4`134`80@A<010dC

4a2O4`0301<C04DC0PdY4`0091<00a0C4`144`0301<C044C00@=4a<@WQ<00`0C4`174`<=9Q<002<C

00<@4a<0AA<00`0C4`124`043A<C49dC00<04a<0BQ<00`dC4`0S4`008a<00a0C4`154`0301<C04<C

00@=4a<@W1<00`0C4`1;4`<=8Q<0028C00<@4a<0AQ<204@C00D=4a<C402K4`80Ca<23B0C000Q4`03

41<C04LC00<04a<0A1<01@dC4a<@09XC00<04a<0D1<23AhC000P4`0341<C04PC00<04a<0AA<01@dC

4a<@09TC00<04a<0DQ<33A/C000O4`0341<C04TC00<04a<0AQ<01@dC4a<@098C0`034`0301<C05DC

0PdI4`007Q<00a0C4`1:4`80Aa<00`dC4`024`0341<C08lC00<04a<00a<00`0C4`1G4`<=5Q<001dC

00<@4a<0Ba<00`0C4`174`033A<C008C00<@4a<0Sa<00`0C4`024`80Fa<23A@C000L4`0341<C04`C

00<04a<0B1<00`dC4`024`0341<C08hC00<04a<00Q<00`0C4`1L4`<=4A<001/C00<@4a<0Aa<200@C

00<04a<0BA<00`dC4`024`0341<C08`C00<04`000a<00`0C4`1`4`006Q<00a0C4`1:4`0501<C4`00

Ba<00`dC4`034`0341<C08`C00<04a<00Q<00`0C4`1`4`006A<00a0C4`1:4`0301<C008C0P1;4`03

3A<C008C00<@4a<0TA<00`0C4`1`4`00Ia<00`0C4`3W4`80LA<006DC00<04`00oa=M4`00IQ<00`0C

4`3o4e`C000Z4`<0oa>H4`00:Q<00`0C4`3o4iPC000[4`0301<C00@C00<04a<0oa>@4`00:a<0100C

4a<400<C0`3o4h`C000Z4`0301<0008C0P000a<04`044`0301<C0?lCAa<00`0C4`0g4`0301<C00HC

000[4`0301<C00<C00<04`000a<00`0C4`3o4d0C00<04a<011<00`0C4`0C4`0301<C02<C00<04a<0

1A<0034C00<04`0011<00`0C4`064`0301<C02LC0`0[4`0301<C0</C00@04a<C10024`801Q<00`0C

4`034`0301<C008C00<04a<00Q<00`0C4`024`0301<C00DC00@04a<C1@024`0401<C4`800a<300<C

00<04a<011<200@C00@04a<C0P014`006a<300034`00008031<300@C0`084`0301<C02HC00@04a<0

3a<300034`0000800Q<00`0C4`024`0301<C008C00<04a<01A<0100C4a<5008C00@04a<C0P034`<0

0a<00`0C4`044`80ZQ<00`0C00074`0301<C00@C1@034`0701<C4`0C00074`0301<000@C1@034`03

01<C00PC00@04a<011<00`0C00044`0301<C00@C00<04a<00Q<1004C000J4`0401<C02@C00<04a<0

9A<0100C4`0>4`0401<C00HC00<04`001a<00`0C00044`D00a<00`0C4`084`0401<C00@C00<04`00

11<00`0C4`2Z4`0301<0008C10000a<04`074`0301<C00<C00L04a<C01<000TC00<04a<011<00`0C

4`034`0301<C00LC00<04a<00Q<00`0C4`034`0301<C008C00<04a<011<00`0C4`034`40000J4`05

01<C01<010000a<0000H02dC0`0>4`0501<C01<0100011<04`094`0301<C00@C00<04a<00a<00`0C

4`074`0301<C008C00<04a<00a<00`0C4`024`0301<C09<C0P000a<0000B4`0301<000LC00<04a<0

1Q<00`0C4`034`0701<C4`0C00074`801a<00`0C4`034`0301<C00PC00D04a<C00034`801A<00`0C

4`044`0301<C00<C0@0001/C0`1?4`0301<C00dC0`064`0301<000LC0P074`0301<C00<C00<04a<0

21<01@0C4a<000<C0P054`0301<C09@C00<04`004a<00`0C00074`0301<000dC00H04a<04`074`03

01<C00`C00<04a<01Q<00`0C00024`0301<0008C00<04a<011<00`0C00034`0301<C00<C0@014`00

7A<00`0C4`1<4`804A<00`0C4`044`0301<000LC00<04a<031<00`0C4`064`0301<0008C00<04`00

0Q<00`0C4`044`0301<009DC00<04a<04a<00`0C4`064`<03Q<0100C4`084`<02a<200TC00<04a<0

0Q<0100C4a<300@C0`024`0301<C00<C0P014`0071<2060C0P074`0301<C00HC0`0;4`802A<00`0C

4`024`0401<C4`<011<309DC00<04a<0L1<00?lCDA<00`0C001a4`009Q<200HC0P3o4b0C0P000a<0

001`4`00:1<00`0C4`024`0301<C0?lCUA<002LC00<04a<00a<00`0C4`064`0301<C0?lCS1<002PC

00<04a<00Q<00`0C4`024`<000@C01<C0`3o4hTC000V4`0301<000@C00<04`000Q<2008C00<04a<0

0Q<00`0C4`3o4hLC000W4`0301<C00<C0`044`0401<C008C00<04a<0oa>84`00=1<0100C4`034`03

01<C0?lCQa<0038C0`044`<0oa>94`00oa?54`00oa?54`00oa?54`00oa?54`00oa?54`00\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-6.95686, -1.4865, 0.0206072, 0.0206072}}],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .45351 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.47619 0.010798 0.47619 [

[ 0 0 0 0 ]

[ 1 .45351 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 m

1 0 L

1 .45351 L

0 .45351 L

closepath

clip

newpath

% Start of sub-graphic

p

0.0238095 0.010798 0.477324 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.238095 0.238095 [

[.02381 .2256 -6 -9 ]

[.02381 .2256 6 0 ]

[.2619 .2256 -6 -9 ]

[.2619 .2256 6 0 ]

[.7381 .2256 -3 -9 ]

[.7381 .2256 3 0 ]

[.97619 .2256 -3 -9 ]

[.97619 .2256 3 0 ]

[1.025 .2381 0 -8 ]

[1.025 .2381 9 8 ]

[.4875 0 -12 -4.5 ]

[.4875 0 0 4.5 ]

[.4875 .11905 -24 -4.5 ]

[.4875 .11905 0 4.5 ]

[.4875 .35714 -18 -4.5 ]

[.4875 .35714 0 4.5 ]

[.4875 .47619 -6 -4.5 ]

[.4875 .47619 0 4.5 ]

[.4875 .59524 -18 -4.5 ]

[.4875 .59524 0 4.5 ]

[.4875 .71429 -6 -4.5 ]

[.4875 .71429 0 4.5 ]

[.4875 .83333 -18 -4.5 ]

[.4875 .83333 0 4.5 ]

[.4875 .95238 -6 -4.5 ]

[.4875 .95238 0 4.5 ]

[.5 .97738 -4.5 0 ]

[.5 .97738 4.5 16 ]

[.5 .96488 -82 0 ]

[.5 .96488 82 24 ]

[ 0 0 0 0 ]

[ 1 .95238 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .2381 m

.02381 .24435 L

s

[(-2)] .02381 .2256 0 1 Mshowa

.2619 .2381 m

.2619 .24435 L

s

[(-1)] .2619 .2256 0 1 Mshowa

.7381 .2381 m

.7381 .24435 L

s

[(1)] .7381 .2256 0 1 Mshowa

.97619 .2381 m

.97619 .24435 L

s

[(2)] .97619 .2256 0 1 Mshowa

.125 Mabswid

.07143 .2381 m

.07143 .24185 L

s

.11905 .2381 m

.11905 .24185 L

s

.16667 .2381 m

.16667 .24185 L

s

.21429 .2381 m

.21429 .24185 L

s

.30952 .2381 m

.30952 .24185 L

s

.35714 .2381 m

.35714 .24185 L

s

.40476 .2381 m

.40476 .24185 L

s

.45238 .2381 m

.45238 .24185 L

s

.54762 .2381 m

.54762 .24185 L

s

.59524 .2381 m

.59524 .24185 L

s

.64286 .2381 m

.64286 .24185 L

s

.69048 .2381 m

.69048 .24185 L

s

.78571 .2381 m

.78571 .24185 L

s

.83333 .2381 m

.83333 .24185 L

s

.88095 .2381 m

.88095 .24185 L

s

.92857 .2381 m

.92857 .24185 L

s

.25 Mabswid

0 .2381 m

1 .2381 L

s

gsave

1.025 .2381 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 0 m

.50625 0 L

s

[(-1)] .4875 0 1 0 Mshowa

.5 .11905 m

.50625 .11905 L

s

[(-0.5)] .4875 .11905 1 0 Mshowa

.5 .35714 m

.50625 .35714 L

s

[(0.5)] .4875 .35714 1 0 Mshowa

.5 .47619 m

.50625 .47619 L

s

[(1)] .4875 .47619 1 0 Mshowa

.5 .59524 m

.50625 .59524 L

s

[(1.5)] .4875 .59524 1 0 Mshowa

.5 .71429 m

.50625 .71429 L

s

[(2)] .4875 .71429 1 0 Mshowa

.5 .83333 m

.50625 .83333 L

s

[(2.5)] .4875 .83333 1 0 Mshowa

.5 .95238 m

.50625 .95238 L

s

[(3)] .4875 .95238 1 0 Mshowa

.125 Mabswid

.5 .02381 m

.50375 .02381 L

s

.5 .04762 m

.50375 .04762 L

s

.5 .07143 m

.50375 .07143 L

s

.5 .09524 m

.50375 .09524 L

s

.5 .14286 m

.50375 .14286 L

s

.5 .16667 m

.50375 .16667 L

s

.5 .19048 m

.50375 .19048 L

s

.5 .21429 m

.50375 .21429 L

s

.5 .2619 m

.50375 .2619 L

s

.5 .28571 m

.50375 .28571 L

s

.5 .30952 m

.50375 .30952 L

s

.5 .33333 m

.50375 .33333 L

s

.5 .38095 m

.50375 .38095 L

s

.5 .40476 m

.50375 .40476 L

s

.5 .42857 m

.50375 .42857 L

s

.5 .45238 m

.50375 .45238 L

s

.5 .5 m

.50375 .5 L

s

.5 .52381 m

.50375 .52381 L

s

.5 .54762 m

.50375 .54762 L

s

.5 .57143 m

.50375 .57143 L

s

.5 .61905 m

.50375 .61905 L

s

.5 .64286 m

.50375 .64286 L

s

.5 .66667 m

.50375 .66667 L

s

.5 .69048 m

.50375 .69048 L

s

.5 .7381 m

.50375 .7381 L

s

.5 .7619 m

.50375 .7619 L

s

.5 .78571 m

.50375 .78571 L

s

.5 .80952 m

.50375 .80952 L

s

.5 .85714 m

.50375 .85714 L

s

.5 .88095 m

.50375 .88095 L

s

.5 .90476 m

.50375 .90476 L

s

.5 .92857 m

.50375 .92857 L

s

.25 Mabswid

.5 0 m

.5 .95238 L

s

gsave

.5 .97738 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .96488 -143 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 32 translate 1 -1 scale

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

68.000000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

75.625000 13.062500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

82.625000 13.062500 moveto

(C) show

87.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

91.125000 9.500000 moveto

(\\220) show

94.625000 9.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

0.500000 setlinewidth

0.000000 0.000000 0.000000 setrgbcolor

74.250000 17.000000 moveto

24.750000 0.000000 rlineto

stroke

79.125000 26.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

84.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

87.625000 23.500000 moveto

(\\220) show

91.125000 23.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

101.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(,) show

161.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(d) show

166.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

171.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

186.250000 19.500000 moveto

0.000000 0.000000 rmoveto

188.250000 19.500000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

195.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.32) show

217.250000 19.500000 moveto

(C) show

222.250000 19.500000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .95238 L

0 .95238 L

closepath

clip

newpath

0 .4 1 r

.5 Mabswid

.02381 .95238 m

.06244 .9132 L

.10458 .86914 L

.14415 .8263 L

.18221 .78358 L

.22272 .73618 L

.26171 .68831 L

.30316 .63447 L

.34309 .57887 L

.3815 .52069 L

.42237 .45126 L

.44268 .41223 L

.46172 .37115 L

.47994 .32456 L

.48519 .30873 L

.49018 .2918 L

.49466 .27387 L

.4972 .26138 L

.49832 .25465 L

.49955 .24496 L

.50084 .2485 L

.50154 .25371 L

.5022 .25788 L

.50463 .27062 L

.51012 .29289 L

.52007 .32461 L

.53868 .37207 L

.57759 .45118 L

.61895 .52141 L

.6588 .58158 L

.69713 .63484 L

.73791 .68783 L

.77717 .73605 L

.81492 .78029 L

.85513 .82551 L

.89382 .86743 L

.93496 .91053 L

.97458 .95077 L

.97619 .95238 L

s

1 0 0 r

.22944 0 m

.26171 .0426 L

.30316 .09731 L

.34309 .15002 L

.3815 .20072 L

.42237 .25467 L

.46172 .30661 L

.49955 .35655 L

.53984 .40973 L

.57861 .46091 L

.61984 .51533 L

.65954 .56774 L

.69774 .61816 L

.73838 .67181 L

.77751 .72346 L

.81909 .77835 L

.85916 .83124 L

.89771 .88212 L

.93871 .93625 L

s

.93871 .93625 m

.95094 .95238 L

s

MathSubEnd

P

% End of sub-graphic

% Start of sub-graphic

p

0.522676 0.010798 0.97619 0.442717 MathSubStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.5 0.238095 0.3125 0.238095 [

[.02381 .3 -6 -9 ]

[.02381 .3 6 0 ]

[.2619 .3 -6 -9 ]

[.2619 .3 6 0 ]

[.7381 .3 -3 -9 ]

[.7381 .3 3 0 ]

[.97619 .3 -3 -9 ]

[.97619 .3 3 0 ]

[1.025 .3125 0 -8 ]

[1.025 .3125 9 8 ]

[.4875 .0744 -12 -4.5 ]

[.4875 .0744 0 4.5 ]

[.4875 .19345 -24 -4.5 ]

[.4875 .19345 0 4.5 ]

[.4875 .43155 -18 -4.5 ]

[.4875 .43155 0 4.5 ]

[.4875 .55059 -6 -4.5 ]

[.4875 .55059 0 4.5 ]

[.4875 .66964 -18 -4.5 ]

[.4875 .66964 0 4.5 ]

[.4875 .78869 -6 -4.5 ]

[.4875 .78869 0 4.5 ]

[.5 .84048 -4.5 0 ]

[.5 .84048 4.5 16 ]

[.5 .82798 -134.5 0 ]

[.5 .82798 134.5 16 ]

[ 0 0 0 0 ]

[ 1 .81548 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.02381 .3125 m

.02381 .31875 L

s

[(-2)] .02381 .3 0 1 Mshowa

.2619 .3125 m

.2619 .31875 L

s

[(-1)] .2619 .3 0 1 Mshowa

.7381 .3125 m

.7381 .31875 L

s

[(1)] .7381 .3 0 1 Mshowa

.97619 .3125 m

.97619 .31875 L

s

[(2)] .97619 .3 0 1 Mshowa

.125 Mabswid

.07143 .3125 m

.07143 .31625 L

s

.11905 .3125 m

.11905 .31625 L

s

.16667 .3125 m

.16667 .31625 L

s

.21429 .3125 m

.21429 .31625 L

s

.30952 .3125 m

.30952 .31625 L

s

.35714 .3125 m

.35714 .31625 L

s

.40476 .3125 m

.40476 .31625 L

s

.45238 .3125 m

.45238 .31625 L

s

.54762 .3125 m

.54762 .31625 L

s

.59524 .3125 m

.59524 .31625 L

s

.64286 .3125 m

.64286 .31625 L

s

.69048 .3125 m

.69048 .31625 L

s

.78571 .3125 m

.78571 .31625 L

s

.83333 .3125 m

.83333 .31625 L

s

.88095 .3125 m

.88095 .31625 L

s

.92857 .3125 m

.92857 .31625 L

s

.25 Mabswid

0 .3125 m

1 .3125 L

s

gsave

1.025 .3125 -61 -12 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

.5 .0744 m

.50625 .0744 L

s

[(-1)] .4875 .0744 1 0 Mshowa

.5 .19345 m

.50625 .19345 L

s

[(-0.5)] .4875 .19345 1 0 Mshowa

.5 .43155 m

.50625 .43155 L

s

[(0.5)] .4875 .43155 1 0 Mshowa

.5 .55059 m

.50625 .55059 L

s

[(1)] .4875 .55059 1 0 Mshowa

.5 .66964 m

.50625 .66964 L

s

[(1.5)] .4875 .66964 1 0 Mshowa

.5 .78869 m

.50625 .78869 L

s

[(2)] .4875 .78869 1 0 Mshowa

.125 Mabswid

.5 .09821 m

.50375 .09821 L

s

.5 .12202 m

.50375 .12202 L

s

.5 .14583 m

.50375 .14583 L

s

.5 .16964 m

.50375 .16964 L

s

.5 .21726 m

.50375 .21726 L

s

.5 .24107 m

.50375 .24107 L

s

.5 .26488 m

.50375 .26488 L

s

.5 .28869 m

.50375 .28869 L

s

.5 .33631 m

.50375 .33631 L

s

.5 .36012 m

.50375 .36012 L

s

.5 .38393 m

.50375 .38393 L

s

.5 .40774 m

.50375 .40774 L

s

.5 .45536 m

.50375 .45536 L

s

.5 .47917 m

.50375 .47917 L

s

.5 .50298 m

.50375 .50298 L

s

.5 .52679 m

.50375 .52679 L

s

.5 .5744 m

.50375 .5744 L

s

.5 .59821 m

.50375 .59821 L

s

.5 .62202 m

.50375 .62202 L

s

.5 .64583 m

.50375 .64583 L

s

.5 .69345 m

.50375 .69345 L

s

.5 .71726 m

.50375 .71726 L

s

.5 .74107 m

.50375 .74107 L

s

.5 .76488 m

.50375 .76488 L

s

.5 .05059 m

.50375 .05059 L

s

.5 .02679 m

.50375 .02679 L

s

.5 .00298 m

.50375 .00298 L

s

.5 .8125 m

.50375 .8125 L

s

.25 Mabswid

.5 0 m

.5 .81548 L

s

gsave

.5 .84048 -65.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

1.000000 setlinewidth

%%DocumentNeededResources: font Courier

%%DocumentNeededFonts: Courier

%%DocumentFonts: font Courier

grestore

gsave

.5 .82798 -195.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 24 translate 1 -1 scale

63.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

218.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

223.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

228.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(C) show

235.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

242.000000 15.000000 moveto

(H) show

247.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0.5) show

262.000000 15.000000 moveto

0.000000 0.000000 rmoveto

264.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(+) show

271.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.32) show

293.000000 15.000000 moveto

(C) show

%%IncludeResource: font Math2Mono

%%IncludeFont: Math2Mono

/Math2Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

298.000000 15.000000 moveto

(L) show

305.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

312.000000 15.000000 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

319.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

324.000000 11.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

328.000000 15.000000 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1Mono

%%DocumentNeededResources: + font Math2Mono

%%DocumentNeededResources: + font Courier

%%DocumentNeededFonts: Math1Mono

%%DocumentNeededFont: + Math2Mono

%%DocumentNeededFont: + Courier

%%DocumentFonts: font Math1Mono

%%DocumentFonts: + font Math2Mono

%%DocumentFonts: + font Courier

grestore

0 0 m

1 0 L

1 .81548 L

0 .81548 L

closepath

clip

newpath

1 0 0 r

.5 Mabswid

.02381 .13561 m

.02575 .13562 L

.03156 .13565 L

.04111 .1357 L

.05427 .13577 L

.07079 .13586 L

.09039 .13598 L

.11275 .13613 L

.13748 .1363 L

.16415 .13651 L

.1923 .13675 L

.22147 .13703 L

.25114 .13735 L

.28082 .13772 L

.30998 .13813 L

.33814 .1386 L

.36481 .13912 L

.38953 .13969 L

.41189 .14029 L

.4315 .1409 L

.44802 .1415 L

.46117 .14204 L

.47073 .14248 L

.47653 .14277 L

.47848 .14287 L

s

.47848 .14287 m

.47898 .1429 L

.48049 .14298 L

.48297 .14311 L

.48638 .1433 L

.49067 .14355 L

.49576 .14387 L

.50156 .14425 L

.50798 .1447 L

.5149 .14523 L

.52221 .14586 L

.52978 .14658 L

.53748 .14741 L

.54518 .14837 L

.55275 .14946 L

.56006 .15071 L

.56698 .15213 L

.5734 .15374 L

.5792 .15558 L

.58429 .15765 L

.58857 .16 L

.59199 .16264 L

.59447 .16561 L

.59597 .16894 L

.59648 .17264 L

s

.47848 .39726 m

.47898 .38444 L

.48049 .37159 L

.48297 .35882 L

.48638 .34617 L

.49067 .33369 L

.49576 .32143 L

.50156 .30943 L

.50798 .29774 L

.5149 .28639 L

.52221 .27542 L

.52978 .26486 L

.53748 .25475 L

.54518 .2451 L

.55275 .23595 L

.56006 .2273 L

.56698 .21917 L

.5734 .21157 L

.5792 .2045 L

.58429 .19795 L

.58857 .19192 L

.59199 .1864 L

.59447 .18136 L

.59597 .17679 L

.59648 .17268 L

s

.47848 .39737 m

.47898 .41016 L

.48049 .42293 L

.48297 .43557 L

.48638 .44803 L

.49067 .46026 L

.49576 .4722 L

.50156 .48382 L

.50798 .49506 L

.5149 .50588 L

.52221 .51622 L

.52978 .52606 L

.53748 .53534 L

.54518 .54403 L

.55275 .55209 L

.56006 .55949 L

.56698 .5662 L

.5734 .57218 L

.5792 .57742 L

.58429 .58189 L

.58857 .58558 L

.59199 .58846 L

.59447 .59052 L

.59597 .59177 L

.59648 .59218 L

s

.59648 .59218 m

.59758 .59308 L

.60085 .59574 L

.60625 .60005 L

.61368 .60583 L

.62301 .61287 L

.63408 .62093 L

.64671 .62978 L

.66067 .63918 L

.67573 .64893 L

.69164 .65883 L

.70811 .66869 L

.72486 .67837 L

.74162 .68772 L

.75809 .69662 L

.774 .70497 L

.78906 .71267 L

.80302 .71965 L

.81565 .72583 L

.82672 .73115 L

.83605 .73557 L

.84348 .73905 L

.84887 .74155 L

.85215 .74306 L

.85325 .74357 L

s

.85325 .09695 m

.85377 .09384 L

.85534 .09049 L

.85793 .0869 L

.86148 .0831 L

.86595 .07912 L

.87125 .07497 L

.8773 .0707 L

.88398 .06633 L

.8912 .06192 L

.89881 .0575 L

.9067 .05312 L

.91472 .04884 L

.92274 .04469 L

.93063 .04073 L

.93824 .03699 L

.94546 .03353 L

.95214 .03038 L

.95819 .02757 L

.96349 .02513 L

.96795 .02311 L

.97151 .02151 L

.9741 .02035 L

.97566 .01965 L

.97619 .01942 L

s

.85325 .09698 m

.85377 .09984 L

.85534 .10248 L

.85793 .10488 L

.86148 .10706 L

.86595 .10902 L

.87125 .11078 L

.8773 .11235 L

.88398 .11375 L

.8912 .11499 L

.89881 .11609 L

.9067 .11706 L

.91472 .11791 L

.92274 .11866 L

.93063 .11931 L

.93824 .11987 L

.94546 .12036 L

.95214 .12077 L

.95819 .12112 L

.96349 .1214 L

.96795 .12163 L

.97151 .1218 L

.9741 .12193 L

.97566 .122 L

.97619 .12202 L

s

.85325 .74357 m

.85377 .74381 L

.85534 .74453 L

.85793 .74571 L

.86148 .74733 L

.86595 .74936 L

.87125 .75175 L

.8773 .75445 L

.88398 .75742 L

.8912 .76059 L

.89881 .76391 L

.9067 .76731 L

.91472 .77075 L

.92274 .77415 L

.93063 .77746 L

.93824 .78063 L

.94546 .78361 L

.95214 .78635 L

.95819 .78882 L

.96349 .79096 L

.96795 .79276 L

.97151 .79419 L

.9741 .79522 L

.97566 .79585 L

.97619 .79606 L

s

MathSubEnd

P

% End of sub-graphic

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{452, 204.813},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  AnimationDisplayTime->0.03333,

  AnimationCycleOffset->-1,

  AnimationCycleRepetitions->Infinity,

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000740000c0P10`40000100000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P020P<30`<3L`:K:l?okl:2PY820P?l0003o0?oo0000ool0o`3oooooo`000800002008200000

P800P?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooolCaA<00?lCaA<00?lCaA<00?lCaA<00?lC

aA<00?lCaA<00?lCaA<006@C1@3o4e`C001V4`0301<C0>PC00<04a<0L1<003dC00<=4a<081<300<C

00<04a<00Q<20>@C0P1a4`00?Q<00`dC4`0U4`0301<C008C00<04a<0ha<00`0C4`1`4`00?Q<00`dC

4`0U4`0301<C008C00<04a<0ha<00`0C4`1`4`00?a<00`dC4`0S4`8011<00`0C4`3S4`0301<C05dC

0PdA4`00@1<00`dC4`0X4`80i1<205dC00<=4a<04A<0044C00<=4a<09a<00`0C4`3S4`0301<C05TC

0`dD4`00@A<00`dC4`0W4`0301<C0><C00<04a<0F1<00`dC4`0E4`00@Q<00`dC4`0V4`0301<C0><C

00<04a<0EA<33APC00134`033A<C02DC0P3T4`0301<C05<C0PdK4`00@a<00`dC4`0U4`0301<C0><C

0P1C4`033A<C01/C00144`033A<C02@C00<04a<0ha<00`0C4`1@4`8=7Q<004DC00<=4a<08a<00`0C

4`3S4`0301<C04hC0PdP4`00AA<00`dC4`0S4`80gA<5008C00<04a<0Ba<33B8C00164`033A<C028C

00<04a<0gQ<00`0C4`024`0301<C04XC00<=4a<08a<004LC00<=4a<08A<00`0C4`3H4`<00a<00`0C

4`024`80BQ<00`dC4`0T4`00B1<00`dC4`0P4`0301<C0=hC00<04a<00Q<00`0C4`184`033A<C02DC

00184`033A<C020C0P3O4`0301<C008C00<04a<0Aa<00`dC4`0V4`00BA<00`dC4`0O4`0301<C0=dC

0P044`0301<C04HC00<=4a<09a<004XC00<=4a<03a<00`0C4`024`0301<C008C00<04a<00Q<00`0C

4`3S4`0301<C04DC00<=4a<0:1<004/C00<=4a<03A<00`0C00074`0301<000<C00<04a<0ha<204HC

00<=4a<0:1<004/C00<=4a<021<3008C00<04`002A<0100C4a<20>@C00<04a<0AQ<00`dC4`0W4`00

C1<00`dC4`0<4`0301<000LC0P044`0301<C0><C00<04a<0Aa<23BLC001=4`033A<C00/C00<04`00

1a<00`0C4`034`0301<C0><C00<04a<0BA<53B8C001>4`033A<C00/C00<04a<01Q<300<C00<04a<0

ha<00`0C4`1>4`T=6A<004hC00<=4a<06Q<00`0C4`3S4`80F1<83A4C001?4`033A<C01TC0P3T4`03

01<C070C001@4`033A<C01PC00<04a<0ha<00`0C4`1`4`00DA<00`dC4`0G4`0301<C088CC@dD4`03

01<C070C001B4`033A<C01HC00<04a<0ca<G3G0C001B4`033A<C01HC0P3T4`8000<C3@d01`eW4`00

Da<00`dC4`0E4`0301<C0><C00<04a<02A<43F<C000J4`<09A<500dC00<=4a<051<00`0C4`0T4`D0

91<309<C00<04a<03A<23F4C000J4`0301<C02LC00<04a<03Q<00`dC4`0C4`0301<C02HC00<04a<0

91<00`0C4`2C4`0301<C00lC0PeO4`005A<300<C00<04a<081<300<C00<04a<03Q<00`dC4`0C4`80

9a<00`0C4`0U4`0301<C098C00<04a<041<23EhC000K4`0301<C02HC00<04a<03a<00`dC4`0B4`03

01<C02HC00<04a<09A<00`0C4`2B4`804Q<00`dC4`1L4`006Q<00`0C000W4`0301<C010C00<=4a<0

4A<00`0C4`0V4`0301<C02@C00<04`00Ta<00`0C4`0A4`033A<C05`C000K4`0301<C02DC0P0C4`03

3A<C010C00<04a<09A<202LC00<04a<0Pa<00`0C4`024`0301<C008C00<04a<00Q<00`0C4`0@4`03

3A<C05dC001I4`033A<C00lC0P3D4`0301<000LC00<04`000a<00`0C4`0@4`033A<C05dC001I4`03

3A<C00lC00<04a<0cQ<3008C00<04`002A<0100C4a<2010C00<=4a<0GQ<005XC00<=4a<03Q<00`0C

4`1K4`80MQ<00`0C00074`8011<00`0C4`0>4`033A<C05lC001K4`033A<C00dC00<04a<0FQ<00`0C

4`1f4`0301<000LC00<04a<00a<00`0C4`0=4`033A<C060C000E4dL000<=0000H`064`0301<C07LC

00<04a<01Q<300<C00<04a<03A<00`dC4`1P4`006A<00`0C4`064`0301<C00DC00<04a<01A<00`0C

4`054`0301<C00DC00<04a<01A<00`0C4`064`0301<C00DC00<03A<01A<00`0C4`054`0341<C00DC

00<04a<01Q<00`0C4`054`0301<C00DC00<04a<01A<00`0C4`054`0301<C00DC00<04a<01Q<00`0C

4`054`0301<C00DC00<04a<021<00`0C4`264`0301<C00`C00<=4a<0HA<005dC00<=4a<02a<00a0C

4`1J4`0301<008HC0P0<4`033A<C068C001N4`033A<C00XC0Q1K4`<0QQ<00`0C4`0;4`033A<C068C

001O4`033A<C00TC0Q3T4`0301<C00TC0PeU4`00H1<00`dC4`074`03400@0>@C00<04a<021<00`dC

4`1U4`00H1<00`dC4`074`03400@0>@C00<04a<021<00`dC4`1U4`00HA<00`dC4`064`03400@0>@C

0P084`033A<C06HC001R4`033A<C00@C00D@4`00403S4`0301<C00HC00<=4a<0Ia<006<C00<=4a<0

0a<01A0C01<@0><C00<04a<01A<00`dC4`1X4`00Ha<00`dC4`034`0541<04a00ha<00`0C4`054`03

3A<C06PC001T4`033A<C008C00<@4`000Q<00a0C4`204`<0;A<502/C00<04a<011<00`dC4`0T4`D0

;A<3010C001U4`063A<C4a0C0P000a<@4`214`0301<C02lC00<04a<0:a<200@C00<=4a<09a<00`0C

4`0]4`0301<C010C001V4`063A<C41<00Q<00a0C4`1k4`<00a<00`0C4`0X4`<00a<00`0C4`0[4`03

01<C008C00<=4a<0:1<00`0C4`0^4`0301<C00lC001V4`033A<@008C00D04a<C40224`0301<C02hC

00<04a<0:a<00`0C4`024`033A<C02PC00<04a<0;Q<00`0C4`0?4`00Ia<01@d@4a<000<C00<@4a<0

Oa<00`0C000_4`0301<C02/C00D04a<C3@0[4`0301<C02dC00<04`0041<006PC00<=4a<00P024`03

41<C080C00<04a<0;A<202dC00@04a<=:a<2030C00<04a<03a<006LC00D@4`dC00044`0341<C0=hC

0P000a<=4`1^4`00G1<00`0C4`024`0301<C008C00H041<=4`044`0341<C0=hC00<04`d0L1<005/C

00<04`001a<00`0@00024`033@0C00<C00<@4a<0gQ<00`0C3@1`4`00Fa<00`0C00084`03400C008C

00<=01<00a<00a0C4`3M4`0300dC06`C0P024`00Fa<00`0C00074`03010C00<C00<03A<00a<00a0C

4`3M4`033A<C06/C00<04a<00Q<005/C00<04`001a<00a0C4`034`0301<=00@C00<@4a<0MQ=U0003

3@0006D01a<00`0C4`024`00G1<00`0C4`064`03400000<C00<04`d011<00a0C4`1k4`0301<C02hC

00<04a<0;1<00`d04`0_4`0301<C02dC00<04a<02Q<00`0C4`024`00I1<00a0C4`044`8000<C3A<0

0Q<00a0C4`3K4`033@0C06`C00<04`000Q<006@C00<@4a<011<01@0C4a<=00<C00<@4a<0fA<00`dC

001]4`<00Q<006<C00<@4a<01A<00`0C4`024`043A<C4=/C00<=4`00LQ<006<C00<@4a<01A<00`0C

4`024`053A<C4a00fQ<010dC001a4`00HQ<00a0C4`064`0301<C00<C00@=4a<@fA<010dC4`1b4`00

HQ<00a0C4`064`801A<010dC4a3H4`043A<C078C001Q4`0341<C00LC00<04a<01A<00`dC403H4`04

3A<C078C001Q4`0341<C00LC00<04a<01Q<00`d@4`3G4`033A<C0080LA<0060C00<@4a<021<00`0C

4`064`033A<@0=LC00@=4a<0LQ<0060C00<@4a<021<200PC00<=41<0eA<01@dC4a<0078C001O4`03

41<C00TC00<04a<021<00`d@4`3D4`053A<C4`00LQ<005lC00<@4a<02A<00`0C4`094`033A<C0=<C

00D=4a<C001b4`00GQ<00a0C4`0:4`0301<C00TC00<=41<0da<010dC4a<2074C001N4`0341<C00XC

0P0;4`033A<C0=8C00D=4a<C001b4`00GA<00a0C4`0;4`0301<C00/C00<=4a<0dA<01@dC4a<0078C

001M4`0341<C00@C1@024`0301<C00/C00<@3A<0dA<01@dC4a<0078C001L4`0341<C00LC00<04a<0

0Q<00`0C4`0<4`033A<C0=0C00D=4a<C001b4`00Fa<00a0C4`084`0301<C008C0P0>4`033A<C0<lC

00@=4a<C0P1a4`00Fa<00a0C4`084`0301<C008C00<04a<03A<00a0=4`3?4`053A<C4`00LQ<005XC

00<@4a<02A<00`0C4`024`0301<C00hC00<=4a<0cQ<01@dC4a<0078C001J4`0341<C00PC0P044`03

01<C00lC00<=4a<0`Q<00`0C4`024`0301<C008C00<03A<00Q<00`0C4`1`4`00FA<00a0C4`0?4`80

41<00a0=4`314`0301<000LC00<04`d00a<00`0C4`1`4`00F1<00a0C4`0@4`0301<C010C00<@3A<0

`1<00`0C00094`0400dC4`80LA<005PC00<@4a<041<00`0C4`0A4`033A<C0;lC00<04`001a<20005

4`dC4`00LQ<005LC00<@4a<04A<00`0C4`0A4`0340dC0;lC00<04`001a<0100C4`d24`0301<C070C

001F4`0341<C018C0P0C4`0340dC0;lC00<04a<01Q<300043A<C078C001F4`0341<C018C00<04a<0

4a<00a0=4`3:4`043A<C078C001E4`0341<C01<C00<04a<04a<00a0=4`3;4`043A<0074C001D4`03

41<C01@C00<04a<051<00a0=4`3:4`033A<0078C001C4`0341<C01DC0P0E4`0341<=0<XC00<=4`00

LQ<005<C00<@4a<05A<00`0C4`0E4`0341<=0<XC00<=01<0LA<0058C00<@4a<05Q<00`0C4`0F4`03

40dC0<TC00<=01<0LA<0054C00<@4a<05a<00`0C4`0F4`0341<=0<XC00<=01<0L1<0054C00<@4a<0

5a<201PC00<@4`d0bA<00`dC4`1`4`00D1<00a0C4`0H4`0301<C01LC00@@4a<=b1<00`0=4`1`4`00

Ca<00a0C4`084`D00Q<00`0C4`024`0301<C008C00<04a<061<00a0C3@384`0301<=070C001?4`03

41<C00XC00<04a<01Q<00`0C00034`0301<C01TC00<@4`d0aa<200033A<C06hC001>4`0341<C00/C

00<04a<021<0100C4a<201/C00<@4`d0aQ<0100C4`e_4`00CA<00a0C4`0<4`0301<C00HC0P044`03

01<C01XC00@@4a<=aA<01@0C4a<=06hC001<4`0341<C00dC00<04a<01Q<00`0C4`034`0301<C01/C

00<@4`d0aA<00`0C4`024`033A<C06/C001<4`0341<C00`C0P084`<00a<00`0C4`0L4`0341<=0<@C

00<04a<00Q<00`dC4`1[4`00Ba<00a0C4`0M4`807Q<00a0C3@334`8011<00`dC4`1Z4`00BQ<00a0C

4`0N4`0301<C01dC00@@4a<=`Q<00`0C4`044`033A<C06TC001:4`0341<C01hC00<04a<07Q<0110C

4`g14`0301<C00DC00<=4a<0J1<004TC00<@4a<07a<00`0C4`0O4`0341<=0;XC1@024`0301<C00DC

00<=4a<0J1<004PC00<@4a<081<2024C00<@4`d0^a<00`0C4`024`0301<C00HC00<=4a<0Ia<004LC

00<@4a<08A<00`0C4`0Q4`0341<=0;XC00<04a<00Q<200PC0PeW4`00Aa<00a0C4`0Q4`0301<C024C

00@@4a<=^A<00`0C4`024`0301<C00PC00<=4a<0IA<004HC00<@4a<08Q<00`0C4`0R4`0341<=0;TC

00<04a<00Q<00`0C4`094`033A<C06@C00154`0341<C02<C0P0T4`0341<=0;LC0P044`0301<C00XC

0PeT4`00A1<00a0C4`0T4`0301<C02@C00<@4`d0_1<00`0C4`0;4`033A<C068C00144`0341<C02@C

00<04a<091<0110C4`fk4`803A<00`dC4`1Q4`00@a<00a0C4`0U4`0301<C02DC00@@4a<=^Q<00`0C

4`0=4`033A<C060C00124`0341<C02HC00<04a<09Q<00a0C3@2j4`0301<C00hC0PeP4`00@A<00a0C

4`0W4`80:1<00a0C3@2i4`0301<C010C00<=4a<0GA<0040C00<@4a<0:1<00`0C4`0X4`0341<=0;PC

00<04a<04A<23EdC00104`0341<C028C0`034`0301<C02TC00<@4`d0]a<201@C00<=4a<0FQ<003lC

00<@4a<08a<00`0C4`034`0301<C02TC00<@4`d0]a<00`0C4`0D4`033A<C05TC000n4`0341<C02DC

00<04a<00Q<202/C00<@4`d0]Q<00`0C4`0E4`033A<C05PC000m4`0341<C02HC00<04a<00Q<00`0C

4`0[4`0341<=0;DC00<04a<05Q<00`dC4`1G4`00?A<00a0C4`0U4`0301<000<C00<04a<0;1<00a0C

3@2d4`0301<C01LC00<=4a<0EQ<003`C00<@4a<09a<00`0C4`024`0301<C02dC00<@3A<0/a<201TC

0PeF4`00>a<00a0C4`0]4`80;a<00a0=4`2b4`0301<C01XC0PeD4`00>Q<00a0C4`0^4`0301<C02hC

00<@4`d0/Q<00`0C4`0L4`8=DQ<003XC00<@4a<0;Q<00`0C4`0_4`0340dC0;4C00<04a<07Q<00`dC

4`1?4`00>A<00a0C4`0_4`0301<C030C00<@3A<0/1<00`0C4`0O4`8=Ca<003PC00<@4a<0<1<2038C

00<@3A<0[a<2028C00<=4a<0C1<003LC00<@4a<0<A<00`0C4`0a4`0341<=0:lC00<04a<08Q<23D`C

000g4`0341<C034C00<04a<0<Q<00a0=4`2M4`D00Q<00`0C4`024`0301<C008C00<04a<091<00`dC

4`194`00=Q<00a0C4`0b4`0301<C03<C00<@3A<0WQ<00`0C4`064`0301<000<C00<04a<09A<23DTC

000e4`0341<C03<C0P0e4`0340dC09dC00<04a<021<0100C4a<202PC0Pe74`00=1<00a0C4`0d4`03

01<C03DC00<@3A<0W1<00`0C4`064`8011<00`0C4`0Y4`8=AA<003<C00<@4a<0=A<00`0C4`0f4`03

3A<C09/C00<04a<01Q<00`0C4`034`0301<C02/C00<=4a<0@Q<0038C00<@4a<0=Q<00`0C4`0f4`03

40dC09XC0P084`<00a<00`0C4`0/4`8=@Q<0034C00<@4a<0=a<203PC00<@3A<0ZA<00`0C4`0^4`03

3A<C03lC000`4`0341<C03PC00<04a<0>1<00a0=4`2X4`80<1<23ClC000_4`0341<C02TC0`034`03

01<C008C00<04a<00Q<00`0C4`0i4`033A<C0:LC00<04a<0<A<23CdC000^4`0341<C02XC00<04a<0

1a<00`0C00034`0301<C03XC00<=4a<0YQ<00`0C4`0c4`8=>a<002dC00<@4a<0;1<00`0C4`084`04

01<C4`80?1<00`dC4`2U4`0301<C03DC0Pdi4`00;1<00a0C4`0]4`0301<C00HC0P044`0301<C03`C

00<=4a<0Y1<00`0C4`0g4`8==a<002/C00<@4a<0;A<00`0C00074`0301<C00<C00<04a<0?1<00`d@

4`2T4`80>Q<23CDC000Z4`0341<C02lC00<04a<01Q<300<C00<04a<0?A<00`d@4`2S4`0301<C03/C

00<=4a<0<Q<002TC00<@4a<0?a<203lC00<=41<0XQ<00`0C4`0l4`<=<A<002PC00<@4a<0@1<00`0C

4`0o4`033A0C0:4C00<04a<0?a<23BlC000W4`0341<C044C00<04a<0?a<00`dC402Q4`0301<C044C

0Pd]4`009Q<00a0C4`124`0301<C040C00<=4a00X1<204@C0`dZ4`009A<00a0C4`134`80@Q<00`dC

402O4`0301<C04DC0`dX4`0091<00a0C4`144`0301<C048C00<=4a00WQ<00`0C4`184`8=9Q<002<C

00<@4a<0AA<00`0C4`124`043A<C49dC00<04a<0BQ<23B@C000S4`0341<C04DC00<04a<0@a<010dC

4a2L4`0301<C04`C0PdR4`008Q<00a0C4`164`80AA<010dC4a2K4`80Ca<33AlC000Q4`0341<C04LC

00<04a<0A1<01@dC4a<@09XC00<04a<0DA<23AdC000P4`0341<C04PC00<04a<0AA<01@dC4a<@09TC

00<04a<0Da<33AXC000O4`0341<C04TC00<04a<0AQ<01@dC4a<@098C0`034`0301<C05HC00<=4a<0

5a<001hC00<@4a<0BQ<204PC00D=4a<C402A4`0301<C00<C00<04a<0Ea<33AHC000M4`0341<C04/C

00<04a<0Aa<00`dC4`024`0341<C08lC00<04a<00Q<205/C0`dC4`0071<00a0C4`1<4`0301<C04PC

00<=4a<00Q<00a0C4`2>4`0301<C008C00<04a<0G1<33A4C000K4`0341<C04LC0P044`0301<C04TC

00<=4a<00Q<00a0C4`2<4`0301<000<C00<04a<0L1<001XC00<@4a<0BQ<01@0C4a<004`C00<=4a<0

0Q<00a0C4`2<4`0301<C008C00<04a<0L1<001TC00<@4a<0BQ<00`0C4`024`80C1<01@dC4a<@09<C

00<04a<0L1<006LC00<04a<0ia<2074C001U4`0301<00?lCGA<006HC00<04a<0oa=L4`00;1<30?lC

UQ<002`C00<04a<0oa>F4`00;A<00`0C4`054`0301<C0?lCSA<002dC00@04a<C0`0011<04a<30?lC

RQ<002`C00<04`000Q<2008C00<04a<00Q<00`0C4`3o4dPC00<04a<0<Q<00`0C4`084`00;A<00`0C

4`034`0401<C008C00<04a<0oa=14`0301<C00@C00<04a<04a<00`0C4`0N4`0301<C00LC000c4`04

01<C00<C00<04a<01Q<00`0C4`0U4`<0;A<00`0C4`3<4`0401<C4`@00Q<200HC00<04a<00a<00`0C

4`024`0301<C008C00<04a<00Q<00`0C4`054`0401<C4`D00Q<0100C4a<200<C0`054`8011<0100C

4a<2004C0@0100007A<300034`00008031<300@C0`084`0301<C02@C00@04a<04A<300034`000080

0Q<00`0C4`024`0301<C008C00<04a<01A<0100C4a<5008C00@04a<C0P034`<01A<20;0C00<04`00

1a<00`0C4`044`D00a<01`0C4a<04`001a<00`0C00044`D00a<00`0C4`084`0401<C00HC00<04a<0

11<00`0C4`024`0301<0004C000L4`0401<C02@C00<04a<08a<0100C4`0@4`0401<C00HC00<04`00

1a<00`0C00044`D00a<00`0C4`084`0401<C00HC00<04a<0UQ<200034`0001DC00<04`000Q<40003

4`0C00LC00<04a<00a<01`0C4a<04`002A<00`0C4`044`0301<C00<C00<04a<01a<00`0C4`024`03

01<C00<C00<04a<011<00`0C4`034`400A<14`0071<01@0C4`0C00@000<C0000600[4`<041<01@0C

4`0C00@000@C01<02A<00`0C4`044`0301<C00<C00<04a<01a<00`0C4`024`0301<C00<C00<04a<0

Ua<00`0C000F4`0301<000LC00<04a<01Q<00`0C4`034`0701<C4`0C00074`801a<00`0C4`034`03

01<C00PC00D04a<C00054`0301<C00@C00<04a<00a<1004C0A<001dC0`1=4`0301<C00lC0`064`03

01<000LC0P074`0301<C00<C00<04a<021<01@0C4a<000DC00<04a<0V1<00`0C4`0E4`0301<000LC

00<04`003A<01P0C4`0C00LC00<04a<031<00`0C4`064`0301<0008C00<04`0011<00`0C00034`03

01<C00<C00<04`000A<001lC00<04a<0BQ<201<C00<04a<011<00`0C00074`0301<C00`C00<04a<0

1Q<00`0C00024`0301<000@C00<04`00V1<00`0C4`0F4`0301<C00HC0`0>4`0401<C00PC0`0;4`80

2A<00`0C4`024`0301<C00<C0`024`0301<C00<C0P014`400@0001hC0P1P4`801a<00`0C4`064`<0

2a<200TC00<04a<00Q<00`0C4`034`<0Ua<00`0C001a4`00oa=@4`8000<C0000L1<002TC0P064`80

oa>B4`00:a<00`0C4`024`0301<C0?lCTQ<002XC00<04a<00a<00`0C4`054`0301<C0?lCRQ<002/C

00<04a<00Q<00`0C4`024`@00a<30?lCQQ<002TC00<04`0011<00`0C00024`8000<C01<011<00`0C

4`3o4h@C000Z4`0301<C00<C0`044`0301<000<C00<04a<0oa>54`00=a<00`0C00044`0301<C0?lC

Q1<003DC0`044`<0oa>64`00oa?54`00oa?54`00oa?54`00oa?54`00oa?54`00\

\>"],

  ImageRangeCache->{{{0, 451}, {203.813, 0}} -> {-0.0537225, -0.0226806, 

  0.00467283, 0.00467283}, {{11.4375, 215.25}, {198.938, 

  4.8125}} -> {-2.63411, -1.22941, 0.0244682, 0.0244682}, {{235.688, 439.5}, {

  198.938, 4.8125}} -> {-6.95686, -1.48328, 0.0206072, 0.0206072}}]

}, Closed]]

}, Open  ]]

}, Open  ]]

}, Open  ]],



Cell[CellGroupData[{



Cell[TextData[StyleBox["4  References", "Section",

  FontFamily->"Times New Roman",

  FontSize->18]], "Section",

  FontFamily->"Times New Roman",

  FontSize->18],



Cell[BoxData[{

    RowBox[{

      RowBox[{

        StyleBox[\(1.  Chow\),

          FontFamily->"Times New Roman",

          FontSize->16], 

        StyleBox[",",

          FontFamily->"Times New Roman",

          FontSize->16], 

        StyleBox[\(S . C . \),

          FontFamily->"Times New Roman",

          FontSize->16], 

        StyleBox[",",

          FontFamily->"Times New Roman",

          FontSize->16], 

        StyleBox[" ",

          FontFamily->"Times New Roman"], 

        StyleBox["Hale",

          FontFamily->"Times New Roman"], 

        StyleBox[",",

          FontFamily->"Times New Roman"], 

        StyleBox[" ",

          FontFamily->"Times New Roman"], 

        StyleBox[\(J . K . \ Chapter\ 5\),

          FontFamily->"Times New Roman"], 

        StyleBox[",",

          FontFamily->"Times New Roman"], 

        StyleBox[" ",

          FontFamily->"Times New Roman",

          FontSlant->"Italic"], 

        StyleBox[\(Methods\ of\ Bifurcation\ Theory\),

          FontFamily->"Times New Roman",

          FontSlant->"Italic"], 

        StyleBox[",",

          FontFamily->"Times New Roman",

          FontSlant->"Italic"], "\n", 

        StyleBox[

          RowBox[{"   ", 

            StyleBox[" ",

              FontFamily->"Times New Roman"]}]], 

        StyleBox[\(Springer - Verlag\),

          FontFamily->"Times New Roman"], 

        StyleBox[",",

          FontFamily->"Times New Roman"], 

        StyleBox[" ",

          FontFamily->"Times New Roman"], 

        StyleBox[\(Berlin\ and\ New\ York\),

          FontFamily->"Times New Roman"], 

        StyleBox[",",

          FontFamily->"Times New Roman"], 

        StyleBox[" ",

          FontFamily->"Times New Roman"], 

        StyleBox["1982.",

          FontFamily->"Times New Roman"]}], "\n"}], 

    StyleBox[\(2. \  Wolkowisky, J . H . , \ 

      Buckling\ of\ the\ Circular\ Plate\ Embedded\ in\ Elastic\),

      FontFamily->"Times New Roman"], 

    RowBox[{"    ", 

      RowBox[{

        StyleBox["Springs",

          FontFamily->"Times New Roman"], 

        StyleBox[",",

          FontFamily->"Times New Roman"], 

        StyleBox[" ",

          FontFamily->"Times New Roman"], 

        StyleBox[\(An\ Application\ to\ Geophysics\),

          FontFamily->"Times New Roman"], 

        StyleBox[",",

          FontFamily->"Times New Roman"], 

        StyleBox[" ",

          FontFamily->"Times New Roman"], 

        StyleBox[\(Communications\ on\ Pure\ and\),

          FontFamily->"Times New Roman",

          FontSlant->"Italic"]}], 

      StyleBox[" ",

        FontFamily->"Times New Roman",

        FontSlant->"Italic"]}], 

    RowBox[{

      StyleBox[

        StyleBox[

          RowBox[{"   ", 

            StyleBox[" ",

              FontFamily->"Times New Roman"]}]],

        FontSlant->"Italic"], 

      RowBox[{

        StyleBox[\(Applied\ Mathematics\),

          FontFamily->"Times New Roman",

          FontSlant->"Italic"], 

        StyleBox[",",

          FontFamily->"Times New Roman"], 

        StyleBox["1969",

          FontFamily->"Times New Roman"], 

        StyleBox[",",

          FontFamily->"Times New Roman"], 

        StyleBox[" ",

          FontFamily->"Times New Roman"], 

        StyleBox["22",

          FontFamily->"Times New Roman"], 

        StyleBox[",",

          FontFamily->"Times New Roman"], 

        StyleBox[" ",

          FontFamily->"Times New Roman"], 

        StyleBox[\(639 - 667. \),

          FontFamily->"Times New Roman"]}]}]}], "Input",

  FontSize->16]

}, Open  ]]

}, Open  ]]

},

FrontEndVersion->"Microsoft Windows 3.0",

ScreenRectangle->{{0, 1024}, {0, 687}},

AutoGeneratedPackage->None,

WindowSize->{746, 530},

WindowMargins->{{Automatic, 120}, {Automatic, 32}},

PrintingCopies->1,

PrintingPageRange->{Automatic, Automatic}

]





(***********************************************************************

Cached data follows.  If you edit this Notebook file directly, not using

Mathematica, you must remove the line containing CacheID at the top of 

the file.  The cache data will then be recreated when you save this file 

from within Mathematica.

***********************************************************************)



(*CellTagsOutline

CellTagsIndex->{}

*)



(*CellTagsIndex

CellTagsIndex->{}

*)



(*NotebookFileOutline

Notebook[{



Cell[CellGroupData[{

Cell[1731, 51, 217, 7, 150, "Title"],

Cell[1951, 60, 204, 8, 180, "Subtitle"],



Cell[CellGroupData[{

Cell[2180, 72, 123, 5, 55, "Section"],



Cell[CellGroupData[{

Cell[2328, 81, 7063, 243, 1035, "Input"],

Cell[9394, 326, 48987, 806, 608, 48864, 802, "GraphicsData", 

"Bitmap", "Graphics"]

}, Open  ]],

Cell[58396, 1135, 685, 11, 180, "Input"]

}, Open  ]],



Cell[CellGroupData[{

Cell[59118, 1151, 132, 2, 54, "Section"],

Cell[59253, 1155, 37888, 623, 460, 37794, 620, "GraphicsData", 

"Bitmap", "Graphics"],



Cell[CellGroupData[{

Cell[97166, 1782, 86, 1, 50, "Subsection"],

Cell[97255, 1785, 4205, 142, 552, "Input"]

}, Open  ]],



Cell[CellGroupData[{

Cell[101497, 1932, 85, 1, 50, "Subsection"],

Cell[101585, 1935, 1257, 37, 327, "Input"],

Cell[102845, 1974, 1759, 49, 58, "Input"],

Cell[104607, 2025, 2153, 59, 80, "Input"],

Cell[106763, 2086, 344, 14, 33, "Input"],

Cell[107110, 2102, 1062, 27, 94, "Input"],

Cell[108175, 2131, 594, 26, 54, "Input"],

Cell[108772, 2159, 910, 31, 55, "Input"],

Cell[109685, 2192, 1610, 67, 96, "Input"],

Cell[111298, 2261, 914, 20, 320, "Input"],

Cell[112215, 2283, 359, 14, 75, "Input"],

Cell[112577, 2299, 78, 2, 30, "Input"],

Cell[112658, 2303, 331, 9, 51, "Input"],

Cell[112992, 2314, 699, 24, 159, "Input"],

Cell[113694, 2340, 227, 7, 30, "Input"],



Cell[CellGroupData[{

Cell[113946, 2351, 85, 2, 33, "Input"],

Cell[114034, 2355, 102, 3, 31, "Output"]

}, Open  ]],

Cell[114151, 2361, 351, 14, 96, "Input"],

Cell[114505, 2377, 305, 6, 90, "Input"],

Cell[114813, 2385, 482, 19, 75, "Input"],



Cell[CellGroupData[{

Cell[115320, 2408, 80, 2, 30, "Input"],

Cell[115403, 2412, 27285, 1037, 380, 14443, 873, "GraphicsData", 

"PostScript", "Graphics"]

}, Open  ]]

}, Open  ]],



Cell[CellGroupData[{

Cell[142737, 3455, 119, 2, 50, "Subsection"],

Cell[142859, 3459, 16474, 488, 756, "Input"],

Cell[159336, 3949, 2272, 49, 190, "Input"],

Cell[161611, 4000, 225, 8, 96, "Input"],

Cell[161839, 4010, 101, 2, 30, "Input"],

Cell[161943, 4014, 2102, 47, 150, "Input"],

Cell[164048, 4063, 180, 4, 70, "Input"],

Cell[164231, 4069, 200, 5, 54, "Input"],

Cell[164434, 4076, 1084, 28, 408, "Input",

  InitializationCell->True],

Cell[165521, 4106, 294, 8, 117, "Input"],

Cell[165818, 4116, 323, 10, 102, "Input",

  InitializationCell->True],

Cell[166144, 4128, 125, 7, 96, "Input"],

Cell[166272, 4137, 542, 12, 56, "Input"],

Cell[166817, 4151, 301, 8, 56, "Input"],

Cell[167121, 4161, 72, 1, 50, "Input"],

Cell[167196, 4164, 131, 2, 50, "Input"],

Cell[167330, 4168, 682, 16, 156, "Input",

  InitializationCell->True],

Cell[168015, 4186, 260, 8, 30, "Input",

  InitializationCell->True],

Cell[168278, 4196, 502, 19, 56, "Input"],

Cell[168783, 4217, 2371, 51, 210, "Input"]

}, Open  ]],



Cell[CellGroupData[{

Cell[171191, 4273, 59, 1, 50, "Subsection"],

Cell[171253, 4276, 360, 9, 76, "Input"],



Cell[CellGroupData[{

Cell[171638, 4289, 1168, 26, 130, "Input"],



Cell[CellGroupData[{

Cell[172831, 4319, 40080, 1691, 359, 23877, 1486, "GraphicsData", 

"PostScript", "Graphics"],

Cell[212914, 6012, 39067, 1597, 186, 22142, 1383, "GraphicsData", 

"PostScript", "Graphics"],

Cell[251984, 7611, 44958, 1825, 186, 25167, 1576, "GraphicsData", 

"PostScript", "Graphics"],

Cell[296945, 9438, 39566, 1510, 186, 20286, 1267, "GraphicsData", 

"PostScript", "Graphics"],

Cell[336514, 10950, 55772, 2514, 186, 35742, 2262, "GraphicsData", 

"PostScript", "Graphics"],

Cell[392289, 13466, 65875, 3161, 186, 45719, 2907, "GraphicsData", 

"PostScript", "Graphics"],

Cell[458167, 16629, 78028, 3937, 186, 57953, 3684, "GraphicsData", 

"PostScript", "Graphics"],

Cell[536198, 20568, 78848, 3973, 186, 58494, 3717, "GraphicsData", 

"PostScript", "Graphics"],

Cell[615049, 24543, 75737, 3777, 186, 55309, 3520, "GraphicsData", 

"PostScript", "Graphics"],

Cell[690789, 28322, 63933, 3085, 186, 44923, 2845, "GraphicsData", 

"PostScript", "Graphics"],

Cell[754725, 31409, 44130, 1955, 186, 27735, 1747, "GraphicsData", 

"PostScript", "Graphics"]

}, Closed]]

}, Open  ]],

Cell[798882, 33368, 782, 30, 135, "Input"],



Cell[CellGroupData[{

Cell[799689, 33402, 49, 1, 30, "Input"],

Cell[799741, 33405, 38, 1, 29, "Output"]

}, Open  ]],

Cell[799794, 33409, 62, 1, 30, "Input"],



Cell[CellGroupData[{

Cell[799881, 33414, 276, 5, 70, "Input"],

Cell[800160, 33421, 45597, 2433, 186, 35962, 2310, "GraphicsData", 

"PostScript", "Graphics"],

Cell[845760, 35856, 130, 3, 29, "Output"]

}, Open  ]],

Cell[845905, 35862, 812, 12, 230, "Input"],

Cell[846720, 35876, 235, 12, 138, "Input",

  InitializationCell->True],

Cell[846958, 35890, 411, 7, 110, "Input"],

Cell[847372, 35899, 228, 5, 70, "Input"],

Cell[847603, 35906, 165, 3, 50, "Input"],



Cell[CellGroupData[{

Cell[847793, 35913, 60, 1, 30, "Input"],



Cell[CellGroupData[{

Cell[847878, 35918, 60164, 3016, 198, 44451, 2817, "GraphicsData", 

"PostScript", "Graphics"],

Cell[908045, 38936, 60255, 3017, 198, 44453, 2817, "GraphicsData", 

"PostScript", "Graphics"],

Cell[968303, 41955, 60252, 3017, 198, 44450, 2817, "GraphicsData", 

"PostScript", "Graphics"],

Cell[1028558, 44974, 60194, 3015, 198, 44416, 2815, "GraphicsData", 

"PostScript", "Graphics"],

Cell[1088755, 47991, 60420, 3017, 198, 44415, 2814, "GraphicsData", 

"PostScript", "Graphics"],

Cell[1149178, 51010, 60296, 3014, 198, 44360, 2812, "GraphicsData", 

"PostScript", "Graphics"],

Cell[1209477, 54026, 60469, 3016, 198, 44371, 2812, "GraphicsData", 

"PostScript", "Graphics"],

Cell[1269949, 57044, 60129, 2994, 198, 44048, 2791, "GraphicsData", 

"PostScript", "Graphics"],

Cell[1330081, 60040, 60155, 2995, 198, 44033, 2791, "GraphicsData", 

"PostScript", "Graphics"],

Cell[1390239, 63037, 60359, 3016, 198, 44395, 2814, "GraphicsData", 

"PostScript", "Graphics"],

Cell[1450601, 66055, 60636, 3024, 198, 44498, 2820, "GraphicsData", 

"PostScript", "Graphics"],

Cell[1511240, 69081, 60687, 3026, 198, 44508, 2821, "GraphicsData", 

"PostScript", "Graphics"],

Cell[1571930, 72109, 60485, 3023, 198, 44517, 2821, "GraphicsData", 

"PostScript", "Graphics"],

Cell[1632418, 75134, 60556, 3021, 198, 44438, 2817, "GraphicsData", 

"PostScript", "Graphics"],

Cell[1692977, 78157, 60514, 3020, 198, 44447, 2817, "GraphicsData", 

"PostScript", "Graphics"],

Cell[1753494, 81179, 60651, 3024, 198, 44474, 2819, "GraphicsData", 

"PostScript", "Graphics"],

Cell[1814148, 84205, 60247, 3023, 198, 44576, 2825, "GraphicsData", 

"PostScript", "Graphics"],

Cell[1874398, 87230, 60272, 3025, 198, 44600, 2827, "GraphicsData", 

"PostScript", "Graphics"],

Cell[1934673, 90257, 60273, 3023, 198, 44536, 2824, "GraphicsData", 

"PostScript", "Graphics"],

Cell[1994949, 93282, 60265, 3020, 198, 44512, 2821, "GraphicsData", 

"PostScript", "Graphics"],

Cell[2055217, 96304, 60415, 3018, 198, 44431, 2816, "GraphicsData", 

"PostScript", "Graphics"],

Cell[2115635, 99324, 60306, 3017, 198, 44431, 2816, "GraphicsData", 

"PostScript", "Graphics"],

Cell[2175944, 102343, 60661, 3029, 198, 44584, 2826, "GraphicsData", 

"PostScript", "Graphics"],

Cell[2236608, 105374, 60592, 3025, 198, 44506, 2821, "GraphicsData", 

"PostScript", "Graphics"],

Cell[2297203, 108401, 60408, 3019, 198, 44452, 2817, "GraphicsData", 

"PostScript", "Graphics"],

Cell[2357614, 111422, 59755, 3011, 198, 44435, 2817, "GraphicsData", 

"PostScript", "Graphics"],

Cell[2417372, 114435, 60630, 3024, 198, 44496, 2820, "GraphicsData", 

"PostScript", "Graphics"],

Cell[2478005, 117461, 60353, 3018, 198, 44454, 2817, "GraphicsData", 

"PostScript", "Graphics"],

Cell[2538361, 120481, 59898, 2992, 198, 44039, 2791, "GraphicsData", 

"PostScript", "Graphics"],

Cell[2598262, 123475, 59564, 2966, 198, 43616, 2764, "GraphicsData", 

"PostScript", "Graphics"],

Cell[2657829, 126443, 60221, 3011, 198, 44330, 2810, "GraphicsData", 

"PostScript", "Graphics"],

Cell[2718053, 129456, 60292, 3017, 198, 44437, 2816, "GraphicsData", 

"PostScript", "Graphics"],

Cell[2778348, 132475, 60368, 3014, 198, 44372, 2812, "GraphicsData", 

"PostScript", "Graphics"],

Cell[2838719, 135491, 60521, 3020, 198, 44444, 2817, "GraphicsData", 

"PostScript", "Graphics"],

Cell[2899243, 138513, 59547, 3008, 198, 44401, 2816, "GraphicsData", 

"PostScript", "Graphics"],

Cell[2958793, 141523, 60239, 3016, 198, 44429, 2816, "GraphicsData", 

"PostScript", "Graphics"],

Cell[3019035, 144541, 60010, 3010, 198, 44362, 2812, "GraphicsData", 

"PostScript", "Graphics"],

Cell[3079048, 147553, 60035, 3012, 198, 44395, 2814, "GraphicsData", 

"PostScript", "Graphics"],

Cell[3139086, 150567, 60063, 3014, 198, 44427, 2816, "GraphicsData", 

"PostScript", "Graphics"],

Cell[3199152, 153583, 60225, 3015, 198, 44415, 2815, "GraphicsData", 

"PostScript", "Graphics"],

Cell[3259380, 156600, 60145, 3013, 198, 44388, 2814, "GraphicsData", 

"PostScript", "Graphics"]

}, Closed]]

}, Open  ]]

}, Open  ]],



Cell[CellGroupData[{

Cell[3319586, 159620, 68, 1, 34, "Subsection"],



Cell[CellGroupData[{

Cell[3319679, 159625, 1713, 34, 423, "Input"],

Cell[3321395, 159661, 23108, 381, 578, 23012, 378, "GraphicsData", 

"Bitmap", "Graphics"]

}, Open  ]],

Cell[3344518, 160045, 868, 17, 228, "Input"],

Cell[3345389, 160064, 130, 6, 48, "Input"],

Cell[3345522, 160072, 752, 19, 246, "Input"],

Cell[3346277, 160093, 179, 3, 70, "Input"],

Cell[3346459, 160098, 153, 4, 57, "Input"],



Cell[CellGroupData[{

Cell[3346637, 160106, 76, 1, 30, "Input"],



Cell[CellGroupData[{

Cell[3346738, 160111, 34852, 1270, 213, 20267, 1084, "GraphicsData", 

"PostScript", "Graphics"],

Cell[3381593, 161383, 34901, 1270, 213, 20311, 1084, "GraphicsData", 

"PostScript", "Graphics"],

Cell[3416497, 162655, 34813, 1270, 213, 20271, 1084, "GraphicsData", 

"PostScript", "Graphics"],

Cell[3451313, 163927, 35130, 1273, 139, 20301, 1084, "GraphicsData", 

"PostScript", "Graphics"],

Cell[3486446, 165202, 35042, 1273, 139, 20253, 1084, "GraphicsData", 

"PostScript", "Graphics"],

Cell[3521491, 166477, 35064, 1273, 139, 20267, 1084, "GraphicsData", 

"PostScript", "Graphics"],

Cell[3556558, 167752, 35015, 1272, 139, 20283, 1084, "GraphicsData", 

"PostScript", "Graphics"],

Cell[3591576, 169026, 35068, 1272, 139, 20312, 1084, "GraphicsData", 

"PostScript", "Graphics"],

Cell[3626647, 170300, 34981, 1272, 139, 20289, 1084, "GraphicsData", 

"PostScript", "Graphics"],

Cell[3661631, 171574, 35081, 1273, 139, 20292, 1084, "GraphicsData", 

"PostScript", "Graphics"],

Cell[3696715, 172849, 34863, 1270, 139, 20269, 1084, "GraphicsData", 

"PostScript", "Graphics"],

Cell[3731581, 174121, 35022, 1272, 139, 20274, 1084, "GraphicsData", 

"PostScript", "Graphics"],

Cell[3766606, 175395, 34806, 1269, 139, 20306, 1084, "GraphicsData", 

"PostScript", "Graphics"],

Cell[3801415, 176666, 34882, 1270, 139, 20300, 1084, "GraphicsData", 

"PostScript", "Graphics"],

Cell[3836300, 177938, 34818, 1269, 139, 20301, 1084, "GraphicsData", 

"PostScript", "Graphics"],

Cell[3871121, 179209, 34841, 1270, 139, 20276, 1084, "GraphicsData", 

"PostScript", "Graphics"],

Cell[3905965, 180481, 35022, 1272, 139, 20302, 1084, "GraphicsData", 

"PostScript", "Graphics"],

Cell[3940990, 181755, 34991, 1272, 139, 20261, 1084, "GraphicsData", 

"PostScript", "Graphics"],

Cell[3975984, 183029, 34917, 1270, 139, 20315, 1084, "GraphicsData", 

"PostScript", "Graphics"],

Cell[4010904, 184301, 35015, 1272, 139, 20307, 1084, "GraphicsData", 

"PostScript", "Graphics"],

Cell[4045922, 185575, 34916, 1268, 139, 20281, 1081, "GraphicsData", 

"PostScript", "Graphics"],

Cell[4080841, 186845, 34946, 1268, 139, 20268, 1081, "GraphicsData", 

"PostScript", "Graphics"],

Cell[4115790, 188115, 34881, 1268, 139, 20272, 1081, "GraphicsData", 

"PostScript", "Graphics"],

Cell[4150674, 189385, 34916, 1268, 139, 20274, 1081, "GraphicsData", 

"PostScript", "Graphics"],

Cell[4185593, 190655, 34888, 1267, 139, 20282, 1081, "GraphicsData", 

"PostScript", "Graphics"],

Cell[4220484, 191924, 34998, 1269, 139, 20286, 1081, "GraphicsData", 

"PostScript", "Graphics"],

Cell[4255485, 193195, 34924, 1268, 139, 20268, 1081, "GraphicsData", 

"PostScript", "Graphics"],

Cell[4290412, 194465, 34917, 1268, 139, 20274, 1081, "GraphicsData", 

"PostScript", "Graphics"],

Cell[4325332, 195735, 34843, 1267, 139, 20241, 1081, "GraphicsData", 

"PostScript", "Graphics"],

Cell[4360178, 197004, 34931, 1268, 139, 20264, 1081, "GraphicsData", 

"PostScript", "Graphics"],

Cell[4395112, 198274, 34538, 1261, 139, 20239, 1078, "GraphicsData", 

"PostScript", "Graphics"],

Cell[4429653, 199537, 34704, 1264, 139, 20267, 1080, "GraphicsData", 

"PostScript", "Graphics"],

Cell[4464360, 200803, 34580, 1263, 139, 20285, 1080, "GraphicsData", 

"PostScript", "Graphics"],

Cell[4498943, 202068, 34581, 1263, 139, 20234, 1080, "GraphicsData", 

"PostScript", "Graphics"],

Cell[4533527, 203333, 34510, 1262, 139, 20248, 1080, "GraphicsData", 

"PostScript", "Graphics"],

Cell[4568040, 204597, 34627, 1263, 139, 20276, 1080, "GraphicsData", 

"PostScript", "Graphics"],

Cell[4602670, 205862, 34677, 1264, 139, 20271, 1080, "GraphicsData", 

"PostScript", "Graphics"],

Cell[4637350, 207128, 34688, 1264, 139, 20256, 1080, "GraphicsData", 

"PostScript", "Graphics"],

Cell[4672041, 208394, 34569, 1263, 139, 20251, 1080, "GraphicsData", 

"PostScript", "Graphics"],

Cell[4706613, 209659, 34586, 1258, 139, 20172, 1074, "GraphicsData", 

"PostScript", "Graphics"],

Cell[4741202, 210919, 34448, 1257, 139, 20137, 1074, "GraphicsData", 

"PostScript", "Graphics"],

Cell[4775653, 212178, 34572, 1258, 139, 20172, 1074, "GraphicsData", 

"PostScript", "Graphics"],

Cell[4810228, 213438, 34480, 1257, 139, 20169, 1074, "GraphicsData", 

"PostScript", "Graphics"],

Cell[4844711, 214697, 34368, 1256, 139, 20162, 1074, "GraphicsData", 

"PostScript", "Graphics"],

Cell[4879082, 215955, 34306, 1255, 139, 20165, 1074, "GraphicsData", 

"PostScript", "Graphics"],

Cell[4913391, 217212, 34556, 1258, 139, 20165, 1074, "GraphicsData", 

"PostScript", "Graphics"],

Cell[4947950, 218472, 34483, 1257, 139, 20168, 1074, "GraphicsData", 

"PostScript", "Graphics"],

Cell[4982436, 219731, 34498, 1257, 139, 20155, 1074, "GraphicsData", 

"PostScript", "Graphics"],

Cell[5016937, 220990, 35978, 1360, 139, 21716, 1178, "GraphicsData", 

"PostScript", "Graphics"],

Cell[5052918, 222352, 36117, 1362, 139, 21741, 1178, "GraphicsData", 

"PostScript", "Graphics"],

Cell[5089038, 223716, 35876, 1359, 139, 21705, 1178, "GraphicsData", 

"PostScript", "Graphics"],

Cell[5124917, 225077, 35855, 1359, 139, 21720, 1178, "GraphicsData", 

"PostScript", "Graphics"],

Cell[5160775, 226438, 36057, 1361, 139, 21754, 1178, "GraphicsData", 

"PostScript", "Graphics"],

Cell[5196835, 227801, 36127, 1362, 139, 21752, 1178, "GraphicsData", 

"PostScript", "Graphics"],

Cell[5232965, 229165, 36067, 1361, 139, 21752, 1178, "GraphicsData", 

"PostScript", "Graphics"],

Cell[5269035, 230528, 36054, 1358, 139, 21727, 1175, "GraphicsData", 

"PostScript", "Graphics"],

Cell[5305092, 231888, 35947, 1357, 139, 21701, 1175, "GraphicsData", 

"PostScript", "Graphics"],

Cell[5341042, 233247, 35992, 1357, 139, 21730, 1175, "GraphicsData", 

"PostScript", "Graphics"],

Cell[5377037, 234606, 35894, 1356, 139, 21717, 1175, "GraphicsData", 

"PostScript", "Graphics"],

Cell[5412934, 235964, 35777, 1356, 139, 21693, 1176, "GraphicsData", 

"PostScript", "Graphics"],

Cell[5448714, 237322, 35727, 1355, 139, 21740, 1176, "GraphicsData", 

"PostScript", "Graphics"],

Cell[5484444, 238679, 35930, 1357, 139, 21729, 1176, "GraphicsData", 

"PostScript", "Graphics"],

Cell[5520377, 240038, 35916, 1357, 139, 21751, 1176, "GraphicsData", 

"PostScript", "Graphics"],

Cell[5556296, 241397, 35953, 1357, 213, 21752, 1176, "GraphicsData", 

"PostScript", "Graphics"],

Cell[5592252, 242756, 35912, 1357, 213, 21747, 1176, "GraphicsData", 

"PostScript", "Graphics"],

Cell[5628167, 244115, 35846, 1356, 213, 21731, 1176, "GraphicsData", 

"PostScript", "Graphics"],

Cell[5664016, 245473, 35528, 1353, 213, 21655, 1176, "GraphicsData", 

"PostScript", "Graphics"]

}, Closed]]

}, Open  ]]

}, Open  ]]

}, Open  ]],



Cell[CellGroupData[{

Cell[5699617, 246834, 161, 4, 34, "Section"],

Cell[5699781, 246840, 3500, 104, 147, "Input"]

}, Open  ]]

}, Open  ]]

}

]

*)









(***********************************************************************

End of Mathematica Notebook file.

***********************************************************************)



